(*
This notebook forms part of the supporting material for the book

Elasticity with Mathematica (r)
by A. Constantinescu and A.M. Korsunsky
published by Cambridge University Press, 2007
(ISBN-13: 9780521842013)

Copyright (c) 2007 A. Constantinescu and A.M. Korsunsky

Please acknowledge the use of this material in teaching, research and 
further development.

Authors accept no responsibility for the results obtained and 
conclusions drawn on the basis of using this material.

*)


IsotropicStiffness[nu_] := 
  Array[ nu / (1 + nu)/(1 - 
                2 nu )  KroneckerDelta[#1, #2] KroneckerDelta[#3, #4] +
                         
        1/ (1 + nu)/2( 
            KroneckerDelta[#1, #3] KroneckerDelta[#2, #4] + 
              KroneckerDelta[#1, #4]KroneckerDelta[#2, #3]) &, {3, 3, 3, 3}]

IsotropicCompliance[nu_] := 
  Array[   - nu KroneckerDelta[#1, #2] KroneckerDelta[#3, #4] +
           (1 + nu) / 2  ( 
            KroneckerDelta[#1, #3] KroneckerDelta[#2, #4] + 
              KroneckerDelta[#1, #4]KroneckerDelta[#2, #3]) &, {3, 3, 3, 3}]


DDot[T4_, t2_] := GTr[GDot[T4, t2, 1, 1], 1, 4]

Strain[u_?$VecQ] := (Grad[u] + Transpose[Grad[u]])/2

Strain[sig_?$TenQ] := DDot[ IsotropicCompliance[nu] , sig ]

Stress[eps_] := DDot[ IsotropicStiffness[nu] , eps ]


