(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     54967,       1918]
NotebookOptionsPosition[     50965,       1774]
NotebookOutlinePosition[     51319,       1790]
CellTagsIndexPosition[     51276,       1787]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["\<\
General Form of the small strain tensor (after Bui - Control \
M\[EAcute]canique 1985, Ecole Polytechnique)  \
\>", "Subsection"],

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "\"\<ElasticaBook/Packages\>\"", "]"}], "\n", 
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n"}], "Input",
 CellChangeTimes->{3.402067925560688*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"eps", " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], " ", 
   RowBox[{"exy", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["exy", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{
       SuperscriptBox["exy", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]},
     {
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["exy", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "0", 
      RowBox[{
       SuperscriptBox["exy", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]},
     {
      RowBox[{
       SuperscriptBox["exy", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], 
      RowBox[{
       SuperscriptBox["exy", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{
        SuperscriptBox["exy", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["exy", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "0", ",", "2"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
  "0", "   ", "then", " ", "its", " ", "linear", " ", "function", " ", "of", 
   " ", "z"}]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"exy", "[", 
   RowBox[{"x_", ",", " ", "y_", ",", " ", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", " ", 
     RowBox[{"x", ",", " ", "y"}], "]"}], " ", "z"}], " ", "+", " ", 
   RowBox[{"b", "[", 
    RowBox[{"x", ",", "y"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{
       SuperscriptBox["a", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]},
     {"0", "0", 
      RowBox[{
       SuperscriptBox["a", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}]},
     {
      RowBox[{
       SuperscriptBox["a", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}], 
      RowBox[{
       SuperscriptBox["a", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y"}], "]"}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"z", " ", 
          RowBox[{
           SuperscriptBox["a", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"x", ",", "y"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["b", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y"}], "]"}]}], ")"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SuperscriptBox["a", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", " ", 
  RowBox[{
  "0", "   ", "then", "  ", "a", " ", "independent", " ", "of", " ", 
   "y"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SuperscriptBox["a", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", " ", 
  RowBox[{
  "0", "   ", "then", "  ", "a", " ", "independent", " ", "of", " ", 
   "x"}]}], "\[IndentingNewLine]", 
 RowBox[{"then", " ", "a", " ", "is", " ", "a", " ", 
  "constant"}]}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "[", 
   RowBox[{"x_", ",", " ", "y_"}], "]"}], " ", ":=", " ", 
  "a"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{
        SuperscriptBox["b", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y"}], "]"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["b", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "y"}], "]"}], "\[Equal]", " ", 
  RowBox[{"0", "   ", "then", "  ", "is", " "}]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", "[", 
   RowBox[{"x_", ",", " ", "y_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"bx", "[", "x", "]"}], " ", "+", " ", 
   RowBox[{"by", "[", "y", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"exy", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", "z"}], "+", 
  RowBox[{"bx", "[", "x", "]"}], "+", 
  RowBox[{"by", "[", "y", "]"}]}]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{
       RowBox[{"a", " ", "z"}], "+", 
       RowBox[{"bx", "[", "x", "]"}], "+", 
       RowBox[{"by", "[", "y", "]"}]}], "0"},
     {
      RowBox[{
       RowBox[{"a", " ", "z"}], "+", 
       RowBox[{"bx", "[", "x", "]"}], "+", 
       RowBox[{"by", "[", "y", "]"}]}], "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], " ", 
   RowBox[{"ert", "[", 
    RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["ert", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], 
      FractionBox[
       RowBox[{
        SuperscriptBox["ert", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"]},
     {
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["ert", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "r"], "+", 
       RowBox[{
        SuperscriptBox["ert", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]},
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["ert", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "r"], "+", 
       RowBox[{
        SuperscriptBox["ert", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["ert", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox["ert", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox["r", "2"]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["ert", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "0", ",", "2"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "\[Equal]", " ", 
  RowBox[{
  "0", "   ", "then", " ", "its", " ", "linear", " ", "function", " ", "of", 
   " ", "z"}]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ert", "[", 
   RowBox[{"r_", ",", " ", "t_", ",", " ", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", " ", 
     RowBox[{"r", ",", " ", "t"}], "]"}], " ", "z"}], " ", "+", " ", 
   RowBox[{"b", "[", 
    RowBox[{"r", ",", "t"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      FractionBox[
       RowBox[{
        SuperscriptBox["a", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t"}], "]"}], "r"]},
     {"0", "0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"a", "[", 
          RowBox[{"r", ",", "t"}], "]"}]}], "r"], "+", 
       RowBox[{
        SuperscriptBox["a", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t"}], "]"}]}]},
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["a", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t"}], "]"}], "r"], 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"a", "[", 
          RowBox[{"r", ",", "t"}], "]"}]}], "r"], "+", 
       RowBox[{
        SuperscriptBox["a", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t"}], "]"}]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"z", " ", 
            RowBox[{
             SuperscriptBox["a", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"r", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["b", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "t"}], "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"z", " ", 
               RowBox[{
                SuperscriptBox["a", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"r", ",", "t"}], "]"}]}], "+", 
              RowBox[{
               SuperscriptBox["b", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"r", ",", "t"}], "]"}]}], ")"}]}]}], ")"}]}], 
        SuperscriptBox["r", "2"]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["a", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"r", ",", "t"}], "]"}], "r"], "\[Equal]", " ", 
  RowBox[{
  "0", "   ", "then", " ", "its", " ", "linear", " ", "function", " ", "of", 
   " ", "z"}]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"r_", ",", " ", "t_"}], "]"}], " ", ":=", " ", 
   RowBox[{"a", "[", " ", "r", "]"}]}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"inceps", " ", "=", " ", 
    RowBox[{"Inc", "[", " ", "eps", " ", "]"}]}], ")"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"a", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{
        SuperscriptBox["a", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"a", "[", "r", "]"}]}], "r"], "+", 
       RowBox[{
        SuperscriptBox["a", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["b", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "t"}], "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox["b", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"r", ",", "t"}], "]"}]}]}], ")"}]}], 
        SuperscriptBox["r", "2"]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"inceps", "[", 
     RowBox[{"[", 
      RowBox[{"3", ",", "2"}], "]"}], "]"}], " ", "\[Equal]", " ", "0"}], " ",
    ",", " ", 
   RowBox[{"a", "[", "r", "]"}], ",", " ", "r"}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "[", "r", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"C", "[", "1", "]"}], 
     SuperscriptBox["r", "2"]]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"inceps", "[", 
    RowBox[{"[", 
     RowBox[{"3", ",", "3"}], "]"}], "]"}], " ", 
   RowBox[{
    RowBox[{
     RowBox[{"r", "^", "2"}], " ", "/", " ", "2"}], "  "}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{
    SuperscriptBox["b", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"r", ",", "t"}], "]"}]}], "-", 
  RowBox[{"r", " ", 
   RowBox[{
    SuperscriptBox["b", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"r", ",", "t"}], "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", "[", 
   RowBox[{"r", ",", "t"}], "]"}], " ", ":=", " ", 
  RowBox[{"b", "[", "r", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "[", "r", "]"}], " ", ":=", " ", 
  RowBox[{"c", "/", 
   RowBox[{"r", "^", "2"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "}"}], " ", 
   RowBox[{"erz", "[", 
    RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "r"]}], 
      FractionBox[
       RowBox[{
        SuperscriptBox["ert", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["ert", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
        SuperscriptBox["r", "2"]]}]},
     {
      FractionBox[
       RowBox[{
        SuperscriptBox["ert", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{
        SuperscriptBox["ert", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["ert", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
        SuperscriptBox["r", "2"]]}], 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["erz", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "\[Equal]", " ", 
  RowBox[{
  "0", "   ", "then", " ", "ert", " ", "is", " ", "a", " ", "function", " ", 
   "of", " ", "only", " ", "r", " ", "and", " ", "t", 
   " "}]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ert", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", ":=", " ", 
  RowBox[{"ert", "[", 
   RowBox[{"r", ",", "t"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["ert", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t"}], "]"}], 
        SuperscriptBox["r", "2"]]}]},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t"}], "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["ert", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t"}], "]"}], 
        SuperscriptBox["r", "2"]]}], 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t"}], "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["ert", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["erz", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "2"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"r", ",", "t"}], "]"}], "\[Equal]", " ", 
  RowBox[{
  "0", "   ", "then", " ", "ert", " ", "is", " ", "a", " ", "linear", " ", 
   "function", " ", "of", " ", "t", " "}]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"erz", "[", 
   RowBox[{"r", ",", "t"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "r", "]"}], " ", "t"}], " ", "+", " ", 
   RowBox[{"b", "[", "r", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{"a", "[", "r", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{"a", "[", "r", "]"}]}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["a", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], 
       SuperscriptBox["r", "2"]], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"a", "[", "r", "]"}]}], "+", 
     RowBox[{"r", " ", 
      RowBox[{
       SuperscriptBox["a", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], " ", "\[Equal]", " ", 
    "0"}], ",", " ", 
   RowBox[{"a", "[", "r", "]"}], ",", " ", "r"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "[", "r", "]"}], "\[Rule]", 
    RowBox[{"r", " ", 
     RowBox[{"C", "[", "1", "]"}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"erz", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"a", " ", "r", " ", "t"}], " ", "+", " ", 
   RowBox[{"b", "[", "r", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Only", "     ", "etz"}], " ", "=!=", " ", "0"}]], "Subsection"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}], " ", 
   RowBox[{"etz", "[", 
    RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "//", " ", "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", 
      RowBox[{"etz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]},
     {"0", 
      RowBox[{"etz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["etz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "r"]}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["etz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"]}], "+", 
       RowBox[{
        SuperscriptBox["etz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["etz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["etz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["etz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"]}], "+", 
       RowBox[{
        SuperscriptBox["etz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "0", 
      FractionBox[
       RowBox[{
        RowBox[{"etz", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["etz", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox["etz", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "0", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["etz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["etz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]], 
      FractionBox[
       RowBox[{
        RowBox[{"etz", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["etz", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox["etz", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"2", ",", "0", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
       SuperscriptBox["r", "2"]], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["etz", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "\[Equal]", " ", 
  RowBox[{
  "0", "   ", "then", " ", "ert", " ", "is", " ", "a", " ", "linear", " ", 
   "function", " ", "of", " ", "t", " "}]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"etz", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"a", "[", 
    RowBox[{"r", ",", "t"}], "]"}], "+", " ", 
   RowBox[{"b", "[", 
    RowBox[{"r", ",", " ", "z"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["b", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "z"}], "]"}], "r"]}], "+", 
       RowBox[{
        SuperscriptBox["b", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "z"}], "]"}]}], 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["a", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t"}], "]"}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["a", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["b", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "z"}], "]"}], "r"]}], "+", 
       RowBox[{
        SuperscriptBox["b", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "z"}], "]"}]}], "0", 
      FractionBox[
       RowBox[{
        RowBox[{"a", "[", 
         RowBox[{"r", ",", "t"}], "]"}], "+", 
        RowBox[{"b", "[", 
         RowBox[{"r", ",", "z"}], "]"}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["a", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "t"}], "]"}], "+", 
           RowBox[{
            SuperscriptBox["b", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "z"}], "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["a", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"r", ",", "t"}], "]"}], "+", 
              RowBox[{
               SuperscriptBox["b", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"r", ",", "z"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["a", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t"}], "]"}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["a", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t"}], "]"}]}]}], 
       SuperscriptBox["r", "2"]], 
      FractionBox[
       RowBox[{
        RowBox[{"a", "[", 
         RowBox[{"r", ",", "t"}], "]"}], "+", 
        RowBox[{"b", "[", 
         RowBox[{"r", ",", "z"}], "]"}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["a", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "t"}], "]"}], "+", 
           RowBox[{
            SuperscriptBox["b", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"r", ",", "z"}], "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["a", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"r", ",", "t"}], "]"}], "+", 
              RowBox[{
               SuperscriptBox["b", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"2", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"r", ",", "z"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
       SuperscriptBox["r", "2"]], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", "[", 
   RowBox[{"r_", ",", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"b", "[", "r", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "[", 
   RowBox[{"r_", ",", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"a", "[", "r", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"a", "[", "r", "]"}], "+", 
        RowBox[{"b", "[", "r", "]"}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["a", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "+", 
           RowBox[{
            SuperscriptBox["b", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "r", "]"}], "+", 
              RowBox[{
               SuperscriptBox["b", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], 
          ")"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"a", "[", "r", "]"}], "+", 
        RowBox[{"b", "[", "r", "]"}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["a", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "+", 
           RowBox[{
            SuperscriptBox["b", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["a", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "r", "]"}], "+", 
              RowBox[{
               SuperscriptBox["b", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], ")"}]}]}], 
          ")"}]}]}], 
       SuperscriptBox["r", "2"]], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"etz", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", ":=", " ", 
  RowBox[{"etz", "[", "r", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{
        RowBox[{"etz", "[", "r", "]"}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["etz", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox["etz", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
       SuperscriptBox["r", "2"]]},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{"etz", "[", "r", "]"}], "-", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["etz", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "+", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox["etz", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
       SuperscriptBox["r", "2"]], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"etz", "[", "r", "]"}], "-", 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["etz", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], "+", 
        RowBox[{"r", " ", 
         RowBox[{
          SuperscriptBox["etz", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], " ", 
    "\[Equal]", " ", "0"}], " ", ",", " ", 
   RowBox[{"etz", "[", "r", "]"}], " ", ",", " ", "r"}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"etz", "[", "r", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", 
       RowBox[{"C", "[", "1", "]"}]}], 
      RowBox[{"2", " ", "r"}]], "+", 
     FractionBox[
      RowBox[{"\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", 
       RowBox[{"C", "[", "2", "]"}]}], 
      RowBox[{"2", " ", "r"}]]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"etz", "[", "r", "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["r", "2"]}], ")"}], " ", 
     RowBox[{"C", "[", "1", "]"}]}], 
    RowBox[{"2", " ", "r"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["r", "2"]}], ")"}], " ", 
     RowBox[{"C", "[", "2", "]"}]}], 
    RowBox[{"2", " ", "r"}]]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1172, 821},
WindowMargins->{{Automatic, 37}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 139, 3, 39, "Subsection"],
Cell[1473, 43, 188, 3, 77, "Input"],
Cell[CellGroupData[{
Cell[1686, 50, 137, 3, 32, "Input"],
Cell[1826, 55, 96, 2, 31, "Output"]
}, Open  ]],
Cell[1937, 60, 399, 12, 32, "Input"],
Cell[CellGroupData[{
Cell[2361, 76, 115, 3, 32, "Input"],
Cell[2479, 81, 2038, 68, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4554, 154, 385, 12, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[4964, 170, 432, 12, 55, "Input"],
Cell[5399, 184, 1738, 61, 72, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7186, 251, 779, 26, 74, "Subsubsection"],
Cell[CellGroupData[{
Cell[7990, 281, 240, 7, 55, "Input"],
Cell[8233, 290, 498, 18, 62, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8780, 314, 303, 10, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[9108, 328, 487, 12, 99, "Input"],
Cell[9598, 342, 141, 4, 31, "Output"],
Cell[9742, 348, 485, 16, 60, "Output"],
Cell[10230, 366, 219, 8, 58, "Output"]
}, Open  ]],
Cell[10464, 377, 73, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[10562, 382, 139, 3, 32, "Input"],
Cell[10704, 387, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10839, 394, 540, 15, 77, "Input"],
Cell[11382, 411, 3291, 105, 104, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14722, 522, 385, 12, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[15132, 538, 432, 12, 55, "Input"],
Cell[15567, 552, 2933, 95, 100, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18549, 653, 387, 13, 52, "Subsubsection"],
Cell[CellGroupData[{
Cell[18961, 670, 355, 10, 55, "Input"],
Cell[19319, 682, 1391, 45, 86, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20747, 732, 279, 8, 32, "Input"],
Cell[21029, 742, 214, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21280, 754, 233, 8, 32, "Input"],
Cell[21516, 764, 485, 19, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22038, 788, 394, 11, 77, "Input"],
Cell[22435, 801, 219, 8, 58, "Output"]
}, Open  ]],
Cell[22669, 812, 73, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[22767, 817, 612, 16, 99, "Input"],
Cell[23382, 835, 3428, 111, 102, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26859, 952, 430, 13, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[27314, 969, 296, 8, 55, "Input"],
Cell[27613, 979, 2111, 72, 102, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29773, 1057, 386, 12, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[30184, 1073, 348, 10, 55, "Input"],
Cell[30535, 1085, 779, 26, 84, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31351, 1116, 387, 12, 32, "Input"],
Cell[31741, 1130, 189, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31967, 1141, 338, 9, 55, "Input"],
Cell[32308, 1152, 219, 8, 58, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[32588, 1167, 98, 2, 40, "Subsection"],
Cell[32689, 1171, 73, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[32787, 1176, 612, 16, 99, "Input"],
Cell[33402, 1194, 363, 12, 60, "Output"],
Cell[33768, 1208, 4735, 147, 110, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38540, 1360, 406, 12, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[38971, 1376, 383, 11, 55, "Input"],
Cell[39357, 1389, 5529, 176, 110, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44923, 1570, 403, 11, 77, "Input"],
Cell[45329, 1583, 1955, 56, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47321, 1644, 272, 7, 55, "Input"],
Cell[47596, 1653, 1193, 36, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48826, 1694, 596, 17, 32, "Input"],
Cell[49425, 1713, 605, 20, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50067, 1738, 636, 21, 81, "Input"],
Cell[50706, 1761, 219, 8, 58, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

