(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     67202,       2371]
NotebookOptionsPosition[     63248,       2229]
NotebookOutlinePosition[     63580,       2244]
CellTagsIndexPosition[     63537,       2241]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"",
   "]"}], "\n", 
 RowBox[{"<<", "Tensor2Analysis.m"}]}], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T", "[", " ", 
   RowBox[{"x_", ",", " ", "y_", ",", " ", "z_"}], " ", "]"}], " ", "=", " ", 
  
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", " ", "+", " ", 
     RowBox[{"2", " ", "y", " ", "a"}]}], ",", " ", "y", ",", " ", "z"}], 
   "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "+", 
    RowBox[{"2", " ", "a", " ", "y"}]}], ",", "y", ",", "z"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"F", " ", "=", " ", 
    RowBox[{"Grad", "[", " ", 
     RowBox[{"T", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]}], " ", ")"}], "//", 
  " ", "MatrixForm", " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"2", " ", "a"}], "0"},
     {"0", "1", "0"},
     {"0", "0", "1"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{"V2", "=", " ", 
     RowBox[{"F", " ", ".", " ", 
      RowBox[{"Transpose", "[", "F", "]"}]}]}], "  ", ")"}], "//", " ", 
   "MatrixForm"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{"U2", " ", "=", " ", 
     RowBox[{
      RowBox[{"Transpose", "[", "F", "]"}], " ", ".", " ", "F"}]}], "  ", 
    ")"}], "//", " ", "MatrixForm"}], " "}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"1", "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["a", "2"]}]}], 
      RowBox[{"2", " ", "a"}], "0"},
     {
      RowBox[{"2", " ", "a"}], "1", "0"},
     {"0", "0", "1"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"2", " ", "a"}], "0"},
     {
      RowBox[{"2", " ", "a"}], 
      RowBox[{"1", "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["a", "2"]}]}], "0"},
     {"0", "0", "1"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eigenU2", " ", "=", " ", 
  RowBox[{"Eigensystem", "[", "U2", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["a", "4"]}]]}]}], ",", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["a", "4"]}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["a", "4"]}]]}], "a"]}], ",", "1", ",", "0"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["a", "4"]}]]}], "a"]}], ",", "1", ",", "0"}], 
      "}"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eU2", "=", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"eigenU2", "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", "^", "2"}], " ", "+", " ", 
        RowBox[{"a", "^", "4"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}]}], " ", "->", " ", 
     RowBox[{"a", " ", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{"1", " ", "+", " ", 
         RowBox[{"a", "^", "2"}]}], " ", ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}]}]}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]]}]}], ",", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], "-", 
        SqrtBox[
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"]}]]}], ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "a"}], "+", 
        SqrtBox[
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"]}]]}], ",", "1", ",", "0"}], "}"}]}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"EigenToTensor", "[", " ", "eigen_", "]"}], " ", ":=", " ", 
  RowBox[{"Sum", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"eigen", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "i"}], "]"}], "]"}], " ", "/", " ", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{"eigen", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "i"}], "]"}], "]"}], " ", ".", " ", 
         RowBox[{"eigen", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "i"}], "]"}], "]"}]}], " ", ")"}], "^", "2"}]}], 
     
     RowBox[{"Outer", "[", " ", 
      RowBox[{"Times", ",", " ", 
       RowBox[{"eigen", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "i"}], "]"}], "]"}], " ", ",", " ", 
       RowBox[{"eigen", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "i"}], "]"}], "]"}]}], " ", "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eigU", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"eU2", "[", 
     RowBox[{"[", "1", "]"}], "]"}], " ", "/.", " ", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]]}]}], " ", "\[Rule]", " ", 
     RowBox[{"(", "  ", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]], " ", "-", " ", "a"}], ")"}]}]}], " ", "/.",
    " ", 
   RowBox[{
    RowBox[{"1", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"]}], "+", 
     RowBox[{"2", " ", "a", " ", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]}]}], " ", "\[Rule]", " ", 
    RowBox[{"(", " ", 
     RowBox[{"a", " ", "+", " ", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]}], ")"}], 
    " "}]}]}], "\[IndentingNewLine]", 
 RowBox[{"eigbasisU", " ", "=", " ", 
  RowBox[{"Map", "[", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{"#", "  ", "/", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"#", " ", ".", " ", "#"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}]}], "  ", "&"}], " ", ",", " ", 
    RowBox[{"eU2", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], " ", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{
    RowBox[{"-", "a"}], "+", 
    SqrtBox[
     RowBox[{"1", "+", 
      SuperscriptBox["a", "2"]}]]}], ",", 
   RowBox[{"a", "+", 
    SqrtBox[
     RowBox[{"1", "+", 
      SuperscriptBox["a", "2"]}]]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "a"}], "-", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]]}], 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "-", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]], ",", 
     FractionBox["1", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "-", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"-", "a"}], "+", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]]}], 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]], ",", 
     FractionBox["1", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]], ",", "0"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", " ", "=", " ", 
  RowBox[{"EigenToTensor", "[", 
   RowBox[{"{", 
    RowBox[{"eigU", ",", " ", "eigbasisU"}], "}"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "-", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "-", 
             SqrtBox[
              RowBox[{"1", "+", 
               SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "-", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]], "+", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "a"}], "-", 
               SqrtBox[
                RowBox[{"1", "+", 
                 SuperscriptBox["a", "2"]}]]}], ")"}], "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "-", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]}], ")"}], 
         "2"]}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", 
             SqrtBox[
              RowBox[{"1", "+", 
               SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "+", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]], "+", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "a"}], "+", 
               SqrtBox[
                RowBox[{"1", "+", 
                 SuperscriptBox["a", "2"]}]]}], ")"}], "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "+", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]}], ")"}], 
         "2"]}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "-", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "-", 
             SqrtBox[
              RowBox[{"1", "+", 
               SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "-", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]], "+", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "a"}], "-", 
               SqrtBox[
                RowBox[{"1", "+", 
                 SuperscriptBox["a", "2"]}]]}], ")"}], "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "-", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]}], ")"}], 
         "2"]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", 
             SqrtBox[
              RowBox[{"1", "+", 
               SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "+", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]], "+", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "a"}], "+", 
               SqrtBox[
                RowBox[{"1", "+", 
                 SuperscriptBox["a", "2"]}]]}], ")"}], "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "+", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]}], ")"}], 
         "2"]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "-", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "-", 
             SqrtBox[
              RowBox[{"1", "+", 
               SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "-", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]], "+", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "a"}], "-", 
               SqrtBox[
                RowBox[{"1", "+", 
                 SuperscriptBox["a", "2"]}]]}], ")"}], "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "-", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]}], ")"}], 
         "2"]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", 
             SqrtBox[
              RowBox[{"1", "+", 
               SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "+", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]], "+", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "a"}], "+", 
               SqrtBox[
                RowBox[{"1", "+", 
                 SuperscriptBox["a", "2"]}]]}], ")"}], "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "+", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]}], ")"}], 
         "2"]}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", "a"}], "+", 
        SqrtBox[
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"]}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "-", 
             SqrtBox[
              RowBox[{"1", "+", 
               SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "-", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]], "+", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "a"}], "-", 
               SqrtBox[
                RowBox[{"1", "+", 
                 SuperscriptBox["a", "2"]}]]}], ")"}], "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "-", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]}], ")"}], 
         "2"]}]], "+", 
      FractionBox[
       RowBox[{"a", "+", 
        SqrtBox[
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"]}]]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", 
             SqrtBox[
              RowBox[{"1", "+", 
               SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "+", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]], "+", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "a"}], "+", 
               SqrtBox[
                RowBox[{"1", "+", 
                 SuperscriptBox["a", "2"]}]]}], ")"}], "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "a"}], "+", 
                SqrtBox[
                 RowBox[{"1", "+", 
                  SuperscriptBox["a", "2"]}]]}], ")"}], "2"]}]]}], ")"}], 
         "2"]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", "U", " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]], ",", 
     FractionBox["a", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["a", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]], ",", 
     FractionBox[
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"]}]}], 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check the Result ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"U", " ", ".", " ", "U"}], " ", "-", " ", "U2"}], " ", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check the Result with MatrixPower", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", " ", "=", " ", 
  RowBox[{"MatrixPower", "[", " ", 
   RowBox[{"U2", " ", ",", " ", 
    RowBox[{"1", "/", "2"}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "-", 
          RowBox[{"2", " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["a", "4"]}]]}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["a", "4"]}]]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["a", "4"]}]]}], ")"}], " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["a", "4"]}]]}]}]]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SqrtBox[
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"]}], "-", 
           RowBox[{"2", " ", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["a", "4"]}]]}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["a", "4"]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["a", "4"]}]]}], ")"}]}], 
        RowBox[{"2", " ", "a", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["a", "4"]}]]}]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["a", "4"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["a", "4"]}]]}], ")"}], " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["a", "4"]}]]}]}]]}], 
       RowBox[{"2", " ", "a", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"a", " ", 
         SqrtBox[
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"]}], "-", 
           RowBox[{"2", " ", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["a", "4"]}]]}]}]]}], 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["a", "4"]}]]}]]}], "+", 
      FractionBox[
       RowBox[{"a", " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["a", "4"]}]]}]}]]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "-", 
          RowBox[{"2", " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["a", "4"]}]]}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["a", "4"]}]]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["a", "4"]}]]}], ")"}], " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["a", "4"]}]]}]}]]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", " ", "=", " ", 
  RowBox[{"U", " ", "/.", "  ", 
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["a", "4"]}]], " ", "\[Rule]", " ", 
    RowBox[{"a", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", " ", "+", " ", 
        RowBox[{"a", "^", "2"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}]}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "-", 
          RowBox[{"2", " ", "a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}], " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"2", " ", "a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}]]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SqrtBox[
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"]}], "-", 
           RowBox[{"2", " ", "a", " ", 
            SqrtBox[
             RowBox[{"1", "+", 
              SuperscriptBox["a", "2"]}]]}]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "+", 
           RowBox[{"a", " ", 
            SqrtBox[
             RowBox[{"1", "+", 
              SuperscriptBox["a", "2"]}]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           RowBox[{"a", " ", 
            SqrtBox[
             RowBox[{"1", "+", 
              SuperscriptBox["a", "2"]}]]}]}], ")"}]}], 
        RowBox[{"2", " ", "a", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["a", "4"]}]]}]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}], " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"2", " ", "a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}]]}], 
       RowBox[{"2", " ", "a", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"a", " ", 
         SqrtBox[
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"]}], "-", 
           RowBox[{"2", " ", "a", " ", 
            SqrtBox[
             RowBox[{"1", "+", 
              SuperscriptBox["a", "2"]}]]}]}]]}], 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["a", "4"]}]]}]]}], "+", 
      FractionBox[
       RowBox[{"a", " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"2", " ", "a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}]]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "-", 
          RowBox[{"2", " ", "a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}], " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"2", " ", "a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}]]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", " ", "=", " ", 
  RowBox[{
   RowBox[{"U", " ", "/.", " ", 
    RowBox[{
     SqrtBox[
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"]}], "-", 
       RowBox[{"2", " ", "a", " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"]}]]}]}]], "\[Rule]", "  ", 
     RowBox[{
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"], " "}]], "-", " ", "a"}]}]}], " ", "/.", 
   RowBox[{
    SqrtBox[
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"]}], "+", " ", 
      RowBox[{"2", " ", "a", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]]}]}]], "\[Rule]", "  ", 
    RowBox[{"a", " ", "+", " ", 
     SqrtBox[
      RowBox[{"1", "+", 
       SuperscriptBox["a", "2"]}]], "    "}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], "+", 
           RowBox[{"a", " ", 
            SqrtBox[
             RowBox[{"1", "+", 
              SuperscriptBox["a", "2"]}]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           RowBox[{"a", " ", 
            SqrtBox[
             RowBox[{"1", "+", 
              SuperscriptBox["a", "2"]}]]}]}], ")"}]}], 
        RowBox[{"2", " ", "a", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["a", "4"]}]]}]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}]}], 
       RowBox[{"2", " ", "a", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}], ")"}]}], 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["a", "4"]}]]}]]}], "+", 
      FractionBox[
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", 
          SqrtBox[
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["a", "4"]}]]}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"U", " ", "=", " ", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", "U", " ", "]"}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"1", "/", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["a", "4"]}]]}], " ", "\[RuleDelayed]", "  ", 
    RowBox[{
     RowBox[{"1", " ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"a", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "+", " ", 
           RowBox[{"a", "^", "2"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}]}], "  ", ")"}]}], 
     "   "}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]], ",", 
     FractionBox["a", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["a", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]], ",", 
     FractionBox[
      RowBox[{"a", "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "3"]}]}], 
      RowBox[{"a", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check the Result ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"U", " ", ".", " ", "U"}], " ", "-", " ", "U2"}], " ", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation of the Rotation tensor R ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R", " ", "=", " ", 
  RowBox[{"F", " ", ".", "  ", 
   RowBox[{"Inverse", "[", " ", "U", " ", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "+", 
           SuperscriptBox["a", "2"]}]], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]], "+", 
           FractionBox[
            SuperscriptBox["a", "2"], 
            RowBox[{"1", "+", 
             SuperscriptBox["a", "2"]}]]}], ")"}]}]]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox["1", 
         SqrtBox[
          RowBox[{"1", "+", 
           SuperscriptBox["a", "2"]}]]], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"]}], 
         SqrtBox[
          RowBox[{"1", "+", 
           SuperscriptBox["a", "2"]}]]]}], 
       RowBox[{
        FractionBox["1", 
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"]}]], "+", 
        FractionBox[
         SuperscriptBox["a", "2"], 
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"]}]]}]]}], ",", 
     FractionBox["a", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"1", "+", 
           SuperscriptBox["a", "2"]}]], "+", 
         FractionBox[
          SuperscriptBox["a", "2"], 
          RowBox[{"1", "+", 
           SuperscriptBox["a", "2"]}]]}], ")"}]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["a", 
       RowBox[{
        SqrtBox[
         RowBox[{"1", "+", 
          SuperscriptBox["a", "2"]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]], "+", 
          FractionBox[
           SuperscriptBox["a", "2"], 
           RowBox[{"1", "+", 
            SuperscriptBox["a", "2"]}]]}], ")"}]}]]}], ",", 
     FractionBox["1", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"1", "+", 
           SuperscriptBox["a", "2"]}]], "+", 
         FractionBox[
          SuperscriptBox["a", "2"], 
          RowBox[{"1", "+", 
           SuperscriptBox["a", "2"]}]]}], ")"}]}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", "R", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]], ",", 
     FractionBox["a", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["a", 
       SqrtBox[
        RowBox[{"1", "+", 
         SuperscriptBox["a", "2"]}]]]}], ",", 
     FractionBox["1", 
      SqrtBox[
       RowBox[{"1", "+", 
        SuperscriptBox["a", "2"]}]]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
we continue the computation passing to trigometric notation for the shear \
parameter a -> Tan[alpha] \
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eU2trig", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Eigensystem", "[", " ", 
    RowBox[{"U2", " ", "/.", " ", 
     RowBox[{"a", " ", "\[Rule]", " ", 
      RowBox[{"Tan", "[", " ", "alpha", " ", "]"}]}]}], "]"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Tan", "[", "alpha", "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"Sec", "[", "alpha", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Tan", "[", "alpha", "]"}], "2"]}]]}]}], ",", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Tan", "[", "alpha", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"Sec", "[", "alpha", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Tan", "[", "alpha", "]"}], "2"]}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cot", "[", "alpha", "]"}]}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Tan", "[", "alpha", "]"}], "2"], "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{"Sec", "[", "alpha", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"Tan", "[", "alpha", "]"}], "2"]}]]}], ")"}]}], ",", "1",
        ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Tan", "[", "alpha", "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cot", "[", "alpha", "]"}], " ", 
         SqrtBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"Sec", "[", "alpha", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"Tan", "[", "alpha", "]"}], "2"]}]]}]}], ",", "1", ",", 
       "0"}], "}"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eU2trig", " ", "=", " ", 
  RowBox[{"TrigFactor", "[", " ", 
   RowBox[{"eU2trig", " ", "/.", " ", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sec", "[", "alpha", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Tan", "[", "alpha", "]"}], "2"]}]], " ", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"Sin", "[", "alpha", "]"}], " ", "/", " ", 
      RowBox[{
       RowBox[{"Cos", "[", "alpha", "]"}], "^", "2"}]}]}]}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["alpha", "2"], "]"}], "-", 
         RowBox[{"Sin", "[", 
          FractionBox["alpha", "2"], "]"}]}], ")"}], "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["alpha", "2"], "]"}], "+", 
         RowBox[{"Sin", "[", 
          FractionBox["alpha", "2"], "]"}]}], ")"}], "2"]], ",", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["alpha", "2"], "]"}], "+", 
         RowBox[{"Sin", "[", 
          FractionBox["alpha", "2"], "]"}]}], ")"}], "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["alpha", "2"], "]"}], "-", 
         RowBox[{"Sin", "[", 
          FractionBox["alpha", "2"], "]"}]}], ")"}], "2"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"Cos", "[", 
           FractionBox["alpha", "2"], "]"}], "+", 
          RowBox[{"Sin", "[", 
           FractionBox["alpha", "2"], "]"}]}], 
         RowBox[{
          RowBox[{"Cos", "[", 
           FractionBox["alpha", "2"], "]"}], "-", 
          RowBox[{"Sin", "[", 
           FractionBox["alpha", "2"], "]"}]}]]}], ",", "1", ",", "0"}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["alpha", "2"], "]"}], "-", 
         RowBox[{"Sin", "[", 
          FractionBox["alpha", "2"], "]"}]}], 
        RowBox[{
         RowBox[{"Cos", "[", 
          FractionBox["alpha", "2"], "]"}], "+", 
         RowBox[{"Sin", "[", 
          FractionBox["alpha", "2"], "]"}]}]], ",", "1", ",", "0"}], "}"}]}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tpiplusa", " ", "=", " ", 
  RowBox[{"Factor", "[", " ", 
   RowBox[{"Expand", "[", " ", 
    RowBox[{"TrigFactor", "[", " ", 
     RowBox[{"Tan", "[", " ", 
      RowBox[{
       RowBox[{"Pi", " ", "/", " ", "4"}], " ", "+", "  ", 
       RowBox[{"alpha", " ", "/", " ", "2"}]}], " ", "]"}], "]"}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"tpiminusa", " ", "=", " ", 
  RowBox[{"Factor", "[", " ", 
   RowBox[{"Expand", "[", " ", 
    RowBox[{"TrigFactor", "[", " ", 
     RowBox[{"Tan", "[", " ", 
      RowBox[{
       RowBox[{"Pi", " ", "/", " ", "4"}], " ", "-", "  ", 
       RowBox[{"alpha", " ", "/", " ", "2"}]}], " ", "]"}], "]"}], "]"}], 
   "]"}]}]}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"Cos", "[", 
    FractionBox["alpha", "2"], "]"}], "+", 
   RowBox[{"Sin", "[", 
    FractionBox["alpha", "2"], "]"}]}], 
  RowBox[{
   RowBox[{"Cos", "[", 
    FractionBox["alpha", "2"], "]"}], "-", 
   RowBox[{"Sin", "[", 
    FractionBox["alpha", "2"], "]"}]}]]], "Output"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"Cos", "[", 
    FractionBox["alpha", "2"], "]"}], "-", 
   RowBox[{"Sin", "[", 
    FractionBox["alpha", "2"], "]"}]}], 
  RowBox[{
   RowBox[{"Cos", "[", 
    FractionBox["alpha", "2"], "]"}], "+", 
   RowBox[{"Sin", "[", 
    FractionBox["alpha", "2"], "]"}]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eU2trig", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"eU2trig", " ", "/.", " ", 
      RowBox[{"tpiplusa", " ", "\[Rule]", " ", 
       RowBox[{"Tan", "[", " ", 
        RowBox[{
         RowBox[{"Pi", " ", "/", " ", "4"}], " ", "+", "  ", 
         RowBox[{"alpha", " ", "/", " ", "2"}]}], " ", "]"}]}]}], " ", "/.", 
     "  ", 
     RowBox[{
      RowBox[{"tpiplusa", "^", "2"}], " ", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Tan", "[", " ", 
        RowBox[{
         RowBox[{"Pi", " ", "/", " ", "4"}], " ", "+", "  ", 
         RowBox[{"alpha", " ", "/", " ", "2"}]}], " ", "]"}], "^", "2"}]}]}], 
    " ", "/.", " ", 
    RowBox[{"tpiminusa", " ", "\[Rule]", " ", 
     RowBox[{"Tan", "[", " ", 
      RowBox[{
       RowBox[{"Pi", " ", "/", " ", "4"}], " ", "+", "  ", 
       RowBox[{"alpha", " ", "/", " ", "2"}]}], " ", "]"}]}]}], " ", "/.", 
   "  ", 
   RowBox[{
    RowBox[{"tpiminusa", "^", "2"}], " ", "\[Rule]", " ", 
    RowBox[{
     RowBox[{"Tan", "[", " ", 
      RowBox[{
       RowBox[{"Pi", " ", "/", " ", "4"}], " ", "+", "  ", 
       RowBox[{"alpha", " ", "/", " ", "2"}]}], " ", "]"}], "^", 
     "2"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     SuperscriptBox[
      RowBox[{"Tan", "[", 
       RowBox[{
        FractionBox["alpha", "2"], "+", 
        FractionBox["\[Pi]", "4"]}], "]"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"Tan", "[", 
       RowBox[{
        FractionBox["alpha", "2"], "+", 
        FractionBox["\[Pi]", "4"]}], "]"}], "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Tan", "[", 
         RowBox[{
          FractionBox["alpha", "2"], "+", 
          FractionBox["\[Pi]", "4"]}], "]"}]}], ",", "1", ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Tan", "[", 
        RowBox[{
         FractionBox["alpha", "2"], "+", 
         FractionBox["\[Pi]", "4"]}], "]"}], ",", "1", ",", "0"}], "}"}]}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["small shear  a << 1 -> alpha << 1  ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", " ", 
  RowBox[{
   RowBox[{"ArcTan", "[", "a", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"a", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"a", "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "a", "]"}], "2"],
    SeriesData[a, 0, {}, 1, 2, 1],
    Editable->False]}],
  SeriesData[a, 0, {1}, 1, 2, 1],
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Normal", "[", " ", 
    RowBox[{"Series", "[", " ", 
     RowBox[{"R", ",", " ", 
      RowBox[{"{", 
       RowBox[{"a", ",", "0", ",", "1"}], "}"}]}], "]"}], " ", "]"}], " ", "//",
    " ", "MatrixForm"}]}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "a", "0"},
     {
      RowBox[{"-", "a"}], "1", "0"},
     {"0", "0", "1"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Normal", "[", " ", 
    RowBox[{"Series", "[", " ", 
     RowBox[{
      RowBox[{"Eigensystem", "[", " ", "U2", " ", "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"a", ",", "0", ",", "1"}], "}"}]}], "]"}], " ", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "  ", "//", " ", "MatrixForm"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"%%", "[", 
     RowBox[{"[", "2", "]"}], "]"}], " ", "//", " ", "MatrixForm"}]}], 
  "  "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "a"}]}], ",", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "a"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "-", "a"}], ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "-", "a"}], ",", "1", ",", "0"}], "}"}]}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1"},
     {
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "a"}]}]},
     {
      RowBox[{"1", "+", 
       RowBox[{"2", " ", "a"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{1, 1 - 2 a, 1 + 2 a}]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "1"},
     {
      RowBox[{
       RowBox[{"-", "1"}], "-", "a"}], "1", "0"},
     {
      RowBox[{"1", "-", "a"}], "1", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Normal", "[", " ", 
  RowBox[{"Series", "[", " ", 
   RowBox[{"U2", ",", " ", 
    RowBox[{"{", 
     RowBox[{"a", ",", "0", ",", "1"}], "}"}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Eigensystem", "[", "%", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"2", " ", "a"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "a"}], ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "a"}]}], ",", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", "a"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{977, 813},
WindowMargins->{{18, Automatic}, {Automatic, 1}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 159, 3, 55, "Input"],
Cell[1493, 43, 72, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1602, 48, 137, 3, 32, "Input"],
Cell[1742, 53, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1875, 60, 289, 9, 32, "Input"],
Cell[2167, 71, 145, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2349, 81, 240, 7, 32, "Input"],
Cell[2592, 90, 246, 9, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2875, 104, 488, 14, 77, "Input"],
Cell[3366, 120, 358, 13, 60, "Output"],
Cell[3727, 135, 358, 13, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4122, 153, 104, 2, 32, "Input"],
Cell[4229, 157, 1312, 46, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5578, 208, 584, 18, 32, "Input"],
Cell[6165, 228, 1061, 37, 46, "Output"]
}, Open  ]],
Cell[7241, 268, 981, 29, 55, "Input"],
Cell[CellGroupData[{
Cell[8247, 301, 1392, 45, 77, "Input"],
Cell[9642, 348, 287, 11, 46, "Output"],
Cell[9932, 361, 1624, 60, 84, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11593, 426, 164, 4, 32, "Input"],
Cell[11760, 432, 13050, 418, 439, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24847, 855, 104, 2, 32, "Input"],
Cell[24954, 859, 737, 27, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25728, 891, 39, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[25792, 895, 142, 4, 32, "Input"],
Cell[25937, 901, 260, 8, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26246, 915, 55, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[26326, 919, 167, 4, 32, "Input"],
Cell[26496, 925, 6051, 202, 261, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32584, 1132, 430, 14, 42, "Input"],
Cell[33017, 1148, 5849, 194, 261, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38903, 1347, 873, 29, 58, "Input"],
Cell[39779, 1378, 5093, 174, 179, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44909, 1557, 630, 20, 49, "Input"],
Cell[45542, 1579, 767, 28, 54, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46358, 1613, 39, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[46422, 1617, 142, 4, 32, "Input"],
Cell[46567, 1623, 260, 8, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46876, 1637, 59, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[46960, 1641, 138, 3, 32, "Input"],
Cell[47101, 1646, 2607, 89, 134, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49745, 1740, 99, 2, 32, "Input"],
Cell[49847, 1744, 677, 25, 52, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50573, 1775, 132, 3, 39, "Subsection"],
Cell[CellGroupData[{
Cell[50730, 1782, 280, 7, 32, "Input"],
Cell[51013, 1791, 1902, 60, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52952, 1856, 518, 15, 47, "Input"],
Cell[53473, 1873, 2101, 67, 126, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55611, 1945, 710, 18, 55, "Input"],
Cell[56324, 1965, 326, 11, 64, "Output"],
Cell[56653, 1978, 326, 11, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57016, 1994, 1200, 33, 77, "Input"],
Cell[58219, 2029, 976, 33, 47, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[59244, 2068, 57, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[59326, 2072, 185, 5, 32, "Input"],
Cell[59514, 2079, 261, 9, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59812, 2093, 271, 8, 32, "Input"],
Cell[60086, 2103, 241, 9, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60364, 2117, 560, 17, 77, "Input"],
Cell[60927, 2136, 569, 20, 31, "Output"],
Cell[61499, 2158, 295, 11, 58, "Output"],
Cell[61797, 2171, 296, 11, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62130, 2187, 263, 7, 55, "Input"],
Cell[62396, 2196, 312, 10, 31, "Output"],
Cell[62711, 2208, 509, 17, 31, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

