(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    169758,       5138]
NotebookOptionsPosition[    165280,       4993]
NotebookOutlinePosition[    165613,       5008]
CellTagsIndexPosition[    165570,       5005]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "\"\<ElasticaBook/Packages\>\"", "]"}], "\n", 
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n"}], "Input",
 CellChangeTimes->{3.40206827905162*^9}],

Cell[BoxData["\<\"/local/constant/Oxford/Tex/ElasticaBook/Packages\"\>"], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SetCoordinates", "[", 
    RowBox[{"Cylindrical", "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"cs", "=", 
    RowBox[{"Coordinates", "[", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"sf", "=", 
    RowBox[{"ScaleFactors", "[", "cs", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "t", ",", "z"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "r", ",", "1"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"f", " ", "=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"r", "^", "4"}], " ", ",", " ", 
    RowBox[{"Log", "[", " ", 
     RowBox[{"z", " ", "+", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"r", "^", "2"}], " ", "+", " ", 
        RowBox[{"z", "^", "2"}]}], "]"}]}], "]"}], " ", ",", " ", 
    RowBox[{
     RowBox[{"Cos", "[", "t", " ", "]"}], " ", "+", " ", 
     RowBox[{"a", " ", 
      RowBox[{"Tan", "[", " ", 
       RowBox[{"z", " ", "t"}], "]"}]}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"nf", " ", "=", " ", 
  RowBox[{"Grad", "[", "f", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["r", "4"], ",", 
   RowBox[{"Log", "[", 
    RowBox[{"z", "+", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       SuperscriptBox["z", "2"]}]]}], "]"}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "t", "]"}], "+", 
    RowBox[{"a", " ", 
     RowBox[{"Tan", "[", 
      RowBox[{"t", " ", "z"}], "]"}]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["r", "3"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Log", "[", 
        RowBox[{"z", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["z", "2"]}]]}], "]"}], "r"]}], ",", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["r", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         SuperscriptBox["z", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{"z", "+", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["r", "2"], "+", 
           SuperscriptBox["z", "2"]}]]}], ")"}]}]], ",", 
     SuperscriptBox["r", "3"], ",", 
     FractionBox[
      RowBox[{"1", "+", 
       FractionBox["z", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["r", "2"], "+", 
          SuperscriptBox["z", "2"]}]]]}], 
      RowBox[{"z", "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         SuperscriptBox["z", "2"]}]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"a", " ", "z", " ", 
        SuperscriptBox[
         RowBox[{"Sec", "[", 
          RowBox[{"t", " ", "z"}], "]"}], "2"]}], "-", 
       RowBox[{"Sin", "[", "t", "]"}]}], "r"], ",", 
     RowBox[{"a", " ", "t", " ", 
      SuperscriptBox[
       RowBox[{"Sec", "[", 
        RowBox[{"t", " ", "z"}], "]"}], "2"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IntegrateNabla", "[", "nf", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["r", "4"], ",", 
   FractionBox[
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       SuperscriptBox["z", "2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{"z", "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         SuperscriptBox["z", "2"]}]]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      RowBox[{"z", "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["r", "2"], "+", 
         SuperscriptBox["z", "2"]}]]}], "]"}]}], 
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     SuperscriptBox["z", "2"], "+", 
     RowBox[{"z", " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        SuperscriptBox["z", "2"]}]]}]}]], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "t", "]"}], "+", 
    RowBox[{"a", " ", 
     RowBox[{"Tan", "[", 
      RowBox[{"t", " ", "z"}], "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Expand", "[", "%", " ", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["r", "4"], ",", 
   RowBox[{"Log", "[", 
    RowBox[{"z", "+", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       SuperscriptBox["z", "2"]}]]}], "]"}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "t", "]"}], "+", 
    RowBox[{"a", " ", 
     RowBox[{"Tan", "[", 
      RowBox[{"t", " ", "z"}], "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"f", " ", "=", " ", 
  RowBox[{
   RowBox[{"r", "^", "4"}], " ", 
   RowBox[{"Sin", "[", "t", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"nf", " ", "=", " ", 
  RowBox[{"Grad", "[", "f", "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "4"], " ", 
  RowBox[{"Sin", "[", "t", "]"}]}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["r", "3"], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{
    SuperscriptBox["r", "3"], " ", 
    RowBox[{"Cos", "[", "t", "]"}]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IntegrateNabla", "[", "nf", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "4"], " ", 
  RowBox[{"Sin", "[", "t", "]"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SuperscriptBox["r", "4"], " ", 
  RowBox[{"Sin", "[", "t", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["r", "3"], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{
    SuperscriptBox["r", "3"], " ", 
    RowBox[{"Cos", "[", "t", "]"}]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"nf", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["r", "3"]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "r"], " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], "r"]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"intf", "=", 
    RowBox[{"Integrate", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Transpose", "[", " ", "nf", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", 
       RowBox[{"sf", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", 
      RowBox[{"cs", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"r2", "=", 
    RowBox[{
     RowBox[{"Transpose", "[", " ", 
      RowBox[{"nf", "-", 
       RowBox[{"Grad", "[", "intf", "]"}]}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h1", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"r2", " ", 
        RowBox[{"sf", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ",", 
       RowBox[{"cs", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"intf", "=", 
    RowBox[{"intf", "+", "h1"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"r3", "=", 
    RowBox[{
     RowBox[{"Transpose", "[", " ", 
      RowBox[{"nf", "-", 
       RowBox[{"Grad", "[", "intf", "]"}]}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"h1", "=", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{"r3", " ", 
        RowBox[{"sf", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ",", 
       RowBox[{"cs", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"intf", "=", 
    RowBox[{"intf", "+", "h1"}]}], "\n"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["r", "4"], ",", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "r"], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Sin", "[", "t", "]"}], "r"]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["r", "4"], ",", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "r"], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"Cos", "[", "t", "]"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["r", "4"], ",", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "r"], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"Cos", "[", "t", "]"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SetCoordinates", "[", 
    RowBox[{"Cartesian", "[", 
     RowBox[{"x1", ",", "x2", ",", "x3"}], "]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"cs", "=", 
    RowBox[{"Coordinates", "[", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"sf", "=", 
    RowBox[{"ScaleFactors", "[", "cs", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"u", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"x2", " ", "x3"}], 
        RowBox[{"L", " ", 
         RowBox[{"Log", "[", 
          RowBox[{"x1", " ", "/", " ", "x2"}], "]"}]}]]}], ",", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Log", "[", 
         RowBox[{"x1", " ", "+", " ", 
          RowBox[{"Sqrt", "[", " ", 
           RowBox[{
            RowBox[{"x1", "^", "2"}], " ", "+", " ", 
            RowBox[{"x2", "^", "2"}], " ", "+", " ", 
            RowBox[{"x3", "^", "2"}]}], "  ", "]"}]}], "]"}], "L"]}], ",", 
      FractionBox[
       RowBox[{
        RowBox[{"x1", "^", "2"}], " ", 
        RowBox[{"x2", "^", "5"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"x1", " ", "x2"}], "]"}]}], "L"]}], "}"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"eps", " ", "=", " ", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", ")"}], " ", "/", " ", 
     "2"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"eps", " ", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"-", "x3"}], "/", "L"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "x3"}], "/", "L"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], " ", "*)"}], 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x1", ",", "x2", ",", "x3"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x1", ",", "x2", ",", "x3"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "1"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"x2", " ", "x3"}], 
     RowBox[{"L", " ", 
      RowBox[{"Log", "[", 
       FractionBox["x1", "x2"], "]"}]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Log", "[", 
      RowBox[{"x1", "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["x1", "2"], "+", 
         SuperscriptBox["x2", "2"], "+", 
         SuperscriptBox["x3", "2"]}]]}], "]"}], "L"]}], ",", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x1", "2"], " ", 
     SuperscriptBox["x2", "5"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"x1", " ", "x2"}], "]"}]}], "L"]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"x2", " ", "x3"}], 
      RowBox[{"L", " ", "x1", " ", 
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox["x1", "x2"], "]"}], "2"]}]], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", 
           FractionBox["x1", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"]}]]]}], 
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"x1", "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"]}]]}], ")"}]}]]}], "-", 
        FractionBox["x3", 
         RowBox[{"L", " ", 
          SuperscriptBox[
           RowBox[{"Log", "[", 
            FractionBox["x1", "x2"], "]"}], "2"]}]], "-", 
        FractionBox["x3", 
         RowBox[{"L", " ", 
          RowBox[{"Log", "[", 
           FractionBox["x1", "x2"], "]"}]}]]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "x1", " ", 
          SuperscriptBox["x2", "5"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"x1", " ", "x2"}], "]"}]}], "L"], "-", 
        FractionBox["x2", 
         RowBox[{"L", " ", 
          RowBox[{"Log", "[", 
           FractionBox["x1", "x2"], "]"}]}]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x1", "2"], " ", 
          SuperscriptBox["x2", "6"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"x1", " ", "x2"}], "]"}]}], "L"]}], ")"}]}]}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", 
           FractionBox["x1", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["x1", "2"], "+", 
              SuperscriptBox["x2", "2"], "+", 
              SuperscriptBox["x3", "2"]}]]]}], 
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"x1", "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"]}]]}], ")"}]}]]}], "-", 
        FractionBox["x3", 
         RowBox[{"L", " ", 
          SuperscriptBox[
           RowBox[{"Log", "[", 
            FractionBox["x1", "x2"], "]"}], "2"]}]], "-", 
        FractionBox["x3", 
         RowBox[{"L", " ", 
          RowBox[{"Log", "[", 
           FractionBox["x1", "x2"], "]"}]}]]}], ")"}]}], ",", 
     RowBox[{"-", 
      FractionBox["x2", 
       RowBox[{"L", " ", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["x1", "2"], "+", 
          SuperscriptBox["x2", "2"], "+", 
          SuperscriptBox["x3", "2"]}]], " ", 
        RowBox[{"(", 
         RowBox[{"x1", "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["x1", "2"], "+", 
            SuperscriptBox["x2", "2"], "+", 
            SuperscriptBox["x3", "2"]}]]}], ")"}]}]]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["x3", 
          RowBox[{"L", " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"]}]], " ", 
           RowBox[{"(", 
            RowBox[{"x1", "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"]}]]}], ")"}]}]]}], "+", 
        FractionBox[
         RowBox[{"5", " ", 
          SuperscriptBox["x1", "2"], " ", 
          SuperscriptBox["x2", "4"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"x1", " ", "x2"}], "]"}]}], "L"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x1", "3"], " ", 
          SuperscriptBox["x2", "5"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"x1", " ", "x2"}], "]"}]}], "L"]}], ")"}]}]}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "x1", " ", 
          SuperscriptBox["x2", "5"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"x1", " ", "x2"}], "]"}]}], "L"], "-", 
        FractionBox["x2", 
         RowBox[{"L", " ", 
          RowBox[{"Log", "[", 
           FractionBox["x1", "x2"], "]"}]}]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x1", "2"], " ", 
          SuperscriptBox["x2", "6"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"x1", " ", "x2"}], "]"}]}], "L"]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["x3", 
          RowBox[{"L", " ", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["x1", "2"], "+", 
             SuperscriptBox["x2", "2"], "+", 
             SuperscriptBox["x3", "2"]}]], " ", 
           RowBox[{"(", 
            RowBox[{"x1", "+", 
             SqrtBox[
              RowBox[{
               SuperscriptBox["x1", "2"], "+", 
               SuperscriptBox["x2", "2"], "+", 
               SuperscriptBox["x3", "2"]}]]}], ")"}]}]]}], "+", 
        FractionBox[
         RowBox[{"5", " ", 
          SuperscriptBox["x1", "2"], " ", 
          SuperscriptBox["x2", "4"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"x1", " ", "x2"}], "]"}]}], "L"], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["x1", "3"], " ", 
          SuperscriptBox["x2", "5"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"x1", " ", "x2"}], "]"}]}], "L"]}], ")"}]}], ",", "0"}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "p", "]"}], " ", 
     RowBox[{"Cos", "[", "t", "]"}]}], " ", ",", " ", 
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "p", "]"}]}], " ", ",", " ", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "p", "]"}]}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", ")"}], " ", "/", " ", 
   "2"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x1", ",", "x2", ",", "x3"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"x1", ",", "x2", ",", "x3"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "1"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "p", ",", " ", "t"}], " ", "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"cs", "=", 
  RowBox[{"Coordinates", "[", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"sf", "=", 
  RowBox[{"ScaleFactors", "[", "cs", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "p", "]"}], " ", 
     RowBox[{"Cos", "[", "t", "]"}]}], " ", ",", " ", 
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "p", "]"}]}], " ", ",", " ", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", "p", "]"}]}]}], " ", 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", ")"}], " ", "/", " ", 
   "2", " "}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "p", ",", "t"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "p", ",", "t"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "r", ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "p", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}], " ", 
    RowBox[{"Sin", "[", "p", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "p", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "p", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "t", "]"}], " ", 
      RowBox[{"Sin", "[", "p", "]"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Cos", "[", "p", "]"}], " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Sin", "[", "t", "]"}], "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Cos", "[", "p", "]"}], " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "p", "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", "p", "]"}]}], " ", 
         RowBox[{"Cot", "[", "p", "]"}]}], "-", 
        RowBox[{"Sin", "[", "p", "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Sin", "[", "t", "]"}], "2"]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", "p", "]"}]}], " ", 
         RowBox[{"Cot", "[", "p", "]"}]}], "-", 
        RowBox[{"Sin", "[", "p", "]"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "p", "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", " ", "z"}], " ", "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"cs", "=", 
  RowBox[{"Coordinates", "[", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"sf", "=", 
  RowBox[{"ScaleFactors", "[", "cs", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"r", "^", "4"}], " ", ",", " ", 
    RowBox[{"Log", "[", " ", 
     RowBox[{"z", " ", "+", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"r", "^", "2"}], " ", "+", " ", 
        RowBox[{"z", "^", "2"}]}], "]"}]}], "]"}], " ", ",", " ", 
    RowBox[{
     RowBox[{"Cos", "[", "t", " ", "]"}], " ", "+", " ", 
     RowBox[{"a", " ", 
      RowBox[{"Tan", "[", " ", 
       RowBox[{"z", " ", "t"}], "]"}]}]}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", ")"}], " ", "/", " ", 
   "2"}]}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "t", ",", "z"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "r", ",", "1"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["r", "4"], ",", 
   RowBox[{"Log", "[", 
    RowBox[{"z", "+", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       SuperscriptBox["z", "2"]}]]}], "]"}], ",", 
   RowBox[{
    RowBox[{"Cos", "[", "t", "]"}], "+", 
    RowBox[{"a", " ", 
     RowBox[{"Tan", "[", 
      RowBox[{"t", " ", "z"}], "]"}]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["r", "3"]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["r", 
         RowBox[{
          SqrtBox[
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            SuperscriptBox["z", "2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{"z", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["r", "2"], "+", 
              SuperscriptBox["z", "2"]}]]}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{"Log", "[", 
          RowBox[{"z", "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["r", "2"], "+", 
             SuperscriptBox["z", "2"]}]]}], "]"}], "r"]}], ")"}]}], ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["r", 
         RowBox[{
          SqrtBox[
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            SuperscriptBox["z", "2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{"z", "+", 
            SqrtBox[
             RowBox[{
              SuperscriptBox["r", "2"], "+", 
              SuperscriptBox["z", "2"]}]]}], ")"}]}]], "-", 
        FractionBox[
         RowBox[{"Log", "[", 
          RowBox[{"z", "+", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["r", "2"], "+", 
             SuperscriptBox["z", "2"]}]]}], "]"}], "r"]}], ")"}]}], ",", 
     SuperscriptBox["r", "3"], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"1", "+", 
          FractionBox["z", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["r", "2"], "+", 
             SuperscriptBox["z", "2"]}]]]}], 
         RowBox[{"z", "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            SuperscriptBox["z", "2"]}]]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"a", " ", "z", " ", 
           SuperscriptBox[
            RowBox[{"Sec", "[", 
             RowBox[{"t", " ", "z"}], "]"}], "2"]}], "-", 
          RowBox[{"Sin", "[", "t", "]"}]}], "r"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"1", "+", 
          FractionBox["z", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["r", "2"], "+", 
             SuperscriptBox["z", "2"]}]]]}], 
         RowBox[{"z", "+", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["r", "2"], "+", 
            SuperscriptBox["z", "2"]}]]}]], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"a", " ", "z", " ", 
           SuperscriptBox[
            RowBox[{"Sec", "[", 
             RowBox[{"t", " ", "z"}], "]"}], "2"]}], "-", 
          RowBox[{"Sin", "[", "t", "]"}]}], "r"]}], ")"}]}], ",", 
     RowBox[{"a", " ", "t", " ", 
      SuperscriptBox[
       RowBox[{"Sec", "[", 
        RowBox[{"t", " ", "z"}], "]"}], "2"]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eps", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"Grad", "[", "u", "]"}], " ", "+", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", ")"}], " ", "/", " ", 
    "2"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", "eps", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gradtheta", " ", "=", " ", 
   RowBox[{"-", " ", 
    RowBox[{"Curl", "[", "eps", "]"}]}]}], " ", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"theta", " ", "=", " ", 
   RowBox[{"IntegrateNabla", "[", " ", "gradtheta", " ", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Grad", "[", "theta", "]"}], " ", "-", " ", "gradtheta"}], 
  "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "t", " ", "z"}], "2"]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "3"], " ", "z"}], "12"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "5"], " ", "z"}], "960"], "-", 
          RowBox[{"z", " ", 
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], "r"], "+", 
        RowBox[{"Sin", "[", "t", "]"}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"t", " ", "z"}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "3"], " ", "z"}], "8"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "5"], " ", "z"}], "960"], "+", 
          RowBox[{"z", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["t", "2"]}], "+", 
             FractionBox[
              SuperscriptBox["t", "3"], "8"], "+", 
             FractionBox[
              SuperscriptBox["t", "5"], "480"], "+", 
             FractionBox[
              SuperscriptBox["t", "7"], "80640"], "-", 
             FractionBox[
              RowBox[{"Sin", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}]}], "r"]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["t", "2"]}], "-", 
        FractionBox[
         SuperscriptBox["t", "4"], "48"], "-", 
        FractionBox[
         SuperscriptBox["t", "6"], "2880"], "-", 
        FractionBox[
         SuperscriptBox["t", "8"], "645120"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           FractionBox["t", "2"], "]"}], "2"]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "t", " ", "z"}], "2"]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "3"], " ", "z"}], "12"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "5"], " ", "z"}], "960"], "-", 
          RowBox[{"z", " ", 
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], "r"], "+", 
        RowBox[{"Sin", "[", "t", "]"}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"t", " ", "z"}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "3"], " ", "z"}], "8"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "5"], " ", "z"}], "960"], "+", 
          RowBox[{"z", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["t", "2"]}], "+", 
             FractionBox[
              SuperscriptBox["t", "3"], "8"], "+", 
             FractionBox[
              SuperscriptBox["t", "5"], "480"], "+", 
             FractionBox[
              SuperscriptBox["t", "7"], "80640"], "-", 
             FractionBox[
              RowBox[{"Sin", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}]}], "r"]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"], " ", "z"}], "4"]}], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "4"], " ", "z"}], "48"], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "6"], " ", "z"}], "5760"], "+", 
            RowBox[{"z", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], "2"]}]}], ")"}]}], "r"], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", 
            FractionBox[
             RowBox[{"3", " ", 
              SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
            RowBox[{"z", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "2"]}], "+", 
               FractionBox[
                RowBox[{"3", " ", 
                 SuperscriptBox["t", "2"]}], "8"], "+", 
               FractionBox[
                SuperscriptBox["t", "4"], "96"], "+", 
               FractionBox[
                SuperscriptBox["t", "6"], "11520"], "-", 
               FractionBox[
                RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"r", " ", 
             RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "r"]}], ")"}]}], 
     ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["t", "2"], "+", 
        FractionBox[
         SuperscriptBox["t", "5"], "960"], "+", 
        FractionBox[
         SuperscriptBox["t", "7"], "80640"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"r", " ", "t"}], "2"]}], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "5"]}], "960"], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "7"]}], "80640"], "-", 
          RowBox[{"r", " ", 
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
        FractionBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["t", "2"]}], "-", 
        FractionBox[
         SuperscriptBox["t", "4"], "48"], "-", 
        FractionBox[
         SuperscriptBox["t", "6"], "2880"], "-", 
        FractionBox[
         SuperscriptBox["t", "8"], "645120"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           FractionBox["t", "2"], "]"}], "2"]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["t", "2"], "+", 
        FractionBox[
         SuperscriptBox["t", "5"], "960"], "+", 
        FractionBox[
         SuperscriptBox["t", "7"], "80640"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"r", " ", "t"}], "2"]}], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "5"]}], "960"], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "7"]}], "80640"], "-", 
          RowBox[{"r", " ", 
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
        FractionBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], ")"}]}], ",", "0"}], "}"}]}],
   "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "t"}], "-", 
         FractionBox[
          SuperscriptBox["t", "3"], "12"], "-", 
         FractionBox[
          SuperscriptBox["t", "5"], "480"], "-", 
         FractionBox[
          SuperscriptBox["t", "7"], "80640"], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", 
           FractionBox["t", "2"], "]"}], " ", 
          RowBox[{"Sin", "[", 
           FractionBox["t", "2"], "]"}]}]}], 
        RowBox[{"2", " ", "r"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"3", " ", "t"}], "2"]}], "-", 
            FractionBox[
             SuperscriptBox["t", "3"], "12"], "-", 
            FractionBox[
             SuperscriptBox["t", "5"], "960"], "-", 
            RowBox[{
             RowBox[{"Cos", "[", 
              FractionBox["t", "2"], "]"}], " ", 
             RowBox[{"Sin", "[", 
              FractionBox["t", "2"], "]"}]}]}], "r"]}], "+", 
         FractionBox[
          RowBox[{
           FractionBox["t", "2"], "+", 
           FractionBox[
            SuperscriptBox["t", "5"], "960"], "+", 
           FractionBox[
            SuperscriptBox["t", "7"], "80640"], "-", 
           FractionBox[
            RowBox[{"Sin", "[", "t", "]"}], "2"]}], "r"]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox["t", "2"], "+", 
        FractionBox[
         SuperscriptBox["t", "5"], "960"], "+", 
        FractionBox[
         SuperscriptBox["t", "7"], "80640"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"r", " ", "t"}], "2"]}], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "5"]}], "960"], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "7"]}], "80640"], "-", 
          RowBox[{"r", " ", 
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
        FractionBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
       RowBox[{"2", " ", "r"}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["t", "2"]}], "-", 
         FractionBox[
          SuperscriptBox["t", "4"], "48"], "-", 
         FractionBox[
          SuperscriptBox["t", "6"], "2880"], "-", 
         FractionBox[
          SuperscriptBox["t", "8"], "645120"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], "2"]}]}], 
        RowBox[{"2", " ", "r"}]]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"3", " ", 
                 SuperscriptBox["t", "2"]}], "4"]}], "-", 
              FractionBox[
               SuperscriptBox["t", "4"], "48"], "-", 
              FractionBox[
               SuperscriptBox["t", "6"], "5760"], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                FractionBox["t", "2"], "]"}], "2"]}], ")"}]}], "r"]}], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["1", "2"], "+", 
             FractionBox[
              SuperscriptBox["t", "4"], "192"], "+", 
             FractionBox[
              SuperscriptBox["t", "6"], "11520"], "-", 
             FractionBox[
              RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "r"]}], 
        ")"}]}], "-", 
      FractionBox[
       RowBox[{
        FractionBox["1", "2"], "+", 
        FractionBox[
         SuperscriptBox["t", "4"], "192"], "+", 
        FractionBox[
         SuperscriptBox["t", "6"], "11520"], "-", 
        FractionBox[
         RowBox[{"Cos", "[", "t", "]"}], "2"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["r", "2"]}], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "4"]}], "192"], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "6"]}], "11520"], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", "r", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], "2"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "r", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], 
       RowBox[{"2", " ", "r"}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["t", "2"]}], "-", 
            FractionBox[
             SuperscriptBox["t", "5"], "960"], "-", 
            FractionBox[
             SuperscriptBox["t", "7"], "80640"], "-", 
            RowBox[{
             RowBox[{"Cos", "[", 
              FractionBox["t", "2"], "]"}], " ", 
             RowBox[{"Sin", "[", 
              FractionBox["t", "2"], "]"}]}]}], "r"]}], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"r", " ", "t"}], "2"]}], "-", 
           FractionBox[
            RowBox[{"r", " ", 
             SuperscriptBox["t", "5"]}], "960"], "-", 
           FractionBox[
            RowBox[{"r", " ", 
             SuperscriptBox["t", "7"]}], "80640"], "-", 
           RowBox[{"r", " ", 
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], " ", 
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}]}]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"3", " ", "t"}], "2"]}], "-", 
           FractionBox[
            SuperscriptBox["t", "3"], "12"], "-", 
           FractionBox[
            SuperscriptBox["t", "5"], "960"], "-", 
           RowBox[{
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], " ", 
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
         FractionBox[
          RowBox[{
           FractionBox["t", "2"], "+", 
           FractionBox[
            SuperscriptBox["t", "5"], "960"], "+", 
           FractionBox[
            SuperscriptBox["t", "7"], "80640"], "-", 
           FractionBox[
            RowBox[{"Sin", "[", "t", "]"}], "2"]}], "r"]}], ")"}]}]}], ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"3", " ", "t", " ", "z"}], "2"]}], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "3"], " ", "z"}], "12"], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "5"], " ", "z"}], "960"], "-", 
            RowBox[{"z", " ", 
             RowBox[{"Cos", "[", 
              FractionBox["t", "2"], "]"}], " ", 
             RowBox[{"Sin", "[", 
              FractionBox["t", "2"], "]"}]}]}], 
           SuperscriptBox["r", "2"]]}], "-", 
         FractionBox[
          RowBox[{"Sin", "[", "t", "]"}], "r"], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"t", " ", "z"}], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["t", "3"], " ", "z"}], "8"], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["t", "5"], " ", "z"}], "960"], "+", 
           RowBox[{"z", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["t", "2"]}], "+", 
              FractionBox[
               SuperscriptBox["t", "3"], "8"], "+", 
              FractionBox[
               SuperscriptBox["t", "5"], "480"], "+", 
              FractionBox[
               SuperscriptBox["t", "7"], "80640"], "-", 
              FractionBox[
               RowBox[{"Sin", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
           RowBox[{"r", " ", 
            RowBox[{"Sin", "[", "t", "]"}]}]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "t", " ", "z"}], "2"]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "3"], " ", "z"}], "12"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "5"], " ", "z"}], "960"], "-", 
          RowBox[{"z", " ", 
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], "r"], "+", 
        RowBox[{"Sin", "[", "t", "]"}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"t", " ", "z"}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "3"], " ", "z"}], "8"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "5"], " ", "z"}], "960"], "+", 
          RowBox[{"z", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["t", "2"]}], "+", 
             FractionBox[
              SuperscriptBox["t", "3"], "8"], "+", 
             FractionBox[
              SuperscriptBox["t", "5"], "480"], "+", 
             FractionBox[
              SuperscriptBox["t", "7"], "80640"], "-", 
             FractionBox[
              RowBox[{"Sin", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}]}], "r"]}], "r"]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"3", " ", 
                 SuperscriptBox["t", "2"], " ", "z"}], "4"]}], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["t", "4"], " ", "z"}], "48"], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["t", "6"], " ", "z"}], "5760"], "+", 
              RowBox[{"z", " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 FractionBox["t", "2"], "]"}], "2"]}]}], ")"}]}], 
           SuperscriptBox["r", "2"]]}], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "r"], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
             RowBox[{"z", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "2"]}], "+", 
                FractionBox[
                 RowBox[{"3", " ", 
                  SuperscriptBox["t", "2"]}], "8"], "+", 
                FractionBox[
                 SuperscriptBox["t", "4"], "96"], "+", 
                FractionBox[
                 SuperscriptBox["t", "6"], "11520"], "-", 
                FractionBox[
                 RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"], " ", "z"}], "4"]}], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "4"], " ", "z"}], "48"], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "6"], " ", "z"}], "5760"], "+", 
            RowBox[{"z", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], "2"]}]}], ")"}]}], "r"], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", 
            FractionBox[
             RowBox[{"3", " ", 
              SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
            RowBox[{"z", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "2"]}], "+", 
               FractionBox[
                RowBox[{"3", " ", 
                 SuperscriptBox["t", "2"]}], "8"], "+", 
               FractionBox[
                SuperscriptBox["t", "4"], "96"], "+", 
               FractionBox[
                SuperscriptBox["t", "6"], "11520"], "-", 
               FractionBox[
                RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"r", " ", 
             RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "r"]}], 
       RowBox[{"2", " ", "r"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"Cos", "[", "t", "]"}], "-", 
        FractionBox[
         RowBox[{"z", "-", 
          FractionBox[
           RowBox[{"3", " ", 
            SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
          RowBox[{"z", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "2"]}], "+", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"]}], "8"], "+", 
             FractionBox[
              SuperscriptBox["t", "4"], "96"], "+", 
             FractionBox[
              SuperscriptBox["t", "6"], "11520"], "-", 
             FractionBox[
              RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}]}], "r"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "z"}], "2"]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "2"], " ", "z"}], "4"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "4"], " ", "z"}], "192"], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", "z", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], "2"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "z", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], 
       RowBox[{"2", " ", "r"}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "t"}], "-", 
        FractionBox[
         SuperscriptBox["t", "3"], "12"], "-", 
        FractionBox[
         SuperscriptBox["t", "5"], "480"], "-", 
        FractionBox[
         SuperscriptBox["t", "7"], "80640"], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          FractionBox["t", "2"], "]"}], " ", 
         RowBox[{"Sin", "[", 
          FractionBox["t", "2"], "]"}]}]}], 
       RowBox[{"2", " ", "r"}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["t", "2"]}], "-", 
           FractionBox[
            SuperscriptBox["t", "5"], "960"], "-", 
           FractionBox[
            SuperscriptBox["t", "7"], "80640"], "-", 
           RowBox[{
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], " ", 
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"r", " ", "t"}], "2"]}], "-", 
           FractionBox[
            RowBox[{"r", " ", 
             SuperscriptBox["t", "5"]}], "960"], "-", 
           FractionBox[
            RowBox[{"r", " ", 
             SuperscriptBox["t", "7"]}], "80640"], "-", 
           RowBox[{"r", " ", 
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], " ", 
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}]}]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{
        FractionBox["t", "2"], "+", 
        FractionBox[
         SuperscriptBox["t", "5"], "960"], "+", 
        FractionBox[
         SuperscriptBox["t", "7"], "80640"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"r", " ", "t"}], "2"]}], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "5"]}], "960"], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "7"]}], "80640"], "-", 
          RowBox[{"r", " ", 
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
        FractionBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
       RowBox[{"2", " ", "r"}]]}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["t", "2"], "-", 
    FractionBox[
     SuperscriptBox["t", "3"], "12"], "-", 
    FractionBox[
     SuperscriptBox["t", "5"], "960"], "+", 
    FractionBox[
     SuperscriptBox["t", "7"], "80640"], "+", 
    FractionBox[
     SuperscriptBox["t", "9"], "11612160"]}], ",", 
   RowBox[{
    FractionBox[
     SuperscriptBox["t", "2"], "2"], "+", 
    FractionBox[
     SuperscriptBox["t", "4"], "96"], "+", 
    FractionBox[
     SuperscriptBox["t", "6"], "5760"], "+", 
    FractionBox[
     SuperscriptBox["t", "8"], "1290240"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"t", " ", 
       RowBox[{"(", 
        RowBox[{"161280", "+", 
         RowBox[{"6720", " ", 
          SuperscriptBox["t", "2"]}], "+", 
         RowBox[{"168", " ", 
          SuperscriptBox["t", "4"]}], "+", 
         SuperscriptBox["t", "6"]}], ")"}], " ", "z"}], 
      RowBox[{"161280", " ", "r"}]]}], "-", 
    RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"645120", "+", 
          RowBox[{"13440", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"224", " ", 
           SuperscriptBox["t", "4"]}], "+", 
          SuperscriptBox["t", "6"]}], ")"}]}], 
       RowBox[{"1290240", " ", "r"}]]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"t", " ", 
       RowBox[{"(", 
        RowBox[{"5806080", "-", 
         RowBox[{"967680", " ", 
          SuperscriptBox["t", "2"]}], "-", 
         RowBox[{"12096", " ", 
          SuperscriptBox["t", "4"]}], "+", 
         RowBox[{"144", " ", 
          SuperscriptBox["t", "6"]}], "+", 
         SuperscriptBox["t", "8"]}], ")"}]}], 
      RowBox[{"11612160", " ", "r"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", "\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Curl", "[", " ", 
    RowBox[{"Transpose", "[", " ", 
     RowBox[{"Grad", "[", "theta", "]"}], "]"}], " ", "]"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"omega", " ", "=", " ", 
   RowBox[{"Table", "[", " ", 
    RowBox[{
     RowBox[{"Sum", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"Signature", "[", 
         RowBox[{"{", 
          RowBox[{"i", ",", "j", ",", "k"}], "}"}], "]"}], "  ", 
        RowBox[{"theta", "[", 
         RowBox[{"[", "k", "]"}], "]"}]}], " ", ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", "3"}], "}"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], " ", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"omega", " ", "+", " ", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"Grad", "[", "u", "]"}], " ", "-", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", ")"}], " ", "/", " ", 
     "2"}]}], " ", "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"u", " ", "=", " ", 
   RowBox[{"IntegrateNabla", "[", " ", 
    RowBox[{"eps", " ", "+", " ", "omega"}], " ", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"2", " ", "eps"}], " ", "-", " ", 
   RowBox[{"Grad", "[", "u", "]"}], " ", "-", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Grad", "[", "u", "]"}], "]"}]}], " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"]}], "4"]}], "-", 
             FractionBox[
              SuperscriptBox["t", "4"], "48"], "-", 
             FractionBox[
              SuperscriptBox["t", "6"], "5760"], "+", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], "2"]}], ")"}]}], 
          SuperscriptBox["r", "2"]], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["1", "2"], "+", 
             FractionBox[
              SuperscriptBox["t", "4"], "192"], "+", 
             FractionBox[
              SuperscriptBox["t", "6"], "11520"], "-", 
             FractionBox[
              RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"]}], "4"]}], "-", 
            FractionBox[
             SuperscriptBox["t", "4"], "48"], "-", 
            FractionBox[
             SuperscriptBox["t", "6"], "5760"], "+", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              FractionBox["t", "2"], "]"}], "2"]}], ")"}]}], "r"], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "2"], "+", 
            FractionBox[
             SuperscriptBox["t", "4"], "192"], "+", 
            FractionBox[
             SuperscriptBox["t", "6"], "11520"], "-", 
            FractionBox[
             RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "r"]}], 
       RowBox[{"2", " ", "r"}]], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           FractionBox["1", "2"], "+", 
           FractionBox[
            SuperscriptBox["t", "4"], "192"], "+", 
           FractionBox[
            SuperscriptBox["t", "6"], "11520"], "-", 
           FractionBox[
            RowBox[{"Cos", "[", "t", "]"}], "2"]}], "r"]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["3", "2"]}], "-", 
          FractionBox[
           SuperscriptBox["t", "2"], "4"], "-", 
          FractionBox[
           SuperscriptBox["t", "4"], "192"], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], "2"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], 
       RowBox[{"2", " ", "r"}]], "+", 
      RowBox[{
       FractionBox["1", "r"], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", "2"}], "-", 
           FractionBox[
            SuperscriptBox["t", "2"], "4"], "-", 
           FractionBox[
            SuperscriptBox["t", "4"], "96"], "-", 
           FractionBox[
            SuperscriptBox["t", "6"], "11520"], "-", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}], "2"]}], 
          RowBox[{"2", " ", "r"}]], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "2"]}], "-", 
               FractionBox[
                SuperscriptBox["t", "4"], "192"], "-", 
               FractionBox[
                SuperscriptBox["t", "6"], "11520"], "-", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  FractionBox["t", "2"], "]"}], "2"]}], "+", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], "+", 
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               FractionBox["r", "2"]}], "-", 
              FractionBox[
               RowBox[{"r", " ", 
                SuperscriptBox["t", "4"]}], "192"], "-", 
              FractionBox[
               RowBox[{"r", " ", 
                SuperscriptBox["t", "6"]}], "11520"], "-", 
              RowBox[{
               FractionBox["1", "2"], " ", "r", " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 FractionBox["t", "2"], "]"}], "2"]}], "+", 
              RowBox[{
               FractionBox["1", "2"], " ", "r", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 FractionBox["t", "2"], "]"}], "2"]}]}], 
             SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
         FractionBox[
          RowBox[{
           FractionBox["1", "2"], "+", 
           FractionBox[
            SuperscriptBox["t", "4"], "192"], "+", 
           FractionBox[
            SuperscriptBox["t", "6"], "11520"], "-", 
           FractionBox[
            RowBox[{"Cos", "[", "t", "]"}], "2"], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              FractionBox["r", "2"]}], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "4"]}], "192"], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "6"]}], "11520"], "-", 
             RowBox[{
              FractionBox["1", "2"], " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                FractionBox["t", "2"], "]"}], "2"]}], "+", 
             RowBox[{
              FractionBox["1", "2"], " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], 
          RowBox[{"2", " ", "r"}]]}], ")"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "t"}], "-", 
        FractionBox[
         SuperscriptBox["t", "3"], "12"], "-", 
        FractionBox[
         SuperscriptBox["t", "5"], "480"], "-", 
        FractionBox[
         SuperscriptBox["t", "7"], "80640"], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          FractionBox["t", "2"], "]"}], " ", 
         RowBox[{"Sin", "[", 
          FractionBox["t", "2"], "]"}]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["t", "2"]}], "-", 
             FractionBox[
              SuperscriptBox["t", "5"], "960"], "-", 
             FractionBox[
              SuperscriptBox["t", "7"], "80640"], "-", 
             RowBox[{
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], " ", 
              RowBox[{"Sin", "[", 
               FractionBox["t", "2"], "]"}]}]}], ")"}]}], 
          SuperscriptBox["r", "2"]], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"r", " ", "t"}], "2"]}], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "5"]}], "960"], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "7"]}], "80640"], "-", 
             RowBox[{"r", " ", 
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], " ", 
              RowBox[{"Sin", "[", 
               FractionBox["t", "2"], "]"}]}]}], ")"}]}], 
          SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["t", "2"]}], "-", 
          FractionBox[
           SuperscriptBox["t", "5"], "960"], "-", 
          FractionBox[
           SuperscriptBox["t", "7"], "80640"], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"r", " ", "t"}], "2"]}], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "5"]}], "960"], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "7"]}], "80640"], "-", 
          RowBox[{"r", " ", 
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], 
         SuperscriptBox["r", "2"]]}], 
       RowBox[{"2", " ", "r"}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"3", " ", "t"}], "2"]}], "-", 
           FractionBox[
            SuperscriptBox["t", "3"], "12"], "-", 
           FractionBox[
            SuperscriptBox["t", "5"], "960"], "-", 
           RowBox[{
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], " ", 
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}]}]}], 
          SuperscriptBox["r", "2"]], "-", 
         FractionBox[
          RowBox[{
           FractionBox["t", "2"], "+", 
           FractionBox[
            SuperscriptBox["t", "5"], "960"], "+", 
           FractionBox[
            SuperscriptBox["t", "7"], "80640"], "-", 
           FractionBox[
            RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "t"}], "2"]}], "-", 
          FractionBox[
           SuperscriptBox["t", "3"], "12"], "-", 
          FractionBox[
           SuperscriptBox["t", "5"], "960"], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
        FractionBox[
         RowBox[{
          FractionBox["t", "2"], "+", 
          FractionBox[
           SuperscriptBox["t", "5"], "960"], "+", 
          FractionBox[
           SuperscriptBox["t", "7"], "80640"], "-", 
          FractionBox[
           RowBox[{"Sin", "[", "t", "]"}], "2"]}], "r"]}], "r"], "-", 
      FractionBox[
       RowBox[{
        FractionBox["t", "2"], "+", 
        FractionBox[
         SuperscriptBox["t", "5"], "960"], "+", 
        FractionBox[
         SuperscriptBox["t", "7"], "80640"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"r", " ", "t"}], "2"]}], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "5"]}], "960"], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "7"]}], "80640"], "-", 
          RowBox[{"r", " ", 
           RowBox[{"Cos", "[", 
            FractionBox["t", "2"], "]"}], " ", 
           RowBox[{"Sin", "[", 
            FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
        FractionBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["t", "2"]}], "-", 
        FractionBox[
         SuperscriptBox["t", "4"], "48"], "-", 
        FractionBox[
         SuperscriptBox["t", "6"], "2880"], "-", 
        FractionBox[
         SuperscriptBox["t", "8"], "645120"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           FractionBox["t", "2"], "]"}], "2"]}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}]], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"3", " ", 
                 SuperscriptBox["t", "2"]}], "4"]}], "-", 
              FractionBox[
               SuperscriptBox["t", "4"], "48"], "-", 
              FractionBox[
               SuperscriptBox["t", "6"], "5760"], "+", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                FractionBox["t", "2"], "]"}], "2"]}], ")"}]}], 
           SuperscriptBox["r", "2"]]}], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             FractionBox["1", "2"], "+", 
             FractionBox[
              SuperscriptBox["t", "4"], "192"], "+", 
             FractionBox[
              SuperscriptBox["t", "6"], "11520"], "-", 
             FractionBox[
              RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], "-", 
          FractionBox[
           SuperscriptBox["t", "4"], "192"], "-", 
          FractionBox[
           SuperscriptBox["t", "6"], "11520"], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], "2"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}], "2"]}]}], "r"], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["r", "2"]}], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "4"]}], "192"], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "6"]}], "11520"], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", "r", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], "2"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "r", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}], "2"]}]}], 
         SuperscriptBox["r", "2"]]}], 
       RowBox[{"2", " ", "r"}]], "+", 
      FractionBox[
       RowBox[{
        FractionBox["1", "2"], "+", 
        FractionBox[
         SuperscriptBox["t", "4"], "192"], "+", 
        FractionBox[
         SuperscriptBox["t", "6"], "11520"], "-", 
        FractionBox[
         RowBox[{"Cos", "[", "t", "]"}], "2"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["r", "2"]}], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "4"]}], "192"], "-", 
          FractionBox[
           RowBox[{"r", " ", 
            SuperscriptBox["t", "6"]}], "11520"], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", "r", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], "2"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "r", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}]], "+", 
      RowBox[{
       FractionBox["1", "r"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["t", "2"]}], "-", 
            FractionBox[
             SuperscriptBox["t", "4"], "48"], "-", 
            FractionBox[
             SuperscriptBox["t", "6"], "2880"], "-", 
            FractionBox[
             SuperscriptBox["t", "8"], "645120"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], "2"]}]}], 
           RowBox[{"2", " ", "r"}]]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"3", " ", 
                    SuperscriptBox["t", "2"]}], "4"]}], "-", 
                 FractionBox[
                  SuperscriptBox["t", "4"], "48"], "-", 
                 FractionBox[
                  SuperscriptBox["t", "6"], "5760"], "+", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   FractionBox["t", "2"], "]"}], "2"]}], ")"}]}], "r"]}], "-",
             
            FractionBox[
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{
                FractionBox["1", "2"], "+", 
                FractionBox[
                 SuperscriptBox["t", "4"], "192"], "+", 
                FractionBox[
                 SuperscriptBox["t", "6"], "11520"], "-", 
                FractionBox[
                 RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "r"]}], 
           ")"}]}], "-", 
         FractionBox[
          RowBox[{
           FractionBox["1", "2"], "+", 
           FractionBox[
            SuperscriptBox["t", "4"], "192"], "+", 
           FractionBox[
            SuperscriptBox["t", "6"], "11520"], "-", 
           FractionBox[
            RowBox[{"Cos", "[", "t", "]"}], "2"], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              FractionBox["r", "2"]}], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "4"]}], "192"], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "6"]}], "11520"], "-", 
             RowBox[{
              FractionBox["1", "2"], " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                FractionBox["t", "2"], "]"}], "2"]}], "+", 
             RowBox[{
              FractionBox["1", "2"], " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], 
          RowBox[{"2", " ", "r"}]]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "r"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "2"}], "-", 
            FractionBox[
             SuperscriptBox["t", "2"], "4"], "-", 
            FractionBox[
             SuperscriptBox["t", "4"], "96"], "-", 
            FractionBox[
             SuperscriptBox["t", "6"], "11520"], "-", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              FractionBox["t", "2"], "]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              FractionBox["t", "2"], "]"}], "2"]}], 
           RowBox[{"2", " ", "r"}]]}], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               FractionBox["1", "2"], "+", 
               FractionBox[
                SuperscriptBox["t", "4"], "192"], "+", 
               FractionBox[
                SuperscriptBox["t", "6"], "11520"], "-", 
               FractionBox[
                RowBox[{"Cos", "[", "t", "]"}], "2"]}], "r"]}], "+", 
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               FractionBox["3", "2"]}], "-", 
              FractionBox[
               SuperscriptBox["t", "2"], "4"], "-", 
              FractionBox[
               SuperscriptBox["t", "4"], "192"], "-", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 FractionBox["t", "2"], "]"}], "2"]}], "+", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], ")"}]}], "+",
          
         FractionBox[
          RowBox[{
           FractionBox["1", "2"], "+", 
           FractionBox[
            SuperscriptBox["t", "4"], "192"], "+", 
           FractionBox[
            SuperscriptBox["t", "6"], "11520"], "-", 
           FractionBox[
            RowBox[{"Cos", "[", "t", "]"}], "2"], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              FractionBox["r", "2"]}], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "4"]}], "192"], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "6"]}], "11520"], "-", 
             RowBox[{
              FractionBox["1", "2"], " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                FractionBox["t", "2"], "]"}], "2"]}], "+", 
             RowBox[{
              FractionBox["1", "2"], " ", "r", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], 
          RowBox[{"2", " ", "r"}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox["t", "2"]}], "-", 
              FractionBox[
               SuperscriptBox["t", "5"], "960"], "-", 
              FractionBox[
               SuperscriptBox["t", "7"], "80640"], "-", 
              RowBox[{
               RowBox[{"Cos", "[", 
                FractionBox["t", "2"], "]"}], " ", 
               RowBox[{"Sin", "[", 
                FractionBox["t", "2"], "]"}]}]}], ")"}]}], 
           SuperscriptBox["r", "2"]]}], "+", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"r", " ", "t"}], "2"]}], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "5"]}], "960"], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "7"]}], "80640"], "-", 
             RowBox[{"r", " ", 
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], " ", 
              RowBox[{"Sin", "[", 
               FractionBox["t", "2"], "]"}]}]}], ")"}]}], 
          SuperscriptBox["r", "3"]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               FractionBox["t", "2"]}], "-", 
              FractionBox[
               SuperscriptBox["t", "5"], "960"], "-", 
              FractionBox[
               SuperscriptBox["t", "7"], "80640"], "-", 
              RowBox[{
               RowBox[{"Cos", "[", 
                FractionBox["t", "2"], "]"}], " ", 
               RowBox[{"Sin", "[", 
                FractionBox["t", "2"], "]"}]}]}], "r"]}], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"r", " ", "t"}], "2"]}], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "5"]}], "960"], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "7"]}], "80640"], "-", 
             RowBox[{"r", " ", 
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], " ", 
              RowBox[{"Sin", "[", 
               FractionBox["t", "2"], "]"}]}]}], 
            SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"3", " ", "t"}], "2"]}], "-", 
             FractionBox[
              SuperscriptBox["t", "3"], "12"], "-", 
             FractionBox[
              SuperscriptBox["t", "5"], "960"], "-", 
             RowBox[{
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], " ", 
              RowBox[{"Sin", "[", 
               FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
           FractionBox[
            RowBox[{
             FractionBox["t", "2"], "+", 
             FractionBox[
              SuperscriptBox["t", "5"], "960"], "+", 
             FractionBox[
              SuperscriptBox["t", "7"], "80640"], "-", 
             FractionBox[
              RowBox[{"Sin", "[", "t", "]"}], "2"]}], "r"]}], ")"}]}]}], "r"],
       "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"3", " ", "t"}], "2"]}], "-", 
           FractionBox[
            SuperscriptBox["t", "3"], "12"], "-", 
           FractionBox[
            SuperscriptBox["t", "5"], "960"], "-", 
           RowBox[{
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], " ", 
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}]}]}], 
          SuperscriptBox["r", "2"]], "-", 
         FractionBox[
          RowBox[{
           FractionBox["t", "2"], "+", 
           FractionBox[
            SuperscriptBox["t", "5"], "960"], "+", 
           FractionBox[
            SuperscriptBox["t", "7"], "80640"], "-", 
           FractionBox[
            RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["1", "r"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "t"}], "-", 
            FractionBox[
             SuperscriptBox["t", "3"], "12"], "-", 
            FractionBox[
             SuperscriptBox["t", "5"], "480"], "-", 
            FractionBox[
             SuperscriptBox["t", "7"], "80640"], "-", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", 
              FractionBox["t", "2"], "]"}], " ", 
             RowBox[{"Sin", "[", 
              FractionBox["t", "2"], "]"}]}]}], 
           RowBox[{"2", " ", "r"}]]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"3", " ", "t"}], "2"]}], "-", 
               FractionBox[
                SuperscriptBox["t", "3"], "12"], "-", 
               FractionBox[
                SuperscriptBox["t", "5"], "960"], "-", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 FractionBox["t", "2"], "]"}], " ", 
                RowBox[{"Sin", "[", 
                 FractionBox["t", "2"], "]"}]}]}], "r"]}], "+", 
            FractionBox[
             RowBox[{
              FractionBox["t", "2"], "+", 
              FractionBox[
               SuperscriptBox["t", "5"], "960"], "+", 
              FractionBox[
               SuperscriptBox["t", "7"], "80640"], "-", 
              FractionBox[
               RowBox[{"Sin", "[", "t", "]"}], "2"]}], "r"]}], ")"}]}], "+", 
         FractionBox[
          RowBox[{
           FractionBox["t", "2"], "+", 
           FractionBox[
            SuperscriptBox["t", "5"], "960"], "+", 
           FractionBox[
            SuperscriptBox["t", "7"], "80640"], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"r", " ", "t"}], "2"]}], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "5"]}], "960"], "-", 
             FractionBox[
              RowBox[{"r", " ", 
               SuperscriptBox["t", "7"]}], "80640"], "-", 
             RowBox[{"r", " ", 
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], " ", 
              RowBox[{"Sin", "[", 
               FractionBox["t", "2"], "]"}]}]}], "r"], "-", 
           FractionBox[
            RowBox[{"Sin", "[", "t", "]"}], "2"]}], 
          RowBox[{"2", " ", "r"}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"3", " ", 
                 SuperscriptBox["t", "2"], " ", "z"}], "4"]}], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["t", "4"], " ", "z"}], "48"], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["t", "6"], " ", "z"}], "5760"], "+", 
              RowBox[{"z", " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 FractionBox["t", "2"], "]"}], "2"]}]}], ")"}]}], 
           SuperscriptBox["r", "3"]]}], "+", 
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], 
          SuperscriptBox["r", "2"]], "-", 
         FractionBox[
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"z", "-", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
             RowBox[{"z", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "2"]}], "+", 
                FractionBox[
                 RowBox[{"3", " ", 
                  SuperscriptBox["t", "2"]}], "8"], "+", 
                FractionBox[
                 SuperscriptBox["t", "4"], "96"], "+", 
                FractionBox[
                 SuperscriptBox["t", "6"], "11520"], "-", 
                FractionBox[
                 RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], 
          SuperscriptBox["r", "3"]]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"], " ", "z"}], "4"]}], "-", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "4"], " ", "z"}], "48"], "-", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "6"], " ", "z"}], "5760"], "+", 
             RowBox[{"z", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                FractionBox["t", "2"], "]"}], "2"]}]}], ")"}]}], 
          SuperscriptBox["r", "2"]]}], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "r"], "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", 
            FractionBox[
             RowBox[{"3", " ", 
              SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
            RowBox[{"z", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "2"]}], "+", 
               FractionBox[
                RowBox[{"3", " ", 
                 SuperscriptBox["t", "2"]}], "8"], "+", 
               FractionBox[
                SuperscriptBox["t", "4"], "96"], "+", 
               FractionBox[
                SuperscriptBox["t", "6"], "11520"], "-", 
               FractionBox[
                RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"r", " ", 
             RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], 
         SuperscriptBox["r", "2"]]}], 
       RowBox[{"2", " ", "r"}]], "+", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"], " ", "z"}], "4"]}], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "4"], " ", "z"}], "48"], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "6"], " ", "z"}], "5760"], "+", 
            RowBox[{"z", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               FractionBox["t", "2"], "]"}], "2"]}]}], ")"}]}], "r"], "+", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", 
            FractionBox[
             RowBox[{"3", " ", 
              SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
            RowBox[{"z", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "2"]}], "+", 
               FractionBox[
                RowBox[{"3", " ", 
                 SuperscriptBox["t", "2"]}], "8"], "+", 
               FractionBox[
                SuperscriptBox["t", "4"], "96"], "+", 
               FractionBox[
                SuperscriptBox["t", "6"], "11520"], "-", 
               FractionBox[
                RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"r", " ", 
             RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "r"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"Cos", "[", "t", "]"}], "r"]}], "+", 
        FractionBox[
         RowBox[{"z", "-", 
          FractionBox[
           RowBox[{"3", " ", 
            SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
          RowBox[{"z", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "2"]}], "+", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"]}], "8"], "+", 
             FractionBox[
              SuperscriptBox["t", "4"], "96"], "+", 
             FractionBox[
              SuperscriptBox["t", "6"], "11520"], "-", 
             FractionBox[
              RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}]}], 
         SuperscriptBox["r", "2"]], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "z"}], "2"]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "2"], " ", "z"}], "4"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "4"], " ", "z"}], "192"], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", "z", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], "2"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "z", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}], "2"]}]}], 
         SuperscriptBox["r", "2"]]}], 
       RowBox[{"2", " ", "r"}]], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"Cos", "[", "t", "]"}], "-", 
        FractionBox[
         RowBox[{"z", "-", 
          FractionBox[
           RowBox[{"3", " ", 
            SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
          RowBox[{"z", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["1", "2"]}], "+", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"]}], "8"], "+", 
             FractionBox[
              SuperscriptBox["t", "4"], "96"], "+", 
             FractionBox[
              SuperscriptBox["t", "6"], "11520"], "-", 
             FractionBox[
              RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}]}], "r"], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"3", " ", "z"}], "2"]}], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "2"], " ", "z"}], "4"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["t", "4"], " ", "z"}], "192"], "-", 
          RowBox[{
           FractionBox["1", "2"], " ", "z", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             FractionBox["t", "2"], "]"}], "2"]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", "z", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}]], "-", 
      RowBox[{
       FractionBox["1", "r"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox[
             RowBox[{"Cos", "[", "t", "]"}], "r"], "-", 
            FractionBox[
             RowBox[{"z", "-", 
              FractionBox[
               RowBox[{"3", " ", 
                SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
              RowBox[{"z", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox["1", "2"]}], "+", 
                 FractionBox[
                  RowBox[{"3", " ", 
                   SuperscriptBox["t", "2"]}], "8"], "+", 
                 FractionBox[
                  SuperscriptBox["t", "4"], "96"], "+", 
                 FractionBox[
                  SuperscriptBox["t", "6"], "11520"], "-", 
                 FractionBox[
                  RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"Cos", "[", "t", "]"}]}]}], 
             SuperscriptBox["r", "2"]], "+", 
            FractionBox[
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"3", " ", "z"}], "2"]}], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["t", "2"], " ", "z"}], "4"], "-", 
              FractionBox[
               RowBox[{
                SuperscriptBox["t", "4"], " ", "z"}], "192"], "-", 
              RowBox[{
               FractionBox["1", "2"], " ", "z", " ", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 FractionBox["t", "2"], "]"}], "2"]}], "+", 
              RowBox[{
               FractionBox["1", "2"], " ", "z", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 FractionBox["t", "2"], "]"}], "2"]}]}], 
             SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{"Cos", "[", "t", "]"}], "-", 
           FractionBox[
            RowBox[{"z", "-", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
             RowBox[{"z", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "2"]}], "+", 
                FractionBox[
                 RowBox[{"3", " ", 
                  SuperscriptBox["t", "2"]}], "8"], "+", 
                FractionBox[
                 SuperscriptBox["t", "4"], "96"], "+", 
                FractionBox[
                 SuperscriptBox["t", "6"], "11520"], "-", 
                FractionBox[
                 RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"Cos", "[", "t", "]"}]}]}], "r"], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"3", " ", "z"}], "2"]}], "-", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "2"], " ", "z"}], "4"], "-", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "4"], " ", "z"}], "192"], "-", 
             RowBox[{
              FractionBox["1", "2"], " ", "z", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                FractionBox["t", "2"], "]"}], "2"]}], "+", 
             RowBox[{
              FractionBox["1", "2"], " ", "z", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], "r"]}], 
        ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "r"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  FractionBox[
                   RowBox[{"3", " ", 
                    SuperscriptBox["t", "2"], " ", "z"}], "4"]}], "-", 
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["t", "4"], " ", "z"}], "48"], "-", 
                 FractionBox[
                  RowBox[{
                   SuperscriptBox["t", "6"], " ", "z"}], "5760"], "+", 
                 RowBox[{"z", " ", 
                  SuperscriptBox[
                   RowBox[{"Cos", "[", 
                    FractionBox["t", "2"], "]"}], "2"]}]}], ")"}]}], 
              SuperscriptBox["r", "2"]]}], "+", 
            FractionBox[
             RowBox[{"2", " ", 
              RowBox[{"Cos", "[", "t", "]"}]}], "r"], "-", 
            FractionBox[
             RowBox[{"2", " ", 
              RowBox[{"(", 
               RowBox[{"z", "-", 
                FractionBox[
                 RowBox[{"3", " ", 
                  SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
                RowBox[{"z", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", 
                    FractionBox["1", "2"]}], "+", 
                   FractionBox[
                    RowBox[{"3", " ", 
                    SuperscriptBox["t", "2"]}], "8"], "+", 
                   FractionBox[
                    SuperscriptBox["t", "4"], "96"], "+", 
                   FractionBox[
                    SuperscriptBox["t", "6"], "11520"], "-", 
                   FractionBox[
                    RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
                RowBox[{"r", " ", 
                 RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], 
             SuperscriptBox["r", "2"]]}], ")"}]}], "-", 
         FractionBox[
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"3", " ", 
                  SuperscriptBox["t", "2"], " ", "z"}], "4"]}], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["t", "4"], " ", "z"}], "48"], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["t", "6"], " ", "z"}], "5760"], "+", 
               RowBox[{"z", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  FractionBox["t", "2"], "]"}], "2"]}]}], ")"}]}], "r"], "+", 
           
           FractionBox[
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"z", "-", 
               FractionBox[
                RowBox[{"3", " ", 
                 SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
               RowBox[{"z", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox["1", "2"]}], "+", 
                  FractionBox[
                   RowBox[{"3", " ", 
                    SuperscriptBox["t", "2"]}], "8"], "+", 
                  FractionBox[
                   SuperscriptBox["t", "4"], "96"], "+", 
                  FractionBox[
                   SuperscriptBox["t", "6"], "11520"], "-", 
                  FractionBox[
                   RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
               RowBox[{"r", " ", 
                RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "r"]}], 
          RowBox[{"2", " ", "r"}]], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"Cos", "[", "t", "]"}], "-", 
           FractionBox[
            RowBox[{"z", "-", 
             FractionBox[
              RowBox[{"3", " ", 
               SuperscriptBox["t", "2"], " ", "z"}], "8"], "-", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "4"], " ", "z"}], "192"], "+", 
             RowBox[{"z", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "2"]}], "+", 
                FractionBox[
                 RowBox[{"3", " ", 
                  SuperscriptBox["t", "2"]}], "8"], "+", 
                FractionBox[
                 SuperscriptBox["t", "4"], "96"], "+", 
                FractionBox[
                 SuperscriptBox["t", "6"], "11520"], "-", 
                FractionBox[
                 RowBox[{"Cos", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"Cos", "[", "t", "]"}]}]}], "r"], "+", 
           FractionBox[
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"3", " ", "z"}], "2"]}], "-", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "2"], " ", "z"}], "4"], "-", 
             FractionBox[
              RowBox[{
               SuperscriptBox["t", "4"], " ", "z"}], "192"], "-", 
             RowBox[{
              FractionBox["1", "2"], " ", "z", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                FractionBox["t", "2"], "]"}], "2"]}], "+", 
             RowBox[{
              FractionBox["1", "2"], " ", "z", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                FractionBox["t", "2"], "]"}], "2"]}]}], "r"]}], 
          RowBox[{"2", " ", "r"}]]}], ")"}]}]}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"t", " ", 
         RowBox[{"(", 
          RowBox[{"161280", "+", 
           RowBox[{"6720", " ", 
            SuperscriptBox["t", "2"]}], "+", 
           RowBox[{"168", " ", 
            SuperscriptBox["t", "4"]}], "+", 
           SuperscriptBox["t", "6"]}], ")"}], " ", "z"}], 
        RowBox[{"161280", " ", "r"}]]}], "-", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["t", "2"], "2"]}], "-", 
      FractionBox[
       SuperscriptBox["t", "4"], "96"], "-", 
      FractionBox[
       SuperscriptBox["t", "6"], "5760"], "-", 
      FractionBox[
       SuperscriptBox["t", "8"], "1290240"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{"161280", "+", 
          RowBox[{"6720", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"168", " ", 
           SuperscriptBox["t", "4"]}], "+", 
          SuperscriptBox["t", "6"]}], ")"}], " ", "z"}], 
       RowBox[{"161280", " ", "r"}]], "+", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", "0", ",", 
     RowBox[{
      FractionBox["t", "2"], "-", 
      FractionBox[
       SuperscriptBox["t", "3"], "12"], "-", 
      FractionBox[
       SuperscriptBox["t", "5"], "960"], "+", 
      FractionBox[
       SuperscriptBox["t", "7"], "80640"], "+", 
      FractionBox[
       SuperscriptBox["t", "9"], "11612160"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       SuperscriptBox["t", "2"], "2"], "+", 
      FractionBox[
       SuperscriptBox["t", "4"], "96"], "+", 
      FractionBox[
       SuperscriptBox["t", "6"], "5760"], "+", 
      FractionBox[
       SuperscriptBox["t", "8"], "1290240"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["t", "2"]}], "+", 
      FractionBox[
       SuperscriptBox["t", "3"], "12"], "+", 
      FractionBox[
       SuperscriptBox["t", "5"], "960"], "-", 
      FractionBox[
       SuperscriptBox["t", "7"], "80640"], "-", 
      FractionBox[
       SuperscriptBox["t", "9"], "11612160"]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"t", " ", 
         RowBox[{"(", 
          RowBox[{"161280", "+", 
           RowBox[{"6720", " ", 
            SuperscriptBox["t", "2"]}], "+", 
           RowBox[{"168", " ", 
            SuperscriptBox["t", "4"]}], "+", 
           SuperscriptBox["t", "6"]}], ")"}], " ", "z"}], "+", 
        RowBox[{"161280", " ", "r", " ", 
         RowBox[{"Sin", "[", "t", "]"}]}]}], 
       RowBox[{"80640", " ", "r"}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["t", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"4320", "+", 
          RowBox[{"120", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          SuperscriptBox["t", "4"]}], ")"}]}], "5760"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{"161280", "+", 
          RowBox[{"6720", " ", 
           SuperscriptBox["t", "2"]}], "+", 
          RowBox[{"168", " ", 
           SuperscriptBox["t", "4"]}], "+", 
          SuperscriptBox["t", "6"]}], ")"}], " ", "z"}], "+", 
       RowBox[{"161280", " ", "r", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], 
      RowBox[{"80640", " ", "r"}]], ",", "0", ",", 
     RowBox[{"t", "-", 
      FractionBox[
       SuperscriptBox["t", "3"], "12"], "+", 
      FractionBox[
       SuperscriptBox["t", "7"], "40320"], "+", 
      FractionBox[
       SuperscriptBox["t", "9"], "11612160"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["t", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"4320", "+", 
         RowBox[{"120", " ", 
          SuperscriptBox["t", "2"]}], "+", 
         SuperscriptBox["t", "4"]}], ")"}]}], "5760"], ",", 
     RowBox[{
      RowBox[{"-", "t"}], "+", 
      FractionBox[
       SuperscriptBox["t", "3"], "12"], "-", 
      FractionBox[
       SuperscriptBox["t", "7"], "40320"], "-", 
      FractionBox[
       SuperscriptBox["t", "9"], "11612160"]}], ",", "0"}], "}"}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["t", "2"]}], " ", "z"}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", "4"], " ", "z"}], "48"], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", "6"], " ", "z"}], "2880"], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", "8"], " ", "z"}], "645120"], "+", 
    RowBox[{"z", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       FractionBox["t", "2"], "]"}], "2"]}]}], ",", 
   RowBox[{
    RowBox[{"t", " ", "z"}], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", "3"], " ", "z"}], "4"], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", "5"], " ", "z"}], "320"], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", "7"], " ", "z"}], "80640"], "+", 
    RowBox[{"z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["t", "2"]}], "+", 
       FractionBox[
        SuperscriptBox["t", "3"], "6"], "+", 
       FractionBox[
        SuperscriptBox["t", "5"], "480"], "+", 
       FractionBox[
        SuperscriptBox["t", "7"], "40320"], "+", 
       FractionBox[
        SuperscriptBox["t", "9"], "11612160"], "-", 
       FractionBox[
        RowBox[{"Sin", "[", "t", "]"}], "2"]}], ")"}]}], "+", 
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"r", " ", 
       SuperscriptBox["t", "2"]}], "4"]}], "+", 
    FractionBox[
     RowBox[{"r", " ", 
      SuperscriptBox["t", "4"]}], "48"], "+", 
    FractionBox[
     RowBox[{"r", " ", 
      SuperscriptBox["t", "6"]}], "5760"], "-", 
    FractionBox[
     RowBox[{"r", " ", 
      SuperscriptBox["t", "8"]}], "645120"], "-", 
    FractionBox[
     RowBox[{"r", " ", 
      SuperscriptBox["t", "10"]}], "116121600"], "+", 
    RowBox[{"r", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       FractionBox["t", "2"], "]"}], "2"]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{"t", " ", 
       RowBox[{"(", 
        RowBox[{"5806080", "-", 
         RowBox[{"967680", " ", 
          SuperscriptBox["t", "2"]}], "-", 
         RowBox[{"12096", " ", 
          SuperscriptBox["t", "4"]}], "+", 
         RowBox[{"144", " ", 
          SuperscriptBox["t", "6"]}], "+", 
         SuperscriptBox["t", "8"]}], ")"}], " ", "z"}], 
      RowBox[{"11612160", " ", "r"}]], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["t", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"29030400", "-", 
         RowBox[{"2419200", " ", 
          SuperscriptBox["t", "2"]}], "-", 
         RowBox[{"20160", " ", 
          SuperscriptBox["t", "4"]}], "+", 
         RowBox[{"180", " ", 
          SuperscriptBox["t", "6"]}], "+", 
         SuperscriptBox["t", "8"]}], ")"}]}], "116121600"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"t", " ", 
       RowBox[{"(", 
        RowBox[{"5806080", "-", 
         RowBox[{"967680", " ", 
          SuperscriptBox["t", "2"]}], "-", 
         RowBox[{"12096", " ", 
          SuperscriptBox["t", "4"]}], "+", 
         RowBox[{"144", " ", 
          SuperscriptBox["t", "6"]}], "+", 
         SuperscriptBox["t", "8"]}], ")"}], " ", "z"}], 
      RowBox[{"11612160", " ", "r"}]], ",", 
     FractionBox[
      RowBox[{
       SuperscriptBox["t", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"645120", "+", 
         RowBox[{"13440", " ", 
          SuperscriptBox["t", "2"]}], "+", 
         RowBox[{"224", " ", 
          SuperscriptBox["t", "4"]}], "+", 
         SuperscriptBox["t", "6"]}], ")"}], " ", "z"}], 
      RowBox[{"645120", " ", "r"}]], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["t", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"29030400", "-", 
         RowBox[{"2419200", " ", 
          SuperscriptBox["t", "2"]}], "-", 
         RowBox[{"20160", " ", 
          SuperscriptBox["t", "4"]}], "+", 
         RowBox[{"180", " ", 
          SuperscriptBox["t", "6"]}], "+", 
         SuperscriptBox["t", "8"]}], ")"}]}], "116121600"], ",", "0", ",", 
     "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", "  ", "%", " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{"Cos", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", 
          FractionBox["p", "2"], "]"}], "]"}]}], ")"}], " ", 
      RowBox[{"Sin", "[", "p", "]"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"Cos", "[", 
             FractionBox["p", "2"], "]"}], "]"}], "-", 
           RowBox[{"Log", "[", 
            RowBox[{"Sin", "[", 
             FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{"Cos", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", 
          FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", "t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"Cos", "[", 
             FractionBox["p", "2"], "]"}], "]"}], "-", 
           RowBox[{"Log", "[", 
            RowBox[{"Sin", "[", 
             FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{"Cos", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", 
          FractionBox["p", "2"], "]"}], "]"}]}], ")"}], " ", 
      RowBox[{"Sin", "[", "p", "]"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox["t", "2"], " ", 
      RowBox[{"Csc", "[", "p", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"Log", "[", 
         RowBox[{"Cos", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", "p", "]"}], "]"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{"Cos", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", 
          FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox["t", "2"], " ", 
      RowBox[{"Csc", "[", "p", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        RowBox[{"Log", "[", 
         RowBox[{"Cos", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", "p", "]"}], "]"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "t"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Cot", "[", "p", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"Cos", "[", 
             FractionBox["p", "2"], "]"}], "]"}], "+", 
           RowBox[{"Log", "[", 
            RowBox[{"Sin", "[", 
             FractionBox["p", "2"], "]"}], "]"}], "-", 
           RowBox[{"Log", "[", 
            RowBox[{"Sin", "[", "p", "]"}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Log", "[", 
             RowBox[{"Cos", "[", 
              FractionBox["p", "2"], "]"}], "]"}]}], "+", 
           RowBox[{"Log", "[", 
            RowBox[{"Sin", "[", 
             FractionBox["p", "2"], "]"}], "]"}]}], ")"}], " ", 
         RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gradtheta", " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"Cot", "[", "p", "]"}], " ", 
          RowBox[{"Csc", "[", "p", "]"}]}], 
         RowBox[{"2", " ", "r"}]]}], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"Cot", "[", "p", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Cos", "[", "p", "]"}]}], " ", 
            RowBox[{"Cot", "[", "p", "]"}]}], "-", 
           RowBox[{"Sin", "[", "p", "]"}]}], ")"}]}], "r"], "-", 
       FractionBox[
        RowBox[{"Sin", "[", "t", "]"}], 
        RowBox[{"2", " ", "r"}]]}], 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], 
        RowBox[{"2", " ", "r"}]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "p", "]"}], " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], 
        RowBox[{"2", " ", "r"}]]}]},
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", "p", "]"}]}], " ", 
         RowBox[{"Cot", "[", "p", "]"}]}], "-", 
        RowBox[{"Sin", "[", "p", "]"}]}], 
       RowBox[{"2", " ", "r"}]], 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          RowBox[{"Cos", "[", "p", "]"}], " ", 
          RowBox[{"Cos", "[", "t", "]"}], " ", 
          RowBox[{"Cot", "[", "p", "]"}]}], 
         RowBox[{"2", " ", "r"}]]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Csc", "[", "p", "]"}]}], 
        RowBox[{"2", " ", "r"}]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "p", "]"}]}], "r"], "+", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "p", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "t", "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], 
        RowBox[{"2", " ", "r"}]]}]},
     {"0", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "p", "]"}]}], 
        RowBox[{"2", " ", "r"}]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "p", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "t", "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], 
        RowBox[{"2", " ", "r"}]]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Cos", "[", "p", "]"}]}], " ", 
          RowBox[{"Cot", "[", "p", "]"}]}], "-", 
         RowBox[{"Sin", "[", "p", "]"}]}], 
        RowBox[{"2", " ", "r"}]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Grad", "[", " ", "theta", " ", "]"}], " ", "]"}], " ", "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"Cot", "[", "p", "]"}], " ", 
         RowBox[{"Csc", "[", "p", "]"}]}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{"Cos", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "+", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "-", 
        RowBox[{"Sin", "[", "t", "]"}]}], 
       RowBox[{"2", " ", "r"}]], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "t"}], "+", 
        RowBox[{"t", " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"Cos", "[", 
             FractionBox["p", "2"], "]"}], "]"}], "-", 
           RowBox[{"Log", "[", 
            RowBox[{"Sin", "[", 
             FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"p", " ", 
            RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}], " ", 
         RowBox[{"Sin", "[", "p", "]"}]}]}], 
       RowBox[{"2", " ", "r"}]]},
     {"0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Csc", "[", "p", "]"}], "r"]}], 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "t", " ", 
         RowBox[{"Cot", "[", "p", "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Csc", "[", "p", "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", 
           RowBox[{"p", " ", 
            RowBox[{"Cos", "[", "t", "]"}]}], "+", 
           RowBox[{"t", " ", 
            RowBox[{"Cot", "[", "p", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Log", "[", 
               RowBox[{"Cos", "[", 
                FractionBox["p", "2"], "]"}], "]"}], "-", 
              RowBox[{"Log", "[", 
               RowBox[{"Sin", "[", 
                FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
       RowBox[{"2", " ", "r"}]]},
     {"0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "p", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", 
            RowBox[{"p", " ", 
             RowBox[{"Cos", "[", "t", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"t", " ", 
          RowBox[{"Cot", "[", "p", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Cos", "[", "t", "]"}], "-", 
            RowBox[{"t", " ", 
             RowBox[{"Log", "[", 
              RowBox[{"Cos", "[", 
               FractionBox["p", "2"], "]"}], "]"}]}], "+", 
            RowBox[{"t", " ", 
             RowBox[{"Log", "[", 
              RowBox[{"Sin", "[", 
               FractionBox["p", "2"], "]"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], 
        RowBox[{"2", " ", "r"}]]}], 
      FractionBox[
       RowBox[{
        RowBox[{"Csc", "[", "p", "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"p", "+", 
           RowBox[{"Cot", "[", "p", "]"}]}], ")"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}]}], 
       RowBox[{"2", " ", "r"}]]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"IntegrateNabla", "[", " ", 
     RowBox[{"Grad", "[", " ", "theta", " ", "]"}], "]"}], "  ", "-", " ", 
    "theta"}], "]"}], " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "p", " ", 
          RowBox[{"Log", "[", 
           RowBox[{"1", "-", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}]}], "+", 
         RowBox[{"2", " ", "p", " ", 
          RowBox[{"Log", "[", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}]}], "-", 
         RowBox[{"2", " ", "p", " ", 
          RowBox[{"Log", "[", 
           RowBox[{"Cos", "[", 
            FractionBox["p", "2"], "]"}], "]"}]}], "+", 
         RowBox[{"2", " ", "p", " ", 
          RowBox[{"Log", "[", 
           RowBox[{"Sin", "[", 
            FractionBox["p", "2"], "]"}], "]"}]}], "-", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          RowBox[{"PolyLog", "[", 
           RowBox[{"2", ",", 
            RowBox[{"-", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", "p"}]]}]}], "]"}]}], "+", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", 
          RowBox[{"PolyLog", "[", 
           RowBox[{"2", ",", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"Log", "[", 
           RowBox[{"Cos", "[", 
            FractionBox["p", "2"], "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"Log", "[", 
           RowBox[{"Sin", "[", 
            FractionBox["p", "2"], "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"Log", "[", 
           RowBox[{"Sin", "[", "p", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}]},
     {
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Log", "[", 
             RowBox[{"Cos", "[", 
              FractionBox["p", "2"], "]"}], "]"}], "-", 
            RowBox[{"Log", "[", 
             RowBox[{"Sin", "[", 
              FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["t", "2"], " ", 
          RowBox[{"Cos", "[", "p", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", 
            RowBox[{"Log", "[", 
             RowBox[{"Cos", "[", 
              FractionBox["p", "2"], "]"}], "]"}], "+", 
            RowBox[{"Log", "[", 
             RowBox[{"Sin", "[", 
              FractionBox["p", "2"], "]"}], "]"}], "-", 
            RowBox[{"Log", "[", 
             RowBox[{"Sin", "[", "p", "]"}], "]"}]}], ")"}]}]}], ")"}]}]},
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Cos", "[", "p", "]"}]}], " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "-", 
         RowBox[{"t", " ", 
          RowBox[{"Cos", "[", "p", "]"}], " ", 
          RowBox[{"Log", "[", 
           RowBox[{"Cos", "[", 
            FractionBox["p", "2"], "]"}], "]"}]}], "+", 
         RowBox[{"t", " ", 
          RowBox[{"Cos", "[", "p", "]"}], " ", 
          RowBox[{"Log", "[", 
           RowBox[{"Sin", "[", 
            FractionBox["p", "2"], "]"}], "]"}]}], "-", 
         RowBox[{"p", " ", 
          RowBox[{"Cos", "[", "t", "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}], "+", 
         RowBox[{"p", " ", "t", " ", 
          RowBox[{"Log", "[", 
           RowBox[{"1", "-", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}], "-", 
         RowBox[{"p", " ", "t", " ", 
          RowBox[{"Log", "[", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}], "+", 
         RowBox[{"p", " ", "t", " ", 
          RowBox[{"Log", "[", 
           RowBox[{"Cos", "[", 
            FractionBox["p", "2"], "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}], "-", 
         RowBox[{"p", " ", "t", " ", 
          RowBox[{"Log", "[", 
           RowBox[{"Sin", "[", 
            FractionBox["p", "2"], "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "t", " ", 
          RowBox[{"PolyLog", "[", 
           RowBox[{"2", ",", 
            RowBox[{"-", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", "p"}]]}]}], "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}], "-", 
         RowBox[{"\[ImaginaryI]", " ", "t", " ", 
          RowBox[{"PolyLog", "[", 
           RowBox[{"2", ",", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}], " ", 
          RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Rational[1, 4] ((-2) p Log[1 - E^(Complex[0, 1] p)] + 
     2 p Log[1 + E^(Complex[0, 1] p)] - 2 p Log[
       Cos[Rational[1, 2] p]] + 2 p Log[
        Sin[Rational[1, 2] p]] + 
     Complex[0, -2] PolyLog[2, -E^(Complex[0, 1] p)] + 
     Complex[0, 2] PolyLog[2, E^(Complex[0, 1] p)] - 2 t^2 Sin[p] - t^2 Log[
       Cos[Rational[1, 2] p]] Sin[p] - t^2 Log[
       Sin[Rational[1, 2] p]] Sin[p] + t^2 Log[
        Sin[p]] Sin[p]), Rational[1, 4] (2 (Log[
         Cos[Rational[1, 2] p]] - Log[
        Sin[Rational[1, 2] p]]) - t^2 Cos[p] (2 + Log[
        Cos[Rational[1, 2] p]] + Log[
        Sin[Rational[1, 2] p]] - Log[
       Sin[p]])), Rational[1, 2] (-Cos[p] Cos[t] - t Cos[p] Log[
       Cos[Rational[1, 2] p]] + t Cos[p] Log[
        Sin[Rational[1, 2] p]] - p Cos[t] Sin[p] + 
     p t Log[1 - E^(Complex[0, 1] p)] Sin[p] - p t 
     Log[1 + E^(Complex[0, 1] p)] Sin[p] + p t Log[
        Cos[Rational[1, 2] p]] Sin[p] - p t Log[
       Sin[Rational[1, 2] p]] Sin[p] + 
     Complex[0, 1] t PolyLog[2, -E^(Complex[0, 1] p)] Sin[p] + 
     Complex[0, -1] t PolyLog[2, E^(Complex[0, 1] p)] Sin[p])}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"PowerExpand", "[", 
   RowBox[{"ComplexExpand", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"TrigToExp", "[", "%", "]"}], "]"}], "]"}], "]"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"Arg", "[", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "p"}], "2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "p"}]]}], ")"}]}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        RowBox[{"Arg", "[", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "p"}], "2"]}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "p"}]]}], ")"}]}], "]"}]}], "+", 
       RowBox[{"Log", "[", 
        RowBox[{"1", "-", 
         RowBox[{"Cos", "[", "p", "]"}]}], "]"}], "-", 
       RowBox[{"Log", "[", 
        RowBox[{"1", "+", 
         RowBox[{"Cos", "[", "p", "]"}]}], "]"}]}], 
      RowBox[{"4", " ", "r"}]], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "r"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "t"}], "-", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", 
         RowBox[{"Arg", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "p"}], "2"]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", "p"}]]}], ")"}]}], "]"}], " ", 
         RowBox[{"Cos", "[", "p", "]"}]}], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", 
         RowBox[{"Arg", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "p"}], "2"]}]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", "p"}]]}], ")"}]}], "]"}], " ", 
         RowBox[{"Cos", "[", "p", "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], "-", 
        RowBox[{"t", " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{"1", "-", 
           RowBox[{"Cos", "[", "p", "]"}]}], "]"}]}], "+", 
        RowBox[{"t", " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{"1", "+", 
           RowBox[{"Cos", "[", "p", "]"}]}], "]"}]}], "+", 
        RowBox[{"2", " ", "p", " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Csc", "[", "p", "]"}], 
       RowBox[{"2", " ", "r"}]]}], ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"4", " ", "r"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "p", " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], "-", 
        RowBox[{"4", " ", "t", " ", 
         RowBox[{"Cot", "[", "p", "]"}]}], "-", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", 
         RowBox[{"Arg", "[", 
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "p"}], "2"]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", "p"}]]}], ")"}]}], "]"}], " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Cot", "[", "p", "]"}]}], "+", 
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", 
         RowBox[{"Arg", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "p"}], "2"]}]], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", "p"}]]}], ")"}]}], "]"}], " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Cot", "[", "p", "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Cot", "[", "p", "]"}]}], "-", 
        RowBox[{"t", " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Cot", "[", "p", "]"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{"1", "-", 
           RowBox[{"Cos", "[", "p", "]"}]}], "]"}]}], "+", 
        RowBox[{"t", " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Cot", "[", "p", "]"}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{"1", "+", 
           RowBox[{"Cos", "[", "p", "]"}]}], "]"}]}]}], ")"}]}]}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"8", " ", "r"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Cot", "[", "p", "]"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", "p", "]"}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "t", " ", 
           RowBox[{"Arg", "[", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", "p"}], "2"]}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", " ", "p"}]]}], ")"}]}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "p", "]"}], "2"]}], "-", 
          RowBox[{"4", " ", "t", " ", 
           RowBox[{"Arg", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", "p"}], "2"]}]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", " ", "p"}]]}], ")"}]}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "p", "]"}], "2"]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"Log", "[", 
                  RowBox[{"1", "-", 
                   RowBox[{"Cos", "[", "p", "]"}]}], "]"}]}], "+", 
                RowBox[{"Log", "[", 
                 RowBox[{"1", "+", 
                  RowBox[{"Cos", "[", "p", "]"}]}], "]"}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", "p", "]"}], "2"]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"Cos", "[", "p", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"t", "-", 
                RowBox[{"p", " ", 
                 RowBox[{"Cos", "[", "t", "]"}], " ", 
                 RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}], ")"}]}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "+", 
         RowBox[{"Cot", "[", "p", "]"}]}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], 
      RowBox[{"2", " ", "r"}]]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SetCoordinates", "[", 
    RowBox[{"Cylindrical", "[", 
     RowBox[{"r", ",", "t", ",", " ", "z"}], " ", "]"}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"u", " ", "=", " ", 
    RowBox[{"{", " ", 
     RowBox[{"z", " ", ",", 
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], " ", ",", " ", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{"gu", " ", "=", " ", 
    RowBox[{"Grad", "[", "u", "]"}]}], " ", "\[IndentingNewLine]", 
   RowBox[{"IntegrateNabla", "[", " ", "gu", " ", "]"}], 
   "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"z", ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "t", "]"}], ",", 
     RowBox[{
      FractionBox["z", "r"], "+", 
      RowBox[{"Cos", "[", "t", "]"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "t", "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", "0"}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"z", ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Spherical", "[", 
    RowBox[{"r", ",", "p", ",", " ", "t"}], " ", "]"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Csc", "[", "p", "]"}], "2"]}], ",", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{"Cos", "[", 
          FractionBox["p", "2"], "]"}], "]"}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", 
          FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{"Sin", "[", "t", "]"}], "2"]}], ",", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"Cos", "[", "p", "]"}], " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], "-", 
     RowBox[{"Sin", "[", "p", "]"}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "t"}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "t", "]"}], "+", 
           RowBox[{"t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Log", "[", 
               RowBox[{"Cos", "[", 
                FractionBox["p", "2"], "]"}], "]"}], "-", 
              RowBox[{"Log", "[", 
               RowBox[{"Sin", "[", 
                FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}]}], ")"}]}], 
        "-", 
        RowBox[{"p", " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gu", " ", "=", " ", 
   RowBox[{"Grad", "[", "u", "]"}]}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IntegrateNabla", "[", " ", "gu", " ", "]"}], "\[IndentingNewLine]",
   "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "p", ",", "t"}], "]"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Csc", "[", "p", "]"}], "2"]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"Cos", "[", 
         FractionBox["p", "2"], "]"}], "]"}], "-", 
       RowBox[{"Log", "[", 
        RowBox[{"Sin", "[", 
         FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"Sin", "[", "t", "]"}], "2"]}], ",", 
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"Cos", "[", "p", "]"}], " ", 
     RowBox[{"Cos", "[", "t", "]"}]}], "-", 
    RowBox[{"Sin", "[", "p", "]"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "t"}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "p", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", "t", "]"}], "+", 
          RowBox[{"t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"Cos", "[", 
               FractionBox["p", "2"], "]"}], "]"}], "-", 
             RowBox[{"Log", "[", 
              RowBox[{"Sin", "[", 
               FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}]}], ")"}]}], "-",
        
       RowBox[{"p", " ", 
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}]}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"Cot", "[", "p", "]"}], " ", 
        RowBox[{"Csc", "[", "p", "]"}]}], 
       RowBox[{"2", " ", "r"}]], "-", 
      FractionBox[
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Log", "[", 
            RowBox[{"Cos", "[", 
             FractionBox["p", "2"], "]"}], "]"}], "-", 
           RowBox[{"Log", "[", 
            RowBox[{"Sin", "[", 
             FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}], "+", 
        FractionBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}], "r"]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"Cos", "[", "p", "]"}], " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], "-", 
        RowBox[{"Sin", "[", "p", "]"}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "t"}], "-", 
           RowBox[{
            RowBox[{"Cos", "[", "p", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", "t", "]"}], "+", 
              RowBox[{"t", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  RowBox[{"Cos", "[", 
                   FractionBox["p", "2"], "]"}], "]"}], "-", 
                 RowBox[{"Log", "[", 
                  RowBox[{"Sin", "[", 
                   FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}]}], ")"}]}], 
           "-", 
           RowBox[{"p", " ", 
            RowBox[{"Cos", "[", "t", "]"}], " ", 
            RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}]}], "r"]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Csc", "[", "p", "]"}], 
        RowBox[{"2", " ", "r"}]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], " ", 
         RowBox[{"Cot", "[", 
          FractionBox["p", "2"], "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"Tan", "[", 
          FractionBox["p", "2"], "]"}]}]}], 
       RowBox[{"2", " ", "r"}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"Cos", "[", "t", "]"}], " ", 
        RowBox[{"Csc", "[", "p", "]"}]}], 
       RowBox[{"2", " ", "r"}]], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"Cot", "[", "p", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"Cos", "[", "p", "]"}], " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "-", 
          RowBox[{"Sin", "[", "p", "]"}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "t"}], "-", 
             RowBox[{
              RowBox[{"Cos", "[", "p", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Cos", "[", "t", "]"}], "+", 
                RowBox[{"t", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Log", "[", 
                    RowBox[{"Cos", "[", 
                    FractionBox["p", "2"], "]"}], "]"}], "-", 
                   RowBox[{"Log", "[", 
                    RowBox[{"Sin", "[", 
                    FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}]}], ")"}]}],
              "-", 
             RowBox[{"p", " ", 
              RowBox[{"Cos", "[", "t", "]"}], " ", 
              RowBox[{"Sin", "[", "p", "]"}]}]}], ")"}]}]}], ")"}]}], 
       "r"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox["1", "r"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "p", "]"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"Sin", "[", "p", "]"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "p"}], " ", 
            RowBox[{"Cos", "[", "p", "]"}], " ", 
            RowBox[{"Cos", "[", "t", "]"}]}], "-", 
           RowBox[{
            RowBox[{"Cos", "[", "t", "]"}], " ", 
            RowBox[{"Sin", "[", "p", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", "t", "]"}], "+", 
              RowBox[{"t", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  RowBox[{"Cos", "[", 
                   FractionBox["p", "2"], "]"}], "]"}], "-", 
                 RowBox[{"Log", "[", 
                  RowBox[{"Sin", "[", 
                   FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}]}], ")"}], 
            " ", 
            RowBox[{"Sin", "[", "p", "]"}]}], "-", 
           RowBox[{"t", " ", 
            RowBox[{"Cos", "[", "p", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "2"]}], " ", 
               RowBox[{"Cot", "[", 
                FractionBox["p", "2"], "]"}]}], "-", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               RowBox[{"Tan", "[", 
                FractionBox["p", "2"], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Csc", "[", "p", "]"}], 
        RowBox[{"2", " ", "r"}]]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"Cot", "[", "p", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"Cos", "[", 
               FractionBox["p", "2"], "]"}], "]"}], "-", 
             RowBox[{"Log", "[", 
              RowBox[{"Sin", "[", 
               FractionBox["p", "2"], "]"}], "]"}]}], ")"}]}], "+", 
          FractionBox[
           RowBox[{"Sin", "[", "t", "]"}], "2"]}], ")"}]}], "r"], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"Csc", "[", "p", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], " ", 
           RowBox[{"Cos", "[", "p", "]"}], " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], "+", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             RowBox[{
              RowBox[{"Cos", "[", "p", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Log", "[", 
                 RowBox[{"Cos", "[", 
                  FractionBox["p", "2"], "]"}], "]"}], "-", 
                RowBox[{"Log", "[", 
                 RowBox[{"Sin", "[", 
                  FractionBox["p", "2"], "]"}], "]"}], "-", 
                RowBox[{"Sin", "[", "t", "]"}]}], ")"}]}], "+", 
             RowBox[{"p", " ", 
              RowBox[{"Sin", "[", "p", "]"}], " ", 
              RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}], 
       "r"]}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Csc", "[", "p", "]"}]}], "-", 
       RowBox[{"p", " ", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}]}], "+", 
       RowBox[{"p", " ", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}]}], "-", 
       RowBox[{"p", " ", 
        RowBox[{"Log", "[", 
         RowBox[{"Cos", "[", 
          FractionBox["p", "2"], "]"}], "]"}]}], "+", 
       RowBox[{"p", " ", 
        RowBox[{"Log", "[", 
         RowBox[{"Sin", "[", 
          FractionBox["p", "2"], "]"}], "]"}]}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"PolyLog", "[", 
         RowBox[{"2", ",", 
          RowBox[{"-", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", "p"}]]}]}], "]"}]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{"PolyLog", "[", 
         RowBox[{"2", ",", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}]}], "-", 
       RowBox[{"p", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["t", "2"]}], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"Log", "[", 
           RowBox[{"Cos", "[", 
            FractionBox["p", "2"], "]"}], "]"}], "+", 
          RowBox[{"Log", "[", 
           RowBox[{"Sin", "[", 
            FractionBox["p", "2"], "]"}], "]"}], "-", 
          RowBox[{"Log", "[", 
           RowBox[{"Sin", "[", "p", "]"}], "]"}]}], ")"}], " ", 
        RowBox[{"Sin", "[", "p", "]"}]}], "+", 
       RowBox[{"2", " ", "p", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{"Cos", "[", 
      FractionBox["p", "2"], "]"}], "]"}], "-", 
    RowBox[{"Log", "[", 
     RowBox[{"Sin", "[", 
      FractionBox["p", "2"], "]"}], "]"}], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["t", "2"]}], " ", 
        RowBox[{"Cos", "[", "p", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"Log", "[", 
           RowBox[{"Cos", "[", 
            FractionBox["p", "2"], "]"}], "]"}], "+", 
          RowBox[{"Log", "[", 
           RowBox[{"Sin", "[", 
            FractionBox["p", "2"], "]"}], "]"}], "-", 
          RowBox[{"Log", "[", 
           RowBox[{"Sin", "[", "p", "]"}], "]"}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"t", "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"Cos", "[", "p", "]"}], " ", 
     RowBox[{"Cos", "[", "t", "]"}]}], "-", 
    RowBox[{"t", " ", 
     RowBox[{"Cos", "[", "p", "]"}], " ", 
     RowBox[{"Log", "[", 
      RowBox[{"Cos", "[", 
       FractionBox["p", "2"], "]"}], "]"}]}], "+", 
    RowBox[{"t", " ", 
     RowBox[{"Cos", "[", "p", "]"}], " ", 
     RowBox[{"Log", "[", 
      RowBox[{"Sin", "[", 
       FractionBox["p", "2"], "]"}], "]"}]}], "-", 
    RowBox[{"Sin", "[", "p", "]"}], "-", 
    RowBox[{"p", " ", 
     RowBox[{"Cos", "[", "t", "]"}], " ", 
     RowBox[{"Sin", "[", "p", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "p", " ", "t", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}], " ", 
     RowBox[{"Sin", "[", "p", "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "p", " ", "t", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}], " ", 
     RowBox[{"Sin", "[", "p", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "p", " ", "t", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"Cos", "[", 
       FractionBox["p", "2"], "]"}], "]"}], " ", 
     RowBox[{"Sin", "[", "p", "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "p", " ", "t", " ", 
     RowBox[{"Log", "[", 
      RowBox[{"Sin", "[", 
       FractionBox["p", "2"], "]"}], "]"}], " ", 
     RowBox[{"Sin", "[", "p", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "t", " ", 
     RowBox[{"PolyLog", "[", 
      RowBox[{"2", ",", 
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "p"}]]}]}], "]"}], " ", 
     RowBox[{"Sin", "[", "p", "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "t", " ", 
     RowBox[{"PolyLog", "[", 
      RowBox[{"2", ",", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "p"}]]}], "]"}], " ", 
     RowBox[{"Sin", "[", "p", "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{1014, 821},
WindowMargins->{{21, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 187, 3, 77, "Input"],
Cell[1521, 43, 85, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1643, 49, 426, 10, 143, "Input"],
Cell[2072, 61, 98, 2, 31, "Output"],
Cell[2173, 65, 83, 2, 31, "Output"],
Cell[2259, 69, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2379, 76, 630, 17, 55, "Input"],
Cell[3012, 95, 405, 14, 46, "Output"],
Cell[3420, 111, 1577, 55, 73, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5034, 171, 68, 1, 32, "Input"],
Cell[5105, 174, 954, 34, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6096, 213, 141, 3, 55, "Input"],
Cell[6240, 218, 405, 14, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6682, 237, 231, 6, 55, "Input"],
Cell[6916, 245, 104, 3, 33, "Output"],
Cell[7023, 250, 257, 8, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7317, 263, 68, 1, 32, "Input"],
Cell[7388, 266, 104, 3, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7529, 274, 103, 3, 32, "Input"],
Cell[7635, 279, 257, 8, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7929, 292, 97, 3, 32, "Input"],
Cell[8029, 297, 277, 9, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8343, 311, 1751, 51, 297, "Input"],
Cell[10097, 364, 204, 6, 33, "Output"],
Cell[10304, 372, 158, 5, 47, "Output"],
Cell[10465, 379, 235, 7, 33, "Output"],
Cell[10703, 388, 83, 2, 31, "Output"],
Cell[10789, 392, 235, 7, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11061, 404, 2042, 58, 233, "Input"],
Cell[13106, 464, 99, 2, 31, "Output"],
Cell[13208, 468, 86, 2, 31, "Output"],
Cell[13297, 472, 83, 2, 31, "Output"],
Cell[13383, 476, 671, 23, 67, "Output"],
Cell[14057, 501, 6244, 192, 392, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20338, 698, 645, 19, 55, "Input"],
Cell[20986, 719, 99, 2, 31, "Output"],
Cell[21088, 723, 86, 2, 31, "Output"],
Cell[21177, 727, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21297, 734, 999, 27, 143, "Input"],
Cell[22299, 763, 96, 2, 31, "Output"],
Cell[22398, 767, 83, 2, 31, "Output"],
Cell[22484, 771, 139, 4, 31, "Output"],
Cell[22626, 777, 293, 9, 31, "Output"],
Cell[22922, 788, 1889, 62, 118, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24848, 855, 1165, 31, 143, "Input"],
Cell[26016, 888, 98, 2, 31, "Output"],
Cell[26117, 892, 83, 2, 31, "Output"],
Cell[26203, 896, 83, 2, 31, "Output"],
Cell[26289, 900, 405, 14, 46, "Output"],
Cell[26697, 916, 3279, 108, 212, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30013, 1029, 894, 25, 209, "Input"],
Cell[30910, 1056, 7876, 234, 360, "Output"],
Cell[38789, 1292, 260, 8, 31, "Output"],
Cell[39052, 1302, 18735, 547, 726, "Output"],
Cell[57790, 1851, 1039, 34, 51, "Output"],
Cell[58832, 1887, 1054, 32, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59923, 1924, 239, 6, 55, "Input"],
Cell[60165, 1932, 260, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[60462, 1945, 1454, 40, 165, "Input"],
Cell[61919, 1987, 49374, 1390, 1961, "Output"],
Cell[111296, 3379, 2318, 74, 132, "Output"],
Cell[113617, 3455, 2180, 68, 135, "Output"],
Cell[115800, 3525, 2016, 68, 126, "Output"],
Cell[117819, 3595, 2285, 68, 135, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120141, 3668, 108, 2, 55, "Input"],
Cell[120252, 3672, 4409, 134, 184, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124698, 3811, 77, 1, 32, "Input"],
Cell[124778, 3814, 3130, 98, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[127945, 3917, 163, 4, 32, "Input"],
Cell[128111, 3923, 3496, 104, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131644, 4032, 249, 6, 32, "Input"],
Cell[131896, 4040, 6607, 165, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138540, 4210, 219, 6, 32, "Input"],
Cell[138762, 4218, 8446, 224, 283, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147245, 4447, 706, 17, 165, "Input"],
Cell[147954, 4466, 98, 2, 31, "Output"],
Cell[148055, 4470, 195, 6, 31, "Output"],
Cell[148253, 4478, 521, 17, 44, "Output"],
Cell[148777, 4497, 195, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[149009, 4508, 2026, 60, 253, "Input"],
Cell[151038, 4570, 96, 2, 31, "Output"],
Cell[151137, 4574, 1478, 47, 82, "Output"],
Cell[152618, 4623, 7442, 218, 318, "Output"],
Cell[160063, 4843, 5201, 147, 254, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

