(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    124253,       6080]
NotebookOptionsPosition[    120497,       5951]
NotebookOutlinePosition[    120830,       5966]
CellTagsIndexPosition[    120787,       5963]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"Rigid", " ", "Body", " ", "Displacements"}], "Subtitle"], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.402068334677615*^9, 3.402068341615406*^9}}],

Cell[BoxData[
 FormBox[
  StyleBox[
   RowBox[{"The", " ", "mouvement"}], "Subsubtitle"], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.402068345228572*^9, 3.402068355526911*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<ElasticaBook/C01_Kinematics/PDF\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{3.402068321715452*^9}],

Cell[BoxData["\<\"/local/constant/Oxford/Tex/ElasticaBook/C01_Kinematics/PDF\"\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"center", " ", "=", "  ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", "R", ",", "0"}], "}"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(center\\)\\\" is similar to existing symbol \
\\\"\\!\\(Center\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "R", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"a1", ",", "a2", ",", "a3"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"v", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"v1", ",", " ", "0", ",", " ", "0"}], "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a1", ",", "a2", ",", "a3"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"v1", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rot", "[", "\[CurlyPhi]_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", ",", " ", 
      RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}], ",", " ", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sin", "[", "\[CurlyPhi]", "]"}]}], ",", 
      RowBox[{"Cos", "[", "\[CurlyPhi]", "]"}], " ", ",", "  ", "0"}], "}"}], 
    ",", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"F", "[", 
   RowBox[{"a_", ",", " ", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"v", " ", "t"}], " ", "+", " ", "center", "+", " ", 
   RowBox[{
    RowBox[{"rot", "[", 
     RowBox[{"\[Omega]", " ", "t"}], "]"}], "  ", ".", "   ", 
    RowBox[{"(", 
     RowBox[{"a", " ", "-", " ", "center"}], ")"}]}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "[", 
  RowBox[{"a", ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"t", " ", "v1"}], "+", 
    RowBox[{"a1", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a2", "-", "R"}], ")"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ",", 
   RowBox[{"R", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a2", "-", "R"}], ")"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"t", " ", "\[Omega]"}], "]"}]}], "-", 
    RowBox[{"a1", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"t", " ", "\[Omega]"}], "]"}]}]}], ",", "a3"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Trajectories - Points on the radius ", \
"Subsubtitle"]], "Subsection",
 CellChangeTimes->{{3.402068363858317*^9, 3.402068380476534*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"R", " ", "=", " ", "1"}], ";", " ", 
  RowBox[{"\[Omega]", " ", "=", " ", "1"}], ";", " ", 
  RowBox[{"v1", " ", "=", " ", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"points", "  ", "=", " ", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{"center", " ", "+", " ", 
       RowBox[{"r", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", "\[Alpha]", "]"}], ",", " ", 
          RowBox[{"Sin", "[", "\[Alpha]", "]"}], ",", " ", "0"}], "}"}]}]}], 
      ",", "  ", 
      RowBox[{"{", 
       RowBox[{"r", ",", "0.5", ",", "1.5", ",", "0.2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Alpha]", ",", "0", ",", "0"}], "}"}]}], "]"}], " ", ",", 
    " ", "1"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.5`", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7`", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9`", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.1`", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.3`", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5`", ",", "1", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wheel", " ", "=", " ", 
   RowBox[{"ParametricPlot", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"R", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
       RowBox[{"1", " ", "+", " ", 
        RowBox[{"R", " ", 
         RowBox[{"Sin", "[", 
          StyleBox["\[Theta]",
           FontWeight->"Plain"], "]"}]}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"\[Theta]", ",", "0", ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", " ", 
     RowBox[{"DisplayFunction", " ", "\[Rule]", " ", "Identity"}]}], " ", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trajectoires", "  ", "=", " ", 
   RowBox[{"Map", "[", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ParametricPlot", "[", " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Evaluate", "[", " ", 
         RowBox[{"Drop", "[", " ", 
          RowBox[{
           RowBox[{"F", "[", " ", 
            RowBox[{
             RowBox[{"center", " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"0.", " ", "+", " ", 
                 RowBox[{"0.2", " ", "#"}]}], " ", ")"}], " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Cos", "[", "0", "]"}], ",", " ", 
                 RowBox[{"Sin", "[", "0", "]"}], ",", " ", "0"}], "}"}]}]}], 
             ",", " ", "t"}], "]"}], " ", ",", " ", 
           RowBox[{"-", "1"}]}], " ", "]"}], "]"}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotStyle", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"Evaluate", "[", 
           RowBox[{"Hue", "[", 
            RowBox[{"0.1", " ", "#"}], "]"}], "]"}], "}"}]}], " ", ",", " ", 
        RowBox[{"DisplayFunction", " ", "\[Rule]", " ", "Identity"}]}], " ", 
       "]"}], "  ", "&"}], " ", ",", " ", "\[IndentingNewLine]", " ", 
     RowBox[{"Range", "[", "8", "]"}]}], " ", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"wheel", ",", " ", 
   RowBox[{"Sequence", "[", "trajectoires", "]"}], " ", ",", " ", 
   RowBox[{"DisplayFunction", " ", "\[Rule]", " ", "$DisplayFunction"}], ",", 
   " ", 
   RowBox[{"AspectRatio", " ", "\[Rule]", " ", "Automatic"}]}], " ", 
  "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .29542 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11173 0.0879215 0.0597865 0.0879215 [
[.28757 .04729 -3 -9 ]
[.28757 .04729 3 0 ]
[.46342 .04729 -3 -9 ]
[.46342 .04729 3 0 ]
[.63926 .04729 -3 -9 ]
[.63926 .04729 3 0 ]
[.8151 .04729 -3 -9 ]
[.8151 .04729 3 0 ]
[.99094 .04729 -6 -9 ]
[.99094 .04729 6 0 ]
[.09923 .01583 -24 -4.5 ]
[.09923 .01583 0 4.5 ]
[.09923 .10375 -18 -4.5 ]
[.09923 .10375 0 4.5 ]
[.09923 .14771 -6 -4.5 ]
[.09923 .14771 0 4.5 ]
[.09923 .19167 -18 -4.5 ]
[.09923 .19167 0 4.5 ]
[.09923 .23563 -6 -4.5 ]
[.09923 .23563 0 4.5 ]
[.09923 .27959 -18 -4.5 ]
[.09923 .27959 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .29542 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.28757 .05979 m
.28757 .06604 L
s
[(2)] .28757 .04729 0 1 Mshowa
.46342 .05979 m
.46342 .06604 L
s
[(4)] .46342 .04729 0 1 Mshowa
.63926 .05979 m
.63926 .06604 L
s
[(6)] .63926 .04729 0 1 Mshowa
.8151 .05979 m
.8151 .06604 L
s
[(8)] .8151 .04729 0 1 Mshowa
.99094 .05979 m
.99094 .06604 L
s
[(10)] .99094 .04729 0 1 Mshowa
.125 Mabswid
.15569 .05979 m
.15569 .06354 L
s
.19965 .05979 m
.19965 .06354 L
s
.24361 .05979 m
.24361 .06354 L
s
.33153 .05979 m
.33153 .06354 L
s
.37549 .05979 m
.37549 .06354 L
s
.41946 .05979 m
.41946 .06354 L
s
.50738 .05979 m
.50738 .06354 L
s
.55134 .05979 m
.55134 .06354 L
s
.5953 .05979 m
.5953 .06354 L
s
.68322 .05979 m
.68322 .06354 L
s
.72718 .05979 m
.72718 .06354 L
s
.77114 .05979 m
.77114 .06354 L
s
.85906 .05979 m
.85906 .06354 L
s
.90302 .05979 m
.90302 .06354 L
s
.94698 .05979 m
.94698 .06354 L
s
.06777 .05979 m
.06777 .06354 L
s
.02381 .05979 m
.02381 .06354 L
s
.25 Mabswid
0 .05979 m
1 .05979 L
s
.11173 .01583 m
.11798 .01583 L
s
[(-0.5)] .09923 .01583 1 0 Mshowa
.11173 .10375 m
.11798 .10375 L
s
[(0.5)] .09923 .10375 1 0 Mshowa
.11173 .14771 m
.11798 .14771 L
s
[(1)] .09923 .14771 1 0 Mshowa
.11173 .19167 m
.11798 .19167 L
s
[(1.5)] .09923 .19167 1 0 Mshowa
.11173 .23563 m
.11798 .23563 L
s
[(2)] .09923 .23563 1 0 Mshowa
.11173 .27959 m
.11798 .27959 L
s
[(2.5)] .09923 .27959 1 0 Mshowa
.125 Mabswid
.11173 .02462 m
.11548 .02462 L
s
.11173 .03341 m
.11548 .03341 L
s
.11173 .0422 m
.11548 .0422 L
s
.11173 .05099 m
.11548 .05099 L
s
.11173 .06858 m
.11548 .06858 L
s
.11173 .07737 m
.11548 .07737 L
s
.11173 .08616 m
.11548 .08616 L
s
.11173 .09496 m
.11548 .09496 L
s
.11173 .11254 m
.11548 .11254 L
s
.11173 .12133 m
.11548 .12133 L
s
.11173 .13012 m
.11548 .13012 L
s
.11173 .13892 m
.11548 .13892 L
s
.11173 .1565 m
.11548 .1565 L
s
.11173 .16529 m
.11548 .16529 L
s
.11173 .17408 m
.11548 .17408 L
s
.11173 .18288 m
.11548 .18288 L
s
.11173 .20046 m
.11548 .20046 L
s
.11173 .20925 m
.11548 .20925 L
s
.11173 .21805 m
.11548 .21805 L
s
.11173 .22684 m
.11548 .22684 L
s
.11173 .24442 m
.11548 .24442 L
s
.11173 .25321 m
.11548 .25321 L
s
.11173 .26201 m
.11548 .26201 L
s
.11173 .2708 m
.11548 .2708 L
s
.11173 .00703 m
.11548 .00703 L
s
.11173 .28838 m
.11548 .28838 L
s
.25 Mabswid
.11173 0 m
.11173 .29542 L
s
0 0 m
1 0 L
1 .29542 L
0 .29542 L
closepath
clip
newpath
.5 Mabswid
.19965 .14771 m
.19965 .14839 L
.19964 .14901 L
.19963 .14973 L
.19961 .1504 L
.19957 .15161 L
.1995 .15291 L
.1994 .15435 L
.19927 .15587 L
.19898 .15859 L
.19858 .16139 L
.19813 .164 L
.19681 .16988 L
.19505 .17577 L
.19309 .18104 L
.18746 .19237 L
.18129 .20148 L
.17331 .21046 L
.16467 .2179 L
.15448 .22454 L
.14918 .22726 L
.14324 .22979 L
.13797 .23162 L
.13207 .23324 L
.12925 .23387 L
.12621 .23443 L
.12357 .23483 L
.12068 .23517 L
.11898 .23533 L
.11741 .23545 L
.1159 .23553 L
.11514 .23556 L
.1143 .23559 L
.11355 .23561 L
.11285 .23562 L
.1121 .23563 L
.11171 .23563 L
.1113 .23563 L
.11059 .23562 L
.10983 .23561 L
.10912 .23559 L
.10847 .23557 L
.10714 .23551 L
.10567 .23542 L
.1027 .23516 L
.09996 .23484 L
.09741 .23446 L
.09171 .23332 L
.08568 .23168 L
.08013 .22975 L
Mistroke
.07424 .22724 L
.06405 .22158 L
.05488 .21477 L
.04616 .20629 L
.03856 .19645 L
.03273 .18631 L
.03041 .18113 L
.02832 .17551 L
.02672 .17014 L
.02556 .16516 L
.02463 .15973 L
.02427 .15672 L
.02414 .15533 L
.02402 .15386 L
.02395 .1526 L
.02391 .15193 L
.02388 .15121 L
.02385 .15055 L
.02384 .14995 L
.02382 .14937 L
.02382 .14876 L
.02381 .1481 L
.02381 .14739 L
.02381 .14672 L
.02382 .14611 L
.02384 .1454 L
.02386 .14462 L
.02392 .14322 L
.024 .14185 L
.02411 .14038 L
.02438 .13774 L
.02479 .1346 L
.02527 .13176 L
.02662 .12564 L
.02831 .11994 L
.03266 .10927 L
.0379 .09997 L
.04431 .09127 L
.05258 .08266 L
.06133 .07567 L
.07168 .06944 L
.08234 .06485 L
.0879 .06308 L
.09108 .06225 L
.09411 .06157 L
.09692 .06104 L
.09998 .06058 L
.10277 .06024 L
.10536 .06002 L
.10681 .05992 L
Mistroke
.10816 .05986 L
.10894 .05983 L
.10965 .05981 L
.11004 .0598 L
.11047 .0598 L
.11088 .05979 L
.11125 .05979 L
.11165 .05979 L
.11207 .05979 L
.11247 .05979 L
.11284 .05979 L
.11354 .05981 L
.11428 .05982 L
.11507 .05985 L
.11581 .05988 L
.1175 .05998 L
.119 .06009 L
.1204 .06021 L
.12354 .06058 L
.12629 .061 L
.1292 .06154 L
.13418 .0627 L
.13959 .06432 L
.14999 .06855 L
.16049 .07455 L
.16971 .08162 L
.17833 .0903 L
.18522 .09945 L
.19052 .10869 L
.19304 .11425 L
.19505 .11965 L
.19658 .12466 L
.19786 .13006 L
.19864 .13439 L
.19898 .13687 L
.19924 .1392 L
.19942 .14134 L
.19954 .1433 L
.19959 .14438 L
.19961 .14495 L
.19963 .14556 L
.19964 .14614 L
.19965 .14667 L
.19965 .14721 L
.19965 .14771 L
Mfstroke
1 .6 0 r
.12931 .14771 m
.16355 .14077 L
.18031 .13754 L
.19793 .13452 L
.20563 .13338 L
.21376 .13234 L
.22127 .13154 L
.22814 .13095 L
.23177 .1307 L
.23575 .13047 L
.23974 .1303 L
.24192 .13023 L
.24396 .13018 L
.24488 .13017 L
.24588 .13015 L
.24683 .13014 L
.24771 .13013 L
.24858 .13013 L
.24936 .13012 L
.25027 .13012 L
.25113 .13013 L
.25207 .13013 L
.25254 .13014 L
.25306 .13014 L
.25483 .13017 L
.25583 .13019 L
.25691 .13021 L
.25884 .13027 L
.26276 .13042 L
.26639 .13061 L
.27465 .1312 L
.282 .1319 L
.2899 .13283 L
.31973 .1376 L
.35397 .14439 L
.38978 .15148 L
.40905 .15492 L
.43091 .15832 L
.45271 .1611 L
.47298 .16308 L
.48397 .1639 L
.49441 .1645 L
.49978 .16475 L
.50549 .16496 L
.50847 .16505 L
.51175 .16513 L
.51452 .16519 L
.51598 .16521 L
.51754 .16524 L
.51911 .16525 L
Mistroke
.52054 .16527 L
.52197 .16528 L
.52331 .16529 L
.52469 .16529 L
.52595 .16529 L
.52733 .16529 L
.5288 .16529 L
.53002 .16528 L
.53133 .16527 L
.5337 .16525 L
.53652 .16521 L
.53908 .16516 L
.54477 .16502 L
.55094 .1648 L
.56211 .16427 L
.57242 .1636 L
.58369 .16269 L
.60616 .16031 L
.64741 .15417 L
.6844 .14718 L
.72058 .13986 L
.73752 .13667 L
.75269 .13416 L
.76691 .13226 L
.77473 .13144 L
.78175 .13086 L
.78537 .13063 L
.78919 .13043 L
.79244 .13029 L
.79428 .13024 L
.79601 .13019 L
.79697 .13017 L
.79802 .13016 L
.79897 .13014 L
.79985 .13013 L
.80079 .13013 L
.80133 .13013 L
.80184 .13012 L
.80237 .13012 L
.80286 .13012 L
.8034 .13013 L
.80396 .13013 L
.80485 .13014 L
.8058 .13015 L
.80669 .13016 L
.80751 .13017 L
.8095 .13022 L
.81139 .13027 L
.81481 .1304 L
.81859 .13059 L
Mistroke
.82626 .13113 L
.83343 .1318 L
.84021 .13256 L
.87075 .13734 L
.90579 .14426 L
.94255 .15154 L
.97619 .15727 L
Mfstroke
.8 1 0 r
.1469 .14771 m
.17971 .13383 L
.20956 .12133 L
.2223 .11697 L
.22822 .11535 L
.23346 .11419 L
.23604 .11372 L
.23881 .1133 L
.24142 .11298 L
.24381 .11277 L
.24511 .11268 L
.24633 .11262 L
.24703 .11259 L
.24767 .11257 L
.24802 .11256 L
.2484 .11255 L
.2491 .11254 L
.24948 .11254 L
.24984 .11254 L
.25051 .11254 L
.25123 .11255 L
.25164 .11256 L
.25201 .11257 L
.25333 .11262 L
.25399 .11265 L
.25472 .11269 L
.25611 .11279 L
.25763 .11292 L
.26041 .11324 L
.26567 .11408 L
.27194 .11547 L
.2779 .11713 L
.30335 .12666 L
.33226 .13917 L
.36887 .1539 L
.40985 .16707 L
.43304 .17278 L
.44528 .17527 L
.45863 .17758 L
.47153 .17942 L
.4834 .18076 L
.48918 .1813 L
.49546 .18179 L
.50098 .18215 L
.50692 .18245 L
.51021 .18259 L
.51322 .18269 L
.51625 .18277 L
.51913 .18282 L
.52075 .18284 L
Mistroke
.52163 .18285 L
.52247 .18286 L
.52409 .18287 L
.52557 .18288 L
.52642 .18288 L
.52732 .18287 L
.52894 .18287 L
.52984 .18286 L
.53068 .18285 L
.53258 .18283 L
.53428 .1828 L
.53611 .18276 L
.53945 .18267 L
.5457 .18243 L
.55297 .18204 L
.55966 .18156 L
.57195 .18043 L
.58335 .17906 L
.60874 .1749 L
.63264 .16959 L
.65345 .16386 L
.69394 .14984 L
.72722 .13598 L
.75689 .12331 L
.76895 .11882 L
.78114 .11523 L
.78427 .11452 L
.78754 .11388 L
.79053 .1134 L
.79331 .11304 L
.7959 .11279 L
.79734 .11269 L
.79866 .11262 L
.79941 .11259 L
.8001 .11257 L
.80049 .11256 L
.80086 .11255 L
.80124 .11255 L
.80166 .11254 L
.80238 .11254 L
.80303 .11254 L
.80375 .11255 L
.80411 .11256 L
.80451 .11257 L
.80524 .1126 L
.80591 .11262 L
.80744 .11271 L
.80878 .11281 L
.81021 .11294 L
.8127 .11322 L
Mistroke
.81545 .11362 L
.82163 .11482 L
.82755 .11632 L
.85223 .12518 L
.88334 .13859 L
.91924 .15313 L
.95939 .16627 L
.96144 .16684 L
Mfstroke
.2 1 0 r
.16448 .14771 m
.19587 .12689 L
.22119 .10814 L
.23085 .10161 L
.23511 .09917 L
.23878 .09742 L
.24055 .09672 L
.24244 .09609 L
.24406 .09566 L
.24581 .0953 L
.24676 .09516 L
.24765 .09506 L
.24814 .09502 L
.24859 .09499 L
.24884 .09498 L
.24911 .09497 L
.24936 .09496 L
.2496 .09496 L
.25006 .09496 L
.25048 .09496 L
.25087 .09498 L
.25129 .095 L
.25174 .09503 L
.25223 .09508 L
.25309 .09518 L
.25404 .09533 L
.25494 .0955 L
.25665 .09592 L
.26057 .09729 L
.2641 .09893 L
.26814 .10119 L
.28872 .11572 L
.31566 .13521 L
.34966 .15597 L
.37209 .16715 L
.39473 .17659 L
.42024 .18517 L
.44545 .19168 L
.45933 .19447 L
.47218 .19657 L
.48665 .19838 L
.49468 .19915 L
.50229 .19971 L
.5091 .20008 L
.51298 .20023 L
.51661 .20034 L
.51857 .20039 L
.52044 .20042 L
.52211 .20044 L
.52394 .20045 L
Mistroke
.52497 .20046 L
.52591 .20046 L
.527 .20046 L
.52802 .20046 L
.52984 .20044 L
.53087 .20043 L
.53181 .20042 L
.53339 .20039 L
.53508 .20035 L
.53813 .20027 L
.54175 .20013 L
.54505 .19998 L
.55221 .19955 L
.55895 .19901 L
.57303 .19751 L
.58777 .19534 L
.61352 .19009 L
.6395 .18282 L
.66237 .17466 L
.70509 .15452 L
.74116 .13196 L
.76711 .11293 L
.77745 .10543 L
.78563 .10022 L
.78953 .09818 L
.79355 .09652 L
.7957 .09586 L
.79663 .09562 L
.79765 .09541 L
.79854 .09525 L
.79949 .09512 L
.80001 .09506 L
.80049 .09502 L
.80097 .09499 L
.80142 .09497 L
.80184 .09496 L
.80229 .09496 L
.80272 .09496 L
.80311 .09497 L
.80355 .09499 L
.80402 .09502 L
.80452 .09506 L
.80498 .09511 L
.80595 .09524 L
.80683 .0954 L
.80882 .09585 L
.81055 .09637 L
.81246 .09707 L
.81604 .09868 L
.82464 .10377 L
Mistroke
.83514 .11124 L
.85894 .12884 L
.89275 .15073 L
.93407 .17135 L
.94668 .17641 L
Mfstroke
0 1 .4 r
.18207 .14771 m
.21203 .11995 L
.23282 .09495 L
.2394 .08624 L
.242 .083 L
.2441 .08066 L
.24507 .07973 L
.24608 .07889 L
.24691 .07831 L
.24781 .07783 L
.2483 .07764 L
.24874 .07751 L
.24899 .07745 L
.24921 .07741 L
.24934 .0774 L
.24947 .07739 L
.2496 .07738 L
.24972 .07737 L
.24995 .07737 L
.25016 .07738 L
.25035 .0774 L
.25056 .07743 L
.25079 .07747 L
.25103 .07753 L
.25147 .07767 L
.25195 .07787 L
.25241 .0781 L
.25329 .07866 L
.2554 .08048 L
.25984 .08568 L
.27359 .10363 L
.29788 .13037 L
.3329 .15914 L
.37754 .18505 L
.40416 .19631 L
.41871 .20135 L
.43519 .20619 L
.45027 .20986 L
.46677 .21306 L
.47603 .21451 L
.48451 .21561 L
.49262 .21647 L
.50124 .21718 L
.50503 .21742 L
.50911 .21764 L
.51359 .21783 L
.5156 .21789 L
.51778 .21795 L
.51991 .21799 L
.52188 .21802 L
Mistroke
.52377 .21804 L
.52577 .21805 L
.52775 .21804 L
.52961 .21803 L
.53127 .21801 L
.53307 .21798 L
.53524 .21793 L
.53725 .21787 L
.54183 .2177 L
.54628 .21747 L
.55104 .21717 L
.55964 .21646 L
.56742 .21563 L
.58358 .21336 L
.59826 .21062 L
.63031 .20233 L
.65738 .19263 L
.68479 .17996 L
.72968 .15148 L
.76121 .12338 L
.78296 .09796 L
.79013 .08846 L
.7952 .08209 L
.79731 .0799 L
.79913 .07844 L
.80009 .0779 L
.80062 .07768 L
.80086 .07759 L
.8011 .07752 L
.80131 .07747 L
.8015 .07744 L
.80171 .07741 L
.80194 .07738 L
.80216 .07737 L
.8024 .07737 L
.80262 .07739 L
.80283 .07741 L
.80305 .07744 L
.80328 .07749 L
.80369 .0776 L
.80414 .07776 L
.80463 .07799 L
.80554 .07854 L
.80641 .07919 L
.81109 .0842 L
.82431 .10149 L
.84804 .12816 L
.88282 .15737 L
.92769 .18396 L
.93193 .18597 L
Mistroke
Mfstroke
0 1 1 r
.19965 .14771 m
.21531 .13046 L
.22818 .11301 L
.23833 .09558 L
.24445 .08177 L
.24769 .07183 L
.24875 .06748 L
.24935 .06434 L
.24954 .06303 L
.24968 .06188 L
.24976 .06109 L
.24981 .06044 L
.24982 .06018 L
.24983 .05999 L
.24983 .05993 L
.24984 .05987 L
.24984 .05983 L
.24984 .0598 L
.24984 .05979 L
.24984 .05979 L
.24984 .05979 L
.24984 .05979 L
.24984 .05981 L
.24984 .05985 L
.24984 .05987 L
.24984 .0599 L
.24984 .05997 L
.24985 .06019 L
.24986 .06045 L
.24989 .0608 L
.24996 .06159 L
.25009 .0627 L
.25031 .06423 L
.25098 .06772 L
.25199 .07187 L
.25567 .08292 L
.26136 .09562 L
.26994 .11062 L
.28293 .12868 L
.30047 .14815 L
.32018 .16585 L
.34473 .18365 L
.37059 .19863 L
.39994 .21194 L
.41747 .21829 L
.43448 .22342 L
.45155 .22762 L
.46749 .23071 L
.48549 .23328 L
.49551 .2343 L
Mistroke
.50043 .23469 L
.50507 .235 L
.50953 .23524 L
.51188 .23534 L
.51436 .23544 L
.51645 .2355 L
.51875 .23555 L
.52084 .23559 L
.52279 .23561 L
.52396 .23562 L
.52524 .23563 L
.52756 .23563 L
.52982 .23561 L
.53191 .23558 L
.53417 .23554 L
.53665 .23547 L
.54167 .23528 L
.54607 .23506 L
.55009 .23481 L
.55912 .23407 L
.56704 .23323 L
.57533 .23215 L
.59251 .22927 L
.61048 .22529 L
.64156 .21592 L
.6751 .20185 L
.70354 .18609 L
.74782 .15186 L
.76516 .13354 L
.77938 .11486 L
.78913 .0987 L
.79527 .0858 L
.79938 .0744 L
.80074 .06941 L
.80155 .06559 L
.80199 .06284 L
.80212 .06178 L
.80221 .06086 L
.80225 .06031 L
.80226 .06008 L
.80226 .05993 L
.80226 .05987 L
.80226 .05983 L
.80226 .0598 L
.80226 .05979 L
.80226 .05979 L
.80226 .05979 L
.80226 .05982 L
.80226 .05985 L
.80227 .05989 L
Mistroke
.80227 .05995 L
.80227 .06011 L
.80229 .06035 L
.8023 .06064 L
.80236 .06129 L
.80245 .06221 L
.80288 .06505 L
.80361 .06863 L
.80484 .07338 L
.80654 .07869 L
.81135 .09058 L
.81942 .10584 L
.82986 .12153 L
.84507 .14001 L
.8629 .15758 L
.90866 .19074 L
.91717 .19554 L
Mfstroke
0 .4 1 r
.21724 .14771 m
.23255 .12701 L
.24434 .10607 L
.24883 .09574 L
.25203 .08668 L
.25451 .07746 L
.25546 .07268 L
.25579 .07069 L
.25608 .06858 L
.25627 .06689 L
.25644 .06514 L
.25651 .0642 L
.25656 .06335 L
.2566 .0625 L
.25663 .06173 L
.25665 .06103 L
.25666 .06031 L
.25666 .05951 L
.25665 .05881 L
.25664 .05815 L
.25661 .05746 L
.25658 .05682 L
.25655 .05624 L
.25644 .05489 L
.2563 .05369 L
.25612 .05244 L
.25589 .05118 L
.25532 .04885 L
.25468 .04702 L
.254 .04556 L
.2532 .04429 L
.25247 .04344 L
.25204 .04306 L
.25163 .04276 L
.25117 .04251 L
.25094 .04241 L
.25068 .04233 L
.25047 .04227 L
.25023 .04223 L
.25001 .04221 L
.2498 .0422 L
.24968 .04221 L
.24955 .04222 L
.24931 .04225 L
.24918 .04228 L
.24906 .04231 L
.24879 .04239 L
.24833 .0426 L
.24784 .0429 L
.2474 .04326 L
Mistroke
.24693 .04373 L
.24614 .04478 L
.24527 .04637 L
.24458 .04815 L
.24402 .05011 L
.24375 .05133 L
.24354 .05252 L
.24337 .05373 L
.24324 .05491 L
.24313 .05619 L
.24309 .0569 L
.24307 .05729 L
.24305 .05767 L
.24303 .05838 L
.24302 .05877 L
.24301 .05919 L
.24301 .05961 L
.24301 .06006 L
.24302 .06087 L
.24304 .06164 L
.24307 .06237 L
.2431 .06318 L
.24316 .06406 L
.24332 .06612 L
.24354 .06814 L
.24411 .0721 L
.24487 .07609 L
.24575 .07994 L
.24847 .08922 L
.25606 .10758 L
.26878 .12951 L
.28524 .15101 L
.30779 .17389 L
.33568 .19582 L
.36642 .21444 L
.40039 .22993 L
.43441 .2411 L
.45294 .24557 L
.47072 .24886 L
.48102 .25034 L
.49053 .25143 L
.50103 .25233 L
.50632 .25266 L
.50934 .25282 L
.51213 .25294 L
.51457 .25303 L
.51727 .2531 L
.51997 .25316 L
.52145 .25318 L
.52284 .2532 L
Mistroke
.52539 .25321 L
.52772 .25321 L
.529 .2532 L
.5304 .25319 L
.53296 .25315 L
.53545 .25309 L
.53771 .25302 L
.54278 .25282 L
.54746 .25257 L
.55186 .25227 L
.56243 .25134 L
.5721 .25021 L
.59367 .24669 L
.61258 .24244 L
.6298 .23758 L
.66693 .22357 L
.70017 .20628 L
.72698 .18818 L
.75072 .16796 L
.77182 .14508 L
.78728 .12338 L
.79346 .11263 L
.79886 .1015 L
.80279 .09165 L
.80549 .08319 L
.80732 .07568 L
.80798 .07213 L
.80852 .06845 L
.80873 .06662 L
.8089 .0647 L
.80896 .06385 L
.80901 .06296 L
.80904 .06221 L
.80907 .0614 L
.80908 .06064 L
.80909 .05995 L
.80909 .05917 L
.80907 .05844 L
.80905 .05778 L
.80903 .05719 L
.80899 .05655 L
.80895 .05588 L
.80882 .05443 L
.80863 .05295 L
.80841 .05164 L
.80817 .0505 L
.80765 .04854 L
.807 .04675 L
.80628 .04529 L
.80556 .0442 L
Mistroke
.80514 .0437 L
.80468 .04323 L
.80426 .0429 L
.8038 .04261 L
.80359 .04251 L
.80337 .04241 L
.80317 .04234 L
.80296 .04228 L
.80271 .04224 L
.80248 .04221 L
.80226 .0422 L
.80205 .04221 L
.80184 .04223 L
.80164 .04227 L
.80146 .04231 L
.80127 .04237 L
.80083 .04256 L
.80044 .04278 L
.79962 .04345 L
.79918 .04394 L
.79878 .04445 L
.79806 .04564 L
.79743 .04699 L
.79679 .04883 L
.79629 .05079 L
.79607 .0519 L
.79586 .05321 L
.79569 .05467 L
.79562 .05535 L
.79556 .05611 L
.79552 .05681 L
.79549 .05747 L
.79546 .05815 L
.79545 .05879 L
.79544 .05957 L
.79544 .06029 L
.79545 .06111 L
.79546 .06152 L
.79548 .06198 L
.79551 .06286 L
.79556 .06368 L
.7957 .06557 L
.79588 .06738 L
.7961 .06916 L
.79728 .07603 L
.79825 .0802 L
.79934 .08423 L
.80259 .09398 L
.80668 .10375 L
.81715 .12322 L
Mistroke
.83286 .14527 L
.85143 .16566 L
.90242 .20511 L
Mfstroke
.2 0 1 r
.23482 .14771 m
.24979 .12356 L
.2556 .11156 L
.2605 .09913 L
.26257 .09274 L
.26413 .08708 L
.26543 .0815 L
.26637 .07651 L
.26716 .0709 L
.26745 .06805 L
.26757 .06662 L
.26767 .0651 L
.26774 .06379 L
.26778 .06261 L
.26781 .06144 L
.26782 .06034 L
.26783 .05973 L
.26782 .05908 L
.26781 .05793 L
.26779 .05724 L
.26777 .05659 L
.26771 .05539 L
.26765 .0544 L
.26757 .05336 L
.2674 .05152 L
.26714 .0494 L
.26685 .04754 L
.26606 .04372 L
.26512 .0404 L
.26308 .03526 L
.26172 .03279 L
.26036 .03079 L
.25891 .02905 L
.25725 .0275 L
.25563 .02634 L
.25409 .02553 L
.25319 .02518 L
.25235 .02493 L
.25186 .02482 L
.25142 .02474 L
.25117 .02471 L
.2509 .02467 L
.25042 .02463 L
.24995 .02462 L
.24968 .02462 L
.24943 .02463 L
.24917 .02464 L
.24893 .02466 L
.24865 .02469 L
.24839 .02472 L
Mistroke
.24793 .0248 L
.2475 .02489 L
.24654 .02517 L
.24558 .02554 L
.2447 .02596 L
.24278 .02721 L
.24116 .02865 L
.23953 .0305 L
.23698 .03451 L
.23572 .03722 L
.23467 .04003 L
.23371 .04332 L
.23328 .04518 L
.23288 .04723 L
.23258 .04909 L
.23231 .05122 L
.23211 .05322 L
.23204 .05414 L
.23198 .05516 L
.23193 .05617 L
.23189 .05713 L
.23186 .05814 L
.23185 .05925 L
.23185 .06029 L
.23186 .06129 L
.23188 .06219 L
.23191 .06318 L
.23196 .06427 L
.23203 .06549 L
.23222 .068 L
.23245 .07037 L
.23273 .07264 L
.23354 .07785 L
.23474 .08375 L
.2378 .095 L
.24194 .1065 L
.24683 .11753 L
.26045 .14131 L
.28095 .16783 L
.30533 .19189 L
.33692 .21578 L
.37185 .23568 L
.39115 .24437 L
.41275 .25244 L
.434 .25883 L
.45386 .2635 L
.46359 .26535 L
.47424 .26706 L
.48362 .2683 L
.49377 .26935 L
Mistroke
.49938 .26981 L
.50453 .27016 L
.50971 .27043 L
.51463 .27062 L
.5174 .27069 L
.51892 .27073 L
.52035 .27075 L
.52313 .27079 L
.52565 .2708 L
.52712 .2708 L
.52866 .27079 L
.53143 .27076 L
.53297 .27073 L
.53441 .2707 L
.53767 .27061 L
.54057 .27051 L
.54371 .27037 L
.54942 .27004 L
.56009 .26919 L
.57248 .2678 L
.58385 .26614 L
.60454 .26215 L
.62353 .25733 L
.64403 .25083 L
.66479 .24276 L
.70169 .22417 L
.73173 .2041 L
.75924 .18036 L
.78025 .157 L
.79831 .1306 L
.80984 .10728 L
.81419 .09533 L
.81712 .08482 L
.81825 .07956 L
.81919 .07397 L
.81955 .07124 L
.81985 .06837 L
.81997 .06701 L
.82006 .06574 L
.82013 .06451 L
.82018 .06339 L
.82022 .06222 L
.82023 .06161 L
.82024 .06097 L
.82025 .0599 L
.82025 .05875 L
.82023 .05774 L
.82019 .05667 L
.82015 .05567 L
.8201 .05477 L
Mistroke
.81994 .05267 L
.8197 .05046 L
.81942 .04844 L
.81911 .04665 L
.81846 .04361 L
.81759 .04051 L
.81652 .03755 L
.81539 .03503 L
.81404 .03261 L
.81242 .03031 L
.81079 .0285 L
.80919 .02712 L
.80755 .02605 L
.80603 .02533 L
.80517 .02504 L
.80471 .02492 L
.80423 .02481 L
.80381 .02474 L
.80334 .02468 L
.80292 .02464 L
.80252 .02462 L
.80206 .02462 L
.80182 .02463 L
.80156 .02464 L
.80111 .02468 L
.80068 .02474 L
.80018 .02484 L
.79972 .02494 L
.79869 .02526 L
.79786 .0256 L
.79696 .02605 L
.79519 .02723 L
.79364 .0286 L
.79205 .03038 L
.78947 .03438 L
.78813 .03725 L
.78704 .04019 L
.78603 .04376 L
.7856 .0457 L
.78519 .04789 L
.7849 .04989 L
.78468 .05177 L
.7845 .05373 L
.78443 .05472 L
.78438 .05564 L
.78433 .05674 L
.78431 .05734 L
.7843 .05792 L
.78428 .05896 L
.78428 .0601 L
Mistroke
.78428 .06071 L
.78429 .06138 L
.7843 .06208 L
.78432 .06274 L
.78437 .06394 L
.78444 .06524 L
.78462 .06774 L
.78489 .07045 L
.78556 .07548 L
.78659 .0811 L
.78808 .08753 L
.79176 .09958 L
.79643 .1114 L
.81008 .13699 L
.82741 .16087 L
.84993 .18481 L
.87981 .20926 L
.88766 .21467 L
Mfstroke
.8 0 1 r
.2524 .14771 m
.26007 .13447 L
.26703 .12011 L
.2728 .10526 L
.27665 .09219 L
.27829 .08493 L
.27946 .07826 L
.27993 .07491 L
.28032 .07143 L
.28048 .06964 L
.28063 .06768 L
.28074 .06594 L
.28081 .0643 L
.28086 .0628 L
.28088 .06196 L
.28089 .06119 L
.2809 .05983 L
.28089 .0584 L
.28088 .0576 L
.28086 .05674 L
.28083 .05593 L
.2808 .05519 L
.28073 .0538 L
.28064 .05235 L
.28042 .04975 L
.28015 .04738 L
.27934 .0422 L
.27829 .03746 L
.27687 .03264 L
.27541 .02871 L
.27364 .02487 L
.27188 .02171 L
.26977 .01857 L
.26569 .01392 L
.26326 .01185 L
.26061 .01007 L
.25827 .00887 L
.25694 .00833 L
.25566 .0079 L
.25416 .00751 L
.2528 .00726 L
.25203 .00716 L
.25132 .00709 L
.25095 .00706 L
.25054 .00705 L
.25011 .00704 L
.24971 .00703 L
.24899 .00705 L
.24831 .00709 L
.2477 .00715 L
Mistroke
.24703 .00723 L
.24631 .00735 L
.24554 .0075 L
.24417 .00785 L
.24275 .00832 L
.24127 .00893 L
.23867 .01031 L
.23596 .01221 L
.23312 .01477 L
.23081 .01739 L
.22849 .02061 L
.22482 .02742 L
.22314 .03167 L
.2218 .03591 L
.22059 .0409 L
.22009 .04356 L
.21963 .04658 L
.2193 .0493 L
.21907 .05185 L
.21897 .05322 L
.21889 .05473 L
.21886 .0555 L
.21883 .05632 L
.2188 .05711 L
.21879 .05783 L
.21877 .05926 L
.21877 .06059 L
.21879 .06207 L
.21881 .06282 L
.21884 .06364 L
.21889 .06505 L
.21897 .06657 L
.21917 .06935 L
.21947 .07251 L
.21988 .07593 L
.22087 .08223 L
.2223 .08919 L
.22433 .09709 L
.22918 .11165 L
.2352 .12573 L
.2523 .15541 L
.2735 .18238 L
.30046 .20857 L
.33566 .23448 L
.3738 .25526 L
.39688 .26497 L
.41877 .27245 L
.44136 .27856 L
.4627 .28293 L
.47401 .28471 L
Mistroke
.48654 .28627 L
.49288 .2869 L
.49972 .28745 L
.50618 .28785 L
.5121 .28812 L
.51519 .28822 L
.5181 .2883 L
.52072 .28834 L
.52355 .28837 L
.52664 .28838 L
.52819 .28838 L
.5299 .28836 L
.53293 .28832 L
.53575 .28826 L
.53859 .28817 L
.54128 .28807 L
.54633 .28783 L
.55175 .28749 L
.55764 .28704 L
.57007 .28576 L
.58318 .28396 L
.6064 .27956 L
.62779 .2741 L
.65015 .26684 L
.68839 .25038 L
.72624 .22801 L
.76055 .20066 L
.7869 .17268 L
.80608 .14568 L
.81473 .13017 L
.82131 .11572 L
.82593 .10314 L
.82803 .09616 L
.82967 .08976 L
.83109 .083 L
.83208 .07698 L
.83247 .07397 L
.83281 .07074 L
.83296 .069 L
.83308 .06739 L
.83316 .06589 L
.83324 .06427 L
.83329 .06278 L
.83332 .06142 L
.83333 .06014 L
.83333 .0588 L
.83331 .0576 L
.83328 .0565 L
.83324 .0553 L
.83317 .05402 L
Mistroke
.83298 .05124 L
.83273 .04866 L
.83209 .04402 L
.83122 .03954 L
.83001 .0349 L
.8285 .0304 L
.82686 .02651 L
.82347 .02039 L
.82132 .01743 L
.81923 .01503 L
.81694 .01286 L
.81439 .01092 L
.81189 .00944 L
.80957 .0084 L
.80812 .00791 L
.80678 .00755 L
.80601 .00739 L
.80529 .00727 L
.80454 .00717 L
.80415 .00712 L
.80372 .00709 L
.803 .00705 L
.8026 .00704 L
.80223 .00703 L
.80154 .00705 L
.80081 .00709 L
.80016 .00715 L
.79955 .00722 L
.79816 .00746 L
.79683 .00779 L
.7956 .00817 L
.79285 .00933 L
.79024 .01086 L
.78755 .0129 L
.78515 .01519 L
.78301 .01768 L
.77936 .02319 L
.77766 .02652 L
.77599 .03051 L
.77457 .03471 L
.7733 .03958 L
.77279 .04203 L
.77237 .04443 L
.77202 .04683 L
.77175 .04911 L
.77154 .05131 L
.77137 .0537 L
.7713 .05509 L
.77125 .05642 L
.77122 .05762 L
Mistroke
.7712 .05892 L
.7712 .06036 L
.77121 .06168 L
.77125 .06322 L
.77131 .06469 L
.77137 .06606 L
.77145 .06734 L
.77168 .07026 L
.77198 .07326 L
.7724 .07662 L
.77355 .08358 L
.77505 .09056 L
.77709 .09826 L
.78198 .11262 L
.788 .1265 L
.79618 .1419 L
.81783 .17294 L
.84194 .19876 L
.87291 .22424 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{531, 156.812},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztXXuIZNlZv1O3qqtf093Tz+l5dc9O7+zsw7jZcfPYybrZR2bduNnEPPaV
nU2GTMrdxCUSVwmiiIiKBMSoBJqVoBgJQVgEFaIgBAQhUCIiBkH/URDxD0EI
iAhyrfudc37fOef+zq1TVd3OJlpQ1afPufd7/L7H+e65rw/cfP2VT7928/VX
P3Vz/8nP3/zxV1791E/sX//c50dd5Ymi6GwURfFb+0XdrkZN+3OtqKqqKAv5
Z9SSb/37bWkWRzIuw0/UrW4xLMxWF/Hvq2lKj2Kj0tBxe5+rfzrhwI+m6bzX
9g2LCn3zICH/74DOPFq3DMU7zZajT5fQ7kDDeTL6COG8RPrkd4MMLJO+m0au
A/nTDfiNPktEjB7pexgArKYEOkUGVkjfJ6cTSLa8RuitpQRikrI+K9AFcOlw
0eZbjfceQplBIr8nMzf+RCtWTAzWx1Bj7iO/zOHYxi8fm2ibKdEWMze+YaTQ
UFyAaftEhocIie2UDPNkYCstg6Y0xmWu/p0rrhZUNfntk4F57LZARl/yOEea
vjslw6jvqtfXNchdLai6Sbn6KVJR39xkUr8rU2rGvpeSn8nACDBGbN+PH4/8
jJX8MsUY0XnSx/b15RfxmdQ9Qmwhk0FSakZ0MZPoi2nU35nJaimTlaSPjxNG
z5tgGX2enBCy+uP6maE/UP8K3xI8usepcTfYd/R5mbB5TuHwN71OMUspH+4+
Gmf6f9CK5m9qudk5OpTsxGTYMOlOkr6uFSPwZivGi8arR5/nOSzvy2S8yGFh
afaZtwYsvRZYXuBgSHc5ibcswfEzQnQWYGTkHZlS9eweg6ptyvOpMPbPRX0K
XLhdLlbS162l6hAgXLJhgXaEHpULoS0xRsKa5Cat+pusRzyiKbk0Fc+CYwnR
cCAwCDDxWbsdmT8+DccqeTyUR4RjJKITnyV/7pyjz0spPPWAPGNuKVvE6cA6
drM27J4h4iiBllkwF7jS7TvI6xsHovyeuE3MX/g/gkc6AkIez3t4TJTZ33Io
dGdg7qPwveIVtxmPzhGL9N2EByPLROqRvk6mSG8FPF63U1Q95D6lV4KGfT1T
ufgfoFkGY34Z6z5dwktaJ8hAlxBIMNKJ1h9gWjAJnjVUBA1X+hvFDFCbpE8q
9a5BpDkqJpACczmTHlt5SnugWsH1FwkHSXsiP5TZzpSX9W3NsO9x8cgLqqjm
rSraXWTH9eIRa9ObzDn7cM4FMqoL+2z0uJzTVbODKl3V/L9L+siGYVxU447P
bpNT3gt3Yu65hNErE6nfiEhWiqRnOu5J7KCPHTo/fpst9aE02leA5xrZaMUG
WVFcnkiFPiQtqujvgB/5fo/DfBlAboSAS9/B/wq4R1wqdiaPIlov3klQ2yB9
64Drju8OuPpxysHfSRjbtYlL0D45fcno/lsJm/QS15yZ06sQnwkW3SwszhV8
MBhA2wDowu0CqDMR46MC6CIBw15/M/qcJqNnZ5CzqAYOnJyF6CmxKcGz5jdL
CrIg7cE7zhBAdjGaC42bzIyYA/1mLtDPiMvA4lL/zoTLeWh+rsVRGlhFxFoX
Pmwk1f91AiXS+yZPj08TYSBgBSmqSSOMQZPbdzopcT9g72LLwRUXKjYWJlo2
K5O8E2t2Df5lwD/XVBY25j3nM/t2MmFDOjpm2HoJ3s6LW3iz2rIFNZafLhix
vLmNzYZNrHpg6uPUMK0vu7dt4ux6NkY+z5APm3PBk56AfXEMOFHfHuljF6G5
qzpCszZq3hghJ3Hisgz55ZfIKDsPHcauzGdnsXGJeRwO+6SPLTTESbKorFTB
koyTL2W4LCw86JVDSTgwf7Tqs0KHqcrKpY0W+SzwTflmRqD0ODgCRVXpif/Y
B6zbtPjADlGOKcyKagaC2kBFVPmwjq2yTXZl21gE1AiVn1ZY6rbX57FDA9G2
9I8rx+mN60OsYJXHfxQRcmhcSzdqueP/UMKCJUj57VvSjWUQr9ANSxnHTlqW
sGPHBK2/NXV7hS1bnLuU2beeIawTRYVjmcwIbw3sJdOBL7I03PVvPk9vCm+w
C5JFk0krNmyRUlfEJr9B4YD0neL6OAhqiQt1MbpA5QKhB92uVkXDEAlX864K
8vzSY6lhGPL0iybH0y8VHZb2Qne2orPiKHt9Rf5NFWzhyL8LwEnREdk0UQZY
9uhRQFwRFiATKue55FzAs7KIFBX4NOp5UhQGos0BV9+eIy5HCKlsmfZLBVLN
OxGQZmyeHMwoRi60lyydYRFrTQwyaJ6r1oxXBiI6w/kRYK+XXyear3II229f
uUz61hwuxmqB7v6BlpOf6YMzYJ4+8DN1vvFMGGg6Z6m7VU1GN6bDKto0FzV3
i5EfZtyq7Qg65bAW4ynlYimYcqPZRnboESZseYBFxrCo4nxYf20t5uKr6TBT
o3kX6TsJ04bKWRdhuqQXbY0B3O5MOfmFZST/DYKNHbApRq2LW578PnOXK1qQ
PWXkKsbdy8QgXCLqlESdtPNx/2lWlATLBF/fDuP4usjP4VvzsisN7HSgniy8
QkYXiMDpi7lHJU+93UiwoanKetIwh3zeUFwqF77K1vr1f//tcXfx7R+EBW7b
EQ6lz94K1ODPNGgc+FTuBoY0bBl985kqlFZSZ1kRoQiqQKSPgb9LiGLP08Kx
/C+Djn8oQTzPTNqWaC9gZGXBxMWqHl+YoS1wfWEcpM/NDumc6tMN9IETdFUl
o5Z/0Ykv+XitrFsXSq6Qu5ub6ar+7z/t9u5/K53nn+G0X1kPaJOvrdb05VN+
hlXjUNuk1I+ZjTAle8DendkHpwy1tKE4TE6d47VsP0OtSHVjFNXugbL/we3h
2Y/bg51/iiWs/7rVRH87KKpCWtdhx8AjyT46u0U6CAnfK53HxpOtr82QzCZN
DUMbxOtgSq9nI8Twdob4TkM6t1Vg5app+WE8x3bMrJKSqeEXZeQXVqSPjIFc
uu5xJL1RooPm7bQOAcKd1Dp7GxXfngLlvztjVb4bDIPDWd/QPlF//msrgX2g
G6VJQ8heIKQz/oeN8u6xBz6Y9yT7FHSrHtOMOU7u3bTp9WmGVHQgYWvTf4Nb
l16Ytbk1w1Ndgq3y9giVMpLJIV7L9CNToG0js6kCY94GHMsbvvfPEXr+orsX
tzi+97z7XzyPb6a2dr+Ij8OHBU93vg3ctkzseHK1dhCxPziZDa5YUs6Eklea
624pD2XJsC2RjzNIXLTVX//ozyH/z46eJ3aX7DsuDkKZw7NDKIBDsfuEJGMd
i13/9/QY40jX5Ui3YB200EI+jZ9XEhxKBdqVhq3iRi33tRWojA3dWDWliTSS
/5FowHZLWycq0w7d4UFaDaNiVIzq/cCTWqv+/vBkoXTJWNAkhnBi1I3jw9ha
6MKq2LfqieqeJbTyZGtEYW2uR3Q1hVJpCTi2b4w1XXpxOlg8/iGlnzstYk+a
lD6bgPVcII5TESXrbNr1iHZJS6uvPmWMzK4Mv5f07fsgSJZo8W8GOEKqUdyH
vutVmg6BYcF3DxKzRUMQYlm8hPpWAeftf2cGxmjGyaenOr9v2JgQurF12a1q
LFQ69a/6XRdKiWmuT2bTC9A89nz77RhtjYMf0rTVZhc5/VCE28makF+ERfuy
6qeD6FJZ/Lyl241U+Rs4aocrpWE6aOXaZhLformaJeYUlUVdjGv2xGTWdU+b
gycHM0flcpM7ra5g1B9W8zBT+/VNbGrWN87UClIQuYeFO5A9NFj8FZTr6DaI
3G4qCeTaue2gwLfz1GppKlFLSCowSemxMaaWrjN++B7y7NU8K19/WCD3W1Rh
KvvWbdt3nHU1hdncNtLnW55NvWMOC1efUJnUsMeukcs7GnOi2SOTxbC92N55
vYVEs0IzU6RrPPJUlco7/dVQNDFHNWbrNIXxUDknjVK0neqG1ie+Wfd1gQIO
fL2d0sTH+0T86By/3PAT/SyK+hO1/d/z7aF7amO2Y6yHkPRAPpFAq8bZ0Ioa
bq7N9M3rk2aFReUWgEoks29AP2tuDyrFcj5FMmPmatU0y8nZhG7PkrirB0VK
q6RT7Z1pS+8brQt+SlX26GFqE4rIZ14sJCrygF6RCH0/P7o+LDJHxvcXpf3t
J8qdglWfaNGFjtZ/gxL8TWBRtmKhPOaJBONmiBABfulibkgwb2mbyRpYlDbQ
D4sH0h7ELrycI30LiC/1TvXY1hm2KKDDUXgQWydOx2smfpoKSxzeCHRfRWuO
6M3yCVtIyfUbVwkMWY45DpX7ULkDRb9vCm/Rx2dItPWBFYtUlthbRc9CTaOt
/tv2SNJpIIt8Xf1AYuINgLdAvGSB0Mv1kpzH9B2vvvPQqAd9757CRTKKFHZz
EXsM7CyKJR2yhLuKIX8dyi6Fo9G+s6SApNHkeeVstC0kptFc438Omh8cj3HZ
DXfHoqLGnHitPCtDVox/CSouQ+157LGYojelIV2e0Fpwai21HlFJVXrRaC9t
tH2zecEvZ8w11dEosRAaSJSQ0wbztRJfqFtzdWsFo3igchxzSi/DQOks0phs
Z1E0mQxE5aVQKVF0d4pgky5mN3YL8FGrE18pV3/VlhtQ7LMIu1MYXRofbPJo
CyZf2oK8TGRP92bzBgvxpN4iuyaPk9B2I21GZijW526hHJcfkzW0QMdqDSa6
LBRJ5pBbGiT8tjC6HBoqGWrMUG05nV0AOyQGGuesuUbTdHMSusk1jTKxr85u
NPZYglyjMSXYpMaUOA3Pk8sYFurWmdAvI/MttnGbwnzs4tyJzKfuKvJpbtDc
v388BmKpZCIDJQU+C2M8jNY+RlewB24KakZp4cXwFGZhJyJyzcJWPHSqVX1X
oZF5QkD2if/kWacjNFC7wHLP7TrMslS3LmN0NTRQMm6YLG3z7DgD5ZbBzEAs
4S9CjzXodmaMqZJFxflMgdu8tiFwZCAV8/66tY9liC4yts5fLD0eoYHYExIn
MpDEsCZenUvtrTAufU96tWXYt3fEZmEV2WIouhjjJ9FaD82i0aIATGkC9k6h
XBMwd1CXi4xRhJcubs1ulv1ZzSLgLRGBNwD8a2htEhPo3NLOLdcYy5kaOekH
6vsVm+c06u86HriZYm0ANKIgAn4LcH8arW2MniQqsjkj1wQs/TAT5M6R7fGg
laK5pXvMtfbspgb2SMBZTBD5vhxp2qOVob17uIscqibwZxTf86aAm737bxa4
WWpV97o0BviMvkuZAidNIJApjOoVsqLQr+GW44y5urULs6wQxZjvs7mAHZ+z
9MNekphMqCz9iEZael+cHe4DIlIu3Mw/WFWjvn8eJngMJjiH0dUwWo4Q+HXS
x4Bv49GQJTLGnjHGLLcZ3knEZCpG/sFMIMIJoHItzj7gfgdaFzC6hj2wL/xt
gPQzDmT2fKeJQBa+zIHumx3ay5nQJks9Ec49tqUanILXSsKarwGV2WMZh2Yy
uo49dHJt58beusfgZo8aY5HbxoP79Di4pYvd486epZ0LMgszzeLr8FXhe0cN
8j0AeQPbraQUmxLk3LN4DryB5ulK49BUe/SRAgxG1nc3EWQWaNWTNwHja2ht
YnQlVIeH7VX+DtTcJXxW3zAP1SnwymSAXiZ99xLhJgJUQNHMuQXwBvBVC63L
xEydjAmNlXW5S4G50KqvGqzSj2nRN2FGo+0PrWImuG8GE2hhpCbYBvCfgDG2
MYrt8N7nccAzn04u8UkUOBj9NPADBtANAgDLsOx1CLmPrXrbJICKmDrfr8FX
dwDe8wB0JwVjskJg4LGHZjP5cr327UcEbfLxVd8/g8DqAe6xMdVAjvN6uGNT
oD0N4JPQim+xV4KzJYOJABVuFkb2nDp2aGGvs0gEOoPx7SkxNWgi4dQvFTzJ
ef0asscB4y7Aw3bVCqHH5nu2MneR9LF92w1u3IY+FJEtELHrXXOhfcAwHRY0
CFnmRFFVnQJ4e4DWHh5cxS00rvgK6t8BjDYOUHY4nwRUKLM62Vak7Lmb+iaX
5EuFoj72DMoHMwNJM+eqA8/z0AOAJwXKPA4LyxSM7JW+DEZ2ZOhWtAs6oZm3
zNOHtS6TPn03k4Y3A4q9kq49lHFU7/mbFGlXangO0IcivlolVJYaPHwJ7iJ9
LB5Y2L4rDVTuU23ZW9qTGUfsrtnKHtmMAPgxQIHyu1rFHsxT2JTADhSSUAhl
C8AszzZ+qNU9tSpStTeh9i20tojaKynRI273mj2GBc1MzC9NyM/0ROv3zOB2
OtlvA4Ab8ADUW9Ua2dctuALakQD3t5qAZQhbmOY+7pwB8HAKgMjumvpOQ9ln
oezpUNmJ7M5KC2aCR42yydcFSBez+yOEAXMxZmN19zNQ+xm0djEaqR1YzOd7
tdXJ3ztGxQwbPwoGyXQjYm4421Vnoc776lYPhZpmfFZ/cMojvrmp1Jgl+w0Z
DIAnWp1XS3DNxuehotzHtFC3LoTKam2Q4bzvTikrElgVmejMxg71ovihTJdd
JiruQzEpYeSRn3emVEw66rVWR7W3+zEHZMmI9T0VOqoIskLUkcJgGdXXIhQr
Q3XWiJis0PhB0mfgjt/+I/KyyeXplHWYEiKmpPb1WvS3uWircMzrRVaUPASe
xwi3J43AyXc6sT5R7EOEGAtnjZ0tKPEZtLYwmov641DHip77vq4tiP4RkFCU
XAnvi3kLre1QTLVOJNx10mefVnAJ7HNfFvqxTIS1QEL1UL2E1g5GT5F9tWZ4
fwpr+zo9Ed35YeG9Ou8FgqYGE+b46qNouVUO1IAJNH/NsL8LrNhCpL7y8EYK
r0gkCcl+TeEpiLQLkdaxxyqh9yUjkl45wBZFTmL0k4QEq2bWwP4ChLuG1lmI
vhEKJ6j/phHpPjAt7GPU7EewYcsKi9jjFohpKt+ASHcApfsh0h5GmUhfNgLI
0sdczYDdSyOrbXIv/qsplITsJlhJCC0DkXpmqi5hdBN7sFPrViRTIoZ3gFf1
Qfjo8znIz3KRiiFIn633vxt9WyFzoXJoWD5AdGd4/BQxwg4YfAatbcLqDcPq
agrmqO8LhJUG5S20dsLoiSC1TO8nkCY87qcJ313rXYPqBvieDvnKHl/xDCgu
zZZzfqbVk85ajxsgFw2qXcLqtw2ra4iPnw09QxzjPIi9H60zGGUXGfhkI7l/
DgxOgcQeZHwUDM6H4Sl7/G6a7M9jo3WQ3Qcxu7w3au1hVMn+XprsL2CjDewo
SWKpJialxCISR4kYlj2+FmP7ixjaxOZyjvRiTeKKAWHUt4Xtvp6W7Jex0RZ2
/Cxa24bBaPT30yR+BSR2sOMtSHYao2+mSXwRfE5jx5dDEjL6B2kSvxqSECme
RWsXUvxhDOeXMHQGmz+D1hmQ/eM079/ARmex4xPGV0atc2DwjTSJL4PEOeNu
ox0fQmsPo3+aJnEIPnvGoZxfiBQXQeLP0iTewEZyxnG93lFu79isWwcY/WYM
4lcw9CAQeBB9f57m+DvY6BW0/sJsfmDDeZoTpl8FsZuGyqj1LY9stDlb02XT
wNdA9kWQ/UtDlp1RbH/jy9dB4sNo/bUhxs73tp84etMYekTiOlp/a4ixc/ps
OmVk/8i44NA6Y79u/b2P49QvyvgT0LsPrX/yoJQZq/1FEeKFy/WO28bhR61/
jT1zWLe26z/fSXuh/H77aMaLE/8D6yjQRA==\
\>"],
 ImageRangeCache->{{{0, 530}, {155.812, 0}} -> {-1.28542, -0.680015, \
0.0215649, 0.0215649}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<trajectories.pdf\>\"", ",", " ", "%"}], "]"}]], "Input"],

Cell[BoxData["\<\"trajectories.pdf\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  StyleBox["Streaklines", "Subsubtitle"], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.402068386964308*^9, 3.402068389312358*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Finv", "[", 
   RowBox[{"\[Alpha]_", ",", " ", "\[Tau]_"}], "]"}], " ", ":=", "  ", 
  RowBox[{"center", "+", " ", 
   RowBox[{
    RowBox[{"rot", "[", 
     RowBox[{
      RowBox[{"-", " ", "\[Omega]"}], " ", "\[Tau]"}], "]"}], "  ", ".", 
    "   ", 
    RowBox[{"(", 
     RowBox[{"\[Alpha]", " ", "-", " ", 
      RowBox[{"v", " ", "\[Tau]"}], " ", "-", " ", "center"}], 
     ")"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(Finv\\)\
\\\" is similar to existing symbol \\\"\\!\\(Find\\)\\\". \\!\\(\\*ButtonBox[\
\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Alpha]", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"\[Alpha]1", ",", "\[Alpha]2", ",", "\[Alpha]3"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"finv", " ", "=", " ", 
  RowBox[{"Solve", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"\[Alpha]", ",", "t"}], "]"}], " ", "==", " ", "a"}], ",", " ", 
    "\[Alpha]"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Alpha]1", ",", "\[Alpha]2", ",", "\[Alpha]3"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(finv\\)\
\\\" is similar to existing symbol \\\"\\!\\(Finv\\)\\\". \\!\\(\\*ButtonBox[\
\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Alpha]3", "\[Rule]", "a3"}], ",", 
    RowBox[{"\[Alpha]1", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "a1"}], " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], "+", 
        RowBox[{"t", " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], "-", 
        RowBox[{"Sin", "[", "t", "]"}], "+", 
        RowBox[{"a2", " ", 
         RowBox[{"Sin", "[", "t", "]"}]}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", "t", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}]]}]}], ",", 
    RowBox[{"\[Alpha]2", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "a2", "-", 
           RowBox[{"Cos", "[", "t", "]"}]}], ")"}], " ", 
         RowBox[{"Cos", "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a1"}], "+", "t", "-", 
           RowBox[{"Sin", "[", "t", "]"}]}], ")"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}]}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", "t", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "t", "]"}], "2"]}]]}]}]}], "}"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "finv", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Alpha]3", "\[Rule]", "a3"}], ",", 
    RowBox[{"\[Alpha]1", "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a1", "-", "t"}], ")"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a2"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}]}], ",", 
    RowBox[{"\[Alpha]2", "\[Rule]", 
     RowBox[{"1", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "a2"}], ")"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a1", "-", "t"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}]}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Finv", "[", " ", 
  RowBox[{"\[Alpha]", " ", ",", " ", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "t"}], "+", "\[Alpha]1"}], ")"}], " ", 
     RowBox[{"Cos", "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]2"}], ")"}], " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
   RowBox[{"1", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]2"}], ")"}], " ", 
     RowBox[{"Cos", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "t"}], "+", "\[Alpha]1"}], ")"}], " ", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], ",", "\[Alpha]3"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"v", " ", "t"}], " ", "+", " ", "center", "+", " ", 
   RowBox[{
    RowBox[{"rot", "[", 
     RowBox[{"\[Omega]", " ", "t"}], "]"}], "  ", ".", "   ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Finv", "[", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Alpha]1", ",", "\[Alpha]2", ",", "\[Alpha]3"}], "}"}], 
        ",", " ", "\[Tau]"}], "]"}], "-", " ", "center"}], ")"}]}]}], " ", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"t", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Alpha]1", "-", "\[Tau]"}], ")"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"t", "-", "\[Tau]"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]2"}], ")"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"t", "-", "\[Tau]"}], "]"}]}]}], ",", 
   RowBox[{"1", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]2"}], ")"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"t", "-", "\[Tau]"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Alpha]1"}], "+", "\[Tau]"}], ")"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"t", "-", "\[Tau]"}], "]"}]}]}], ",", "\[Alpha]3"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ff", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"F", "[", " ", 
    RowBox[{
     RowBox[{"Finv", "[", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Alpha]1", ",", "\[Alpha]2", ",", "\[Alpha]3"}], "}"}], ",",
        " ", "\[Tau]"}], "]"}], " ", ",", " ", "t"}], "]"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"t", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Alpha]1", "-", "\[Tau]"}], ")"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"t", "-", "\[Tau]"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]2"}], ")"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"t", "-", "\[Tau]"}], "]"}]}]}], ",", 
   RowBox[{"1", "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Alpha]2"}], ")"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"t", "-", "\[Tau]"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Alpha]1"}], "+", "\[Tau]"}], ")"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"t", "-", "\[Tau]"}], "]"}]}]}], ",", "\[Alpha]3"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", " ", "ff", " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "3", "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ff", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "-", " ", "t"}], " ", ")"}], "^",
      "2"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ff", "[", 
        RowBox[{"[", "2", "]"}], "]"}], " ", "-", " ", "R"}], ")"}], "^", 
     "2"}]}], " ", "]"}], " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"1", "+", 
   SuperscriptBox["\[Alpha]1", "2"], "-", 
   RowBox[{"2", " ", "\[Alpha]2"}], "+", 
   SuperscriptBox["\[Alpha]2", "2"], "-", 
   RowBox[{"2", " ", "\[Alpha]1", " ", "\[Tau]"}], "+", 
   SuperscriptBox["\[Tau]", "2"]}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a0", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", "3", ",", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "3", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"F", "[", " ", 
   RowBox[{
    RowBox[{"Finv", "[", 
     RowBox[{"a0", " ", ",", " ", "t"}], "]"}], " ", ",", " ", "1"}], "]"}], 
  "  ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"1", "+", 
       RowBox[{
        RowBox[{"Cos", "[", "1", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "t"}], " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", "1", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "-", 
          RowBox[{"t", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}]},
     {
      RowBox[{"1", "-", 
       RowBox[{
        RowBox[{"Sin", "[", "1", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "t"}], " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "1", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "t", "]"}]}], "-", 
          RowBox[{"t", " ", 
           RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}]},
     {"0"}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   1 + Cos[1] (-t Cos[t] - 2 Sin[t]) + Sin[1] (2 Cos[t] - t Sin[t]), 1 - 
    Sin[1] (-t Cos[t] - 2 Sin[t]) + Cos[1] (2 Cos[t] - t Sin[t]), 
    0}]]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"streaklines", "  ", "=", " ", 
   RowBox[{"Map", "[", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ParametricPlot", "[", " ", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Evaluate", "[", " ", 
         RowBox[{"Drop", "[", " ", 
          RowBox[{
           RowBox[{"F", "[", " ", 
            RowBox[{
             RowBox[{"Finv", "[", " ", 
              RowBox[{
               RowBox[{"center", " ", "+", " ", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "0.5"}], " ", "+", " ", 
                   RowBox[{"0.2", " ", "#"}]}], " ", ")"}], " ", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Cos", "[", "0", "]"}], ",", " ", 
                   RowBox[{"Sin", "[", "0", "]"}], ",", " ", "0"}], "}"}]}]}],
                ",", " ", "t"}], "]"}], " ", ",", " ", "0"}], " ", "]"}], ",",
            " ", 
           RowBox[{"-", "1"}]}], " ", "]"}], "]"}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"-", "10"}], ",", "0"}], "}"}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotStyle", "\[Rule]", " ", 
         RowBox[{"{", 
          RowBox[{"Evaluate", "[", 
           RowBox[{"Hue", "[", 
            RowBox[{"0.1", " ", "#"}], "]"}], "]"}], "}"}]}], " ", ",", " ", 
        RowBox[{"DisplayFunction", " ", "\[Rule]", " ", "Identity"}]}], " ", 
       "]"}], "  ", "&"}], " ", ",", " ", "\[IndentingNewLine]", " ", 
     RowBox[{"Range", "[", "8", "]"}]}], " ", "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"streak", "=", " ", 
  RowBox[{"ParametricPlot", "[", " ", 
   RowBox[{
    RowBox[{"Drop", "[", " ", 
     RowBox[{
      RowBox[{"F", "[", " ", 
       RowBox[{
        RowBox[{"Finv", "[", 
         RowBox[{"a0", " ", ",", " ", "t"}], "]"}], " ", ",", " ", "1"}], 
       "]"}], "  ", ",", "  ", 
      RowBox[{"-", "1"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "10"}], ",", "0"}], "}"}], ",", " ", 
    RowBox[{"AspectRatio", " ", "\[Rule]", " ", "1"}]}], " ", 
   "]"}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.528477 0.0636374 0.376014 0.0545181 [
[.01938 .36351 -6 -9 ]
[.01938 .36351 6 0 ]
[.14665 .36351 -6 -9 ]
[.14665 .36351 6 0 ]
[.27393 .36351 -6 -9 ]
[.27393 .36351 6 0 ]
[.4012 .36351 -6 -9 ]
[.4012 .36351 6 0 ]
[.65575 .36351 -3 -9 ]
[.65575 .36351 3 0 ]
[.78303 .36351 -3 -9 ]
[.78303 .36351 3 0 ]
[.9103 .36351 -3 -9 ]
[.9103 .36351 3 0 ]
[.51598 .10342 -12 -4.5 ]
[.51598 .10342 0 4.5 ]
[.51598 .23972 -24 -4.5 ]
[.51598 .23972 0 4.5 ]
[.51598 .51231 -18 -4.5 ]
[.51598 .51231 0 4.5 ]
[.51598 .6486 -6 -4.5 ]
[.51598 .6486 0 4.5 ]
[.51598 .7849 -18 -4.5 ]
[.51598 .7849 0 4.5 ]
[.51598 .9212 -12 -4.5 ]
[.51598 .9212 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01938 .37601 m
.01938 .38226 L
s
[(-8)] .01938 .36351 0 1 Mshowa
.14665 .37601 m
.14665 .38226 L
s
[(-6)] .14665 .36351 0 1 Mshowa
.27393 .37601 m
.27393 .38226 L
s
[(-4)] .27393 .36351 0 1 Mshowa
.4012 .37601 m
.4012 .38226 L
s
[(-2)] .4012 .36351 0 1 Mshowa
.65575 .37601 m
.65575 .38226 L
s
[(2)] .65575 .36351 0 1 Mshowa
.78303 .37601 m
.78303 .38226 L
s
[(4)] .78303 .36351 0 1 Mshowa
.9103 .37601 m
.9103 .38226 L
s
[(6)] .9103 .36351 0 1 Mshowa
.125 Mabswid
.0512 .37601 m
.0512 .37976 L
s
.08301 .37601 m
.08301 .37976 L
s
.11483 .37601 m
.11483 .37976 L
s
.17847 .37601 m
.17847 .37976 L
s
.21029 .37601 m
.21029 .37976 L
s
.24211 .37601 m
.24211 .37976 L
s
.30575 .37601 m
.30575 .37976 L
s
.33756 .37601 m
.33756 .37976 L
s
.36938 .37601 m
.36938 .37976 L
s
.43302 .37601 m
.43302 .37976 L
s
.46484 .37601 m
.46484 .37976 L
s
.49666 .37601 m
.49666 .37976 L
s
.5603 .37601 m
.5603 .37976 L
s
.59211 .37601 m
.59211 .37976 L
s
.62393 .37601 m
.62393 .37976 L
s
.68757 .37601 m
.68757 .37976 L
s
.71939 .37601 m
.71939 .37976 L
s
.75121 .37601 m
.75121 .37976 L
s
.81484 .37601 m
.81484 .37976 L
s
.84666 .37601 m
.84666 .37976 L
s
.87848 .37601 m
.87848 .37976 L
s
.94212 .37601 m
.94212 .37976 L
s
.97394 .37601 m
.97394 .37976 L
s
.25 Mabswid
0 .37601 m
1 .37601 L
s
.52848 .10342 m
.53473 .10342 L
s
[(-5)] .51598 .10342 1 0 Mshowa
.52848 .23972 m
.53473 .23972 L
s
[(-2.5)] .51598 .23972 1 0 Mshowa
.52848 .51231 m
.53473 .51231 L
s
[(2.5)] .51598 .51231 1 0 Mshowa
.52848 .6486 m
.53473 .6486 L
s
[(5)] .51598 .6486 1 0 Mshowa
.52848 .7849 m
.53473 .7849 L
s
[(7.5)] .51598 .7849 1 0 Mshowa
.52848 .9212 m
.53473 .9212 L
s
[(10)] .51598 .9212 1 0 Mshowa
.125 Mabswid
.52848 .13068 m
.53223 .13068 L
s
.52848 .15794 m
.53223 .15794 L
s
.52848 .1852 m
.53223 .1852 L
s
.52848 .21246 m
.53223 .21246 L
s
.52848 .26698 m
.53223 .26698 L
s
.52848 .29424 m
.53223 .29424 L
s
.52848 .3215 m
.53223 .3215 L
s
.52848 .34876 m
.53223 .34876 L
s
.52848 .40327 m
.53223 .40327 L
s
.52848 .43053 m
.53223 .43053 L
s
.52848 .45779 m
.53223 .45779 L
s
.52848 .48505 m
.53223 .48505 L
s
.52848 .53957 m
.53223 .53957 L
s
.52848 .56683 m
.53223 .56683 L
s
.52848 .59409 m
.53223 .59409 L
s
.52848 .62135 m
.53223 .62135 L
s
.52848 .67586 m
.53223 .67586 L
s
.52848 .70312 m
.53223 .70312 L
s
.52848 .73038 m
.53223 .73038 L
s
.52848 .75764 m
.53223 .75764 L
s
.52848 .81216 m
.53223 .81216 L
s
.52848 .83942 m
.53223 .83942 L
s
.52848 .86668 m
.53223 .86668 L
s
.52848 .89394 m
.53223 .89394 L
s
.52848 .07616 m
.53223 .07616 L
s
.52848 .04891 m
.53223 .04891 L
s
.52848 .02165 m
.53223 .02165 L
s
.52848 .94845 m
.53223 .94845 L
s
.52848 .97571 m
.53223 .97571 L
s
.25 Mabswid
.52848 0 m
.52848 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.46766 .97619 m
.40881 .95862 L
.34752 .9341 L
.28774 .90302 L
.23649 .86947 L
.18587 .82818 L
.14374 .78533 L
.10259 .73207 L
.07241 .68074 L
.05067 .63095 L
.04212 .60535 L
.03459 .57691 L
.02974 .55255 L
.02765 .53885 L
.02614 .5263 L
.02507 .51466 L
.02461 .50808 L
.02427 .50197 L
.02404 .49611 L
.02389 .4908 L
.02381 .48467 L
.02381 .47891 L
.02391 .47276 L
.02411 .46618 L
.02439 .45999 L
.02473 .45434 L
.02588 .44058 L
.02738 .42761 L
.03157 .40205 L
.03791 .37466 L
.04486 .35137 L
.05369 .32712 L
.07318 .28505 L
.09853 .24304 L
.13094 .20096 L
.20138 .13462 L
.24336 .10552 L
.29249 .07851 L
.3466 .05593 L
.39877 .04024 L
.42511 .03438 L
.43906 .03181 L
.45386 .02949 L
.46683 .02778 L
.48111 .02625 L
.49409 .02519 L
.50622 .02446 L
.51227 .0242 L
.51886 .02399 L
.52508 .02387 L
Mistroke
.53083 .02381 L
.53653 .02381 L
.54169 .02387 L
.54763 .02399 L
.5532 .02416 L
.55931 .02441 L
.56575 .02475 L
.57722 .02555 L
.5895 .02667 L
.60287 .02821 L
.62945 .03228 L
.65414 .03731 L
.69897 .04971 L
.74471 .06718 L
.79088 .09062 L
.82741 .1143 L
.86361 .14365 L
.89647 .17741 L
.92238 .21145 L
.94277 .24615 L
.95186 .2656 L
.95903 .28394 L
.96457 .30114 L
.96866 .31686 L
.97217 .33437 L
.97363 .344 L
.97471 .35308 L
.97512 .35742 L
.97548 .36207 L
.97574 .36608 L
.97595 .37045 L
.97605 .37311 L
.97612 .37556 L
.97619 .3804 L
.97618 .38479 L
.9761 .38944 L
.97595 .39394 L
.97571 .39878 L
.9754 .40334 L
.97506 .40752 L
.97402 .41716 L
.97257 .42724 L
.96941 .44364 L
.9656 .45867 L
.954 .49176 L
.94636 .50837 L
.93692 .5258 L
.91685 .55569 L
.87035 .60459 L
.84293 .62548 L
Mistroke
.8104 .6451 L
.77438 .66161 L
.73932 .67327 L
.72187 .67761 L
.70271 .68133 L
.69392 .68267 L
.68454 .68386 L
.67576 .68475 L
.66769 .68538 L
.66355 .68563 L
.65918 .68584 L
.6548 .68599 L
.65232 .68606 L
.65 .6861 L
.64581 .68614 L
.642 .68614 L
.63761 .68608 L
.63346 .68598 L
.62975 .68584 L
.62582 .68565 L
.61879 .68521 L
.61126 .68458 L
.60302 .68369 L
.58636 .68127 L
.56919 .67787 L
.53957 .6697 L
.50955 .65808 L
.47934 .64229 L
.45369 .62476 L
.43306 .60692 L
.41267 .58444 L
.39698 .56173 L
.38531 .53903 L
.3807 .52733 L
.37661 .51433 L
.37393 .50319 L
.37278 .49704 L
.3719 .4912 L
.37126 .48579 L
.37099 .48293 L
.37076 .4799 L
.3706 .4771 L
.37049 .47456 L
.37042 .47202 L
.37039 .46963 L
.3704 .46682 L
.37046 .46382 L
.37057 .461 L
.3707 .45843 L
.37092 .45543 L
Mistroke
.37121 .45218 L
.3719 .44631 L
.37284 .44021 L
.37409 .43381 L
.37694 .4225 L
.38023 .41239 L
.38389 .40314 L
.3942 .38302 L
.40805 .3632 L
.42364 .34623 L
.4394 .33275 L
.45821 .32006 L
.47977 .30902 L
.50032 .30134 L
.512 .29805 L
.52478 .29528 L
.53069 .29429 L
.53694 .29343 L
.54229 .29285 L
.54533 .29259 L
.54815 .29238 L
.55089 .29222 L
.55391 .29208 L
.55548 .29203 L
.55694 .29199 L
.55849 .29196 L
.56016 .29194 L
.56304 .29194 L
.56449 .29196 L
.56607 .29199 L
.56887 .29207 L
.57146 .29218 L
.57421 .29233 L
.57679 .29251 L
.5816 .29294 L
.58675 .29352 L
.59228 .29431 L
.6038 .29647 L
.61568 .2995 L
.63599 .30671 L
.65367 .31546 L
.67084 .3268 L
.68508 .33913 L
.69626 .35158 L
.70658 .36676 L
.71386 .38166 L
.71702 .39052 L
.71922 .39866 L
.72016 .40321 L
.72096 .40815 L
Mistroke
.72125 .41043 L
.7215 .41284 L
.72168 .41489 L
.72182 .41714 L
.72192 .41942 L
.72196 .42151 L
.72197 .42261 L
.72196 .42382 L
.72195 .42508 L
.72191 .42626 L
.72182 .42842 L
.7217 .4304 L
.72152 .43257 L
.72129 .43485 L
.72076 .43881 L
.72014 .44247 L
.71826 .4507 L
.71548 .45952 L
.7123 .46735 L
.703 .48409 L
.69921 .48944 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 288},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {287, 0}} -> {-8.32907, -6.91143, 0.0548386, \
0.0640115}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", " ", 
  RowBox[{"wheel", ",", " ", "streaklines", ",", " ", 
   RowBox[{"DisplayFunction", " ", "\[Rule]", " ", "$DisplayFunction"}], " ", 
   ",", " ", 
   RowBox[{"AspectRatio", " ", "\[Rule]", " ", "1"}]}], "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.582493 0.0528467 0.530714 0.0632903 [
[.05403 .51821 -9 -9 ]
[.05403 .51821 9 0 ]
[.18614 .51821 -12 -9 ]
[.18614 .51821 12 0 ]
[.31826 .51821 -6 -9 ]
[.31826 .51821 6 0 ]
[.45038 .51821 -12 -9 ]
[.45038 .51821 12 0 ]
[.71461 .51821 -9 -9 ]
[.71461 .51821 9 0 ]
[.84673 .51821 -3 -9 ]
[.84673 .51821 3 0 ]
[.97884 .51821 -9 -9 ]
[.97884 .51821 9 0 ]
[.56999 .02439 -12 -4.5 ]
[.56999 .02439 0 4.5 ]
[.56999 .15097 -12 -4.5 ]
[.56999 .15097 0 4.5 ]
[.56999 .27755 -12 -4.5 ]
[.56999 .27755 0 4.5 ]
[.56999 .40413 -12 -4.5 ]
[.56999 .40413 0 4.5 ]
[.56999 .65729 -6 -4.5 ]
[.56999 .65729 0 4.5 ]
[.56999 .78387 -6 -4.5 ]
[.56999 .78387 0 4.5 ]
[.56999 .91046 -6 -4.5 ]
[.56999 .91046 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05403 .53071 m
.05403 .53696 L
s
[(-10)] .05403 .51821 0 1 Mshowa
.18614 .53071 m
.18614 .53696 L
s
[(-7.5)] .18614 .51821 0 1 Mshowa
.31826 .53071 m
.31826 .53696 L
s
[(-5)] .31826 .51821 0 1 Mshowa
.45038 .53071 m
.45038 .53696 L
s
[(-2.5)] .45038 .51821 0 1 Mshowa
.71461 .53071 m
.71461 .53696 L
s
[(2.5)] .71461 .51821 0 1 Mshowa
.84673 .53071 m
.84673 .53696 L
s
[(5)] .84673 .51821 0 1 Mshowa
.97884 .53071 m
.97884 .53696 L
s
[(7.5)] .97884 .51821 0 1 Mshowa
.125 Mabswid
.08045 .53071 m
.08045 .53446 L
s
.10687 .53071 m
.10687 .53446 L
s
.1333 .53071 m
.1333 .53446 L
s
.15972 .53071 m
.15972 .53446 L
s
.21257 .53071 m
.21257 .53446 L
s
.23899 .53071 m
.23899 .53446 L
s
.26541 .53071 m
.26541 .53446 L
s
.29184 .53071 m
.29184 .53446 L
s
.34468 .53071 m
.34468 .53446 L
s
.37111 .53071 m
.37111 .53446 L
s
.39753 .53071 m
.39753 .53446 L
s
.42395 .53071 m
.42395 .53446 L
s
.4768 .53071 m
.4768 .53446 L
s
.50322 .53071 m
.50322 .53446 L
s
.52965 .53071 m
.52965 .53446 L
s
.55607 .53071 m
.55607 .53446 L
s
.60892 .53071 m
.60892 .53446 L
s
.63534 .53071 m
.63534 .53446 L
s
.66176 .53071 m
.66176 .53446 L
s
.68819 .53071 m
.68819 .53446 L
s
.74103 .53071 m
.74103 .53446 L
s
.76746 .53071 m
.76746 .53446 L
s
.79388 .53071 m
.79388 .53446 L
s
.8203 .53071 m
.8203 .53446 L
s
.87315 .53071 m
.87315 .53446 L
s
.89957 .53071 m
.89957 .53446 L
s
.926 .53071 m
.926 .53446 L
s
.95242 .53071 m
.95242 .53446 L
s
.0276 .53071 m
.0276 .53446 L
s
.00118 .53071 m
.00118 .53446 L
s
.25 Mabswid
0 .53071 m
1 .53071 L
s
.58249 .02439 m
.58874 .02439 L
s
[(-8)] .56999 .02439 1 0 Mshowa
.58249 .15097 m
.58874 .15097 L
s
[(-6)] .56999 .15097 1 0 Mshowa
.58249 .27755 m
.58874 .27755 L
s
[(-4)] .56999 .27755 1 0 Mshowa
.58249 .40413 m
.58874 .40413 L
s
[(-2)] .56999 .40413 1 0 Mshowa
.58249 .65729 m
.58874 .65729 L
s
[(2)] .56999 .65729 1 0 Mshowa
.58249 .78387 m
.58874 .78387 L
s
[(4)] .56999 .78387 1 0 Mshowa
.58249 .91046 m
.58874 .91046 L
s
[(6)] .56999 .91046 1 0 Mshowa
.125 Mabswid
.58249 .05604 m
.58624 .05604 L
s
.58249 .08768 m
.58624 .08768 L
s
.58249 .11933 m
.58624 .11933 L
s
.58249 .18262 m
.58624 .18262 L
s
.58249 .21426 m
.58624 .21426 L
s
.58249 .24591 m
.58624 .24591 L
s
.58249 .3092 m
.58624 .3092 L
s
.58249 .34084 m
.58624 .34084 L
s
.58249 .37249 m
.58624 .37249 L
s
.58249 .43578 m
.58624 .43578 L
s
.58249 .46742 m
.58624 .46742 L
s
.58249 .49907 m
.58624 .49907 L
s
.58249 .56236 m
.58624 .56236 L
s
.58249 .594 m
.58624 .594 L
s
.58249 .62565 m
.58624 .62565 L
s
.58249 .68894 m
.58624 .68894 L
s
.58249 .72058 m
.58624 .72058 L
s
.58249 .75223 m
.58624 .75223 L
s
.58249 .81552 m
.58624 .81552 L
s
.58249 .84717 m
.58624 .84717 L
s
.58249 .87881 m
.58624 .87881 L
s
.58249 .9421 m
.58624 .9421 L
s
.58249 .97375 m
.58624 .97375 L
s
.25 Mabswid
.58249 0 m
.58249 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.63534 .594 m
.63534 .59449 L
.63533 .59494 L
.63533 .59546 L
.63531 .59594 L
.63529 .59681 L
.63525 .59775 L
.63519 .59878 L
.63511 .59988 L
.63493 .60184 L
.6347 .60385 L
.63442 .60573 L
.63363 .60996 L
.63258 .6142 L
.6314 .618 L
.62801 .62616 L
.6243 .63271 L
.61951 .63918 L
.61431 .64453 L
.60819 .64931 L
.605 .65127 L
.60143 .65309 L
.59827 .65441 L
.59472 .65558 L
.59302 .65602 L
.5912 .65643 L
.58961 .65672 L
.58787 .65697 L
.58685 .65708 L
.5859 .65716 L
.585 .65722 L
.58454 .65725 L
.58404 .65727 L
.58358 .65728 L
.58317 .65729 L
.58271 .65729 L
.58248 .65729 L
.58223 .65729 L
.58181 .65729 L
.58135 .65728 L
.58092 .65727 L
.58054 .65725 L
.57973 .65721 L
.57885 .65714 L
.57706 .65696 L
.57542 .65672 L
.57389 .65645 L
.57046 .65563 L
.56683 .65445 L
.5635 .65306 L
Mistroke
.55996 .65125 L
.55384 .64718 L
.54832 .64228 L
.54308 .63617 L
.53851 .62909 L
.53501 .62179 L
.53361 .61806 L
.53236 .61402 L
.53139 .61015 L
.5307 .60657 L
.53014 .60266 L
.52992 .60049 L
.52984 .59949 L
.52978 .59843 L
.52973 .59752 L
.52971 .59704 L
.52969 .59652 L
.52967 .59605 L
.52966 .59562 L
.52966 .5952 L
.52965 .59476 L
.52965 .59428 L
.52965 .59377 L
.52965 .59329 L
.52965 .59286 L
.52966 .59234 L
.52968 .59178 L
.52971 .59077 L
.52976 .58979 L
.52983 .58873 L
.52999 .58683 L
.53024 .58457 L
.53052 .58252 L
.53134 .57812 L
.53235 .57401 L
.53497 .56633 L
.53812 .55964 L
.54197 .55338 L
.54694 .54718 L
.5522 .54215 L
.55842 .53766 L
.56483 .53436 L
.56817 .53308 L
.57008 .53248 L
.5719 .532 L
.57359 .53162 L
.57543 .53128 L
.57711 .53104 L
.57866 .53088 L
.57953 .53081 L
Mistroke
.58035 .53077 L
.58082 .53075 L
.58124 .53073 L
.58148 .53073 L
.58174 .53072 L
.58198 .53072 L
.58221 .53071 L
.58244 .53071 L
.5827 .53071 L
.58294 .53072 L
.58316 .53072 L
.58358 .53073 L
.58402 .53074 L
.5845 .53076 L
.58495 .53078 L
.58596 .53085 L
.58687 .53093 L
.5877 .53102 L
.58959 .53129 L
.59124 .53159 L
.59299 .53198 L
.59599 .53281 L
.59924 .53398 L
.60549 .53702 L
.6118 .54134 L
.61735 .54643 L
.62252 .55268 L
.62667 .55926 L
.62985 .56591 L
.63136 .56992 L
.63258 .57381 L
.63349 .57742 L
.63426 .5813 L
.63473 .58442 L
.63494 .5862 L
.63509 .58788 L
.6352 .58942 L
.63527 .59083 L
.6353 .59161 L
.63531 .59202 L
.63532 .59246 L
.63533 .59288 L
.63534 .59326 L
.63534 .59364 L
.63534 .594 L
Mfstroke
1 .6 0 r
.15237 .92799 m
.13245 .87527 L
.11572 .81582 L
.10932 .78537 L
.10399 .75258 L
.10198 .73662 L
.10041 .72153 L
.09928 .70797 L
.09836 .69326 L
.098 .68546 L
.09783 .68116 L
.0977 .67708 L
.09752 .66917 L
.09743 .66194 L
.09741 .65781 L
.09742 .65341 L
.09751 .6455 L
.0976 .64067 L
.09772 .63612 L
.09803 .62763 L
.09844 .61923 L
.09898 .61038 L
.10022 .5946 L
.10197 .57771 L
.10435 .55932 L
.10934 .52941 L
.11613 .49794 L
.13201 .44302 L
.15326 .38887 L
.18141 .33415 L
.20958 .29087 L
.24432 .24789 L
.27848 .21378 L
.31785 .18225 L
.36169 .15509 L
.38367 .14424 L
.4044 .13553 L
.42584 .12804 L
.44545 .12246 L
.46735 .11764 L
.4794 .1156 L
.49077 .11408 L
.50185 .11297 L
.50743 .11255 L
.51356 .11219 L
.51878 .11198 L
.52438 .11183 L
.52966 .11179 L
.53448 .11182 L
.53738 .11187 L
Mistroke
.54047 .11195 L
.54602 .11216 L
.54941 .11234 L
.5526 .11254 L
.55853 .11299 L
.56942 .1141 L
.58111 .11569 L
.60165 .11952 L
.62051 .12423 L
.64249 .1312 L
.66203 .13883 L
.70039 .15803 L
.73867 .18359 L
.79765 .23942 L
.82571 .27614 L
.84799 .31273 L
.86494 .34754 L
.87974 .38644 L
.88659 .40921 L
.89181 .43028 L
.89584 .4504 L
.89914 .47194 L
.90044 .48304 L
.90143 .4935 L
.9021 .50288 L
.90238 .50771 L
.90262 .51301 L
.90279 .51798 L
.90291 .52262 L
.90298 .52751 L
.90299 .53274 L
.90295 .53759 L
.90287 .54219 L
.90276 .5463 L
.90259 .55077 L
.90234 .556 L
.90205 .56089 L
.9012 .57201 L
.90011 .58275 L
.89865 .59424 L
.89529 .61469 L
.89141 .63307 L
.88112 .66947 L
.86891 .70148 L
.85283 .7342 L
.83287 .76605 L
.81144 .7932 L
.78603 .81873 L
.76038 .83888 L
.73565 .85396 L
Mistroke
.71021 .86562 L
.69784 .86999 L
.68605 .87342 L
.6794 .87503 L
.67215 .87654 L
.6655 .87768 L
.65947 .87853 L
.65233 .87931 L
.64842 .87962 L
.64474 .87985 L
.64134 .88 L
.63821 .88009 L
.63479 .88013 L
.63308 .88013 L
.63119 .88011 L
.62778 .88003 L
.62463 .8799 L
.62118 .87971 L
.61754 .87944 L
.61146 .87883 L
.60481 .87795 L
.59271 .87575 L
.58158 .87302 L
.55761 .86469 L
.54476 .85873 L
.53342 .85252 L
.49605 .82433 L
.47801 .8051 L
.46346 .78554 L
.45052 .76352 L
.44065 .7418 L
.43375 .7218 L
.4307 .71049 L
.42836 .69989 L
.42655 .68953 L
.42514 .67846 L
.42457 .67218 L
.42435 .66911 L
.42419 .66626 L
.42407 .6637 L
.42398 .66098 L
.42394 .65943 L
.42391 .65797 L
.42388 .65526 L
.42389 .65257 L
.4239 .65105 L
.42393 .64963 L
.424 .64679 L
.42406 .6452 L
.42412 .64376 L
Mistroke
.42444 .6384 L
.42485 .63339 L
.42546 .62766 L
.42615 .62243 L
.42816 .61086 L
.43024 .60168 L
.43289 .59212 L
.43871 .57575 L
.44718 .55799 L
.4562 .54352 L
.4655 .53168 L
.47617 .52086 L
.48852 .51122 L
.50036 .50438 L
.50677 .50153 L
.51267 .49942 L
.51912 .49765 L
.52235 .49697 L
.52587 .49639 L
.52745 .49618 L
.52895 .49602 L
.5303 .49589 L
.53173 .49579 L
.53246 .49575 L
.53327 .49571 L
.53469 .49566 L
.53549 .49565 L
.53634 .49564 L
.53715 .49564 L
.53788 .49565 L
.5392 .49569 L
.54042 .49575 L
.54175 .49584 L
.54316 .49596 L
.54602 .49629 L
.54858 .49669 L
.55366 .49778 L
.55885 .49933 L
.5631 .50095 L
.56757 .50303 L
.57669 .50872 L
.58409 .51514 L
.59049 .52267 L
.59533 .53042 L
.59861 .5377 L
.60003 .54188 L
.60105 .54578 L
.60148 .54785 L
.60186 .55003 L
.60202 .55116 L
Mistroke
.60217 .5524 L
.60228 .55354 L
.60237 .55457 L
.60243 .55561 L
.60248 .5566 L
.6025 .55763 L
.60251 .55821 L
.60251 .55875 L
.6025 .55963 L
.60247 .5606 L
.60242 .56161 L
.60236 .56255 L
.6022 .56431 L
.60196 .56614 L
.60138 .56932 L
.60054 .5726 L
.59937 .576 L
.59788 .57934 L
.59624 .58226 L
.59264 .58702 L
.59035 .58927 L
.58809 .59104 L
.58547 .59266 L
.58256 .59398 L
.58056 .59463 L
.57959 .59487 L
.57869 .59505 L
.57765 .59522 L
.5771 .59529 L
.57651 .59534 L
.576 .59538 L
.57552 .5954 L
.57499 .59542 L
.57442 .59542 L
.57393 .59541 L
.57348 .59539 L
.57297 .59536 L
.57244 .59532 L
.57188 .59526 L
.57135 .59519 L
.57035 .59502 L
.56856 .59461 L
.56664 .594 L
Mfstroke
.8 1 0 r
.1435 .93487 m
.12308 .88112 L
.10589 .82049 L
.0993 .78942 L
.09381 .75595 L
.09172 .73967 L
.09009 .72426 L
.08891 .71042 L
.08794 .6954 L
.08756 .68743 L
.08738 .68304 L
.08724 .67887 L
.08704 .67079 L
.08693 .66341 L
.08691 .65919 L
.08691 .6547 L
.08698 .64662 L
.08707 .64168 L
.08718 .63703 L
.08748 .62836 L
.08788 .61978 L
.08841 .61074 L
.08965 .59461 L
.0914 .57736 L
.0938 .55856 L
.09884 .52798 L
.10571 .4958 L
.12183 .43961 L
.14344 .38418 L
.17211 .32813 L
.20083 .28377 L
.23628 .23966 L
.27117 .20464 L
.3114 .17222 L
.35624 .14425 L
.37872 .13305 L
.39995 .12406 L
.42189 .11629 L
.44198 .1105 L
.46441 .10548 L
.47676 .10334 L
.48842 .10174 L
.49977 .10056 L
.50549 .10011 L
.51178 .09972 L
.51713 .09947 L
.52287 .09931 L
.52829 .09924 L
.53323 .09925 L
.53621 .09929 L
Mistroke
.53937 .09936 L
.54506 .09956 L
.54854 .09973 L
.55181 .09992 L
.55791 .10036 L
.56908 .10145 L
.58108 .10304 L
.60216 .10688 L
.62153 .11163 L
.64411 .1187 L
.6642 .12644 L
.70364 .14598 L
.74306 .17207 L
.80386 .22918 L
.83285 .26681 L
.8559 .30434 L
.87348 .34008 L
.88887 .38006 L
.89602 .40348 L
.90148 .42516 L
.90571 .44588 L
.9092 .46806 L
.91059 .4795 L
.91165 .49028 L
.91239 .49995 L
.91269 .50493 L
.91296 .51039 L
.91316 .51552 L
.9133 .5203 L
.91339 .52534 L
.91343 .53075 L
.91341 .53575 L
.91334 .54049 L
.91324 .54474 L
.91309 .54935 L
.91286 .55475 L
.91258 .5598 L
.91175 .57128 L
.91067 .58238 L
.90922 .59425 L
.90585 .61539 L
.90192 .6344 L
.89146 .67208 L
.87899 .70527 L
.86253 .73923 L
.84204 .77235 L
.81999 .80064 L
.7938 .82731 L
.76732 .84843 L
.74175 .8643 L
Mistroke
.7154 .87665 L
.69033 .88499 L
.67591 .88837 L
.66273 .89058 L
.65547 .89144 L
.65138 .89181 L
.64758 .89209 L
.64394 .89229 L
.64065 .89242 L
.63883 .89246 L
.63686 .8925 L
.6333 .89251 L
.62992 .89247 L
.62684 .89238 L
.6233 .89223 L
.61995 .89202 L
.61404 .89153 L
.60766 .8908 L
.6007 .88978 L
.59338 .88844 L
.58045 .88538 L
.56743 .88139 L
.55554 .8769 L
.52977 .86411 L
.50857 .84997 L
.48827 .83263 L
.45766 .79645 L
.44492 .77576 L
.43371 .75259 L
.42544 .73005 L
.41986 .70927 L
.41755 .6977 L
.41653 .69138 L
.41572 .68548 L
.4151 .68004 L
.41463 .6751 L
.41424 .66962 L
.41407 .66662 L
.41395 .66377 L
.41386 .66071 L
.4138 .65794 L
.41379 .65641 L
.41378 .65476 L
.4138 .65178 L
.41385 .64898 L
.41393 .64605 L
.41403 .64355 L
.41417 .64083 L
.4146 .63472 L
.41523 .62824 L
Mistroke
.4168 .6168 L
.41894 .6055 L
.42138 .59538 L
.42845 .57377 L
.43629 .55634 L
.44603 .53972 L
.45593 .52642 L
.46749 .5141 L
.47905 .50443 L
.48999 .49727 L
.49605 .49405 L
.50254 .49114 L
.50815 .48907 L
.51421 .48726 L
.51792 .48639 L
.5213 .48573 L
.52452 .48523 L
.52616 .48503 L
.5279 .48484 L
.52948 .48471 L
.53091 .48462 L
.53234 .48455 L
.53369 .48451 L
.53525 .48449 L
.53669 .4845 L
.53826 .48454 L
.53905 .48457 L
.53992 .48461 L
.54136 .48471 L
.5427 .48482 L
.54571 .48515 L
.54859 .48559 L
.55163 .48618 L
.55699 .48753 L
.56169 .48908 L
.56696 .49125 L
.57238 .49402 L
.58138 .50003 L
.58872 .50662 L
.59553 .51475 L
.59843 .5191 L
.60115 .52392 L
.60332 .52854 L
.605 .53289 L
.60647 .53763 L
.60749 .54192 L
.60794 .54437 L
.60827 .54666 L
.60853 .54906 L
.60863 .5504 L
Mistroke
.60867 .55105 L
.6087 .55163 L
.60874 .55264 L
.60877 .5537 L
.60877 .55469 L
.60876 .55562 L
.60873 .55669 L
.60869 .55767 L
.60862 .55874 L
.60853 .55987 L
.60831 .56192 L
.60803 .56381 L
.60716 .56798 L
.60617 .57142 L
.60482 .57496 L
.60328 .57818 L
.6014 .58134 L
.59943 .58403 L
.59748 .58622 L
.59551 .58807 L
.59332 .58977 L
.59154 .59091 L
.58951 .59198 L
.58761 .59277 L
.58583 .59334 L
.58482 .5936 L
.58371 .59382 L
.58309 .59392 L
.58253 .594 L
.58195 .59406 L
.5814 .59411 L
.58094 .59414 L
.58044 .59415 L
.57988 .59416 L
.57937 .59416 L
.57887 .59414 L
.57832 .59411 L
.57774 .59406 L
.57721 .594 L
Mfstroke
.2 1 0 r
.13464 .94176 m
.11371 .88698 L
.09607 .82516 L
.08929 .79347 L
.08362 .75933 L
.08146 .74271 L
.07977 .72699 L
.07846 .71178 L
.07753 .69754 L
.07714 .68998 L
.07682 .68186 L
.07668 .67725 L
.07657 .67286 L
.07643 .66463 L
.0764 .66045 L
.07639 .656 L
.07645 .64801 L
.07652 .64311 L
.07663 .63851 L
.0769 .62992 L
.07722 .62238 L
.07764 .61443 L
.07862 .60024 L
.07998 .58504 L
.08184 .56845 L
.08692 .53441 L
.09414 .49861 L
.11165 .4362 L
.13362 .37949 L
.16282 .32211 L
.19209 .27666 L
.22825 .23144 L
.26386 .1955 L
.30496 .16218 L
.35079 .13341 L
.37378 .12186 L
.39549 .11258 L
.41794 .10455 L
.43851 .09855 L
.46147 .09332 L
.47411 .09109 L
.48606 .0894 L
.49769 .08815 L
.50355 .08766 L
.50999 .08724 L
.51548 .08697 L
.52136 .08678 L
.52691 .08669 L
.53197 .08668 L
.53503 .08671 L
Mistroke
.53828 .08677 L
.54411 .08695 L
.54768 .08711 L
.55103 .0873 L
.55728 .08772 L
.56873 .0888 L
.58104 .09038 L
.60268 .09424 L
.62255 .09903 L
.64396 .10558 L
.66636 .11405 L
.71018 .13583 L
.74744 .16055 L
.81007 .21894 L
.84 .25747 L
.86382 .29596 L
.88202 .33263 L
.898 .37368 L
.90544 .39775 L
.91115 .42004 L
.91558 .44135 L
.91926 .46418 L
.92074 .47596 L
.92187 .48706 L
.92267 .49701 L
.923 .50214 L
.9233 .50778 L
.92353 .51306 L
.92369 .51799 L
.9238 .52318 L
.92387 .52875 L
.92387 .53391 L
.92382 .5388 L
.92373 .54318 L
.9236 .54793 L
.92338 .5535 L
.92311 .55871 L
.9223 .57055 L
.92124 .582 L
.91979 .59426 L
.9164 .61608 L
.91243 .63573 L
.9018 .6747 L
.88908 .70905 L
.87223 .74426 L
.8512 .77865 L
.82854 .80808 L
.80157 .83589 L
.77426 .85798 L
.74784 .87464 L
Mistroke
.72058 .88768 L
.69462 .89656 L
.67966 .9002 L
.66599 .90262 L
.65845 .90358 L
.65448 .90398 L
.65026 .90433 L
.64621 .90459 L
.64254 .90476 L
.63887 .90487 L
.63542 .90491 L
.63212 .90491 L
.62859 .90484 L
.62528 .90473 L
.62226 .90458 L
.61874 .90436 L
.61492 .90404 L
.60801 .90331 L
.60085 .9023 L
.59331 .90098 L
.57999 .89794 L
.55712 .89056 L
.53318 .87964 L
.50991 .86538 L
.4903 .85001 L
.46966 .82963 L
.45283 .80867 L
.43857 .78644 L
.4277 .76523 L
.418 .74085 L
.41397 .72798 L
.41043 .71427 L
.40797 .70237 L
.40689 .69607 L
.40591 .6893 L
.40517 .68311 L
.40462 .67747 L
.40419 .67182 L
.40402 .66907 L
.40389 .66648 L
.40377 .66325 L
.40369 .66034 L
.40365 .65722 L
.40364 .65546 L
.40364 .65385 L
.40366 .65116 L
.40372 .64821 L
.40382 .64515 L
.40394 .64231 L
.40413 .63895 L
Mistroke
.40435 .63578 L
.40486 .6299 L
.40556 .62363 L
.4065 .61692 L
.40845 .60593 L
.4107 .5959 L
.41729 .57417 L
.42549 .55466 L
.436 .53573 L
.44708 .52027 L
.46033 .50581 L
.4737 .49457 L
.48659 .48627 L
.49346 .48274 L
.50094 .47956 L
.50753 .47729 L
.51448 .47545 L
.5207 .47425 L
.52421 .47376 L
.52588 .47358 L
.52746 .47344 L
.52888 .47333 L
.53043 .47324 L
.53182 .47318 L
.53311 .47315 L
.53449 .47314 L
.53601 .47314 L
.53759 .47318 L
.53907 .47324 L
.54057 .47333 L
.54216 .47346 L
.545 .47375 L
.54833 .47422 L
.55131 .47476 L
.55765 .47629 L
.56341 .47816 L
.57299 .48241 L
.58244 .48822 L
.59068 .49499 L
.59846 .50342 L
.60506 .51304 L
.60979 .52253 L
.61159 .52726 L
.61317 .53245 L
.61431 .53734 L
.61472 .53967 L
.61505 .54184 L
.6153 .54397 L
.6154 .54508 L
.61549 .54625 L
Mistroke
.61556 .54723 L
.61561 .5483 L
.61564 .54927 L
.61566 .55016 L
.61566 .55129 L
.61565 .55235 L
.61562 .55329 L
.61558 .55431 L
.61552 .55541 L
.61543 .55657 L
.61522 .55862 L
.61495 .56065 L
.61459 .56274 L
.61378 .56636 L
.61267 .57006 L
.61121 .57388 L
.60973 .57697 L
.60795 .58002 L
.60431 .58483 L
.60061 .58837 L
.59838 .59001 L
.59625 .59128 L
.59417 .59228 L
.59219 .59302 L
.5901 .5936 L
.58898 .59383 L
.58778 .594 L
Mfstroke
0 1 .4 r
.12577 .94865 m
.10434 .89284 L
.08625 .82982 L
.07928 .79752 L
.07343 .76271 L
.0712 .74576 L
.06945 .72972 L
.06809 .7142 L
.06711 .69967 L
.0667 .69197 L
.06636 .68368 L
.0662 .67897 L
.06609 .67449 L
.06593 .6661 L
.06589 .66183 L
.06588 .65729 L
.06592 .64913 L
.06599 .64414 L
.06609 .63944 L
.0662 .63522 L
.06635 .63067 L
.06666 .62303 L
.06709 .61466 L
.06825 .59783 L
.06967 .58232 L
.07128 .56791 L
.07647 .53276 L
.08266 .50125 L
.10147 .43279 L
.12317 .37623 L
.14732 .32713 L
.18002 .27427 L
.21468 .22953 L
.28753 .16034 L
.32976 .1315 L
.37727 .10685 L
.42102 .09059 L
.44612 .08383 L
.46959 .07914 L
.48239 .07723 L
.49447 .07585 L
.50531 .07495 L
.51141 .07458 L
.51704 .07434 L
.52308 .07417 L
.52872 .07411 L
.53195 .07411 L
.5349 .07414 L
.5383 .0742 L
.54152 .07429 L
Mistroke
.54463 .0744 L
.54793 .07455 L
.55385 .07489 L
.56088 .07543 L
.56722 .07603 L
.57784 .07728 L
.5894 .07902 L
.61247 .08364 L
.63349 .08924 L
.65274 .09557 L
.69473 .11366 L
.73703 .13853 L
.77412 .16689 L
.8107 .20246 L
.83891 .2367 L
.86605 .27764 L
.88818 .31993 L
.90507 .36139 L
.91877 .40653 L
.92458 .4323 L
.9287 .45603 L
.93148 .47774 L
.93262 .48989 L
.93341 .50089 L
.93368 .50589 L
.93392 .51117 L
.93412 .51695 L
.93424 .52227 L
.93431 .52721 L
.93433 .53183 L
.9343 .53688 L
.93421 .5423 L
.93413 .54531 L
.93403 .54852 L
.93381 .55426 L
.93349 .56042 L
.93305 .5672 L
.93204 .57925 L
.93082 .59049 L
.9279 .61118 L
.9238 .6331 L
.91361 .67261 L
.89888 .71352 L
.87985 .75313 L
.85912 .78678 L
.83503 .81792 L
.81015 .84372 L
.78654 .86357 L
.7593 .88189 L
.73119 .89638 L
Mistroke
.71659 .90231 L
.70077 .90758 L
.68593 .91147 L
.67235 .91416 L
.66583 .91516 L
.65872 .91603 L
.65548 .91636 L
.65202 .91665 L
.64881 .91688 L
.64582 .91705 L
.64215 .91721 L
.6402 .91726 L
.63812 .91731 L
.63594 .91733 L
.63388 .91734 L
.63003 .9173 L
.62643 .9172 L
.62312 .91706 L
.61949 .91685 L
.61565 .91656 L
.60778 .91576 L
.60045 .91476 L
.58399 .91159 L
.57001 .90787 L
.5575 .9037 L
.53049 .89174 L
.50685 .87755 L
.48654 .86201 L
.46508 .84135 L
.44723 .81973 L
.43216 .79696 L
.41858 .77087 L
.40878 .74625 L
.4019 .7231 L
.39912 .71086 L
.39675 .69771 L
.39584 .69135 L
.39511 .68532 L
.39453 .6794 L
.3941 .67406 L
.39391 .67097 L
.39374 .66764 L
.39366 .66581 L
.3936 .66413 L
.39351 .66084 L
.39346 .65801 L
.39345 .65492 L
.39347 .65171 L
.39352 .64872 L
.39357 .64703 L
Mistroke
.39363 .64519 L
.39377 .64186 L
.39415 .63566 L
.39477 .6285 L
.3955 .62196 L
.39716 .61076 L
.39946 .59899 L
.4049 .57859 L
.41336 .55602 L
.42278 .53716 L
.44464 .50634 L
.45867 .49235 L
.47244 .4817 L
.4875 .47292 L
.49499 .46955 L
.50191 .46698 L
.50807 .46512 L
.51482 .46354 L
.5183 .46291 L
.52154 .46244 L
.52494 .46205 L
.52684 .46189 L
.52856 .46178 L
.53021 .46169 L
.53175 .46164 L
.53343 .46162 L
.53524 .46162 L
.53702 .46166 L
.53792 .46169 L
.53889 .46174 L
.54061 .46184 L
.5422 .46197 L
.54531 .46229 L
.54811 .46268 L
.55427 .46384 L
.56071 .46554 L
.56744 .4679 L
.57885 .47339 L
.58852 .47983 L
.59789 .48811 L
.60616 .49783 L
.61242 .50764 L
.61495 .51261 L
.61732 .51812 L
.61906 .52301 L
.62057 .52824 L
.62171 .53339 L
.62245 .53803 L
.6227 .54024 L
.62281 .5414 L
Mistroke
.6229 .54262 L
.62297 .54368 L
.62303 .54485 L
.62307 .5459 L
.62309 .54687 L
.6231 .5481 L
.62309 .54871 L
.62308 .54939 L
.62305 .55058 L
.62301 .55169 L
.62293 .55298 L
.62284 .55415 L
.62257 .55676 L
.62228 .55884 L
.6219 .56107 L
.62091 .56542 L
.61978 .5692 L
.61833 .57302 L
.61517 .57923 L
.6116 .58429 L
.60953 .5866 L
.60722 .58876 L
.60511 .59041 L
.60271 .59197 L
.59835 .594 L
Mfstroke
0 1 1 r
.1169 .95553 m
.09497 .89869 L
.07642 .83449 L
.06926 .80157 L
.06325 .76608 L
.06094 .7488 L
.05913 .73245 L
.05771 .71663 L
.05669 .70181 L
.05627 .69395 L
.0559 .6855 L
.05573 .68069 L
.0556 .67613 L
.05544 .66756 L
.05539 .66321 L
.05536 .65858 L
.05539 .65025 L
.05545 .64516 L
.05555 .64037 L
.05565 .63607 L
.0558 .63142 L
.0561 .62362 L
.05653 .61509 L
.05768 .59791 L
.0591 .58207 L
.06072 .56737 L
.06595 .53148 L
.07221 .49931 L
.09129 .42938 L
.11335 .37157 L
.13791 .32136 L
.17121 .26727 L
.20654 .22146 L
.28085 .15053 L
.32397 .12091 L
.37251 .09555 L
.41723 .07877 L
.4429 .07178 L
.4669 .0669 L
.48 .0649 L
.49236 .06344 L
.50345 .06249 L
.5097 .06209 L
.51546 .06182 L
.52164 .06163 L
.52742 .06155 L
.53072 .06154 L
.53374 .06156 L
.53723 .06161 L
.54053 .06169 L
Mistroke
.54371 .06179 L
.54709 .06193 L
.55315 .06226 L
.56035 .06278 L
.56685 .06338 L
.57772 .06463 L
.58957 .06636 L
.61322 .07102 L
.63476 .07667 L
.6545 .08309 L
.69758 .10147 L
.74101 .1268 L
.77912 .15574 L
.81675 .19208 L
.84579 .2271 L
.87378 .26901 L
.89525 .30937 L
.91413 .35487 L
.92263 .38064 L
.9292 .40456 L
.93437 .42746 L
.93873 .45203 L
.94049 .46448 L
.94186 .47622 L
.94295 .48764 L
.94372 .49815 L
.94427 .50814 L
.94446 .51316 L
.94463 .51867 L
.94473 .52419 L
.94478 .53011 L
.94477 .53568 L
.9447 .54076 L
.94456 .54669 L
.94446 .54968 L
.94433 .55298 L
.94374 .56424 L
.9433 .57054 L
.94274 .57731 L
.9415 .58949 L
.93824 .61307 L
.93432 .63431 L
.92368 .67604 L
.91074 .71295 L
.89341 .75091 L
.8716 .78817 L
.84794 .82021 L
.81962 .85069 L
.7933 .8732 L
.7628 .89372 L
Mistroke
.73206 .90927 L
.70266 .91985 L
.68632 .92406 L
.67136 .92688 L
.66312 .92803 L
.65877 .92852 L
.65414 .92895 L
.6497 .92928 L
.64568 .92951 L
.64166 .92967 L
.63787 .92975 L
.63432 .92978 L
.63053 .92974 L
.62696 .92966 L
.62372 .92953 L
.61992 .92933 L
.6158 .92903 L
.60836 .92831 L
.60064 .92731 L
.5925 .92597 L
.57811 .92285 L
.56521 .91922 L
.55336 .91516 L
.52739 .90366 L
.5027 .88897 L
.47879 .87058 L
.44208 .83135 L
.42642 .80853 L
.41232 .78271 L
.40155 .75733 L
.39394 .73372 L
.3906 .72047 L
.38775 .70642 L
.38588 .69442 L
.38504 .68766 L
.3844 .68127 L
.3841 .67774 L
.38383 .67391 L
.38362 .67039 L
.38347 .66722 L
.38334 .66345 L
.38329 .66139 L
.38326 .65945 L
.38323 .656 L
.38323 .65407 L
.38324 .65229 L
.3833 .64908 L
.38338 .6461 L
.3835 .64283 L
.38367 .63935 L
Mistroke
.38416 .6323 L
.38475 .62594 L
.38633 .61363 L
.38857 .60087 L
.39401 .57888 L
.40174 .55668 L
.41227 .53426 L
.42373 .51552 L
.43539 .50031 L
.45016 .48501 L
.46472 .47326 L
.47851 .46464 L
.49349 .45767 L
.50209 .4547 L
.51018 .45258 L
.51739 .45121 L
.52143 .45066 L
.52512 .4503 L
.52701 .45016 L
.52879 .45006 L
.53038 .45 L
.53211 .44996 L
.53398 .44995 L
.53492 .44996 L
.53595 .44998 L
.53778 .45004 L
.53948 .45013 L
.54108 .45023 L
.54276 .45037 L
.54575 .45069 L
.54892 .45113 L
.55236 .45173 L
.5594 .45335 L
.56667 .45562 L
.57899 .46101 L
.59049 .46812 L
.60149 .47732 L
.61034 .48718 L
.61712 .49701 L
.62256 .50736 L
.62642 .51728 L
.62809 .523 L
.62928 .52822 L
.6298 .53108 L
.63026 .53418 L
.63059 .53709 L
.63081 .53976 L
.63089 .54113 L
.63092 .54187 L
.63095 .54256 L
Mistroke
.63098 .54378 L
.631 .54511 L
.631 .54585 L
.63099 .54655 L
.63096 .54785 L
.63094 .54857 L
.63091 .54924 L
.63083 .55073 L
.63074 .55192 L
.63065 .55303 L
.63037 .55551 L
.63003 .55789 L
.62959 .5604 L
.6286 .56472 L
.62731 .56904 L
.62441 .57614 L
.62115 .58188 L
.61714 .58711 L
.61296 .59114 L
.60892 .594 L
Mfstroke
0 .4 1 r
.10803 .96242 m
.0856 .90455 L
.0666 .83916 L
.05925 .80562 L
.05306 .76946 L
.05068 .75185 L
.04881 .73518 L
.04734 .71905 L
.04627 .70394 L
.04579 .69526 L
.04544 .68732 L
.04514 .6785 L
.04502 .67364 L
.04494 .66903 L
.04488 .66459 L
.04485 .65987 L
.04486 .65138 L
.04492 .64618 L
.045 .64129 L
.04511 .63691 L
.04524 .63217 L
.04554 .62422 L
.04596 .61551 L
.04711 .59798 L
.04853 .58183 L
.05017 .56683 L
.05544 .53021 L
.06177 .49737 L
.08111 .42597 L
.10352 .36691 L
.1285 .31559 L
.1624 .26028 L
.1984 .21339 L
.27418 .14072 L
.31819 .11031 L
.36775 .08425 L
.41344 .06696 L
.43968 .05972 L
.46422 .05466 L
.47761 .05257 L
.49025 .05104 L
.5016 .05002 L
.50799 .0496 L
.51388 .04931 L
.52021 .04909 L
.52612 .04899 L
.5295 .04897 L
.53259 .04897 L
.53615 .04902 L
.53953 .04909 L
Mistroke
.54279 .04918 L
.54625 .04931 L
.55246 .04963 L
.55983 .05014 L
.56648 .05073 L
.57761 .05197 L
.58974 .05371 L
.61396 .05839 L
.63603 .06411 L
.65625 .07061 L
.70042 .08928 L
.74499 .11508 L
.78412 .14459 L
.8228 .1817 L
.85268 .2175 L
.88151 .26039 L
.90366 .30171 L
.92318 .34834 L
.93199 .37477 L
.93882 .3993 L
.9442 .4228 L
.94876 .44804 L
.9506 .46082 L
.95206 .47288 L
.95321 .48462 L
.95404 .49542 L
.95463 .50567 L
.95485 .51084 L
.95504 .5165 L
.95517 .52218 L
.95524 .52826 L
.95524 .53399 L
.95519 .53921 L
.95506 .54532 L
.95497 .54839 L
.95485 .55179 L
.95428 .56337 L
.95385 .56985 L
.9533 .57682 L
.95207 .58936 L
.9488 .61363 L
.94484 .63551 L
.93405 .67853 L
.92085 .71662 L
.90315 .75583 L
.88082 .79436 L
.85655 .82755 L
.82746 .85917 L
.80039 .88259 L
.76898 .90399 L
Mistroke
.73728 .92027 L
.70693 .93143 L
.69004 .9359 L
.67458 .93894 L
.66605 .94019 L
.66155 .94073 L
.65676 .94122 L
.65217 .94159 L
.64801 .94186 L
.64384 .94205 L
.63992 .94217 L
.63624 .94222 L
.63232 .94222 L
.62862 .94216 L
.62525 .94205 L
.62132 .94187 L
.61705 .9416 L
.60934 .94092 L
.60132 .93994 L
.59289 .93862 L
.57794 .9355 L
.56454 .93185 L
.55222 .92774 L
.52519 .91604 L
.49944 .90102 L
.47446 .88213 L
.43597 .84168 L
.41948 .81808 L
.40456 .79131 L
.39311 .76495 L
.38495 .74038 L
.38134 .72658 L
.37823 .71191 L
.37615 .69938 L
.37448 .68564 L
.37381 .67794 L
.37337 .67094 L
.3732 .66708 L
.37312 .6649 L
.37307 .66289 L
.373 .65921 L
.37298 .65715 L
.37298 .6553 L
.373 .65168 L
.37306 .64836 L
.37317 .64474 L
.37333 .64093 L
.37371 .63456 L
.37428 .62763 L
.375 .62083 L
Mistroke
.37596 .61353 L
.37815 .60049 L
.38376 .57699 L
.38776 .56426 L
.39261 .55129 L
.40276 .52949 L
.41378 .51096 L
.42702 .4932 L
.44052 .47872 L
.45379 .46723 L
.46965 .45642 L
.47893 .45137 L
.48743 .44751 L
.49502 .44465 L
.50325 .44215 L
.50776 .44104 L
.5119 .44018 L
.51614 .43946 L
.51999 .43894 L
.52183 .43874 L
.52384 .43856 L
.52556 .43843 L
.52746 .43832 L
.52946 .43823 L
.53055 .4382 L
.53158 .43818 L
.5334 .43817 L
.53536 .4382 L
.53707 .43824 L
.53893 .43833 L
.54087 .43845 L
.54266 .43859 L
.54585 .43892 L
.54922 .43937 L
.55319 .44005 L
.55742 .44094 L
.56491 .44298 L
.57195 .44545 L
.5782 .44814 L
.59023 .4548 L
.60043 .46226 L
.61035 .47159 L
.61943 .4827 L
.62647 .49398 L
.62956 .50014 L
.63237 .50679 L
.63462 .51324 L
.63626 .5191 L
.63755 .52496 L
.63804 .5278 L
Mistroke
.63843 .53044 L
.63877 .53326 L
.639 .53581 L
.6391 .53726 L
.63918 .53863 L
.63924 .54006 L
.63926 .54087 L
.63928 .54161 L
.63929 .54298 L
.63929 .54426 L
.63926 .54565 L
.63924 .54643 L
.63921 .54715 L
.63914 .54849 L
.63905 .54995 L
.63879 .55285 L
.63848 .55539 L
.63814 .55765 L
.63716 .56258 L
.63602 .56695 L
.63474 .57088 L
.63169 .57805 L
.62779 .58471 L
.62402 .58957 L
.61949 .594 L
Mfstroke
.2 0 1 r
.09916 .9693 m
.07623 .9104 L
.05677 .84383 L
.04924 .80967 L
.04287 .77283 L
.04042 .75489 L
.03849 .73791 L
.03697 .72148 L
.03585 .70608 L
.03535 .69723 L
.03498 .68913 L
.03466 .68015 L
.03453 .6752 L
.03444 .67049 L
.03438 .66597 L
.03434 .66116 L
.03434 .6525 L
.03439 .6472 L
.03446 .64222 L
.03456 .63775 L
.03469 .63292 L
.03498 .62481 L
.0354 .61593 L
.03654 .59806 L
.03797 .58159 L
.03961 .5663 L
.04492 .52894 L
.05132 .49543 L
.07094 .42256 L
.09369 .36225 L
.11909 .30982 L
.15359 .25328 L
.19025 .20532 L
.2675 .1309 L
.3124 .09972 L
.36299 .07295 L
.40965 .05514 L
.43646 .04767 L
.46153 .04241 L
.47522 .04024 L
.48815 .03864 L
.49975 .03756 L
.50629 .03711 L
.51231 .03679 L
.51877 .03655 L
.52482 .03642 L
.52828 .03639 L
.53144 .03639 L
.53508 .03642 L
.53854 .03648 L
Mistroke
.54187 .03657 L
.54541 .0367 L
.55176 .037 L
.5593 .0375 L
.56611 .03808 L
.57749 .03931 L
.58991 .04105 L
.6147 .04576 L
.6373 .05154 L
.65801 .05812 L
.70327 .07709 L
.74897 .10335 L
.78913 .13344 L
.82885 .17132 L
.85957 .2079 L
.88925 .25176 L
.91208 .29405 L
.93224 .34181 L
.94135 .36889 L
.94843 .39405 L
.95403 .41815 L
.95879 .44404 L
.96072 .45716 L
.96225 .46953 L
.96347 .48159 L
.96436 .49268 L
.965 .50321 L
.96525 .50852 L
.96546 .51434 L
.9656 .52017 L
.96569 .52642 L
.96572 .53231 L
.96568 .53767 L
.96557 .54394 L
.96549 .54711 L
.96538 .55059 L
.96513 .55674 L
.96483 .5625 L
.96394 .5754 L
.96263 .58923 L
.95936 .6142 L
.95536 .63672 L
.94441 .68102 L
.93097 .72028 L
.91289 .76075 L
.89004 .80055 L
.86516 .83489 L
.8353 .86766 L
.80748 .89198 L
.77516 .91426 L
Mistroke
.7425 .93128 L
.7112 .94301 L
.69377 .94775 L
.6778 .951 L
.66899 .95235 L
.66433 .95294 L
.65938 .95348 L
.65463 .9539 L
.65034 .9542 L
.64602 .95444 L
.64197 .95459 L
.63817 .95467 L
.6341 .9547 L
.63027 .95466 L
.62679 .95458 L
.62272 .95442 L
.62042 .9543 L
.6183 .95417 L
.61031 .95352 L
.60271 .95266 L
.59439 .95145 L
.57777 .94816 L
.5637 .94443 L
.54886 .93953 L
.52299 .92842 L
.49687 .91351 L
.47048 .89396 L
.44561 .87037 L
.42518 .84591 L
.40692 .81847 L
.39252 .79102 L
.38199 .76543 L
.3771 .75081 L
.37318 .73702 L
.36971 .72232 L
.36716 .70886 L
.365 .69391 L
.36412 .68569 L
.36348 .67791 L
.36323 .67406 L
.36304 .67044 L
.36296 .66844 L
.36288 .66628 L
.36277 .66252 L
.36271 .65892 L
.3627 .65514 L
.36272 .65192 L
.36278 .6484 L
.36284 .64626 L
.3629 .64424 L
Mistroke
.36306 .64048 L
.36328 .63644 L
.36358 .63207 L
.36427 .62427 L
.36508 .61714 L
.36698 .60427 L
.3696 .59073 L
.37582 .56719 L
.38549 .541 L
.3963 .51901 L
.4215 .48266 L
.43778 .46591 L
.45384 .45297 L
.47152 .44206 L
.48036 .43777 L
.48854 .43444 L
.49587 .43195 L
.5039 .42975 L
.51195 .42809 L
.51633 .42741 L
.52039 .42693 L
.52252 .42673 L
.52477 .42656 L
.52669 .42644 L
.5288 .42636 L
.52997 .42632 L
.53104 .4263 L
.53222 .42629 L
.53346 .42629 L
.53554 .42633 L
.53671 .42636 L
.5378 .4264 L
.5399 .42651 L
.54188 .42665 L
.54556 .427 L
.54948 .4275 L
.55368 .42819 L
.56093 .42977 L
.56839 .43193 L
.58113 .43698 L
.59363 .44383 L
.6058 .4527 L
.61597 .46229 L
.62408 .4719 L
.63182 .48349 L
.63763 .49473 L
.64249 .50736 L
.64452 .51447 L
.64594 .52089 L
.64694 .52701 L
Mistroke
.64731 .53007 L
.64748 .53181 L
.64761 .53339 L
.64771 .53474 L
.64779 .53621 L
.64786 .53775 L
.6479 .5392 L
.64792 .54054 L
.64792 .54197 L
.64791 .54318 L
.64788 .5445 L
.64782 .54604 L
.64778 .54682 L
.64773 .54766 L
.64752 .5505 L
.64717 .55377 L
.64675 .55675 L
.64576 .562 L
.64441 .56735 L
.64173 .57515 L
.63812 .58274 L
.63413 .58903 L
.63005 .594 L
Mfstroke
.8 0 1 r
.09029 .97619 m
.06686 .91626 L
.04695 .8485 L
.03922 .81372 L
.03269 .77621 L
.03016 .75794 L
.02817 .74064 L
.02659 .7239 L
.02544 .70822 L
.02491 .6992 L
.02452 .69095 L
.02419 .6818 L
.02405 .67675 L
.02394 .67196 L
.02387 .66735 L
.02382 .66244 L
.02381 .65362 L
.02385 .64823 L
.02392 .64315 L
.02401 .63859 L
.02414 .63367 L
.02443 .62541 L
.02484 .61636 L
.02598 .59814 L
.0274 .58135 L
.02905 .56576 L
.03441 .52766 L
.04088 .4935 L
.06076 .41914 L
.08387 .35759 L
.10969 .30405 L
.14479 .24628 L
.18211 .19725 L
.26082 .12109 L
.30661 .08913 L
.35823 .06165 L
.40586 .04332 L
.43323 .03561 L
.45885 .03017 L
.47283 .02791 L
.48604 .02623 L
.49789 .0251 L
.50458 .02462 L
.51073 .02427 L
.51734 .02401 L
.52352 .02386 L
.52706 .02382 L
.53029 .02381 L
.53401 .02383 L
.53755 .02388 L
Mistroke
.54095 .02396 L
.54457 .02408 L
.55106 .02437 L
.55877 .02486 L
.56573 .02542 L
.57738 .02665 L
.59008 .02839 L
.61544 .03314 L
.63857 .03897 L
.65977 .04564 L
.70612 .0649 L
.75294 .09162 L
.79413 .12229 L
.8349 .16094 L
.86646 .1983 L
.89698 .24313 L
.92049 .28639 L
.94129 .33528 L
.95071 .36302 L
.95805 .38879 L
.96386 .4135 L
.96882 .44004 L
.97084 .4535 L
.97245 .46619 L
.97374 .47856 L
.97468 .48994 L
.97537 .50075 L
.97564 .5062 L
.97587 .51217 L
.97604 .51816 L
.97615 .52457 L
.97619 .53062 L
.97617 .53613 L
.97608 .54257 L
.976 .54582 L
.9759 .5494 L
.97566 .55572 L
.97537 .56163 L
.9745 .57489 L
.9732 .58909 L
.96992 .61476 L
.96588 .63792 L
.95477 .68351 L
.94109 .72395 L
.92263 .76566 L
.89925 .80674 L
.87377 .84223 L
.84314 .87615 L
.81457 .90137 L
.78133 .92453 L
Mistroke
.74772 .94228 L
.71547 .95459 L
.6975 .95959 L
.68102 .96305 L
.67192 .96451 L
.66712 .96515 L
.66201 .96574 L
.6571 .96621 L
.65266 .96655 L
.64821 .96682 L
.64402 .96701 L
.64009 .96712 L
.63589 .96717 L
.63193 .96716 L
.62833 .9671 L
.62412 .96696 L
.62174 .96686 L
.61955 .96674 L
.61528 .96646 L
.61129 .96613 L
.60343 .96529 L
.59481 .9641 L
.57761 .96082 L
.56286 .95702 L
.5496 .9528 L
.52078 .9408 L
.493 .92515 L
.46897 .90781 L
.44338 .88453 L
.42186 .85995 L
.40348 .83386 L
.38666 .80373 L
.37425 .77508 L
.36529 .74795 L
.36153 .73354 L
.35823 .71799 L
.35579 .70329 L
.35415 .68988 L
.35341 .68176 L
.35291 .67425 L
.3527 .66994 L
.35255 .66605 L
.35249 .66389 L
.35245 .66156 L
.35241 .65937 L
.3524 .65736 L
.3524 .65369 L
.35244 .65028 L
.35252 .64654 L
.35266 .64256 L
Mistroke
.35285 .6384 L
.35309 .63447 L
.35364 .62717 L
.35434 .62016 L
.35512 .61365 L
.35739 .59905 L
.36022 .58515 L
.36392 .5706 L
.37226 .54551 L
.38159 .52409 L
.40645 .4837 L
.42287 .46467 L
.43928 .44966 L
.45753 .43665 L
.47529 .42714 L
.49145 .42087 L
.50058 .41827 L
.50896 .41647 L
.51338 .41574 L
.51739 .4152 L
.51961 .41496 L
.52201 .41475 L
.52408 .41459 L
.52635 .41447 L
.52844 .41439 L
.53039 .41434 L
.53244 .41432 L
.53464 .41434 L
.53657 .41439 L
.5386 .41448 L
.54032 .41458 L
.5422 .41471 L
.54682 .41516 L
.55098 .41572 L
.55572 .41653 L
.56013 .41746 L
.56782 .4195 L
.57589 .42224 L
.58987 .42858 L
.60395 .43735 L
.61706 .44825 L
.62772 .45976 L
.63694 .47255 L
.64407 .48539 L
.6491 .49726 L
.65313 .51036 L
.65471 .51756 L
.65532 .52107 L
.65579 .52429 L
.65613 .52715 L
Mistroke
.65643 .53026 L
.65665 .53337 L
.65673 .53505 L
.65678 .53662 L
.65682 .5383 L
.65683 .53925 L
.65683 .54012 L
.65682 .54172 L
.6568 .54252 L
.65678 .5434 L
.65672 .54491 L
.65664 .54652 L
.65643 .54942 L
.65609 .55278 L
.65563 .55625 L
.65453 .56226 L
.65335 .56718 L
.65208 .57146 L
.64863 .58042 L
.64477 .58784 L
.64062 .594 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 288},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {287, 0}} -> {-11.0224, -8.46865, 0.0666275, \
0.0556332}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<streakline.pdf\>\"", ",", " ", "%"}], "]"}]], "Input"],

Cell[BoxData["\<\"streakline.pdf\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "[", " ", 
        RowBox[{
         RowBox[{"Finv", "[", 
          RowBox[{"a0", " ", ",", " ", "\[Tau]"}], "]"}], " ", ",", " ", 
         "t"}], "]"}], "  ", "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", "-", " ", "t"}], ")"}], "^", 
    "2"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "[", " ", 
        RowBox[{
         RowBox[{"Finv", "[", 
          RowBox[{"a0", " ", ",", " ", "\[Tau]"}], "]"}], " ", ",", " ", 
         "t"}], "]"}], "  ", "[", 
       RowBox[{"[", "2", "]"}], "]"}], " ", "-", " ", "R"}], ")"}], "^", 
    "2"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"4", "+", 
  SuperscriptBox["\[Tau]", "2"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "[", " ", 
         RowBox[{
          RowBox[{"Finv", "[", 
           RowBox[{"a0", " ", ",", " ", "t"}], "]"}], " ", ",", " ", "1"}], 
         "]"}], "  ", "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "-", " ", "1"}], ")"}], "^", 
     "2"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"F", "[", " ", 
         RowBox[{
          RowBox[{"Finv", "[", 
           RowBox[{"a0", " ", ",", " ", "t"}], "]"}], " ", ",", " ", "1"}], 
         "]"}], "  ", "[", 
        RowBox[{"[", "2", "]"}], "]"}], " ", "-", " ", "R"}], ")"}], "^", 
     "2"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "10"}], "}"}]}], " ", "]"}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0476191 0.0147151 0.00565965 [
[.02381 .00222 -9 -9 ]
[.02381 .00222 9 0 ]
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.4875 .12791 -12 -4.5 ]
[.4875 .12791 0 4.5 ]
[.4875 .2411 -12 -4.5 ]
[.4875 .2411 0 4.5 ]
[.4875 .35429 -12 -4.5 ]
[.4875 .35429 0 4.5 ]
[.4875 .46749 -12 -4.5 ]
[.4875 .46749 0 4.5 ]
[.4875 .58068 -18 -4.5 ]
[.4875 .58068 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-10)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-5)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .12791 m
.50625 .12791 L
s
[(20)] .4875 .12791 1 0 Mshowa
.5 .2411 m
.50625 .2411 L
s
[(40)] .4875 .2411 1 0 Mshowa
.5 .35429 m
.50625 .35429 L
s
[(60)] .4875 .35429 1 0 Mshowa
.5 .46749 m
.50625 .46749 L
s
[(80)] .4875 .46749 1 0 Mshowa
.5 .58068 m
.50625 .58068 L
s
[(100)] .4875 .58068 1 0 Mshowa
.125 Mabswid
.5 .04301 m
.50375 .04301 L
s
.5 .07131 m
.50375 .07131 L
s
.5 .09961 m
.50375 .09961 L
s
.5 .15621 m
.50375 .15621 L
s
.5 .1845 m
.50375 .1845 L
s
.5 .2128 m
.50375 .2128 L
s
.5 .2694 m
.50375 .2694 L
s
.5 .2977 m
.50375 .2977 L
s
.5 .326 m
.50375 .326 L
s
.5 .38259 m
.50375 .38259 L
s
.5 .41089 m
.50375 .41089 L
s
.5 .43919 m
.50375 .43919 L
s
.5 .49579 m
.50375 .49579 L
s
.5 .52408 m
.50375 .52408 L
s
.5 .55238 m
.50375 .55238 L
s
.5 .60898 m
.50375 .60898 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .51521 L
.10458 .42761 L
.14415 .35341 L
.18221 .28942 L
.22272 .22925 L
.26171 .17908 L
.30316 .13406 L
.34309 .09881 L
.3815 .0724 L
.40095 .06184 L
.42237 .0524 L
.44268 .04555 L
.45178 .04316 L
.46172 .04101 L
.4671 .04006 L
.4721 .0393 L
.47727 .03864 L
.48196 .03817 L
.48658 .0378 L
.4887 .03767 L
.49093 .03756 L
.49332 .03747 L
.49438 .03743 L
.49552 .0374 L
.49675 .03738 L
.49789 .03736 L
.49859 .03736 L
.49925 .03736 L
.50049 .03735 L
.50163 .03736 L
.50286 .03737 L
.50401 .03739 L
.50508 .03742 L
.50754 .0375 L
.51014 .03761 L
.51268 .03775 L
.51504 .03792 L
.5204 .03839 L
.5293 .0395 L
.53882 .04111 L
.54906 .04336 L
.56016 .04639 L
.58032 .05345 L
.60019 .06241 L
.62123 .07404 L
.65912 .10055 L
.69946 .13665 L
.73829 .17907 L
.77956 .23242 L
Mistroke
.81932 .29185 L
.85757 .35647 L
.89827 .43324 L
.93745 .51497 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-11.1468, -8.03947, \
0.0770056, 0.647909}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<radius.pdf\>\"", ",", "%"}], "]"}]], "Input"],

Cell[BoxData["\<\"radius.pdf\"\>"], "Output"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1270, 821},
WindowMargins->{{Automatic, 71}, {Automatic, 0}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[1309, 36, 223, 6, 46, "Input",
 Evaluatable->False],
Cell[1535, 44, 207, 6, 37, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1767, 54, 148, 3, 32, "Input"],
Cell[1918, 59, 95, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2050, 65, 132, 3, 32, "Input"],
Cell[2185, 70, 391, 8, 24, "Message"],
Cell[2579, 80, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2699, 87, 249, 6, 55, "Input"],
Cell[2951, 95, 86, 2, 31, "Output"],
Cell[3040, 99, 84, 2, 31, "Output"]
}, Open  ]],
Cell[3139, 104, 576, 16, 32, "Input"],
Cell[3718, 122, 364, 10, 32, "Input"],
Cell[CellGroupData[{
Cell[4107, 136, 77, 2, 32, "Input"],
Cell[4187, 140, 656, 21, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4880, 166, 161, 2, 42, "Subsection"],
Cell[CellGroupData[{
Cell[5066, 172, 797, 21, 55, "Input"],
Cell[5866, 195, 485, 14, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6388, 214, 2410, 60, 165, "Input"],
Cell[8801, 276, 32648, 1742, 165, 24678, 1608, "GraphicsData", "PostScript", \
"Graphics"],
Cell[41452, 2020, 134, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41623, 2029, 110, 2, 32, "Input"],
Cell[41736, 2033, 51, 0, 31, "Output"]
}, Open  ]],
Cell[41802, 2036, 180, 4, 37, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[42007, 2044, 438, 13, 32, "Input"],
Cell[42448, 2059, 385, 7, 24, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42870, 2071, 395, 11, 55, "Input"],
Cell[43268, 2084, 107, 2, 31, "Output"],
Cell[43378, 2088, 385, 7, 24, "Message"],
Cell[43766, 2097, 1362, 42, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45165, 2144, 64, 1, 32, "Input"],
Cell[45232, 2147, 817, 26, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46086, 2178, 102, 2, 32, "Input"],
Cell[46191, 2182, 717, 24, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46945, 2211, 494, 14, 32, "Input"],
Cell[47442, 2227, 845, 28, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48324, 2260, 353, 10, 32, "Input"],
Cell[48680, 2272, 845, 28, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49562, 2305, 74, 1, 32, "Input"],
Cell[49639, 2308, 50, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49726, 2314, 467, 15, 32, "Input"],
Cell[50196, 2331, 328, 9, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50561, 2345, 117, 3, 32, "Input"],
Cell[50681, 2350, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50801, 2357, 210, 6, 32, "Input"],
Cell[51014, 2365, 1493, 46, 62, "Output"]
}, Open  ]],
Cell[52522, 2414, 1637, 39, 121, "Input"],
Cell[CellGroupData[{
Cell[54184, 2457, 552, 16, 32, "Input"],
Cell[54739, 2475, 11078, 573, 296, 7436, 510, "GraphicsData", "PostScript", \
"Graphics"],
Cell[65820, 3050, 134, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65991, 3059, 262, 5, 32, "Input"],
Cell[66256, 3066, 45932, 2486, 296, 35559, 2312, "GraphicsData", \
"PostScript", "Graphics"],
Cell[112191, 5554, 134, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112362, 5563, 108, 2, 32, "Input"],
Cell[112473, 5567, 49, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112559, 5572, 750, 24, 32, "Input"],
Cell[113312, 5598, 79, 2, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113428, 5605, 877, 28, 32, "Input"],
Cell[114308, 5635, 5840, 297, 186, 3594, 257, "GraphicsData", "PostScript", \
"Graphics"],
Cell[120151, 5934, 134, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120322, 5943, 99, 2, 32, "Input"],
Cell[120424, 5947, 45, 0, 31, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

