(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18653,        641]
NotebookOptionsPosition[     16479,        558]
NotebookOutlinePosition[     16833,        574]
CellTagsIndexPosition[     16790,        571]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["\<\
General Form of the small strain tensor (after Bui - Control \
M\[EAcute]canique 1985, Ecole Polytechnique)  \
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"",
   "]"}], "\n", 
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n", 
 RowBox[{"<<", " ", "IntegrateStrain.m"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", " ", ":=", " ", 
  RowBox[{"\[Alpha]", " ", 
   RowBox[{"T", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"eps", " ", "//", " ", "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"T", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "0", "0"},
     {"0", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"T", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "0"},
     {"0", "0", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"T", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["T", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
         RowBox[{
          SuperscriptBox["T", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], " ", 
       RowBox[{
        SuperscriptBox["T", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], " ", 
       RowBox[{
        SuperscriptBox["T", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], " ", 
       RowBox[{
        SuperscriptBox["T", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["T", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
         RowBox[{
          SuperscriptBox["T", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], " ", 
       RowBox[{
        SuperscriptBox["T", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], " ", 
       RowBox[{
        SuperscriptBox["T", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], " ", 
       RowBox[{
        SuperscriptBox["T", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["T", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
         RowBox[{
          SuperscriptBox["T", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"2", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "  ", "is", " ", "a", " ", 
  "linear", " ", "combination", " ", "of", " ", "functions", " ", "of", " ", 
  "coordinates", " "}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"x_", ",", " ", "y_", ",", " ", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"a", "[", " ", "x", "]"}], "  ", "+", " ", 
   RowBox[{"b", "[", "y", "]"}], " ", "+", " ", 
   RowBox[{"c", "[", "z", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["b", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "+", 
         RowBox[{
          SuperscriptBox["c", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "z", "]"}]}], ")"}]}], "0", "0"},
     {"0", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "x", "]"}], "+", 
         RowBox[{
          SuperscriptBox["c", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "z", "]"}]}], ")"}]}], "0"},
     {"0", "0", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "x", "]"}], "+", 
         RowBox[{
          SuperscriptBox["b", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "  ", "is", " ", "a", " ", 
  "linear", " ", "combination", " ", "of", " ", "LINEAR", " ", "functions", 
  " ", "of", " ", "coordinates", " "}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"x_", ",", " ", "y_", ",", " ", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"a", " ", "x"}], "  ", "+", " ", 
   RowBox[{"b", " ", "y"}], "  ", "+", " ", 
   RowBox[{"c", " ", "z"}], " ", "+", " ", "d", 
   " "}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Inc", "[", " ", "eps", " ", "]"}], " ", "//", "  ", 
  "MatrixForm"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eps", "  ", "//", "  ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "+", 
         RowBox[{"a", " ", "x"}], "+", 
         RowBox[{"b", " ", "y"}], "+", 
         RowBox[{"c", " ", "z"}]}], ")"}], " ", "\[Alpha]"}], "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "+", 
         RowBox[{"a", " ", "x"}], "+", 
         RowBox[{"b", " ", "y"}], "+", 
         RowBox[{"c", " ", "z"}]}], ")"}], " ", "\[Alpha]"}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "+", 
         RowBox[{"a", " ", "x"}], "+", 
         RowBox[{"b", " ", "y"}], "+", 
         RowBox[{"c", " ", "z"}]}], ")"}], " ", "\[Alpha]"}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", 
  RowBox[{"IntegrateStrain", "[", "eps", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"d", " ", "x", " ", "\[Alpha]"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "a", " ", 
     SuperscriptBox["x", "2"], " ", "\[Alpha]"}], "+", 
    RowBox[{"b", " ", "x", " ", "y", " ", "\[Alpha]"}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "a", " ", 
     SuperscriptBox["y", "2"], " ", "\[Alpha]"}], "+", 
    RowBox[{"c", " ", "x", " ", "z", " ", "\[Alpha]"}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "a", " ", 
     SuperscriptBox["z", "2"], " ", "\[Alpha]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", "b", " ", 
     SuperscriptBox["x", "2"], " ", "\[Alpha]"}], "+", 
    RowBox[{"d", " ", "y", " ", "\[Alpha]"}], "+", 
    RowBox[{"a", " ", "x", " ", "y", " ", "\[Alpha]"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "b", " ", 
     SuperscriptBox["y", "2"], " ", "\[Alpha]"}], "+", 
    RowBox[{"c", " ", "y", " ", "z", " ", "\[Alpha]"}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "b", " ", 
     SuperscriptBox["z", "2"], " ", "\[Alpha]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", "c", " ", 
     SuperscriptBox["x", "2"], " ", "\[Alpha]"}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "c", " ", 
     SuperscriptBox["y", "2"], " ", "\[Alpha]"}], "+", 
    RowBox[{"d", " ", "z", " ", "\[Alpha]"}], "+", 
    RowBox[{"a", " ", "x", " ", "z", " ", "\[Alpha]"}], "+", 
    RowBox[{"b", " ", "y", " ", "z", " ", "\[Alpha]"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "c", " ", 
     SuperscriptBox["z", "2"], " ", "\[Alpha]"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "  ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"c", " ", "z"}], " ", "+", " ", "d"}], "  ", "\[Rule]", " ", 
   RowBox[{
   "vertical", " ", "gradient", " ", "of", " ", 
    "temperature"}]}]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"u", " ", "/.", " ", 
   RowBox[{"a", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
  RowBox[{"b", " ", "\[Rule]", " ", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"d", " ", "x", " ", "\[Alpha]"}], "+", 
    RowBox[{"c", " ", "x", " ", "z", " ", "\[Alpha]"}]}], ",", 
   RowBox[{
    RowBox[{"d", " ", "y", " ", "\[Alpha]"}], "+", 
    RowBox[{"c", " ", "y", " ", "z", " ", "\[Alpha]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", "c", " ", 
     SuperscriptBox["x", "2"], " ", "\[Alpha]"}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "c", " ", 
     SuperscriptBox["y", "2"], " ", "\[Alpha]"}], "+", 
    RowBox[{"d", " ", "z", " ", "\[Alpha]"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "c", " ", 
     SuperscriptBox["z", "2"], " ", "\[Alpha]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", " ", "/.", " ", 
    RowBox[{"a", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
   RowBox[{"b", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
  RowBox[{"z", " ", "\[Rule]", " ", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d", " ", "x", " ", "\[Alpha]"}], ",", 
   RowBox[{"d", " ", "y", " ", "\[Alpha]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", "c", " ", 
     SuperscriptBox["x", "2"], " ", "\[Alpha]"}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", "c", " ", 
     SuperscriptBox["y", "2"], " ", "\[Alpha]"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Vertical", " ", "gradient", " ", "of", " ", "temperature"}], " ", 
  "\[Rule]", " ", 
  RowBox[{
  "curvature", " ", "of", " ", "the", " ", "deformed", " ", "surface", 
   " "}]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"u", " ", "/.", " ", 
      RowBox[{"a", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
     RowBox[{"b", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
    RowBox[{"z", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
   RowBox[{"d", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
  RowBox[{"c", " ", "\[Rule]", " ", 
   RowBox[{"dT", " ", "/", " ", "H"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"dT", " ", 
       SuperscriptBox["x", "2"], " ", "\[Alpha]"}], 
      RowBox[{"2", " ", "H"}]]}], "-", 
    FractionBox[
     RowBox[{"dT", " ", 
      SuperscriptBox["y", "2"], " ", "\[Alpha]"}], 
     RowBox[{"2", " ", "H"}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R", " ", "=", " ", 
  RowBox[{
   RowBox[{"H", " ", "/", " ", "dt"}], " ", "/", " ", "\[Alpha]"}]}]], "Input"],

Cell[BoxData[
 FractionBox["H", 
  RowBox[{"dt", " ", "\[Alpha]"}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"R", " ", "/.", " ", 
    RowBox[{"\[Alpha]", " ", "\[Rule]", " ", 
     RowBox[{"10", "^", 
      RowBox[{"-", "5"}]}]}]}], " ", "/.", " ", 
   RowBox[{"H", " ", "\[Rule]", " ", "0.001"}]}], " ", "/.", " ", 
  RowBox[{"dt", " ", "\[Rule]", " ", "100"}]}]], "Input"],

Cell[BoxData["1.`"], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1172, 821},
WindowMargins->{{43, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 139, 3, 39, "Subsection"],
Cell[CellGroupData[{
Cell[1495, 45, 232, 4, 99, "Input"],
Cell[1730, 51, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1817, 54, 26, 0, 32, "Input"],
Cell[CellGroupData[{
Cell[1868, 58, 137, 3, 32, "Input"],
Cell[2008, 63, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2141, 70, 282, 6, 55, "Input"],
Cell[2426, 78, 537, 17, 60, "Output"]
}, Open  ]],
Cell[2978, 98, 26, 0, 32, "Input"],
Cell[CellGroupData[{
Cell[3029, 102, 115, 3, 32, "Input"],
Cell[3147, 107, 3918, 125, 78, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7102, 237, 237, 5, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[7364, 246, 399, 10, 55, "Input"],
Cell[7766, 258, 1200, 35, 64, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9015, 299, 252, 5, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[9292, 308, 409, 11, 55, "Input"],
Cell[9704, 321, 219, 8, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9960, 334, 73, 1, 32, "Input"],
Cell[10036, 337, 822, 26, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10895, 368, 98, 2, 32, "Input"],
Cell[10996, 372, 1684, 43, 81, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12729, 421, 307, 9, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[13061, 434, 173, 4, 32, "Input"],
Cell[13237, 440, 736, 20, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14010, 465, 249, 6, 32, "Input"],
Cell[14262, 473, 417, 12, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14728, 491, 233, 6, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[14986, 501, 442, 11, 32, "Input"],
Cell[15431, 514, 373, 12, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15841, 531, 134, 3, 32, "Input"],
Cell[15978, 536, 79, 2, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16094, 543, 312, 8, 32, "Input"],
Cell[16409, 553, 30, 0, 31, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

