(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     22225,        824]
NotebookOptionsPosition[     19371,        719]
NotebookOutlinePosition[     19703,        734]
CellTagsIndexPosition[     19660,        731]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"",
   "]"}], "\n", 
 RowBox[{"<<", "Tensor2Analysis.m"}]}], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"pinitial", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"r", ",", "0", ",", " ", "z"}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"pfinal", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", " ", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"z", "/", "L"}]}], "]"}]}], " ", ",", " ", 
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", " ", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"z", " ", "/", " ", "L"}]}], "]"}]}], " ", ",", " ", "z"}], 
   "}"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", "0", ",", "z"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", 
     FractionBox[
      RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], ",", "z"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", " ", 
  RowBox[{"{", 
   RowBox[{"r", ",", 
    RowBox[{"t", " ", "+", " ", 
     RowBox[{"\[Alpha]", " ", 
      RowBox[{"z", " ", "/", " ", "L"}]}]}], ",", " ", "z"}], "}"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"t", "+", 
      FractionBox[
       RowBox[{"z", " ", "\[Alpha]"}], "L"]}], "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"t", "+", 
      FractionBox[
       RowBox[{"z", " ", "\[Alpha]"}], "L"]}], "]"}]}], ",", "z"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesFromCartesian", "[", "%", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SqrtBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"t", "+", 
         FractionBox[
          RowBox[{"z", " ", "\[Alpha]"}], "L"]}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"t", "+", 
         FractionBox[
          RowBox[{"z", " ", "\[Alpha]"}], "L"]}], "]"}], "2"]}]}]], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", "+", 
        FractionBox[
         RowBox[{"z", " ", "\[Alpha]"}], "L"]}], "]"}]}], ",", 
     RowBox[{"r", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", "+", 
        FractionBox[
         RowBox[{"z", " ", "\[Alpha]"}], "L"]}], "]"}]}]}], "]"}], ",", "z"}],
   "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", " ", 
  RowBox[{"%", " ", ",", 
   RowBox[{
    RowBox[{"r", " ", ">", " ", "0"}], "  ", "&&", "  ", 
    RowBox[{
     RowBox[{"Pi", "/", "2"}], "  ", ">", " ", 
     RowBox[{"t", "+", 
      FractionBox[
       RowBox[{"z", " ", "\[Alpha]"}], "L"]}], " ", ">", " ", "0"}]}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r", ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"t", "+", 
       FractionBox[
        RowBox[{"z", " ", "\[Alpha]"}], "L"]}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"t", "+", 
       FractionBox[
        RowBox[{"z", " ", "\[Alpha]"}], "L"]}], "]"}]}], "]"}], ",", "z"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"r_", ",", "t_", ",", "z_"}], "]"}], " ", ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", " ", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"z", "/", " ", "L"}]}], "]"}]}], " ", ",", " ", 
    RowBox[{"r", " ", 
     RowBox[{"Sin", "[", " ", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"z", " ", "/", " ", "L"}]}], "]"}]}], " ", ",", " ", "z"}], 
   "}"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"F", " ", "=", " ", 
    RowBox[{"Grad", "[", " ", 
     RowBox[{"T", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]}], " ", ")"}], "//", 
  " ", "MatrixForm", " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}], 
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        FractionBox[
         RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"r", " ", "\[Alpha]", " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], "L"]}]},
     {
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}], 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}], 
      FractionBox[
       RowBox[{"r", " ", "\[Alpha]", " ", 
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], "L"]},
     {"0", "0", "1"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"R", "[", "\[Theta]_", "]"}], " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", " ", 
      RowBox[{"-", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", " ", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], ",", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", " ", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], ",", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"R1", " ", "=", " ", 
  RowBox[{"R", "[", 
   FractionBox[
    RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], ",", "0"}], "}"}], ",",
    
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", 
      FractionBox[
       RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}], ",", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"F1", " ", "=", " ", 
    RowBox[{"FullSimplify", "[", " ", 
     RowBox[{
      RowBox[{"Inverse", "[", "R1", "]"}], " ", ".", " ", "F"}], " ", "]"}]}],
    ")"}], " ", "//", " ", "MatrixForm", " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", "1", 
      FractionBox[
       RowBox[{"r", " ", "\[Alpha]"}], "L"]},
     {"0", "0", "1"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"etarule", " ", "=", 
  RowBox[{"{", 
   RowBox[{"z", "\[Rule]", 
    RowBox[{"2", " ", "L", " ", 
     RowBox[{"\[Eta]", " ", "/", " ", "\[Alpha]"}]}]}], "}"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"z", "\[Rule]", 
   FractionBox[
    RowBox[{"2", " ", "L", " ", "\[Eta]"}], "\[Alpha]"]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{"V2", "=", " ", 
     RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"F1", ".", " ", 
       RowBox[{"Transpose", "[", "F1", "]"}]}], " ", "]"}]}], "  ", ")"}], "//",
    " ", "MatrixForm"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{"U2", " ", "=", " ", 
     RowBox[{"FullSimplify", "[", " ", 
      RowBox[{
       RowBox[{"Transpose", "[", "F1", "]"}], " ", ".", " ", "F1"}], "]"}]}], 
    "  ", ")"}], "//", " ", "MatrixForm"}], 
  " "}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], 
        SuperscriptBox["L", "2"]]}], 
      FractionBox[
       RowBox[{"r", " ", "\[Alpha]"}], "L"]},
     {"0", 
      FractionBox[
       RowBox[{"r", " ", "\[Alpha]"}], "L"], "1"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", "1", 
      FractionBox[
       RowBox[{"r", " ", "\[Alpha]"}], "L"]},
     {"0", 
      FractionBox[
       RowBox[{"r", " ", "\[Alpha]"}], "L"], 
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox["\[Alpha]", "2"]}], 
        SuperscriptBox["L", "2"]]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"betarule", " ", "=", 
  RowBox[{"r", " ", "\[Rule]", 
   RowBox[{"2", " ", "L", " ", 
    RowBox[{
     RowBox[{"\[Beta]", " ", "/", "\[Alpha]"}], " "}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(betarule\\)\\\" is similar to existing symbol \
\\\"\\!\\(etarule\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"r", "\[Rule]", 
  FractionBox[
   RowBox[{"2", " ", "L", " ", "\[Beta]"}], "\[Alpha]"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{"U2", " ", "=", " ", 
     RowBox[{"FullSimplify", "[", " ", 
      RowBox[{"U2", " ", "/.", " ", "betarule"}], "]"}]}], " ", ")"}], "//", 
   " ", "MatrixForm"}], " ", "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", "1", 
      RowBox[{"2", " ", "\[Beta]"}]},
     {"0", 
      RowBox[{"2", " ", "\[Beta]"}], 
      RowBox[{"1", "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["\[Beta]", "2"]}]}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"FF", " ", "=", " ", 
    RowBox[{
     RowBox[{"F", " ", "/.", " ", "betarule"}], " ", "/.", " ", "etarule"}]}],
    " ", ")"}], " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "\[Eta]"}], "]"}], 
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", "\[Eta]"}], "]"}]}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Beta]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", "\[Eta]"}], "]"}]}]},
     {
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "\[Eta]"}], "]"}], 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "\[Eta]"}], "]"}], 
      RowBox[{"2", " ", "\[Beta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "\[Eta]"}], "]"}]}]},
     {"0", "0", "1"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"gu", " ", "=", 
    RowBox[{
     RowBox[{"Normal", "[", " ", 
      RowBox[{"Series", "[", " ", 
       RowBox[{"FF", " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"\[Eta]", ",", " ", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
     " ", "-", " ", 
     RowBox[{"IdentityMatrix", "[", "3", "]"}]}]}], " ", ")"}], " ", "//", 
  " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Eta]"}], 
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[Beta]", " ", "\[Eta]"}]},
     {
      RowBox[{"2", " ", "\[Eta]"}], "0", 
      RowBox[{"2", " ", "\[Beta]"}]},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"pfinal", " ", "-", " ", "pinitial", "  "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "r"}], "+", 
    RowBox[{"r", " ", 
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", 
     FractionBox[
      RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], ",", "0"}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Grad", "[", "u", "]"}], " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], 
      RowBox[{"-", 
       RowBox[{"Sin", "[", 
        FractionBox[
         RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"r", " ", "\[Alpha]", " ", 
         RowBox[{"Sin", "[", 
          FractionBox[
           RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], "L"]}]},
     {
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}], 
      FractionBox[
       RowBox[{
        RowBox[{"-", "r"}], "+", 
        RowBox[{"r", " ", 
         RowBox[{"Cos", "[", 
          FractionBox[
           RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}]}], "r"], 
      FractionBox[
       RowBox[{"r", " ", "\[Alpha]", " ", 
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{"z", " ", "\[Alpha]"}], "L"], "]"}]}], "L"]},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"gu", " ", "=", 
    RowBox[{
     RowBox[{"Normal", "[", " ", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Grad", "[", "u", "]"}], " ", "/.", " ", "etarule"}], " ", 
        ",", 
        RowBox[{"{", 
         RowBox[{"\[Eta]", ",", " ", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
     " ", "/.", " ", "betarule"}]}], " ", ")"}], "//", " ", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Eta]"}], 
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[Beta]", " ", "\[Eta]"}]},
     {
      RowBox[{"2", " ", "\[Eta]"}], "0", 
      RowBox[{"2", " ", "\[Beta]"}]},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gu", " ", "=", " ", 
  RowBox[{"gu", " ", "/.", " ", 
   RowBox[{
    RowBox[{"\[Beta]", " ", "\[Eta]"}], " ", "\[Rule]", " ", "0", 
    "  "}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[Eta]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "\[Eta]"}], ",", "0", ",", 
     RowBox[{"2", " ", "\[Beta]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], " ", 
   RowBox[{"(", " ", 
    RowBox[{"gu", " ", "-", " ", 
     RowBox[{"Transpose", "[", "gu", "]"}]}], " ", ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[Eta]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "\[Eta]"}], ",", "0", ",", "\[Beta]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"-", "\[Beta]"}], ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w", " ", "=", " ", 
  RowBox[{
   RowBox[{"1", "/", "2"}], " ", 
   RowBox[{"(", " ", 
    RowBox[{"gu", " ", "+", " ", 
     RowBox[{"Transpose", "[", "gu", "]"}]}], " ", ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "\[Beta]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "\[Beta]", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{977, 813},
WindowMargins->{{18, Automatic}, {Automatic, 1}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 159, 3, 55, "Input"],
Cell[1493, 43, 72, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1602, 48, 139, 3, 32, "Input"],
Cell[1744, 53, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1879, 60, 536, 15, 55, "Input"],
Cell[2418, 77, 83, 2, 31, "Output"],
Cell[2504, 81, 314, 11, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2855, 97, 250, 7, 32, "Input"],
Cell[3108, 106, 370, 13, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3515, 124, 77, 1, 32, "Input"],
Cell[3595, 127, 911, 31, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4543, 163, 342, 10, 52, "Input"],
Cell[4888, 175, 389, 13, 44, "Output"]
}, Open  ]],
Cell[5292, 191, 466, 14, 32, "Input"],
Cell[CellGroupData[{
Cell[5783, 209, 240, 7, 32, "Input"],
Cell[6026, 218, 999, 32, 94, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7062, 255, 542, 15, 32, "Input"],
Cell[7607, 272, 442, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8086, 290, 142, 4, 52, "Input"],
Cell[8231, 296, 660, 22, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8928, 323, 262, 7, 32, "Input"],
Cell[9193, 332, 279, 10, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9509, 347, 201, 5, 32, "Input"],
Cell[9713, 354, 148, 4, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9898, 363, 593, 17, 77, "Input"],
Cell[10494, 382, 520, 18, 80, "Output"],
Cell[11017, 402, 520, 18, 80, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11574, 425, 193, 5, 32, "Input"],
Cell[11770, 432, 394, 8, 24, "Message"],
Cell[12167, 442, 124, 3, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12328, 450, 272, 7, 55, "Input"],
Cell[12603, 459, 376, 13, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13016, 477, 227, 6, 32, "Input"],
Cell[13246, 485, 758, 24, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14041, 514, 416, 12, 32, "Input"],
Cell[14460, 528, 410, 14, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14907, 547, 110, 2, 32, "Input"],
Cell[15020, 551, 362, 13, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15419, 569, 100, 2, 32, "Input"],
Cell[15522, 573, 1167, 38, 94, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16726, 616, 457, 14, 32, "Input"],
Cell[17186, 632, 410, 14, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17633, 651, 182, 5, 32, "Input"],
Cell[17818, 658, 376, 12, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18231, 675, 216, 6, 32, "Input"],
Cell[18450, 683, 377, 12, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18864, 700, 216, 6, 32, "Input"],
Cell[19083, 708, 272, 8, 31, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
