(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    158718,       4831]
NotebookOptionsPosition[    152298,       4609]
NotebookOutlinePosition[    152827,       4631]
CellTagsIndexPosition[    152740,       4626]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Series for equilibrium", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "SetDirectory", "[", 
   "\"\<C:\\A1\\AMK04\\elastica\\ElasticaBook\\Packages\>\"", "]"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", 
    "\"\</local/constant/Oxford/Tex/ElasticaBook/Packages\>\"", "]"}], " ", 
   "*)"}]}]}], "Input"],

Cell[BoxData["\<\"C:\\\\A1\\\\AMK04\\\\elastica\\\\ElasticaBook\\\\Packages\"\
\>"], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "Tensor2Analysis.m"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"stress", " ", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], " ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sig11", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
       RowBox[{"sig12", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
       RowBox[{"sig13", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sig12", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
       RowBox[{"sig22", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
       RowBox[{"sig23", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sig13", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
       RowBox[{"sig23", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
       RowBox[{"sig33", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{"Div", "[", 
    RowBox[{"stress", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]], "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sig13", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig12", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig11", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sig23", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig22", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig12", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sig33", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig23", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig13", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Derivative[0, 0, 1][sig13][x, y, z] + Derivative[0, 1, 0][sig12][x, y, z] + 
    Derivative[1, 0, 0][sig11][x, y, z], Derivative[0, 0, 1][sig23][x, y, z] + 
    Derivative[0, 1, 0][sig22][x, y, z] + Derivative[1, 0, 0][sig12][x, y, z],
     Derivative[0, 0, 1][sig33][x, y, z] + 
    Derivative[0, 1, 0][sig23][x, y, z] + 
    Derivative[1, 0, 0][sig13][x, y, z]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"Series", "[", " ", 
    RowBox[{
     RowBox[{"stress", "[", 
      RowBox[{"x", ",", "y", ",", "z"}], "]"}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", "x0", ",", " ", "1"}], "}"}]}], "]"}], " ", ")"}], 
  " ", "//", " ", "MatrixForm", " "}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      InterpretationBox[
       RowBox[{
        RowBox[{"sig11", "[", 
         RowBox[{"x0", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["sig11", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y", ",", "z"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"x", "-", "x0"}], "]"}], "2"],
         SeriesData[x, x0, {}, 0, 2, 1]]}],
       SeriesData[x, x0, {
         sig11[x0, y, z], 
         Derivative[1, 0, 0][sig11][x0, y, z]}, 0, 2, 1]], 
      InterpretationBox[
       RowBox[{
        RowBox[{"sig12", "[", 
         RowBox[{"x0", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["sig12", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y", ",", "z"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"x", "-", "x0"}], "]"}], "2"],
         SeriesData[x, x0, {}, 0, 2, 1]]}],
       SeriesData[x, x0, {
         sig12[x0, y, z], 
         Derivative[1, 0, 0][sig12][x0, y, z]}, 0, 2, 1]], 
      InterpretationBox[
       RowBox[{
        RowBox[{"sig13", "[", 
         RowBox[{"x0", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["sig13", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y", ",", "z"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"x", "-", "x0"}], "]"}], "2"],
         SeriesData[x, x0, {}, 0, 2, 1]]}],
       SeriesData[x, x0, {
         sig13[x0, y, z], 
         Derivative[1, 0, 0][sig13][x0, y, z]}, 0, 2, 1]]},
     {
      InterpretationBox[
       RowBox[{
        RowBox[{"sig12", "[", 
         RowBox[{"x0", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["sig12", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y", ",", "z"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"x", "-", "x0"}], "]"}], "2"],
         SeriesData[x, x0, {}, 0, 2, 1]]}],
       SeriesData[x, x0, {
         sig12[x0, y, z], 
         Derivative[1, 0, 0][sig12][x0, y, z]}, 0, 2, 1]], 
      InterpretationBox[
       RowBox[{
        RowBox[{"sig22", "[", 
         RowBox[{"x0", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["sig22", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y", ",", "z"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"x", "-", "x0"}], "]"}], "2"],
         SeriesData[x, x0, {}, 0, 2, 1]]}],
       SeriesData[x, x0, {
         sig22[x0, y, z], 
         Derivative[1, 0, 0][sig22][x0, y, z]}, 0, 2, 1]], 
      InterpretationBox[
       RowBox[{
        RowBox[{"sig23", "[", 
         RowBox[{"x0", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["sig23", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y", ",", "z"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"x", "-", "x0"}], "]"}], "2"],
         SeriesData[x, x0, {}, 0, 2, 1]]}],
       SeriesData[x, x0, {
         sig23[x0, y, z], 
         Derivative[1, 0, 0][sig23][x0, y, z]}, 0, 2, 1]]},
     {
      InterpretationBox[
       RowBox[{
        RowBox[{"sig13", "[", 
         RowBox[{"x0", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["sig13", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y", ",", "z"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"x", "-", "x0"}], "]"}], "2"],
         SeriesData[x, x0, {}, 0, 2, 1]]}],
       SeriesData[x, x0, {
         sig13[x0, y, z], 
         Derivative[1, 0, 0][sig13][x0, y, z]}, 0, 2, 1]], 
      InterpretationBox[
       RowBox[{
        RowBox[{"sig23", "[", 
         RowBox[{"x0", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["sig23", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y", ",", "z"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"x", "-", "x0"}], "]"}], "2"],
         SeriesData[x, x0, {}, 0, 2, 1]]}],
       SeriesData[x, x0, {
         sig23[x0, y, z], 
         Derivative[1, 0, 0][sig23][x0, y, z]}, 0, 2, 1]], 
      InterpretationBox[
       RowBox[{
        RowBox[{"sig33", "[", 
         RowBox[{"x0", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["sig33", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y", ",", "z"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"x", "-", "x0"}], "]"}], "2"],
         SeriesData[x, x0, {}, 0, 2, 1]]}],
       SeriesData[x, x0, {
         sig33[x0, y, z], 
         Derivative[1, 0, 0][sig33][x0, y, z]}, 0, 2, 1]]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ex", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ey", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ez", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"resultant", " ", "=", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"stress", "[", 
       RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}], " ", ".", " ", 
      RowBox[{"(", 
       RowBox[{"-", "ex"}], ")"}]}], " ", 
     RowBox[{"(", 
      RowBox[{"y", " ", "-", " ", "y0"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "z0"}], ")"}]}], "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"stress", "[", 
       RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}], " ", ".", " ", 
      RowBox[{"(", 
       RowBox[{"-", "ey"}], ")"}]}], " ", 
     RowBox[{"(", 
      RowBox[{"x", " ", "-", " ", "x0"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "z0"}], ")"}]}], "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"stress", "[", 
       RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}], " ", ".", " ", 
      RowBox[{"(", 
       RowBox[{"-", "ez"}], ")"}]}], 
     RowBox[{"(", 
      RowBox[{"x", " ", "-", " ", "x0"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"y", " ", "-", " ", "y0"}], ")"}]}], "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Series", "[", " ", 
       RowBox[{
        RowBox[{"stress", "[", 
         RowBox[{"x", ",", "y0", ",", "z0"}], "]"}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"x", ",", "x0", ",", " ", "1"}], "}"}]}], "]"}], ".", " ", 
      "ex"}], "  ", 
     RowBox[{"(", 
      RowBox[{"y", " ", "-", " ", "y0"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "z0"}], ")"}]}], "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Series", "[", " ", 
       RowBox[{
        RowBox[{"stress", "[", 
         RowBox[{"x0", ",", "y", ",", "z0"}], "]"}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"y", ",", "y0", ",", " ", "1"}], "}"}]}], "]"}], ".", " ", 
      "ey"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", " ", "-", " ", "x0"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", " ", "-", " ", "z0"}], ")"}]}], " ", "+", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Series", "[", " ", 
       RowBox[{
        RowBox[{"stress", "[", 
         RowBox[{"x0", ",", "y0", ",", "z"}], "]"}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"z", ",", "z0", ",", " ", "1"}], "}"}]}], "]"}], ".", " ", 
      "ez"}], "  ", 
     RowBox[{"(", 
      RowBox[{"x", " ", "-", " ", "x0"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"y", " ", "-", " ", "y0"}], ")"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \
\\\"\\!\\(resultant\\)\\\" is similar to existing symbol \
\\\"\\!\\(Resultant\\)\\\".\"\>"}]], "Message"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "x0"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"y", "-", "y0"}], ")"}], " ", 
            RowBox[{"sig13", "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", "x0"}], ")"}], " ", 
               RowBox[{"sig12", "[", 
                RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", "x0"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"y", "-", "y0"}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["sig13", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"z", "-", "z0"}], ")"}]}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", 
              RowBox[{"z", "-", "z0"}], "]"}], "2"],
            SeriesData[z, z0, {}, 0, 2, 1]]}],
          SeriesData[
          z, z0, {(x - x0) (y - y0) 
            sig13[x0, y0, z0], (x - x0) sig12[x0, y0, z0] + (x - x0) (y - y0) 
             Derivative[0, 0, 1][sig13][x0, y0, z0]}, 0, 2, 1]], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"z", "-", "z0"}], ")"}], " ", 
            RowBox[{"sig11", "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
            RowBox[{"sig11", "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "x0"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"z", "-", "z0"}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["sig12", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "y0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"y", "-", "y0"}], "]"}], "2"],
         SeriesData[y, y0, {}, 0, 2, 1]]}],
       SeriesData[y, y0, {
         SeriesData[
         z, z0, {(x - x0) (y - y0) 
           sig13[x0, y0, z0], (x - x0) sig12[x0, y0, z0] + (x - x0) (y - y0) 
            Derivative[0, 0, 1][sig13][x0, y0, z0]}, 0, 2, 1], (z - z0) 
          sig11[x0, y0, z0] + (-z + z0) sig11[x0, y0, z0] + (x - x0) (z - z0) 
          Derivative[0, 1, 0][sig12][x0, y0, z0]}, 0, 2, 1]], ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
         RowBox[{"sig12", "[", 
          RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "y"}], "+", "y0"}], ")"}], " ", 
         RowBox[{"sig13", "[", 
          RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"y", "-", "y0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "z0"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sig11", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        RowBox[{"x", "-", "x0"}], "]"}], "2"],
      SeriesData[x, x0, {}, 0, 2, 1]]}],
    SeriesData[x, x0, {
      SeriesData[y, y0, {
        SeriesData[
        z, z0, {(x - x0) (y - y0) 
          sig13[x0, y0, z0], (x - x0) sig12[x0, y0, z0] + (x - x0) (y - y0) 
           Derivative[0, 0, 1][sig13][x0, y0, z0]}, 0, 2, 1], (z - z0) 
         sig11[x0, y0, z0] + (-z + z0) sig11[x0, y0, z0] + (x - x0) (z - z0) 
         Derivative[0, 1, 0][sig12][x0, y0, z0]}, 0, 2, 1], (-z + z0) 
       sig12[x0, y0, z0] + (-y + y0) sig13[x0, y0, z0] + (y - y0) (z - z0) 
       Derivative[1, 0, 0][sig11][x0, y0, z0]}, 0, 2, 1]], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "x0"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"y", "-", "y0"}], ")"}], " ", 
            RowBox[{"sig23", "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", "x0"}], ")"}], " ", 
               RowBox[{"sig22", "[", 
                RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", "x0"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"y", "-", "y0"}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["sig23", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"z", "-", "z0"}], ")"}]}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", 
              RowBox[{"z", "-", "z0"}], "]"}], "2"],
            SeriesData[z, z0, {}, 0, 2, 1]]}],
          SeriesData[
          z, z0, {(x - x0) (y - y0) 
            sig23[x0, y0, z0], (x - x0) sig22[x0, y0, z0] + (x - x0) (y - y0) 
             Derivative[0, 0, 1][sig23][x0, y0, z0]}, 0, 2, 1]], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"z", "-", "z0"}], ")"}], " ", 
            RowBox[{"sig12", "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
            RowBox[{"sig12", "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "x0"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"z", "-", "z0"}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["sig22", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "y0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"y", "-", "y0"}], "]"}], "2"],
         SeriesData[y, y0, {}, 0, 2, 1]]}],
       SeriesData[y, y0, {
         SeriesData[
         z, z0, {(x - x0) (y - y0) 
           sig23[x0, y0, z0], (x - x0) sig22[x0, y0, z0] + (x - x0) (y - y0) 
            Derivative[0, 0, 1][sig23][x0, y0, z0]}, 0, 2, 1], (z - z0) 
          sig12[x0, y0, z0] + (-z + z0) sig12[x0, y0, z0] + (x - x0) (z - z0) 
          Derivative[0, 1, 0][sig22][x0, y0, z0]}, 0, 2, 1]], ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
         RowBox[{"sig22", "[", 
          RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "y"}], "+", "y0"}], ")"}], " ", 
         RowBox[{"sig23", "[", 
          RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"y", "-", "y0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "z0"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sig12", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        RowBox[{"x", "-", "x0"}], "]"}], "2"],
      SeriesData[x, x0, {}, 0, 2, 1]]}],
    SeriesData[x, x0, {
      SeriesData[y, y0, {
        SeriesData[
        z, z0, {(x - x0) (y - y0) 
          sig23[x0, y0, z0], (x - x0) sig22[x0, y0, z0] + (x - x0) (y - y0) 
           Derivative[0, 0, 1][sig23][x0, y0, z0]}, 0, 2, 1], (z - z0) 
         sig12[x0, y0, z0] + (-z + z0) sig12[x0, y0, z0] + (x - x0) (z - z0) 
         Derivative[0, 1, 0][sig22][x0, y0, z0]}, 0, 2, 1], (-z + z0) 
       sig22[x0, y0, z0] + (-y + y0) sig23[x0, y0, z0] + (y - y0) (z - z0) 
       Derivative[1, 0, 0][sig12][x0, y0, z0]}, 0, 2, 1]], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      InterpretationBox[
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "x0"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"y", "-", "y0"}], ")"}], " ", 
            RowBox[{"sig33", "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", "x0"}], ")"}], " ", 
               RowBox[{"sig23", "[", 
                RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", "x0"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"y", "-", "y0"}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["sig33", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"z", "-", "z0"}], ")"}]}], "+", 
           InterpretationBox[
            SuperscriptBox[
             RowBox[{"O", "[", 
              RowBox[{"z", "-", "z0"}], "]"}], "2"],
            SeriesData[z, z0, {}, 0, 2, 1]]}],
          SeriesData[
          z, z0, {(x - x0) (y - y0) 
            sig33[x0, y0, z0], (x - x0) sig23[x0, y0, z0] + (x - x0) (y - y0) 
             Derivative[0, 0, 1][sig33][x0, y0, z0]}, 0, 2, 1]], ")"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"z", "-", "z0"}], ")"}], " ", 
            RowBox[{"sig13", "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
            RowBox[{"sig13", "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x", "-", "x0"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"z", "-", "z0"}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["sig23", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"y", "-", "y0"}], ")"}]}], "+", 
        InterpretationBox[
         SuperscriptBox[
          RowBox[{"O", "[", 
           RowBox[{"y", "-", "y0"}], "]"}], "2"],
         SeriesData[y, y0, {}, 0, 2, 1]]}],
       SeriesData[y, y0, {
         SeriesData[
         z, z0, {(x - x0) (y - y0) 
           sig33[x0, y0, z0], (x - x0) sig23[x0, y0, z0] + (x - x0) (y - y0) 
            Derivative[0, 0, 1][sig33][x0, y0, z0]}, 0, 2, 1], (z - z0) 
          sig13[x0, y0, z0] + (-z + z0) sig13[x0, y0, z0] + (x - x0) (z - z0) 
          Derivative[0, 1, 0][sig23][x0, y0, z0]}, 0, 2, 1]], ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
         RowBox[{"sig23", "[", 
          RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "y"}], "+", "y0"}], ")"}], " ", 
         RowBox[{"sig33", "[", 
          RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"y", "-", "y0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "z0"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["sig13", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", 
        RowBox[{"x", "-", "x0"}], "]"}], "2"],
      SeriesData[x, x0, {}, 0, 2, 1]]}],
    SeriesData[x, x0, {
      SeriesData[y, y0, {
        SeriesData[
        z, z0, {(x - x0) (y - y0) 
          sig33[x0, y0, z0], (x - x0) sig23[x0, y0, z0] + (x - x0) (y - y0) 
           Derivative[0, 0, 1][sig33][x0, y0, z0]}, 0, 2, 1], (z - z0) 
         sig13[x0, y0, z0] + (-z + z0) sig13[x0, y0, z0] + (x - x0) (z - z0) 
         Derivative[0, 1, 0][sig23][x0, y0, z0]}, 0, 2, 1], (-z + z0) 
       sig23[x0, y0, z0] + (-y + y0) sig33[x0, y0, z0] + (y - y0) (z - z0) 
       Derivative[1, 0, 0][sig13][x0, y0, z0]}, 0, 2, 1]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Normal", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"resultant", " ", "/", "  ", 
        RowBox[{"(", 
         RowBox[{"x", " ", "-", " ", "x0"}], ")"}]}], " ", "/", "  ", 
       RowBox[{"(", 
        RowBox[{"y", " ", "-", " ", "y0"}], ")"}]}], "  ", "/", " ", 
      RowBox[{"(", 
       RowBox[{"z", " ", "-", " ", "z0"}], ")"}]}], "]"}], " ", "]"}], " ", 
   ")"}], "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sig13", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig12", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig11", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sig23", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig22", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig12", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["sig33", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig23", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}], "+", 
       RowBox[{
        SuperscriptBox["sig13", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"x0", ",", "y0", ",", "z0"}], "]"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   Derivative[0, 0, 1][sig13][x0, y0, z0] + 
    Derivative[0, 1, 0][sig12][x0, y0, z0] + 
    Derivative[1, 0, 0][sig11][x0, y0, z0], 
    Derivative[0, 0, 1][sig23][x0, y0, z0] + 
    Derivative[0, 1, 0][sig22][x0, y0, z0] + 
    Derivative[1, 0, 0][sig12][x0, y0, z0], 
    Derivative[0, 0, 1][sig33][x0, y0, z0] + 
    Derivative[0, 1, 0][sig23][x0, y0, z0] + 
    Derivative[1, 0, 0][sig13][x0, y0, z0]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", " ", "-", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Div", "[", 
      RowBox[{"stress", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}], " ", "/.", " ", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "->", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "y0", ",", "z0"}], "}"}]}], "]"}]}], ")"}]}], " ", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Series for equilibrium - other coordinate systems", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sig", "[", 
   RowBox[{"r_", ",", " ", "t_", ",", " ", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Outer", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"ToExpression", "[", " ", 
       RowBox[{"\"\<s\>\"", "<>", 
        RowBox[{"ToString", "[", "#1", "]"}], "<>", 
        RowBox[{"ToString", "[", " ", "#2", "]"}]}], " ", "]"}], "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "&"}], ",", "   ", 
    RowBox[{"Coordinates", "[", "]"}], " ", ",", "  ", 
    RowBox[{"Coordinates", "[", "]"}]}], " ", "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", " ", 
  RowBox[{"sig", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"srr", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"srt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"srz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]},
     {
      RowBox[{"str", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"stt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"stz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]},
     {
      RowBox[{"szr", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"szt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"szz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"difcoor", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"dr", ",", " ", "dt", " ", ",", "dz"}], " ", "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dr", ",", "dt", ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sides", " ", "=", " ", 
  RowBox[{"difcoor", "  ", 
   RowBox[{"ScaleFactors", "[", 
    RowBox[{"{", 
     RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dr", ",", 
   RowBox[{"dt", " ", "r"}], ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"volume", " ", "=", " ", 
   RowBox[{"8", " ", 
    RowBox[{"(", 
     RowBox[{"dr", " ", "r", " ", "dt", " ", "dz"}], ")"}]}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"8", " ", "dr", " ", "dt", " ", "dz", " ", "r"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ee", " ", "=", " ", 
  RowBox[{"IdentityMatrix", "[", "3", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sf", " ", "=", " ", 
  RowBox[{"ScaleFactors", "[", 
   RowBox[{"{", 
    RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "r", ",", "1"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "JacobianMatrix"}]], "Input"],

Cell[BoxData["\<\"JacobianMatrix[pt] gives the Jacobian matrix of  the \
transformation from the default coordinate system to the Cartesian  \
coordinate system at the point pt.  JacobianMatrix[pt, coordsys] gives the  \
Jacobian matrix of the transformation from the coordinate system coordsys  to \
the Cartesian coordinate system at the point pt.  If pt is not given,  the \
default coordinate variables are used.\"\>"], "Print",
 CellTags->"Info3308323525-6898963"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eecart", "=", " ", 
  RowBox[{"Map", "[", "   ", 
   RowBox[{
    RowBox[{
     RowBox[{"#", " ", "/", " ", 
      RowBox[{"ScaleFactors", "[", "]"}]}], " ", "&"}], " ", ",", " ", 
    RowBox[{"JacobianMatrix", "[", "]"}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "t", "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "t", "]"}], ",", 
     RowBox[{"Cos", "[", "t", "]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"trplus", " ", "=", " ", 
  RowBox[{"Normal", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{
         RowBox[{"r", " ", "+", " ", "dr"}], ",", "t", ",", "z"}], "]"}], ",",
        " ", 
       RowBox[{"{", 
        RowBox[{"dr", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], "  ", ".", 
     "  ", 
     RowBox[{"ee", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "  ", "2", " ", "dz", " ", 
    RowBox[{"(", " ", 
     RowBox[{"r", " ", "+", " ", "dr"}], ")"}], " ", "2", " ", "dt"}], "  ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"trminus", " ", "=", " ", 
  RowBox[{"Normal", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{
         RowBox[{"r", " ", "-", " ", "dr"}], ",", "t", ",", "z"}], "]"}], ",",
        " ", 
       RowBox[{"{", 
        RowBox[{"dr", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", ".", 
     "  ", 
     RowBox[{"ee", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "  ", "2", " ", "dz", " ", 
    RowBox[{"(", " ", 
     RowBox[{"r", " ", "-", " ", "dr"}], ")"}], " ", "2", " ", "dt"}], "  ", 
   "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
     RowBox[{"srr", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "dt", " ", "dz", " ", 
        RowBox[{"srr", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
       RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["srr", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
     RowBox[{"str", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "dt", " ", "dz", " ", 
        RowBox[{"str", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
       RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["str", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
     RowBox[{"szr", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "dt", " ", "dz", " ", 
        RowBox[{"szr", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
       RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["szr", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
     RowBox[{"srr", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "dt", " ", "dz", " ", 
        RowBox[{"srr", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "-", 
       RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["srr", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
     RowBox[{"str", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "dt", " ", "dz", " ", 
        RowBox[{"str", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "-", 
       RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["str", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
     RowBox[{"szr", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "dt", " ", "dz", " ", 
        RowBox[{"szr", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "-", 
       RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["szr", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ttplus", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", " ", 
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", 
         RowBox[{"t", " ", "+", " ", "dt"}], " ", ",", "z"}], "]"}], ",", " ",
        
       RowBox[{"{", 
        RowBox[{"dt", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", "]"}], 
    "  ", ".", "   ", 
    RowBox[{"ee", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "   ", "2", " ", "dz", " ", "2", " ", 
   "dr", " "}]}], "\[IndentingNewLine]", 
 RowBox[{"ttminus", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", " ", 
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", 
         RowBox[{"t", " ", "-", " ", "dt"}], " ", ",", "z"}], "]"}], ",", " ",
        
       RowBox[{"{", 
        RowBox[{"dt", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", "]"}], 
    ".", "  ", 
    RowBox[{"ee", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "   ", "2", " ", "dz", " ", "2", " ", 
   "dr", "  "}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"stt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["stt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"szt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["szt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"stt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["stt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"szt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["szt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tzplus", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", " ", 
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", "t", "  ", ",", 
         RowBox[{"z", " ", "+", " ", "dz"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"dz", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], "     ", 
     "]"}], "   ", ".", "   ", 
    RowBox[{"ee", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "  ", "2", " ", "dr", " ", "2", " ", 
   "r", " ", "dt", " "}]}], "\[IndentingNewLine]", 
 RowBox[{"tzminus", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", "  ", 
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", "t", "  ", ",", 
         RowBox[{"z", " ", "-", " ", "dz"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"dz", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", "]"}], 
    " ", ".", "   ", 
    RowBox[{"ee", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "  ", "2", " ", "dr", "  ", "2", " ", 
   "r", " ", "dt", "   "}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"stz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["stz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"szz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["szz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"stz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["stz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"szz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["szz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"rot", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ","}], "}"}], ",", 
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", "}"}]}], "}"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", " ", 
  RowBox[{
   RowBox[{"Normal", "[", " ", 
    RowBox[{
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", "t", "  ", ",", 
         RowBox[{"z", " ", "-", " ", "dz"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"dz", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], "   ", ".", 
     " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], "   ", "]"}], " ",
    "//", " ", "MatrixForm"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"srz", "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
       RowBox[{"dz", " ", 
        RowBox[{
         SuperscriptBox["srz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}]},
     {
      RowBox[{
       RowBox[{"stz", "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
       RowBox[{"dz", " ", 
        RowBox[{
         SuperscriptBox["stz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}]},
     {
      RowBox[{
       RowBox[{"szz", "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
       RowBox[{"dz", " ", 
        RowBox[{
         SuperscriptBox["szz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   srz[r, t, z] - dz Derivative[0, 0, 1][srz][r, t, z], stz[r, t, z] - dz 
    Derivative[0, 0, 1][stz][r, t, z], szz[r, t, z] - dz 
    Derivative[0, 0, 1][szz][r, t, z]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"ee", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "2"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", " ", 
   RowBox[{"res", " ", "=", " ", 
    RowBox[{"Simplify", "[", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
       "trplus", " ", "+", " ", "trminus", " ", "+", " ", "ttplus", " ", "+", 
        " ", "ttminus", " ", "+", " ", "tzplus", " ", "+", " ", "tzminus"}], 
       "  ", ")"}], 
      RowBox[{"fr", " ", "/", " ", 
       RowBox[{"(", 
        RowBox[{"dr", " ", "dt", " ", "dz"}], ")"}]}]}], " ", "]"}]}], " ", 
   ")"}], " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "r", " ", 
           RowBox[{"srr", "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dr"], "-", 
         RowBox[{"2", " ", 
          RowBox[{"srr", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
         FractionBox[
          RowBox[{"srt", "[", 
           RowBox[{"r", ",", "t", ",", "z"}], "]"}], "dt"], "+", 
         FractionBox[
          RowBox[{"2", " ", "dt", " ", "r", " ", 
           RowBox[{"srt", "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dr"], "+", 
         FractionBox[
          RowBox[{"srt", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}], "dt"], "-", 
         RowBox[{"dt", " ", 
          RowBox[{"srt", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
         FractionBox[
          RowBox[{"4", " ", "r", " ", 
           RowBox[{"srz", "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dz"], "+", 
         RowBox[{
          SuperscriptBox["srt", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], ")"}]}]},
     {
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "r", " ", 
           RowBox[{"str", "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dr"], "-", 
         RowBox[{"2", " ", 
          RowBox[{"str", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
         FractionBox[
          RowBox[{"stt", "[", 
           RowBox[{"r", ",", "t", ",", "z"}], "]"}], "dt"], "+", 
         FractionBox[
          RowBox[{"2", " ", "dt", " ", "r", " ", 
           RowBox[{"stt", "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dr"], "+", 
         FractionBox[
          RowBox[{"stt", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}], "dt"], "-", 
         RowBox[{"dt", " ", 
          RowBox[{"stt", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
         FractionBox[
          RowBox[{"4", " ", "r", " ", 
           RowBox[{"stz", "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dz"], "+", 
         RowBox[{
          SuperscriptBox["stt", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], ")"}]}]},
     {
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "r", " ", 
           RowBox[{"szr", "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dr"], "-", 
         RowBox[{"2", " ", 
          RowBox[{"szr", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
         FractionBox[
          RowBox[{"szt", "[", 
           RowBox[{"r", ",", "t", ",", "z"}], "]"}], "dt"], "+", 
         FractionBox[
          RowBox[{"2", " ", "dt", " ", "r", " ", 
           RowBox[{"szt", "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dr"], "+", 
         FractionBox[
          RowBox[{"szt", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}], "dt"], "-", 
         RowBox[{"dt", " ", 
          RowBox[{"szt", "[", 
           RowBox[{"r", ",", 
            RowBox[{
             RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
         FractionBox[
          RowBox[{"4", " ", "r", " ", 
           RowBox[{"szz", "[", 
            RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dz"], "+", 
         RowBox[{
          SuperscriptBox["szt", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], ")"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   4 (2 dr^(-1) r srr[r, t, z] - 2 srr[r, -dt + t, z] + dt^(-1) srt[r, t, z] + 
     2 dr^(-1) dt r srt[r, t, z] + dt^(-1) srt[r, -dt + t, z] - dt 
     srt[r, -dt + t, z] + 4 dz^(-1) r srz[r, t, z] + 
     Derivative[0, 1, 0][srt][r, t, z]), 
    4 (2 dr^(-1) r str[r, t, z] - 2 str[r, -dt + t, z] + dt^(-1) stt[r, t, z] + 
     2 dr^(-1) dt r stt[r, t, z] + dt^(-1) stt[r, -dt + t, z] - dt 
     stt[r, -dt + t, z] + 4 dz^(-1) r stz[r, t, z] + 
     Derivative[0, 1, 0][stt][r, t, z]), 
    4 (2 dr^(-1) r szr[r, t, z] - 2 szr[r, -dt + t, z] + dt^(-1) szt[r, t, z] + 
     2 dr^(-1) dt r szt[r, t, z] + dt^(-1) szt[r, -dt + t, z] - dt 
     szt[r, -dt + t, z] + 4 dz^(-1) r szz[r, t, z] + 
     Derivative[0, 1, 0][szt][r, t, z])}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", " ", 
  RowBox[{
   RowBox[{"SeriesCoefficient", "[", " ", 
    RowBox[{"res", ",", " ", "1"}], " ", "]"}], ",", " ", 
   RowBox[{"dt", " ", "\[Rule]", " ", "0"}]}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"SeriesCoefficient", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        RowBox[{
         FractionBox[
          InterpretationBox[
           RowBox[{
            FractionBox[
             InterpretationBox[
              RowBox[{
               FractionBox[
                RowBox[{"2", " ", "dr", " ", "dt", " ", 
                 RowBox[{"srz", "[", 
                  RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dz"], "+", 
               FractionBox[
                RowBox[{"dr", " ", 
                 RowBox[{"srt", "[", 
                  RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], 
                RowBox[{"2", " ", "r"}]], "+", 
               InterpretationBox[
                SuperscriptBox[
                 RowBox[{"O", "[", "dz", "]"}], "1"],
                SeriesData[dz, 0, {}, -1, 1, 1],
                Editable->False]}],
              SeriesData[
              dz, 0, {2 dr dt srz[r, t, z], Rational[1, 2] dr r^(-1) 
                srt[r, t, z]}, -1, 1, 1],
              Editable->False], "dt"], "+", 
            FractionBox[
             RowBox[{
              RowBox[{"8", " ", "dz", " ", "r", " ", 
               RowBox[{"srr", "[", 
                RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
              RowBox[{"4", " ", "dr", " ", "dz", " ", 
               RowBox[{
                SuperscriptBox["srt", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], 
             RowBox[{"8", " ", "dz", " ", "r"}]], "+", 
            InterpretationBox[
             SuperscriptBox[
              RowBox[{"O", "[", "dt", "]"}], "1"],
             SeriesData[dt, 0, {}, -1, 1, 1],
             Editable->False]}],
           SeriesData[dt, 0, {
             SeriesData[
             dz, 0, {2 dr dt srz[r, t, z], Rational[1, 2] dr r^(-1) 
               srt[r, t, z]}, -1, 1, 1], Rational[1, 8] dz^(-1) 
             r^(-1) (8 dz r srr[r, t, z] + 
              4 dr dz Derivative[0, 1, 0][srt][r, t, z])}, -1, 1, 1],
           Editable->False], "dr"], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"8", " ", "dt", " ", "dz", " ", "r"}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "dt", " ", "dz", " ", 
             RowBox[{"srr", "[", 
              RowBox[{"r", ",", 
               RowBox[{
                RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
            RowBox[{"4", " ", "dz", " ", 
             RowBox[{"srt", "[", 
              RowBox[{"r", ",", 
               RowBox[{
                RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["dt", "2"], " ", "dz", " ", 
             RowBox[{"srt", "[", 
              RowBox[{"r", ",", 
               RowBox[{
                RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
            RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox["srr", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "-", 
               RowBox[{"dt", " ", 
                RowBox[{
                 SuperscriptBox["srt", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["srr", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
               RowBox[{"dt", " ", 
                RowBox[{
                 SuperscriptBox["srt", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", "dr", "]"}], "1"],
          SeriesData[dr, 0, {}, -1, 1, 1],
          Editable->False]}],
        SeriesData[dr, 0, {
          SeriesData[dt, 0, {
            SeriesData[
            dz, 0, {2 dr dt srz[r, t, z], Rational[1, 2] dr r^(-1) 
              srt[r, t, z]}, -1, 1, 1], Rational[1, 8] dz^(-1) 
            r^(-1) (8 dz r srr[r, t, z] + 
             4 dr dz Derivative[0, 1, 0][srt][r, t, z])}, -1, 1, 1], 
          Rational[1, 8] dt^(-1) dz^(-1) 
          r^(-1) ((-8) dt dz srr[r, -dt + t, z] + 4 dz srt[r, -dt + t, z] - 4 
           dt^2 dz srt[r, -dt + t, z] + 
           4 dt dz r (-Derivative[1, 0, 0][srr][r, t, z] - dt 
             Derivative[1, 0, 0][srt][r, t, z]) + 
           4 dt dz r (Derivative[1, 0, 0][srr][r, t, z] + 
             dt Derivative[1, 0, 0][srt][r, t, z]))}, -1, 1, 1],
        Editable->False], ",", 
       InterpretationBox[
        RowBox[{
         FractionBox[
          InterpretationBox[
           RowBox[{
            FractionBox[
             InterpretationBox[
              RowBox[{
               FractionBox[
                RowBox[{"2", " ", "dr", " ", "dt", " ", 
                 RowBox[{"stz", "[", 
                  RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dz"], "+", 
               FractionBox[
                RowBox[{"dr", " ", 
                 RowBox[{"stt", "[", 
                  RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], 
                RowBox[{"2", " ", "r"}]], "+", 
               InterpretationBox[
                SuperscriptBox[
                 RowBox[{"O", "[", "dz", "]"}], "1"],
                SeriesData[dz, 0, {}, -1, 1, 1],
                Editable->False]}],
              SeriesData[
              dz, 0, {2 dr dt stz[r, t, z], Rational[1, 2] dr r^(-1) 
                stt[r, t, z]}, -1, 1, 1],
              Editable->False], "dt"], "+", 
            FractionBox[
             RowBox[{
              RowBox[{"8", " ", "dz", " ", "r", " ", 
               RowBox[{"str", "[", 
                RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
              RowBox[{"4", " ", "dr", " ", "dz", " ", 
               RowBox[{
                SuperscriptBox["stt", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], 
             RowBox[{"8", " ", "dz", " ", "r"}]], "+", 
            InterpretationBox[
             SuperscriptBox[
              RowBox[{"O", "[", "dt", "]"}], "1"],
             SeriesData[dt, 0, {}, -1, 1, 1],
             Editable->False]}],
           SeriesData[dt, 0, {
             SeriesData[
             dz, 0, {2 dr dt stz[r, t, z], Rational[1, 2] dr r^(-1) 
               stt[r, t, z]}, -1, 1, 1], Rational[1, 8] dz^(-1) 
             r^(-1) (8 dz r str[r, t, z] + 
              4 dr dz Derivative[0, 1, 0][stt][r, t, z])}, -1, 1, 1],
           Editable->False], "dr"], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"8", " ", "dt", " ", "dz", " ", "r"}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "dt", " ", "dz", " ", 
             RowBox[{"str", "[", 
              RowBox[{"r", ",", 
               RowBox[{
                RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
            RowBox[{"4", " ", "dz", " ", 
             RowBox[{"stt", "[", 
              RowBox[{"r", ",", 
               RowBox[{
                RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["dt", "2"], " ", "dz", " ", 
             RowBox[{"stt", "[", 
              RowBox[{"r", ",", 
               RowBox[{
                RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
            RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox["str", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "-", 
               RowBox[{"dt", " ", 
                RowBox[{
                 SuperscriptBox["stt", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["str", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
               RowBox[{"dt", " ", 
                RowBox[{
                 SuperscriptBox["stt", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", "dr", "]"}], "1"],
          SeriesData[dr, 0, {}, -1, 1, 1],
          Editable->False]}],
        SeriesData[dr, 0, {
          SeriesData[dt, 0, {
            SeriesData[
            dz, 0, {2 dr dt stz[r, t, z], Rational[1, 2] dr r^(-1) 
              stt[r, t, z]}, -1, 1, 1], Rational[1, 8] dz^(-1) 
            r^(-1) (8 dz r str[r, t, z] + 
             4 dr dz Derivative[0, 1, 0][stt][r, t, z])}, -1, 1, 1], 
          Rational[1, 8] dt^(-1) dz^(-1) 
          r^(-1) ((-8) dt dz str[r, -dt + t, z] + 4 dz stt[r, -dt + t, z] - 4 
           dt^2 dz stt[r, -dt + t, z] + 
           4 dt dz r (-Derivative[1, 0, 0][str][r, t, z] - dt 
             Derivative[1, 0, 0][stt][r, t, z]) + 
           4 dt dz r (Derivative[1, 0, 0][str][r, t, z] + 
             dt Derivative[1, 0, 0][stt][r, t, z]))}, -1, 1, 1],
        Editable->False], ",", 
       InterpretationBox[
        RowBox[{
         FractionBox[
          InterpretationBox[
           RowBox[{
            FractionBox[
             InterpretationBox[
              RowBox[{
               FractionBox[
                RowBox[{"2", " ", "dr", " ", "dt", " ", 
                 RowBox[{"szz", "[", 
                  RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "dz"], "+", 
               FractionBox[
                RowBox[{"dr", " ", 
                 RowBox[{"szt", "[", 
                  RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], 
                RowBox[{"2", " ", "r"}]], "+", 
               InterpretationBox[
                SuperscriptBox[
                 RowBox[{"O", "[", "dz", "]"}], "1"],
                SeriesData[dz, 0, {}, -1, 1, 1],
                Editable->False]}],
              SeriesData[
              dz, 0, {2 dr dt szz[r, t, z], Rational[1, 2] dr r^(-1) 
                szt[r, t, z]}, -1, 1, 1],
              Editable->False], "dt"], "+", 
            FractionBox[
             RowBox[{
              RowBox[{"8", " ", "dz", " ", "r", " ", 
               RowBox[{"szr", "[", 
                RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
              RowBox[{"4", " ", "dr", " ", "dz", " ", 
               RowBox[{
                SuperscriptBox["szt", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], 
             RowBox[{"8", " ", "dz", " ", "r"}]], "+", 
            InterpretationBox[
             SuperscriptBox[
              RowBox[{"O", "[", "dt", "]"}], "1"],
             SeriesData[dt, 0, {}, -1, 1, 1],
             Editable->False]}],
           SeriesData[dt, 0, {
             SeriesData[
             dz, 0, {2 dr dt szz[r, t, z], Rational[1, 2] dr r^(-1) 
               szt[r, t, z]}, -1, 1, 1], Rational[1, 8] dz^(-1) 
             r^(-1) (8 dz r szr[r, t, z] + 
              4 dr dz Derivative[0, 1, 0][szt][r, t, z])}, -1, 1, 1],
           Editable->False], "dr"], "+", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"8", " ", "dt", " ", "dz", " ", "r"}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "dt", " ", "dz", " ", 
             RowBox[{"szr", "[", 
              RowBox[{"r", ",", 
               RowBox[{
                RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
            RowBox[{"4", " ", "dz", " ", 
             RowBox[{"szt", "[", 
              RowBox[{"r", ",", 
               RowBox[{
                RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["dt", "2"], " ", "dz", " ", 
             RowBox[{"szt", "[", 
              RowBox[{"r", ",", 
               RowBox[{
                RowBox[{"-", "dt"}], "+", "t"}], ",", "z"}], "]"}]}], "+", 
            RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                 SuperscriptBox["szr", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "-", 
               RowBox[{"dt", " ", 
                RowBox[{
                 SuperscriptBox["szt", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["szr", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
               RowBox[{"dt", " ", 
                RowBox[{
                 SuperscriptBox["szt", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", "dr", "]"}], "1"],
          SeriesData[dr, 0, {}, -1, 1, 1],
          Editable->False]}],
        SeriesData[dr, 0, {
          SeriesData[dt, 0, {
            SeriesData[
            dz, 0, {2 dr dt szz[r, t, z], Rational[1, 2] dr r^(-1) 
              szt[r, t, z]}, -1, 1, 1], Rational[1, 8] dz^(-1) 
            r^(-1) (8 dz r szr[r, t, z] + 
             4 dr dz Derivative[0, 1, 0][szt][r, t, z])}, -1, 1, 1], 
          Rational[1, 8] dt^(-1) dz^(-1) 
          r^(-1) ((-8) dt dz szr[r, -dt + t, z] + 4 dz szt[r, -dt + t, z] - 4 
           dt^2 dz szt[r, -dt + t, z] + 
           4 dt dz r (-Derivative[1, 0, 0][szr][r, t, z] - dt 
             Derivative[1, 0, 0][szt][r, t, z]) + 
           4 dt dz r (Derivative[1, 0, 0][szr][r, t, z] + 
             dt Derivative[1, 0, 0][szt][r, t, z]))}, -1, 1, 1],
        Editable->False]}], "}"}], ",", "1"}], "]"}], ",", 
   RowBox[{"dt", "\[Rule]", "0"}]}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", ".", " ", 
       RowBox[{"ee0", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "3", "]"}], "]"}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], " ", "+", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Series", "[", " ", 
       RowBox[{
        RowBox[{"sig", "[", 
         RowBox[{"r", ",", 
          RowBox[{"t", " ", "+", " ", "dt"}], ",", "z"}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"dt", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], ".", " ", 
      RowBox[{"ee", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], " ", 
     RowBox[{"sides", "[", 
      RowBox[{"[", "3", "]"}], "]"}], " ", 
     RowBox[{"sides", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"dr", " ", "dz", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"srr", "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["srt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], ")"}], " ", "dt"}], "+", 
     
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "dt", "]"}], "2"],
      SeriesData[dt, 0, {}, 1, 2, 1],
      Editable->False]}],
    SeriesData[
    dt, 0, {dr dz (-srr[r, t, z] + Derivative[0, 1, 0][srt][r, t, z])}, 1, 2, 
     1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"dr", " ", "dz", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"str", "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["stt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], ")"}], " ", "dt"}], "+", 
     
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "dt", "]"}], "2"],
      SeriesData[dt, 0, {}, 1, 2, 1],
      Editable->False]}],
    SeriesData[
    dt, 0, {dr dz (-str[r, t, z] + Derivative[0, 1, 0][stt][r, t, z])}, 1, 2, 
     1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"dr", " ", "dz", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"szr", "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["szt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], ")"}], " ", "dt"}], "+", 
     
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "dt", "]"}], "2"],
      SeriesData[dt, 0, {}, 1, 2, 1],
      Editable->False]}],
    SeriesData[
    dt, 0, {dr dz (-szr[r, t, z] + Derivative[0, 1, 0][szt][r, t, z])}, 1, 2, 
     1],
    Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3", " ", "=", " ", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", ".", " ", 
       RowBox[{"ee0", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}]}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "  ", "+", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Series", "[", " ", 
       RowBox[{
        RowBox[{"sig", "[", 
         RowBox[{"r", ",", "t", ",", 
          RowBox[{"z", "+", "dz"}]}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"dz", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], ".", " ", 
      RowBox[{"ee", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], " ", 
     RowBox[{"sides", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", 
     RowBox[{"sides", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"dr", " ", "dt", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "dr"}], "+", "r"}], ")"}], " ", 
      RowBox[{"srz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
     RowBox[{"2", " ", "dr", " ", "dt", " ", 
      RowBox[{"(", 
       RowBox[{"dr", "+", "r"}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["srz", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "dz"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "dz", "]"}], "2"],
      SeriesData[dz, 0, {}, 0, 2, 1],
      Editable->False]}],
    SeriesData[
    dz, 0, {dr dt (2 dr + r) srz[r, t, z], 2 dr dt (dr + r) 
      Derivative[0, 0, 1][srz][r, t, z]}, 0, 2, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"dr", " ", "dt", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "dr"}], "+", "r"}], ")"}], " ", 
      RowBox[{"stz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
     RowBox[{"2", " ", "dr", " ", "dt", " ", 
      RowBox[{"(", 
       RowBox[{"dr", "+", "r"}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["stz", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "dz"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "dz", "]"}], "2"],
      SeriesData[dz, 0, {}, 0, 2, 1],
      Editable->False]}],
    SeriesData[
    dz, 0, {dr dt (2 dr + r) stz[r, t, z], 2 dr dt (dr + r) 
      Derivative[0, 0, 1][stz][r, t, z]}, 0, 2, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"dr", " ", "dt", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "dr"}], "+", "r"}], ")"}], " ", 
      RowBox[{"szz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
     RowBox[{"2", " ", "dr", " ", "dt", " ", 
      RowBox[{"(", 
       RowBox[{"dr", "+", "r"}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["szz", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "dz"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "dz", "]"}], "2"],
      SeriesData[dz, 0, {}, 0, 2, 1],
      Editable->False]}],
    SeriesData[
    dz, 0, {dr dt (2 dr + r) szz[r, t, z], 2 dr dt (dr + r) 
      Derivative[0, 0, 1][szz][r, t, z]}, 0, 2, 1],
    Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", " ", 
   RowBox[{
    RowBox[{"Normal", "[", " ", 
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{"a1", " ", "+", " ", "a2", " ", "+", " ", "a3"}], ")"}], " ", 
      "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}], "  ", "/", " ", "volume"}], 
   "]"}], " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "dr"}], "+", "r"}], ")"}], " ", 
     RowBox[{"srz", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
    RowBox[{"dz", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"dr", "+", "r"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["srz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
       RowBox[{"r", " ", 
        RowBox[{
         SuperscriptBox["srr", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
   RowBox[{"dz", " ", "r"}]],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"a1", "[", 
    RowBox[{"[", "1", "]"}], "]"}], " ", "+", " ", 
   RowBox[{"a2", "[", 
    RowBox[{"[", "1", "]"}], "]"}], " ", "+", " ", 
   RowBox[{"a3", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], " ", "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "z0"}], ")"}], " ", 
       RowBox[{"srr", "[", 
        RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
       RowBox[{"srt", "[", 
        RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "-", 
      RowBox[{"r0", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"srz", "[", 
          RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["srr", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}]}], ")"}]}]}], ")"}], 
    " ", 
    RowBox[{"(", 
     RowBox[{"r", "-", "r0"}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      RowBox[{"r", "-", "r0"}], "]"}], "2"],
    SeriesData[r, r0, {}, 1, 2, 1],
    Editable->False]}],
  SeriesData[
  r, r0, {(t - t0) (z - z0) srr[r0, t0, z0] + (-z + z0) srt[r0, t0, z0] - 
    r0 (t - t0) (
     srz[r0, t0, z0] + (-z + z0) Derivative[1, 0, 0][srr][r0, t0, z0])}, 1, 2,
    1],
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", " ", 
  RowBox[{
   RowBox[{"%", " ", "/", "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "-", "r0"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"z", "-", "z0"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", "t0"}], ")"}]}], ")"}]}], ",", " ", 
   RowBox[{"r", " ", "\[Rule]", " ", "r0"}], ",", " ", 
   RowBox[{"t", "->", "t0"}], ",", " ", 
   RowBox[{"z", "\[Rule]", "z0"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t", "-", "t0"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", "z0"}], ")"}], " ", 
      RowBox[{"srr", "[", 
       RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
      RowBox[{"srt", "[", 
       RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "-", 
     RowBox[{"r0", " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", "t0"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"srz", "[", 
         RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["srr", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}]}], ")"}]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"t", "-", "t0"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "z0"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t", "-", "t0"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", "z0"}], ")"}], " ", 
      RowBox[{"str", "[", 
       RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
      RowBox[{"stt", "[", 
       RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "-", 
     RowBox[{"r0", " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", "t0"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"stz", "[", 
         RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["str", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}]}], ")"}]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"t", "-", "t0"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "z0"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t", "-", "t0"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"z", "-", "z0"}], ")"}], " ", 
      RowBox[{"szr", "[", 
       RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
      RowBox[{"szt", "[", 
       RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "-", 
     RowBox[{"r0", " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", "t0"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"szz", "[", 
         RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "z"}], "+", "z0"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["szr", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}]}], ")"}]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"t", "-", "t0"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "z0"}], ")"}]}]]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"Expand", "[", " ", 
   RowBox[{"resultant", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "    ", "]"}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"r", "-", "r0"}], ")"}], " ", "r0", " ", 
          RowBox[{"(", 
           RowBox[{"t", "-", "t0"}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["srz", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", "z0"}], ")"}]}], "+", 
         InterpretationBox[
          SuperscriptBox[
           RowBox[{"O", "[", 
            RowBox[{"z", "-", "z0"}], "]"}], "2"],
          SeriesData[z, z0, {}, 1, 2, 1],
          Editable->False]}],
        SeriesData[
        z, z0, {(r - r0) r0 (t - t0) Derivative[0, 0, 1][srz][r0, t0, z0]}, 1,
          2, 1],
        Editable->False], ")"}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "-", "r0"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "z0"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["srt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"t", "-", "t0"}], ")"}]}], "r0"], "+", 
      InterpretationBox[
       SuperscriptBox[
        RowBox[{"O", "[", 
         RowBox[{"t", "-", "t0"}], "]"}], "2"],
       SeriesData[t, t0, {}, 0, 2, 1],
       Editable->False]}],
     SeriesData[t, t0, {
       SeriesData[
       z, z0, {(r - r0) r0 (t - t0) Derivative[0, 0, 1][srz][r0, t0, z0]}, 1, 
        2, 1], (r - r0) r0^(-1) (z - z0) 
       Derivative[0, 1, 0][srt][r0, t0, z0]}, 0, 2, 1],
     Editable->False], ")"}], "+", 
   RowBox[{"r0", " ", 
    RowBox[{"(", 
     RowBox[{"t", "-", "t0"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"z", "-", "z0"}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["srr", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"r", "-", "r0"}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      RowBox[{"r", "-", "r0"}], "]"}], "2"],
    SeriesData[r, r0, {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[r, r0, {
    SeriesData[t, t0, {
      SeriesData[
      z, z0, {(r - r0) r0 (t - t0) Derivative[0, 0, 1][srz][r0, t0, z0]}, 1, 
       2, 1], (r - r0) r0^(-1) (z - z0) Derivative[0, 1, 0][srt][r0, t0, z0]},
      0, 2, 1], r0 (t - t0) (z - z0) Derivative[1, 0, 0][srr][r0, t0, z0]}, 0,
    2, 1],
  Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sides0", "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", 
  RowBox[{"sides0", "[", 
   RowBox[{"[", "2", "]"}], "]"}], "  ", 
  RowBox[{"sides0", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"r", "-", "r0"}], ")"}], " ", "r0", " ", 
  RowBox[{"(", 
   RowBox[{"t", "-", "t0"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"z", "-", "z0"}], ")"}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"resultant", " ", "/", " ", 
         RowBox[{"sides0", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "/", " ", 
        RowBox[{"sides0", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], " ", "/", " ", 
       RowBox[{"sides0", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "  ", "]"}], " ", "]"}], " ", ")"}],
    "//", " ", "MatrixForm"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "r0"], "+", 
          FractionBox["2", 
           RowBox[{
            RowBox[{"-", "r"}], "+", "r0"}]]}], ")"}], " ", 
        RowBox[{"srr", "[", 
         RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "z0"}], ")"}], " ", 
          RowBox[{"srt", "[", 
           RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"t", "-", "t0"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", 
             RowBox[{"srz", "[", 
              RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z", "-", "z0"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r", " ", 
                RowBox[{
                 SuperscriptBox["srz", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["srt", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], "+", 
               RowBox[{"r0", " ", 
                RowBox[{
                 SuperscriptBox["srr", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], 
        RowBox[{"r0", " ", 
         RowBox[{"(", 
          RowBox[{"t", "-", "t0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "z0"}], ")"}]}]]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "r0"], "+", 
          FractionBox["2", 
           RowBox[{
            RowBox[{"-", "r"}], "+", "r0"}]]}], ")"}], " ", 
        RowBox[{"str", "[", 
         RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "z0"}], ")"}], " ", 
          RowBox[{"stt", "[", 
           RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"t", "-", "t0"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", 
             RowBox[{"stz", "[", 
              RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z", "-", "z0"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r", " ", 
                RowBox[{
                 SuperscriptBox["stz", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["stt", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], "+", 
               RowBox[{"r0", " ", 
                RowBox[{
                 SuperscriptBox["str", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], 
        RowBox[{"r0", " ", 
         RowBox[{"(", 
          RowBox[{"t", "-", "t0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "z0"}], ")"}]}]]}]},
     {
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "r0"], "+", 
          FractionBox["2", 
           RowBox[{
            RowBox[{"-", "r"}], "+", "r0"}]]}], ")"}], " ", 
        RowBox[{"szr", "[", 
         RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"z", "-", "z0"}], ")"}], " ", 
          RowBox[{"szt", "[", 
           RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"t", "-", "t0"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", 
             RowBox[{"szz", "[", 
              RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"z", "-", "z0"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r", " ", 
                RowBox[{
                 SuperscriptBox["szz", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["szt", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], "+", 
               RowBox[{"r0", " ", 
                RowBox[{
                 SuperscriptBox["szr", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], 
        RowBox[{"r0", " ", 
         RowBox[{"(", 
          RowBox[{"t", "-", "t0"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"z", "-", "z0"}], ")"}]}]]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{(r0^(-1) + 2/(-r + r0)) srr[r0, t0, z0] + 
    r0^(-1) (t - t0)^(-1) (z - z0)^(-1) ((z - z0) 
       srt[r0, t0, z0] + (t - t0) (
        r srz[r0, t0, z0] + (z - z0) (r Derivative[0, 0, 1][srz][r0, t0, z0] + 
          Derivative[0, 1, 0][srt][r0, t0, z0] + 
          r0 Derivative[1, 0, 0][srr][r0, t0, z0]))), (r0^(-1) + 2/(-r + r0)) 
     str[r0, t0, z0] + 
    r0^(-1) (t - t0)^(-1) (z - z0)^(-1) ((z - z0) 
       stt[r0, t0, z0] + (t - t0) (
        r stz[r0, t0, z0] + (z - z0) (r Derivative[0, 0, 1][stz][r0, t0, z0] + 
          Derivative[0, 1, 0][stt][r0, t0, z0] + 
          r0 Derivative[1, 0, 0][str][r0, t0, z0]))), (r0^(-1) + 2/(-r + r0)) 
     szr[r0, t0, z0] + 
    r0^(-1) (t - t0)^(-1) (z - z0)^(-1) ((z - z0) 
       szt[r0, t0, z0] + (t - t0) (
        r szz[r0, t0, z0] + (z - z0) (r Derivative[0, 0, 1][szz][r0, t0, z0] + 
          Derivative[0, 1, 0][szt][r0, t0, z0] + 
          r0 Derivative[1, 0, 0][szr][r0, t0, z0])))}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", " ", "-", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Div", "[", 
      RowBox[{"sig", "[", 
       RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}], " ", "/.", " ", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r", ",", "t", ",", "p"}], "}"}], "->", 
       RowBox[{"{", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "}"}]}], "]"}]}], ")"}]}], " ", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "r0"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"srr", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"stt", "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["srt", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], "-", 
      RowBox[{
       SuperscriptBox["str", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "-", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["srr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["srr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "r0"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"srt", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
       RowBox[{"str", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "-", 
       RowBox[{"r0", " ", 
        RowBox[{
         SuperscriptBox["stz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["stt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "-", 
       RowBox[{
        SuperscriptBox["stt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], "+", 
       RowBox[{"r0", " ", 
        RowBox[{
         SuperscriptBox["srt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "-", 
       RowBox[{"r0", " ", 
        RowBox[{
         SuperscriptBox["str", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    FractionBox["1", "r0"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"srz", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["szz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["stz", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{
       SuperscriptBox["szt", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}], "-", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["szr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "z0"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", "  ", 
   RowBox[{
    RowBox[{"Div", "[", 
     RowBox[{"sig", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r", ",", "t", ",", "p"}], "}"}], "->", 
      RowBox[{"{", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "r0"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"spp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"srr", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Cot", "[", "t0", "]"}], " ", 
       RowBox[{"str", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "-", 
      RowBox[{"stt", "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{
       RowBox[{"Csc", "[", "t0", "]"}], " ", 
       RowBox[{
        SuperscriptBox["spr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["str", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["srr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "r0"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cot", "[", "t0", "]"}]}], " ", 
       RowBox[{"spp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"srt", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"str", "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{
       RowBox[{"Cot", "[", "t0", "]"}], " ", 
       RowBox[{"stt", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Csc", "[", "t0", "]"}], " ", 
       RowBox[{
        SuperscriptBox["spt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["stt", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "r0"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"spr", "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{
       RowBox[{"Cot", "[", "t0", "]"}], " ", 
       RowBox[{"spt", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"srp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Cot", "[", "t0", "]"}], " ", 
       RowBox[{"stp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Csc", "[", "t0", "]"}], " ", 
       RowBox[{
        SuperscriptBox["spp", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["stp", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["srp", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Spherical", "[", 
  RowBox[{"r", ",", "t", ",", "p"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "p"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "p", "]"}], " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sig", "[", 
   RowBox[{"r_", ",", " ", "t_", ",", " ", "p_"}], "]"}], " ", "=", " ", 
  RowBox[{"Outer", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"ToExpression", "[", " ", 
       RowBox[{"\"\<s\>\"", "<>", 
        RowBox[{"ToString", "[", "#1", "]"}], "<>", 
        RowBox[{"ToString", "[", " ", "#2", "]"}]}], " ", "]"}], "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], " ", "&"}], ",", "   ", 
    RowBox[{"Coordinates", "[", "]"}], " ", ",", "  ", 
    RowBox[{"Coordinates", "[", "]"}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"srr", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], ",", 
     RowBox[{"srt", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], ",", 
     RowBox[{"srp", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"str", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], ",", 
     RowBox[{"stt", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], ",", 
     RowBox[{"stp", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"spr", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], ",", 
     RowBox[{"spt", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], ",", 
     RowBox[{"spp", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"difcoor", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"r", " ", "-", " ", "r0"}], ",", " ", 
    RowBox[{"t", " ", "-", " ", "t0"}], " ", ",", " ", 
    RowBox[{"p", " ", "-", " ", "p0"}]}], " ", "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", "-", "r0"}], ",", 
   RowBox[{"t", "-", "t0"}], ",", 
   RowBox[{"p", "-", "p0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sides0", " ", "=", " ", 
  RowBox[{"difcoor", "  ", 
   RowBox[{"ScaleFactors", "[", 
    RowBox[{"{", 
     RowBox[{"r0", ",", "t0", ",", "p0"}], "}"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", "-", "r0"}], ",", 
   RowBox[{"r0", " ", 
    RowBox[{"(", 
     RowBox[{"t", "-", "t0"}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"p", "-", "p0"}], ")"}], " ", "r0", " ", 
    RowBox[{"Sin", "[", "t0", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sides", " ", "=", " ", 
  RowBox[{"difcoor", "  ", 
   RowBox[{"ScaleFactors", "[", 
    RowBox[{"{", 
     RowBox[{"r", ",", "t", ",", "p"}], "}"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", "-", "r0"}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"(", 
     RowBox[{"t", "-", "t0"}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"p", "-", "p0"}], ")"}], " ", "r", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ee", " ", "=", " ", 
  RowBox[{"IdentityMatrix", "[", "3", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"resultant", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sig", "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], " ", ".", "  ", 
      RowBox[{"(", 
       RowBox[{"-", " ", 
        RowBox[{"ee", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "2", "]"}], "]"}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "3", "]"}], "]"}]}], " ", "+", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"sig", "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], " ", ".", "  ", 
      RowBox[{"(", 
       RowBox[{"-", " ", 
        RowBox[{"ee", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "3", "]"}], "]"}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "+", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"sig", "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], " ", ".", "  ", 
      RowBox[{"(", 
       RowBox[{"-", " ", 
        RowBox[{"ee", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ")"}]}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "+", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Series", "[", " ", 
       RowBox[{
        RowBox[{"sig", "[", 
         RowBox[{"r", ",", "t0", ",", "p0"}], "]"}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r0", ",", " ", "1"}], "}"}]}], "]"}], ".", " ", 
      RowBox[{"ee", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "2", "]"}], "]"}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "3", "]"}], "]"}]}], "+", " ", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Series", "[", " ", 
       RowBox[{
        RowBox[{"sig", "[", 
         RowBox[{"r0", ",", "t", ",", "p0"}], "]"}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "t0", ",", " ", "1"}], "}"}]}], "]"}], ".", " ", 
      RowBox[{"ee", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "3", "]"}], "]"}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], " ", "+", " ", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{
      RowBox[{"Series", "[", " ", 
       RowBox[{
        RowBox[{"sig", "[", 
         RowBox[{"r0", ",", "t0", ",", "p"}], "]"}], " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{"p", ",", "p0", ",", " ", "1"}], "}"}]}], "]"}], ".", " ", 
      RowBox[{"ee", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", 
     RowBox[{"sides0", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", " ", 
  RowBox[{"Map", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", " ", 
       RowBox[{"ee", "[", 
        RowBox[{"[", 
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], " ", 
      RowBox[{"sides0", "[", 
       RowBox[{"[", 
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], " ", 
      RowBox[{"sides0", "[", 
       RowBox[{"[", 
        RowBox[{"#", "[", 
         RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], " ", "&"}], " ",
     ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "}"}]}], "]"}], 
  " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}]}], " ", 
      SuperscriptBox["r0", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", "t0"}], ")"}], " ", 
      RowBox[{"Sin", "[", "t0", "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", "r0"}], ")"}], " ", "r0", " ", 
      RowBox[{"Sin", "[", "t0", "]"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}]}], " ", "r0", " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", "t0"}], ")"}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"resultant", " ", "=", " ", 
  RowBox[{
   RowBox[{"Map", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Dot", "[", " ", 
       RowBox[{
        RowBox[{"sig", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], " ", ",", " ", "#"}], 
       "]"}], " ", "&"}], " ", ",", "    ", 
     RowBox[{"Map", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", " ", 
          RowBox[{"ee", "[", 
           RowBox[{"[", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], " ", 
         RowBox[{"sides0", "[", 
          RowBox[{"[", 
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], " ", 
         RowBox[{"sides0", "[", 
          RowBox[{"[", 
           RowBox[{"#", "[", 
            RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], " ", "&"}], 
       " ", ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "}"}]}], "]"}]}], " ", 
    "]"}], " ", "+", "\[IndentingNewLine]", "  ", 
   RowBox[{"+", " ", 
    RowBox[{"Map", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"Dot", "[", " ", 
        RowBox[{
         RowBox[{"sig", "[", 
          RowBox[{"r", ",", "t", ",", "p"}], "]"}], " ", ",", " ", "#"}], 
        "]"}], " ", "&"}], ",", "   ", 
      RowBox[{"Map", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"+", " ", 
           RowBox[{"ee", "[", 
            RowBox[{"[", 
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], " ", 
          RowBox[{"sides", "[", 
           RowBox[{"[", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], " ", 
          RowBox[{"sides", "[", 
           RowBox[{"[", 
            RowBox[{"#", "[", 
             RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], " ", "&"}], 
        " ", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "3", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "}"}]}], "]"}]}], " ", 
     "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"srr", "[", 
        RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", 
       SuperscriptBox["r0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t0", "]"}], " ", 
       RowBox[{"srr", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"str", "[", 
        RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", 
       SuperscriptBox["r0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t0", "]"}], " ", 
       RowBox[{"str", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"spr", "[", 
        RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", 
       SuperscriptBox["r0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t0", "]"}], " ", 
       RowBox[{"spr", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"srt", "[", 
        RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", "r0", " ", 
       RowBox[{"Sin", "[", "t0", "]"}], " ", 
       RowBox[{"srt", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"stt", "[", 
        RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", "r0", " ", 
       RowBox[{"Sin", "[", "t0", "]"}], " ", 
       RowBox[{"stt", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", 
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"spt", "[", 
        RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "-", "p0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", "r0", " ", 
       RowBox[{"Sin", "[", "t0", "]"}], " ", 
       RowBox[{"spt", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"srp", "[", 
        RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", "r0", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"srp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"stp", "[", 
        RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", "r0", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"stp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"spp", "[", 
        RowBox[{"r", ",", "t", ",", "p"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "-", "r0"}], ")"}], " ", "r0", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "t0"}], ")"}], " ", 
       RowBox[{"spp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"resultant", " ", "/", " ", 
         RowBox[{"sides0", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "/", " ", 
        RowBox[{"sides0", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], " ", "/", " ", 
       RowBox[{"sides0", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "  ", "]"}], " ", "]"}], " ", ")"}],
    "//", " ", "MatrixForm"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", "-", "p0"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["srp", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
          RowBox[{
           RowBox[{"Sin", "[", "t0", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["srt", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
             RowBox[{"r0", " ", 
              RowBox[{
               SuperscriptBox["srr", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], 
       RowBox[{"r", "-", "r0"}]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", "-", "p0"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["stp", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
          RowBox[{
           RowBox[{"Sin", "[", "t0", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["stt", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
             RowBox[{"r0", " ", 
              RowBox[{
               SuperscriptBox["str", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], 
       RowBox[{"r", "-", "r0"}]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p", "-", "p0"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["spp", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
          RowBox[{
           RowBox[{"Sin", "[", "t0", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["spt", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
             RowBox[{"r0", " ", 
              RowBox[{
               SuperscriptBox["spr", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], 
       RowBox[{"r", "-", "r0"}]]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{(p - p0) (r - r0)^(-1) (Derivative[0, 0, 1][srp][r0, t0, p0] + 
     Sin[t0] (Derivative[0, 1, 0][srt][r0, t0, p0] + 
       r0 Derivative[1, 0, 0][srr][r0, t0, p0])), (p - p0) (r - r0)^(-1) (
     Derivative[0, 0, 1][stp][r0, t0, p0] + 
     Sin[t0] (Derivative[0, 1, 0][stt][r0, t0, p0] + 
       r0 Derivative[1, 0, 0][str][r0, t0, p0])), (p - p0) (r - r0)^(-1) (
     Derivative[0, 0, 1][spp][r0, t0, p0] + 
     Sin[t0] (Derivative[0, 1, 0][spt][r0, t0, p0] + 
       r0 Derivative[1, 0, 0][spr][r0, t0, p0]))}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", " ", "-", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Div", "[", 
      RowBox[{"sig", "[", 
       RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}], " ", "/.", " ", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r", ",", "t", ",", "p"}], "}"}], "->", 
       RowBox[{"{", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "}"}]}], "]"}]}], ")"}]}], " ", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "r0"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "r"}], " ", "r0", " ", 
        RowBox[{"Cos", "[", "p", "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"spp", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"srr", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cot", "[", "t0", "]"}], " ", 
        RowBox[{"str", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"stt", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Csc", "[", "t0", "]"}], " ", 
        RowBox[{
         SuperscriptBox["spr", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["str", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
       RowBox[{"r0", " ", 
        RowBox[{
         SuperscriptBox["srr", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "r0"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "r"}], " ", "r0", " ", 
        RowBox[{"Sin", "[", "p", "]"}], " ", 
        RowBox[{"Sin", "[", "t", "]"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cot", "[", "t0", "]"}], " ", 
        RowBox[{"spp", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"srt", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"str", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cot", "[", "t0", "]"}], " ", 
        RowBox[{"stt", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Csc", "[", "t0", "]"}], " ", 
        RowBox[{
         SuperscriptBox["spt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["stt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
       RowBox[{"r0", " ", 
        RowBox[{
         SuperscriptBox["srt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "r0"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "r"}], " ", "r0", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"spr", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cot", "[", "t0", "]"}], " ", 
        RowBox[{"spt", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{"4", " ", 
        RowBox[{"srp", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cot", "[", "t0", "]"}], " ", 
        RowBox[{"stp", "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Csc", "[", "t0", "]"}], " ", 
        RowBox[{
         SuperscriptBox["spp", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["stp", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
       RowBox[{"r0", " ", 
        RowBox[{
         SuperscriptBox["srp", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"Simplify", "[", "  ", 
   RowBox[{
    RowBox[{"Div", "[", 
     RowBox[{"sig", "[", 
      RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}], " ", "/.", " ", 
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r", ",", "t", ",", "p"}], "}"}], "->", 
      RowBox[{"{", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "r0"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"spp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"srr", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Cot", "[", "t0", "]"}], " ", 
       RowBox[{"str", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "-", 
      RowBox[{"stt", "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{
       RowBox[{"Csc", "[", "t0", "]"}], " ", 
       RowBox[{
        SuperscriptBox["spr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["str", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["srr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "r0"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cot", "[", "t0", "]"}]}], " ", 
       RowBox[{"spp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"srt", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"str", "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{
       RowBox[{"Cot", "[", "t0", "]"}], " ", 
       RowBox[{"stt", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Csc", "[", "t0", "]"}], " ", 
       RowBox[{
        SuperscriptBox["spt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["stt", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "r0"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"spr", "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{
       RowBox[{"Cot", "[", "t0", "]"}], " ", 
       RowBox[{"spt", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"srp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Cot", "[", "t0", "]"}], " ", 
       RowBox[{"stp", "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"Csc", "[", "t0", "]"}], " ", 
       RowBox[{
        SuperscriptBox["spp", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["stp", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}], "+", 
      RowBox[{"r0", " ", 
       RowBox[{
        SuperscriptBox["srp", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r0", ",", "t0", ",", "p0"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Condensed",
WindowSize->{1016, 643},
WindowMargins->{{Automatic, 66}, {Automatic, 23}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3308323525-6898963"->{
  Cell[40870, 1245, 469, 6, 85, "Print",
   CellTags->"Info3308323525-6898963"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3308323525-6898963", 152635, 4620}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 65, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1421, 43, 332, 11, 55, "Input"],
Cell[1756, 56, 94, 1, 31, "Output"]
}, Open  ]],
Cell[1865, 60, 61, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[1951, 65, 137, 3, 32, "Input"],
Cell[2091, 70, 96, 2, 31, "Output"]
}, Open  ]],
Cell[2202, 75, 1090, 31, 55, "Input"],
Cell[CellGroupData[{
Cell[3317, 110, 226, 7, 32, "Input"],
Cell[3546, 119, 2920, 88, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6503, 212, 326, 9, 32, "Input"],
Cell[6832, 223, 7251, 214, 70, "Output"]
}, Open  ]],
Cell[14098, 440, 431, 14, 77, "Input"],
Cell[CellGroupData[{
Cell[14554, 458, 2615, 77, 143, "Input"],
Cell[17172, 537, 251, 6, 24, "Message"],
Cell[17426, 545, 15224, 401, 276, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32687, 951, 503, 14, 32, "Input"],
Cell[33193, 967, 2989, 91, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36219, 1063, 471, 14, 32, "Input"],
Cell[36693, 1079, 83, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36825, 1087, 69, 0, 53, "Subtitle"],
Cell[CellGroupData[{
Cell[36919, 1091, 139, 3, 32, "Input"],
Cell[37061, 1096, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37196, 1103, 132, 3, 32, "Input"],
Cell[37331, 1108, 195, 6, 31, "Output"]
}, Open  ]],
Cell[37541, 1117, 584, 14, 55, "Input"],
Cell[CellGroupData[{
Cell[38150, 1135, 132, 3, 32, "Input"],
Cell[38285, 1140, 867, 26, 60, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39189, 1171, 140, 3, 32, "Input"],
Cell[39332, 1176, 86, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39455, 1183, 194, 5, 32, "Input"],
Cell[39652, 1190, 110, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39799, 1198, 201, 6, 55, "Input"],
Cell[40003, 1206, 83, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40123, 1212, 101, 2, 32, "Input"],
Cell[40227, 1216, 260, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40524, 1229, 163, 4, 32, "Input"],
Cell[40690, 1235, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40810, 1242, 57, 1, 32, "Input"],
Cell[40870, 1245, 469, 6, 85, "Print",
 CellTags->"Info3308323525-6898963"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41376, 1256, 272, 7, 32, "Input"],
Cell[41651, 1265, 414, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42102, 1283, 1237, 36, 55, "Input"],
Cell[43342, 1321, 2111, 60, 78, "Output"],
Cell[45456, 1383, 2183, 63, 78, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47676, 1451, 1094, 32, 55, "Input"],
Cell[48773, 1485, 1430, 45, 56, "Output"],
Cell[50206, 1532, 1430, 45, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51673, 1582, 1108, 30, 55, "Input"],
Cell[52784, 1614, 1460, 45, 56, "Output"],
Cell[54247, 1661, 1460, 45, 56, "Output"]
}, Open  ]],
Cell[55722, 1709, 204, 7, 32, "Input"],
Cell[CellGroupData[{
Cell[55951, 1720, 543, 15, 55, "Input"],
Cell[56497, 1737, 1504, 46, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58038, 1788, 115, 3, 55, "Input"],
Cell[58156, 1793, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58276, 1800, 527, 14, 55, "Input"],
Cell[58806, 1816, 5416, 142, 88, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64259, 1963, 224, 5, 32, "Input"],
Cell[64486, 1970, 17208, 418, 346, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81731, 2393, 1038, 29, 55, "Input"],
Cell[82772, 2424, 2459, 80, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85268, 2509, 1029, 29, 55, "Input"],
Cell[86300, 2540, 2870, 86, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89207, 2631, 356, 10, 32, "Input"],
Cell[89566, 2643, 1321, 43, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90924, 2691, 289, 8, 32, "Input"],
Cell[91216, 2701, 1643, 52, 55, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92896, 2758, 478, 14, 32, "Input"],
Cell[93377, 2774, 3710, 119, 146, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97124, 2898, 174, 4, 32, "Input"],
Cell[97301, 2904, 3000, 90, 71, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100338, 2999, 231, 7, 32, "Input"],
Cell[100572, 3008, 215, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100824, 3020, 546, 15, 55, "Input"],
Cell[101373, 3037, 7793, 210, 118, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[109203, 3252, 468, 14, 32, "Input"],
Cell[109674, 3268, 5015, 157, 189, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114726, 3430, 439, 13, 55, "Input"],
Cell[115168, 3445, 4413, 135, 189, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119618, 3585, 137, 3, 32, "Input"],
Cell[119758, 3590, 96, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119891, 3597, 132, 3, 32, "Input"],
Cell[120026, 3602, 335, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[120398, 3617, 583, 14, 55, "Input"],
Cell[120984, 3633, 890, 26, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121911, 3664, 250, 6, 32, "Input"],
Cell[122164, 3672, 158, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122359, 3682, 198, 5, 32, "Input"],
Cell[122560, 3689, 305, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122902, 3704, 194, 5, 32, "Input"],
Cell[123099, 3711, 302, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123438, 3726, 101, 2, 32, "Input"],
Cell[123542, 3730, 260, 8, 31, "Output"]
}, Open  ]],
Cell[123817, 3741, 26, 0, 32, "Input"],
Cell[123846, 3743, 2936, 82, 143, "Input"],
Cell[CellGroupData[{
Cell[126807, 3829, 885, 28, 55, "Input"],
Cell[127695, 3859, 897, 29, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128629, 3893, 2496, 73, 143, "Input"],
Cell[131128, 3968, 5519, 162, 180, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136684, 4135, 546, 15, 55, "Input"],
Cell[137233, 4152, 4496, 126, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141766, 4283, 468, 14, 32, "Input"],
Cell[142237, 4299, 5141, 151, 189, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147415, 4455, 439, 13, 55, "Input"],
Cell[147857, 4470, 4413, 135, 189, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

