(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     47267,       1576]
NotebookOptionsPosition[     43773,       1451]
NotebookOutlinePosition[     44144,       1467]
CellTagsIndexPosition[     44101,       1464]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Series for equilibrium", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "SetDirectory", "[", 
   "\"\<C:\\A1\\AMK04\\elastica\\ElasticaBook\\Packages\>\"", "]"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", 
    "\"\</local/constant/Oxford/Tex/ElasticaBook/Packages\>\"", "]"}], " ", 
   "*)"}]}]}], "Input"],

Cell[BoxData["\<\"C:\\\\A1\\\\AMK04\\\\elastica\\\\ElasticaBook\\\\Packages\"\
\>"], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Series for equilibrium - in cylindrical  coordinate \
systems",
 FontFamily->"Courier"]], "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesToCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", " ", 
    RowBox[{"Cos", "[", "t", "]"}]}], ",", 
   RowBox[{"r", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}], ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sig", "[", 
   RowBox[{"r_", ",", " ", "t_", ",", " ", "z_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Outer", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"ToExpression", "[", " ", 
       RowBox[{"\"\<s\>\"", "<>", 
        RowBox[{"ToString", "[", "#1", "]"}], "<>", 
        RowBox[{"ToString", "[", " ", "#2", "]"}]}], " ", "]"}], "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], " ", "&"}], ",", "   ", 
    RowBox[{"Coordinates", "[", "]"}], " ", ",", "  ", 
    RowBox[{"Coordinates", "[", "]"}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sig", " ", "[", 
    RowBox[{"r_", ",", " ", "t_", ",", " ", "z_"}], "]"}], "  ", ":=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"srr", "[", 
        RowBox[{"r", ",", " ", "t", ",", "z"}], "]"}], ",", 
       RowBox[{"srt", "[", 
        RowBox[{"r", ",", " ", "t", ",", "z"}], "]"}], ",", 
       RowBox[{"srz", "[", 
        RowBox[{"r", ",", " ", "t", ",", "z"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"srt", "[", 
        RowBox[{"r", ",", " ", "t", ",", "z"}], "]"}], ",", 
       RowBox[{"stt", "[", 
        RowBox[{"r", ",", " ", "t", ",", "z"}], "]"}], ",", 
       RowBox[{"stz", "[", 
        RowBox[{"r", ",", " ", "t", ",", "z"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"srz", "[", 
        RowBox[{"r", ",", " ", "t", ",", "z"}], "]"}], ",", 
       RowBox[{"stz", "[", 
        RowBox[{"r", ",", " ", "t", ",", "z"}], "]"}], ",", 
       RowBox[{"szz", "[", 
        RowBox[{"r", ",", " ", "t", ",", "z"}], "]"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"MatrixForm", "[", " ", 
  RowBox[{"sig", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", " ", 
  RowBox[{"Div", "[", 
   RowBox[{"sig", "[", 
    RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}], "]"}]}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"srr", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"srt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"srz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]},
     {
      RowBox[{"srt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"stt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"stz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]},
     {
      RowBox[{"srz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"stz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], 
      RowBox[{"szz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[#]& ]], "Output"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{"srr", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "-", 
       FractionBox[
        RowBox[{"stt", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["srt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"srt", "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "r"], "+", 
       RowBox[{
        SuperscriptBox["stz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["stt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{"srz", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["szz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["stz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   r^(-1) srr[r, t, z] - r^(-1) stt[r, t, z] + 
    Derivative[0, 0, 1][srz][r, t, z] + 
    r^(-1) Derivative[0, 1, 0][srt][r, t, z] + 
    Derivative[1, 0, 0][srr][r, t, z], 2 r^(-1) srt[r, t, z] + 
    Derivative[0, 0, 1][stz][r, t, z] + 
    r^(-1) Derivative[0, 1, 0][stt][r, t, z] + 
    Derivative[1, 0, 0][srt][r, t, z], r^(-1) srz[r, t, z] + 
    Derivative[0, 0, 1][szz][r, t, z] + 
    r^(-1) Derivative[0, 1, 0][stz][r, t, z] + 
    Derivative[1, 0, 0][srz][r, t, z]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"difcoor", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"dr", ",", " ", "dt", " ", ",", "dz"}], " ", "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dr", ",", "dt", ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sides", " ", "=", " ", 
  RowBox[{"difcoor", "  ", 
   RowBox[{"ScaleFactors", "[", 
    RowBox[{"{", 
     RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"dr", ",", 
   RowBox[{"dt", " ", "r"}], ",", "dz"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"volume", " ", "=", " ", 
   RowBox[{"8", " ", 
    RowBox[{"(", 
     RowBox[{"dr", " ", "r", " ", "dt", " ", "dz"}], ")"}]}]}], 
  "\[IndentingNewLine]"}]], "Input"],

Cell[BoxData[
 RowBox[{"8", " ", "dr", " ", "dt", " ", "dz", " ", "r"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ee", " ", "=", " ", 
  RowBox[{"IdentityMatrix", "[", "3", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sf", " ", "=", " ", 
  RowBox[{"ScaleFactors", "[", 
   RowBox[{"{", 
    RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "r", ",", "1"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "JacobianMatrix"}]], "Input"],

Cell[BoxData["\<\"JacobianMatrix[pt] gives the Jacobian matrix of the \
transformation from the default coordinate system to the Cartesian coordinate \
system at the point pt.  JacobianMatrix[pt, coordsys] gives the Jacobian \
matrix of the transformation from the coordinate system coordsys to the \
Cartesian coordinate system at the point pt.  If pt is not given, the default \
coordinate variables are used.\"\>"], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eecart", "=", " ", 
  RowBox[{"Map", "[", "   ", 
   RowBox[{
    RowBox[{
     RowBox[{"#", " ", "/", " ", 
      RowBox[{"ScaleFactors", "[", "]"}]}], " ", "&"}], " ", ",", " ", 
    RowBox[{"JacobianMatrix", "[", "]"}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "t", "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "t", "]"}], ",", 
     RowBox[{"Cos", "[", "t", "]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", " ", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x", "-", "dx"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"dx", ",", " ", "0", ",", "1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], "[", "x", "]"}], " ", "dx"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "dx", "]"}], "2"],
    SeriesData[dx, 0, {}, 0, 2, 1]]}],
  SeriesData[dx, 0, {
    f[x], -Derivative[1][f][x]}, 0, 2, 1]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", 
  RowBox[{"Series", "[", " ", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"x", "-", "dx"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"dx", ",", " ", "0", ",", "1"}], "}"}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x", "]"}], "-", 
  RowBox[{"dx", " ", 
   RowBox[{
    SuperscriptBox["f", "\[Prime]",
     MultilineFunction->None], "[", "x", "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"trplus", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", " ", 
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{
         RowBox[{"r", " ", "+", " ", "dr"}], ",", "t", ",", "z"}], "]"}], ",",
        " ", 
       RowBox[{"{", 
        RowBox[{"dr", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], "]"}], "  ", 
    ".", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "  ", "2", " ", "dz", " ", 
   RowBox[{"(", " ", 
    RowBox[{"r", " ", "+", " ", "dr"}], ")"}], " ", "2", " ", "dt", 
   "  "}]}], "\[IndentingNewLine]", 
 RowBox[{"trminus", " ", "=", " ", 
  RowBox[{"Normal", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{
         RowBox[{"r", " ", "-", " ", "dr"}], ",", "t", ",", "z"}], "]"}], ",",
        " ", 
       RowBox[{"{", 
        RowBox[{"dr", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], "  ", ".", 
     " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "  ", "2", " ", "dz", " ", 
    RowBox[{"(", " ", 
     RowBox[{"r", " ", "-", " ", "dr"}], ")"}], " ", "2", " ", "dt"}], "  ", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{"-", " ", "trplus"}], " ", "+", " ", "trminus"}], ")"}], " ", 
   "/", " ", "volume"}], " ", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", "dt", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{"dr", "+", "r"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srr", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dr", " ", 
       RowBox[{
        SuperscriptBox["srr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dt", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{"dr", "+", "r"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dr", " ", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dt", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{"dr", "+", "r"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dr", " ", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
     RowBox[{"srr", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "dt", " ", "dz", " ", 
        RowBox[{"srr", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "-", 
       RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["srr", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
     RowBox[{"srt", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "dt", " ", "dz", " ", 
        RowBox[{"srt", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "-", 
       RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["srt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
     RowBox[{"srz", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
    RowBox[{"dr", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "dt", " ", "dz", " ", 
        RowBox[{"srz", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "-", 
       RowBox[{"4", " ", "dt", " ", "dz", " ", "r", " ", 
        RowBox[{
         SuperscriptBox["srz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"srr", "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"dr", "+", 
         RowBox[{"2", " ", "r"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["srr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], 
     RowBox[{"2", " ", "r"}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"srt", "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"dr", "+", 
         RowBox[{"2", " ", "r"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], 
     RowBox[{"2", " ", "r"}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"srz", "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"dr", "+", 
         RowBox[{"2", " ", "r"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], 
     RowBox[{"2", " ", "r"}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ttplus", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", " ", 
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", 
         RowBox[{"t", " ", "+", " ", "dt"}], " ", ",", "z"}], "]"}], ",", " ",
        
       RowBox[{"{", 
        RowBox[{"dt", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", "]"}], 
    "  ", ".", "   ", 
    RowBox[{"ee", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "   ", "2", " ", "dz", " ", "2", " ", 
   "dr", " "}]}], "\[IndentingNewLine]", 
 RowBox[{"ttminus", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", " ", 
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", 
         RowBox[{"t", " ", "-", " ", "dt"}], " ", ",", "z"}], "]"}], ",", " ",
        
       RowBox[{"{", 
        RowBox[{"dt", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", "]"}], 
    ".", "  ", 
    RowBox[{"ee", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "   ", "2", " ", "dz", " ", "2", " ", 
   "dr", "  "}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"stt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["stt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"stz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["stz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"stt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["stt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dz", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"stz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dt", " ", 
       RowBox[{
        SuperscriptBox["stz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tzplus", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", " ", 
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", "t", "  ", ",", 
         RowBox[{"z", " ", "+", " ", "dz"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"dz", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], "     ", 
     "]"}], "   ", ".", "   ", 
    RowBox[{"ee", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "  ", "2", " ", "dr", " ", "2", " ", 
   "r", " ", "dt", " "}]}], "\[IndentingNewLine]", 
 RowBox[{"tzminus", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", "  ", 
     RowBox[{"Series", "[", " ", 
      RowBox[{
       RowBox[{"sig", "[", 
        RowBox[{"r", ",", "t", "  ", ",", 
         RowBox[{"z", " ", "-", " ", "dz"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"dz", ",", "0", ",", " ", "1"}], "}"}]}], "]"}], " ", "]"}], 
    " ", ".", "   ", 
    RowBox[{"ee", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "  ", "2", " ", "dr", "  ", "2", " ", 
   "r", " ", "dt", "   "}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"stz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["stz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"szz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["szz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"srz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"stz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["stz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{"4", " ", "dr", " ", "dt", " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"szz", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}], "-", 
      RowBox[{"dz", " ", 
       RowBox[{
        SuperscriptBox["szz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eecart", "=", " ", 
  RowBox[{"Map", "[", "   ", 
   RowBox[{
    RowBox[{
     RowBox[{"#", " ", "/", " ", 
      RowBox[{"ScaleFactors", "[", 
       RowBox[{"{", 
        RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}]}], " ", "&"}], " ", 
    ",", " ", 
    RowBox[{"JacobianMatrix", "[", 
     RowBox[{"{", 
      RowBox[{"r", ",", "t", ",", "z"}], "}"}], "]"}]}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "t", "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "t", "]"}], ",", 
     RowBox[{"Cos", "[", "t", "]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"deecart", "=", " ", 
  RowBox[{"Normal", "[", " ", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"Map", "[", "   ", 
      RowBox[{
       RowBox[{
        RowBox[{"#", " ", "/", " ", 
         RowBox[{"ScaleFactors", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"r", " ", "+", " ", "dr"}], ",", 
            RowBox[{"t", " ", "+", " ", "dt"}], ",", " ", 
            RowBox[{"z", " ", "+", " ", "dz"}]}], "}"}], "]"}]}], " ", "&"}], 
       " ", ",", " ", 
       RowBox[{"JacobianMatrix", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"r", " ", "+", " ", "dr"}], " ", ",", " ", 
          RowBox[{"t", " ", "+", " ", "dt"}], ",", " ", 
          RowBox[{"z", " ", "+", " ", "dz"}]}], "}"}], "]"}]}], " ", "]"}], 
     ",", " ", 
     RowBox[{"{", 
      RowBox[{"dr", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"dz", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"dt", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "t", "]"}], "-", 
      RowBox[{"dt", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "dt"}], " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "-", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"dt", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "+", 
      RowBox[{"Sin", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Cos", "[", "t", "]"}], "-", 
      RowBox[{"dt", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rot", "[", "dt_", "]"}], " ", "=", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"Normal", "[", " ", 
    RowBox[{"Series", "[", " ", 
     RowBox[{
      RowBox[{"eecart", " ", ".", " ", 
       RowBox[{"Inverse", "[", "deecart", "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"dt", ",", " ", "0", ",", "1"}], "}"}]}], " ", "]"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "dt", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "dt"}], ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rot", "[", " ", 
  RowBox[{"-", "dt"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "dt"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"dt", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"newdiv", " ", "=", " ", 
  RowBox[{"Expand", "[", " ", 
   RowBox[{"Limit", "[", " ", 
    RowBox[{
     RowBox[{"Expand", "[", " ", 
      RowBox[{
       RowBox[{"(", " ", 
        RowBox[{"trplus", " ", "-", " ", "trminus", " ", "+", "  ", 
         RowBox[{"ttplus", "  ", ".", " ", 
          RowBox[{"rot", "[", 
           RowBox[{"+", "dt"}], "]"}]}], "  ", "-", "  ", 
         RowBox[{"ttminus", "  ", ".", " ", 
          RowBox[{"rot", "[", " ", 
           RowBox[{"-", "dt"}], "]"}]}], "  ", "+", " ", "tzplus", " ", "-", 
         " ", "tzminus"}], "  ", ")"}], " ", "/", " ", "volume"}], "]"}], ",",
      " ", 
     RowBox[{"dr", " ", "\[Rule]", " ", "0"}]}], " ", "]"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"srr", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "-", 
    FractionBox[
     RowBox[{"stt", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
    RowBox[{
     SuperscriptBox["srz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["srt", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
    RowBox[{
     SuperscriptBox["srr", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"srt", "[", 
       RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "r"], "+", 
    RowBox[{
     SuperscriptBox["stz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["stt", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
    RowBox[{
     SuperscriptBox["srt", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"srz", "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
    RowBox[{
     SuperscriptBox["szz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["stz", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
    RowBox[{
     SuperscriptBox["srz", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"newdiv", " ", "//", " ", "MatrixForm"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{"srr", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "-", 
       FractionBox[
        RowBox[{"stt", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["srt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"srt", "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "r"], "+", 
       RowBox[{
        SuperscriptBox["stz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["stt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{"srz", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["szz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["stz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   r^(-1) srr[r, t, z] - r^(-1) stt[r, t, z] + 
    Derivative[0, 0, 1][srz][r, t, z] + 
    r^(-1) Derivative[0, 1, 0][srt][r, t, z] + 
    Derivative[1, 0, 0][srr][r, t, z], 2 r^(-1) srt[r, t, z] + 
    Derivative[0, 0, 1][stz][r, t, z] + 
    r^(-1) Derivative[0, 1, 0][stt][r, t, z] + 
    Derivative[1, 0, 0][srt][r, t, z], r^(-1) srz[r, t, z] + 
    Derivative[0, 0, 1][szz][r, t, z] + 
    r^(-1) Derivative[0, 1, 0][stz][r, t, z] + 
    Derivative[1, 0, 0][srz][r, t, z]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Div", "[", 
    RowBox[{"sig", "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}], " ", "//", " ", 
   "MatrixForm"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{"srr", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "-", 
       FractionBox[
        RowBox[{"stt", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["srt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srr", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"srt", "[", 
          RowBox[{"r", ",", "t", ",", "z"}], "]"}]}], "r"], "+", 
       RowBox[{
        SuperscriptBox["stz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["stt", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srt", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{"srz", "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["szz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["stz", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"r", ",", "t", ",", "z"}], "]"}], "r"], "+", 
       RowBox[{
        SuperscriptBox["srz", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t", ",", "z"}], "]"}]}]}
    }], "\[NoBreak]", ")"}],
  MatrixForm[{
   r^(-1) srr[r, t, z] - r^(-1) stt[r, t, z] + 
    Derivative[0, 0, 1][srz][r, t, z] + 
    r^(-1) Derivative[0, 1, 0][srt][r, t, z] + 
    Derivative[1, 0, 0][srr][r, t, z], 2 r^(-1) srt[r, t, z] + 
    Derivative[0, 0, 1][stz][r, t, z] + 
    r^(-1) Derivative[0, 1, 0][stt][r, t, z] + 
    Derivative[1, 0, 0][srt][r, t, z], r^(-1) srz[r, t, z] + 
    Derivative[0, 0, 1][szz][r, t, z] + 
    r^(-1) Derivative[0, 1, 0][stz][r, t, z] + 
    Derivative[1, 0, 0][srz][r, t, z]}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{"newdiv", " ", "-", " ", 
   RowBox[{"Div", "[", 
    RowBox[{"sig", "[", 
     RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]}], " ", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]]
},
PrintingStyleEnvironment->"Condensed",
WindowSize->{1016, 643},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 65, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1421, 43, 332, 11, 55, "Input"],
Cell[1756, 56, 94, 1, 31, "Output"]
}, Open  ]],
Cell[1865, 60, 97, 2, 55, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1999, 67, 125, 2, 53, "Subtitle"],
Cell[CellGroupData[{
Cell[2149, 73, 139, 3, 32, "Input"],
Cell[2291, 78, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2426, 85, 132, 3, 32, "Input"],
Cell[2561, 90, 195, 6, 31, "Output"]
}, Open  ]],
Cell[2771, 99, 584, 14, 55, "Input"],
Cell[3358, 115, 1125, 31, 55, "Input"],
Cell[CellGroupData[{
Cell[4508, 150, 299, 7, 55, "Input"],
Cell[4810, 159, 834, 25, 60, "Output"],
Cell[5647, 186, 3596, 108, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9280, 299, 140, 3, 32, "Input"],
Cell[9423, 304, 86, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9546, 311, 194, 5, 32, "Input"],
Cell[9743, 318, 110, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9890, 326, 201, 6, 55, "Input"],
Cell[10094, 334, 83, 1, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10214, 340, 101, 2, 32, "Input"],
Cell[10318, 344, 260, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10615, 357, 163, 4, 32, "Input"],
Cell[10781, 363, 83, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10901, 370, 57, 1, 32, "Input"],
Cell[10961, 373, 427, 5, 85, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11425, 383, 272, 7, 32, "Input"],
Cell[11700, 392, 414, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12151, 410, 212, 6, 32, "Input"],
Cell[12366, 418, 413, 13, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12816, 436, 250, 7, 32, "Input"],
Cell[13069, 445, 194, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13300, 456, 1454, 42, 77, "Input"],
Cell[14757, 500, 1616, 51, 56, "Output"],
Cell[16376, 553, 2183, 63, 78, "Output"],
Cell[18562, 618, 1766, 59, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20365, 682, 1094, 32, 55, "Input"],
Cell[21462, 716, 1430, 45, 56, "Output"],
Cell[22895, 763, 1430, 45, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24362, 813, 1108, 30, 55, "Input"],
Cell[25473, 845, 1460, 45, 56, "Output"],
Cell[26936, 892, 1460, 45, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28433, 942, 421, 13, 32, "Input"],
Cell[28857, 957, 414, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29308, 975, 1093, 29, 77, "Input"],
Cell[30404, 1006, 775, 25, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31216, 1036, 403, 11, 32, "Input"],
Cell[31622, 1049, 283, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31942, 1063, 80, 2, 32, "Input"],
Cell[32025, 1067, 283, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32345, 1081, 740, 18, 77, "Input"],
Cell[33088, 1101, 2761, 93, 126, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35886, 1199, 74, 1, 32, "Input"],
Cell[35963, 1202, 3596, 108, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39596, 1315, 190, 6, 32, "Input"],
Cell[39789, 1323, 3596, 108, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43422, 1436, 208, 5, 32, "Input"],
Cell[43633, 1443, 83, 2, 31, "Output"]
}, Open  ]],
Cell[43731, 1448, 26, 0, 32, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

