(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     10091,        343]
NotebookOptionsPosition[      9116,        304]
NotebookOutlinePosition[      9451,        319]
CellTagsIndexPosition[      9408,        316]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{
 RowBox[{Cell[TextData[{
   "This notebook forms part of the supporting material for the book\n\n",
   StyleBox[
   "Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. Korsunsky\n\
published by Cambridge University Press, 2007\n(ISBN-13: 9780521842013)\n",
    FontSlant->"Italic"],
   "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
  }], "Text",
   CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
    3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
    3.402068091731965*^9}}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "Transformation", " ", "of", " ", "stress", " ", "tensors", " ", "between",
     " ", "coordinate", " ", "systems"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"SetDirectory", "[", "myrootdir", "]"}]}], "Input",
 CellChangeTimes->{3.402069048297966*^9}],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\"\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<elastica\\Packages\>\"", "]"}]], "Input"],

Cell[BoxData["\<\"c:\\\\A1\\\\AMK06\\\\elastica\\\\Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Displacement.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CoordinatesFromCartesian", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["x", "2"], "+", 
     SuperscriptBox["y", "2"]}]], ",", 
   RowBox[{"ArcTan", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ",", "z"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Stress", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"srr", ",", "srt", ",", "srz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"srt", ",", "stt", ",", "stz"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"srz", ",", "stz", ",", "szz"}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressCar", "=", 
  RowBox[{"FieldToCartesian", "[", "Stress", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"srr", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "-", 
         RowBox[{"srt", " ", 
          RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"srt", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "-", 
         RowBox[{"stt", " ", 
          RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"srr", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "-", 
         RowBox[{"srt", " ", 
          RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"srt", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "-", 
         RowBox[{"stt", " ", 
          RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"srz", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "-", 
      RowBox[{"stz", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"srt", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "+", 
         RowBox[{"srr", " ", 
          RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"stt", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "+", 
         RowBox[{"srt", " ", 
          RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Sin", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"srt", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "+", 
         RowBox[{"srr", " ", 
          RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"stt", " ", 
          RowBox[{"Cos", "[", "t", "]"}]}], "+", 
         RowBox[{"srt", " ", 
          RowBox[{"Sin", "[", "t", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"stz", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "+", 
      RowBox[{"srz", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"srz", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "-", 
      RowBox[{"stz", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"stz", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}], "+", 
      RowBox[{"srz", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ",", "szz"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCoordinates", "[", 
   RowBox[{"Spherical", "[", 
    RowBox[{"a", ",", "p", ",", "t"}], "]"}], "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StressSph", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"FieldFromCartesian", "[", "StressCar", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"srr", "+", "szz", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "srr"}], "+", "szz"}], ")"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}], "+", 
        RowBox[{"2", " ", "srz", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "srz", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"srr", "-", "szz"}], ")"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"stz", " ", 
       RowBox[{"Cos", "[", "p", "]"}]}], "+", 
      RowBox[{"srt", " ", 
       RowBox[{"Sin", "[", "p", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "srz", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"srr", "-", "szz"}], ")"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"srr", "+", "szz", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"srr", "-", "szz"}], ")"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}], "-", 
        RowBox[{"2", " ", "srz", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "p"}], "]"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"srt", " ", 
       RowBox[{"Cos", "[", "p", "]"}]}], "-", 
      RowBox[{"stz", " ", 
       RowBox[{"Sin", "[", "p", "]"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"stz", " ", 
       RowBox[{"Cos", "[", "p", "]"}]}], "+", 
      RowBox[{"srt", " ", 
       RowBox[{"Sin", "[", "p", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"srt", " ", 
       RowBox[{"Cos", "[", "p", "]"}]}], "-", 
      RowBox[{"stz", " ", 
       RowBox[{"Sin", "[", "p", "]"}]}]}], ",", "stt"}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]]
},
WindowSize->{1131, 574},
WindowMargins->{{101, Automatic}, {Automatic, 23}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 1083, 21, 348, "Input"],
Cell[1676, 46, 52, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1765, 51, 90, 1, 32, "Input"],
Cell[1858, 54, 76, 0, 31, "Output"]
}, Open  ]],
Cell[1949, 57, 122, 2, 55, "Input"],
Cell[CellGroupData[{
Cell[2096, 63, 139, 3, 32, "Input"],
Cell[2238, 68, 98, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2373, 75, 134, 3, 32, "Input"],
Cell[2510, 80, 234, 8, 46, "Output"]
}, Open  ]],
Cell[2759, 91, 341, 11, 32, "Input"],
Cell[CellGroupData[{
Cell[3125, 106, 105, 2, 32, "Input"],
Cell[3233, 110, 3057, 97, 92, "Output"]
}, Open  ]],
Cell[6305, 210, 157, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[6487, 218, 146, 3, 32, "Input"],
Cell[6636, 223, 2464, 78, 263, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

