(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   7725857,     214120]
NotebookOptionsPosition[   7720916,     213960]
NotebookOutlinePosition[   7721399,     213979]
CellTagsIndexPosition[   7721356,     213976]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Mohr circles", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", 
    "\"\<C:\\A1\\AMK04\\elastica\\ElasticaBook\\Packages\>\"", "]"}], " ", 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[OutputFormData["\<\
\"/local/constant/ElasticaBook/Packages\"\
\>", "\<\
/local/constant/ElasticaBook/Packages\
\>"], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "Tensor2Analysis.m"}]], "Input"],

Cell[CellGroupData[{

Cell["sig = {{s1, 0, 0} , {0, s2, 0}, {0, 0, s3}}", "Input"],

Cell[OutputFormData["\<\
{{s1, 0, 0}, {0, s2, 0}, {0, 0, s3}}\
\>", "\<\
{{s1, 0, 0}, {0, s2, 0}, {0, 0, s3}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
n = {n1, n2, n3}
traction = sig . n \
\>", "Input"],

Cell[OutputFormData["\<\
{n1, n2, n3}\
\>", "\<\
{n1, n2, n3}\
\>"], "Output"],

Cell[OutputFormData["\<\
{n1*s1, n2*s2, n3*s3}\
\>", "\<\
{n1 s1, n2 s2, n3 s3}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
eq = { n . sig . n == sigma,
n1^2 + n2^2 + n3^2 == 1,
tau^2 + sigma^2 == traction . traction }

eq = eq /. Thread[ {n1^2, n2^2, n3^2} -> {n12, n22, n32} ]

Solve[ eq[[1]], {n12, n22, n32} ] \
\>", "Input"],

Cell[OutputFormData["\<\
{n1^2*s1 + n2^2*s2 + n3^2*s3 == sigma, n1^2 + n2^2 + n3^2 == 1, sigma^2 + \
tau^2 == n1^2*s1^2 + n2^2*s2^2 + n3^2*s3^2}\
\>", "\<\
   2        2        2                2     2     2            2      2      \
2   2     2   2     2   2
{n1  s1 + n2  s2 + n3  s3 == sigma, n1  + n2  + n3  == 1, sigma  + tau  == n1 \
 s1  + n2  s2  + n3  s3 }\
\>"], "Output"],

Cell[OutputFormData["\<\
{n12*s1 + n22*s2 + n32*s3 == sigma, n12 + n22 + n32 == 1, sigma^2 + tau^2 == \
n12*s1^2 + n22*s2^2 + n32*s3^2}\
\>", "\<\
                                                               2      2       \
   2         2         2
{n12 s1 + n22 s2 + n32 s3 == sigma, n12 + n22 + n32 == 1, sigma  + tau  == \
n12 s1  + n22 s2  + n32 s3 }\
\>"], "Output"],

Cell["\<\
Solve::svars: Equations may not give solutions for all \"solve\" variables. \
More\[Ellipsis]\
\>", "Message"],

Cell[OutputFormData["\<\
{{n12 -> -((n22*s2)/s1) - (n32*s3)/s1 + sigma/s1}}\
\>", "\<\
           n22 s2    n32 s3   sigma
{{n12 -> -(------) - ------ + -----}}
             s1        s1      s1\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
the Solve operation fails as the system has Det = 0 for in case like s1 = s2. \
We therefore compute the system in a step by step manner\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["mat = {{1, 1, 1},{s1,s2,s3},{s1^2,s2^2,s3^2}}", "Input"],

Cell[OutputFormData["\<\
{{1, 1, 1}, {s1, s2, s3}, {s1^2, s2^2, s3^2}}\
\>", "\<\
                             2    2    2
{{1, 1, 1}, {s1, s2, s3}, {s1 , s2 , s3 }}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Det[mat]", "Input"],

Cell[OutputFormData["\<\
-(s1^2*s2) + s1*s2^2 + s1^2*s3 - s2^2*s3 - s1*s3^2 + s2*s3^2\
\>", "\<\
    2            2     2        2           2        2
-(s1  s2) + s1 s2  + s1  s3 - s2  s3 - s1 s3  + s2 s3\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["invmat = Inverse[mat]", "Input"],

Cell[OutputFormData["\<\
{{(-(s2^2*s3) + s2*s3^2)/(-(s1^2*s2) + s1*s2^2 + s1^2*s3 - s2^2*s3 - s1*s3^2 \
+ s2*s3^2), 
  (s2^2 - s3^2)/(-(s1^2*s2) + s1*s2^2 + s1^2*s3 - s2^2*s3 - s1*s3^2 + \
s2*s3^2), 
  (-s2 + s3)/(-(s1^2*s2) + s1*s2^2 + s1^2*s3 - s2^2*s3 - s1*s3^2 + s2*s3^2)}, \

 {(s1^2*s3 - s1*s3^2)/(-(s1^2*s2) + s1*s2^2 + s1^2*s3 - s2^2*s3 - s1*s3^2 + \
s2*s3^2), 
  (-s1^2 + s3^2)/(-(s1^2*s2) + s1*s2^2 + s1^2*s3 - s2^2*s3 - s1*s3^2 + \
s2*s3^2), 
  (s1 - s3)/(-(s1^2*s2) + s1*s2^2 + s1^2*s3 - s2^2*s3 - s1*s3^2 + s2*s3^2)}, 
 {(-(s1^2*s2) + s1*s2^2)/(-(s1^2*s2) + s1*s2^2 + s1^2*s3 - s2^2*s3 - s1*s3^2 \
+ s2*s3^2), 
  (s1^2 - s2^2)/(-(s1^2*s2) + s1*s2^2 + s1^2*s3 - s2^2*s3 - s1*s3^2 + \
s2*s3^2), 
  (-s1 + s2)/(-(s1^2*s2) + s1*s2^2 + s1^2*s3 - s2^2*s3 - s1*s3^2 + s2*s3^2)}}\
\
\>", "\<\
                        2            2                                        \
    2     2
                    -(s2  s3) + s2 s3                                         \
  s2  - s3
{{------------------------------------------------------, \
------------------------------------------------------, 
      2            2     2        2           2        2      2            2  \
   2        2           2        2
  -(s1  s2) + s1 s2  + s1  s3 - s2  s3 - s1 s3  + s2 s3   -(s1  s2) + s1 s2  \
+ s1  s3 - s2  s3 - s1 s3  + s2 s3
 
                          -s2 + s3
   ------------------------------------------------------}, 
       2            2     2        2           2        2
   -(s1  s2) + s1 s2  + s1  s3 - s2  s3 - s1 s3  + s2 s3
 
                        2           2                                         \
      2     2
                      s1  s3 - s1 s3                                          \
   -s1  + s3
  {------------------------------------------------------, \
------------------------------------------------------, 
       2            2     2        2           2        2      2            2 \
    2        2           2        2
   -(s1  s2) + s1 s2  + s1  s3 - s2  s3 - s1 s3  + s2 s3   -(s1  s2) + s1 s2  \
+ s1  s3 - s2  s3 - s1 s3  + s2 s3
 
                          s1 - s3
   ------------------------------------------------------}, 
       2            2     2        2           2        2
   -(s1  s2) + s1 s2  + s1  s3 - s2  s3 - s1 s3  + s2 s3
 
                         2            2                                       \
     2     2
                     -(s1  s2) + s1 s2                                        \
   s1  - s2
  {------------------------------------------------------, \
------------------------------------------------------, 
       2            2     2        2           2        2      2            2 \
    2        2           2        2
   -(s1  s2) + s1 s2  + s1  s3 - s2  s3 - s1 s3  + s2 s3   -(s1  s2) + s1 s2  \
+ s1  s3 - s2  s3 - s1 s3  + s2 s3
 
                          -s1 + s2
   ------------------------------------------------------}}
       2            2     2        2           2        2
   -(s1  s2) + s1 s2  + s1  s3 - s2  s3 - s1 s3  + s2 s3\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
FullSimplify[ invmat . {1, sigma, sigma^2 + tau^2} ] // MatrixForm\
\>", "Input"],

Cell[OutputFormData["\<\
{((s2 - sigma)*(s3 - sigma) + tau^2)/((s1 - s2)*(s1 - s3)), ((s1 - \
sigma)*(-s3 + sigma) - tau^2)/((s1 - s2)*(s2 - s3)), 
 ((s1 - sigma)*(s2 - sigma) + tau^2)/((s1 - s3)*(s2 - s3))}\
\>", "\<\
                               2
(s2 - sigma) (s3 - sigma) + tau
--------------------------------
      (s1 - s2) (s1 - s3)

                                2
(s1 - sigma) (-s3 + sigma) - tau
---------------------------------
       (s1 - s2) (s2 - s3)

                               2
(s1 - sigma) (s2 - sigma) + tau
--------------------------------
      (s1 - s3) (s2 - s3)\
\>"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plotting covered in the Mohr plane", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"pos", " ", "=", " ", 
  RowBox[{"Coordinates", "[", "]"}]}]}], "Input"],

Cell[OutputFormData["\<\
Spherical[r, t, p]\
\>", "\<\
Spherical[r, t, p]\
\>"], "Output"],

Cell[OutputFormData["\<\
{r, t, p}\
\>", "\<\
{r, t, p}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["n = CoordinatesToCartesian[pos]/r", "Input"],

Cell[OutputFormData["\<\
{Cos[p]*Sin[t], Sin[p]*Sin[t], Cos[t]}\
\>", "\<\
{Cos[p] Sin[t], Sin[p] Sin[t], Cos[t]}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["traction = sig . n ", "Input"],

Cell[OutputFormData["\<\
{s1*Cos[p]*Sin[t], s2*Sin[p]*Sin[t], s3*Cos[t]}\
\>", "\<\
{s1 Cos[p] Sin[t], s2 Sin[p] Sin[t], s3 Cos[t]}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ns = n . traction
tau2 = traction . traction - ns^2  \
\>", "Input"],

Cell[OutputFormData["\<\
s3*Cos[t]^2 + s1*Cos[p]^2*Sin[t]^2 + s2*Sin[p]^2*Sin[t]^2\
\>", "\<\
         2            2       2            2       2
s3 Cos[t]  + s1 Cos[p]  Sin[t]  + s2 Sin[p]  Sin[t]\
\>"], "Output"],

Cell[OutputFormData["\<\
s3^2*Cos[t]^2 + s1^2*Cos[p]^2*Sin[t]^2 + s2^2*Sin[p]^2*Sin[t]^2 - \
(s3*Cos[t]^2 + s1*Cos[p]^2*Sin[t]^2 + s2*Sin[p]^2*Sin[t]^2)^2\
\>", "\<\
  2       2     2       2       2     2       2       2             2         \
   2       2            2       2 2
s3  Cos[t]  + s1  Cos[p]  Sin[t]  + s2  Sin[p]  Sin[t]  - (s3 Cos[t]  + s1 \
Cos[p]  Sin[t]  + s2 Sin[p]  Sin[t] )\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["srule = {s1 -> 5, s2 -> 2, s3 -> -1}", "Input"],

Cell[OutputFormData["\<\
{s1 -> 5, s2 -> 2, s3 -> -1}\
\>", "\<\
{s1 -> 5, s2 -> 2, s3 -> -1}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["f = { ns , tau2^0.5} /. srule ", "Input"],

Cell[OutputFormData["\<\
{-Cos[t]^2 + 5*Cos[p]^2*Sin[t]^2 + 2*Sin[p]^2*Sin[t]^2, (Cos[t]^2 + \
25*Cos[p]^2*Sin[t]^2 + 4*Sin[p]^2*Sin[t]^2 - 
   (-Cos[t]^2 + 5*Cos[p]^2*Sin[t]^2 + 2*Sin[p]^2*Sin[t]^2)^2)^0.5}\
\>", "\<\
        2           2       2           2       2         2            2      \
 2           2       2
{-Cos[t]  + 5 Cos[p]  Sin[t]  + 2 Sin[p]  Sin[t] , (Cos[t]  + 25 Cos[p]  \
Sin[t]  + 4 Sin[p]  Sin[t]  - 
 
             2           2       2           2       2 2 0.5
     (-Cos[t]  + 5 Cos[p]  Sin[t]  + 2 Sin[p]  Sin[t] ) )   }\
\>"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["use of the ParametricMesh.m package to plot the domain ", "Subsection"],

Cell["<< ParametricMesh.m", "Input"],

Cell[CellGroupData[{

Cell["\<\
ParametricMesh[ f , {t, 0, Pi, Pi / 30}, {p, 0, 2 Pi, Pi / 30}, Axes -> True, \
PlotRange -> All, AspectRatio -> Automatic]  \
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49726 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.15873 0.0118395 0.15873 [
[.02381 -0.00066 -6 -9 ]
[.02381 -0.00066 6 0 ]
[.34127 -0.00066 -3 -9 ]
[.34127 -0.00066 3 0 ]
[.5 -0.00066 -3 -9 ]
[.5 -0.00066 3 0 ]
[.65873 -0.00066 -3 -9 ]
[.65873 -0.00066 3 0 ]
[.81746 -0.00066 -3 -9 ]
[.81746 -0.00066 3 0 ]
[.97619 -0.00066 -3 -9 ]
[.97619 -0.00066 3 0 ]
[.17004 .0912 -18 -4.5 ]
[.17004 .0912 0 4.5 ]
[.17004 .17057 -6 -4.5 ]
[.17004 .17057 0 4.5 ]
[.17004 .24993 -18 -4.5 ]
[.17004 .24993 0 4.5 ]
[.17004 .3293 -6 -4.5 ]
[.17004 .3293 0 4.5 ]
[.17004 .40866 -18 -4.5 ]
[.17004 .40866 0 4.5 ]
[.17004 .48803 -6 -4.5 ]
[.17004 .48803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .49726 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01184 m
.02381 .01809 L
s
[(-1)] .02381 -0.00066 0 1 Mshowa
.34127 .01184 m
.34127 .01809 L
s
[(1)] .34127 -0.00066 0 1 Mshowa
.5 .01184 m
.5 .01809 L
s
[(2)] .5 -0.00066 0 1 Mshowa
.65873 .01184 m
.65873 .01809 L
s
[(3)] .65873 -0.00066 0 1 Mshowa
.81746 .01184 m
.81746 .01809 L
s
[(4)] .81746 -0.00066 0 1 Mshowa
.97619 .01184 m
.97619 .01809 L
s
[(5)] .97619 -0.00066 0 1 Mshowa
.125 Mabswid
.05556 .01184 m
.05556 .01559 L
s
.0873 .01184 m
.0873 .01559 L
s
.11905 .01184 m
.11905 .01559 L
s
.15079 .01184 m
.15079 .01559 L
s
.21429 .01184 m
.21429 .01559 L
s
.24603 .01184 m
.24603 .01559 L
s
.27778 .01184 m
.27778 .01559 L
s
.30952 .01184 m
.30952 .01559 L
s
.37302 .01184 m
.37302 .01559 L
s
.40476 .01184 m
.40476 .01559 L
s
.43651 .01184 m
.43651 .01559 L
s
.46825 .01184 m
.46825 .01559 L
s
.53175 .01184 m
.53175 .01559 L
s
.56349 .01184 m
.56349 .01559 L
s
.59524 .01184 m
.59524 .01559 L
s
.62698 .01184 m
.62698 .01559 L
s
.69048 .01184 m
.69048 .01559 L
s
.72222 .01184 m
.72222 .01559 L
s
.75397 .01184 m
.75397 .01559 L
s
.78571 .01184 m
.78571 .01559 L
s
.84921 .01184 m
.84921 .01559 L
s
.88095 .01184 m
.88095 .01559 L
s
.9127 .01184 m
.9127 .01559 L
s
.94444 .01184 m
.94444 .01559 L
s
.25 Mabswid
0 .01184 m
1 .01184 L
s
.18254 .0912 m
.18879 .0912 L
s
[(0.5)] .17004 .0912 1 0 Mshowa
.18254 .17057 m
.18879 .17057 L
s
[(1)] .17004 .17057 1 0 Mshowa
.18254 .24993 m
.18879 .24993 L
s
[(1.5)] .17004 .24993 1 0 Mshowa
.18254 .3293 m
.18879 .3293 L
s
[(2)] .17004 .3293 1 0 Mshowa
.18254 .40866 m
.18879 .40866 L
s
[(2.5)] .17004 .40866 1 0 Mshowa
.18254 .48803 m
.18879 .48803 L
s
[(3)] .17004 .48803 1 0 Mshowa
.125 Mabswid
.18254 .02771 m
.18629 .02771 L
s
.18254 .04359 m
.18629 .04359 L
s
.18254 .05946 m
.18629 .05946 L
s
.18254 .07533 m
.18629 .07533 L
s
.18254 .10708 m
.18629 .10708 L
s
.18254 .12295 m
.18629 .12295 L
s
.18254 .13882 m
.18629 .13882 L
s
.18254 .1547 m
.18629 .1547 L
s
.18254 .18644 m
.18629 .18644 L
s
.18254 .20232 m
.18629 .20232 L
s
.18254 .21819 m
.18629 .21819 L
s
.18254 .23406 m
.18629 .23406 L
s
.18254 .26581 m
.18629 .26581 L
s
.18254 .28168 m
.18629 .28168 L
s
.18254 .29755 m
.18629 .29755 L
s
.18254 .31343 m
.18629 .31343 L
s
.18254 .34517 m
.18629 .34517 L
s
.18254 .36105 m
.18629 .36105 L
s
.18254 .37692 m
.18629 .37692 L
s
.18254 .39279 m
.18629 .39279 L
s
.18254 .42454 m
.18629 .42454 L
s
.18254 .44041 m
.18629 .44041 L
s
.18254 .45628 m
.18629 .45628 L
s
.18254 .47216 m
.18629 .47216 L
s
.25 Mabswid
.18254 0 m
.18254 .49726 L
s
.5 0 1 r
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03422 .11085 L
F
.499 0 1 r
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03416 .11044 L
F
.498 0 1 r
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03399 .10923 L
F
.496 0 1 r
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03372 .10725 L
F
.494 0 1 r
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03335 .10452 L
F
.491 0 1 r
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03291 .10111 L
F
.489 0 1 r
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03242 .09709 L
F
.486 0 1 r
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03189 .09257 L
F
.484 0 1 r
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03134 .08766 L
F
.482 0 1 r
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.03081 .08253 L
F
.479 0 1 r
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.03031 .07736 L
F
.478 0 1 r
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02987 .07242 L
F
.476 0 1 r
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02951 .06801 L
F
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02924 .06446 L
F
.475 0 1 r
.02381 .01184 m
.02381 .01184 L
.02901 .06134 L
.02907 .06215 L
F
.476 0 1 r
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02901 .06134 L
F
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02907 .06215 L
F
.478 0 1 r
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02924 .06446 L
F
.479 0 1 r
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.02951 .06801 L
F
.482 0 1 r
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.02987 .07242 L
F
.484 0 1 r
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03031 .07736 L
F
.486 0 1 r
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03081 .08253 L
F
.489 0 1 r
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03134 .08766 L
F
.491 0 1 r
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03189 .09257 L
F
.494 0 1 r
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03242 .09709 L
F
.496 0 1 r
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03291 .10111 L
F
.498 0 1 r
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03335 .10452 L
F
.499 0 1 r
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03372 .10725 L
F
.5 0 1 r
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03399 .10923 L
F
.02381 .01184 m
.02381 .01184 L
.03422 .11085 L
.03416 .11044 L
F
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03422 .11085 L
F
.499 0 1 r
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03416 .11044 L
F
.498 0 1 r
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03399 .10923 L
F
.496 0 1 r
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03372 .10725 L
F
.494 0 1 r
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03335 .10452 L
F
.491 0 1 r
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03291 .10111 L
F
.489 0 1 r
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03242 .09709 L
F
.486 0 1 r
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03189 .09257 L
F
.484 0 1 r
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03134 .08766 L
F
.482 0 1 r
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.03081 .08253 L
F
.479 0 1 r
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.03031 .07736 L
F
.478 0 1 r
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02987 .07242 L
F
.476 0 1 r
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02951 .06801 L
F
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02924 .06446 L
F
.475 0 1 r
.02381 .01184 m
.02381 .01184 L
.02901 .06134 L
.02907 .06215 L
F
.476 0 1 r
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02901 .06134 L
F
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02907 .06215 L
F
.478 0 1 r
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02924 .06446 L
F
.479 0 1 r
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.02951 .06801 L
F
.482 0 1 r
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.02987 .07242 L
F
.484 0 1 r
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03031 .07736 L
F
.486 0 1 r
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03081 .08253 L
F
.489 0 1 r
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03134 .08766 L
F
.491 0 1 r
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03189 .09257 L
F
.494 0 1 r
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03242 .09709 L
F
.496 0 1 r
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03291 .10111 L
F
.498 0 1 r
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03335 .10452 L
F
.499 0 1 r
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03372 .10725 L
F
.5 0 1 r
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03399 .10923 L
F
.02381 .01184 m
.02381 .01184 L
.03422 .11085 L
.03416 .11044 L
F
1 0 .618 r
.03422 .11085 m
.03416 .11044 L
.06475 .20474 L
.06498 .20552 L
F
1 0 .638 r
.03416 .11044 m
.03399 .10923 L
.06409 .2024 L
.06475 .20474 L
F
1 0 .672 r
.03399 .10923 m
.03372 .10725 L
.06301 .19856 L
.06409 .2024 L
F
1 0 .721 r
.03372 .10725 m
.03335 .10452 L
.06157 .19327 L
.06301 .19856 L
F
1 0 .781 r
.03335 .10452 m
.03291 .10111 L
.05983 .18665 L
.06157 .19327 L
F
1 0 .852 r
.03291 .10111 m
.03242 .09709 L
.05787 .17884 L
.05983 .18665 L
F
1 0 .93 r
.03242 .09709 m
.03189 .09257 L
.05576 .17002 L
.05787 .17884 L
F
.989 0 1 r
.03189 .09257 m
.03134 .08766 L
.05361 .16043 L
.05576 .17002 L
F
.907 0 1 r
.03134 .08766 m
.03081 .08253 L
.05151 .15038 L
.05361 .16043 L
F
.827 0 1 r
.03081 .08253 m
.03031 .07736 L
.04954 .14026 L
.05151 .15038 L
F
.755 0 1 r
.03031 .07736 m
.02987 .07242 L
.0478 .13055 L
.04954 .14026 L
F
.693 0 1 r
.02987 .07242 m
.02951 .06801 L
.04636 .12185 L
.0478 .13055 L
F
.645 0 1 r
.02951 .06801 m
.02924 .06446 L
.04528 .11485 L
.04636 .12185 L
F
.613 0 1 r
.02924 .06446 m
.02907 .06215 L
.04462 .11028 L
.04528 .11485 L
F
.599 0 1 r
.02907 .06215 m
.02901 .06134 L
.04439 .10868 L
.04462 .11028 L
F
.603 0 1 r
.02901 .06134 m
.02907 .06215 L
.04462 .11028 L
.04439 .10868 L
F
.625 0 1 r
.02907 .06215 m
.02924 .06446 L
.04528 .11485 L
.04462 .11028 L
F
.665 0 1 r
.02924 .06446 m
.02951 .06801 L
.04636 .12185 L
.04528 .11485 L
F
.72 0 1 r
.02951 .06801 m
.02987 .07242 L
.0478 .13055 L
.04636 .12185 L
F
.786 0 1 r
.02987 .07242 m
.03031 .07736 L
.04954 .14026 L
.0478 .13055 L
F
.862 0 1 r
.03031 .07736 m
.03081 .08253 L
.05151 .15038 L
.04954 .14026 L
F
.943 0 1 r
.03081 .08253 m
.03134 .08766 L
.05361 .16043 L
.05151 .15038 L
F
1 0 .975 r
.03134 .08766 m
.03189 .09257 L
.05576 .17002 L
.05361 .16043 L
F
1 0 .895 r
.03189 .09257 m
.03242 .09709 L
.05787 .17884 L
.05576 .17002 L
F
1 0 .82 r
.03242 .09709 m
.03291 .10111 L
.05983 .18665 L
.05787 .17884 L
F
1 0 .753 r
.03291 .10111 m
.03335 .10452 L
.06157 .19327 L
.05983 .18665 L
F
1 0 .698 r
.03335 .10452 m
.03372 .10725 L
.06301 .19856 L
.06157 .19327 L
F
1 0 .655 r
.03372 .10725 m
.03399 .10923 L
.06409 .2024 L
.06301 .19856 L
F
1 0 .627 r
.03399 .10923 m
.03416 .11044 L
.06475 .20474 L
.06409 .2024 L
F
1 0 .615 r
.03416 .11044 m
.03422 .11085 L
.06498 .20552 L
.06475 .20474 L
F
1 0 .618 r
.03422 .11085 m
.03416 .11044 L
.06475 .20474 L
.06498 .20552 L
F
1 0 .638 r
.03416 .11044 m
.03399 .10923 L
.06409 .2024 L
.06475 .20474 L
F
1 0 .672 r
.03399 .10923 m
.03372 .10725 L
.06301 .19856 L
.06409 .2024 L
F
1 0 .721 r
.03372 .10725 m
.03335 .10452 L
.06157 .19327 L
.06301 .19856 L
F
1 0 .781 r
.03335 .10452 m
.03291 .10111 L
.05983 .18665 L
.06157 .19327 L
F
1 0 .852 r
.03291 .10111 m
.03242 .09709 L
.05787 .17884 L
.05983 .18665 L
F
1 0 .93 r
.03242 .09709 m
.03189 .09257 L
.05576 .17002 L
.05787 .17884 L
F
.989 0 1 r
.03189 .09257 m
.03134 .08766 L
.05361 .16043 L
.05576 .17002 L
F
.907 0 1 r
.03134 .08766 m
.03081 .08253 L
.05151 .15038 L
.05361 .16043 L
F
.827 0 1 r
.03081 .08253 m
.03031 .07736 L
.04954 .14026 L
.05151 .15038 L
F
.755 0 1 r
.03031 .07736 m
.02987 .07242 L
.0478 .13055 L
.04954 .14026 L
F
.693 0 1 r
.02987 .07242 m
.02951 .06801 L
.04636 .12185 L
.0478 .13055 L
F
.645 0 1 r
.02951 .06801 m
.02924 .06446 L
.04528 .11485 L
.04636 .12185 L
F
.613 0 1 r
.02924 .06446 m
.02907 .06215 L
.04462 .11028 L
.04528 .11485 L
F
.599 0 1 r
.02907 .06215 m
.02901 .06134 L
.04439 .10868 L
.04462 .11028 L
F
.603 0 1 r
.02901 .06134 m
.02907 .06215 L
.04462 .11028 L
.04439 .10868 L
F
.625 0 1 r
.02907 .06215 m
.02924 .06446 L
.04528 .11485 L
.04462 .11028 L
F
.665 0 1 r
.02924 .06446 m
.02951 .06801 L
.04636 .12185 L
.04528 .11485 L
F
.72 0 1 r
.02951 .06801 m
.02987 .07242 L
.0478 .13055 L
.04636 .12185 L
F
.786 0 1 r
.02987 .07242 m
.03031 .07736 L
.04954 .14026 L
.0478 .13055 L
F
.862 0 1 r
.03031 .07736 m
.03081 .08253 L
.05151 .15038 L
.04954 .14026 L
F
.943 0 1 r
.03081 .08253 m
.03134 .08766 L
.05361 .16043 L
.05151 .15038 L
F
1 0 .975 r
.03134 .08766 m
.03189 .09257 L
.05576 .17002 L
.05361 .16043 L
F
1 0 .895 r
.03189 .09257 m
.03242 .09709 L
.05787 .17884 L
.05576 .17002 L
F
1 0 .82 r
.03242 .09709 m
.03291 .10111 L
.05983 .18665 L
.05787 .17884 L
F
1 0 .753 r
.03291 .10111 m
.03335 .10452 L
.06157 .19327 L
.05983 .18665 L
F
1 0 .698 r
.03335 .10452 m
.03372 .10725 L
.06301 .19856 L
.06157 .19327 L
F
1 0 .655 r
.03372 .10725 m
.03399 .10923 L
.06409 .2024 L
.06301 .19856 L
F
1 0 .627 r
.03399 .10923 m
.03416 .11044 L
.06475 .20474 L
.06409 .2024 L
F
1 0 .615 r
.03416 .11044 m
.03422 .11085 L
.06498 .20552 L
.06475 .20474 L
F
1 .912 0 r
.06498 .20552 m
.06475 .20474 L
.11426 .29063 L
.11475 .29174 L
F
1 .866 0 r
.06475 .20474 m
.06409 .2024 L
.11279 .28732 L
.11426 .29063 L
F
1 .783 0 r
.06409 .2024 m
.06301 .19856 L
.11041 .28186 L
.11279 .28732 L
F
1 .665 0 r
.06301 .19856 m
.06157 .19327 L
.10723 .27434 L
.11041 .28186 L
F
1 .516 0 r
.06157 .19327 m
.05983 .18665 L
.10339 .2649 L
.10723 .27434 L
F
1 .341 0 r
.05983 .18665 m
.05787 .17884 L
.09904 .25373 L
.10339 .2649 L
F
1 .144 0 r
.05787 .17884 m
.05576 .17002 L
.09439 .24107 L
.09904 .25373 L
F
1 0 .067 r
.05576 .17002 m
.05361 .16043 L
.08964 .22726 L
.09439 .24107 L
F
1 0 .283 r
.05361 .16043 m
.05151 .15038 L
.08499 .21272 L
.08964 .22726 L
F
1 0 .496 r
.05151 .15038 m
.04954 .14026 L
.08065 .19802 L
.08499 .21272 L
F
1 0 .695 r
.04954 .14026 m
.0478 .13055 L
.0768 .18386 L
.08065 .19802 L
F
1 0 .869 r
.0478 .13055 m
.04636 .12185 L
.07362 .17114 L
.0768 .18386 L
F
.992 0 1 r
.04636 .12185 m
.04528 .11485 L
.07125 .16087 L
.07362 .17114 L
F
.898 0 1 r
.04528 .11485 m
.04462 .11028 L
.06978 .15414 L
.07125 .16087 L
F
.855 0 1 r
.04462 .11028 m
.04439 .10868 L
.06928 .15179 L
.06978 .15414 L
F
.866 0 1 r
.04439 .10868 m
.04462 .11028 L
.06978 .15414 L
.06928 .15179 L
F
.93 0 1 r
.04462 .11028 m
.04528 .11485 L
.07125 .16087 L
.06978 .15414 L
F
1 0 .957 r
.04528 .11485 m
.04636 .12185 L
.07362 .17114 L
.07125 .16087 L
F
1 0 .803 r
.04636 .12185 m
.0478 .13055 L
.0768 .18386 L
.07362 .17114 L
F
1 0 .618 r
.0478 .13055 m
.04954 .14026 L
.08065 .19802 L
.0768 .18386 L
F
1 0 .412 r
.04954 .14026 m
.05151 .15038 L
.08499 .21272 L
.08065 .19802 L
F
1 0 .197 r
.05151 .15038 m
.05361 .16043 L
.08964 .22726 L
.08499 .21272 L
F
1 .018 0 r
.05361 .16043 m
.05576 .17002 L
.09439 .24107 L
.08964 .22726 L
F
1 .224 0 r
.05576 .17002 m
.05787 .17884 L
.09904 .25373 L
.09439 .24107 L
F
1 .413 0 r
.05787 .17884 m
.05983 .18665 L
.10339 .2649 L
.09904 .25373 L
F
1 .578 0 r
.05983 .18665 m
.06157 .19327 L
.10723 .27434 L
.10339 .2649 L
F
1 .715 0 r
.06157 .19327 m
.06301 .19856 L
.11041 .28186 L
.10723 .27434 L
F
1 .82 0 r
.06301 .19856 m
.06409 .2024 L
.11279 .28732 L
.11041 .28186 L
F
1 .888 0 r
.06409 .2024 m
.06475 .20474 L
.11426 .29063 L
.11279 .28732 L
F
1 .919 0 r
.06475 .20474 m
.06498 .20552 L
.11475 .29174 L
.11426 .29063 L
F
1 .912 0 r
.06498 .20552 m
.06475 .20474 L
.11426 .29063 L
.11475 .29174 L
F
1 .866 0 r
.06475 .20474 m
.06409 .2024 L
.11279 .28732 L
.11426 .29063 L
F
1 .783 0 r
.06409 .2024 m
.06301 .19856 L
.11041 .28186 L
.11279 .28732 L
F
1 .665 0 r
.06301 .19856 m
.06157 .19327 L
.10723 .27434 L
.11041 .28186 L
F
1 .516 0 r
.06157 .19327 m
.05983 .18665 L
.10339 .2649 L
.10723 .27434 L
F
1 .341 0 r
.05983 .18665 m
.05787 .17884 L
.09904 .25373 L
.10339 .2649 L
F
1 .144 0 r
.05787 .17884 m
.05576 .17002 L
.09439 .24107 L
.09904 .25373 L
F
1 0 .067 r
.05576 .17002 m
.05361 .16043 L
.08964 .22726 L
.09439 .24107 L
F
1 0 .283 r
.05361 .16043 m
.05151 .15038 L
.08499 .21272 L
.08964 .22726 L
F
1 0 .496 r
.05151 .15038 m
.04954 .14026 L
.08065 .19802 L
.08499 .21272 L
F
1 0 .695 r
.04954 .14026 m
.0478 .13055 L
.0768 .18386 L
.08065 .19802 L
F
1 0 .869 r
.0478 .13055 m
.04636 .12185 L
.07362 .17114 L
.0768 .18386 L
F
.992 0 1 r
.04636 .12185 m
.04528 .11485 L
.07125 .16087 L
.07362 .17114 L
F
.898 0 1 r
.04528 .11485 m
.04462 .11028 L
.06978 .15414 L
.07125 .16087 L
F
.855 0 1 r
.04462 .11028 m
.04439 .10868 L
.06928 .15179 L
.06978 .15414 L
F
.866 0 1 r
.04439 .10868 m
.04462 .11028 L
.06978 .15414 L
.06928 .15179 L
F
.93 0 1 r
.04462 .11028 m
.04528 .11485 L
.07125 .16087 L
.06978 .15414 L
F
1 0 .957 r
.04528 .11485 m
.04636 .12185 L
.07362 .17114 L
.07125 .16087 L
F
1 0 .803 r
.04636 .12185 m
.0478 .13055 L
.0768 .18386 L
.07362 .17114 L
F
1 0 .618 r
.0478 .13055 m
.04954 .14026 L
.08065 .19802 L
.0768 .18386 L
F
1 0 .412 r
.04954 .14026 m
.05151 .15038 L
.08499 .21272 L
.08065 .19802 L
F
1 0 .197 r
.05151 .15038 m
.05361 .16043 L
.08964 .22726 L
.08499 .21272 L
F
1 .018 0 r
.05361 .16043 m
.05576 .17002 L
.09439 .24107 L
.08964 .22726 L
F
1 .224 0 r
.05576 .17002 m
.05787 .17884 L
.09904 .25373 L
.09439 .24107 L
F
1 .413 0 r
.05787 .17884 m
.05983 .18665 L
.10339 .2649 L
.09904 .25373 L
F
1 .578 0 r
.05983 .18665 m
.06157 .19327 L
.10723 .27434 L
.10339 .2649 L
F
1 .715 0 r
.06157 .19327 m
.06301 .19856 L
.11041 .28186 L
.10723 .27434 L
F
1 .82 0 r
.06301 .19856 m
.06409 .2024 L
.11279 .28732 L
.11041 .28186 L
F
1 .888 0 r
.06409 .2024 m
.06475 .20474 L
.11426 .29063 L
.11279 .28732 L
F
1 .919 0 r
.06475 .20474 m
.06498 .20552 L
.11475 .29174 L
.11426 .29063 L
F
0 1 .709 r
.11475 .29174 m
.11426 .29063 L
.18051 .36436 L
.18137 .36572 L
F
0 1 .637 r
.11426 .29063 m
.11279 .28732 L
.17796 .3603 L
.18051 .36436 L
F
0 1 .504 r
.11279 .28732 m
.11041 .28186 L
.17384 .3536 L
.17796 .3603 L
F
0 1 .316 r
.11041 .28186 m
.10723 .27434 L
.16833 .34433 L
.17384 .3536 L
F
0 1 .075 r
.10723 .27434 m
.10339 .2649 L
.16167 .33264 L
.16833 .34433 L
F
.21 1 0 r
.10339 .2649 m
.09904 .25373 L
.15415 .31873 L
.16167 .33264 L
F
.534 1 0 r
.09904 .25373 m
.09439 .24107 L
.14609 .30289 L
.15415 .31873 L
F
.885 1 0 r
.09439 .24107 m
.08964 .22726 L
.13786 .28551 L
.14609 .30289 L
F
1 .75 0 r
.08964 .22726 m
.08499 .21272 L
.12981 .2671 L
.13786 .28551 L
F
1 .384 0 r
.08499 .21272 m
.08065 .19802 L
.12228 .24838 L
.12981 .2671 L
F
1 .035 0 r
.08065 .19802 m
.0768 .18386 L
.11562 .23025 L
.12228 .24838 L
F
1 0 .276 r
.0768 .18386 m
.07362 .17114 L
.11011 .21386 L
.11562 .23025 L
F
1 0 .529 r
.07362 .17114 m
.07125 .16087 L
.10599 .20058 L
.11011 .21386 L
F
1 0 .704 r
.07125 .16087 m
.06978 .15414 L
.10345 .19184 L
.10599 .20058 L
F
1 0 .786 r
.06978 .15414 m
.06928 .15179 L
.10259 .18878 L
.10345 .19184 L
F
1 0 .766 r
.06928 .15179 m
.06978 .15414 L
.10345 .19184 L
.10259 .18878 L
F
1 0 .647 r
.06978 .15414 m
.07125 .16087 L
.10599 .20058 L
.10345 .19184 L
F
1 0 .441 r
.07125 .16087 m
.07362 .17114 L
.11011 .21386 L
.10599 .20058 L
F
1 0 .163 r
.07362 .17114 m
.0768 .18386 L
.11562 .23025 L
.11011 .21386 L
F
1 .164 0 r
.0768 .18386 m
.08065 .19802 L
.12228 .24838 L
.11562 .23025 L
F
1 .521 0 r
.08065 .19802 m
.08499 .21272 L
.12981 .2671 L
.12228 .24838 L
F
1 .888 0 r
.08499 .21272 m
.08964 .22726 L
.13786 .28551 L
.12981 .2671 L
F
.75 1 0 r
.08964 .22726 m
.09439 .24107 L
.14609 .30289 L
.13786 .28551 L
F
.409 1 0 r
.09439 .24107 m
.09904 .25373 L
.15415 .31873 L
.14609 .30289 L
F
.098 1 0 r
.09904 .25373 m
.10339 .2649 L
.16167 .33264 L
.15415 .31873 L
F
0 1 .171 r
.10339 .2649 m
.10723 .27434 L
.16833 .34433 L
.16167 .33264 L
F
0 1 .393 r
.10723 .27434 m
.11041 .28186 L
.17384 .3536 L
.16833 .34433 L
F
0 1 .561 r
.11041 .28186 m
.11279 .28732 L
.17796 .3603 L
.17384 .3536 L
F
0 1 .671 r
.11279 .28732 m
.11426 .29063 L
.18051 .36436 L
.17796 .3603 L
F
0 1 .721 r
.11426 .29063 m
.11475 .29174 L
.18137 .36572 L
.18051 .36436 L
F
0 1 .709 r
.11475 .29174 m
.11426 .29063 L
.18051 .36436 L
.18137 .36572 L
F
0 1 .637 r
.11426 .29063 m
.11279 .28732 L
.17796 .3603 L
.18051 .36436 L
F
0 1 .504 r
.11279 .28732 m
.11041 .28186 L
.17384 .3536 L
.17796 .3603 L
F
0 1 .316 r
.11041 .28186 m
.10723 .27434 L
.16833 .34433 L
.17384 .3536 L
F
0 1 .075 r
.10723 .27434 m
.10339 .2649 L
.16167 .33264 L
.16833 .34433 L
F
.21 1 0 r
.10339 .2649 m
.09904 .25373 L
.15415 .31873 L
.16167 .33264 L
F
.534 1 0 r
.09904 .25373 m
.09439 .24107 L
.14609 .30289 L
.15415 .31873 L
F
.885 1 0 r
.09439 .24107 m
.08964 .22726 L
.13786 .28551 L
.14609 .30289 L
F
1 .75 0 r
.08964 .22726 m
.08499 .21272 L
.12981 .2671 L
.13786 .28551 L
F
1 .384 0 r
.08499 .21272 m
.08065 .19802 L
.12228 .24838 L
.12981 .2671 L
F
1 .035 0 r
.08065 .19802 m
.0768 .18386 L
.11562 .23025 L
.12228 .24838 L
F
1 0 .276 r
.0768 .18386 m
.07362 .17114 L
.11011 .21386 L
.11562 .23025 L
F
1 0 .529 r
.07362 .17114 m
.07125 .16087 L
.10599 .20058 L
.11011 .21386 L
F
1 0 .704 r
.07125 .16087 m
.06978 .15414 L
.10345 .19184 L
.10599 .20058 L
F
1 0 .786 r
.06978 .15414 m
.06928 .15179 L
.10259 .18878 L
.10345 .19184 L
F
1 0 .766 r
.06928 .15179 m
.06978 .15414 L
.10345 .19184 L
.10259 .18878 L
F
1 0 .647 r
.06978 .15414 m
.07125 .16087 L
.10599 .20058 L
.10345 .19184 L
F
1 0 .441 r
.07125 .16087 m
.07362 .17114 L
.11011 .21386 L
.10599 .20058 L
F
1 0 .163 r
.07362 .17114 m
.0768 .18386 L
.11562 .23025 L
.11011 .21386 L
F
1 .164 0 r
.0768 .18386 m
.08065 .19802 L
.12228 .24838 L
.11562 .23025 L
F
1 .521 0 r
.08065 .19802 m
.08499 .21272 L
.12981 .2671 L
.12228 .24838 L
F
1 .888 0 r
.08499 .21272 m
.08964 .22726 L
.13786 .28551 L
.12981 .2671 L
F
.75 1 0 r
.08964 .22726 m
.09439 .24107 L
.14609 .30289 L
.13786 .28551 L
F
.409 1 0 r
.09439 .24107 m
.09904 .25373 L
.15415 .31873 L
.14609 .30289 L
F
.098 1 0 r
.09904 .25373 m
.10339 .2649 L
.16167 .33264 L
.15415 .31873 L
F
0 1 .171 r
.10339 .2649 m
.10723 .27434 L
.16833 .34433 L
.16167 .33264 L
F
0 1 .393 r
.10723 .27434 m
.11041 .28186 L
.17384 .3536 L
.16833 .34433 L
F
0 1 .561 r
.11041 .28186 m
.11279 .28732 L
.17796 .3603 L
.17384 .3536 L
F
0 1 .671 r
.11279 .28732 m
.11426 .29063 L
.18051 .36436 L
.17796 .3603 L
F
0 1 .721 r
.11426 .29063 m
.11475 .29174 L
.18137 .36572 L
.18051 .36436 L
F
.582 0 1 r
.18137 .36572 m
.18051 .36436 L
.2606 .42273 L
.2619 .42423 L
F
.484 0 1 r
.18051 .36436 m
.17796 .3603 L
.25676 .41821 L
.2606 .42273 L
F
.305 0 1 r
.17796 .3603 m
.17384 .3536 L
.25054 .41073 L
.25676 .41821 L
F
.049 0 1 r
.17384 .3536 m
.16833 .34433 L
.24221 .40033 L
.25054 .41073 L
F
0 .279 1 r
.16833 .34433 m
.16167 .33264 L
.23214 .38712 L
.24221 .40033 L
F
0 .671 1 r
.16167 .33264 m
.15415 .31873 L
.22077 .37129 L
.23214 .38712 L
F
0 1 .883 r
.15415 .31873 m
.14609 .30289 L
.2086 .35311 L
.22077 .37129 L
F
0 1 .396 r
.14609 .30289 m
.13786 .28551 L
.19616 .33298 L
.2086 .35311 L
F
.118 1 0 r
.13786 .28551 m
.12981 .2671 L
.18399 .31149 L
.19616 .33298 L
F
.637 1 0 r
.12981 .2671 m
.12228 .24838 L
.17262 .28944 L
.18399 .31149 L
F
1 .862 0 r
.12228 .24838 m
.11562 .23025 L
.16255 .26792 L
.17262 .28944 L
F
1 .407 0 r
.11562 .23025 m
.11011 .21386 L
.15423 .24832 L
.16255 .26792 L
F
1 .031 0 r
.11011 .21386 m
.10599 .20058 L
.148 .23233 L
.15423 .24832 L
F
1 0 .232 r
.10599 .20058 m
.10345 .19184 L
.14416 .22175 L
.148 .23233 L
F
1 0 .357 r
.10345 .19184 m
.10259 .18878 L
.14286 .21804 L
.14416 .22175 L
F
1 0 .328 r
.10259 .18878 m
.10345 .19184 L
.14416 .22175 L
.14286 .21804 L
F
1 0 .149 r
.10345 .19184 m
.10599 .20058 L
.148 .23233 L
.14416 .22175 L
F
1 .16 0 r
.10599 .20058 m
.11011 .21386 L
.15423 .24832 L
.148 .23233 L
F
1 .568 0 r
.11011 .21386 m
.11562 .23025 L
.16255 .26792 L
.15423 .24832 L
F
.957 1 0 r
.11562 .23025 m
.12228 .24838 L
.17262 .28944 L
.16255 .26792 L
F
.447 1 0 r
.12228 .24838 m
.12981 .2671 L
.18399 .31149 L
.17262 .28944 L
F
0 1 .072 r
.12981 .2671 m
.13786 .28551 L
.19616 .33298 L
.18399 .31149 L
F
0 1 .577 r
.13786 .28551 m
.14609 .30289 L
.2086 .35311 L
.19616 .33298 L
F
0 .949 1 r
.14609 .30289 m
.15415 .31873 L
.22077 .37129 L
.2086 .35311 L
F
0 .522 1 r
.15415 .31873 m
.16167 .33264 L
.23214 .38712 L
.22077 .37129 L
F
0 .152 1 r
.16167 .33264 m
.16833 .34433 L
.24221 .40033 L
.23214 .38712 L
F
.15 0 1 r
.16833 .34433 m
.17384 .3536 L
.25054 .41073 L
.24221 .40033 L
F
.379 0 1 r
.17384 .3536 m
.17796 .3603 L
.25676 .41821 L
.25054 .41073 L
F
.529 0 1 r
.17796 .3603 m
.18051 .36436 L
.2606 .42273 L
.25676 .41821 L
F
.597 0 1 r
.18051 .36436 m
.18137 .36572 L
.2619 .42423 L
.2606 .42273 L
F
.582 0 1 r
.18137 .36572 m
.18051 .36436 L
.2606 .42273 L
.2619 .42423 L
F
.484 0 1 r
.18051 .36436 m
.17796 .3603 L
.25676 .41821 L
.2606 .42273 L
F
.305 0 1 r
.17796 .3603 m
.17384 .3536 L
.25054 .41073 L
.25676 .41821 L
F
.049 0 1 r
.17384 .3536 m
.16833 .34433 L
.24221 .40033 L
.25054 .41073 L
F
0 .279 1 r
.16833 .34433 m
.16167 .33264 L
.23214 .38712 L
.24221 .40033 L
F
0 .671 1 r
.16167 .33264 m
.15415 .31873 L
.22077 .37129 L
.23214 .38712 L
F
0 1 .883 r
.15415 .31873 m
.14609 .30289 L
.2086 .35311 L
.22077 .37129 L
F
0 1 .396 r
.14609 .30289 m
.13786 .28551 L
.19616 .33298 L
.2086 .35311 L
F
.118 1 0 r
.13786 .28551 m
.12981 .2671 L
.18399 .31149 L
.19616 .33298 L
F
.637 1 0 r
.12981 .2671 m
.12228 .24838 L
.17262 .28944 L
.18399 .31149 L
F
1 .862 0 r
.12228 .24838 m
.11562 .23025 L
.16255 .26792 L
.17262 .28944 L
F
1 .407 0 r
.11562 .23025 m
.11011 .21386 L
.15423 .24832 L
.16255 .26792 L
F
1 .031 0 r
.11011 .21386 m
.10599 .20058 L
.148 .23233 L
.15423 .24832 L
F
1 0 .232 r
.10599 .20058 m
.10345 .19184 L
.14416 .22175 L
.148 .23233 L
F
1 0 .357 r
.10345 .19184 m
.10259 .18878 L
.14286 .21804 L
.14416 .22175 L
F
1 0 .328 r
.10259 .18878 m
.10345 .19184 L
.14416 .22175 L
.14286 .21804 L
F
1 0 .149 r
.10345 .19184 m
.10599 .20058 L
.148 .23233 L
.14416 .22175 L
F
1 .16 0 r
.10599 .20058 m
.11011 .21386 L
.15423 .24832 L
.148 .23233 L
F
1 .568 0 r
.11011 .21386 m
.11562 .23025 L
.16255 .26792 L
.15423 .24832 L
F
.957 1 0 r
.11562 .23025 m
.12228 .24838 L
.17262 .28944 L
.16255 .26792 L
F
.447 1 0 r
.12228 .24838 m
.12981 .2671 L
.18399 .31149 L
.17262 .28944 L
F
0 1 .072 r
.12981 .2671 m
.13786 .28551 L
.19616 .33298 L
.18399 .31149 L
F
0 1 .577 r
.13786 .28551 m
.14609 .30289 L
.2086 .35311 L
.19616 .33298 L
F
0 .949 1 r
.14609 .30289 m
.15415 .31873 L
.22077 .37129 L
.2086 .35311 L
F
0 .522 1 r
.15415 .31873 m
.16167 .33264 L
.23214 .38712 L
.22077 .37129 L
F
0 .152 1 r
.16167 .33264 m
.16833 .34433 L
.24221 .40033 L
.23214 .38712 L
F
.15 0 1 r
.16833 .34433 m
.17384 .3536 L
.25054 .41073 L
.24221 .40033 L
F
.379 0 1 r
.17384 .3536 m
.17796 .3603 L
.25676 .41821 L
.25054 .41073 L
F
.529 0 1 r
.17796 .3603 m
.18051 .36436 L
.2606 .42273 L
.25676 .41821 L
F
.597 0 1 r
.18051 .36436 m
.18137 .36572 L
.2619 .42423 L
.2606 .42273 L
F
1 .433 0 r
.2619 .42423 m
.2606 .42273 L
.35105 .46319 L
.35285 .46472 L
F
1 .311 0 r
.2606 .42273 m
.25676 .41821 L
.34574 .45858 L
.35105 .46319 L
F
1 .089 0 r
.25676 .41821 m
.25054 .41073 L
.33714 .45088 L
.34574 .45858 L
F
1 0 .231 r
.25054 .41073 m
.24221 .40033 L
.32563 .44008 L
.33714 .45088 L
F
1 0 .641 r
.24221 .40033 m
.23214 .38712 L
.31172 .42623 L
.32563 .44008 L
F
.868 0 1 r
.23214 .38712 m
.22077 .37129 L
.29601 .40943 L
.31172 .42623 L
F
.307 0 1 r
.22077 .37129 m
.2086 .35311 L
.27919 .38989 L
.29601 .40943 L
F
0 .309 1 r
.2086 .35311 m
.19616 .33298 L
.26199 .36799 L
.27919 .38989 L
F
0 .962 1 r
.19616 .33298 m
.18399 .31149 L
.24517 .34432 L
.26199 .36799 L
F
0 1 .373 r
.18399 .31149 m
.17262 .28944 L
.22946 .31975 L
.24517 .34432 L
F
.276 1 0 r
.17262 .28944 m
.16255 .26792 L
.21555 .2955 L
.22946 .31975 L
F
.871 1 0 r
.16255 .26792 m
.15423 .24832 L
.20404 .27319 L
.21555 .2955 L
F
1 .631 0 r
.15423 .24832 m
.148 .23233 L
.19544 .25483 L
.20404 .27319 L
F
1 .278 0 r
.148 .23233 m
.14416 .22175 L
.19013 .2426 L
.19544 .25483 L
F
1 .11 0 r
.14416 .22175 m
.14286 .21804 L
.18833 .23828 L
.19013 .2426 L
F
1 .149 0 r
.14286 .21804 m
.14416 .22175 L
.19013 .2426 L
.18833 .23828 L
F
1 .389 0 r
.14416 .22175 m
.148 .23233 L
.19544 .25483 L
.19013 .2426 L
F
1 .799 0 r
.148 .23233 m
.15423 .24832 L
.20404 .27319 L
.19544 .25483 L
F
.663 1 0 r
.15423 .24832 m
.16255 .26792 L
.21555 .2955 L
.20404 .27319 L
F
.045 1 0 r
.16255 .26792 m
.17262 .28944 L
.22946 .31975 L
.21555 .2955 L
F
0 1 .612 r
.17262 .28944 m
.18399 .31149 L
.24517 .34432 L
.22946 .31975 L
F
0 .725 1 r
.18399 .31149 m
.19616 .33298 L
.26199 .36799 L
.24517 .34432 L
F
0 .084 1 r
.19616 .33298 m
.2086 .35311 L
.27919 .38989 L
.26199 .36799 L
F
.514 0 1 r
.2086 .35311 m
.22077 .37129 L
.29601 .40943 L
.27919 .38989 L
F
1 0 .949 r
.22077 .37129 m
.23214 .38712 L
.31172 .42623 L
.29601 .40943 L
F
1 0 .486 r
.23214 .38712 m
.24221 .40033 L
.32563 .44008 L
.31172 .42623 L
F
1 0 .107 r
.24221 .40033 m
.25054 .41073 L
.33714 .45088 L
.32563 .44008 L
F
1 .178 0 r
.25054 .41073 m
.25676 .41821 L
.34574 .45858 L
.33714 .45088 L
F
1 .366 0 r
.25676 .41821 m
.2606 .42273 L
.35105 .46319 L
.34574 .45858 L
F
1 .451 0 r
.2606 .42273 m
.2619 .42423 L
.35285 .46472 L
.35105 .46319 L
F
1 .433 0 r
.2619 .42423 m
.2606 .42273 L
.35105 .46319 L
.35285 .46472 L
F
1 .311 0 r
.2606 .42273 m
.25676 .41821 L
.34574 .45858 L
.35105 .46319 L
F
1 .089 0 r
.25676 .41821 m
.25054 .41073 L
.33714 .45088 L
.34574 .45858 L
F
1 0 .231 r
.25054 .41073 m
.24221 .40033 L
.32563 .44008 L
.33714 .45088 L
F
1 0 .641 r
.24221 .40033 m
.23214 .38712 L
.31172 .42623 L
.32563 .44008 L
F
.868 0 1 r
.23214 .38712 m
.22077 .37129 L
.29601 .40943 L
.31172 .42623 L
F
.307 0 1 r
.22077 .37129 m
.2086 .35311 L
.27919 .38989 L
.29601 .40943 L
F
0 .309 1 r
.2086 .35311 m
.19616 .33298 L
.26199 .36799 L
.27919 .38989 L
F
0 .962 1 r
.19616 .33298 m
.18399 .31149 L
.24517 .34432 L
.26199 .36799 L
F
0 1 .373 r
.18399 .31149 m
.17262 .28944 L
.22946 .31975 L
.24517 .34432 L
F
.276 1 0 r
.17262 .28944 m
.16255 .26792 L
.21555 .2955 L
.22946 .31975 L
F
.871 1 0 r
.16255 .26792 m
.15423 .24832 L
.20404 .27319 L
.21555 .2955 L
F
1 .631 0 r
.15423 .24832 m
.148 .23233 L
.19544 .25483 L
.20404 .27319 L
F
1 .278 0 r
.148 .23233 m
.14416 .22175 L
.19013 .2426 L
.19544 .25483 L
F
1 .11 0 r
.14416 .22175 m
.14286 .21804 L
.18833 .23828 L
.19013 .2426 L
F
1 .149 0 r
.14286 .21804 m
.14416 .22175 L
.19013 .2426 L
.18833 .23828 L
F
1 .389 0 r
.14416 .22175 m
.148 .23233 L
.19544 .25483 L
.19013 .2426 L
F
1 .799 0 r
.148 .23233 m
.15423 .24832 L
.20404 .27319 L
.19544 .25483 L
F
.663 1 0 r
.15423 .24832 m
.16255 .26792 L
.21555 .2955 L
.20404 .27319 L
F
.045 1 0 r
.16255 .26792 m
.17262 .28944 L
.22946 .31975 L
.21555 .2955 L
F
0 1 .612 r
.17262 .28944 m
.18399 .31149 L
.24517 .34432 L
.22946 .31975 L
F
0 .725 1 r
.18399 .31149 m
.19616 .33298 L
.26199 .36799 L
.24517 .34432 L
F
0 .084 1 r
.19616 .33298 m
.2086 .35311 L
.27919 .38989 L
.26199 .36799 L
F
.514 0 1 r
.2086 .35311 m
.22077 .37129 L
.29601 .40943 L
.27919 .38989 L
F
1 0 .949 r
.22077 .37129 m
.23214 .38712 L
.31172 .42623 L
.29601 .40943 L
F
1 0 .486 r
.23214 .38712 m
.24221 .40033 L
.32563 .44008 L
.31172 .42623 L
F
1 0 .107 r
.24221 .40033 m
.25054 .41073 L
.33714 .45088 L
.32563 .44008 L
F
1 .178 0 r
.25054 .41073 m
.25676 .41821 L
.34574 .45858 L
.33714 .45088 L
F
1 .366 0 r
.25676 .41821 m
.2606 .42273 L
.35105 .46319 L
.34574 .45858 L
F
1 .451 0 r
.2606 .42273 m
.2619 .42423 L
.35285 .46472 L
.35105 .46319 L
F
0 1 .205 r
.35285 .46472 m
.35105 .46319 L
.44789 .484 L
.45022 .48542 L
F
0 1 .061 r
.35105 .46319 m
.34574 .45858 L
.44101 .47969 L
.44789 .484 L
F
.202 1 0 r
.34574 .45858 m
.33714 .45088 L
.42987 .47243 L
.44101 .47969 L
F
.579 1 0 r
.33714 .45088 m
.32563 .44008 L
.41495 .46209 L
.42987 .47243 L
F
1 .935 0 r
.32563 .44008 m
.31172 .42623 L
.39692 .44859 L
.41495 .46209 L
F
1 .352 0 r
.31172 .42623 m
.29601 .40943 L
.37656 .43189 L
.39692 .44859 L
F
1 0 .315 r
.29601 .40943 m
.27919 .38989 L
.35476 .4121 L
.37656 .43189 L
F
.949 0 1 r
.27919 .38989 m
.26199 .36799 L
.33248 .3895 L
.35476 .4121 L
F
.167 0 1 r
.26199 .36799 m
.24517 .34432 L
.31068 .36463 L
.33248 .3895 L
F
0 .634 1 r
.24517 .34432 m
.22946 .31975 L
.29032 .33841 L
.31068 .36463 L
F
0 1 .579 r
.22946 .31975 m
.21555 .2955 L
.27229 .31213 L
.29032 .33841 L
F
.148 1 0 r
.21555 .2955 m
.20404 .27319 L
.25738 .28763 L
.27229 .31213 L
F
.761 1 0 r
.20404 .27319 m
.19544 .25483 L
.24623 .26722 L
.25738 .28763 L
F
1 .8 0 r
.19544 .25483 m
.19013 .2426 L
.23935 .2535 L
.24623 .26722 L
F
1 .589 0 r
.19013 .2426 m
.18833 .23828 L
.23702 .24863 L
.23935 .2535 L
F
1 .637 0 r
.18833 .23828 m
.19013 .2426 L
.23935 .2535 L
.23702 .24863 L
F
1 .936 0 r
.19013 .2426 m
.19544 .25483 L
.24623 .26722 L
.23935 .2535 L
F
.556 1 0 r
.19544 .25483 m
.20404 .27319 L
.25738 .28763 L
.24623 .26722 L
F
0 1 .104 r
.20404 .27319 m
.21555 .2955 L
.27229 .31213 L
.25738 .28763 L
F
0 1 .856 r
.21555 .2955 m
.22946 .31975 L
.29032 .33841 L
.27229 .31213 L
F
0 .349 1 r
.22946 .31975 m
.24517 .34432 L
.31068 .36463 L
.29032 .33841 L
F
.447 0 1 r
.24517 .34432 m
.26199 .36799 L
.33248 .3895 L
.31068 .36463 L
F
1 0 .785 r
.26199 .36799 m
.27919 .38989 L
.35476 .4121 L
.33248 .3895 L
F
1 0 .073 r
.27919 .38989 m
.29601 .40943 L
.37656 .43189 L
.35476 .4121 L
F
1 .566 0 r
.29601 .40943 m
.31172 .42623 L
.39692 .44859 L
.37656 .43189 L
F
.884 1 0 r
.31172 .42623 m
.32563 .44008 L
.41495 .46209 L
.39692 .44859 L
F
.436 1 0 r
.32563 .44008 m
.33714 .45088 L
.42987 .47243 L
.41495 .46209 L
F
.097 1 0 r
.33714 .45088 m
.34574 .45858 L
.44101 .47969 L
.42987 .47243 L
F
0 1 .125 r
.34574 .45858 m
.35105 .46319 L
.44789 .484 L
.44101 .47969 L
F
0 1 .226 r
.35105 .46319 m
.35285 .46472 L
.45022 .48542 L
.44789 .484 L
F
0 1 .205 r
.35285 .46472 m
.35105 .46319 L
.44789 .484 L
.45022 .48542 L
F
0 1 .061 r
.35105 .46319 m
.34574 .45858 L
.44101 .47969 L
.44789 .484 L
F
.202 1 0 r
.34574 .45858 m
.33714 .45088 L
.42987 .47243 L
.44101 .47969 L
F
.579 1 0 r
.33714 .45088 m
.32563 .44008 L
.41495 .46209 L
.42987 .47243 L
F
1 .935 0 r
.32563 .44008 m
.31172 .42623 L
.39692 .44859 L
.41495 .46209 L
F
1 .352 0 r
.31172 .42623 m
.29601 .40943 L
.37656 .43189 L
.39692 .44859 L
F
1 0 .315 r
.29601 .40943 m
.27919 .38989 L
.35476 .4121 L
.37656 .43189 L
F
.949 0 1 r
.27919 .38989 m
.26199 .36799 L
.33248 .3895 L
.35476 .4121 L
F
.167 0 1 r
.26199 .36799 m
.24517 .34432 L
.31068 .36463 L
.33248 .3895 L
F
0 .634 1 r
.24517 .34432 m
.22946 .31975 L
.29032 .33841 L
.31068 .36463 L
F
0 1 .579 r
.22946 .31975 m
.21555 .2955 L
.27229 .31213 L
.29032 .33841 L
F
.148 1 0 r
.21555 .2955 m
.20404 .27319 L
.25738 .28763 L
.27229 .31213 L
F
.761 1 0 r
.20404 .27319 m
.19544 .25483 L
.24623 .26722 L
.25738 .28763 L
F
1 .8 0 r
.19544 .25483 m
.19013 .2426 L
.23935 .2535 L
.24623 .26722 L
F
1 .589 0 r
.19013 .2426 m
.18833 .23828 L
.23702 .24863 L
.23935 .2535 L
F
1 .637 0 r
.18833 .23828 m
.19013 .2426 L
.23935 .2535 L
.23702 .24863 L
F
1 .936 0 r
.19013 .2426 m
.19544 .25483 L
.24623 .26722 L
.23935 .2535 L
F
.556 1 0 r
.19544 .25483 m
.20404 .27319 L
.25738 .28763 L
.24623 .26722 L
F
0 1 .104 r
.20404 .27319 m
.21555 .2955 L
.27229 .31213 L
.25738 .28763 L
F
0 1 .856 r
.21555 .2955 m
.22946 .31975 L
.29032 .33841 L
.27229 .31213 L
F
0 .349 1 r
.22946 .31975 m
.24517 .34432 L
.31068 .36463 L
.29032 .33841 L
F
.447 0 1 r
.24517 .34432 m
.26199 .36799 L
.33248 .3895 L
.31068 .36463 L
F
1 0 .785 r
.26199 .36799 m
.27919 .38989 L
.35476 .4121 L
.33248 .3895 L
F
1 0 .073 r
.27919 .38989 m
.29601 .40943 L
.37656 .43189 L
.35476 .4121 L
F
1 .566 0 r
.29601 .40943 m
.31172 .42623 L
.39692 .44859 L
.37656 .43189 L
F
.884 1 0 r
.31172 .42623 m
.32563 .44008 L
.41495 .46209 L
.39692 .44859 L
F
.436 1 0 r
.32563 .44008 m
.33714 .45088 L
.42987 .47243 L
.41495 .46209 L
F
.097 1 0 r
.33714 .45088 m
.34574 .45858 L
.44101 .47969 L
.42987 .47243 L
F
0 1 .125 r
.34574 .45858 m
.35105 .46319 L
.44789 .484 L
.44101 .47969 L
F
0 1 .226 r
.35105 .46319 m
.35285 .46472 L
.45022 .48542 L
.44789 .484 L
F
0 .141 1 r
.45022 .48542 m
.44789 .484 L
.5469 .48427 L
.54978 .48542 L
F
0 .304 1 r
.44789 .484 m
.44101 .47969 L
.53841 .48074 L
.5469 .48427 L
F
0 .603 1 r
.44101 .47969 m
.42987 .47243 L
.52466 .47465 L
.53841 .48074 L
F
0 1 .966 r
.42987 .47243 m
.41495 .46209 L
.50627 .46571 L
.52466 .47465 L
F
0 1 .411 r
.41495 .46209 m
.39692 .44859 L
.48403 .45365 L
.50627 .46571 L
F
.255 1 0 r
.39692 .44859 m
.37656 .43189 L
.45892 .43822 L
.48403 .45365 L
F
1 .98 0 r
.37656 .43189 m
.35476 .4121 L
.43203 .41935 L
.45892 .43822 L
F
1 .136 0 r
.35476 .4121 m
.33248 .3895 L
.40454 .39718 L
.43203 .41935 L
F
1 0 .764 r
.33248 .3895 m
.31068 .36463 L
.37765 .37215 L
.40454 .39718 L
F
.31 0 1 r
.31068 .36463 m
.29032 .33841 L
.35254 .34514 L
.37765 .37215 L
F
0 .603 1 r
.29032 .33841 m
.27229 .31213 L
.3303 .31753 L
.35254 .34514 L
F
0 1 .549 r
.27229 .31213 m
.25738 .28763 L
.31191 .29131 L
.3303 .31753 L
F
.171 1 0 r
.25738 .28763 m
.24623 .26722 L
.29816 .26914 L
.31191 .29131 L
F
.691 1 0 r
.24623 .26722 m
.23935 .2535 L
.28967 .25403 L
.29816 .26914 L
F
.941 1 0 r
.23935 .2535 m
.23702 .24863 L
.28679 .24863 L
.28967 .25403 L
F
.884 1 0 r
.23702 .24863 m
.23935 .2535 L
.28967 .25403 L
.28679 .24863 L
F
.53 1 0 r
.23935 .2535 m
.24623 .26722 L
.29816 .26914 L
.28967 .25403 L
F
0 1 .068 r
.24623 .26722 m
.25738 .28763 L
.31191 .29131 L
.29816 .26914 L
F
0 1 .84 r
.25738 .28763 m
.27229 .31213 L
.3303 .31753 L
.31191 .29131 L
F
0 .285 1 r
.27229 .31213 m
.29032 .33841 L
.35254 .34514 L
.3303 .31753 L
F
.636 0 1 r
.29032 .33841 m
.31068 .36463 L
.37765 .37215 L
.35254 .34514 L
F
1 0 .445 r
.31068 .36463 m
.33248 .3895 L
.40454 .39718 L
.37765 .37215 L
F
1 .437 0 r
.33248 .3895 m
.35476 .4121 L
.43203 .41935 L
.40454 .39718 L
F
.746 1 0 r
.35476 .4121 m
.37656 .43189 L
.45892 .43822 L
.43203 .41935 L
F
.014 1 0 r
.37656 .43189 m
.39692 .44859 L
.48403 .45365 L
.45892 .43822 L
F
0 1 .614 r
.39692 .44859 m
.41495 .46209 L
.50627 .46571 L
.48403 .45365 L
F
0 .873 1 r
.41495 .46209 m
.42987 .47243 L
.52466 .47465 L
.50627 .46571 L
F
0 .486 1 r
.42987 .47243 m
.44101 .47969 L
.53841 .48074 L
.52466 .47465 L
F
0 .233 1 r
.44101 .47969 m
.44789 .484 L
.5469 .48427 L
.53841 .48074 L
F
0 .117 1 r
.44789 .484 m
.45022 .48542 L
.54978 .48542 L
.5469 .48427 L
F
0 .141 1 r
.45022 .48542 m
.44789 .484 L
.5469 .48427 L
.54978 .48542 L
F
0 .304 1 r
.44789 .484 m
.44101 .47969 L
.53841 .48074 L
.5469 .48427 L
F
0 .603 1 r
.44101 .47969 m
.42987 .47243 L
.52466 .47465 L
.53841 .48074 L
F
0 1 .966 r
.42987 .47243 m
.41495 .46209 L
.50627 .46571 L
.52466 .47465 L
F
0 1 .411 r
.41495 .46209 m
.39692 .44859 L
.48403 .45365 L
.50627 .46571 L
F
.255 1 0 r
.39692 .44859 m
.37656 .43189 L
.45892 .43822 L
.48403 .45365 L
F
1 .98 0 r
.37656 .43189 m
.35476 .4121 L
.43203 .41935 L
.45892 .43822 L
F
1 .136 0 r
.35476 .4121 m
.33248 .3895 L
.40454 .39718 L
.43203 .41935 L
F
1 0 .764 r
.33248 .3895 m
.31068 .36463 L
.37765 .37215 L
.40454 .39718 L
F
.31 0 1 r
.31068 .36463 m
.29032 .33841 L
.35254 .34514 L
.37765 .37215 L
F
0 .603 1 r
.29032 .33841 m
.27229 .31213 L
.3303 .31753 L
.35254 .34514 L
F
0 1 .549 r
.27229 .31213 m
.25738 .28763 L
.31191 .29131 L
.3303 .31753 L
F
.171 1 0 r
.25738 .28763 m
.24623 .26722 L
.29816 .26914 L
.31191 .29131 L
F
.691 1 0 r
.24623 .26722 m
.23935 .2535 L
.28967 .25403 L
.29816 .26914 L
F
.941 1 0 r
.23935 .2535 m
.23702 .24863 L
.28679 .24863 L
.28967 .25403 L
F
.884 1 0 r
.23702 .24863 m
.23935 .2535 L
.28967 .25403 L
.28679 .24863 L
F
.53 1 0 r
.23935 .2535 m
.24623 .26722 L
.29816 .26914 L
.28967 .25403 L
F
0 1 .068 r
.24623 .26722 m
.25738 .28763 L
.31191 .29131 L
.29816 .26914 L
F
0 1 .84 r
.25738 .28763 m
.27229 .31213 L
.3303 .31753 L
.31191 .29131 L
F
0 .285 1 r
.27229 .31213 m
.29032 .33841 L
.35254 .34514 L
.3303 .31753 L
F
.636 0 1 r
.29032 .33841 m
.31068 .36463 L
.37765 .37215 L
.35254 .34514 L
F
1 0 .445 r
.31068 .36463 m
.33248 .3895 L
.40454 .39718 L
.37765 .37215 L
F
1 .437 0 r
.33248 .3895 m
.35476 .4121 L
.43203 .41935 L
.40454 .39718 L
F
.746 1 0 r
.35476 .4121 m
.37656 .43189 L
.45892 .43822 L
.43203 .41935 L
F
.014 1 0 r
.37656 .43189 m
.39692 .44859 L
.48403 .45365 L
.45892 .43822 L
F
0 1 .614 r
.39692 .44859 m
.41495 .46209 L
.50627 .46571 L
.48403 .45365 L
F
0 .873 1 r
.41495 .46209 m
.42987 .47243 L
.52466 .47465 L
.50627 .46571 L
F
0 .486 1 r
.42987 .47243 m
.44101 .47969 L
.53841 .48074 L
.52466 .47465 L
F
0 .233 1 r
.44101 .47969 m
.44789 .484 L
.5469 .48427 L
.53841 .48074 L
F
0 .117 1 r
.44789 .484 m
.45022 .48542 L
.54978 .48542 L
.5469 .48427 L
F
1 0 .632 r
.54978 .48542 m
.5469 .48427 L
.64375 .46403 L
.64715 .46472 L
F
1 0 .813 r
.5469 .48427 m
.53841 .48074 L
.63368 .46181 L
.64375 .46403 L
F
.855 0 1 r
.53841 .48074 m
.52466 .47465 L
.61739 .45771 L
.63368 .46181 L
F
.376 0 1 r
.52466 .47465 m
.50627 .46571 L
.59559 .45123 L
.61739 .45771 L
F
0 .24 1 r
.50627 .46571 m
.48403 .45365 L
.56923 .44179 L
.59559 .45123 L
F
0 .982 1 r
.48403 .45365 m
.45892 .43822 L
.53947 .42888 L
.56923 .44179 L
F
0 1 .167 r
.45892 .43822 m
.43203 .41935 L
.5076 .41215 L
.53947 .42888 L
F
.775 1 0 r
.43203 .41935 m
.40454 .39718 L
.47503 .39154 L
.5076 .41215 L
F
1 .219 0 r
.40454 .39718 m
.37765 .37215 L
.44316 .36735 L
.47503 .39154 L
F
1 0 .819 r
.37765 .37215 m
.35254 .34514 L
.4134 .34039 L
.44316 .36735 L
F
.155 0 1 r
.35254 .34514 m
.3303 .31753 L
.38704 .31207 L
.4134 .34039 L
F
0 .802 1 r
.3303 .31753 m
.31191 .29131 L
.36524 .28452 L
.38704 .31207 L
F
0 1 .381 r
.31191 .29131 m
.29816 .26914 L
.34895 .26072 L
.36524 .28452 L
F
.211 1 0 r
.29816 .26914 m
.28967 .25403 L
.33889 .24423 L
.34895 .26072 L
F
.497 1 0 r
.28967 .25403 m
.28679 .24863 L
.33548 .23828 L
.33889 .24423 L
F
.432 1 0 r
.28679 .24863 m
.28967 .25403 L
.33889 .24423 L
.33548 .23828 L
F
.029 1 0 r
.28967 .25403 m
.29816 .26914 L
.34895 .26072 L
.33889 .24423 L
F
0 1 .651 r
.29816 .26914 m
.31191 .29131 L
.36524 .28452 L
.34895 .26072 L
F
0 .475 1 r
.31191 .29131 m
.3303 .31753 L
.38704 .31207 L
.36524 .28452 L
F
.511 0 1 r
.3303 .31753 m
.35254 .34514 L
.4134 .34039 L
.38704 .31207 L
F
1 0 .456 r
.35254 .34514 m
.37765 .37215 L
.44316 .36735 L
.4134 .34039 L
F
1 .572 0 r
.37765 .37215 m
.40454 .39718 L
.47503 .39154 L
.44316 .36735 L
F
.443 1 0 r
.40454 .39718 m
.43203 .41935 L
.5076 .41215 L
.47503 .39154 L
F
0 1 .469 r
.43203 .41935 m
.45892 .43822 L
.53947 .42888 L
.5076 .41215 L
F
0 .717 1 r
.45892 .43822 m
.48403 .45365 L
.56923 .44179 L
.53947 .42888 L
F
0 .017 1 r
.48403 .45365 m
.50627 .46571 L
.59559 .45123 L
.56923 .44179 L
F
.553 0 1 r
.50627 .46571 m
.52466 .47465 L
.61739 .45771 L
.59559 .45123 L
F
.983 0 1 r
.52466 .47465 m
.53841 .48074 L
.63368 .46181 L
.61739 .45771 L
F
1 0 .735 r
.53841 .48074 m
.5469 .48427 L
.64375 .46403 L
.63368 .46181 L
F
1 0 .606 r
.5469 .48427 m
.54978 .48542 L
.64715 .46472 L
.64375 .46403 L
F
1 0 .632 r
.54978 .48542 m
.5469 .48427 L
.64375 .46403 L
.64715 .46472 L
F
1 0 .813 r
.5469 .48427 m
.53841 .48074 L
.63368 .46181 L
.64375 .46403 L
F
.855 0 1 r
.53841 .48074 m
.52466 .47465 L
.61739 .45771 L
.63368 .46181 L
F
.376 0 1 r
.52466 .47465 m
.50627 .46571 L
.59559 .45123 L
.61739 .45771 L
F
0 .24 1 r
.50627 .46571 m
.48403 .45365 L
.56923 .44179 L
.59559 .45123 L
F
0 .982 1 r
.48403 .45365 m
.45892 .43822 L
.53947 .42888 L
.56923 .44179 L
F
0 1 .167 r
.45892 .43822 m
.43203 .41935 L
.5076 .41215 L
.53947 .42888 L
F
.775 1 0 r
.43203 .41935 m
.40454 .39718 L
.47503 .39154 L
.5076 .41215 L
F
1 .219 0 r
.40454 .39718 m
.37765 .37215 L
.44316 .36735 L
.47503 .39154 L
F
1 0 .819 r
.37765 .37215 m
.35254 .34514 L
.4134 .34039 L
.44316 .36735 L
F
.155 0 1 r
.35254 .34514 m
.3303 .31753 L
.38704 .31207 L
.4134 .34039 L
F
0 .802 1 r
.3303 .31753 m
.31191 .29131 L
.36524 .28452 L
.38704 .31207 L
F
0 1 .381 r
.31191 .29131 m
.29816 .26914 L
.34895 .26072 L
.36524 .28452 L
F
.211 1 0 r
.29816 .26914 m
.28967 .25403 L
.33889 .24423 L
.34895 .26072 L
F
.497 1 0 r
.28967 .25403 m
.28679 .24863 L
.33548 .23828 L
.33889 .24423 L
F
.432 1 0 r
.28679 .24863 m
.28967 .25403 L
.33889 .24423 L
.33548 .23828 L
F
.029 1 0 r
.28967 .25403 m
.29816 .26914 L
.34895 .26072 L
.33889 .24423 L
F
0 1 .651 r
.29816 .26914 m
.31191 .29131 L
.36524 .28452 L
.34895 .26072 L
F
0 .475 1 r
.31191 .29131 m
.3303 .31753 L
.38704 .31207 L
.36524 .28452 L
F
.511 0 1 r
.3303 .31753 m
.35254 .34514 L
.4134 .34039 L
.38704 .31207 L
F
1 0 .456 r
.35254 .34514 m
.37765 .37215 L
.44316 .36735 L
.4134 .34039 L
F
1 .572 0 r
.37765 .37215 m
.40454 .39718 L
.47503 .39154 L
.44316 .36735 L
F
.443 1 0 r
.40454 .39718 m
.43203 .41935 L
.5076 .41215 L
.47503 .39154 L
F
0 1 .469 r
.43203 .41935 m
.45892 .43822 L
.53947 .42888 L
.5076 .41215 L
F
0 .717 1 r
.45892 .43822 m
.48403 .45365 L
.56923 .44179 L
.53947 .42888 L
F
0 .017 1 r
.48403 .45365 m
.50627 .46571 L
.59559 .45123 L
.56923 .44179 L
F
.553 0 1 r
.50627 .46571 m
.52466 .47465 L
.61739 .45771 L
.59559 .45123 L
F
.983 0 1 r
.52466 .47465 m
.53841 .48074 L
.63368 .46181 L
.61739 .45771 L
F
1 0 .735 r
.53841 .48074 m
.5469 .48427 L
.64375 .46403 L
.63368 .46181 L
F
1 0 .606 r
.5469 .48427 m
.54978 .48542 L
.64715 .46472 L
.64375 .46403 L
F
1 .707 0 r
.64715 .46472 m
.64375 .46403 L
.73419 .42421 L
.7381 .42423 L
F
1 .511 0 r
.64375 .46403 m
.63368 .46181 L
.72266 .42394 L
.73419 .42421 L
F
1 .15 0 r
.63368 .46181 m
.61739 .45771 L
.70399 .42282 L
.72266 .42394 L
F
1 0 .371 r
.61739 .45771 m
.59559 .45123 L
.67901 .41998 L
.70399 .42282 L
F
.959 0 1 r
.59559 .45123 m
.56923 .44179 L
.64881 .41445 L
.67901 .41998 L
F
.152 0 1 r
.56923 .44179 m
.53947 .42888 L
.61471 .40534 L
.64881 .41445 L
F
0 .776 1 r
.53947 .42888 m
.5076 .41215 L
.57819 .39197 L
.61471 .40534 L
F
0 1 .197 r
.5076 .41215 m
.47503 .39154 L
.54086 .37401 L
.57819 .39197 L
F
.902 1 0 r
.47503 .39154 m
.44316 .36735 L
.50434 .35159 L
.54086 .37401 L
F
1 0 .038 r
.44316 .36735 m
.4134 .34039 L
.47024 .3254 L
.50434 .35159 L
F
.837 0 1 r
.4134 .34039 m
.38704 .31207 L
.44004 .29685 L
.47024 .3254 L
F
0 .217 1 r
.38704 .31207 m
.36524 .28452 L
.41506 .26819 L
.44004 .29685 L
F
0 1 .881 r
.36524 .28452 m
.34895 .26072 L
.39639 .24272 L
.41506 .26819 L
F
0 1 .225 r
.34895 .26072 m
.33889 .24423 L
.38485 .22465 L
.39639 .24272 L
F
.093 1 0 r
.33889 .24423 m
.33548 .23828 L
.38095 .21804 L
.38485 .22465 L
F
.021 1 0 r
.33548 .23828 m
.33889 .24423 L
.38485 .22465 L
.38095 .21804 L
F
0 1 .427 r
.33889 .24423 m
.34895 .26072 L
.39639 .24272 L
.38485 .22465 L
F
0 .821 1 r
.34895 .26072 m
.36524 .28452 L
.41506 .26819 L
.39639 .24272 L
F
.141 0 1 r
.36524 .28452 m
.38704 .31207 L
.44004 .29685 L
.41506 .26819 L
F
1 0 .775 r
.38704 .31207 m
.4134 .34039 L
.47024 .3254 L
.44004 .29685 L
F
1 .356 0 r
.4134 .34039 m
.44316 .36735 L
.50434 .35159 L
.47024 .3254 L
F
.519 1 0 r
.44316 .36735 m
.47503 .39154 L
.54086 .37401 L
.50434 .35159 L
F
0 1 .556 r
.47503 .39154 m
.5076 .41215 L
.57819 .39197 L
.54086 .37401 L
F
0 .45 1 r
.5076 .41215 m
.53947 .42888 L
.61471 .40534 L
.57819 .39197 L
F
.437 0 1 r
.53947 .42888 m
.56923 .44179 L
.64881 .41445 L
.61471 .40534 L
F
1 0 .802 r
.56923 .44179 m
.59559 .45123 L
.67901 .41998 L
.64881 .41445 L
F
1 0 .181 r
.59559 .45123 m
.61739 .45771 L
.70399 .42282 L
.67901 .41998 L
F
1 .286 0 r
.61739 .45771 m
.63368 .46181 L
.72266 .42394 L
.70399 .42282 L
F
1 .593 0 r
.63368 .46181 m
.64375 .46403 L
.73419 .42421 L
.72266 .42394 L
F
1 .734 0 r
.64375 .46403 m
.64715 .46472 L
.7381 .42423 L
.73419 .42421 L
F
1 .707 0 r
.64715 .46472 m
.64375 .46403 L
.73419 .42421 L
.7381 .42423 L
F
1 .511 0 r
.64375 .46403 m
.63368 .46181 L
.72266 .42394 L
.73419 .42421 L
F
1 .15 0 r
.63368 .46181 m
.61739 .45771 L
.70399 .42282 L
.72266 .42394 L
F
1 0 .371 r
.61739 .45771 m
.59559 .45123 L
.67901 .41998 L
.70399 .42282 L
F
.959 0 1 r
.59559 .45123 m
.56923 .44179 L
.64881 .41445 L
.67901 .41998 L
F
.152 0 1 r
.56923 .44179 m
.53947 .42888 L
.61471 .40534 L
.64881 .41445 L
F
0 .776 1 r
.53947 .42888 m
.5076 .41215 L
.57819 .39197 L
.61471 .40534 L
F
0 1 .197 r
.5076 .41215 m
.47503 .39154 L
.54086 .37401 L
.57819 .39197 L
F
.902 1 0 r
.47503 .39154 m
.44316 .36735 L
.50434 .35159 L
.54086 .37401 L
F
1 0 .038 r
.44316 .36735 m
.4134 .34039 L
.47024 .3254 L
.50434 .35159 L
F
.837 0 1 r
.4134 .34039 m
.38704 .31207 L
.44004 .29685 L
.47024 .3254 L
F
0 .217 1 r
.38704 .31207 m
.36524 .28452 L
.41506 .26819 L
.44004 .29685 L
F
0 1 .881 r
.36524 .28452 m
.34895 .26072 L
.39639 .24272 L
.41506 .26819 L
F
0 1 .225 r
.34895 .26072 m
.33889 .24423 L
.38485 .22465 L
.39639 .24272 L
F
.093 1 0 r
.33889 .24423 m
.33548 .23828 L
.38095 .21804 L
.38485 .22465 L
F
.021 1 0 r
.33548 .23828 m
.33889 .24423 L
.38485 .22465 L
.38095 .21804 L
F
0 1 .427 r
.33889 .24423 m
.34895 .26072 L
.39639 .24272 L
.38485 .22465 L
F
0 .821 1 r
.34895 .26072 m
.36524 .28452 L
.41506 .26819 L
.39639 .24272 L
F
.141 0 1 r
.36524 .28452 m
.38704 .31207 L
.44004 .29685 L
.41506 .26819 L
F
1 0 .775 r
.38704 .31207 m
.4134 .34039 L
.47024 .3254 L
.44004 .29685 L
F
1 .356 0 r
.4134 .34039 m
.44316 .36735 L
.50434 .35159 L
.47024 .3254 L
F
.519 1 0 r
.44316 .36735 m
.47503 .39154 L
.54086 .37401 L
.50434 .35159 L
F
0 1 .556 r
.47503 .39154 m
.5076 .41215 L
.57819 .39197 L
.54086 .37401 L
F
0 .45 1 r
.5076 .41215 m
.53947 .42888 L
.61471 .40534 L
.57819 .39197 L
F
.437 0 1 r
.53947 .42888 m
.56923 .44179 L
.64881 .41445 L
.61471 .40534 L
F
1 0 .802 r
.56923 .44179 m
.59559 .45123 L
.67901 .41998 L
.64881 .41445 L
F
1 0 .181 r
.59559 .45123 m
.61739 .45771 L
.70399 .42282 L
.67901 .41998 L
F
1 .286 0 r
.61739 .45771 m
.63368 .46181 L
.72266 .42394 L
.70399 .42282 L
F
1 .593 0 r
.63368 .46181 m
.64375 .46403 L
.73419 .42421 L
.72266 .42394 L
F
1 .734 0 r
.64375 .46403 m
.64715 .46472 L
.7381 .42423 L
.73419 .42421 L
F
.143 1 0 r
.7381 .42423 m
.73419 .42421 L
.81429 .36668 L
.81863 .36572 L
F
.351 1 0 r
.73419 .42421 m
.72266 .42394 L
.80145 .36919 L
.81429 .36668 L
F
.737 1 0 r
.72266 .42394 m
.70399 .42282 L
.78068 .37226 L
.80145 .36919 L
F
1 .708 0 r
.70399 .42282 m
.67901 .41998 L
.75289 .37447 L
.78068 .37226 L
F
1 0 .008 r
.67901 .41998 m
.64881 .41445 L
.71928 .37428 L
.75289 .37447 L
F
1 0 .872 r
.64881 .41445 m
.61471 .40534 L
.68133 .3703 L
.71928 .37428 L
F
.135 0 1 r
.61471 .40534 m
.57819 .39197 L
.6407 .36145 L
.68133 .3703 L
F
0 .965 1 r
.57819 .39197 m
.54086 .37401 L
.59916 .34712 L
.6407 .36145 L
F
.143 1 0 r
.54086 .37401 m
.50434 .35159 L
.55852 .32723 L
.59916 .34712 L
F
1 .638 0 r
.50434 .35159 m
.47024 .3254 L
.52057 .30236 L
.55852 .32723 L
F
1 0 .572 r
.47024 .3254 m
.44004 .29685 L
.48697 .27385 L
.52057 .30236 L
F
.292 0 1 r
.44004 .29685 m
.41506 .26819 L
.45917 .24404 L
.48697 .27385 L
F
0 .684 1 r
.41506 .26819 m
.39639 .24272 L
.4384 .21653 L
.45917 .24404 L
F
0 1 .605 r
.39639 .24272 m
.38485 .22465 L
.42556 .19634 L
.4384 .21653 L
F
0 1 .26 r
.38485 .22465 m
.38095 .21804 L
.42122 .18878 L
.42556 .19634 L
F
0 1 .339 r
.38095 .21804 m
.38485 .22465 L
.42556 .19634 L
.42122 .18878 L
F
0 1 .825 r
.38485 .22465 m
.39639 .24272 L
.4384 .21653 L
.42556 .19634 L
F
0 .361 1 r
.39639 .24272 m
.41506 .26819 L
.45917 .24404 L
.4384 .21653 L
F
.677 0 1 r
.41506 .26819 m
.44004 .29685 L
.48697 .27385 L
.45917 .24404 L
F
1 0 .157 r
.44004 .29685 m
.47024 .3254 L
.52057 .30236 L
.48697 .27385 L
F
.941 1 0 r
.47024 .3254 m
.50434 .35159 L
.55852 .32723 L
.52057 .30236 L
F
0 1 .265 r
.50434 .35159 m
.54086 .37401 L
.59916 .34712 L
.55852 .32723 L
F
0 .583 1 r
.54086 .37401 m
.57819 .39197 L
.6407 .36145 L
.59916 .34712 L
F
.481 0 1 r
.57819 .39197 m
.61471 .40534 L
.68133 .3703 L
.6407 .36145 L
F
1 0 .57 r
.61471 .40534 m
.64881 .41445 L
.71928 .37428 L
.68133 .3703 L
F
1 .244 0 r
.64881 .41445 m
.67901 .41998 L
.75289 .37447 L
.71928 .37428 L
F
1 .907 0 r
.67901 .41998 m
.70399 .42282 L
.78068 .37226 L
.75289 .37447 L
F
.593 1 0 r
.70399 .42282 m
.72266 .42394 L
.80145 .36919 L
.78068 .37226 L
F
.265 1 0 r
.72266 .42394 m
.73419 .42421 L
.81429 .36668 L
.80145 .36919 L
F
.114 1 0 r
.73419 .42421 m
.7381 .42423 L
.81863 .36572 L
.81429 .36668 L
F
.143 1 0 r
.7381 .42423 m
.73419 .42421 L
.81429 .36668 L
.81863 .36572 L
F
.351 1 0 r
.73419 .42421 m
.72266 .42394 L
.80145 .36919 L
.81429 .36668 L
F
.737 1 0 r
.72266 .42394 m
.70399 .42282 L
.78068 .37226 L
.80145 .36919 L
F
1 .708 0 r
.70399 .42282 m
.67901 .41998 L
.75289 .37447 L
.78068 .37226 L
F
1 0 .008 r
.67901 .41998 m
.64881 .41445 L
.71928 .37428 L
.75289 .37447 L
F
1 0 .872 r
.64881 .41445 m
.61471 .40534 L
.68133 .3703 L
.71928 .37428 L
F
.135 0 1 r
.61471 .40534 m
.57819 .39197 L
.6407 .36145 L
.68133 .3703 L
F
0 .965 1 r
.57819 .39197 m
.54086 .37401 L
.59916 .34712 L
.6407 .36145 L
F
.143 1 0 r
.54086 .37401 m
.50434 .35159 L
.55852 .32723 L
.59916 .34712 L
F
1 .638 0 r
.50434 .35159 m
.47024 .3254 L
.52057 .30236 L
.55852 .32723 L
F
1 0 .572 r
.47024 .3254 m
.44004 .29685 L
.48697 .27385 L
.52057 .30236 L
F
.292 0 1 r
.44004 .29685 m
.41506 .26819 L
.45917 .24404 L
.48697 .27385 L
F
0 .684 1 r
.41506 .26819 m
.39639 .24272 L
.4384 .21653 L
.45917 .24404 L
F
0 1 .605 r
.39639 .24272 m
.38485 .22465 L
.42556 .19634 L
.4384 .21653 L
F
0 1 .26 r
.38485 .22465 m
.38095 .21804 L
.42122 .18878 L
.42556 .19634 L
F
0 1 .339 r
.38095 .21804 m
.38485 .22465 L
.42556 .19634 L
.42122 .18878 L
F
0 1 .825 r
.38485 .22465 m
.39639 .24272 L
.4384 .21653 L
.42556 .19634 L
F
0 .361 1 r
.39639 .24272 m
.41506 .26819 L
.45917 .24404 L
.4384 .21653 L
F
.677 0 1 r
.41506 .26819 m
.44004 .29685 L
.48697 .27385 L
.45917 .24404 L
F
1 0 .157 r
.44004 .29685 m
.47024 .3254 L
.52057 .30236 L
.48697 .27385 L
F
.941 1 0 r
.47024 .3254 m
.50434 .35159 L
.55852 .32723 L
.52057 .30236 L
F
0 1 .265 r
.50434 .35159 m
.54086 .37401 L
.59916 .34712 L
.55852 .32723 L
F
0 .583 1 r
.54086 .37401 m
.57819 .39197 L
.6407 .36145 L
.59916 .34712 L
F
.481 0 1 r
.57819 .39197 m
.61471 .40534 L
.68133 .3703 L
.6407 .36145 L
F
1 0 .57 r
.61471 .40534 m
.64881 .41445 L
.71928 .37428 L
.68133 .3703 L
F
1 .244 0 r
.64881 .41445 m
.67901 .41998 L
.75289 .37447 L
.71928 .37428 L
F
1 .907 0 r
.67901 .41998 m
.70399 .42282 L
.78068 .37226 L
.75289 .37447 L
F
.593 1 0 r
.70399 .42282 m
.72266 .42394 L
.80145 .36919 L
.78068 .37226 L
F
.265 1 0 r
.72266 .42394 m
.73419 .42421 L
.81429 .36668 L
.80145 .36919 L
F
.114 1 0 r
.73419 .42421 m
.7381 .42423 L
.81863 .36572 L
.81429 .36668 L
F
0 1 .804 r
.81863 .36572 m
.81429 .36668 L
.88054 .29416 L
.88525 .29174 L
F
0 1 .586 r
.81429 .36668 m
.80145 .36919 L
.86663 .30076 L
.88054 .29416 L
F
0 1 .182 r
.80145 .36919 m
.78068 .37226 L
.84412 .30976 L
.86663 .30076 L
F
.402 1 0 r
.78068 .37226 m
.75289 .37447 L
.81399 .31882 L
.84412 .30976 L
F
1 .844 0 r
.75289 .37447 m
.71928 .37428 L
.77757 .32559 L
.81399 .31882 L
F
1 0 .065 r
.71928 .37428 m
.68133 .3703 L
.73644 .32806 L
.77757 .32559 L
F
.889 0 1 r
.68133 .3703 m
.6407 .36145 L
.6924 .32474 L
.73644 .32806 L
F
0 .271 1 r
.6407 .36145 m
.59916 .34712 L
.64738 .31477 L
.6924 .32474 L
F
0 1 .486 r
.59916 .34712 m
.55852 .32723 L
.60334 .29791 L
.64738 .31477 L
F
.801 1 0 r
.55852 .32723 m
.52057 .30236 L
.56221 .27463 L
.60334 .29791 L
F
1 0 .081 r
.52057 .30236 m
.48697 .27385 L
.52578 .24619 L
.56221 .27463 L
F
.715 0 1 r
.48697 .27385 m
.45917 .24404 L
.49566 .21487 L
.52578 .24619 L
F
0 .321 1 r
.45917 .24404 m
.4384 .21653 L
.47315 .18446 L
.49566 .21487 L
F
0 1 .922 r
.4384 .21653 m
.42556 .19634 L
.45923 .16095 L
.47315 .18446 L
F
0 1 .554 r
.42556 .19634 m
.42122 .18878 L
.45453 .15179 L
.45923 .16095 L
F
0 1 .64 r
.42122 .18878 m
.42556 .19634 L
.45923 .16095 L
.45453 .15179 L
F
0 .843 1 r
.42556 .19634 m
.4384 .21653 L
.47315 .18446 L
.45923 .16095 L
F
.021 0 1 r
.4384 .21653 m
.45917 .24404 L
.49566 .21487 L
.47315 .18446 L
F
1 0 .878 r
.45917 .24404 m
.48697 .27385 L
.52578 .24619 L
.49566 .21487 L
F
1 .356 0 r
.48697 .27385 m
.52057 .30236 L
.56221 .27463 L
.52578 .24619 L
F
.36 1 0 r
.52057 .30236 m
.55852 .32723 L
.60334 .29791 L
.56221 .27463 L
F
0 1 .913 r
.55852 .32723 m
.59916 .34712 L
.64738 .31477 L
.60334 .29791 L
F
.128 0 1 r
.59916 .34712 m
.6407 .36145 L
.6924 .32474 L
.64738 .31477 L
F
1 0 .751 r
.6407 .36145 m
.68133 .3703 L
.73644 .32806 L
.6924 .32474 L
F
1 .249 0 r
.68133 .3703 m
.71928 .37428 L
.77757 .32559 L
.73644 .32806 L
F
.894 1 0 r
.71928 .37428 m
.75289 .37447 L
.81399 .31882 L
.77757 .32559 L
F
.197 1 0 r
.75289 .37447 m
.78068 .37226 L
.84412 .30976 L
.81399 .31882 L
F
0 1 .329 r
.78068 .37226 m
.80145 .36919 L
.86663 .30076 L
.84412 .30976 L
F
0 1 .674 r
.80145 .36919 m
.81429 .36668 L
.88054 .29416 L
.86663 .30076 L
F
0 1 .834 r
.81429 .36668 m
.81863 .36572 L
.88525 .29174 L
.88054 .29416 L
F
0 1 .804 r
.81863 .36572 m
.81429 .36668 L
.88054 .29416 L
.88525 .29174 L
F
0 1 .586 r
.81429 .36668 m
.80145 .36919 L
.86663 .30076 L
.88054 .29416 L
F
0 1 .182 r
.80145 .36919 m
.78068 .37226 L
.84412 .30976 L
.86663 .30076 L
F
.402 1 0 r
.78068 .37226 m
.75289 .37447 L
.81399 .31882 L
.84412 .30976 L
F
1 .844 0 r
.75289 .37447 m
.71928 .37428 L
.77757 .32559 L
.81399 .31882 L
F
1 0 .065 r
.71928 .37428 m
.68133 .3703 L
.73644 .32806 L
.77757 .32559 L
F
.889 0 1 r
.68133 .3703 m
.6407 .36145 L
.6924 .32474 L
.73644 .32806 L
F
0 .271 1 r
.6407 .36145 m
.59916 .34712 L
.64738 .31477 L
.6924 .32474 L
F
0 1 .486 r
.59916 .34712 m
.55852 .32723 L
.60334 .29791 L
.64738 .31477 L
F
.801 1 0 r
.55852 .32723 m
.52057 .30236 L
.56221 .27463 L
.60334 .29791 L
F
1 0 .081 r
.52057 .30236 m
.48697 .27385 L
.52578 .24619 L
.56221 .27463 L
F
.715 0 1 r
.48697 .27385 m
.45917 .24404 L
.49566 .21487 L
.52578 .24619 L
F
0 .321 1 r
.45917 .24404 m
.4384 .21653 L
.47315 .18446 L
.49566 .21487 L
F
0 1 .922 r
.4384 .21653 m
.42556 .19634 L
.45923 .16095 L
.47315 .18446 L
F
0 1 .554 r
.42556 .19634 m
.42122 .18878 L
.45453 .15179 L
.45923 .16095 L
F
0 1 .64 r
.42122 .18878 m
.42556 .19634 L
.45923 .16095 L
.45453 .15179 L
F
0 .843 1 r
.42556 .19634 m
.4384 .21653 L
.47315 .18446 L
.45923 .16095 L
F
.021 0 1 r
.4384 .21653 m
.45917 .24404 L
.49566 .21487 L
.47315 .18446 L
F
1 0 .878 r
.45917 .24404 m
.48697 .27385 L
.52578 .24619 L
.49566 .21487 L
F
1 .356 0 r
.48697 .27385 m
.52057 .30236 L
.56221 .27463 L
.52578 .24619 L
F
.36 1 0 r
.52057 .30236 m
.55852 .32723 L
.60334 .29791 L
.56221 .27463 L
F
0 1 .913 r
.55852 .32723 m
.59916 .34712 L
.64738 .31477 L
.60334 .29791 L
F
.128 0 1 r
.59916 .34712 m
.6407 .36145 L
.6924 .32474 L
.64738 .31477 L
F
1 0 .751 r
.6407 .36145 m
.68133 .3703 L
.73644 .32806 L
.6924 .32474 L
F
1 .249 0 r
.68133 .3703 m
.71928 .37428 L
.77757 .32559 L
.73644 .32806 L
F
.894 1 0 r
.71928 .37428 m
.75289 .37447 L
.81399 .31882 L
.77757 .32559 L
F
.197 1 0 r
.75289 .37447 m
.78068 .37226 L
.84412 .30976 L
.81399 .31882 L
F
0 1 .329 r
.78068 .37226 m
.80145 .36919 L
.86663 .30076 L
.84412 .30976 L
F
0 1 .674 r
.80145 .36919 m
.81429 .36668 L
.88054 .29416 L
.86663 .30076 L
F
0 1 .834 r
.81429 .36668 m
.81863 .36572 L
.88525 .29174 L
.88054 .29416 L
F
0 .464 1 r
.88525 .29174 m
.88054 .29416 L
.93004 .21046 L
.93502 .20552 L
F
0 .688 1 r
.88054 .29416 m
.86663 .30076 L
.91533 .22369 L
.93004 .21046 L
F
0 1 .893 r
.86663 .30076 m
.84412 .30976 L
.89152 .24153 L
.91533 .22369 L
F
0 1 .288 r
.84412 .30976 m
.81399 .31882 L
.85965 .25987 L
.89152 .24153 L
F
.495 1 0 r
.81399 .31882 m
.77757 .32559 L
.82112 .27528 L
.85965 .25987 L
F
1 .56 0 r
.77757 .32559 m
.73644 .32806 L
.77761 .28521 L
.82112 .27528 L
F
1 0 .527 r
.73644 .32806 m
.6924 .32474 L
.73103 .28796 L
.77761 .28521 L
F
.267 0 1 r
.6924 .32474 m
.64738 .31477 L
.68341 .28258 L
.73103 .28796 L
F
0 1 .975 r
.64738 .31477 m
.60334 .29791 L
.63682 .26882 L
.68341 .28258 L
F
.365 1 0 r
.60334 .29791 m
.56221 .27463 L
.59332 .24707 L
.63682 .26882 L
F
1 .302 0 r
.56221 .27463 m
.52578 .24619 L
.55479 .21846 L
.59332 .24707 L
F
1 0 .954 r
.52578 .24619 m
.49566 .21487 L
.52292 .18503 L
.55479 .21846 L
F
0 .038 1 r
.49566 .21487 m
.47315 .18446 L
.49911 .15033 L
.52292 .18503 L
F
0 .832 1 r
.47315 .18446 m
.45923 .16095 L
.48439 .12106 L
.49911 .15033 L
F
0 1 .783 r
.45923 .16095 m
.45453 .15179 L
.47942 .10868 L
.48439 .12106 L
F
0 1 .875 r
.45453 .15179 m
.45923 .16095 L
.48439 .12106 L
.47942 .10868 L
F
0 .583 1 r
.45923 .16095 m
.47315 .18446 L
.49911 .15033 L
.48439 .12106 L
F
.32 0 1 r
.47315 .18446 m
.49566 .21487 L
.52292 .18503 L
.49911 .15033 L
F
1 0 .532 r
.49566 .21487 m
.52578 .24619 L
.55479 .21846 L
.52292 .18503 L
F
1 .754 0 r
.52578 .24619 m
.56221 .27463 L
.59332 .24707 L
.55479 .21846 L
F
0 1 .092 r
.56221 .27463 m
.60334 .29791 L
.63682 .26882 L
.59332 .24707 L
F
0 .583 1 r
.60334 .29791 m
.64738 .31477 L
.68341 .28258 L
.63682 .26882 L
F
.68 0 1 r
.64738 .31477 m
.6924 .32474 L
.73103 .28796 L
.68341 .28258 L
F
1 0 .154 r
.6924 .32474 m
.73644 .32806 L
.77761 .28521 L
.73103 .28796 L
F
1 .884 0 r
.73644 .32806 m
.77757 .32559 L
.82112 .27528 L
.77761 .28521 L
F
.226 1 0 r
.77757 .32559 m
.81399 .31882 L
.85965 .25987 L
.82112 .27528 L
F
0 1 .497 r
.81399 .31882 m
.84412 .30976 L
.89152 .24153 L
.85965 .25987 L
F
0 .958 1 r
.84412 .30976 m
.86663 .30076 L
.91533 .22369 L
.89152 .24153 L
F
0 .601 1 r
.86663 .30076 m
.88054 .29416 L
.93004 .21046 L
.91533 .22369 L
F
0 .435 1 r
.88054 .29416 m
.88525 .29174 L
.93502 .20552 L
.93004 .21046 L
F
0 .464 1 r
.88525 .29174 m
.88054 .29416 L
.93004 .21046 L
.93502 .20552 L
F
0 .688 1 r
.88054 .29416 m
.86663 .30076 L
.91533 .22369 L
.93004 .21046 L
F
0 1 .893 r
.86663 .30076 m
.84412 .30976 L
.89152 .24153 L
.91533 .22369 L
F
0 1 .288 r
.84412 .30976 m
.81399 .31882 L
.85965 .25987 L
.89152 .24153 L
F
.495 1 0 r
.81399 .31882 m
.77757 .32559 L
.82112 .27528 L
.85965 .25987 L
F
1 .56 0 r
.77757 .32559 m
.73644 .32806 L
.77761 .28521 L
.82112 .27528 L
F
1 0 .527 r
.73644 .32806 m
.6924 .32474 L
.73103 .28796 L
.77761 .28521 L
F
.267 0 1 r
.6924 .32474 m
.64738 .31477 L
.68341 .28258 L
.73103 .28796 L
F
0 1 .975 r
.64738 .31477 m
.60334 .29791 L
.63682 .26882 L
.68341 .28258 L
F
.365 1 0 r
.60334 .29791 m
.56221 .27463 L
.59332 .24707 L
.63682 .26882 L
F
1 .302 0 r
.56221 .27463 m
.52578 .24619 L
.55479 .21846 L
.59332 .24707 L
F
1 0 .954 r
.52578 .24619 m
.49566 .21487 L
.52292 .18503 L
.55479 .21846 L
F
0 .038 1 r
.49566 .21487 m
.47315 .18446 L
.49911 .15033 L
.52292 .18503 L
F
0 .832 1 r
.47315 .18446 m
.45923 .16095 L
.48439 .12106 L
.49911 .15033 L
F
0 1 .783 r
.45923 .16095 m
.45453 .15179 L
.47942 .10868 L
.48439 .12106 L
F
0 1 .875 r
.45453 .15179 m
.45923 .16095 L
.48439 .12106 L
.47942 .10868 L
F
0 .583 1 r
.45923 .16095 m
.47315 .18446 L
.49911 .15033 L
.48439 .12106 L
F
.32 0 1 r
.47315 .18446 m
.49566 .21487 L
.52292 .18503 L
.49911 .15033 L
F
1 0 .532 r
.49566 .21487 m
.52578 .24619 L
.55479 .21846 L
.52292 .18503 L
F
1 .754 0 r
.52578 .24619 m
.56221 .27463 L
.59332 .24707 L
.55479 .21846 L
F
0 1 .092 r
.56221 .27463 m
.60334 .29791 L
.63682 .26882 L
.59332 .24707 L
F
0 .583 1 r
.60334 .29791 m
.64738 .31477 L
.68341 .28258 L
.63682 .26882 L
F
.68 0 1 r
.64738 .31477 m
.6924 .32474 L
.73103 .28796 L
.68341 .28258 L
F
1 0 .154 r
.6924 .32474 m
.73644 .32806 L
.77761 .28521 L
.73103 .28796 L
F
1 .884 0 r
.73644 .32806 m
.77757 .32559 L
.82112 .27528 L
.77761 .28521 L
F
.226 1 0 r
.77757 .32559 m
.81399 .31882 L
.85965 .25987 L
.82112 .27528 L
F
0 1 .497 r
.81399 .31882 m
.84412 .30976 L
.89152 .24153 L
.85965 .25987 L
F
0 .958 1 r
.84412 .30976 m
.86663 .30076 L
.91533 .22369 L
.89152 .24153 L
F
0 .601 1 r
.86663 .30076 m
.88054 .29416 L
.93004 .21046 L
.91533 .22369 L
F
0 .435 1 r
.88054 .29416 m
.88525 .29174 L
.93502 .20552 L
.93004 .21046 L
F
.045 0 1 r
.93502 .20552 m
.93004 .21046 L
.96064 .12193 L
.96578 .11085 L
F
0 .181 1 r
.93004 .21046 m
.91533 .22369 L
.94543 .14844 L
.96064 .12193 L
F
0 .608 1 r
.91533 .22369 m
.89152 .24153 L
.92081 .17995 L
.94543 .14844 L
F
0 1 .77 r
.89152 .24153 m
.85965 .25987 L
.88787 .20986 L
.92081 .17995 L
F
.034 1 0 r
.85965 .25987 m
.82112 .27528 L
.84804 .23445 L
.88787 .20986 L
F
1 .996 0 r
.82112 .27528 m
.77761 .28521 L
.80306 .25147 L
.84804 .23445 L
F
1 0 .12 r
.77761 .28521 m
.73103 .28796 L
.75491 .25955 L
.80306 .25147 L
F
.643 0 1 r
.73103 .28796 m
.68341 .28258 L
.70568 .258 L
.75491 .25955 L
F
0 .684 1 r
.68341 .28258 m
.63682 .26882 L
.65752 .24668 L
.70568 .258 L
F
.059 1 0 r
.63682 .26882 m
.59332 .24707 L
.61254 .22604 L
.65752 .24668 L
F
1 .571 0 r
.59332 .24707 m
.55479 .21846 L
.57271 .19703 L
.61254 .22604 L
F
1 0 .721 r
.55479 .21846 m
.52292 .18503 L
.53977 .16121 L
.57271 .19703 L
F
.162 0 1 r
.52292 .18503 m
.49911 .15033 L
.51516 .12112 L
.53977 .16121 L
F
0 .66 1 r
.49911 .15033 m
.48439 .12106 L
.49994 .08204 L
.51516 .12112 L
F
0 1 .941 r
.48439 .12106 m
.47942 .10868 L
.4948 .06134 L
.49994 .08204 L
F
0 .957 1 r
.47942 .10868 m
.48439 .12106 L
.49994 .08204 L
.4948 .06134 L
F
0 .4 1 r
.48439 .12106 m
.49911 .15033 L
.51516 .12112 L
.49994 .08204 L
F
.528 0 1 r
.49911 .15033 m
.52292 .18503 L
.53977 .16121 L
.51516 .12112 L
F
1 0 .29 r
.52292 .18503 m
.55479 .21846 L
.57271 .19703 L
.53977 .16121 L
F
.968 1 0 r
.55479 .21846 m
.59332 .24707 L
.61254 .22604 L
.57271 .19703 L
F
0 1 .407 r
.59332 .24707 m
.63682 .26882 L
.65752 .24668 L
.61254 .22604 L
F
0 .232 1 r
.63682 .26882 m
.68341 .28258 L
.70568 .258 L
.65752 .24668 L
F
1 0 .934 r
.68341 .28258 m
.73103 .28796 L
.75491 .25955 L
.70568 .258 L
F
1 .263 0 r
.73103 .28796 m
.77761 .28521 L
.80306 .25147 L
.75491 .25955 L
F
.671 1 0 r
.77761 .28521 m
.82112 .27528 L
.84804 .23445 L
.80306 .25147 L
F
0 1 .241 r
.82112 .27528 m
.85965 .25987 L
.88787 .20986 L
.84804 .23445 L
F
0 1 .982 r
.85965 .25987 m
.89152 .24153 L
.92081 .17995 L
.88787 .20986 L
F
0 .462 1 r
.89152 .24153 m
.91533 .22369 L
.94543 .14844 L
.92081 .17995 L
F
0 .099 1 r
.91533 .22369 m
.93004 .21046 L
.96064 .12193 L
.94543 .14844 L
F
.07 0 1 r
.93004 .21046 m
.93502 .20552 L
.96578 .11085 L
.96064 .12193 L
F
.045 0 1 r
.93502 .20552 m
.93004 .21046 L
.96064 .12193 L
.96578 .11085 L
F
0 .181 1 r
.93004 .21046 m
.91533 .22369 L
.94543 .14844 L
.96064 .12193 L
F
0 .608 1 r
.91533 .22369 m
.89152 .24153 L
.92081 .17995 L
.94543 .14844 L
F
0 1 .77 r
.89152 .24153 m
.85965 .25987 L
.88787 .20986 L
.92081 .17995 L
F
.034 1 0 r
.85965 .25987 m
.82112 .27528 L
.84804 .23445 L
.88787 .20986 L
F
1 .996 0 r
.82112 .27528 m
.77761 .28521 L
.80306 .25147 L
.84804 .23445 L
F
1 0 .12 r
.77761 .28521 m
.73103 .28796 L
.75491 .25955 L
.80306 .25147 L
F
.643 0 1 r
.73103 .28796 m
.68341 .28258 L
.70568 .258 L
.75491 .25955 L
F
0 .684 1 r
.68341 .28258 m
.63682 .26882 L
.65752 .24668 L
.70568 .258 L
F
.059 1 0 r
.63682 .26882 m
.59332 .24707 L
.61254 .22604 L
.65752 .24668 L
F
1 .571 0 r
.59332 .24707 m
.55479 .21846 L
.57271 .19703 L
.61254 .22604 L
F
1 0 .721 r
.55479 .21846 m
.52292 .18503 L
.53977 .16121 L
.57271 .19703 L
F
.162 0 1 r
.52292 .18503 m
.49911 .15033 L
.51516 .12112 L
.53977 .16121 L
F
0 .66 1 r
.49911 .15033 m
.48439 .12106 L
.49994 .08204 L
.51516 .12112 L
F
0 1 .941 r
.48439 .12106 m
.47942 .10868 L
.4948 .06134 L
.49994 .08204 L
F
0 .957 1 r
.47942 .10868 m
.48439 .12106 L
.49994 .08204 L
.4948 .06134 L
F
0 .4 1 r
.48439 .12106 m
.49911 .15033 L
.51516 .12112 L
.49994 .08204 L
F
.528 0 1 r
.49911 .15033 m
.52292 .18503 L
.53977 .16121 L
.51516 .12112 L
F
1 0 .29 r
.52292 .18503 m
.55479 .21846 L
.57271 .19703 L
.53977 .16121 L
F
.968 1 0 r
.55479 .21846 m
.59332 .24707 L
.61254 .22604 L
.57271 .19703 L
F
0 1 .407 r
.59332 .24707 m
.63682 .26882 L
.65752 .24668 L
.61254 .22604 L
F
0 .232 1 r
.63682 .26882 m
.68341 .28258 L
.70568 .258 L
.65752 .24668 L
F
1 0 .934 r
.68341 .28258 m
.73103 .28796 L
.75491 .25955 L
.70568 .258 L
F
1 .263 0 r
.73103 .28796 m
.77761 .28521 L
.80306 .25147 L
.75491 .25955 L
F
.671 1 0 r
.77761 .28521 m
.82112 .27528 L
.84804 .23445 L
.80306 .25147 L
F
0 1 .241 r
.82112 .27528 m
.85965 .25987 L
.88787 .20986 L
.84804 .23445 L
F
0 1 .982 r
.85965 .25987 m
.89152 .24153 L
.92081 .17995 L
.88787 .20986 L
F
0 .462 1 r
.89152 .24153 m
.91533 .22369 L
.94543 .14844 L
.92081 .17995 L
F
0 .099 1 r
.91533 .22369 m
.93004 .21046 L
.96064 .12193 L
.94543 .14844 L
F
.07 0 1 r
.93004 .21046 m
.93502 .20552 L
.96578 .11085 L
.96064 .12193 L
F
.34 0 1 r
.96578 .11085 m
.96064 .12193 L
.97099 .06134 L
.97619 .01184 L
F
.107 0 1 r
.96064 .12193 m
.94543 .14844 L
.95561 .10868 L
.97099 .06134 L
F
0 .332 1 r
.94543 .14844 m
.92081 .17995 L
.93072 .15179 L
.95561 .10868 L
F
0 .967 1 r
.92081 .17995 m
.88787 .20986 L
.89741 .18878 L
.93072 .15179 L
F
0 1 .217 r
.88787 .20986 m
.84804 .23445 L
.85714 .21804 L
.89741 .18878 L
F
.767 1 0 r
.84804 .23445 m
.80306 .25147 L
.81167 .23828 L
.85714 .21804 L
F
1 .101 0 r
.80306 .25147 m
.75491 .25955 L
.76298 .24863 L
.81167 .23828 L
F
.847 0 1 r
.75491 .25955 m
.70568 .258 L
.71321 .24863 L
.76298 .24863 L
F
0 .498 1 r
.70568 .258 m
.65752 .24668 L
.66452 .23828 L
.71321 .24863 L
F
0 1 .109 r
.65752 .24668 m
.61254 .22604 L
.61905 .21804 L
.66452 .23828 L
F
1 .72 0 r
.61254 .22604 m
.57271 .19703 L
.57878 .18878 L
.61905 .21804 L
F
1 0 .589 r
.57271 .19703 m
.53977 .16121 L
.54547 .15179 L
.57878 .18878 L
F
.278 0 1 r
.53977 .16121 m
.51516 .12112 L
.52058 .10868 L
.54547 .15179 L
F
0 .557 1 r
.51516 .12112 m
.49994 .08204 L
.5052 .06134 L
.52058 .10868 L
F
0 .979 1 r
.49994 .08204 m
.4948 .06134 L
.5 .01184 L
.5052 .06134 L
F
0 .86 1 r
.4948 .06134 m
.49994 .08204 L
.5052 .06134 L
.5 .01184 L
F
0 .305 1 r
.49994 .08204 m
.51516 .12112 L
.52058 .10868 L
.5052 .06134 L
F
.638 0 1 r
.51516 .12112 m
.53977 .16121 L
.54547 .15179 L
.52058 .10868 L
F
1 0 .161 r
.53977 .16121 m
.57271 .19703 L
.57878 .18878 L
.54547 .15179 L
F
.817 1 0 r
.57271 .19703 m
.61254 .22604 L
.61905 .21804 L
.57878 .18878 L
F
0 1 .579 r
.61254 .22604 m
.65752 .24668 L
.66452 .23828 L
.61905 .21804 L
F
0 .04 1 r
.65752 .24668 m
.70568 .258 L
.71321 .24863 L
.66452 .23828 L
F
1 0 .723 r
.70568 .258 m
.75491 .25955 L
.76298 .24863 L
.71321 .24863 L
F
1 .492 0 r
.75491 .25955 m
.80306 .25147 L
.81167 .23828 L
.76298 .24863 L
F
.425 1 0 r
.80306 .25147 m
.84804 .23445 L
.85714 .21804 L
.81167 .23828 L
F
0 1 .503 r
.84804 .23445 m
.88787 .20986 L
.89741 .18878 L
.85714 .21804 L
F
0 .743 1 r
.88787 .20986 m
.92081 .17995 L
.93072 .15179 L
.89741 .18878 L
F
0 .176 1 r
.92081 .17995 m
.94543 .14844 L
.95561 .10868 L
.93072 .15179 L
F
.19 0 1 r
.94543 .14844 m
.96064 .12193 L
.97099 .06134 L
.95561 .10868 L
F
.342 0 1 r
.96064 .12193 m
.96578 .11085 L
.97619 .01184 L
.97099 .06134 L
F
.34 0 1 r
.96578 .11085 m
.96064 .12193 L
.97099 .06134 L
.97619 .01184 L
F
.107 0 1 r
.96064 .12193 m
.94543 .14844 L
.95561 .10868 L
.97099 .06134 L
F
0 .332 1 r
.94543 .14844 m
.92081 .17995 L
.93072 .15179 L
.95561 .10868 L
F
0 .967 1 r
.92081 .17995 m
.88787 .20986 L
.89741 .18878 L
.93072 .15179 L
F
0 1 .217 r
.88787 .20986 m
.84804 .23445 L
.85714 .21804 L
.89741 .18878 L
F
.767 1 0 r
.84804 .23445 m
.80306 .25147 L
.81167 .23828 L
.85714 .21804 L
F
1 .101 0 r
.80306 .25147 m
.75491 .25955 L
.76298 .24863 L
.81167 .23828 L
F
.847 0 1 r
.75491 .25955 m
.70568 .258 L
.71321 .24863 L
.76298 .24863 L
F
0 .498 1 r
.70568 .258 m
.65752 .24668 L
.66452 .23828 L
.71321 .24863 L
F
0 1 .109 r
.65752 .24668 m
.61254 .22604 L
.61905 .21804 L
.66452 .23828 L
F
1 .72 0 r
.61254 .22604 m
.57271 .19703 L
.57878 .18878 L
.61905 .21804 L
F
1 0 .589 r
.57271 .19703 m
.53977 .16121 L
.54547 .15179 L
.57878 .18878 L
F
.278 0 1 r
.53977 .16121 m
.51516 .12112 L
.52058 .10868 L
.54547 .15179 L
F
0 .557 1 r
.51516 .12112 m
.49994 .08204 L
.5052 .06134 L
.52058 .10868 L
F
0 .979 1 r
.49994 .08204 m
.4948 .06134 L
.5 .01184 L
.5052 .06134 L
F
0 .86 1 r
.4948 .06134 m
.49994 .08204 L
.5052 .06134 L
.5 .01184 L
F
0 .305 1 r
.49994 .08204 m
.51516 .12112 L
.52058 .10868 L
.5052 .06134 L
F
.638 0 1 r
.51516 .12112 m
.53977 .16121 L
.54547 .15179 L
.52058 .10868 L
F
1 0 .161 r
.53977 .16121 m
.57271 .19703 L
.57878 .18878 L
.54547 .15179 L
F
.817 1 0 r
.57271 .19703 m
.61254 .22604 L
.61905 .21804 L
.57878 .18878 L
F
0 1 .579 r
.61254 .22604 m
.65752 .24668 L
.66452 .23828 L
.61905 .21804 L
F
0 .04 1 r
.65752 .24668 m
.70568 .258 L
.71321 .24863 L
.66452 .23828 L
F
1 0 .723 r
.70568 .258 m
.75491 .25955 L
.76298 .24863 L
.71321 .24863 L
F
1 .492 0 r
.75491 .25955 m
.80306 .25147 L
.81167 .23828 L
.76298 .24863 L
F
.425 1 0 r
.80306 .25147 m
.84804 .23445 L
.85714 .21804 L
.81167 .23828 L
F
0 1 .503 r
.84804 .23445 m
.88787 .20986 L
.89741 .18878 L
.85714 .21804 L
F
0 .743 1 r
.88787 .20986 m
.92081 .17995 L
.93072 .15179 L
.89741 .18878 L
F
0 .176 1 r
.92081 .17995 m
.94543 .14844 L
.95561 .10868 L
.93072 .15179 L
F
.19 0 1 r
.94543 .14844 m
.96064 .12193 L
.97099 .06134 L
.95561 .10868 L
F
.342 0 1 r
.96064 .12193 m
.96578 .11085 L
.97619 .01184 L
.97099 .06134 L
F
.355 0 1 r
.97619 .01184 m
.97099 .06134 L
.96064 .12193 L
.96578 .11085 L
F
.128 0 1 r
.97099 .06134 m
.95561 .10868 L
.94543 .14844 L
.96064 .12193 L
F
0 .307 1 r
.95561 .10868 m
.93072 .15179 L
.92081 .17995 L
.94543 .14844 L
F
0 .939 1 r
.93072 .15179 m
.89741 .18878 L
.88787 .20986 L
.92081 .17995 L
F
0 1 .246 r
.89741 .18878 m
.85714 .21804 L
.84804 .23445 L
.88787 .20986 L
F
.738 1 0 r
.85714 .21804 m
.81167 .23828 L
.80306 .25147 L
.84804 .23445 L
F
1 .13 0 r
.81167 .23828 m
.76298 .24863 L
.75491 .25955 L
.80306 .25147 L
F
.875 0 1 r
.76298 .24863 m
.71321 .24863 L
.70568 .258 L
.75491 .25955 L
F
0 .471 1 r
.71321 .24863 m
.66452 .23828 L
.65752 .24668 L
.70568 .258 L
F
0 1 .133 r
.66452 .23828 m
.61905 .21804 L
.61254 .22604 L
.65752 .24668 L
F
1 .744 0 r
.61905 .21804 m
.57878 .18878 L
.57271 .19703 L
.61254 .22604 L
F
1 0 .567 r
.57878 .18878 m
.54547 .15179 L
.53977 .16121 L
.57271 .19703 L
F
.3 0 1 r
.54547 .15179 m
.52058 .10868 L
.51516 .12112 L
.53977 .16121 L
F
0 .533 1 r
.52058 .10868 m
.5052 .06134 L
.49994 .08204 L
.51516 .12112 L
F
0 .952 1 r
.5052 .06134 m
.5 .01184 L
.4948 .06134 L
.49994 .08204 L
F
0 .881 1 r
.5 .01184 m
.5052 .06134 L
.49994 .08204 L
.4948 .06134 L
F
0 .307 1 r
.5052 .06134 m
.52058 .10868 L
.51516 .12112 L
.49994 .08204 L
F
.645 0 1 r
.52058 .10868 m
.54547 .15179 L
.53977 .16121 L
.51516 .12112 L
F
1 0 .148 r
.54547 .15179 m
.57878 .18878 L
.57271 .19703 L
.53977 .16121 L
F
.799 1 0 r
.57878 .18878 m
.61905 .21804 L
.61254 .22604 L
.57271 .19703 L
F
0 1 .601 r
.61905 .21804 m
.66452 .23828 L
.65752 .24668 L
.61254 .22604 L
F
0 .013 1 r
.66452 .23828 m
.71321 .24863 L
.70568 .258 L
.65752 .24668 L
F
1 0 .692 r
.71321 .24863 m
.76298 .24863 L
.75491 .25955 L
.70568 .258 L
F
1 .526 0 r
.76298 .24863 m
.81167 .23828 L
.80306 .25147 L
.75491 .25955 L
F
.388 1 0 r
.81167 .23828 m
.85714 .21804 L
.84804 .23445 L
.80306 .25147 L
F
0 1 .544 r
.85714 .21804 m
.89741 .18878 L
.88787 .20986 L
.84804 .23445 L
F
0 .699 1 r
.89741 .18878 m
.93072 .15179 L
.92081 .17995 L
.88787 .20986 L
F
0 .128 1 r
.93072 .15179 m
.95561 .10868 L
.94543 .14844 L
.92081 .17995 L
F
.242 0 1 r
.95561 .10868 m
.97099 .06134 L
.96064 .12193 L
.94543 .14844 L
F
.397 0 1 r
.97099 .06134 m
.97619 .01184 L
.96578 .11085 L
.96064 .12193 L
F
.355 0 1 r
.97619 .01184 m
.97099 .06134 L
.96064 .12193 L
.96578 .11085 L
F
.128 0 1 r
.97099 .06134 m
.95561 .10868 L
.94543 .14844 L
.96064 .12193 L
F
0 .307 1 r
.95561 .10868 m
.93072 .15179 L
.92081 .17995 L
.94543 .14844 L
F
0 .939 1 r
.93072 .15179 m
.89741 .18878 L
.88787 .20986 L
.92081 .17995 L
F
0 1 .246 r
.89741 .18878 m
.85714 .21804 L
.84804 .23445 L
.88787 .20986 L
F
.738 1 0 r
.85714 .21804 m
.81167 .23828 L
.80306 .25147 L
.84804 .23445 L
F
1 .13 0 r
.81167 .23828 m
.76298 .24863 L
.75491 .25955 L
.80306 .25147 L
F
.875 0 1 r
.76298 .24863 m
.71321 .24863 L
.70568 .258 L
.75491 .25955 L
F
0 .471 1 r
.71321 .24863 m
.66452 .23828 L
.65752 .24668 L
.70568 .258 L
F
0 1 .133 r
.66452 .23828 m
.61905 .21804 L
.61254 .22604 L
.65752 .24668 L
F
1 .744 0 r
.61905 .21804 m
.57878 .18878 L
.57271 .19703 L
.61254 .22604 L
F
1 0 .567 r
.57878 .18878 m
.54547 .15179 L
.53977 .16121 L
.57271 .19703 L
F
.3 0 1 r
.54547 .15179 m
.52058 .10868 L
.51516 .12112 L
.53977 .16121 L
F
0 .533 1 r
.52058 .10868 m
.5052 .06134 L
.49994 .08204 L
.51516 .12112 L
F
0 .952 1 r
.5052 .06134 m
.5 .01184 L
.4948 .06134 L
.49994 .08204 L
F
0 .881 1 r
.5 .01184 m
.5052 .06134 L
.49994 .08204 L
.4948 .06134 L
F
0 .307 1 r
.5052 .06134 m
.52058 .10868 L
.51516 .12112 L
.49994 .08204 L
F
.645 0 1 r
.52058 .10868 m
.54547 .15179 L
.53977 .16121 L
.51516 .12112 L
F
1 0 .148 r
.54547 .15179 m
.57878 .18878 L
.57271 .19703 L
.53977 .16121 L
F
.799 1 0 r
.57878 .18878 m
.61905 .21804 L
.61254 .22604 L
.57271 .19703 L
F
0 1 .601 r
.61905 .21804 m
.66452 .23828 L
.65752 .24668 L
.61254 .22604 L
F
0 .013 1 r
.66452 .23828 m
.71321 .24863 L
.70568 .258 L
.65752 .24668 L
F
1 0 .692 r
.71321 .24863 m
.76298 .24863 L
.75491 .25955 L
.70568 .258 L
F
1 .526 0 r
.76298 .24863 m
.81167 .23828 L
.80306 .25147 L
.75491 .25955 L
F
.388 1 0 r
.81167 .23828 m
.85714 .21804 L
.84804 .23445 L
.80306 .25147 L
F
0 1 .544 r
.85714 .21804 m
.89741 .18878 L
.88787 .20986 L
.84804 .23445 L
F
0 .699 1 r
.89741 .18878 m
.93072 .15179 L
.92081 .17995 L
.88787 .20986 L
F
0 .128 1 r
.93072 .15179 m
.95561 .10868 L
.94543 .14844 L
.92081 .17995 L
F
.242 0 1 r
.95561 .10868 m
.97099 .06134 L
.96064 .12193 L
.94543 .14844 L
F
.397 0 1 r
.97099 .06134 m
.97619 .01184 L
.96578 .11085 L
.96064 .12193 L
F
.156 0 1 r
.96578 .11085 m
.96064 .12193 L
.93004 .21046 L
.93502 .20552 L
F
0 .08 1 r
.96064 .12193 m
.94543 .14844 L
.91533 .22369 L
.93004 .21046 L
F
0 .512 1 r
.94543 .14844 m
.92081 .17995 L
.89152 .24153 L
.91533 .22369 L
F
0 1 .864 r
.92081 .17995 m
.88787 .20986 L
.85965 .25987 L
.89152 .24153 L
F
0 1 .059 r
.88787 .20986 m
.84804 .23445 L
.82112 .27528 L
.85965 .25987 L
F
.913 1 0 r
.84804 .23445 m
.80306 .25147 L
.77761 .28521 L
.82112 .27528 L
F
1 0 .032 r
.80306 .25147 m
.75491 .25955 L
.73103 .28796 L
.77761 .28521 L
F
.727 0 1 r
.75491 .25955 m
.70568 .258 L
.68341 .28258 L
.73103 .28796 L
F
0 .605 1 r
.70568 .258 m
.65752 .24668 L
.63682 .26882 L
.68341 .28258 L
F
0 1 .015 r
.65752 .24668 m
.61254 .22604 L
.59332 .24707 L
.63682 .26882 L
F
1 .64 0 r
.61254 .22604 m
.57271 .19703 L
.55479 .21846 L
.59332 .24707 L
F
1 0 .656 r
.57271 .19703 m
.53977 .16121 L
.52292 .18503 L
.55479 .21846 L
F
.224 0 1 r
.53977 .16121 m
.51516 .12112 L
.49911 .15033 L
.52292 .18503 L
F
0 .6 1 r
.51516 .12112 m
.49994 .08204 L
.48439 .12106 L
.49911 .15033 L
F
0 1 .992 r
.49994 .08204 m
.4948 .06134 L
.47942 .10868 L
.48439 .12106 L
F
0 .935 1 r
.4948 .06134 m
.49994 .08204 L
.48439 .12106 L
.47942 .10868 L
F
0 .384 1 r
.49994 .08204 m
.51516 .12112 L
.49911 .15033 L
.48439 .12106 L
F
.556 0 1 r
.51516 .12112 m
.53977 .16121 L
.52292 .18503 L
.49911 .15033 L
F
1 0 .248 r
.53977 .16121 m
.57271 .19703 L
.55479 .21846 L
.52292 .18503 L
F
.913 1 0 r
.57271 .19703 m
.61254 .22604 L
.59332 .24707 L
.55479 .21846 L
F
0 1 .474 r
.61254 .22604 m
.65752 .24668 L
.63682 .26882 L
.59332 .24707 L
F
0 .153 1 r
.65752 .24668 m
.70568 .258 L
.68341 .28258 L
.63682 .26882 L
F
1 0 .845 r
.70568 .258 m
.75491 .25955 L
.73103 .28796 L
.68341 .28258 L
F
1 .362 0 r
.75491 .25955 m
.80306 .25147 L
.77761 .28521 L
.73103 .28796 L
F
.563 1 0 r
.80306 .25147 m
.84804 .23445 L
.82112 .27528 L
.77761 .28521 L
F
0 1 .358 r
.84804 .23445 m
.88787 .20986 L
.85965 .25987 L
.82112 .27528 L
F
0 .893 1 r
.88787 .20986 m
.92081 .17995 L
.89152 .24153 L
.85965 .25987 L
F
0 .332 1 r
.92081 .17995 m
.94543 .14844 L
.91533 .22369 L
.89152 .24153 L
F
.032 0 1 r
.94543 .14844 m
.96064 .12193 L
.93004 .21046 L
.91533 .22369 L
F
.194 0 1 r
.96064 .12193 m
.96578 .11085 L
.93502 .20552 L
.93004 .21046 L
F
.156 0 1 r
.96578 .11085 m
.96064 .12193 L
.93004 .21046 L
.93502 .20552 L
F
0 .08 1 r
.96064 .12193 m
.94543 .14844 L
.91533 .22369 L
.93004 .21046 L
F
0 .512 1 r
.94543 .14844 m
.92081 .17995 L
.89152 .24153 L
.91533 .22369 L
F
0 1 .864 r
.92081 .17995 m
.88787 .20986 L
.85965 .25987 L
.89152 .24153 L
F
0 1 .059 r
.88787 .20986 m
.84804 .23445 L
.82112 .27528 L
.85965 .25987 L
F
.913 1 0 r
.84804 .23445 m
.80306 .25147 L
.77761 .28521 L
.82112 .27528 L
F
1 0 .032 r
.80306 .25147 m
.75491 .25955 L
.73103 .28796 L
.77761 .28521 L
F
.727 0 1 r
.75491 .25955 m
.70568 .258 L
.68341 .28258 L
.73103 .28796 L
F
0 .605 1 r
.70568 .258 m
.65752 .24668 L
.63682 .26882 L
.68341 .28258 L
F
0 1 .015 r
.65752 .24668 m
.61254 .22604 L
.59332 .24707 L
.63682 .26882 L
F
1 .64 0 r
.61254 .22604 m
.57271 .19703 L
.55479 .21846 L
.59332 .24707 L
F
1 0 .656 r
.57271 .19703 m
.53977 .16121 L
.52292 .18503 L
.55479 .21846 L
F
.224 0 1 r
.53977 .16121 m
.51516 .12112 L
.49911 .15033 L
.52292 .18503 L
F
0 .6 1 r
.51516 .12112 m
.49994 .08204 L
.48439 .12106 L
.49911 .15033 L
F
0 1 .992 r
.49994 .08204 m
.4948 .06134 L
.47942 .10868 L
.48439 .12106 L
F
0 .935 1 r
.4948 .06134 m
.49994 .08204 L
.48439 .12106 L
.47942 .10868 L
F
0 .384 1 r
.49994 .08204 m
.51516 .12112 L
.49911 .15033 L
.48439 .12106 L
F
.556 0 1 r
.51516 .12112 m
.53977 .16121 L
.52292 .18503 L
.49911 .15033 L
F
1 0 .248 r
.53977 .16121 m
.57271 .19703 L
.55479 .21846 L
.52292 .18503 L
F
.913 1 0 r
.57271 .19703 m
.61254 .22604 L
.59332 .24707 L
.55479 .21846 L
F
0 1 .474 r
.61254 .22604 m
.65752 .24668 L
.63682 .26882 L
.59332 .24707 L
F
0 .153 1 r
.65752 .24668 m
.70568 .258 L
.68341 .28258 L
.63682 .26882 L
F
1 0 .845 r
.70568 .258 m
.75491 .25955 L
.73103 .28796 L
.68341 .28258 L
F
1 .362 0 r
.75491 .25955 m
.80306 .25147 L
.77761 .28521 L
.73103 .28796 L
F
.563 1 0 r
.80306 .25147 m
.84804 .23445 L
.82112 .27528 L
.77761 .28521 L
F
0 1 .358 r
.84804 .23445 m
.88787 .20986 L
.85965 .25987 L
.82112 .27528 L
F
0 .893 1 r
.88787 .20986 m
.92081 .17995 L
.89152 .24153 L
.85965 .25987 L
F
0 .332 1 r
.92081 .17995 m
.94543 .14844 L
.91533 .22369 L
.89152 .24153 L
F
.032 0 1 r
.94543 .14844 m
.96064 .12193 L
.93004 .21046 L
.91533 .22369 L
F
.194 0 1 r
.96064 .12193 m
.96578 .11085 L
.93502 .20552 L
.93004 .21046 L
F
0 .273 1 r
.93502 .20552 m
.93004 .21046 L
.88054 .29416 L
.88525 .29174 L
F
0 .505 1 r
.93004 .21046 m
.91533 .22369 L
.86663 .30076 L
.88054 .29416 L
F
0 .931 1 r
.91533 .22369 m
.89152 .24153 L
.84412 .30976 L
.86663 .30076 L
F
0 1 .457 r
.89152 .24153 m
.85965 .25987 L
.81399 .31882 L
.84412 .30976 L
F
.332 1 0 r
.85965 .25987 m
.82112 .27528 L
.77757 .32559 L
.81399 .31882 L
F
1 .717 0 r
.82112 .27528 m
.77761 .28521 L
.73644 .32806 L
.77757 .32559 L
F
1 0 .377 r
.77761 .28521 m
.73103 .28796 L
.6924 .32474 L
.73644 .32806 L
F
.409 0 1 r
.73103 .28796 m
.68341 .28258 L
.64738 .31477 L
.6924 .32474 L
F
0 .893 1 r
.68341 .28258 m
.63682 .26882 L
.60334 .29791 L
.64738 .31477 L
F
.243 1 0 r
.63682 .26882 m
.59332 .24707 L
.56221 .27463 L
.60334 .29791 L
F
1 .414 0 r
.59332 .24707 m
.55479 .21846 L
.52578 .24619 L
.56221 .27463 L
F
1 0 .851 r
.55479 .21846 m
.52292 .18503 L
.49566 .21487 L
.52578 .24619 L
F
.056 0 1 r
.52292 .18503 m
.49911 .15033 L
.47315 .18446 L
.49566 .21487 L
F
0 .747 1 r
.49911 .15033 m
.48439 .12106 L
.45923 .16095 L
.47315 .18446 L
F
0 1 .854 r
.48439 .12106 m
.47942 .10868 L
.45453 .15179 L
.45923 .16095 L
F
0 1 .928 r
.47942 .10868 m
.48439 .12106 L
.45923 .16095 L
.45453 .15179 L
F
0 .536 1 r
.48439 .12106 m
.49911 .15033 L
.47315 .18446 L
.45923 .16095 L
F
.378 0 1 r
.49911 .15033 m
.52292 .18503 L
.49566 .21487 L
.47315 .18446 L
F
1 0 .457 r
.52292 .18503 m
.55479 .21846 L
.52578 .24619 L
.49566 .21487 L
F
1 .848 0 r
.55479 .21846 m
.59332 .24707 L
.56221 .27463 L
.52578 .24619 L
F
0 1 .204 r
.59332 .24707 m
.63682 .26882 L
.60334 .29791 L
.56221 .27463 L
F
0 .454 1 r
.63682 .26882 m
.68341 .28258 L
.64738 .31477 L
.60334 .29791 L
F
.826 0 1 r
.68341 .28258 m
.73103 .28796 L
.6924 .32474 L
.64738 .31477 L
F
1 .007 0 r
.73103 .28796 m
.77761 .28521 L
.73644 .32806 L
.6924 .32474 L
F
.941 1 0 r
.77761 .28521 m
.82112 .27528 L
.77757 .32559 L
.73644 .32806 L
F
.04 1 0 r
.82112 .27528 m
.85965 .25987 L
.81399 .31882 L
.77757 .32559 L
F
0 1 .692 r
.85965 .25987 m
.89152 .24153 L
.84412 .30976 L
.81399 .31882 L
F
0 .758 1 r
.89152 .24153 m
.91533 .22369 L
.86663 .30076 L
.84412 .30976 L
F
0 .399 1 r
.91533 .22369 m
.93004 .21046 L
.88054 .29416 L
.86663 .30076 L
F
0 .237 1 r
.93004 .21046 m
.93502 .20552 L
.88525 .29174 L
.88054 .29416 L
F
0 .273 1 r
.93502 .20552 m
.93004 .21046 L
.88054 .29416 L
.88525 .29174 L
F
0 .505 1 r
.93004 .21046 m
.91533 .22369 L
.86663 .30076 L
.88054 .29416 L
F
0 .931 1 r
.91533 .22369 m
.89152 .24153 L
.84412 .30976 L
.86663 .30076 L
F
0 1 .457 r
.89152 .24153 m
.85965 .25987 L
.81399 .31882 L
.84412 .30976 L
F
.332 1 0 r
.85965 .25987 m
.82112 .27528 L
.77757 .32559 L
.81399 .31882 L
F
1 .717 0 r
.82112 .27528 m
.77761 .28521 L
.73644 .32806 L
.77757 .32559 L
F
1 0 .377 r
.77761 .28521 m
.73103 .28796 L
.6924 .32474 L
.73644 .32806 L
F
.409 0 1 r
.73103 .28796 m
.68341 .28258 L
.64738 .31477 L
.6924 .32474 L
F
0 .893 1 r
.68341 .28258 m
.63682 .26882 L
.60334 .29791 L
.64738 .31477 L
F
.243 1 0 r
.63682 .26882 m
.59332 .24707 L
.56221 .27463 L
.60334 .29791 L
F
1 .414 0 r
.59332 .24707 m
.55479 .21846 L
.52578 .24619 L
.56221 .27463 L
F
1 0 .851 r
.55479 .21846 m
.52292 .18503 L
.49566 .21487 L
.52578 .24619 L
F
.056 0 1 r
.52292 .18503 m
.49911 .15033 L
.47315 .18446 L
.49566 .21487 L
F
0 .747 1 r
.49911 .15033 m
.48439 .12106 L
.45923 .16095 L
.47315 .18446 L
F
0 1 .854 r
.48439 .12106 m
.47942 .10868 L
.45453 .15179 L
.45923 .16095 L
F
0 1 .928 r
.47942 .10868 m
.48439 .12106 L
.45923 .16095 L
.45453 .15179 L
F
0 .536 1 r
.48439 .12106 m
.49911 .15033 L
.47315 .18446 L
.45923 .16095 L
F
.378 0 1 r
.49911 .15033 m
.52292 .18503 L
.49566 .21487 L
.47315 .18446 L
F
1 0 .457 r
.52292 .18503 m
.55479 .21846 L
.52578 .24619 L
.49566 .21487 L
F
1 .848 0 r
.55479 .21846 m
.59332 .24707 L
.56221 .27463 L
.52578 .24619 L
F
0 1 .204 r
.59332 .24707 m
.63682 .26882 L
.60334 .29791 L
.56221 .27463 L
F
0 .454 1 r
.63682 .26882 m
.68341 .28258 L
.64738 .31477 L
.60334 .29791 L
F
.826 0 1 r
.68341 .28258 m
.73103 .28796 L
.6924 .32474 L
.64738 .31477 L
F
1 .007 0 r
.73103 .28796 m
.77761 .28521 L
.73644 .32806 L
.6924 .32474 L
F
.941 1 0 r
.77761 .28521 m
.82112 .27528 L
.77757 .32559 L
.73644 .32806 L
F
.04 1 0 r
.82112 .27528 m
.85965 .25987 L
.81399 .31882 L
.77757 .32559 L
F
0 1 .692 r
.85965 .25987 m
.89152 .24153 L
.84412 .30976 L
.81399 .31882 L
F
0 .758 1 r
.89152 .24153 m
.91533 .22369 L
.86663 .30076 L
.84412 .30976 L
F
0 .399 1 r
.91533 .22369 m
.93004 .21046 L
.88054 .29416 L
.86663 .30076 L
F
0 .237 1 r
.93004 .21046 m
.93502 .20552 L
.88525 .29174 L
.88054 .29416 L
F
0 .929 1 r
.88525 .29174 m
.88054 .29416 L
.81429 .36668 L
.81863 .36572 L
F
0 1 .846 r
.88054 .29416 m
.86663 .30076 L
.80145 .36919 L
.81429 .36668 L
F
0 1 .434 r
.86663 .30076 m
.84412 .30976 L
.78068 .37226 L
.80145 .36919 L
F
.159 1 0 r
.84412 .30976 m
.81399 .31882 L
.75289 .37447 L
.78068 .37226 L
F
.922 1 0 r
.81399 .31882 m
.77757 .32559 L
.71928 .37428 L
.75289 .37447 L
F
1 .158 0 r
.77757 .32559 m
.73644 .32806 L
.68133 .3703 L
.71928 .37428 L
F
1 0 .901 r
.73644 .32806 m
.6924 .32474 L
.6407 .36145 L
.68133 .3703 L
F
0 .074 1 r
.6924 .32474 m
.64738 .31477 L
.59916 .34712 L
.6407 .36145 L
F
0 1 .669 r
.64738 .31477 m
.60334 .29791 L
.55852 .32723 L
.59916 .34712 L
F
.633 1 0 r
.60334 .29791 m
.56221 .27463 L
.52057 .30236 L
.55852 .32723 L
F
1 .071 0 r
.56221 .27463 m
.52578 .24619 L
.48697 .27385 L
.52057 .30236 L
F
.852 0 1 r
.52578 .24619 m
.49566 .21487 L
.45917 .24404 L
.48697 .27385 L
F
0 .199 1 r
.49566 .21487 m
.47315 .18446 L
.4384 .21653 L
.45917 .24404 L
F
0 .971 1 r
.47315 .18446 m
.45923 .16095 L
.42556 .19634 L
.4384 .21653 L
F
0 1 .646 r
.45923 .16095 m
.45453 .15179 L
.42122 .18878 L
.42556 .19634 L
F
0 1 .718 r
.45453 .15179 m
.45923 .16095 L
.42556 .19634 L
.42122 .18878 L
F
0 .766 1 r
.45923 .16095 m
.47315 .18446 L
.4384 .21653 L
.42556 .19634 L
F
.11 0 1 r
.47315 .18446 m
.49566 .21487 L
.45917 .24404 L
.4384 .21653 L
F
1 0 .77 r
.49566 .21487 m
.52578 .24619 L
.48697 .27385 L
.45917 .24404 L
F
1 .487 0 r
.52578 .24619 m
.56221 .27463 L
.52057 .30236 L
.48697 .27385 L
F
.205 1 0 r
.56221 .27463 m
.60334 .29791 L
.55852 .32723 L
.52057 .30236 L
F
0 .909 1 r
.60334 .29791 m
.64738 .31477 L
.59916 .34712 L
.55852 .32723 L
F
.327 0 1 r
.64738 .31477 m
.6924 .32474 L
.6407 .36145 L
.59916 .34712 L
F
1 0 .532 r
.6924 .32474 m
.73644 .32806 L
.68133 .3703 L
.6407 .36145 L
F
1 .485 0 r
.73644 .32806 m
.77757 .32559 L
.71928 .37428 L
.68133 .3703 L
F
.643 1 0 r
.77757 .32559 m
.81399 .31882 L
.75289 .37447 L
.71928 .37428 L
F
0 1 .065 r
.81399 .31882 m
.84412 .30976 L
.78068 .37226 L
.75289 .37447 L
F
0 1 .598 r
.84412 .30976 m
.86663 .30076 L
.80145 .36919 L
.78068 .37226 L
F
0 1 .947 r
.86663 .30076 m
.88054 .29416 L
.81429 .36668 L
.80145 .36919 L
F
0 .895 1 r
.88054 .29416 m
.88525 .29174 L
.81863 .36572 L
.81429 .36668 L
F
0 .929 1 r
.88525 .29174 m
.88054 .29416 L
.81429 .36668 L
.81863 .36572 L
F
0 1 .846 r
.88054 .29416 m
.86663 .30076 L
.80145 .36919 L
.81429 .36668 L
F
0 1 .434 r
.86663 .30076 m
.84412 .30976 L
.78068 .37226 L
.80145 .36919 L
F
.159 1 0 r
.84412 .30976 m
.81399 .31882 L
.75289 .37447 L
.78068 .37226 L
F
.922 1 0 r
.81399 .31882 m
.77757 .32559 L
.71928 .37428 L
.75289 .37447 L
F
1 .158 0 r
.77757 .32559 m
.73644 .32806 L
.68133 .3703 L
.71928 .37428 L
F
1 0 .901 r
.73644 .32806 m
.6924 .32474 L
.6407 .36145 L
.68133 .3703 L
F
0 .074 1 r
.6924 .32474 m
.64738 .31477 L
.59916 .34712 L
.6407 .36145 L
F
0 1 .669 r
.64738 .31477 m
.60334 .29791 L
.55852 .32723 L
.59916 .34712 L
F
.633 1 0 r
.60334 .29791 m
.56221 .27463 L
.52057 .30236 L
.55852 .32723 L
F
1 .071 0 r
.56221 .27463 m
.52578 .24619 L
.48697 .27385 L
.52057 .30236 L
F
.852 0 1 r
.52578 .24619 m
.49566 .21487 L
.45917 .24404 L
.48697 .27385 L
F
0 .199 1 r
.49566 .21487 m
.47315 .18446 L
.4384 .21653 L
.45917 .24404 L
F
0 .971 1 r
.47315 .18446 m
.45923 .16095 L
.42556 .19634 L
.4384 .21653 L
F
0 1 .646 r
.45923 .16095 m
.45453 .15179 L
.42122 .18878 L
.42556 .19634 L
F
0 1 .718 r
.45453 .15179 m
.45923 .16095 L
.42556 .19634 L
.42122 .18878 L
F
0 .766 1 r
.45923 .16095 m
.47315 .18446 L
.4384 .21653 L
.42556 .19634 L
F
.11 0 1 r
.47315 .18446 m
.49566 .21487 L
.45917 .24404 L
.4384 .21653 L
F
1 0 .77 r
.49566 .21487 m
.52578 .24619 L
.48697 .27385 L
.45917 .24404 L
F
1 .487 0 r
.52578 .24619 m
.56221 .27463 L
.52057 .30236 L
.48697 .27385 L
F
.205 1 0 r
.56221 .27463 m
.60334 .29791 L
.55852 .32723 L
.52057 .30236 L
F
0 .909 1 r
.60334 .29791 m
.64738 .31477 L
.59916 .34712 L
.55852 .32723 L
F
.327 0 1 r
.64738 .31477 m
.6924 .32474 L
.6407 .36145 L
.59916 .34712 L
F
1 0 .532 r
.6924 .32474 m
.73644 .32806 L
.68133 .3703 L
.6407 .36145 L
F
1 .485 0 r
.73644 .32806 m
.77757 .32559 L
.71928 .37428 L
.68133 .3703 L
F
.643 1 0 r
.77757 .32559 m
.81399 .31882 L
.75289 .37447 L
.71928 .37428 L
F
0 1 .065 r
.81399 .31882 m
.84412 .30976 L
.78068 .37226 L
.75289 .37447 L
F
0 1 .598 r
.84412 .30976 m
.86663 .30076 L
.80145 .36919 L
.78068 .37226 L
F
0 1 .947 r
.86663 .30076 m
.88054 .29416 L
.81429 .36668 L
.80145 .36919 L
F
0 .895 1 r
.88054 .29416 m
.88525 .29174 L
.81863 .36572 L
.81429 .36668 L
F
0 1 .196 r
.81863 .36572 m
.81429 .36668 L
.73419 .42421 L
.7381 .42423 L
F
.018 1 0 r
.81429 .36668 m
.80145 .36919 L
.72266 .42394 L
.73419 .42421 L
F
.412 1 0 r
.80145 .36919 m
.78068 .37226 L
.70399 .42282 L
.72266 .42394 L
F
.978 1 0 r
.78068 .37226 m
.75289 .37447 L
.67901 .41998 L
.70399 .42282 L
F
1 .293 0 r
.75289 .37447 m
.71928 .37428 L
.64881 .41445 L
.67901 .41998 L
F
1 0 .585 r
.71928 .37428 m
.68133 .3703 L
.61471 .40534 L
.64881 .41445 L
F
.405 0 1 r
.68133 .3703 m
.6407 .36145 L
.57819 .39197 L
.61471 .40534 L
F
0 .713 1 r
.6407 .36145 m
.59916 .34712 L
.54086 .37401 L
.57819 .39197 L
F
0 1 .089 r
.59916 .34712 m
.55852 .32723 L
.50434 .35159 L
.54086 .37401 L
F
1 .849 0 r
.55852 .32723 m
.52057 .30236 L
.47024 .3254 L
.50434 .35159 L
F
1 0 .382 r
.52057 .30236 m
.48697 .27385 L
.44004 .29685 L
.47024 .3254 L
F
.46 0 1 r
.48697 .27385 m
.45917 .24404 L
.41506 .26819 L
.44004 .29685 L
F
0 .536 1 r
.45917 .24404 m
.4384 .21653 L
.39639 .24272 L
.41506 .26819 L
F
0 1 .733 r
.4384 .21653 m
.42556 .19634 L
.38485 .22465 L
.39639 .24272 L
F
0 1 .372 r
.42556 .19634 m
.42122 .18878 L
.38095 .21804 L
.38485 .22465 L
F
0 1 .44 r
.42122 .18878 m
.42556 .19634 L
.38485 .22465 L
.38095 .21804 L
F
0 1 .928 r
.42556 .19634 m
.4384 .21653 L
.39639 .24272 L
.38485 .22465 L
F
0 .244 1 r
.4384 .21653 m
.45917 .24404 L
.41506 .26819 L
.39639 .24272 L
F
.818 0 1 r
.45917 .24404 m
.48697 .27385 L
.44004 .29685 L
.41506 .26819 L
F
1 .01 0 r
.48697 .27385 m
.52057 .30236 L
.47024 .3254 L
.44004 .29685 L
F
.746 1 0 r
.52057 .30236 m
.55852 .32723 L
.50434 .35159 L
.47024 .3254 L
F
0 1 .488 r
.55852 .32723 m
.59916 .34712 L
.54086 .37401 L
.50434 .35159 L
F
0 .334 1 r
.59916 .34712 m
.6407 .36145 L
.57819 .39197 L
.54086 .37401 L
F
.754 0 1 r
.6407 .36145 m
.68133 .3703 L
.61471 .40534 L
.57819 .39197 L
F
1 0 .276 r
.68133 .3703 m
.71928 .37428 L
.64881 .41445 L
.61471 .40534 L
F
1 .556 0 r
.71928 .37428 m
.75289 .37447 L
.67901 .41998 L
.64881 .41445 L
F
.768 1 0 r
.75289 .37447 m
.78068 .37226 L
.70399 .42282 L
.67901 .41998 L
F
.258 1 0 r
.78068 .37226 m
.80145 .36919 L
.72266 .42394 L
.70399 .42282 L
F
0 1 .075 r
.80145 .36919 m
.81429 .36668 L
.73419 .42421 L
.72266 .42394 L
F
0 1 .228 r
.81429 .36668 m
.81863 .36572 L
.7381 .42423 L
.73419 .42421 L
F
0 1 .196 r
.81863 .36572 m
.81429 .36668 L
.73419 .42421 L
.7381 .42423 L
F
.018 1 0 r
.81429 .36668 m
.80145 .36919 L
.72266 .42394 L
.73419 .42421 L
F
.412 1 0 r
.80145 .36919 m
.78068 .37226 L
.70399 .42282 L
.72266 .42394 L
F
.978 1 0 r
.78068 .37226 m
.75289 .37447 L
.67901 .41998 L
.70399 .42282 L
F
1 .293 0 r
.75289 .37447 m
.71928 .37428 L
.64881 .41445 L
.67901 .41998 L
F
1 0 .585 r
.71928 .37428 m
.68133 .3703 L
.61471 .40534 L
.64881 .41445 L
F
.405 0 1 r
.68133 .3703 m
.6407 .36145 L
.57819 .39197 L
.61471 .40534 L
F
0 .713 1 r
.6407 .36145 m
.59916 .34712 L
.54086 .37401 L
.57819 .39197 L
F
0 1 .089 r
.59916 .34712 m
.55852 .32723 L
.50434 .35159 L
.54086 .37401 L
F
1 .849 0 r
.55852 .32723 m
.52057 .30236 L
.47024 .3254 L
.50434 .35159 L
F
1 0 .382 r
.52057 .30236 m
.48697 .27385 L
.44004 .29685 L
.47024 .3254 L
F
.46 0 1 r
.48697 .27385 m
.45917 .24404 L
.41506 .26819 L
.44004 .29685 L
F
0 .536 1 r
.45917 .24404 m
.4384 .21653 L
.39639 .24272 L
.41506 .26819 L
F
0 1 .733 r
.4384 .21653 m
.42556 .19634 L
.38485 .22465 L
.39639 .24272 L
F
0 1 .372 r
.42556 .19634 m
.42122 .18878 L
.38095 .21804 L
.38485 .22465 L
F
0 1 .44 r
.42122 .18878 m
.42556 .19634 L
.38485 .22465 L
.38095 .21804 L
F
0 1 .928 r
.42556 .19634 m
.4384 .21653 L
.39639 .24272 L
.38485 .22465 L
F
0 .244 1 r
.4384 .21653 m
.45917 .24404 L
.41506 .26819 L
.39639 .24272 L
F
.818 0 1 r
.45917 .24404 m
.48697 .27385 L
.44004 .29685 L
.41506 .26819 L
F
1 .01 0 r
.48697 .27385 m
.52057 .30236 L
.47024 .3254 L
.44004 .29685 L
F
.746 1 0 r
.52057 .30236 m
.55852 .32723 L
.50434 .35159 L
.47024 .3254 L
F
0 1 .488 r
.55852 .32723 m
.59916 .34712 L
.54086 .37401 L
.50434 .35159 L
F
0 .334 1 r
.59916 .34712 m
.6407 .36145 L
.57819 .39197 L
.54086 .37401 L
F
.754 0 1 r
.6407 .36145 m
.68133 .3703 L
.61471 .40534 L
.57819 .39197 L
F
1 0 .276 r
.68133 .3703 m
.71928 .37428 L
.64881 .41445 L
.61471 .40534 L
F
1 .556 0 r
.71928 .37428 m
.75289 .37447 L
.67901 .41998 L
.64881 .41445 L
F
.768 1 0 r
.75289 .37447 m
.78068 .37226 L
.70399 .42282 L
.67901 .41998 L
F
.258 1 0 r
.78068 .37226 m
.80145 .36919 L
.72266 .42394 L
.70399 .42282 L
F
0 1 .075 r
.80145 .36919 m
.81429 .36668 L
.73419 .42421 L
.72266 .42394 L
F
0 1 .228 r
.81429 .36668 m
.81863 .36572 L
.7381 .42423 L
.73419 .42421 L
F
.887 1 0 r
.7381 .42423 m
.73419 .42421 L
.64375 .46403 L
.64715 .46472 L
F
1 .911 0 r
.73419 .42421 m
.72266 .42394 L
.63368 .46181 L
.64375 .46403 L
F
1 .541 0 r
.72266 .42394 m
.70399 .42282 L
.61739 .45771 L
.63368 .46181 L
F
1 .008 0 r
.70399 .42282 m
.67901 .41998 L
.59559 .45123 L
.61739 .45771 L
F
1 0 .677 r
.67901 .41998 m
.64881 .41445 L
.56923 .44179 L
.59559 .45123 L
F
.497 0 1 r
.64881 .41445 m
.61471 .40534 L
.53947 .42888 L
.56923 .44179 L
F
0 .451 1 r
.61471 .40534 m
.57819 .39197 L
.5076 .41215 L
.53947 .42888 L
F
0 1 .499 r
.57819 .39197 m
.54086 .37401 L
.47503 .39154 L
.5076 .41215 L
F
.625 1 0 r
.54086 .37401 m
.50434 .35159 L
.44316 .36735 L
.47503 .39154 L
F
1 .213 0 r
.50434 .35159 m
.47024 .3254 L
.4134 .34039 L
.44316 .36735 L
F
1 0 .94 r
.47024 .3254 m
.44004 .29685 L
.38704 .31207 L
.4134 .34039 L
F
0 .021 1 r
.44004 .29685 m
.41506 .26819 L
.36524 .28452 L
.38704 .31207 L
F
0 .949 1 r
.41506 .26819 m
.39639 .24272 L
.34895 .26072 L
.36524 .28452 L
F
0 1 .372 r
.39639 .24272 m
.38485 .22465 L
.33889 .24423 L
.34895 .26072 L
F
0 1 .036 r
.38485 .22465 m
.38095 .21804 L
.33548 .23828 L
.33889 .24423 L
F
0 1 .1 r
.38095 .21804 m
.38485 .22465 L
.33889 .24423 L
.33548 .23828 L
F
0 1 .552 r
.38485 .22465 m
.39639 .24272 L
.34895 .26072 L
.33889 .24423 L
F
0 .678 1 r
.39639 .24272 m
.41506 .26819 L
.36524 .28452 L
.34895 .26072 L
F
.311 0 1 r
.41506 .26819 m
.44004 .29685 L
.38704 .31207 L
.36524 .28452 L
F
1 0 .574 r
.44004 .29685 m
.47024 .3254 L
.4134 .34039 L
.38704 .31207 L
F
1 .59 0 r
.47024 .3254 m
.50434 .35159 L
.44316 .36735 L
.4134 .34039 L
F
.254 1 0 r
.50434 .35159 m
.54086 .37401 L
.47503 .39154 L
.44316 .36735 L
F
0 1 .851 r
.54086 .37401 m
.57819 .39197 L
.5076 .41215 L
.47503 .39154 L
F
0 .127 1 r
.57819 .39197 m
.61471 .40534 L
.53947 .42888 L
.5076 .41215 L
F
.785 0 1 r
.61471 .40534 m
.64881 .41445 L
.56923 .44179 L
.53947 .42888 L
F
1 0 .433 r
.64881 .41445 m
.67901 .41998 L
.59559 .45123 L
.56923 .44179 L
F
1 .204 0 r
.67901 .41998 m
.70399 .42282 L
.61739 .45771 L
.59559 .45123 L
F
1 .684 0 r
.70399 .42282 m
.72266 .42394 L
.63368 .46181 L
.61739 .45771 L
F
1 .998 0 r
.72266 .42394 m
.73419 .42421 L
.64375 .46403 L
.63368 .46181 L
F
.858 1 0 r
.73419 .42421 m
.7381 .42423 L
.64715 .46472 L
.64375 .46403 L
F
.887 1 0 r
.7381 .42423 m
.73419 .42421 L
.64375 .46403 L
.64715 .46472 L
F
1 .911 0 r
.73419 .42421 m
.72266 .42394 L
.63368 .46181 L
.64375 .46403 L
F
1 .541 0 r
.72266 .42394 m
.70399 .42282 L
.61739 .45771 L
.63368 .46181 L
F
1 .008 0 r
.70399 .42282 m
.67901 .41998 L
.59559 .45123 L
.61739 .45771 L
F
1 0 .677 r
.67901 .41998 m
.64881 .41445 L
.56923 .44179 L
.59559 .45123 L
F
.497 0 1 r
.64881 .41445 m
.61471 .40534 L
.53947 .42888 L
.56923 .44179 L
F
0 .451 1 r
.61471 .40534 m
.57819 .39197 L
.5076 .41215 L
.53947 .42888 L
F
0 1 .499 r
.57819 .39197 m
.54086 .37401 L
.47503 .39154 L
.5076 .41215 L
F
.625 1 0 r
.54086 .37401 m
.50434 .35159 L
.44316 .36735 L
.47503 .39154 L
F
1 .213 0 r
.50434 .35159 m
.47024 .3254 L
.4134 .34039 L
.44316 .36735 L
F
1 0 .94 r
.47024 .3254 m
.44004 .29685 L
.38704 .31207 L
.4134 .34039 L
F
0 .021 1 r
.44004 .29685 m
.41506 .26819 L
.36524 .28452 L
.38704 .31207 L
F
0 .949 1 r
.41506 .26819 m
.39639 .24272 L
.34895 .26072 L
.36524 .28452 L
F
0 1 .372 r
.39639 .24272 m
.38485 .22465 L
.33889 .24423 L
.34895 .26072 L
F
0 1 .036 r
.38485 .22465 m
.38095 .21804 L
.33548 .23828 L
.33889 .24423 L
F
0 1 .1 r
.38095 .21804 m
.38485 .22465 L
.33889 .24423 L
.33548 .23828 L
F
0 1 .552 r
.38485 .22465 m
.39639 .24272 L
.34895 .26072 L
.33889 .24423 L
F
0 .678 1 r
.39639 .24272 m
.41506 .26819 L
.36524 .28452 L
.34895 .26072 L
F
.311 0 1 r
.41506 .26819 m
.44004 .29685 L
.38704 .31207 L
.36524 .28452 L
F
1 0 .574 r
.44004 .29685 m
.47024 .3254 L
.4134 .34039 L
.38704 .31207 L
F
1 .59 0 r
.47024 .3254 m
.50434 .35159 L
.44316 .36735 L
.4134 .34039 L
F
.254 1 0 r
.50434 .35159 m
.54086 .37401 L
.47503 .39154 L
.44316 .36735 L
F
0 1 .851 r
.54086 .37401 m
.57819 .39197 L
.5076 .41215 L
.47503 .39154 L
F
0 .127 1 r
.57819 .39197 m
.61471 .40534 L
.53947 .42888 L
.5076 .41215 L
F
.785 0 1 r
.61471 .40534 m
.64881 .41445 L
.56923 .44179 L
.53947 .42888 L
F
1 0 .433 r
.64881 .41445 m
.67901 .41998 L
.59559 .45123 L
.56923 .44179 L
F
1 .204 0 r
.67901 .41998 m
.70399 .42282 L
.61739 .45771 L
.59559 .45123 L
F
1 .684 0 r
.70399 .42282 m
.72266 .42394 L
.63368 .46181 L
.61739 .45771 L
F
1 .998 0 r
.72266 .42394 m
.73419 .42421 L
.64375 .46403 L
.63368 .46181 L
F
.858 1 0 r
.73419 .42421 m
.7381 .42423 L
.64715 .46472 L
.64375 .46403 L
F
1 0 .165 r
.64715 .46472 m
.64375 .46403 L
.5469 .48427 L
.54978 .48542 L
F
1 0 .351 r
.64375 .46403 m
.63368 .46181 L
.53841 .48074 L
.5469 .48427 L
F
1 0 .693 r
.63368 .46181 m
.61739 .45771 L
.52466 .47465 L
.53841 .48074 L
F
.815 0 1 r
.61739 .45771 m
.59559 .45123 L
.50627 .46571 L
.52466 .47465 L
F
.181 0 1 r
.59559 .45123 m
.56923 .44179 L
.48403 .45365 L
.50627 .46571 L
F
0 .582 1 r
.56923 .44179 m
.53947 .42888 L
.45892 .43822 L
.48403 .45365 L
F
0 1 .542 r
.53947 .42888 m
.5076 .41215 L
.43203 .41935 L
.45892 .43822 L
F
.427 1 0 r
.5076 .41215 m
.47503 .39154 L
.40454 .39718 L
.43203 .41935 L
F
1 .537 0 r
.47503 .39154 m
.44316 .36735 L
.37765 .37215 L
.40454 .39718 L
F
1 0 .532 r
.44316 .36735 m
.4134 .34039 L
.35254 .34514 L
.37765 .37215 L
F
.409 0 1 r
.4134 .34039 m
.38704 .31207 L
.3303 .31753 L
.35254 .34514 L
F
0 .581 1 r
.38704 .31207 m
.36524 .28452 L
.31191 .29131 L
.3303 .31753 L
F
0 1 .571 r
.36524 .28452 m
.34895 .26072 L
.29816 .26914 L
.31191 .29131 L
F
.047 1 0 r
.34895 .26072 m
.33889 .24423 L
.28967 .25403 L
.29816 .26914 L
F
.352 1 0 r
.33889 .24423 m
.33548 .23828 L
.28679 .24863 L
.28967 .25403 L
F
.295 1 0 r
.33548 .23828 m
.33889 .24423 L
.28967 .25403 L
.28679 .24863 L
F
0 1 .116 r
.33889 .24423 m
.34895 .26072 L
.29816 .26914 L
.28967 .25403 L
F
0 1 .817 r
.34895 .26072 m
.36524 .28452 L
.31191 .29131 L
.29816 .26914 L
F
0 .279 1 r
.36524 .28452 m
.38704 .31207 L
.3303 .31753 L
.31191 .29131 L
F
.742 0 1 r
.38704 .31207 m
.4134 .34039 L
.35254 .34514 L
.3303 .31753 L
F
1 0 .189 r
.4134 .34039 m
.44316 .36735 L
.37765 .37215 L
.35254 .34514 L
F
1 .876 0 r
.44316 .36735 m
.47503 .39154 L
.40454 .39718 L
.37765 .37215 L
F
.105 1 0 r
.47503 .39154 m
.5076 .41215 L
.43203 .41935 L
.40454 .39718 L
F
0 1 .838 r
.5076 .41215 m
.53947 .42888 L
.45892 .43822 L
.43203 .41935 L
F
0 .32 1 r
.53947 .42888 m
.56923 .44179 L
.48403 .45365 L
.45892 .43822 L
F
.404 0 1 r
.56923 .44179 m
.59559 .45123 L
.50627 .46571 L
.48403 .45365 L
F
.993 0 1 r
.59559 .45123 m
.61739 .45771 L
.52466 .47465 L
.50627 .46571 L
F
1 0 .563 r
.61739 .45771 m
.63368 .46181 L
.53841 .48074 L
.52466 .47465 L
F
1 0 .272 r
.63368 .46181 m
.64375 .46403 L
.5469 .48427 L
.53841 .48074 L
F
1 0 .138 r
.64375 .46403 m
.64715 .46472 L
.54978 .48542 L
.5469 .48427 L
F
1 0 .165 r
.64715 .46472 m
.64375 .46403 L
.5469 .48427 L
.54978 .48542 L
F
1 0 .351 r
.64375 .46403 m
.63368 .46181 L
.53841 .48074 L
.5469 .48427 L
F
1 0 .693 r
.63368 .46181 m
.61739 .45771 L
.52466 .47465 L
.53841 .48074 L
F
.815 0 1 r
.61739 .45771 m
.59559 .45123 L
.50627 .46571 L
.52466 .47465 L
F
.181 0 1 r
.59559 .45123 m
.56923 .44179 L
.48403 .45365 L
.50627 .46571 L
F
0 .582 1 r
.56923 .44179 m
.53947 .42888 L
.45892 .43822 L
.48403 .45365 L
F
0 1 .542 r
.53947 .42888 m
.5076 .41215 L
.43203 .41935 L
.45892 .43822 L
F
.427 1 0 r
.5076 .41215 m
.47503 .39154 L
.40454 .39718 L
.43203 .41935 L
F
1 .537 0 r
.47503 .39154 m
.44316 .36735 L
.37765 .37215 L
.40454 .39718 L
F
1 0 .532 r
.44316 .36735 m
.4134 .34039 L
.35254 .34514 L
.37765 .37215 L
F
.409 0 1 r
.4134 .34039 m
.38704 .31207 L
.3303 .31753 L
.35254 .34514 L
F
0 .581 1 r
.38704 .31207 m
.36524 .28452 L
.31191 .29131 L
.3303 .31753 L
F
0 1 .571 r
.36524 .28452 m
.34895 .26072 L
.29816 .26914 L
.31191 .29131 L
F
.047 1 0 r
.34895 .26072 m
.33889 .24423 L
.28967 .25403 L
.29816 .26914 L
F
.352 1 0 r
.33889 .24423 m
.33548 .23828 L
.28679 .24863 L
.28967 .25403 L
F
.295 1 0 r
.33548 .23828 m
.33889 .24423 L
.28967 .25403 L
.28679 .24863 L
F
0 1 .116 r
.33889 .24423 m
.34895 .26072 L
.29816 .26914 L
.28967 .25403 L
F
0 1 .817 r
.34895 .26072 m
.36524 .28452 L
.31191 .29131 L
.29816 .26914 L
F
0 .279 1 r
.36524 .28452 m
.38704 .31207 L
.3303 .31753 L
.31191 .29131 L
F
.742 0 1 r
.38704 .31207 m
.4134 .34039 L
.35254 .34514 L
.3303 .31753 L
F
1 0 .189 r
.4134 .34039 m
.44316 .36735 L
.37765 .37215 L
.35254 .34514 L
F
1 .876 0 r
.44316 .36735 m
.47503 .39154 L
.40454 .39718 L
.37765 .37215 L
F
.105 1 0 r
.47503 .39154 m
.5076 .41215 L
.43203 .41935 L
.40454 .39718 L
F
0 1 .838 r
.5076 .41215 m
.53947 .42888 L
.45892 .43822 L
.43203 .41935 L
F
0 .32 1 r
.53947 .42888 m
.56923 .44179 L
.48403 .45365 L
.45892 .43822 L
F
.404 0 1 r
.56923 .44179 m
.59559 .45123 L
.50627 .46571 L
.48403 .45365 L
F
.993 0 1 r
.59559 .45123 m
.61739 .45771 L
.52466 .47465 L
.50627 .46571 L
F
1 0 .563 r
.61739 .45771 m
.63368 .46181 L
.53841 .48074 L
.52466 .47465 L
F
1 0 .272 r
.63368 .46181 m
.64375 .46403 L
.5469 .48427 L
.53841 .48074 L
F
1 0 .138 r
.64375 .46403 m
.64715 .46472 L
.54978 .48542 L
.5469 .48427 L
F
.382 0 1 r
.54978 .48542 m
.5469 .48427 L
.44789 .484 L
.45022 .48542 L
F
.213 0 1 r
.5469 .48427 m
.53841 .48074 L
.44101 .47969 L
.44789 .484 L
F
0 .097 1 r
.53841 .48074 m
.52466 .47465 L
.42987 .47243 L
.44101 .47969 L
F
0 .543 1 r
.52466 .47465 m
.50627 .46571 L
.41495 .46209 L
.42987 .47243 L
F
0 1 .883 r
.50627 .46571 m
.48403 .45365 L
.39692 .44859 L
.41495 .46209 L
F
0 1 .192 r
.48403 .45365 m
.45892 .43822 L
.37656 .43189 L
.39692 .44859 L
F
.601 1 0 r
.45892 .43822 m
.43203 .41935 L
.35476 .4121 L
.37656 .43189 L
F
1 .523 0 r
.43203 .41935 m
.40454 .39718 L
.33248 .3895 L
.35476 .4121 L
F
1 0 .411 r
.40454 .39718 m
.37765 .37215 L
.31068 .36463 L
.33248 .3895 L
F
.626 0 1 r
.37765 .37215 m
.35254 .34514 L
.29032 .33841 L
.31068 .36463 L
F
0 .324 1 r
.35254 .34514 m
.3303 .31753 L
.27229 .31213 L
.29032 .33841 L
F
0 1 .79 r
.3303 .31753 m
.31191 .29131 L
.25738 .28763 L
.27229 .31213 L
F
0 1 .034 r
.31191 .29131 m
.29816 .26914 L
.24623 .26722 L
.25738 .28763 L
F
.515 1 0 r
.29816 .26914 m
.28967 .25403 L
.23935 .2535 L
.24623 .26722 L
F
.784 1 0 r
.28967 .25403 m
.28679 .24863 L
.23702 .24863 L
.23935 .2535 L
F
.734 1 0 r
.28679 .24863 m
.28967 .25403 L
.23935 .2535 L
.23702 .24863 L
F
.37 1 0 r
.28967 .25403 m
.29816 .26914 L
.24623 .26722 L
.23935 .2535 L
F
0 1 .252 r
.29816 .26914 m
.31191 .29131 L
.25738 .28763 L
.24623 .26722 L
F
0 .943 1 r
.31191 .29131 m
.3303 .31753 L
.27229 .31213 L
.25738 .28763 L
F
0 .029 1 r
.3303 .31753 m
.35254 .34514 L
.29032 .33841 L
.27229 .31213 L
F
.932 0 1 r
.35254 .34514 m
.37765 .37215 L
.31068 .36463 L
.29032 .33841 L
F
1 0 .109 r
.37765 .37215 m
.40454 .39718 L
.33248 .3895 L
.31068 .36463 L
F
1 .811 0 r
.40454 .39718 m
.43203 .41935 L
.35476 .4121 L
.33248 .3895 L
F
.336 1 0 r
.43203 .41935 m
.45892 .43822 L
.37656 .43189 L
.35476 .4121 L
F
0 1 .426 r
.45892 .43822 m
.48403 .45365 L
.39692 .44859 L
.37656 .43189 L
F
0 .918 1 r
.48403 .45365 m
.50627 .46571 L
.41495 .46209 L
.39692 .44859 L
F
0 .384 1 r
.50627 .46571 m
.52466 .47465 L
.42987 .47243 L
.41495 .46209 L
F
.019 0 1 r
.52466 .47465 m
.53841 .48074 L
.44101 .47969 L
.42987 .47243 L
F
.284 0 1 r
.53841 .48074 m
.5469 .48427 L
.44789 .484 L
.44101 .47969 L
F
.406 0 1 r
.5469 .48427 m
.54978 .48542 L
.45022 .48542 L
.44789 .484 L
F
.382 0 1 r
.54978 .48542 m
.5469 .48427 L
.44789 .484 L
.45022 .48542 L
F
.213 0 1 r
.5469 .48427 m
.53841 .48074 L
.44101 .47969 L
.44789 .484 L
F
0 .097 1 r
.53841 .48074 m
.52466 .47465 L
.42987 .47243 L
.44101 .47969 L
F
0 .543 1 r
.52466 .47465 m
.50627 .46571 L
.41495 .46209 L
.42987 .47243 L
F
0 1 .883 r
.50627 .46571 m
.48403 .45365 L
.39692 .44859 L
.41495 .46209 L
F
0 1 .192 r
.48403 .45365 m
.45892 .43822 L
.37656 .43189 L
.39692 .44859 L
F
.601 1 0 r
.45892 .43822 m
.43203 .41935 L
.35476 .4121 L
.37656 .43189 L
F
1 .523 0 r
.43203 .41935 m
.40454 .39718 L
.33248 .3895 L
.35476 .4121 L
F
1 0 .411 r
.40454 .39718 m
.37765 .37215 L
.31068 .36463 L
.33248 .3895 L
F
.626 0 1 r
.37765 .37215 m
.35254 .34514 L
.29032 .33841 L
.31068 .36463 L
F
0 .324 1 r
.35254 .34514 m
.3303 .31753 L
.27229 .31213 L
.29032 .33841 L
F
0 1 .79 r
.3303 .31753 m
.31191 .29131 L
.25738 .28763 L
.27229 .31213 L
F
0 1 .034 r
.31191 .29131 m
.29816 .26914 L
.24623 .26722 L
.25738 .28763 L
F
.515 1 0 r
.29816 .26914 m
.28967 .25403 L
.23935 .2535 L
.24623 .26722 L
F
.784 1 0 r
.28967 .25403 m
.28679 .24863 L
.23702 .24863 L
.23935 .2535 L
F
.734 1 0 r
.28679 .24863 m
.28967 .25403 L
.23935 .2535 L
.23702 .24863 L
F
.37 1 0 r
.28967 .25403 m
.29816 .26914 L
.24623 .26722 L
.23935 .2535 L
F
0 1 .252 r
.29816 .26914 m
.31191 .29131 L
.25738 .28763 L
.24623 .26722 L
F
0 .943 1 r
.31191 .29131 m
.3303 .31753 L
.27229 .31213 L
.25738 .28763 L
F
0 .029 1 r
.3303 .31753 m
.35254 .34514 L
.29032 .33841 L
.27229 .31213 L
F
.932 0 1 r
.35254 .34514 m
.37765 .37215 L
.31068 .36463 L
.29032 .33841 L
F
1 0 .109 r
.37765 .37215 m
.40454 .39718 L
.33248 .3895 L
.31068 .36463 L
F
1 .811 0 r
.40454 .39718 m
.43203 .41935 L
.35476 .4121 L
.33248 .3895 L
F
.336 1 0 r
.43203 .41935 m
.45892 .43822 L
.37656 .43189 L
.35476 .4121 L
F
0 1 .426 r
.45892 .43822 m
.48403 .45365 L
.39692 .44859 L
.37656 .43189 L
F
0 .918 1 r
.48403 .45365 m
.50627 .46571 L
.41495 .46209 L
.39692 .44859 L
F
0 .384 1 r
.50627 .46571 m
.52466 .47465 L
.42987 .47243 L
.41495 .46209 L
F
.019 0 1 r
.52466 .47465 m
.53841 .48074 L
.44101 .47969 L
.42987 .47243 L
F
.284 0 1 r
.53841 .48074 m
.5469 .48427 L
.44789 .484 L
.44101 .47969 L
F
.406 0 1 r
.5469 .48427 m
.54978 .48542 L
.45022 .48542 L
.44789 .484 L
F
0 1 .774 r
.45022 .48542 m
.44789 .484 L
.35105 .46319 L
.35285 .46472 L
F
0 1 .625 r
.44789 .484 m
.44101 .47969 L
.34574 .45858 L
.35105 .46319 L
F
0 1 .351 r
.44101 .47969 m
.42987 .47243 L
.33714 .45088 L
.34574 .45858 L
F
.044 1 0 r
.42987 .47243 m
.41495 .46209 L
.32563 .44008 L
.33714 .45088 L
F
.551 1 0 r
.41495 .46209 m
.39692 .44859 L
.31172 .42623 L
.32563 .44008 L
F
1 .839 0 r
.39692 .44859 m
.37656 .43189 L
.29601 .40943 L
.31172 .42623 L
F
1 .14 0 r
.37656 .43189 m
.35476 .4121 L
.27919 .38989 L
.29601 .40943 L
F
1 0 .631 r
.35476 .4121 m
.33248 .3895 L
.26199 .36799 L
.27919 .38989 L
F
.548 0 1 r
.33248 .3895 m
.31068 .36463 L
.24517 .34432 L
.26199 .36799 L
F
0 .295 1 r
.31068 .36463 m
.29032 .33841 L
.22946 .31975 L
.24517 .34432 L
F
0 1 .876 r
.29032 .33841 m
.27229 .31213 L
.21555 .2955 L
.22946 .31975 L
F
0 1 .107 r
.27229 .31213 m
.25738 .28763 L
.20404 .27319 L
.21555 .2955 L
F
.546 1 0 r
.25738 .28763 m
.24623 .26722 L
.19544 .25483 L
.20404 .27319 L
F
1 .983 0 r
.24623 .26722 m
.23935 .2535 L
.19013 .2426 L
.19544 .25483 L
F
1 .752 0 r
.23935 .2535 m
.23702 .24863 L
.18833 .23828 L
.19013 .2426 L
F
1 .796 0 r
.23702 .24863 m
.23935 .2535 L
.19013 .2426 L
.18833 .23828 L
F
.894 1 0 r
.23935 .2535 m
.24623 .26722 L
.19544 .25483 L
.19013 .2426 L
F
.36 1 0 r
.24623 .26722 m
.25738 .28763 L
.20404 .27319 L
.19544 .25483 L
F
0 1 .336 r
.25738 .28763 m
.27229 .31213 L
.21555 .2955 L
.20404 .27319 L
F
0 .869 1 r
.27229 .31213 m
.29032 .33841 L
.22946 .31975 L
.21555 .2955 L
F
0 .031 1 r
.29032 .33841 m
.31068 .36463 L
.24517 .34432 L
.22946 .31975 L
F
.81 0 1 r
.31068 .36463 m
.33248 .3895 L
.26199 .36799 L
.24517 .34432 L
F
1 0 .381 r
.33248 .3895 m
.35476 .4121 L
.27919 .38989 L
.26199 .36799 L
F
1 .37 0 r
.35476 .4121 m
.37656 .43189 L
.29601 .40943 L
.27919 .38989 L
F
.957 1 0 r
.37656 .43189 m
.39692 .44859 L
.31172 .42623 L
.29601 .40943 L
F
.378 1 0 r
.39692 .44859 m
.41495 .46209 L
.32563 .44008 L
.31172 .42623 L
F
0 1 .095 r
.41495 .46209 m
.42987 .47243 L
.33714 .45088 L
.32563 .44008 L
F
0 1 .452 r
.42987 .47243 m
.44101 .47969 L
.34574 .45858 L
.33714 .45088 L
F
0 1 .686 r
.44101 .47969 m
.44789 .484 L
.35105 .46319 L
.34574 .45858 L
F
0 1 .794 r
.44789 .484 m
.45022 .48542 L
.35285 .46472 L
.35105 .46319 L
F
0 1 .774 r
.45022 .48542 m
.44789 .484 L
.35105 .46319 L
.35285 .46472 L
F
0 1 .625 r
.44789 .484 m
.44101 .47969 L
.34574 .45858 L
.35105 .46319 L
F
0 1 .351 r
.44101 .47969 m
.42987 .47243 L
.33714 .45088 L
.34574 .45858 L
F
.044 1 0 r
.42987 .47243 m
.41495 .46209 L
.32563 .44008 L
.33714 .45088 L
F
.551 1 0 r
.41495 .46209 m
.39692 .44859 L
.31172 .42623 L
.32563 .44008 L
F
1 .839 0 r
.39692 .44859 m
.37656 .43189 L
.29601 .40943 L
.31172 .42623 L
F
1 .14 0 r
.37656 .43189 m
.35476 .4121 L
.27919 .38989 L
.29601 .40943 L
F
1 0 .631 r
.35476 .4121 m
.33248 .3895 L
.26199 .36799 L
.27919 .38989 L
F
.548 0 1 r
.33248 .3895 m
.31068 .36463 L
.24517 .34432 L
.26199 .36799 L
F
0 .295 1 r
.31068 .36463 m
.29032 .33841 L
.22946 .31975 L
.24517 .34432 L
F
0 1 .876 r
.29032 .33841 m
.27229 .31213 L
.21555 .2955 L
.22946 .31975 L
F
0 1 .107 r
.27229 .31213 m
.25738 .28763 L
.20404 .27319 L
.21555 .2955 L
F
.546 1 0 r
.25738 .28763 m
.24623 .26722 L
.19544 .25483 L
.20404 .27319 L
F
1 .983 0 r
.24623 .26722 m
.23935 .2535 L
.19013 .2426 L
.19544 .25483 L
F
1 .752 0 r
.23935 .2535 m
.23702 .24863 L
.18833 .23828 L
.19013 .2426 L
F
1 .796 0 r
.23702 .24863 m
.23935 .2535 L
.19013 .2426 L
.18833 .23828 L
F
.894 1 0 r
.23935 .2535 m
.24623 .26722 L
.19544 .25483 L
.19013 .2426 L
F
.36 1 0 r
.24623 .26722 m
.25738 .28763 L
.20404 .27319 L
.19544 .25483 L
F
0 1 .336 r
.25738 .28763 m
.27229 .31213 L
.21555 .2955 L
.20404 .27319 L
F
0 .869 1 r
.27229 .31213 m
.29032 .33841 L
.22946 .31975 L
.21555 .2955 L
F
0 .031 1 r
.29032 .33841 m
.31068 .36463 L
.24517 .34432 L
.22946 .31975 L
F
.81 0 1 r
.31068 .36463 m
.33248 .3895 L
.26199 .36799 L
.24517 .34432 L
F
1 0 .381 r
.33248 .3895 m
.35476 .4121 L
.27919 .38989 L
.26199 .36799 L
F
1 .37 0 r
.35476 .4121 m
.37656 .43189 L
.29601 .40943 L
.27919 .38989 L
F
.957 1 0 r
.37656 .43189 m
.39692 .44859 L
.31172 .42623 L
.29601 .40943 L
F
.378 1 0 r
.39692 .44859 m
.41495 .46209 L
.32563 .44008 L
.31172 .42623 L
F
0 1 .095 r
.41495 .46209 m
.42987 .47243 L
.33714 .45088 L
.32563 .44008 L
F
0 1 .452 r
.42987 .47243 m
.44101 .47969 L
.34574 .45858 L
.33714 .45088 L
F
0 1 .686 r
.44101 .47969 m
.44789 .484 L
.35105 .46319 L
.34574 .45858 L
F
0 1 .794 r
.44789 .484 m
.45022 .48542 L
.35285 .46472 L
.35105 .46319 L
F
.963 1 0 r
.35285 .46472 m
.35105 .46319 L
.2606 .42273 L
.2619 .42423 L
F
1 .91 0 r
.35105 .46319 m
.34574 .45858 L
.25676 .41821 L
.2606 .42273 L
F
1 .676 0 r
.34574 .45858 m
.33714 .45088 L
.25054 .41073 L
.25676 .41821 L
F
1 .338 0 r
.33714 .45088 m
.32563 .44008 L
.24221 .40033 L
.25054 .41073 L
F
1 0 .096 r
.32563 .44008 m
.31172 .42623 L
.23214 .38712 L
.24221 .40033 L
F
1 0 .616 r
.31172 .42623 m
.29601 .40943 L
.22077 .37129 L
.23214 .38712 L
F
.788 0 1 r
.29601 .40943 m
.27919 .38989 L
.2086 .35311 L
.22077 .37129 L
F
.133 0 1 r
.27919 .38989 m
.26199 .36799 L
.19616 .33298 L
.2086 .35311 L
F
0 .563 1 r
.26199 .36799 m
.24517 .34432 L
.18399 .31149 L
.19616 .33298 L
F
0 1 .726 r
.24517 .34432 m
.22946 .31975 L
.17262 .28944 L
.18399 .31149 L
F
0 1 .03 r
.22946 .31975 m
.21555 .2955 L
.16255 .26792 L
.17262 .28944 L
F
.611 1 0 r
.21555 .2955 m
.20404 .27319 L
.15423 .24832 L
.16255 .26792 L
F
1 .85 0 r
.20404 .27319 m
.19544 .25483 L
.148 .23233 L
.15423 .24832 L
F
1 .463 0 r
.19544 .25483 m
.19013 .2426 L
.14416 .22175 L
.148 .23233 L
F
1 .274 0 r
.19013 .2426 m
.18833 .23828 L
.14286 .21804 L
.14416 .22175 L
F
1 .309 0 r
.18833 .23828 m
.19013 .2426 L
.14416 .22175 L
.14286 .21804 L
F
1 .562 0 r
.19013 .2426 m
.19544 .25483 L
.148 .23233 L
.14416 .22175 L
F
.999 1 0 r
.19544 .25483 m
.20404 .27319 L
.15423 .24832 L
.148 .23233 L
F
.423 1 0 r
.20404 .27319 m
.21555 .2955 L
.16255 .26792 L
.15423 .24832 L
F
0 1 .24 r
.21555 .2955 m
.22946 .31975 L
.17262 .28944 L
.16255 .26792 L
F
0 1 .945 r
.22946 .31975 m
.24517 .34432 L
.18399 .31149 L
.17262 .28944 L
F
0 .345 1 r
.24517 .34432 m
.26199 .36799 L
.19616 .33298 L
.18399 .31149 L
F
.341 0 1 r
.26199 .36799 m
.27919 .38989 L
.2086 .35311 L
.19616 .33298 L
F
.98 0 1 r
.27919 .38989 m
.29601 .40943 L
.22077 .37129 L
.2086 .35311 L
F
1 0 .445 r
.29601 .40943 m
.31172 .42623 L
.23214 .38712 L
.22077 .37129 L
F
1 .05 0 r
.31172 .42623 m
.32563 .44008 L
.24221 .40033 L
.23214 .38712 L
F
1 .454 0 r
.32563 .44008 m
.33714 .45088 L
.25054 .41073 L
.24221 .40033 L
F
1 .76 0 r
.33714 .45088 m
.34574 .45858 L
.25676 .41821 L
.25054 .41073 L
F
1 .962 0 r
.34574 .45858 m
.35105 .46319 L
.2606 .42273 L
.25676 .41821 L
F
.945 1 0 r
.35105 .46319 m
.35285 .46472 L
.2619 .42423 L
.2606 .42273 L
F
.963 1 0 r
.35285 .46472 m
.35105 .46319 L
.2606 .42273 L
.2619 .42423 L
F
1 .91 0 r
.35105 .46319 m
.34574 .45858 L
.25676 .41821 L
.2606 .42273 L
F
1 .676 0 r
.34574 .45858 m
.33714 .45088 L
.25054 .41073 L
.25676 .41821 L
F
1 .338 0 r
.33714 .45088 m
.32563 .44008 L
.24221 .40033 L
.25054 .41073 L
F
1 0 .096 r
.32563 .44008 m
.31172 .42623 L
.23214 .38712 L
.24221 .40033 L
F
1 0 .616 r
.31172 .42623 m
.29601 .40943 L
.22077 .37129 L
.23214 .38712 L
F
.788 0 1 r
.29601 .40943 m
.27919 .38989 L
.2086 .35311 L
.22077 .37129 L
F
.133 0 1 r
.27919 .38989 m
.26199 .36799 L
.19616 .33298 L
.2086 .35311 L
F
0 .563 1 r
.26199 .36799 m
.24517 .34432 L
.18399 .31149 L
.19616 .33298 L
F
0 1 .726 r
.24517 .34432 m
.22946 .31975 L
.17262 .28944 L
.18399 .31149 L
F
0 1 .03 r
.22946 .31975 m
.21555 .2955 L
.16255 .26792 L
.17262 .28944 L
F
.611 1 0 r
.21555 .2955 m
.20404 .27319 L
.15423 .24832 L
.16255 .26792 L
F
1 .85 0 r
.20404 .27319 m
.19544 .25483 L
.148 .23233 L
.15423 .24832 L
F
1 .463 0 r
.19544 .25483 m
.19013 .2426 L
.14416 .22175 L
.148 .23233 L
F
1 .274 0 r
.19013 .2426 m
.18833 .23828 L
.14286 .21804 L
.14416 .22175 L
F
1 .309 0 r
.18833 .23828 m
.19013 .2426 L
.14416 .22175 L
.14286 .21804 L
F
1 .562 0 r
.19013 .2426 m
.19544 .25483 L
.148 .23233 L
.14416 .22175 L
F
.999 1 0 r
.19544 .25483 m
.20404 .27319 L
.15423 .24832 L
.148 .23233 L
F
.423 1 0 r
.20404 .27319 m
.21555 .2955 L
.16255 .26792 L
.15423 .24832 L
F
0 1 .24 r
.21555 .2955 m
.22946 .31975 L
.17262 .28944 L
.16255 .26792 L
F
0 1 .945 r
.22946 .31975 m
.24517 .34432 L
.18399 .31149 L
.17262 .28944 L
F
0 .345 1 r
.24517 .34432 m
.26199 .36799 L
.19616 .33298 L
.18399 .31149 L
F
.341 0 1 r
.26199 .36799 m
.27919 .38989 L
.2086 .35311 L
.19616 .33298 L
F
.98 0 1 r
.27919 .38989 m
.29601 .40943 L
.22077 .37129 L
.2086 .35311 L
F
1 0 .445 r
.29601 .40943 m
.31172 .42623 L
.23214 .38712 L
.22077 .37129 L
F
1 .05 0 r
.31172 .42623 m
.32563 .44008 L
.24221 .40033 L
.23214 .38712 L
F
1 .454 0 r
.32563 .44008 m
.33714 .45088 L
.25054 .41073 L
.24221 .40033 L
F
1 .76 0 r
.33714 .45088 m
.34574 .45858 L
.25676 .41821 L
.25054 .41073 L
F
1 .962 0 r
.34574 .45858 m
.35105 .46319 L
.2606 .42273 L
.25676 .41821 L
F
.945 1 0 r
.35105 .46319 m
.35285 .46472 L
.2619 .42423 L
.2606 .42273 L
F
1 0 .792 r
.2619 .42423 m
.2606 .42273 L
.18051 .36436 L
.18137 .36572 L
F
1 0 .896 r
.2606 .42273 m
.25676 .41821 L
.17796 .3603 L
.18051 .36436 L
F
.913 0 1 r
.25676 .41821 m
.25054 .41073 L
.17384 .3536 L
.17796 .3603 L
F
.637 0 1 r
.25054 .41073 m
.24221 .40033 L
.16833 .34433 L
.17384 .3536 L
F
.283 0 1 r
.24221 .40033 m
.23214 .38712 L
.16167 .33264 L
.16833 .34433 L
F
0 .141 1 r
.23214 .38712 m
.22077 .37129 L
.15415 .31873 L
.16167 .33264 L
F
0 .624 1 r
.22077 .37129 m
.2086 .35311 L
.14609 .30289 L
.15415 .31873 L
F
0 1 .846 r
.2086 .35311 m
.19616 .33298 L
.13786 .28551 L
.14609 .30289 L
F
0 1 .286 r
.19616 .33298 m
.18399 .31149 L
.12981 .2671 L
.13786 .28551 L
F
.282 1 0 r
.18399 .31149 m
.17262 .28944 L
.12228 .24838 L
.12981 .2671 L
F
.834 1 0 r
.17262 .28944 m
.16255 .26792 L
.11562 .23025 L
.12228 .24838 L
F
1 .662 0 r
.16255 .26792 m
.15423 .24832 L
.11011 .21386 L
.11562 .23025 L
F
1 .243 0 r
.15423 .24832 m
.148 .23233 L
.10599 .20058 L
.11011 .21386 L
F
1 0 .055 r
.148 .23233 m
.14416 .22175 L
.10345 .19184 L
.10599 .20058 L
F
1 0 .2 r
.14416 .22175 m
.14286 .21804 L
.10259 .18878 L
.10345 .19184 L
F
1 0 .174 r
.14286 .21804 m
.14416 .22175 L
.10345 .19184 L
.10259 .18878 L
F
1 .019 0 r
.14416 .22175 m
.148 .23233 L
.10599 .20058 L
.10345 .19184 L
F
1 .357 0 r
.148 .23233 m
.15423 .24832 L
.11011 .21386 L
.10599 .20058 L
F
1 .806 0 r
.15423 .24832 m
.16255 .26792 L
.11562 .23025 L
.11011 .21386 L
F
.672 1 0 r
.16255 .26792 m
.17262 .28944 L
.12228 .24838 L
.11562 .23025 L
F
.112 1 0 r
.17262 .28944 m
.18399 .31149 L
.12981 .2671 L
.12228 .24838 L
F
0 1 .457 r
.18399 .31149 m
.19616 .33298 L
.13786 .28551 L
.12981 .2671 L
F
0 .99 1 r
.19616 .33298 m
.2086 .35311 L
.14609 .30289 L
.13786 .28551 L
F
0 .472 1 r
.2086 .35311 m
.22077 .37129 L
.15415 .31873 L
.14609 .30289 L
F
0 .005 1 r
.22077 .37129 m
.23214 .38712 L
.16167 .33264 L
.15415 .31873 L
F
.399 0 1 r
.23214 .38712 m
.24221 .40033 L
.16833 .34433 L
.16167 .33264 L
F
.729 0 1 r
.24221 .40033 m
.25054 .41073 L
.17384 .3536 L
.16833 .34433 L
F
.98 0 1 r
.25054 .41073 m
.25676 .41821 L
.17796 .3603 L
.17384 .3536 L
F
1 0 .855 r
.25676 .41821 m
.2606 .42273 L
.18051 .36436 L
.17796 .3603 L
F
1 0 .778 r
.2606 .42273 m
.2619 .42423 L
.18137 .36572 L
.18051 .36436 L
F
1 0 .792 r
.2619 .42423 m
.2606 .42273 L
.18051 .36436 L
.18137 .36572 L
F
1 0 .896 r
.2606 .42273 m
.25676 .41821 L
.17796 .3603 L
.18051 .36436 L
F
.913 0 1 r
.25676 .41821 m
.25054 .41073 L
.17384 .3536 L
.17796 .3603 L
F
.637 0 1 r
.25054 .41073 m
.24221 .40033 L
.16833 .34433 L
.17384 .3536 L
F
.283 0 1 r
.24221 .40033 m
.23214 .38712 L
.16167 .33264 L
.16833 .34433 L
F
0 .141 1 r
.23214 .38712 m
.22077 .37129 L
.15415 .31873 L
.16167 .33264 L
F
0 .624 1 r
.22077 .37129 m
.2086 .35311 L
.14609 .30289 L
.15415 .31873 L
F
0 1 .846 r
.2086 .35311 m
.19616 .33298 L
.13786 .28551 L
.14609 .30289 L
F
0 1 .286 r
.19616 .33298 m
.18399 .31149 L
.12981 .2671 L
.13786 .28551 L
F
.282 1 0 r
.18399 .31149 m
.17262 .28944 L
.12228 .24838 L
.12981 .2671 L
F
.834 1 0 r
.17262 .28944 m
.16255 .26792 L
.11562 .23025 L
.12228 .24838 L
F
1 .662 0 r
.16255 .26792 m
.15423 .24832 L
.11011 .21386 L
.11562 .23025 L
F
1 .243 0 r
.15423 .24832 m
.148 .23233 L
.10599 .20058 L
.11011 .21386 L
F
1 0 .055 r
.148 .23233 m
.14416 .22175 L
.10345 .19184 L
.10599 .20058 L
F
1 0 .2 r
.14416 .22175 m
.14286 .21804 L
.10259 .18878 L
.10345 .19184 L
F
1 0 .174 r
.14286 .21804 m
.14416 .22175 L
.10345 .19184 L
.10259 .18878 L
F
1 .019 0 r
.14416 .22175 m
.148 .23233 L
.10599 .20058 L
.10345 .19184 L
F
1 .357 0 r
.148 .23233 m
.15423 .24832 L
.11011 .21386 L
.10599 .20058 L
F
1 .806 0 r
.15423 .24832 m
.16255 .26792 L
.11562 .23025 L
.11011 .21386 L
F
.672 1 0 r
.16255 .26792 m
.17262 .28944 L
.12228 .24838 L
.11562 .23025 L
F
.112 1 0 r
.17262 .28944 m
.18399 .31149 L
.12981 .2671 L
.12228 .24838 L
F
0 1 .457 r
.18399 .31149 m
.19616 .33298 L
.13786 .28551 L
.12981 .2671 L
F
0 .99 1 r
.19616 .33298 m
.2086 .35311 L
.14609 .30289 L
.13786 .28551 L
F
0 .472 1 r
.2086 .35311 m
.22077 .37129 L
.15415 .31873 L
.14609 .30289 L
F
0 .005 1 r
.22077 .37129 m
.23214 .38712 L
.16167 .33264 L
.15415 .31873 L
F
.399 0 1 r
.23214 .38712 m
.24221 .40033 L
.16833 .34433 L
.16167 .33264 L
F
.729 0 1 r
.24221 .40033 m
.25054 .41073 L
.17384 .3536 L
.16833 .34433 L
F
.98 0 1 r
.25054 .41073 m
.25676 .41821 L
.17796 .3603 L
.17384 .3536 L
F
1 0 .855 r
.25676 .41821 m
.2606 .42273 L
.18051 .36436 L
.17796 .3603 L
F
1 0 .778 r
.2606 .42273 m
.2619 .42423 L
.18137 .36572 L
.18051 .36436 L
F
0 .665 1 r
.18137 .36572 m
.18051 .36436 L
.11426 .29063 L
.11475 .29174 L
F
0 .744 1 r
.18051 .36436 m
.17796 .3603 L
.11279 .28732 L
.11426 .29063 L
F
0 .89 1 r
.17796 .3603 m
.17384 .3536 L
.11041 .28186 L
.11279 .28732 L
F
0 1 .901 r
.17384 .3536 m
.16833 .34433 L
.10723 .27434 L
.11041 .28186 L
F
0 1 .633 r
.16833 .34433 m
.16167 .33264 L
.10339 .2649 L
.10723 .27434 L
F
0 1 .313 r
.16167 .33264 m
.15415 .31873 L
.09904 .25373 L
.10339 .2649 L
F
.051 1 0 r
.15415 .31873 m
.14609 .30289 L
.09439 .24107 L
.09904 .25373 L
F
.446 1 0 r
.14609 .30289 m
.13786 .28551 L
.08964 .22726 L
.09439 .24107 L
F
.861 1 0 r
.13786 .28551 m
.12981 .2671 L
.08499 .21272 L
.08964 .22726 L
F
1 .721 0 r
.12981 .2671 m
.12228 .24838 L
.08065 .19802 L
.08499 .21272 L
F
1 .321 0 r
.12228 .24838 m
.11562 .23025 L
.0768 .18386 L
.08065 .19802 L
F
1 0 .04 r
.11562 .23025 m
.11011 .21386 L
.07362 .17114 L
.0768 .18386 L
F
1 0 .337 r
.11011 .21386 m
.10599 .20058 L
.07125 .16087 L
.07362 .17114 L
F
1 0 .545 r
.10599 .20058 m
.10345 .19184 L
.06978 .15414 L
.07125 .16087 L
F
1 0 .646 r
.10345 .19184 m
.10259 .18878 L
.06928 .15179 L
.06978 .15414 L
F
1 0 .628 r
.10259 .18878 m
.10345 .19184 L
.06978 .15414 L
.06928 .15179 L
F
1 0 .495 r
.10345 .19184 m
.10599 .20058 L
.07125 .16087 L
.06978 .15414 L
F
1 0 .259 r
.10599 .20058 m
.11011 .21386 L
.07362 .17114 L
.07125 .16087 L
F
1 .059 0 r
.11011 .21386 m
.11562 .23025 L
.0768 .18386 L
.07362 .17114 L
F
1 .434 0 r
.11562 .23025 m
.12228 .24838 L
.08065 .19802 L
.0768 .18386 L
F
1 .842 0 r
.12228 .24838 m
.12981 .2671 L
.08499 .21272 L
.08065 .19802 L
F
.74 1 0 r
.12981 .2671 m
.13786 .28551 L
.08964 .22726 L
.08499 .21272 L
F
.329 1 0 r
.13786 .28551 m
.14609 .30289 L
.09439 .24107 L
.08964 .22726 L
F
0 1 .059 r
.14609 .30289 m
.15415 .31873 L
.09904 .25373 L
.09439 .24107 L
F
0 1 .411 r
.15415 .31873 m
.16167 .33264 L
.10339 .2649 L
.09904 .25373 L
F
0 1 .717 r
.16167 .33264 m
.16833 .34433 L
.10723 .27434 L
.10339 .2649 L
F
0 1 .968 r
.16833 .34433 m
.17384 .3536 L
.11041 .28186 L
.10723 .27434 L
F
0 .84 1 r
.17384 .3536 m
.17796 .3603 L
.11279 .28732 L
.11041 .28186 L
F
0 .714 1 r
.17796 .3603 m
.18051 .36436 L
.11426 .29063 L
.11279 .28732 L
F
0 .655 1 r
.18051 .36436 m
.18137 .36572 L
.11475 .29174 L
.11426 .29063 L
F
0 .665 1 r
.18137 .36572 m
.18051 .36436 L
.11426 .29063 L
.11475 .29174 L
F
0 .744 1 r
.18051 .36436 m
.17796 .3603 L
.11279 .28732 L
.11426 .29063 L
F
0 .89 1 r
.17796 .3603 m
.17384 .3536 L
.11041 .28186 L
.11279 .28732 L
F
0 1 .901 r
.17384 .3536 m
.16833 .34433 L
.10723 .27434 L
.11041 .28186 L
F
0 1 .633 r
.16833 .34433 m
.16167 .33264 L
.10339 .2649 L
.10723 .27434 L
F
0 1 .313 r
.16167 .33264 m
.15415 .31873 L
.09904 .25373 L
.10339 .2649 L
F
.051 1 0 r
.15415 .31873 m
.14609 .30289 L
.09439 .24107 L
.09904 .25373 L
F
.446 1 0 r
.14609 .30289 m
.13786 .28551 L
.08964 .22726 L
.09439 .24107 L
F
.861 1 0 r
.13786 .28551 m
.12981 .2671 L
.08499 .21272 L
.08964 .22726 L
F
1 .721 0 r
.12981 .2671 m
.12228 .24838 L
.08065 .19802 L
.08499 .21272 L
F
1 .321 0 r
.12228 .24838 m
.11562 .23025 L
.0768 .18386 L
.08065 .19802 L
F
1 0 .04 r
.11562 .23025 m
.11011 .21386 L
.07362 .17114 L
.0768 .18386 L
F
1 0 .337 r
.11011 .21386 m
.10599 .20058 L
.07125 .16087 L
.07362 .17114 L
F
1 0 .545 r
.10599 .20058 m
.10345 .19184 L
.06978 .15414 L
.07125 .16087 L
F
1 0 .646 r
.10345 .19184 m
.10259 .18878 L
.06928 .15179 L
.06978 .15414 L
F
1 0 .628 r
.10259 .18878 m
.10345 .19184 L
.06978 .15414 L
.06928 .15179 L
F
1 0 .495 r
.10345 .19184 m
.10599 .20058 L
.07125 .16087 L
.06978 .15414 L
F
1 0 .259 r
.10599 .20058 m
.11011 .21386 L
.07362 .17114 L
.07125 .16087 L
F
1 .059 0 r
.11011 .21386 m
.11562 .23025 L
.0768 .18386 L
.07362 .17114 L
F
1 .434 0 r
.11562 .23025 m
.12228 .24838 L
.08065 .19802 L
.0768 .18386 L
F
1 .842 0 r
.12228 .24838 m
.12981 .2671 L
.08499 .21272 L
.08065 .19802 L
F
.74 1 0 r
.12981 .2671 m
.13786 .28551 L
.08964 .22726 L
.08499 .21272 L
F
.329 1 0 r
.13786 .28551 m
.14609 .30289 L
.09439 .24107 L
.08964 .22726 L
F
0 1 .059 r
.14609 .30289 m
.15415 .31873 L
.09904 .25373 L
.09439 .24107 L
F
0 1 .411 r
.15415 .31873 m
.16167 .33264 L
.10339 .2649 L
.09904 .25373 L
F
0 1 .717 r
.16167 .33264 m
.16833 .34433 L
.10723 .27434 L
.10339 .2649 L
F
0 1 .968 r
.16833 .34433 m
.17384 .3536 L
.11041 .28186 L
.10723 .27434 L
F
0 .84 1 r
.17384 .3536 m
.17796 .3603 L
.11279 .28732 L
.11041 .28186 L
F
0 .714 1 r
.17796 .3603 m
.18051 .36436 L
.11426 .29063 L
.11279 .28732 L
F
0 .655 1 r
.18051 .36436 m
.18137 .36572 L
.11475 .29174 L
.11426 .29063 L
F
.503 1 0 r
.11475 .29174 m
.11426 .29063 L
.06475 .20474 L
.06498 .20552 L
F
.556 1 0 r
.11426 .29063 m
.11279 .28732 L
.06409 .2024 L
.06475 .20474 L
F
.653 1 0 r
.11279 .28732 m
.11041 .28186 L
.06301 .19856 L
.06409 .2024 L
F
.792 1 0 r
.11041 .28186 m
.10723 .27434 L
.06157 .19327 L
.06301 .19856 L
F
.97 1 0 r
.10723 .27434 m
.10339 .2649 L
.05983 .18665 L
.06157 .19327 L
F
1 .819 0 r
.10339 .2649 m
.09904 .25373 L
.05787 .17884 L
.05983 .18665 L
F
1 .582 0 r
.09904 .25373 m
.09439 .24107 L
.05576 .17002 L
.05787 .17884 L
F
1 .325 0 r
.09439 .24107 m
.08964 .22726 L
.05361 .16043 L
.05576 .17002 L
F
1 .06 0 r
.08964 .22726 m
.08499 .21272 L
.05151 .15038 L
.05361 .16043 L
F
1 0 .204 r
.08499 .21272 m
.08065 .19802 L
.04954 .14026 L
.05151 .15038 L
F
1 0 .452 r
.08065 .19802 m
.0768 .18386 L
.0478 .13055 L
.04954 .14026 L
F
1 0 .672 r
.0768 .18386 m
.07362 .17114 L
.04636 .12185 L
.0478 .13055 L
F
1 0 .85 r
.07362 .17114 m
.07125 .16087 L
.04528 .11485 L
.04636 .12185 L
F
1 0 .973 r
.07125 .16087 m
.06978 .15414 L
.04462 .11028 L
.04528 .11485 L
F
.968 0 1 r
.06978 .15414 m
.06928 .15179 L
.04439 .10868 L
.04462 .11028 L
F
.977 0 1 r
.06928 .15179 m
.06978 .15414 L
.04462 .11028 L
.04439 .10868 L
F
1 0 .946 r
.06978 .15414 m
.07125 .16087 L
.04528 .11485 L
.04462 .11028 L
F
1 0 .807 r
.07125 .16087 m
.07362 .17114 L
.04636 .12185 L
.04528 .11485 L
F
1 0 .616 r
.07362 .17114 m
.0768 .18386 L
.0478 .13055 L
.04636 .12185 L
F
1 0 .387 r
.0768 .18386 m
.08065 .19802 L
.04954 .14026 L
.0478 .13055 L
F
1 0 .133 r
.08065 .19802 m
.08499 .21272 L
.05151 .15038 L
.04954 .14026 L
F
1 .132 0 r
.08499 .21272 m
.08964 .22726 L
.05361 .16043 L
.05151 .15038 L
F
1 .396 0 r
.08964 .22726 m
.09439 .24107 L
.05576 .17002 L
.05361 .16043 L
F
1 .649 0 r
.09439 .24107 m
.09904 .25373 L
.05787 .17884 L
.05576 .17002 L
F
1 .88 0 r
.09904 .25373 m
.10339 .2649 L
.05983 .18665 L
.05787 .17884 L
F
.918 1 0 r
.10339 .2649 m
.10723 .27434 L
.06157 .19327 L
.05983 .18665 L
F
.75 1 0 r
.10723 .27434 m
.11041 .28186 L
.06301 .19856 L
.06157 .19327 L
F
.622 1 0 r
.11041 .28186 m
.11279 .28732 L
.06409 .2024 L
.06301 .19856 L
F
.537 1 0 r
.11279 .28732 m
.11426 .29063 L
.06475 .20474 L
.06409 .2024 L
F
.497 1 0 r
.11426 .29063 m
.11475 .29174 L
.06498 .20552 L
.06475 .20474 L
F
.503 1 0 r
.11475 .29174 m
.11426 .29063 L
.06475 .20474 L
.06498 .20552 L
F
.556 1 0 r
.11426 .29063 m
.11279 .28732 L
.06409 .2024 L
.06475 .20474 L
F
.653 1 0 r
.11279 .28732 m
.11041 .28186 L
.06301 .19856 L
.06409 .2024 L
F
.792 1 0 r
.11041 .28186 m
.10723 .27434 L
.06157 .19327 L
.06301 .19856 L
F
.97 1 0 r
.10723 .27434 m
.10339 .2649 L
.05983 .18665 L
.06157 .19327 L
F
1 .819 0 r
.10339 .2649 m
.09904 .25373 L
.05787 .17884 L
.05983 .18665 L
F
1 .582 0 r
.09904 .25373 m
.09439 .24107 L
.05576 .17002 L
.05787 .17884 L
F
1 .325 0 r
.09439 .24107 m
.08964 .22726 L
.05361 .16043 L
.05576 .17002 L
F
1 .06 0 r
.08964 .22726 m
.08499 .21272 L
.05151 .15038 L
.05361 .16043 L
F
1 0 .204 r
.08499 .21272 m
.08065 .19802 L
.04954 .14026 L
.05151 .15038 L
F
1 0 .452 r
.08065 .19802 m
.0768 .18386 L
.0478 .13055 L
.04954 .14026 L
F
1 0 .672 r
.0768 .18386 m
.07362 .17114 L
.04636 .12185 L
.0478 .13055 L
F
1 0 .85 r
.07362 .17114 m
.07125 .16087 L
.04528 .11485 L
.04636 .12185 L
F
1 0 .973 r
.07125 .16087 m
.06978 .15414 L
.04462 .11028 L
.04528 .11485 L
F
.968 0 1 r
.06978 .15414 m
.06928 .15179 L
.04439 .10868 L
.04462 .11028 L
F
.977 0 1 r
.06928 .15179 m
.06978 .15414 L
.04462 .11028 L
.04439 .10868 L
F
1 0 .946 r
.06978 .15414 m
.07125 .16087 L
.04528 .11485 L
.04462 .11028 L
F
1 0 .807 r
.07125 .16087 m
.07362 .17114 L
.04636 .12185 L
.04528 .11485 L
F
1 0 .616 r
.07362 .17114 m
.0768 .18386 L
.0478 .13055 L
.04636 .12185 L
F
1 0 .387 r
.0768 .18386 m
.08065 .19802 L
.04954 .14026 L
.0478 .13055 L
F
1 0 .133 r
.08065 .19802 m
.08499 .21272 L
.05151 .15038 L
.04954 .14026 L
F
1 .132 0 r
.08499 .21272 m
.08964 .22726 L
.05361 .16043 L
.05151 .15038 L
F
1 .396 0 r
.08964 .22726 m
.09439 .24107 L
.05576 .17002 L
.05361 .16043 L
F
1 .649 0 r
.09439 .24107 m
.09904 .25373 L
.05787 .17884 L
.05576 .17002 L
F
1 .88 0 r
.09904 .25373 m
.10339 .2649 L
.05983 .18665 L
.05787 .17884 L
F
.918 1 0 r
.10339 .2649 m
.10723 .27434 L
.06157 .19327 L
.05983 .18665 L
F
.75 1 0 r
.10723 .27434 m
.11041 .28186 L
.06301 .19856 L
.06157 .19327 L
F
.622 1 0 r
.11041 .28186 m
.11279 .28732 L
.06409 .2024 L
.06301 .19856 L
F
.537 1 0 r
.11279 .28732 m
.11426 .29063 L
.06475 .20474 L
.06409 .2024 L
F
.497 1 0 r
.11426 .29063 m
.11475 .29174 L
.06498 .20552 L
.06475 .20474 L
F
1 0 .154 r
.06498 .20552 m
.06475 .20474 L
.03416 .11044 L
.03422 .11085 L
F
1 0 .18 r
.06475 .20474 m
.06409 .2024 L
.03399 .10923 L
.03416 .11044 L
F
1 0 .228 r
.06409 .2024 m
.06301 .19856 L
.03372 .10725 L
.03399 .10923 L
F
1 0 .297 r
.06301 .19856 m
.06157 .19327 L
.03335 .10452 L
.03372 .10725 L
F
1 0 .384 r
.06157 .19327 m
.05983 .18665 L
.03291 .10111 L
.03335 .10452 L
F
1 0 .487 r
.05983 .18665 m
.05787 .17884 L
.03242 .09709 L
.03291 .10111 L
F
1 0 .601 r
.05787 .17884 m
.05576 .17002 L
.03189 .09257 L
.03242 .09709 L
F
1 0 .722 r
.05576 .17002 m
.05361 .16043 L
.03134 .08766 L
.03189 .09257 L
F
1 0 .845 r
.05361 .16043 m
.05151 .15038 L
.03081 .08253 L
.03134 .08766 L
F
1 0 .966 r
.05151 .15038 m
.04954 .14026 L
.03031 .07736 L
.03081 .08253 L
F
.923 0 1 r
.04954 .14026 m
.0478 .13055 L
.02987 .07242 L
.03031 .07736 L
F
.827 0 1 r
.0478 .13055 m
.04636 .12185 L
.02951 .06801 L
.02987 .07242 L
F
.75 0 1 r
.04636 .12185 m
.04528 .11485 L
.02924 .06446 L
.02951 .06801 L
F
.698 0 1 r
.04528 .11485 m
.04462 .11028 L
.02907 .06215 L
.02924 .06446 L
F
.672 0 1 r
.04462 .11028 m
.04439 .10868 L
.02901 .06134 L
.02907 .06215 L
F
.676 0 1 r
.04439 .10868 m
.04462 .11028 L
.02907 .06215 L
.02901 .06134 L
F
.707 0 1 r
.04462 .11028 m
.04528 .11485 L
.02924 .06446 L
.02907 .06215 L
F
.766 0 1 r
.04528 .11485 m
.04636 .12185 L
.02951 .06801 L
.02924 .06446 L
F
.847 0 1 r
.04636 .12185 m
.0478 .13055 L
.02987 .07242 L
.02951 .06801 L
F
.948 0 1 r
.0478 .13055 m
.04954 .14026 L
.03031 .07736 L
.02987 .07242 L
F
1 0 .939 r
.04954 .14026 m
.05151 .15038 L
.03081 .08253 L
.03031 .07736 L
F
1 0 .817 r
.05151 .15038 m
.05361 .16043 L
.03134 .08766 L
.03081 .08253 L
F
1 0 .694 r
.05361 .16043 m
.05576 .17002 L
.03189 .09257 L
.03134 .08766 L
F
1 0 .574 r
.05576 .17002 m
.05787 .17884 L
.03242 .09709 L
.03189 .09257 L
F
1 0 .462 r
.05787 .17884 m
.05983 .18665 L
.03291 .10111 L
.03242 .09709 L
F
1 0 .363 r
.05983 .18665 m
.06157 .19327 L
.03335 .10452 L
.03291 .10111 L
F
1 0 .279 r
.06157 .19327 m
.06301 .19856 L
.03372 .10725 L
.03335 .10452 L
F
1 0 .215 r
.06301 .19856 m
.06409 .2024 L
.03399 .10923 L
.03372 .10725 L
F
1 0 .172 r
.06409 .2024 m
.06475 .20474 L
.03416 .11044 L
.03399 .10923 L
F
1 0 .152 r
.06475 .20474 m
.06498 .20552 L
.03422 .11085 L
.03416 .11044 L
F
1 0 .154 r
.06498 .20552 m
.06475 .20474 L
.03416 .11044 L
.03422 .11085 L
F
1 0 .18 r
.06475 .20474 m
.06409 .2024 L
.03399 .10923 L
.03416 .11044 L
F
1 0 .228 r
.06409 .2024 m
.06301 .19856 L
.03372 .10725 L
.03399 .10923 L
F
1 0 .297 r
.06301 .19856 m
.06157 .19327 L
.03335 .10452 L
.03372 .10725 L
F
1 0 .384 r
.06157 .19327 m
.05983 .18665 L
.03291 .10111 L
.03335 .10452 L
F
1 0 .487 r
.05983 .18665 m
.05787 .17884 L
.03242 .09709 L
.03291 .10111 L
F
1 0 .601 r
.05787 .17884 m
.05576 .17002 L
.03189 .09257 L
.03242 .09709 L
F
1 0 .722 r
.05576 .17002 m
.05361 .16043 L
.03134 .08766 L
.03189 .09257 L
F
1 0 .845 r
.05361 .16043 m
.05151 .15038 L
.03081 .08253 L
.03134 .08766 L
F
1 0 .966 r
.05151 .15038 m
.04954 .14026 L
.03031 .07736 L
.03081 .08253 L
F
.923 0 1 r
.04954 .14026 m
.0478 .13055 L
.02987 .07242 L
.03031 .07736 L
F
.827 0 1 r
.0478 .13055 m
.04636 .12185 L
.02951 .06801 L
.02987 .07242 L
F
.75 0 1 r
.04636 .12185 m
.04528 .11485 L
.02924 .06446 L
.02951 .06801 L
F
.698 0 1 r
.04528 .11485 m
.04462 .11028 L
.02907 .06215 L
.02924 .06446 L
F
.672 0 1 r
.04462 .11028 m
.04439 .10868 L
.02901 .06134 L
.02907 .06215 L
F
.676 0 1 r
.04439 .10868 m
.04462 .11028 L
.02907 .06215 L
.02901 .06134 L
F
.707 0 1 r
.04462 .11028 m
.04528 .11485 L
.02924 .06446 L
.02907 .06215 L
F
.766 0 1 r
.04528 .11485 m
.04636 .12185 L
.02951 .06801 L
.02924 .06446 L
F
.847 0 1 r
.04636 .12185 m
.0478 .13055 L
.02987 .07242 L
.02951 .06801 L
F
.948 0 1 r
.0478 .13055 m
.04954 .14026 L
.03031 .07736 L
.02987 .07242 L
F
1 0 .939 r
.04954 .14026 m
.05151 .15038 L
.03081 .08253 L
.03031 .07736 L
F
1 0 .817 r
.05151 .15038 m
.05361 .16043 L
.03134 .08766 L
.03081 .08253 L
F
1 0 .694 r
.05361 .16043 m
.05576 .17002 L
.03189 .09257 L
.03134 .08766 L
F
1 0 .574 r
.05576 .17002 m
.05787 .17884 L
.03242 .09709 L
.03189 .09257 L
F
1 0 .462 r
.05787 .17884 m
.05983 .18665 L
.03291 .10111 L
.03242 .09709 L
F
1 0 .363 r
.05983 .18665 m
.06157 .19327 L
.03335 .10452 L
.03291 .10111 L
F
1 0 .279 r
.06157 .19327 m
.06301 .19856 L
.03372 .10725 L
.03335 .10452 L
F
1 0 .215 r
.06301 .19856 m
.06409 .2024 L
.03399 .10923 L
.03372 .10725 L
F
1 0 .172 r
.06409 .2024 m
.06475 .20474 L
.03416 .11044 L
.03399 .10923 L
F
1 0 .152 r
.06475 .20474 m
.06498 .20552 L
.03422 .11085 L
.03416 .11044 L
F
.692 0 1 r
.03422 .11085 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
F
.687 0 1 r
.03416 .11044 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
F
.679 0 1 r
.03399 .10923 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
F
.668 0 1 r
.03372 .10725 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
F
.653 0 1 r
.03335 .10452 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
F
.636 0 1 r
.03291 .10111 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
F
.617 0 1 r
.03242 .09709 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
F
.597 0 1 r
.03189 .09257 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
F
.577 0 1 r
.03134 .08766 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
F
.558 0 1 r
.03081 .08253 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
F
.54 0 1 r
.03031 .07736 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
F
.525 0 1 r
.02987 .07242 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
F
.513 0 1 r
.02951 .06801 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
F
.505 0 1 r
.02924 .06446 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
F
.501 0 1 r
.02907 .06215 m
.02901 .06134 L
.02381 .01184 L
.02381 .01184 L
F
.02901 .06134 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
F
.505 0 1 r
.02907 .06215 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
F
.513 0 1 r
.02924 .06446 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
F
.525 0 1 r
.02951 .06801 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
F
.54 0 1 r
.02987 .07242 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
F
.558 0 1 r
.03031 .07736 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
F
.577 0 1 r
.03081 .08253 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
F
.597 0 1 r
.03134 .08766 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
F
.617 0 1 r
.03189 .09257 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
F
.636 0 1 r
.03242 .09709 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
F
.653 0 1 r
.03291 .10111 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
F
.668 0 1 r
.03335 .10452 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
F
.679 0 1 r
.03372 .10725 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
F
.687 0 1 r
.03399 .10923 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
F
.692 0 1 r
.03416 .11044 m
.03422 .11085 L
.02381 .01184 L
.02381 .01184 L
F
.03422 .11085 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
F
.687 0 1 r
.03416 .11044 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
F
.679 0 1 r
.03399 .10923 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
F
.668 0 1 r
.03372 .10725 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
F
.653 0 1 r
.03335 .10452 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
F
.636 0 1 r
.03291 .10111 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
F
.617 0 1 r
.03242 .09709 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
F
.597 0 1 r
.03189 .09257 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
F
.577 0 1 r
.03134 .08766 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
F
.558 0 1 r
.03081 .08253 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
F
.54 0 1 r
.03031 .07736 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
F
.525 0 1 r
.02987 .07242 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
F
.513 0 1 r
.02951 .06801 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
F
.505 0 1 r
.02924 .06446 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
F
.501 0 1 r
.02907 .06215 m
.02901 .06134 L
.02381 .01184 L
.02381 .01184 L
F
.02901 .06134 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
F
.505 0 1 r
.02907 .06215 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
F
.513 0 1 r
.02924 .06446 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
F
.525 0 1 r
.02951 .06801 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
F
.54 0 1 r
.02987 .07242 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
F
.558 0 1 r
.03031 .07736 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
F
.577 0 1 r
.03081 .08253 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
F
.597 0 1 r
.03134 .08766 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
F
.617 0 1 r
.03189 .09257 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
F
.636 0 1 r
.03242 .09709 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
F
.653 0 1 r
.03291 .10111 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
F
.668 0 1 r
.03335 .10452 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
F
.679 0 1 r
.03372 .10725 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
F
.687 0 1 r
.03399 .10923 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
F
.692 0 1 r
.03416 .11044 m
.03422 .11085 L
.02381 .01184 L
.02381 .01184 L
F
0 g
.5 Mabswid
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03422 .11085 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03416 .11044 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03399 .10923 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03372 .10725 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03335 .10452 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03291 .10111 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03242 .09709 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03189 .09257 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03134 .08766 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.03081 .08253 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.03031 .07736 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02987 .07242 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02951 .06801 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02924 .06446 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02901 .06134 L
.02907 .06215 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02901 .06134 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02907 .06215 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02924 .06446 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.02951 .06801 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.02987 .07242 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03031 .07736 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03081 .08253 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03134 .08766 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03189 .09257 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03242 .09709 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03291 .10111 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03335 .10452 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03372 .10725 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03399 .10923 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03422 .11085 L
.03416 .11044 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03422 .11085 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03416 .11044 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03399 .10923 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03372 .10725 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03335 .10452 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03291 .10111 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03242 .09709 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03189 .09257 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03134 .08766 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.03081 .08253 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.03031 .07736 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02987 .07242 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02951 .06801 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02924 .06446 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02901 .06134 L
.02907 .06215 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02901 .06134 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02907 .06215 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02924 .06446 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.02951 .06801 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.02987 .07242 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03031 .07736 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03081 .08253 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03134 .08766 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03189 .09257 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03242 .09709 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03291 .10111 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03335 .10452 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03372 .10725 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03399 .10923 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03422 .11085 L
.03416 .11044 L
.02381 .01184 L
s
.03422 .11085 m
.03416 .11044 L
.06475 .20474 L
.06498 .20552 L
.03422 .11085 L
s
.03416 .11044 m
.03399 .10923 L
.06409 .2024 L
.06475 .20474 L
.03416 .11044 L
s
.03399 .10923 m
.03372 .10725 L
.06301 .19856 L
.06409 .2024 L
.03399 .10923 L
s
.03372 .10725 m
.03335 .10452 L
.06157 .19327 L
.06301 .19856 L
.03372 .10725 L
s
.03335 .10452 m
.03291 .10111 L
.05983 .18665 L
.06157 .19327 L
.03335 .10452 L
s
.03291 .10111 m
.03242 .09709 L
.05787 .17884 L
.05983 .18665 L
.03291 .10111 L
s
.03242 .09709 m
.03189 .09257 L
.05576 .17002 L
.05787 .17884 L
.03242 .09709 L
s
.03189 .09257 m
.03134 .08766 L
.05361 .16043 L
.05576 .17002 L
.03189 .09257 L
s
.03134 .08766 m
.03081 .08253 L
.05151 .15038 L
.05361 .16043 L
.03134 .08766 L
s
.03081 .08253 m
.03031 .07736 L
.04954 .14026 L
.05151 .15038 L
.03081 .08253 L
s
.03031 .07736 m
.02987 .07242 L
.0478 .13055 L
.04954 .14026 L
.03031 .07736 L
s
.02987 .07242 m
.02951 .06801 L
.04636 .12185 L
.0478 .13055 L
.02987 .07242 L
s
.02951 .06801 m
.02924 .06446 L
.04528 .11485 L
.04636 .12185 L
.02951 .06801 L
s
.02924 .06446 m
.02907 .06215 L
.04462 .11028 L
.04528 .11485 L
.02924 .06446 L
s
.02907 .06215 m
.02901 .06134 L
.04439 .10868 L
.04462 .11028 L
.02907 .06215 L
s
.02901 .06134 m
.02907 .06215 L
.04462 .11028 L
.04439 .10868 L
.02901 .06134 L
s
.02907 .06215 m
.02924 .06446 L
.04528 .11485 L
.04462 .11028 L
.02907 .06215 L
s
.02924 .06446 m
.02951 .06801 L
.04636 .12185 L
.04528 .11485 L
.02924 .06446 L
s
.02951 .06801 m
.02987 .07242 L
.0478 .13055 L
.04636 .12185 L
.02951 .06801 L
s
.02987 .07242 m
.03031 .07736 L
.04954 .14026 L
.0478 .13055 L
.02987 .07242 L
s
.03031 .07736 m
.03081 .08253 L
.05151 .15038 L
.04954 .14026 L
.03031 .07736 L
s
.03081 .08253 m
.03134 .08766 L
.05361 .16043 L
.05151 .15038 L
.03081 .08253 L
s
.03134 .08766 m
.03189 .09257 L
.05576 .17002 L
.05361 .16043 L
.03134 .08766 L
s
.03189 .09257 m
.03242 .09709 L
.05787 .17884 L
.05576 .17002 L
.03189 .09257 L
s
.03242 .09709 m
.03291 .10111 L
.05983 .18665 L
.05787 .17884 L
.03242 .09709 L
s
.03291 .10111 m
.03335 .10452 L
.06157 .19327 L
.05983 .18665 L
.03291 .10111 L
s
.03335 .10452 m
.03372 .10725 L
.06301 .19856 L
.06157 .19327 L
.03335 .10452 L
s
.03372 .10725 m
.03399 .10923 L
.06409 .2024 L
.06301 .19856 L
.03372 .10725 L
s
.03399 .10923 m
.03416 .11044 L
.06475 .20474 L
.06409 .2024 L
.03399 .10923 L
s
.03416 .11044 m
.03422 .11085 L
.06498 .20552 L
.06475 .20474 L
.03416 .11044 L
s
.03422 .11085 m
.03416 .11044 L
.06475 .20474 L
.06498 .20552 L
.03422 .11085 L
s
.03416 .11044 m
.03399 .10923 L
.06409 .2024 L
.06475 .20474 L
.03416 .11044 L
s
.03399 .10923 m
.03372 .10725 L
.06301 .19856 L
.06409 .2024 L
.03399 .10923 L
s
.03372 .10725 m
.03335 .10452 L
.06157 .19327 L
.06301 .19856 L
.03372 .10725 L
s
.03335 .10452 m
.03291 .10111 L
.05983 .18665 L
.06157 .19327 L
.03335 .10452 L
s
.03291 .10111 m
.03242 .09709 L
.05787 .17884 L
.05983 .18665 L
.03291 .10111 L
s
.03242 .09709 m
.03189 .09257 L
.05576 .17002 L
.05787 .17884 L
.03242 .09709 L
s
.03189 .09257 m
.03134 .08766 L
.05361 .16043 L
.05576 .17002 L
.03189 .09257 L
s
.03134 .08766 m
.03081 .08253 L
.05151 .15038 L
.05361 .16043 L
.03134 .08766 L
s
.03081 .08253 m
.03031 .07736 L
.04954 .14026 L
.05151 .15038 L
.03081 .08253 L
s
.03031 .07736 m
.02987 .07242 L
.0478 .13055 L
.04954 .14026 L
.03031 .07736 L
s
.02987 .07242 m
.02951 .06801 L
.04636 .12185 L
.0478 .13055 L
.02987 .07242 L
s
.02951 .06801 m
.02924 .06446 L
.04528 .11485 L
.04636 .12185 L
.02951 .06801 L
s
.02924 .06446 m
.02907 .06215 L
.04462 .11028 L
.04528 .11485 L
.02924 .06446 L
s
.02907 .06215 m
.02901 .06134 L
.04439 .10868 L
.04462 .11028 L
.02907 .06215 L
s
.02901 .06134 m
.02907 .06215 L
.04462 .11028 L
.04439 .10868 L
.02901 .06134 L
s
.02907 .06215 m
.02924 .06446 L
.04528 .11485 L
.04462 .11028 L
.02907 .06215 L
s
.02924 .06446 m
.02951 .06801 L
.04636 .12185 L
.04528 .11485 L
.02924 .06446 L
s
.02951 .06801 m
.02987 .07242 L
.0478 .13055 L
.04636 .12185 L
.02951 .06801 L
s
.02987 .07242 m
.03031 .07736 L
.04954 .14026 L
.0478 .13055 L
.02987 .07242 L
s
.03031 .07736 m
.03081 .08253 L
.05151 .15038 L
.04954 .14026 L
.03031 .07736 L
s
.03081 .08253 m
.03134 .08766 L
.05361 .16043 L
.05151 .15038 L
.03081 .08253 L
s
.03134 .08766 m
.03189 .09257 L
.05576 .17002 L
.05361 .16043 L
.03134 .08766 L
s
.03189 .09257 m
.03242 .09709 L
.05787 .17884 L
.05576 .17002 L
.03189 .09257 L
s
.03242 .09709 m
.03291 .10111 L
.05983 .18665 L
.05787 .17884 L
.03242 .09709 L
s
.03291 .10111 m
.03335 .10452 L
.06157 .19327 L
.05983 .18665 L
.03291 .10111 L
s
.03335 .10452 m
.03372 .10725 L
.06301 .19856 L
.06157 .19327 L
.03335 .10452 L
s
.03372 .10725 m
.03399 .10923 L
.06409 .2024 L
.06301 .19856 L
.03372 .10725 L
s
.03399 .10923 m
.03416 .11044 L
.06475 .20474 L
.06409 .2024 L
.03399 .10923 L
s
.03416 .11044 m
.03422 .11085 L
.06498 .20552 L
.06475 .20474 L
.03416 .11044 L
s
.06498 .20552 m
.06475 .20474 L
.11426 .29063 L
.11475 .29174 L
.06498 .20552 L
s
.06475 .20474 m
.06409 .2024 L
.11279 .28732 L
.11426 .29063 L
.06475 .20474 L
s
.06409 .2024 m
.06301 .19856 L
.11041 .28186 L
.11279 .28732 L
.06409 .2024 L
s
.06301 .19856 m
.06157 .19327 L
.10723 .27434 L
.11041 .28186 L
.06301 .19856 L
s
.06157 .19327 m
.05983 .18665 L
.10339 .2649 L
.10723 .27434 L
.06157 .19327 L
s
.05983 .18665 m
.05787 .17884 L
.09904 .25373 L
.10339 .2649 L
.05983 .18665 L
s
.05787 .17884 m
.05576 .17002 L
.09439 .24107 L
.09904 .25373 L
.05787 .17884 L
s
.05576 .17002 m
.05361 .16043 L
.08964 .22726 L
.09439 .24107 L
.05576 .17002 L
s
.05361 .16043 m
.05151 .15038 L
.08499 .21272 L
.08964 .22726 L
.05361 .16043 L
s
.05151 .15038 m
.04954 .14026 L
.08065 .19802 L
.08499 .21272 L
.05151 .15038 L
s
.04954 .14026 m
.0478 .13055 L
.0768 .18386 L
.08065 .19802 L
.04954 .14026 L
s
.0478 .13055 m
.04636 .12185 L
.07362 .17114 L
.0768 .18386 L
.0478 .13055 L
s
.04636 .12185 m
.04528 .11485 L
.07125 .16087 L
.07362 .17114 L
.04636 .12185 L
s
.04528 .11485 m
.04462 .11028 L
.06978 .15414 L
.07125 .16087 L
.04528 .11485 L
s
.04462 .11028 m
.04439 .10868 L
.06928 .15179 L
.06978 .15414 L
.04462 .11028 L
s
.04439 .10868 m
.04462 .11028 L
.06978 .15414 L
.06928 .15179 L
.04439 .10868 L
s
.04462 .11028 m
.04528 .11485 L
.07125 .16087 L
.06978 .15414 L
.04462 .11028 L
s
.04528 .11485 m
.04636 .12185 L
.07362 .17114 L
.07125 .16087 L
.04528 .11485 L
s
.04636 .12185 m
.0478 .13055 L
.0768 .18386 L
.07362 .17114 L
.04636 .12185 L
s
.0478 .13055 m
.04954 .14026 L
.08065 .19802 L
.0768 .18386 L
.0478 .13055 L
s
.04954 .14026 m
.05151 .15038 L
.08499 .21272 L
.08065 .19802 L
.04954 .14026 L
s
.05151 .15038 m
.05361 .16043 L
.08964 .22726 L
.08499 .21272 L
.05151 .15038 L
s
.05361 .16043 m
.05576 .17002 L
.09439 .24107 L
.08964 .22726 L
.05361 .16043 L
s
.05576 .17002 m
.05787 .17884 L
.09904 .25373 L
.09439 .24107 L
.05576 .17002 L
s
.05787 .17884 m
.05983 .18665 L
.10339 .2649 L
.09904 .25373 L
.05787 .17884 L
s
.05983 .18665 m
.06157 .19327 L
.10723 .27434 L
.10339 .2649 L
.05983 .18665 L
s
.06157 .19327 m
.06301 .19856 L
.11041 .28186 L
.10723 .27434 L
.06157 .19327 L
s
.06301 .19856 m
.06409 .2024 L
.11279 .28732 L
.11041 .28186 L
.06301 .19856 L
s
.06409 .2024 m
.06475 .20474 L
.11426 .29063 L
.11279 .28732 L
.06409 .2024 L
s
.06475 .20474 m
.06498 .20552 L
.11475 .29174 L
.11426 .29063 L
.06475 .20474 L
s
.06498 .20552 m
.06475 .20474 L
.11426 .29063 L
.11475 .29174 L
.06498 .20552 L
s
.06475 .20474 m
.06409 .2024 L
.11279 .28732 L
.11426 .29063 L
.06475 .20474 L
s
.06409 .2024 m
.06301 .19856 L
.11041 .28186 L
.11279 .28732 L
.06409 .2024 L
s
.06301 .19856 m
.06157 .19327 L
.10723 .27434 L
.11041 .28186 L
.06301 .19856 L
s
.06157 .19327 m
.05983 .18665 L
.10339 .2649 L
.10723 .27434 L
.06157 .19327 L
s
.05983 .18665 m
.05787 .17884 L
.09904 .25373 L
.10339 .2649 L
.05983 .18665 L
s
.05787 .17884 m
.05576 .17002 L
.09439 .24107 L
.09904 .25373 L
.05787 .17884 L
s
.05576 .17002 m
.05361 .16043 L
.08964 .22726 L
.09439 .24107 L
.05576 .17002 L
s
.05361 .16043 m
.05151 .15038 L
.08499 .21272 L
.08964 .22726 L
.05361 .16043 L
s
.05151 .15038 m
.04954 .14026 L
.08065 .19802 L
.08499 .21272 L
.05151 .15038 L
s
.04954 .14026 m
.0478 .13055 L
.0768 .18386 L
.08065 .19802 L
.04954 .14026 L
s
.0478 .13055 m
.04636 .12185 L
.07362 .17114 L
.0768 .18386 L
.0478 .13055 L
s
.04636 .12185 m
.04528 .11485 L
.07125 .16087 L
.07362 .17114 L
.04636 .12185 L
s
.04528 .11485 m
.04462 .11028 L
.06978 .15414 L
.07125 .16087 L
.04528 .11485 L
s
.04462 .11028 m
.04439 .10868 L
.06928 .15179 L
.06978 .15414 L
.04462 .11028 L
s
.04439 .10868 m
.04462 .11028 L
.06978 .15414 L
.06928 .15179 L
.04439 .10868 L
s
.04462 .11028 m
.04528 .11485 L
.07125 .16087 L
.06978 .15414 L
.04462 .11028 L
s
.04528 .11485 m
.04636 .12185 L
.07362 .17114 L
.07125 .16087 L
.04528 .11485 L
s
.04636 .12185 m
.0478 .13055 L
.0768 .18386 L
.07362 .17114 L
.04636 .12185 L
s
.0478 .13055 m
.04954 .14026 L
.08065 .19802 L
.0768 .18386 L
.0478 .13055 L
s
.04954 .14026 m
.05151 .15038 L
.08499 .21272 L
.08065 .19802 L
.04954 .14026 L
s
.05151 .15038 m
.05361 .16043 L
.08964 .22726 L
.08499 .21272 L
.05151 .15038 L
s
.05361 .16043 m
.05576 .17002 L
.09439 .24107 L
.08964 .22726 L
.05361 .16043 L
s
.05576 .17002 m
.05787 .17884 L
.09904 .25373 L
.09439 .24107 L
.05576 .17002 L
s
.05787 .17884 m
.05983 .18665 L
.10339 .2649 L
.09904 .25373 L
.05787 .17884 L
s
.05983 .18665 m
.06157 .19327 L
.10723 .27434 L
.10339 .2649 L
.05983 .18665 L
s
.06157 .19327 m
.06301 .19856 L
.11041 .28186 L
.10723 .27434 L
.06157 .19327 L
s
.06301 .19856 m
.06409 .2024 L
.11279 .28732 L
.11041 .28186 L
.06301 .19856 L
s
.06409 .2024 m
.06475 .20474 L
.11426 .29063 L
.11279 .28732 L
.06409 .2024 L
s
.06475 .20474 m
.06498 .20552 L
.11475 .29174 L
.11426 .29063 L
.06475 .20474 L
s
.11475 .29174 m
.11426 .29063 L
.18051 .36436 L
.18137 .36572 L
.11475 .29174 L
s
.11426 .29063 m
.11279 .28732 L
.17796 .3603 L
.18051 .36436 L
.11426 .29063 L
s
.11279 .28732 m
.11041 .28186 L
.17384 .3536 L
.17796 .3603 L
.11279 .28732 L
s
.11041 .28186 m
.10723 .27434 L
.16833 .34433 L
.17384 .3536 L
.11041 .28186 L
s
.10723 .27434 m
.10339 .2649 L
.16167 .33264 L
.16833 .34433 L
.10723 .27434 L
s
.10339 .2649 m
.09904 .25373 L
.15415 .31873 L
.16167 .33264 L
.10339 .2649 L
s
.09904 .25373 m
.09439 .24107 L
.14609 .30289 L
.15415 .31873 L
.09904 .25373 L
s
.09439 .24107 m
.08964 .22726 L
.13786 .28551 L
.14609 .30289 L
.09439 .24107 L
s
.08964 .22726 m
.08499 .21272 L
.12981 .2671 L
.13786 .28551 L
.08964 .22726 L
s
.08499 .21272 m
.08065 .19802 L
.12228 .24838 L
.12981 .2671 L
.08499 .21272 L
s
.08065 .19802 m
.0768 .18386 L
.11562 .23025 L
.12228 .24838 L
.08065 .19802 L
s
.0768 .18386 m
.07362 .17114 L
.11011 .21386 L
.11562 .23025 L
.0768 .18386 L
s
.07362 .17114 m
.07125 .16087 L
.10599 .20058 L
.11011 .21386 L
.07362 .17114 L
s
.07125 .16087 m
.06978 .15414 L
.10345 .19184 L
.10599 .20058 L
.07125 .16087 L
s
.06978 .15414 m
.06928 .15179 L
.10259 .18878 L
.10345 .19184 L
.06978 .15414 L
s
.06928 .15179 m
.06978 .15414 L
.10345 .19184 L
.10259 .18878 L
.06928 .15179 L
s
.06978 .15414 m
.07125 .16087 L
.10599 .20058 L
.10345 .19184 L
.06978 .15414 L
s
.07125 .16087 m
.07362 .17114 L
.11011 .21386 L
.10599 .20058 L
.07125 .16087 L
s
.07362 .17114 m
.0768 .18386 L
.11562 .23025 L
.11011 .21386 L
.07362 .17114 L
s
.0768 .18386 m
.08065 .19802 L
.12228 .24838 L
.11562 .23025 L
.0768 .18386 L
s
.08065 .19802 m
.08499 .21272 L
.12981 .2671 L
.12228 .24838 L
.08065 .19802 L
s
.08499 .21272 m
.08964 .22726 L
.13786 .28551 L
.12981 .2671 L
.08499 .21272 L
s
.08964 .22726 m
.09439 .24107 L
.14609 .30289 L
.13786 .28551 L
.08964 .22726 L
s
.09439 .24107 m
.09904 .25373 L
.15415 .31873 L
.14609 .30289 L
.09439 .24107 L
s
.09904 .25373 m
.10339 .2649 L
.16167 .33264 L
.15415 .31873 L
.09904 .25373 L
s
.10339 .2649 m
.10723 .27434 L
.16833 .34433 L
.16167 .33264 L
.10339 .2649 L
s
.10723 .27434 m
.11041 .28186 L
.17384 .3536 L
.16833 .34433 L
.10723 .27434 L
s
.11041 .28186 m
.11279 .28732 L
.17796 .3603 L
.17384 .3536 L
.11041 .28186 L
s
.11279 .28732 m
.11426 .29063 L
.18051 .36436 L
.17796 .3603 L
.11279 .28732 L
s
.11426 .29063 m
.11475 .29174 L
.18137 .36572 L
.18051 .36436 L
.11426 .29063 L
s
.11475 .29174 m
.11426 .29063 L
.18051 .36436 L
.18137 .36572 L
.11475 .29174 L
s
.11426 .29063 m
.11279 .28732 L
.17796 .3603 L
.18051 .36436 L
.11426 .29063 L
s
.11279 .28732 m
.11041 .28186 L
.17384 .3536 L
.17796 .3603 L
.11279 .28732 L
s
.11041 .28186 m
.10723 .27434 L
.16833 .34433 L
.17384 .3536 L
.11041 .28186 L
s
.10723 .27434 m
.10339 .2649 L
.16167 .33264 L
.16833 .34433 L
.10723 .27434 L
s
.10339 .2649 m
.09904 .25373 L
.15415 .31873 L
.16167 .33264 L
.10339 .2649 L
s
.09904 .25373 m
.09439 .24107 L
.14609 .30289 L
.15415 .31873 L
.09904 .25373 L
s
.09439 .24107 m
.08964 .22726 L
.13786 .28551 L
.14609 .30289 L
.09439 .24107 L
s
.08964 .22726 m
.08499 .21272 L
.12981 .2671 L
.13786 .28551 L
.08964 .22726 L
s
.08499 .21272 m
.08065 .19802 L
.12228 .24838 L
.12981 .2671 L
.08499 .21272 L
s
.08065 .19802 m
.0768 .18386 L
.11562 .23025 L
.12228 .24838 L
.08065 .19802 L
s
.0768 .18386 m
.07362 .17114 L
.11011 .21386 L
.11562 .23025 L
.0768 .18386 L
s
.07362 .17114 m
.07125 .16087 L
.10599 .20058 L
.11011 .21386 L
.07362 .17114 L
s
.07125 .16087 m
.06978 .15414 L
.10345 .19184 L
.10599 .20058 L
.07125 .16087 L
s
.06978 .15414 m
.06928 .15179 L
.10259 .18878 L
.10345 .19184 L
.06978 .15414 L
s
.06928 .15179 m
.06978 .15414 L
.10345 .19184 L
.10259 .18878 L
.06928 .15179 L
s
.06978 .15414 m
.07125 .16087 L
.10599 .20058 L
.10345 .19184 L
.06978 .15414 L
s
.07125 .16087 m
.07362 .17114 L
.11011 .21386 L
.10599 .20058 L
.07125 .16087 L
s
.07362 .17114 m
.0768 .18386 L
.11562 .23025 L
.11011 .21386 L
.07362 .17114 L
s
.0768 .18386 m
.08065 .19802 L
.12228 .24838 L
.11562 .23025 L
.0768 .18386 L
s
.08065 .19802 m
.08499 .21272 L
.12981 .2671 L
.12228 .24838 L
.08065 .19802 L
s
.08499 .21272 m
.08964 .22726 L
.13786 .28551 L
.12981 .2671 L
.08499 .21272 L
s
.08964 .22726 m
.09439 .24107 L
.14609 .30289 L
.13786 .28551 L
.08964 .22726 L
s
.09439 .24107 m
.09904 .25373 L
.15415 .31873 L
.14609 .30289 L
.09439 .24107 L
s
.09904 .25373 m
.10339 .2649 L
.16167 .33264 L
.15415 .31873 L
.09904 .25373 L
s
.10339 .2649 m
.10723 .27434 L
.16833 .34433 L
.16167 .33264 L
.10339 .2649 L
s
.10723 .27434 m
.11041 .28186 L
.17384 .3536 L
.16833 .34433 L
.10723 .27434 L
s
.11041 .28186 m
.11279 .28732 L
.17796 .3603 L
.17384 .3536 L
.11041 .28186 L
s
.11279 .28732 m
.11426 .29063 L
.18051 .36436 L
.17796 .3603 L
.11279 .28732 L
s
.11426 .29063 m
.11475 .29174 L
.18137 .36572 L
.18051 .36436 L
.11426 .29063 L
s
.18137 .36572 m
.18051 .36436 L
.2606 .42273 L
.2619 .42423 L
.18137 .36572 L
s
.18051 .36436 m
.17796 .3603 L
.25676 .41821 L
.2606 .42273 L
.18051 .36436 L
s
.17796 .3603 m
.17384 .3536 L
.25054 .41073 L
.25676 .41821 L
.17796 .3603 L
s
.17384 .3536 m
.16833 .34433 L
.24221 .40033 L
.25054 .41073 L
.17384 .3536 L
s
.16833 .34433 m
.16167 .33264 L
.23214 .38712 L
.24221 .40033 L
.16833 .34433 L
s
.16167 .33264 m
.15415 .31873 L
.22077 .37129 L
.23214 .38712 L
.16167 .33264 L
s
.15415 .31873 m
.14609 .30289 L
.2086 .35311 L
.22077 .37129 L
.15415 .31873 L
s
.14609 .30289 m
.13786 .28551 L
.19616 .33298 L
.2086 .35311 L
.14609 .30289 L
s
.13786 .28551 m
.12981 .2671 L
.18399 .31149 L
.19616 .33298 L
.13786 .28551 L
s
.12981 .2671 m
.12228 .24838 L
.17262 .28944 L
.18399 .31149 L
.12981 .2671 L
s
.12228 .24838 m
.11562 .23025 L
.16255 .26792 L
.17262 .28944 L
.12228 .24838 L
s
.11562 .23025 m
.11011 .21386 L
.15423 .24832 L
.16255 .26792 L
.11562 .23025 L
s
.11011 .21386 m
.10599 .20058 L
.148 .23233 L
.15423 .24832 L
.11011 .21386 L
s
.10599 .20058 m
.10345 .19184 L
.14416 .22175 L
.148 .23233 L
.10599 .20058 L
s
.10345 .19184 m
.10259 .18878 L
.14286 .21804 L
.14416 .22175 L
.10345 .19184 L
s
.10259 .18878 m
.10345 .19184 L
.14416 .22175 L
.14286 .21804 L
.10259 .18878 L
s
.10345 .19184 m
.10599 .20058 L
.148 .23233 L
.14416 .22175 L
.10345 .19184 L
s
.10599 .20058 m
.11011 .21386 L
.15423 .24832 L
.148 .23233 L
.10599 .20058 L
s
.11011 .21386 m
.11562 .23025 L
.16255 .26792 L
.15423 .24832 L
.11011 .21386 L
s
.11562 .23025 m
.12228 .24838 L
.17262 .28944 L
.16255 .26792 L
.11562 .23025 L
s
.12228 .24838 m
.12981 .2671 L
.18399 .31149 L
.17262 .28944 L
.12228 .24838 L
s
.12981 .2671 m
.13786 .28551 L
.19616 .33298 L
.18399 .31149 L
.12981 .2671 L
s
.13786 .28551 m
.14609 .30289 L
.2086 .35311 L
.19616 .33298 L
.13786 .28551 L
s
.14609 .30289 m
.15415 .31873 L
.22077 .37129 L
.2086 .35311 L
.14609 .30289 L
s
.15415 .31873 m
.16167 .33264 L
.23214 .38712 L
.22077 .37129 L
.15415 .31873 L
s
.16167 .33264 m
.16833 .34433 L
.24221 .40033 L
.23214 .38712 L
.16167 .33264 L
s
.16833 .34433 m
.17384 .3536 L
.25054 .41073 L
.24221 .40033 L
.16833 .34433 L
s
.17384 .3536 m
.17796 .3603 L
.25676 .41821 L
.25054 .41073 L
.17384 .3536 L
s
.17796 .3603 m
.18051 .36436 L
.2606 .42273 L
.25676 .41821 L
.17796 .3603 L
s
.18051 .36436 m
.18137 .36572 L
.2619 .42423 L
.2606 .42273 L
.18051 .36436 L
s
.18137 .36572 m
.18051 .36436 L
.2606 .42273 L
.2619 .42423 L
.18137 .36572 L
s
.18051 .36436 m
.17796 .3603 L
.25676 .41821 L
.2606 .42273 L
.18051 .36436 L
s
.17796 .3603 m
.17384 .3536 L
.25054 .41073 L
.25676 .41821 L
.17796 .3603 L
s
.17384 .3536 m
.16833 .34433 L
.24221 .40033 L
.25054 .41073 L
.17384 .3536 L
s
.16833 .34433 m
.16167 .33264 L
.23214 .38712 L
.24221 .40033 L
.16833 .34433 L
s
.16167 .33264 m
.15415 .31873 L
.22077 .37129 L
.23214 .38712 L
.16167 .33264 L
s
.15415 .31873 m
.14609 .30289 L
.2086 .35311 L
.22077 .37129 L
.15415 .31873 L
s
.14609 .30289 m
.13786 .28551 L
.19616 .33298 L
.2086 .35311 L
.14609 .30289 L
s
.13786 .28551 m
.12981 .2671 L
.18399 .31149 L
.19616 .33298 L
.13786 .28551 L
s
.12981 .2671 m
.12228 .24838 L
.17262 .28944 L
.18399 .31149 L
.12981 .2671 L
s
.12228 .24838 m
.11562 .23025 L
.16255 .26792 L
.17262 .28944 L
.12228 .24838 L
s
.11562 .23025 m
.11011 .21386 L
.15423 .24832 L
.16255 .26792 L
.11562 .23025 L
s
.11011 .21386 m
.10599 .20058 L
.148 .23233 L
.15423 .24832 L
.11011 .21386 L
s
.10599 .20058 m
.10345 .19184 L
.14416 .22175 L
.148 .23233 L
.10599 .20058 L
s
.10345 .19184 m
.10259 .18878 L
.14286 .21804 L
.14416 .22175 L
.10345 .19184 L
s
.10259 .18878 m
.10345 .19184 L
.14416 .22175 L
.14286 .21804 L
.10259 .18878 L
s
.10345 .19184 m
.10599 .20058 L
.148 .23233 L
.14416 .22175 L
.10345 .19184 L
s
.10599 .20058 m
.11011 .21386 L
.15423 .24832 L
.148 .23233 L
.10599 .20058 L
s
.11011 .21386 m
.11562 .23025 L
.16255 .26792 L
.15423 .24832 L
.11011 .21386 L
s
.11562 .23025 m
.12228 .24838 L
.17262 .28944 L
.16255 .26792 L
.11562 .23025 L
s
.12228 .24838 m
.12981 .2671 L
.18399 .31149 L
.17262 .28944 L
.12228 .24838 L
s
.12981 .2671 m
.13786 .28551 L
.19616 .33298 L
.18399 .31149 L
.12981 .2671 L
s
.13786 .28551 m
.14609 .30289 L
.2086 .35311 L
.19616 .33298 L
.13786 .28551 L
s
.14609 .30289 m
.15415 .31873 L
.22077 .37129 L
.2086 .35311 L
.14609 .30289 L
s
.15415 .31873 m
.16167 .33264 L
.23214 .38712 L
.22077 .37129 L
.15415 .31873 L
s
.16167 .33264 m
.16833 .34433 L
.24221 .40033 L
.23214 .38712 L
.16167 .33264 L
s
.16833 .34433 m
.17384 .3536 L
.25054 .41073 L
.24221 .40033 L
.16833 .34433 L
s
.17384 .3536 m
.17796 .3603 L
.25676 .41821 L
.25054 .41073 L
.17384 .3536 L
s
.17796 .3603 m
.18051 .36436 L
.2606 .42273 L
.25676 .41821 L
.17796 .3603 L
s
.18051 .36436 m
.18137 .36572 L
.2619 .42423 L
.2606 .42273 L
.18051 .36436 L
s
.2619 .42423 m
.2606 .42273 L
.35105 .46319 L
.35285 .46472 L
.2619 .42423 L
s
.2606 .42273 m
.25676 .41821 L
.34574 .45858 L
.35105 .46319 L
.2606 .42273 L
s
.25676 .41821 m
.25054 .41073 L
.33714 .45088 L
.34574 .45858 L
.25676 .41821 L
s
.25054 .41073 m
.24221 .40033 L
.32563 .44008 L
.33714 .45088 L
.25054 .41073 L
s
.24221 .40033 m
.23214 .38712 L
.31172 .42623 L
.32563 .44008 L
.24221 .40033 L
s
.23214 .38712 m
.22077 .37129 L
.29601 .40943 L
.31172 .42623 L
.23214 .38712 L
s
.22077 .37129 m
.2086 .35311 L
.27919 .38989 L
.29601 .40943 L
.22077 .37129 L
s
.2086 .35311 m
.19616 .33298 L
.26199 .36799 L
.27919 .38989 L
.2086 .35311 L
s
.19616 .33298 m
.18399 .31149 L
.24517 .34432 L
.26199 .36799 L
.19616 .33298 L
s
.18399 .31149 m
.17262 .28944 L
.22946 .31975 L
.24517 .34432 L
.18399 .31149 L
s
.17262 .28944 m
.16255 .26792 L
.21555 .2955 L
.22946 .31975 L
.17262 .28944 L
s
.16255 .26792 m
.15423 .24832 L
.20404 .27319 L
.21555 .2955 L
.16255 .26792 L
s
.15423 .24832 m
.148 .23233 L
.19544 .25483 L
.20404 .27319 L
.15423 .24832 L
s
.148 .23233 m
.14416 .22175 L
.19013 .2426 L
.19544 .25483 L
.148 .23233 L
s
.14416 .22175 m
.14286 .21804 L
.18833 .23828 L
.19013 .2426 L
.14416 .22175 L
s
.14286 .21804 m
.14416 .22175 L
.19013 .2426 L
.18833 .23828 L
.14286 .21804 L
s
.14416 .22175 m
.148 .23233 L
.19544 .25483 L
.19013 .2426 L
.14416 .22175 L
s
.148 .23233 m
.15423 .24832 L
.20404 .27319 L
.19544 .25483 L
.148 .23233 L
s
.15423 .24832 m
.16255 .26792 L
.21555 .2955 L
.20404 .27319 L
.15423 .24832 L
s
.16255 .26792 m
.17262 .28944 L
.22946 .31975 L
.21555 .2955 L
.16255 .26792 L
s
.17262 .28944 m
.18399 .31149 L
.24517 .34432 L
.22946 .31975 L
.17262 .28944 L
s
.18399 .31149 m
.19616 .33298 L
.26199 .36799 L
.24517 .34432 L
.18399 .31149 L
s
.19616 .33298 m
.2086 .35311 L
.27919 .38989 L
.26199 .36799 L
.19616 .33298 L
s
.2086 .35311 m
.22077 .37129 L
.29601 .40943 L
.27919 .38989 L
.2086 .35311 L
s
.22077 .37129 m
.23214 .38712 L
.31172 .42623 L
.29601 .40943 L
.22077 .37129 L
s
.23214 .38712 m
.24221 .40033 L
.32563 .44008 L
.31172 .42623 L
.23214 .38712 L
s
.24221 .40033 m
.25054 .41073 L
.33714 .45088 L
.32563 .44008 L
.24221 .40033 L
s
.25054 .41073 m
.25676 .41821 L
.34574 .45858 L
.33714 .45088 L
.25054 .41073 L
s
.25676 .41821 m
.2606 .42273 L
.35105 .46319 L
.34574 .45858 L
.25676 .41821 L
s
.2606 .42273 m
.2619 .42423 L
.35285 .46472 L
.35105 .46319 L
.2606 .42273 L
s
.2619 .42423 m
.2606 .42273 L
.35105 .46319 L
.35285 .46472 L
.2619 .42423 L
s
.2606 .42273 m
.25676 .41821 L
.34574 .45858 L
.35105 .46319 L
.2606 .42273 L
s
.25676 .41821 m
.25054 .41073 L
.33714 .45088 L
.34574 .45858 L
.25676 .41821 L
s
.25054 .41073 m
.24221 .40033 L
.32563 .44008 L
.33714 .45088 L
.25054 .41073 L
s
.24221 .40033 m
.23214 .38712 L
.31172 .42623 L
.32563 .44008 L
.24221 .40033 L
s
.23214 .38712 m
.22077 .37129 L
.29601 .40943 L
.31172 .42623 L
.23214 .38712 L
s
.22077 .37129 m
.2086 .35311 L
.27919 .38989 L
.29601 .40943 L
.22077 .37129 L
s
.2086 .35311 m
.19616 .33298 L
.26199 .36799 L
.27919 .38989 L
.2086 .35311 L
s
.19616 .33298 m
.18399 .31149 L
.24517 .34432 L
.26199 .36799 L
.19616 .33298 L
s
.18399 .31149 m
.17262 .28944 L
.22946 .31975 L
.24517 .34432 L
.18399 .31149 L
s
.17262 .28944 m
.16255 .26792 L
.21555 .2955 L
.22946 .31975 L
.17262 .28944 L
s
.16255 .26792 m
.15423 .24832 L
.20404 .27319 L
.21555 .2955 L
.16255 .26792 L
s
.15423 .24832 m
.148 .23233 L
.19544 .25483 L
.20404 .27319 L
.15423 .24832 L
s
.148 .23233 m
.14416 .22175 L
.19013 .2426 L
.19544 .25483 L
.148 .23233 L
s
.14416 .22175 m
.14286 .21804 L
.18833 .23828 L
.19013 .2426 L
.14416 .22175 L
s
.14286 .21804 m
.14416 .22175 L
.19013 .2426 L
.18833 .23828 L
.14286 .21804 L
s
.14416 .22175 m
.148 .23233 L
.19544 .25483 L
.19013 .2426 L
.14416 .22175 L
s
.148 .23233 m
.15423 .24832 L
.20404 .27319 L
.19544 .25483 L
.148 .23233 L
s
.15423 .24832 m
.16255 .26792 L
.21555 .2955 L
.20404 .27319 L
.15423 .24832 L
s
.16255 .26792 m
.17262 .28944 L
.22946 .31975 L
.21555 .2955 L
.16255 .26792 L
s
.17262 .28944 m
.18399 .31149 L
.24517 .34432 L
.22946 .31975 L
.17262 .28944 L
s
.18399 .31149 m
.19616 .33298 L
.26199 .36799 L
.24517 .34432 L
.18399 .31149 L
s
.19616 .33298 m
.2086 .35311 L
.27919 .38989 L
.26199 .36799 L
.19616 .33298 L
s
.2086 .35311 m
.22077 .37129 L
.29601 .40943 L
.27919 .38989 L
.2086 .35311 L
s
.22077 .37129 m
.23214 .38712 L
.31172 .42623 L
.29601 .40943 L
.22077 .37129 L
s
.23214 .38712 m
.24221 .40033 L
.32563 .44008 L
.31172 .42623 L
.23214 .38712 L
s
.24221 .40033 m
.25054 .41073 L
.33714 .45088 L
.32563 .44008 L
.24221 .40033 L
s
.25054 .41073 m
.25676 .41821 L
.34574 .45858 L
.33714 .45088 L
.25054 .41073 L
s
.25676 .41821 m
.2606 .42273 L
.35105 .46319 L
.34574 .45858 L
.25676 .41821 L
s
.2606 .42273 m
.2619 .42423 L
.35285 .46472 L
.35105 .46319 L
.2606 .42273 L
s
.35285 .46472 m
.35105 .46319 L
.44789 .484 L
.45022 .48542 L
.35285 .46472 L
s
.35105 .46319 m
.34574 .45858 L
.44101 .47969 L
.44789 .484 L
.35105 .46319 L
s
.34574 .45858 m
.33714 .45088 L
.42987 .47243 L
.44101 .47969 L
.34574 .45858 L
s
.33714 .45088 m
.32563 .44008 L
.41495 .46209 L
.42987 .47243 L
.33714 .45088 L
s
.32563 .44008 m
.31172 .42623 L
.39692 .44859 L
.41495 .46209 L
.32563 .44008 L
s
.31172 .42623 m
.29601 .40943 L
.37656 .43189 L
.39692 .44859 L
.31172 .42623 L
s
.29601 .40943 m
.27919 .38989 L
.35476 .4121 L
.37656 .43189 L
.29601 .40943 L
s
.27919 .38989 m
.26199 .36799 L
.33248 .3895 L
.35476 .4121 L
.27919 .38989 L
s
.26199 .36799 m
.24517 .34432 L
.31068 .36463 L
.33248 .3895 L
.26199 .36799 L
s
.24517 .34432 m
.22946 .31975 L
.29032 .33841 L
.31068 .36463 L
.24517 .34432 L
s
.22946 .31975 m
.21555 .2955 L
.27229 .31213 L
.29032 .33841 L
.22946 .31975 L
s
.21555 .2955 m
.20404 .27319 L
.25738 .28763 L
.27229 .31213 L
.21555 .2955 L
s
.20404 .27319 m
.19544 .25483 L
.24623 .26722 L
.25738 .28763 L
.20404 .27319 L
s
.19544 .25483 m
.19013 .2426 L
.23935 .2535 L
.24623 .26722 L
.19544 .25483 L
s
.19013 .2426 m
.18833 .23828 L
.23702 .24863 L
.23935 .2535 L
.19013 .2426 L
s
.18833 .23828 m
.19013 .2426 L
.23935 .2535 L
.23702 .24863 L
.18833 .23828 L
s
.19013 .2426 m
.19544 .25483 L
.24623 .26722 L
.23935 .2535 L
.19013 .2426 L
s
.19544 .25483 m
.20404 .27319 L
.25738 .28763 L
.24623 .26722 L
.19544 .25483 L
s
.20404 .27319 m
.21555 .2955 L
.27229 .31213 L
.25738 .28763 L
.20404 .27319 L
s
.21555 .2955 m
.22946 .31975 L
.29032 .33841 L
.27229 .31213 L
.21555 .2955 L
s
.22946 .31975 m
.24517 .34432 L
.31068 .36463 L
.29032 .33841 L
.22946 .31975 L
s
.24517 .34432 m
.26199 .36799 L
.33248 .3895 L
.31068 .36463 L
.24517 .34432 L
s
.26199 .36799 m
.27919 .38989 L
.35476 .4121 L
.33248 .3895 L
.26199 .36799 L
s
.27919 .38989 m
.29601 .40943 L
.37656 .43189 L
.35476 .4121 L
.27919 .38989 L
s
.29601 .40943 m
.31172 .42623 L
.39692 .44859 L
.37656 .43189 L
.29601 .40943 L
s
.31172 .42623 m
.32563 .44008 L
.41495 .46209 L
.39692 .44859 L
.31172 .42623 L
s
.32563 .44008 m
.33714 .45088 L
.42987 .47243 L
.41495 .46209 L
.32563 .44008 L
s
.33714 .45088 m
.34574 .45858 L
.44101 .47969 L
.42987 .47243 L
.33714 .45088 L
s
.34574 .45858 m
.35105 .46319 L
.44789 .484 L
.44101 .47969 L
.34574 .45858 L
s
.35105 .46319 m
.35285 .46472 L
.45022 .48542 L
.44789 .484 L
.35105 .46319 L
s
.35285 .46472 m
.35105 .46319 L
.44789 .484 L
.45022 .48542 L
.35285 .46472 L
s
.35105 .46319 m
.34574 .45858 L
.44101 .47969 L
.44789 .484 L
.35105 .46319 L
s
.34574 .45858 m
.33714 .45088 L
.42987 .47243 L
.44101 .47969 L
.34574 .45858 L
s
.33714 .45088 m
.32563 .44008 L
.41495 .46209 L
.42987 .47243 L
.33714 .45088 L
s
.32563 .44008 m
.31172 .42623 L
.39692 .44859 L
.41495 .46209 L
.32563 .44008 L
s
.31172 .42623 m
.29601 .40943 L
.37656 .43189 L
.39692 .44859 L
.31172 .42623 L
s
.29601 .40943 m
.27919 .38989 L
.35476 .4121 L
.37656 .43189 L
.29601 .40943 L
s
.27919 .38989 m
.26199 .36799 L
.33248 .3895 L
.35476 .4121 L
.27919 .38989 L
s
.26199 .36799 m
.24517 .34432 L
.31068 .36463 L
.33248 .3895 L
.26199 .36799 L
s
.24517 .34432 m
.22946 .31975 L
.29032 .33841 L
.31068 .36463 L
.24517 .34432 L
s
.22946 .31975 m
.21555 .2955 L
.27229 .31213 L
.29032 .33841 L
.22946 .31975 L
s
.21555 .2955 m
.20404 .27319 L
.25738 .28763 L
.27229 .31213 L
.21555 .2955 L
s
.20404 .27319 m
.19544 .25483 L
.24623 .26722 L
.25738 .28763 L
.20404 .27319 L
s
.19544 .25483 m
.19013 .2426 L
.23935 .2535 L
.24623 .26722 L
.19544 .25483 L
s
.19013 .2426 m
.18833 .23828 L
.23702 .24863 L
.23935 .2535 L
.19013 .2426 L
s
.18833 .23828 m
.19013 .2426 L
.23935 .2535 L
.23702 .24863 L
.18833 .23828 L
s
.19013 .2426 m
.19544 .25483 L
.24623 .26722 L
.23935 .2535 L
.19013 .2426 L
s
.19544 .25483 m
.20404 .27319 L
.25738 .28763 L
.24623 .26722 L
.19544 .25483 L
s
.20404 .27319 m
.21555 .2955 L
.27229 .31213 L
.25738 .28763 L
.20404 .27319 L
s
.21555 .2955 m
.22946 .31975 L
.29032 .33841 L
.27229 .31213 L
.21555 .2955 L
s
.22946 .31975 m
.24517 .34432 L
.31068 .36463 L
.29032 .33841 L
.22946 .31975 L
s
.24517 .34432 m
.26199 .36799 L
.33248 .3895 L
.31068 .36463 L
.24517 .34432 L
s
.26199 .36799 m
.27919 .38989 L
.35476 .4121 L
.33248 .3895 L
.26199 .36799 L
s
.27919 .38989 m
.29601 .40943 L
.37656 .43189 L
.35476 .4121 L
.27919 .38989 L
s
.29601 .40943 m
.31172 .42623 L
.39692 .44859 L
.37656 .43189 L
.29601 .40943 L
s
.31172 .42623 m
.32563 .44008 L
.41495 .46209 L
.39692 .44859 L
.31172 .42623 L
s
.32563 .44008 m
.33714 .45088 L
.42987 .47243 L
.41495 .46209 L
.32563 .44008 L
s
.33714 .45088 m
.34574 .45858 L
.44101 .47969 L
.42987 .47243 L
.33714 .45088 L
s
.34574 .45858 m
.35105 .46319 L
.44789 .484 L
.44101 .47969 L
.34574 .45858 L
s
.35105 .46319 m
.35285 .46472 L
.45022 .48542 L
.44789 .484 L
.35105 .46319 L
s
.45022 .48542 m
.44789 .484 L
.5469 .48427 L
.54978 .48542 L
.45022 .48542 L
s
.44789 .484 m
.44101 .47969 L
.53841 .48074 L
.5469 .48427 L
.44789 .484 L
s
.44101 .47969 m
.42987 .47243 L
.52466 .47465 L
.53841 .48074 L
.44101 .47969 L
s
.42987 .47243 m
.41495 .46209 L
.50627 .46571 L
.52466 .47465 L
.42987 .47243 L
s
.41495 .46209 m
.39692 .44859 L
.48403 .45365 L
.50627 .46571 L
.41495 .46209 L
s
.39692 .44859 m
.37656 .43189 L
.45892 .43822 L
.48403 .45365 L
.39692 .44859 L
s
.37656 .43189 m
.35476 .4121 L
.43203 .41935 L
.45892 .43822 L
.37656 .43189 L
s
.35476 .4121 m
.33248 .3895 L
.40454 .39718 L
.43203 .41935 L
.35476 .4121 L
s
.33248 .3895 m
.31068 .36463 L
.37765 .37215 L
.40454 .39718 L
.33248 .3895 L
s
.31068 .36463 m
.29032 .33841 L
.35254 .34514 L
.37765 .37215 L
.31068 .36463 L
s
.29032 .33841 m
.27229 .31213 L
.3303 .31753 L
.35254 .34514 L
.29032 .33841 L
s
.27229 .31213 m
.25738 .28763 L
.31191 .29131 L
.3303 .31753 L
.27229 .31213 L
s
.25738 .28763 m
.24623 .26722 L
.29816 .26914 L
.31191 .29131 L
.25738 .28763 L
s
.24623 .26722 m
.23935 .2535 L
.28967 .25403 L
.29816 .26914 L
.24623 .26722 L
s
.23935 .2535 m
.23702 .24863 L
.28679 .24863 L
.28967 .25403 L
.23935 .2535 L
s
.23702 .24863 m
.23935 .2535 L
.28967 .25403 L
.28679 .24863 L
.23702 .24863 L
s
.23935 .2535 m
.24623 .26722 L
.29816 .26914 L
.28967 .25403 L
.23935 .2535 L
s
.24623 .26722 m
.25738 .28763 L
.31191 .29131 L
.29816 .26914 L
.24623 .26722 L
s
.25738 .28763 m
.27229 .31213 L
.3303 .31753 L
.31191 .29131 L
.25738 .28763 L
s
.27229 .31213 m
.29032 .33841 L
.35254 .34514 L
.3303 .31753 L
.27229 .31213 L
s
.29032 .33841 m
.31068 .36463 L
.37765 .37215 L
.35254 .34514 L
.29032 .33841 L
s
.31068 .36463 m
.33248 .3895 L
.40454 .39718 L
.37765 .37215 L
.31068 .36463 L
s
.33248 .3895 m
.35476 .4121 L
.43203 .41935 L
.40454 .39718 L
.33248 .3895 L
s
.35476 .4121 m
.37656 .43189 L
.45892 .43822 L
.43203 .41935 L
.35476 .4121 L
s
.37656 .43189 m
.39692 .44859 L
.48403 .45365 L
.45892 .43822 L
.37656 .43189 L
s
.39692 .44859 m
.41495 .46209 L
.50627 .46571 L
.48403 .45365 L
.39692 .44859 L
s
.41495 .46209 m
.42987 .47243 L
.52466 .47465 L
.50627 .46571 L
.41495 .46209 L
s
.42987 .47243 m
.44101 .47969 L
.53841 .48074 L
.52466 .47465 L
.42987 .47243 L
s
.44101 .47969 m
.44789 .484 L
.5469 .48427 L
.53841 .48074 L
.44101 .47969 L
s
.44789 .484 m
.45022 .48542 L
.54978 .48542 L
.5469 .48427 L
.44789 .484 L
s
.45022 .48542 m
.44789 .484 L
.5469 .48427 L
.54978 .48542 L
.45022 .48542 L
s
.44789 .484 m
.44101 .47969 L
.53841 .48074 L
.5469 .48427 L
.44789 .484 L
s
.44101 .47969 m
.42987 .47243 L
.52466 .47465 L
.53841 .48074 L
.44101 .47969 L
s
.42987 .47243 m
.41495 .46209 L
.50627 .46571 L
.52466 .47465 L
.42987 .47243 L
s
.41495 .46209 m
.39692 .44859 L
.48403 .45365 L
.50627 .46571 L
.41495 .46209 L
s
.39692 .44859 m
.37656 .43189 L
.45892 .43822 L
.48403 .45365 L
.39692 .44859 L
s
.37656 .43189 m
.35476 .4121 L
.43203 .41935 L
.45892 .43822 L
.37656 .43189 L
s
.35476 .4121 m
.33248 .3895 L
.40454 .39718 L
.43203 .41935 L
.35476 .4121 L
s
.33248 .3895 m
.31068 .36463 L
.37765 .37215 L
.40454 .39718 L
.33248 .3895 L
s
.31068 .36463 m
.29032 .33841 L
.35254 .34514 L
.37765 .37215 L
.31068 .36463 L
s
.29032 .33841 m
.27229 .31213 L
.3303 .31753 L
.35254 .34514 L
.29032 .33841 L
s
.27229 .31213 m
.25738 .28763 L
.31191 .29131 L
.3303 .31753 L
.27229 .31213 L
s
.25738 .28763 m
.24623 .26722 L
.29816 .26914 L
.31191 .29131 L
.25738 .28763 L
s
.24623 .26722 m
.23935 .2535 L
.28967 .25403 L
.29816 .26914 L
.24623 .26722 L
s
.23935 .2535 m
.23702 .24863 L
.28679 .24863 L
.28967 .25403 L
.23935 .2535 L
s
.23702 .24863 m
.23935 .2535 L
.28967 .25403 L
.28679 .24863 L
.23702 .24863 L
s
.23935 .2535 m
.24623 .26722 L
.29816 .26914 L
.28967 .25403 L
.23935 .2535 L
s
.24623 .26722 m
.25738 .28763 L
.31191 .29131 L
.29816 .26914 L
.24623 .26722 L
s
.25738 .28763 m
.27229 .31213 L
.3303 .31753 L
.31191 .29131 L
.25738 .28763 L
s
.27229 .31213 m
.29032 .33841 L
.35254 .34514 L
.3303 .31753 L
.27229 .31213 L
s
.29032 .33841 m
.31068 .36463 L
.37765 .37215 L
.35254 .34514 L
.29032 .33841 L
s
.31068 .36463 m
.33248 .3895 L
.40454 .39718 L
.37765 .37215 L
.31068 .36463 L
s
.33248 .3895 m
.35476 .4121 L
.43203 .41935 L
.40454 .39718 L
.33248 .3895 L
s
.35476 .4121 m
.37656 .43189 L
.45892 .43822 L
.43203 .41935 L
.35476 .4121 L
s
.37656 .43189 m
.39692 .44859 L
.48403 .45365 L
.45892 .43822 L
.37656 .43189 L
s
.39692 .44859 m
.41495 .46209 L
.50627 .46571 L
.48403 .45365 L
.39692 .44859 L
s
.41495 .46209 m
.42987 .47243 L
.52466 .47465 L
.50627 .46571 L
.41495 .46209 L
s
.42987 .47243 m
.44101 .47969 L
.53841 .48074 L
.52466 .47465 L
.42987 .47243 L
s
.44101 .47969 m
.44789 .484 L
.5469 .48427 L
.53841 .48074 L
.44101 .47969 L
s
.44789 .484 m
.45022 .48542 L
.54978 .48542 L
.5469 .48427 L
.44789 .484 L
s
.54978 .48542 m
.5469 .48427 L
.64375 .46403 L
.64715 .46472 L
.54978 .48542 L
s
.5469 .48427 m
.53841 .48074 L
.63368 .46181 L
.64375 .46403 L
.5469 .48427 L
s
.53841 .48074 m
.52466 .47465 L
.61739 .45771 L
.63368 .46181 L
.53841 .48074 L
s
.52466 .47465 m
.50627 .46571 L
.59559 .45123 L
.61739 .45771 L
.52466 .47465 L
s
.50627 .46571 m
.48403 .45365 L
.56923 .44179 L
.59559 .45123 L
.50627 .46571 L
s
.48403 .45365 m
.45892 .43822 L
.53947 .42888 L
.56923 .44179 L
.48403 .45365 L
s
.45892 .43822 m
.43203 .41935 L
.5076 .41215 L
.53947 .42888 L
.45892 .43822 L
s
.43203 .41935 m
.40454 .39718 L
.47503 .39154 L
.5076 .41215 L
.43203 .41935 L
s
.40454 .39718 m
.37765 .37215 L
.44316 .36735 L
.47503 .39154 L
.40454 .39718 L
s
.37765 .37215 m
.35254 .34514 L
.4134 .34039 L
.44316 .36735 L
.37765 .37215 L
s
.35254 .34514 m
.3303 .31753 L
.38704 .31207 L
.4134 .34039 L
.35254 .34514 L
s
.3303 .31753 m
.31191 .29131 L
.36524 .28452 L
.38704 .31207 L
.3303 .31753 L
s
.31191 .29131 m
.29816 .26914 L
.34895 .26072 L
.36524 .28452 L
.31191 .29131 L
s
.29816 .26914 m
.28967 .25403 L
.33889 .24423 L
.34895 .26072 L
.29816 .26914 L
s
.28967 .25403 m
.28679 .24863 L
.33548 .23828 L
.33889 .24423 L
.28967 .25403 L
s
.28679 .24863 m
.28967 .25403 L
.33889 .24423 L
.33548 .23828 L
.28679 .24863 L
s
.28967 .25403 m
.29816 .26914 L
.34895 .26072 L
.33889 .24423 L
.28967 .25403 L
s
.29816 .26914 m
.31191 .29131 L
.36524 .28452 L
.34895 .26072 L
.29816 .26914 L
s
.31191 .29131 m
.3303 .31753 L
.38704 .31207 L
.36524 .28452 L
.31191 .29131 L
s
.3303 .31753 m
.35254 .34514 L
.4134 .34039 L
.38704 .31207 L
.3303 .31753 L
s
.35254 .34514 m
.37765 .37215 L
.44316 .36735 L
.4134 .34039 L
.35254 .34514 L
s
.37765 .37215 m
.40454 .39718 L
.47503 .39154 L
.44316 .36735 L
.37765 .37215 L
s
.40454 .39718 m
.43203 .41935 L
.5076 .41215 L
.47503 .39154 L
.40454 .39718 L
s
.43203 .41935 m
.45892 .43822 L
.53947 .42888 L
.5076 .41215 L
.43203 .41935 L
s
.45892 .43822 m
.48403 .45365 L
.56923 .44179 L
.53947 .42888 L
.45892 .43822 L
s
.48403 .45365 m
.50627 .46571 L
.59559 .45123 L
.56923 .44179 L
.48403 .45365 L
s
.50627 .46571 m
.52466 .47465 L
.61739 .45771 L
.59559 .45123 L
.50627 .46571 L
s
.52466 .47465 m
.53841 .48074 L
.63368 .46181 L
.61739 .45771 L
.52466 .47465 L
s
.53841 .48074 m
.5469 .48427 L
.64375 .46403 L
.63368 .46181 L
.53841 .48074 L
s
.5469 .48427 m
.54978 .48542 L
.64715 .46472 L
.64375 .46403 L
.5469 .48427 L
s
.54978 .48542 m
.5469 .48427 L
.64375 .46403 L
.64715 .46472 L
.54978 .48542 L
s
.5469 .48427 m
.53841 .48074 L
.63368 .46181 L
.64375 .46403 L
.5469 .48427 L
s
.53841 .48074 m
.52466 .47465 L
.61739 .45771 L
.63368 .46181 L
.53841 .48074 L
s
.52466 .47465 m
.50627 .46571 L
.59559 .45123 L
.61739 .45771 L
.52466 .47465 L
s
.50627 .46571 m
.48403 .45365 L
.56923 .44179 L
.59559 .45123 L
.50627 .46571 L
s
.48403 .45365 m
.45892 .43822 L
.53947 .42888 L
.56923 .44179 L
.48403 .45365 L
s
.45892 .43822 m
.43203 .41935 L
.5076 .41215 L
.53947 .42888 L
.45892 .43822 L
s
.43203 .41935 m
.40454 .39718 L
.47503 .39154 L
.5076 .41215 L
.43203 .41935 L
s
.40454 .39718 m
.37765 .37215 L
.44316 .36735 L
.47503 .39154 L
.40454 .39718 L
s
.37765 .37215 m
.35254 .34514 L
.4134 .34039 L
.44316 .36735 L
.37765 .37215 L
s
.35254 .34514 m
.3303 .31753 L
.38704 .31207 L
.4134 .34039 L
.35254 .34514 L
s
.3303 .31753 m
.31191 .29131 L
.36524 .28452 L
.38704 .31207 L
.3303 .31753 L
s
.31191 .29131 m
.29816 .26914 L
.34895 .26072 L
.36524 .28452 L
.31191 .29131 L
s
.29816 .26914 m
.28967 .25403 L
.33889 .24423 L
.34895 .26072 L
.29816 .26914 L
s
.28967 .25403 m
.28679 .24863 L
.33548 .23828 L
.33889 .24423 L
.28967 .25403 L
s
.28679 .24863 m
.28967 .25403 L
.33889 .24423 L
.33548 .23828 L
.28679 .24863 L
s
.28967 .25403 m
.29816 .26914 L
.34895 .26072 L
.33889 .24423 L
.28967 .25403 L
s
.29816 .26914 m
.31191 .29131 L
.36524 .28452 L
.34895 .26072 L
.29816 .26914 L
s
.31191 .29131 m
.3303 .31753 L
.38704 .31207 L
.36524 .28452 L
.31191 .29131 L
s
.3303 .31753 m
.35254 .34514 L
.4134 .34039 L
.38704 .31207 L
.3303 .31753 L
s
.35254 .34514 m
.37765 .37215 L
.44316 .36735 L
.4134 .34039 L
.35254 .34514 L
s
.37765 .37215 m
.40454 .39718 L
.47503 .39154 L
.44316 .36735 L
.37765 .37215 L
s
.40454 .39718 m
.43203 .41935 L
.5076 .41215 L
.47503 .39154 L
.40454 .39718 L
s
.43203 .41935 m
.45892 .43822 L
.53947 .42888 L
.5076 .41215 L
.43203 .41935 L
s
.45892 .43822 m
.48403 .45365 L
.56923 .44179 L
.53947 .42888 L
.45892 .43822 L
s
.48403 .45365 m
.50627 .46571 L
.59559 .45123 L
.56923 .44179 L
.48403 .45365 L
s
.50627 .46571 m
.52466 .47465 L
.61739 .45771 L
.59559 .45123 L
.50627 .46571 L
s
.52466 .47465 m
.53841 .48074 L
.63368 .46181 L
.61739 .45771 L
.52466 .47465 L
s
.53841 .48074 m
.5469 .48427 L
.64375 .46403 L
.63368 .46181 L
.53841 .48074 L
s
.5469 .48427 m
.54978 .48542 L
.64715 .46472 L
.64375 .46403 L
.5469 .48427 L
s
.64715 .46472 m
.64375 .46403 L
.73419 .42421 L
.7381 .42423 L
.64715 .46472 L
s
.64375 .46403 m
.63368 .46181 L
.72266 .42394 L
.73419 .42421 L
.64375 .46403 L
s
.63368 .46181 m
.61739 .45771 L
.70399 .42282 L
.72266 .42394 L
.63368 .46181 L
s
.61739 .45771 m
.59559 .45123 L
.67901 .41998 L
.70399 .42282 L
.61739 .45771 L
s
.59559 .45123 m
.56923 .44179 L
.64881 .41445 L
.67901 .41998 L
.59559 .45123 L
s
.56923 .44179 m
.53947 .42888 L
.61471 .40534 L
.64881 .41445 L
.56923 .44179 L
s
.53947 .42888 m
.5076 .41215 L
.57819 .39197 L
.61471 .40534 L
.53947 .42888 L
s
.5076 .41215 m
.47503 .39154 L
.54086 .37401 L
.57819 .39197 L
.5076 .41215 L
s
.47503 .39154 m
.44316 .36735 L
.50434 .35159 L
.54086 .37401 L
.47503 .39154 L
s
.44316 .36735 m
.4134 .34039 L
.47024 .3254 L
.50434 .35159 L
.44316 .36735 L
s
.4134 .34039 m
.38704 .31207 L
.44004 .29685 L
.47024 .3254 L
.4134 .34039 L
s
.38704 .31207 m
.36524 .28452 L
.41506 .26819 L
.44004 .29685 L
.38704 .31207 L
s
.36524 .28452 m
.34895 .26072 L
.39639 .24272 L
.41506 .26819 L
.36524 .28452 L
s
.34895 .26072 m
.33889 .24423 L
.38485 .22465 L
.39639 .24272 L
.34895 .26072 L
s
.33889 .24423 m
.33548 .23828 L
.38095 .21804 L
.38485 .22465 L
.33889 .24423 L
s
.33548 .23828 m
.33889 .24423 L
.38485 .22465 L
.38095 .21804 L
.33548 .23828 L
s
.33889 .24423 m
.34895 .26072 L
.39639 .24272 L
.38485 .22465 L
.33889 .24423 L
s
.34895 .26072 m
.36524 .28452 L
.41506 .26819 L
.39639 .24272 L
.34895 .26072 L
s
.36524 .28452 m
.38704 .31207 L
.44004 .29685 L
.41506 .26819 L
.36524 .28452 L
s
.38704 .31207 m
.4134 .34039 L
.47024 .3254 L
.44004 .29685 L
.38704 .31207 L
s
.4134 .34039 m
.44316 .36735 L
.50434 .35159 L
.47024 .3254 L
.4134 .34039 L
s
.44316 .36735 m
.47503 .39154 L
.54086 .37401 L
.50434 .35159 L
.44316 .36735 L
s
.47503 .39154 m
.5076 .41215 L
.57819 .39197 L
.54086 .37401 L
.47503 .39154 L
s
.5076 .41215 m
.53947 .42888 L
.61471 .40534 L
.57819 .39197 L
.5076 .41215 L
s
.53947 .42888 m
.56923 .44179 L
.64881 .41445 L
.61471 .40534 L
.53947 .42888 L
s
.56923 .44179 m
.59559 .45123 L
.67901 .41998 L
.64881 .41445 L
.56923 .44179 L
s
.59559 .45123 m
.61739 .45771 L
.70399 .42282 L
.67901 .41998 L
.59559 .45123 L
s
.61739 .45771 m
.63368 .46181 L
.72266 .42394 L
.70399 .42282 L
.61739 .45771 L
s
.63368 .46181 m
.64375 .46403 L
.73419 .42421 L
.72266 .42394 L
.63368 .46181 L
s
.64375 .46403 m
.64715 .46472 L
.7381 .42423 L
.73419 .42421 L
.64375 .46403 L
s
.64715 .46472 m
.64375 .46403 L
.73419 .42421 L
.7381 .42423 L
.64715 .46472 L
s
.64375 .46403 m
.63368 .46181 L
.72266 .42394 L
.73419 .42421 L
.64375 .46403 L
s
.63368 .46181 m
.61739 .45771 L
.70399 .42282 L
.72266 .42394 L
.63368 .46181 L
s
.61739 .45771 m
.59559 .45123 L
.67901 .41998 L
.70399 .42282 L
.61739 .45771 L
s
.59559 .45123 m
.56923 .44179 L
.64881 .41445 L
.67901 .41998 L
.59559 .45123 L
s
.56923 .44179 m
.53947 .42888 L
.61471 .40534 L
.64881 .41445 L
.56923 .44179 L
s
.53947 .42888 m
.5076 .41215 L
.57819 .39197 L
.61471 .40534 L
.53947 .42888 L
s
.5076 .41215 m
.47503 .39154 L
.54086 .37401 L
.57819 .39197 L
.5076 .41215 L
s
.47503 .39154 m
.44316 .36735 L
.50434 .35159 L
.54086 .37401 L
.47503 .39154 L
s
.44316 .36735 m
.4134 .34039 L
.47024 .3254 L
.50434 .35159 L
.44316 .36735 L
s
.4134 .34039 m
.38704 .31207 L
.44004 .29685 L
.47024 .3254 L
.4134 .34039 L
s
.38704 .31207 m
.36524 .28452 L
.41506 .26819 L
.44004 .29685 L
.38704 .31207 L
s
.36524 .28452 m
.34895 .26072 L
.39639 .24272 L
.41506 .26819 L
.36524 .28452 L
s
.34895 .26072 m
.33889 .24423 L
.38485 .22465 L
.39639 .24272 L
.34895 .26072 L
s
.33889 .24423 m
.33548 .23828 L
.38095 .21804 L
.38485 .22465 L
.33889 .24423 L
s
.33548 .23828 m
.33889 .24423 L
.38485 .22465 L
.38095 .21804 L
.33548 .23828 L
s
.33889 .24423 m
.34895 .26072 L
.39639 .24272 L
.38485 .22465 L
.33889 .24423 L
s
.34895 .26072 m
.36524 .28452 L
.41506 .26819 L
.39639 .24272 L
.34895 .26072 L
s
.36524 .28452 m
.38704 .31207 L
.44004 .29685 L
.41506 .26819 L
.36524 .28452 L
s
.38704 .31207 m
.4134 .34039 L
.47024 .3254 L
.44004 .29685 L
.38704 .31207 L
s
.4134 .34039 m
.44316 .36735 L
.50434 .35159 L
.47024 .3254 L
.4134 .34039 L
s
.44316 .36735 m
.47503 .39154 L
.54086 .37401 L
.50434 .35159 L
.44316 .36735 L
s
.47503 .39154 m
.5076 .41215 L
.57819 .39197 L
.54086 .37401 L
.47503 .39154 L
s
.5076 .41215 m
.53947 .42888 L
.61471 .40534 L
.57819 .39197 L
.5076 .41215 L
s
.53947 .42888 m
.56923 .44179 L
.64881 .41445 L
.61471 .40534 L
.53947 .42888 L
s
.56923 .44179 m
.59559 .45123 L
.67901 .41998 L
.64881 .41445 L
.56923 .44179 L
s
.59559 .45123 m
.61739 .45771 L
.70399 .42282 L
.67901 .41998 L
.59559 .45123 L
s
.61739 .45771 m
.63368 .46181 L
.72266 .42394 L
.70399 .42282 L
.61739 .45771 L
s
.63368 .46181 m
.64375 .46403 L
.73419 .42421 L
.72266 .42394 L
.63368 .46181 L
s
.64375 .46403 m
.64715 .46472 L
.7381 .42423 L
.73419 .42421 L
.64375 .46403 L
s
.7381 .42423 m
.73419 .42421 L
.81429 .36668 L
.81863 .36572 L
.7381 .42423 L
s
.73419 .42421 m
.72266 .42394 L
.80145 .36919 L
.81429 .36668 L
.73419 .42421 L
s
.72266 .42394 m
.70399 .42282 L
.78068 .37226 L
.80145 .36919 L
.72266 .42394 L
s
.70399 .42282 m
.67901 .41998 L
.75289 .37447 L
.78068 .37226 L
.70399 .42282 L
s
.67901 .41998 m
.64881 .41445 L
.71928 .37428 L
.75289 .37447 L
.67901 .41998 L
s
.64881 .41445 m
.61471 .40534 L
.68133 .3703 L
.71928 .37428 L
.64881 .41445 L
s
.61471 .40534 m
.57819 .39197 L
.6407 .36145 L
.68133 .3703 L
.61471 .40534 L
s
.57819 .39197 m
.54086 .37401 L
.59916 .34712 L
.6407 .36145 L
.57819 .39197 L
s
.54086 .37401 m
.50434 .35159 L
.55852 .32723 L
.59916 .34712 L
.54086 .37401 L
s
.50434 .35159 m
.47024 .3254 L
.52057 .30236 L
.55852 .32723 L
.50434 .35159 L
s
.47024 .3254 m
.44004 .29685 L
.48697 .27385 L
.52057 .30236 L
.47024 .3254 L
s
.44004 .29685 m
.41506 .26819 L
.45917 .24404 L
.48697 .27385 L
.44004 .29685 L
s
.41506 .26819 m
.39639 .24272 L
.4384 .21653 L
.45917 .24404 L
.41506 .26819 L
s
.39639 .24272 m
.38485 .22465 L
.42556 .19634 L
.4384 .21653 L
.39639 .24272 L
s
.38485 .22465 m
.38095 .21804 L
.42122 .18878 L
.42556 .19634 L
.38485 .22465 L
s
.38095 .21804 m
.38485 .22465 L
.42556 .19634 L
.42122 .18878 L
.38095 .21804 L
s
.38485 .22465 m
.39639 .24272 L
.4384 .21653 L
.42556 .19634 L
.38485 .22465 L
s
.39639 .24272 m
.41506 .26819 L
.45917 .24404 L
.4384 .21653 L
.39639 .24272 L
s
.41506 .26819 m
.44004 .29685 L
.48697 .27385 L
.45917 .24404 L
.41506 .26819 L
s
.44004 .29685 m
.47024 .3254 L
.52057 .30236 L
.48697 .27385 L
.44004 .29685 L
s
.47024 .3254 m
.50434 .35159 L
.55852 .32723 L
.52057 .30236 L
.47024 .3254 L
s
.50434 .35159 m
.54086 .37401 L
.59916 .34712 L
.55852 .32723 L
.50434 .35159 L
s
.54086 .37401 m
.57819 .39197 L
.6407 .36145 L
.59916 .34712 L
.54086 .37401 L
s
.57819 .39197 m
.61471 .40534 L
.68133 .3703 L
.6407 .36145 L
.57819 .39197 L
s
.61471 .40534 m
.64881 .41445 L
.71928 .37428 L
.68133 .3703 L
.61471 .40534 L
s
.64881 .41445 m
.67901 .41998 L
.75289 .37447 L
.71928 .37428 L
.64881 .41445 L
s
.67901 .41998 m
.70399 .42282 L
.78068 .37226 L
.75289 .37447 L
.67901 .41998 L
s
.70399 .42282 m
.72266 .42394 L
.80145 .36919 L
.78068 .37226 L
.70399 .42282 L
s
.72266 .42394 m
.73419 .42421 L
.81429 .36668 L
.80145 .36919 L
.72266 .42394 L
s
.73419 .42421 m
.7381 .42423 L
.81863 .36572 L
.81429 .36668 L
.73419 .42421 L
s
.7381 .42423 m
.73419 .42421 L
.81429 .36668 L
.81863 .36572 L
.7381 .42423 L
s
.73419 .42421 m
.72266 .42394 L
.80145 .36919 L
.81429 .36668 L
.73419 .42421 L
s
.72266 .42394 m
.70399 .42282 L
.78068 .37226 L
.80145 .36919 L
.72266 .42394 L
s
.70399 .42282 m
.67901 .41998 L
.75289 .37447 L
.78068 .37226 L
.70399 .42282 L
s
.67901 .41998 m
.64881 .41445 L
.71928 .37428 L
.75289 .37447 L
.67901 .41998 L
s
.64881 .41445 m
.61471 .40534 L
.68133 .3703 L
.71928 .37428 L
.64881 .41445 L
s
.61471 .40534 m
.57819 .39197 L
.6407 .36145 L
.68133 .3703 L
.61471 .40534 L
s
.57819 .39197 m
.54086 .37401 L
.59916 .34712 L
.6407 .36145 L
.57819 .39197 L
s
.54086 .37401 m
.50434 .35159 L
.55852 .32723 L
.59916 .34712 L
.54086 .37401 L
s
.50434 .35159 m
.47024 .3254 L
.52057 .30236 L
.55852 .32723 L
.50434 .35159 L
s
.47024 .3254 m
.44004 .29685 L
.48697 .27385 L
.52057 .30236 L
.47024 .3254 L
s
.44004 .29685 m
.41506 .26819 L
.45917 .24404 L
.48697 .27385 L
.44004 .29685 L
s
.41506 .26819 m
.39639 .24272 L
.4384 .21653 L
.45917 .24404 L
.41506 .26819 L
s
.39639 .24272 m
.38485 .22465 L
.42556 .19634 L
.4384 .21653 L
.39639 .24272 L
s
.38485 .22465 m
.38095 .21804 L
.42122 .18878 L
.42556 .19634 L
.38485 .22465 L
s
.38095 .21804 m
.38485 .22465 L
.42556 .19634 L
.42122 .18878 L
.38095 .21804 L
s
.38485 .22465 m
.39639 .24272 L
.4384 .21653 L
.42556 .19634 L
.38485 .22465 L
s
.39639 .24272 m
.41506 .26819 L
.45917 .24404 L
.4384 .21653 L
.39639 .24272 L
s
.41506 .26819 m
.44004 .29685 L
.48697 .27385 L
.45917 .24404 L
.41506 .26819 L
s
.44004 .29685 m
.47024 .3254 L
.52057 .30236 L
.48697 .27385 L
.44004 .29685 L
s
.47024 .3254 m
.50434 .35159 L
.55852 .32723 L
.52057 .30236 L
.47024 .3254 L
s
.50434 .35159 m
.54086 .37401 L
.59916 .34712 L
.55852 .32723 L
.50434 .35159 L
s
.54086 .37401 m
.57819 .39197 L
.6407 .36145 L
.59916 .34712 L
.54086 .37401 L
s
.57819 .39197 m
.61471 .40534 L
.68133 .3703 L
.6407 .36145 L
.57819 .39197 L
s
.61471 .40534 m
.64881 .41445 L
.71928 .37428 L
.68133 .3703 L
.61471 .40534 L
s
.64881 .41445 m
.67901 .41998 L
.75289 .37447 L
.71928 .37428 L
.64881 .41445 L
s
.67901 .41998 m
.70399 .42282 L
.78068 .37226 L
.75289 .37447 L
.67901 .41998 L
s
.70399 .42282 m
.72266 .42394 L
.80145 .36919 L
.78068 .37226 L
.70399 .42282 L
s
.72266 .42394 m
.73419 .42421 L
.81429 .36668 L
.80145 .36919 L
.72266 .42394 L
s
.73419 .42421 m
.7381 .42423 L
.81863 .36572 L
.81429 .36668 L
.73419 .42421 L
s
.81863 .36572 m
.81429 .36668 L
.88054 .29416 L
.88525 .29174 L
.81863 .36572 L
s
.81429 .36668 m
.80145 .36919 L
.86663 .30076 L
.88054 .29416 L
.81429 .36668 L
s
.80145 .36919 m
.78068 .37226 L
.84412 .30976 L
.86663 .30076 L
.80145 .36919 L
s
.78068 .37226 m
.75289 .37447 L
.81399 .31882 L
.84412 .30976 L
.78068 .37226 L
s
.75289 .37447 m
.71928 .37428 L
.77757 .32559 L
.81399 .31882 L
.75289 .37447 L
s
.71928 .37428 m
.68133 .3703 L
.73644 .32806 L
.77757 .32559 L
.71928 .37428 L
s
.68133 .3703 m
.6407 .36145 L
.6924 .32474 L
.73644 .32806 L
.68133 .3703 L
s
.6407 .36145 m
.59916 .34712 L
.64738 .31477 L
.6924 .32474 L
.6407 .36145 L
s
.59916 .34712 m
.55852 .32723 L
.60334 .29791 L
.64738 .31477 L
.59916 .34712 L
s
.55852 .32723 m
.52057 .30236 L
.56221 .27463 L
.60334 .29791 L
.55852 .32723 L
s
.52057 .30236 m
.48697 .27385 L
.52578 .24619 L
.56221 .27463 L
.52057 .30236 L
s
.48697 .27385 m
.45917 .24404 L
.49566 .21487 L
.52578 .24619 L
.48697 .27385 L
s
.45917 .24404 m
.4384 .21653 L
.47315 .18446 L
.49566 .21487 L
.45917 .24404 L
s
.4384 .21653 m
.42556 .19634 L
.45923 .16095 L
.47315 .18446 L
.4384 .21653 L
s
.42556 .19634 m
.42122 .18878 L
.45453 .15179 L
.45923 .16095 L
.42556 .19634 L
s
.42122 .18878 m
.42556 .19634 L
.45923 .16095 L
.45453 .15179 L
.42122 .18878 L
s
.42556 .19634 m
.4384 .21653 L
.47315 .18446 L
.45923 .16095 L
.42556 .19634 L
s
.4384 .21653 m
.45917 .24404 L
.49566 .21487 L
.47315 .18446 L
.4384 .21653 L
s
.45917 .24404 m
.48697 .27385 L
.52578 .24619 L
.49566 .21487 L
.45917 .24404 L
s
.48697 .27385 m
.52057 .30236 L
.56221 .27463 L
.52578 .24619 L
.48697 .27385 L
s
.52057 .30236 m
.55852 .32723 L
.60334 .29791 L
.56221 .27463 L
.52057 .30236 L
s
.55852 .32723 m
.59916 .34712 L
.64738 .31477 L
.60334 .29791 L
.55852 .32723 L
s
.59916 .34712 m
.6407 .36145 L
.6924 .32474 L
.64738 .31477 L
.59916 .34712 L
s
.6407 .36145 m
.68133 .3703 L
.73644 .32806 L
.6924 .32474 L
.6407 .36145 L
s
.68133 .3703 m
.71928 .37428 L
.77757 .32559 L
.73644 .32806 L
.68133 .3703 L
s
.71928 .37428 m
.75289 .37447 L
.81399 .31882 L
.77757 .32559 L
.71928 .37428 L
s
.75289 .37447 m
.78068 .37226 L
.84412 .30976 L
.81399 .31882 L
.75289 .37447 L
s
.78068 .37226 m
.80145 .36919 L
.86663 .30076 L
.84412 .30976 L
.78068 .37226 L
s
.80145 .36919 m
.81429 .36668 L
.88054 .29416 L
.86663 .30076 L
.80145 .36919 L
s
.81429 .36668 m
.81863 .36572 L
.88525 .29174 L
.88054 .29416 L
.81429 .36668 L
s
.81863 .36572 m
.81429 .36668 L
.88054 .29416 L
.88525 .29174 L
.81863 .36572 L
s
.81429 .36668 m
.80145 .36919 L
.86663 .30076 L
.88054 .29416 L
.81429 .36668 L
s
.80145 .36919 m
.78068 .37226 L
.84412 .30976 L
.86663 .30076 L
.80145 .36919 L
s
.78068 .37226 m
.75289 .37447 L
.81399 .31882 L
.84412 .30976 L
.78068 .37226 L
s
.75289 .37447 m
.71928 .37428 L
.77757 .32559 L
.81399 .31882 L
.75289 .37447 L
s
.71928 .37428 m
.68133 .3703 L
.73644 .32806 L
.77757 .32559 L
.71928 .37428 L
s
.68133 .3703 m
.6407 .36145 L
.6924 .32474 L
.73644 .32806 L
.68133 .3703 L
s
.6407 .36145 m
.59916 .34712 L
.64738 .31477 L
.6924 .32474 L
.6407 .36145 L
s
.59916 .34712 m
.55852 .32723 L
.60334 .29791 L
.64738 .31477 L
.59916 .34712 L
s
.55852 .32723 m
.52057 .30236 L
.56221 .27463 L
.60334 .29791 L
.55852 .32723 L
s
.52057 .30236 m
.48697 .27385 L
.52578 .24619 L
.56221 .27463 L
.52057 .30236 L
s
.48697 .27385 m
.45917 .24404 L
.49566 .21487 L
.52578 .24619 L
.48697 .27385 L
s
.45917 .24404 m
.4384 .21653 L
.47315 .18446 L
.49566 .21487 L
.45917 .24404 L
s
.4384 .21653 m
.42556 .19634 L
.45923 .16095 L
.47315 .18446 L
.4384 .21653 L
s
.42556 .19634 m
.42122 .18878 L
.45453 .15179 L
.45923 .16095 L
.42556 .19634 L
s
.42122 .18878 m
.42556 .19634 L
.45923 .16095 L
.45453 .15179 L
.42122 .18878 L
s
.42556 .19634 m
.4384 .21653 L
.47315 .18446 L
.45923 .16095 L
.42556 .19634 L
s
.4384 .21653 m
.45917 .24404 L
.49566 .21487 L
.47315 .18446 L
.4384 .21653 L
s
.45917 .24404 m
.48697 .27385 L
.52578 .24619 L
.49566 .21487 L
.45917 .24404 L
s
.48697 .27385 m
.52057 .30236 L
.56221 .27463 L
.52578 .24619 L
.48697 .27385 L
s
.52057 .30236 m
.55852 .32723 L
.60334 .29791 L
.56221 .27463 L
.52057 .30236 L
s
.55852 .32723 m
.59916 .34712 L
.64738 .31477 L
.60334 .29791 L
.55852 .32723 L
s
.59916 .34712 m
.6407 .36145 L
.6924 .32474 L
.64738 .31477 L
.59916 .34712 L
s
.6407 .36145 m
.68133 .3703 L
.73644 .32806 L
.6924 .32474 L
.6407 .36145 L
s
.68133 .3703 m
.71928 .37428 L
.77757 .32559 L
.73644 .32806 L
.68133 .3703 L
s
.71928 .37428 m
.75289 .37447 L
.81399 .31882 L
.77757 .32559 L
.71928 .37428 L
s
.75289 .37447 m
.78068 .37226 L
.84412 .30976 L
.81399 .31882 L
.75289 .37447 L
s
.78068 .37226 m
.80145 .36919 L
.86663 .30076 L
.84412 .30976 L
.78068 .37226 L
s
.80145 .36919 m
.81429 .36668 L
.88054 .29416 L
.86663 .30076 L
.80145 .36919 L
s
.81429 .36668 m
.81863 .36572 L
.88525 .29174 L
.88054 .29416 L
.81429 .36668 L
s
.88525 .29174 m
.88054 .29416 L
.93004 .21046 L
.93502 .20552 L
.88525 .29174 L
s
.88054 .29416 m
.86663 .30076 L
.91533 .22369 L
.93004 .21046 L
.88054 .29416 L
s
.86663 .30076 m
.84412 .30976 L
.89152 .24153 L
.91533 .22369 L
.86663 .30076 L
s
.84412 .30976 m
.81399 .31882 L
.85965 .25987 L
.89152 .24153 L
.84412 .30976 L
s
.81399 .31882 m
.77757 .32559 L
.82112 .27528 L
.85965 .25987 L
.81399 .31882 L
s
.77757 .32559 m
.73644 .32806 L
.77761 .28521 L
.82112 .27528 L
.77757 .32559 L
s
.73644 .32806 m
.6924 .32474 L
.73103 .28796 L
.77761 .28521 L
.73644 .32806 L
s
.6924 .32474 m
.64738 .31477 L
.68341 .28258 L
.73103 .28796 L
.6924 .32474 L
s
.64738 .31477 m
.60334 .29791 L
.63682 .26882 L
.68341 .28258 L
.64738 .31477 L
s
.60334 .29791 m
.56221 .27463 L
.59332 .24707 L
.63682 .26882 L
.60334 .29791 L
s
.56221 .27463 m
.52578 .24619 L
.55479 .21846 L
.59332 .24707 L
.56221 .27463 L
s
.52578 .24619 m
.49566 .21487 L
.52292 .18503 L
.55479 .21846 L
.52578 .24619 L
s
.49566 .21487 m
.47315 .18446 L
.49911 .15033 L
.52292 .18503 L
.49566 .21487 L
s
.47315 .18446 m
.45923 .16095 L
.48439 .12106 L
.49911 .15033 L
.47315 .18446 L
s
.45923 .16095 m
.45453 .15179 L
.47942 .10868 L
.48439 .12106 L
.45923 .16095 L
s
.45453 .15179 m
.45923 .16095 L
.48439 .12106 L
.47942 .10868 L
.45453 .15179 L
s
.45923 .16095 m
.47315 .18446 L
.49911 .15033 L
.48439 .12106 L
.45923 .16095 L
s
.47315 .18446 m
.49566 .21487 L
.52292 .18503 L
.49911 .15033 L
.47315 .18446 L
s
.49566 .21487 m
.52578 .24619 L
.55479 .21846 L
.52292 .18503 L
.49566 .21487 L
s
.52578 .24619 m
.56221 .27463 L
.59332 .24707 L
.55479 .21846 L
.52578 .24619 L
s
.56221 .27463 m
.60334 .29791 L
.63682 .26882 L
.59332 .24707 L
.56221 .27463 L
s
.60334 .29791 m
.64738 .31477 L
.68341 .28258 L
.63682 .26882 L
.60334 .29791 L
s
.64738 .31477 m
.6924 .32474 L
.73103 .28796 L
.68341 .28258 L
.64738 .31477 L
s
.6924 .32474 m
.73644 .32806 L
.77761 .28521 L
.73103 .28796 L
.6924 .32474 L
s
.73644 .32806 m
.77757 .32559 L
.82112 .27528 L
.77761 .28521 L
.73644 .32806 L
s
.77757 .32559 m
.81399 .31882 L
.85965 .25987 L
.82112 .27528 L
.77757 .32559 L
s
.81399 .31882 m
.84412 .30976 L
.89152 .24153 L
.85965 .25987 L
.81399 .31882 L
s
.84412 .30976 m
.86663 .30076 L
.91533 .22369 L
.89152 .24153 L
.84412 .30976 L
s
.86663 .30076 m
.88054 .29416 L
.93004 .21046 L
.91533 .22369 L
.86663 .30076 L
s
.88054 .29416 m
.88525 .29174 L
.93502 .20552 L
.93004 .21046 L
.88054 .29416 L
s
.88525 .29174 m
.88054 .29416 L
.93004 .21046 L
.93502 .20552 L
.88525 .29174 L
s
.88054 .29416 m
.86663 .30076 L
.91533 .22369 L
.93004 .21046 L
.88054 .29416 L
s
.86663 .30076 m
.84412 .30976 L
.89152 .24153 L
.91533 .22369 L
.86663 .30076 L
s
.84412 .30976 m
.81399 .31882 L
.85965 .25987 L
.89152 .24153 L
.84412 .30976 L
s
.81399 .31882 m
.77757 .32559 L
.82112 .27528 L
.85965 .25987 L
.81399 .31882 L
s
.77757 .32559 m
.73644 .32806 L
.77761 .28521 L
.82112 .27528 L
.77757 .32559 L
s
.73644 .32806 m
.6924 .32474 L
.73103 .28796 L
.77761 .28521 L
.73644 .32806 L
s
.6924 .32474 m
.64738 .31477 L
.68341 .28258 L
.73103 .28796 L
.6924 .32474 L
s
.64738 .31477 m
.60334 .29791 L
.63682 .26882 L
.68341 .28258 L
.64738 .31477 L
s
.60334 .29791 m
.56221 .27463 L
.59332 .24707 L
.63682 .26882 L
.60334 .29791 L
s
.56221 .27463 m
.52578 .24619 L
.55479 .21846 L
.59332 .24707 L
.56221 .27463 L
s
.52578 .24619 m
.49566 .21487 L
.52292 .18503 L
.55479 .21846 L
.52578 .24619 L
s
.49566 .21487 m
.47315 .18446 L
.49911 .15033 L
.52292 .18503 L
.49566 .21487 L
s
.47315 .18446 m
.45923 .16095 L
.48439 .12106 L
.49911 .15033 L
.47315 .18446 L
s
.45923 .16095 m
.45453 .15179 L
.47942 .10868 L
.48439 .12106 L
.45923 .16095 L
s
.45453 .15179 m
.45923 .16095 L
.48439 .12106 L
.47942 .10868 L
.45453 .15179 L
s
.45923 .16095 m
.47315 .18446 L
.49911 .15033 L
.48439 .12106 L
.45923 .16095 L
s
.47315 .18446 m
.49566 .21487 L
.52292 .18503 L
.49911 .15033 L
.47315 .18446 L
s
.49566 .21487 m
.52578 .24619 L
.55479 .21846 L
.52292 .18503 L
.49566 .21487 L
s
.52578 .24619 m
.56221 .27463 L
.59332 .24707 L
.55479 .21846 L
.52578 .24619 L
s
.56221 .27463 m
.60334 .29791 L
.63682 .26882 L
.59332 .24707 L
.56221 .27463 L
s
.60334 .29791 m
.64738 .31477 L
.68341 .28258 L
.63682 .26882 L
.60334 .29791 L
s
.64738 .31477 m
.6924 .32474 L
.73103 .28796 L
.68341 .28258 L
.64738 .31477 L
s
.6924 .32474 m
.73644 .32806 L
.77761 .28521 L
.73103 .28796 L
.6924 .32474 L
s
.73644 .32806 m
.77757 .32559 L
.82112 .27528 L
.77761 .28521 L
.73644 .32806 L
s
.77757 .32559 m
.81399 .31882 L
.85965 .25987 L
.82112 .27528 L
.77757 .32559 L
s
.81399 .31882 m
.84412 .30976 L
.89152 .24153 L
.85965 .25987 L
.81399 .31882 L
s
.84412 .30976 m
.86663 .30076 L
.91533 .22369 L
.89152 .24153 L
.84412 .30976 L
s
.86663 .30076 m
.88054 .29416 L
.93004 .21046 L
.91533 .22369 L
.86663 .30076 L
s
.88054 .29416 m
.88525 .29174 L
.93502 .20552 L
.93004 .21046 L
.88054 .29416 L
s
.93502 .20552 m
.93004 .21046 L
.96064 .12193 L
.96578 .11085 L
.93502 .20552 L
s
.93004 .21046 m
.91533 .22369 L
.94543 .14844 L
.96064 .12193 L
.93004 .21046 L
s
.91533 .22369 m
.89152 .24153 L
.92081 .17995 L
.94543 .14844 L
.91533 .22369 L
s
.89152 .24153 m
.85965 .25987 L
.88787 .20986 L
.92081 .17995 L
.89152 .24153 L
s
.85965 .25987 m
.82112 .27528 L
.84804 .23445 L
.88787 .20986 L
.85965 .25987 L
s
.82112 .27528 m
.77761 .28521 L
.80306 .25147 L
.84804 .23445 L
.82112 .27528 L
s
.77761 .28521 m
.73103 .28796 L
.75491 .25955 L
.80306 .25147 L
.77761 .28521 L
s
.73103 .28796 m
.68341 .28258 L
.70568 .258 L
.75491 .25955 L
.73103 .28796 L
s
.68341 .28258 m
.63682 .26882 L
.65752 .24668 L
.70568 .258 L
.68341 .28258 L
s
.63682 .26882 m
.59332 .24707 L
.61254 .22604 L
.65752 .24668 L
.63682 .26882 L
s
.59332 .24707 m
.55479 .21846 L
.57271 .19703 L
.61254 .22604 L
.59332 .24707 L
s
.55479 .21846 m
.52292 .18503 L
.53977 .16121 L
.57271 .19703 L
.55479 .21846 L
s
.52292 .18503 m
.49911 .15033 L
.51516 .12112 L
.53977 .16121 L
.52292 .18503 L
s
.49911 .15033 m
.48439 .12106 L
.49994 .08204 L
.51516 .12112 L
.49911 .15033 L
s
.48439 .12106 m
.47942 .10868 L
.4948 .06134 L
.49994 .08204 L
.48439 .12106 L
s
.47942 .10868 m
.48439 .12106 L
.49994 .08204 L
.4948 .06134 L
.47942 .10868 L
s
.48439 .12106 m
.49911 .15033 L
.51516 .12112 L
.49994 .08204 L
.48439 .12106 L
s
.49911 .15033 m
.52292 .18503 L
.53977 .16121 L
.51516 .12112 L
.49911 .15033 L
s
.52292 .18503 m
.55479 .21846 L
.57271 .19703 L
.53977 .16121 L
.52292 .18503 L
s
.55479 .21846 m
.59332 .24707 L
.61254 .22604 L
.57271 .19703 L
.55479 .21846 L
s
.59332 .24707 m
.63682 .26882 L
.65752 .24668 L
.61254 .22604 L
.59332 .24707 L
s
.63682 .26882 m
.68341 .28258 L
.70568 .258 L
.65752 .24668 L
.63682 .26882 L
s
.68341 .28258 m
.73103 .28796 L
.75491 .25955 L
.70568 .258 L
.68341 .28258 L
s
.73103 .28796 m
.77761 .28521 L
.80306 .25147 L
.75491 .25955 L
.73103 .28796 L
s
.77761 .28521 m
.82112 .27528 L
.84804 .23445 L
.80306 .25147 L
.77761 .28521 L
s
.82112 .27528 m
.85965 .25987 L
.88787 .20986 L
.84804 .23445 L
.82112 .27528 L
s
.85965 .25987 m
.89152 .24153 L
.92081 .17995 L
.88787 .20986 L
.85965 .25987 L
s
.89152 .24153 m
.91533 .22369 L
.94543 .14844 L
.92081 .17995 L
.89152 .24153 L
s
.91533 .22369 m
.93004 .21046 L
.96064 .12193 L
.94543 .14844 L
.91533 .22369 L
s
.93004 .21046 m
.93502 .20552 L
.96578 .11085 L
.96064 .12193 L
.93004 .21046 L
s
.93502 .20552 m
.93004 .21046 L
.96064 .12193 L
.96578 .11085 L
.93502 .20552 L
s
.93004 .21046 m
.91533 .22369 L
.94543 .14844 L
.96064 .12193 L
.93004 .21046 L
s
.91533 .22369 m
.89152 .24153 L
.92081 .17995 L
.94543 .14844 L
.91533 .22369 L
s
.89152 .24153 m
.85965 .25987 L
.88787 .20986 L
.92081 .17995 L
.89152 .24153 L
s
.85965 .25987 m
.82112 .27528 L
.84804 .23445 L
.88787 .20986 L
.85965 .25987 L
s
.82112 .27528 m
.77761 .28521 L
.80306 .25147 L
.84804 .23445 L
.82112 .27528 L
s
.77761 .28521 m
.73103 .28796 L
.75491 .25955 L
.80306 .25147 L
.77761 .28521 L
s
.73103 .28796 m
.68341 .28258 L
.70568 .258 L
.75491 .25955 L
.73103 .28796 L
s
.68341 .28258 m
.63682 .26882 L
.65752 .24668 L
.70568 .258 L
.68341 .28258 L
s
.63682 .26882 m
.59332 .24707 L
.61254 .22604 L
.65752 .24668 L
.63682 .26882 L
s
.59332 .24707 m
.55479 .21846 L
.57271 .19703 L
.61254 .22604 L
.59332 .24707 L
s
.55479 .21846 m
.52292 .18503 L
.53977 .16121 L
.57271 .19703 L
.55479 .21846 L
s
.52292 .18503 m
.49911 .15033 L
.51516 .12112 L
.53977 .16121 L
.52292 .18503 L
s
.49911 .15033 m
.48439 .12106 L
.49994 .08204 L
.51516 .12112 L
.49911 .15033 L
s
.48439 .12106 m
.47942 .10868 L
.4948 .06134 L
.49994 .08204 L
.48439 .12106 L
s
.47942 .10868 m
.48439 .12106 L
.49994 .08204 L
.4948 .06134 L
.47942 .10868 L
s
.48439 .12106 m
.49911 .15033 L
.51516 .12112 L
.49994 .08204 L
.48439 .12106 L
s
.49911 .15033 m
.52292 .18503 L
.53977 .16121 L
.51516 .12112 L
.49911 .15033 L
s
.52292 .18503 m
.55479 .21846 L
.57271 .19703 L
.53977 .16121 L
.52292 .18503 L
s
.55479 .21846 m
.59332 .24707 L
.61254 .22604 L
.57271 .19703 L
.55479 .21846 L
s
.59332 .24707 m
.63682 .26882 L
.65752 .24668 L
.61254 .22604 L
.59332 .24707 L
s
.63682 .26882 m
.68341 .28258 L
.70568 .258 L
.65752 .24668 L
.63682 .26882 L
s
.68341 .28258 m
.73103 .28796 L
.75491 .25955 L
.70568 .258 L
.68341 .28258 L
s
.73103 .28796 m
.77761 .28521 L
.80306 .25147 L
.75491 .25955 L
.73103 .28796 L
s
.77761 .28521 m
.82112 .27528 L
.84804 .23445 L
.80306 .25147 L
.77761 .28521 L
s
.82112 .27528 m
.85965 .25987 L
.88787 .20986 L
.84804 .23445 L
.82112 .27528 L
s
.85965 .25987 m
.89152 .24153 L
.92081 .17995 L
.88787 .20986 L
.85965 .25987 L
s
.89152 .24153 m
.91533 .22369 L
.94543 .14844 L
.92081 .17995 L
.89152 .24153 L
s
.91533 .22369 m
.93004 .21046 L
.96064 .12193 L
.94543 .14844 L
.91533 .22369 L
s
.93004 .21046 m
.93502 .20552 L
.96578 .11085 L
.96064 .12193 L
.93004 .21046 L
s
.96578 .11085 m
.96064 .12193 L
.97099 .06134 L
.97619 .01184 L
.96578 .11085 L
s
.96064 .12193 m
.94543 .14844 L
.95561 .10868 L
.97099 .06134 L
.96064 .12193 L
s
.94543 .14844 m
.92081 .17995 L
.93072 .15179 L
.95561 .10868 L
.94543 .14844 L
s
.92081 .17995 m
.88787 .20986 L
.89741 .18878 L
.93072 .15179 L
.92081 .17995 L
s
.88787 .20986 m
.84804 .23445 L
.85714 .21804 L
.89741 .18878 L
.88787 .20986 L
s
.84804 .23445 m
.80306 .25147 L
.81167 .23828 L
.85714 .21804 L
.84804 .23445 L
s
.80306 .25147 m
.75491 .25955 L
.76298 .24863 L
.81167 .23828 L
.80306 .25147 L
s
.75491 .25955 m
.70568 .258 L
.71321 .24863 L
.76298 .24863 L
.75491 .25955 L
s
.70568 .258 m
.65752 .24668 L
.66452 .23828 L
.71321 .24863 L
.70568 .258 L
s
.65752 .24668 m
.61254 .22604 L
.61905 .21804 L
.66452 .23828 L
.65752 .24668 L
s
.61254 .22604 m
.57271 .19703 L
.57878 .18878 L
.61905 .21804 L
.61254 .22604 L
s
.57271 .19703 m
.53977 .16121 L
.54547 .15179 L
.57878 .18878 L
.57271 .19703 L
s
.53977 .16121 m
.51516 .12112 L
.52058 .10868 L
.54547 .15179 L
.53977 .16121 L
s
.51516 .12112 m
.49994 .08204 L
.5052 .06134 L
.52058 .10868 L
.51516 .12112 L
s
.49994 .08204 m
.4948 .06134 L
.5 .01184 L
.5052 .06134 L
.49994 .08204 L
s
.4948 .06134 m
.49994 .08204 L
.5052 .06134 L
.5 .01184 L
.4948 .06134 L
s
.49994 .08204 m
.51516 .12112 L
.52058 .10868 L
.5052 .06134 L
.49994 .08204 L
s
.51516 .12112 m
.53977 .16121 L
.54547 .15179 L
.52058 .10868 L
.51516 .12112 L
s
.53977 .16121 m
.57271 .19703 L
.57878 .18878 L
.54547 .15179 L
.53977 .16121 L
s
.57271 .19703 m
.61254 .22604 L
.61905 .21804 L
.57878 .18878 L
.57271 .19703 L
s
.61254 .22604 m
.65752 .24668 L
.66452 .23828 L
.61905 .21804 L
.61254 .22604 L
s
.65752 .24668 m
.70568 .258 L
.71321 .24863 L
.66452 .23828 L
.65752 .24668 L
s
.70568 .258 m
.75491 .25955 L
.76298 .24863 L
.71321 .24863 L
.70568 .258 L
s
.75491 .25955 m
.80306 .25147 L
.81167 .23828 L
.76298 .24863 L
.75491 .25955 L
s
.80306 .25147 m
.84804 .23445 L
.85714 .21804 L
.81167 .23828 L
.80306 .25147 L
s
.84804 .23445 m
.88787 .20986 L
.89741 .18878 L
.85714 .21804 L
.84804 .23445 L
s
.88787 .20986 m
.92081 .17995 L
.93072 .15179 L
.89741 .18878 L
.88787 .20986 L
s
.92081 .17995 m
.94543 .14844 L
.95561 .10868 L
.93072 .15179 L
.92081 .17995 L
s
.94543 .14844 m
.96064 .12193 L
.97099 .06134 L
.95561 .10868 L
.94543 .14844 L
s
.96064 .12193 m
.96578 .11085 L
.97619 .01184 L
.97099 .06134 L
.96064 .12193 L
s
.96578 .11085 m
.96064 .12193 L
.97099 .06134 L
.97619 .01184 L
.96578 .11085 L
s
.96064 .12193 m
.94543 .14844 L
.95561 .10868 L
.97099 .06134 L
.96064 .12193 L
s
.94543 .14844 m
.92081 .17995 L
.93072 .15179 L
.95561 .10868 L
.94543 .14844 L
s
.92081 .17995 m
.88787 .20986 L
.89741 .18878 L
.93072 .15179 L
.92081 .17995 L
s
.88787 .20986 m
.84804 .23445 L
.85714 .21804 L
.89741 .18878 L
.88787 .20986 L
s
.84804 .23445 m
.80306 .25147 L
.81167 .23828 L
.85714 .21804 L
.84804 .23445 L
s
.80306 .25147 m
.75491 .25955 L
.76298 .24863 L
.81167 .23828 L
.80306 .25147 L
s
.75491 .25955 m
.70568 .258 L
.71321 .24863 L
.76298 .24863 L
.75491 .25955 L
s
.70568 .258 m
.65752 .24668 L
.66452 .23828 L
.71321 .24863 L
.70568 .258 L
s
.65752 .24668 m
.61254 .22604 L
.61905 .21804 L
.66452 .23828 L
.65752 .24668 L
s
.61254 .22604 m
.57271 .19703 L
.57878 .18878 L
.61905 .21804 L
.61254 .22604 L
s
.57271 .19703 m
.53977 .16121 L
.54547 .15179 L
.57878 .18878 L
.57271 .19703 L
s
.53977 .16121 m
.51516 .12112 L
.52058 .10868 L
.54547 .15179 L
.53977 .16121 L
s
.51516 .12112 m
.49994 .08204 L
.5052 .06134 L
.52058 .10868 L
.51516 .12112 L
s
.49994 .08204 m
.4948 .06134 L
.5 .01184 L
.5052 .06134 L
.49994 .08204 L
s
.4948 .06134 m
.49994 .08204 L
.5052 .06134 L
.5 .01184 L
.4948 .06134 L
s
.49994 .08204 m
.51516 .12112 L
.52058 .10868 L
.5052 .06134 L
.49994 .08204 L
s
.51516 .12112 m
.53977 .16121 L
.54547 .15179 L
.52058 .10868 L
.51516 .12112 L
s
.53977 .16121 m
.57271 .19703 L
.57878 .18878 L
.54547 .15179 L
.53977 .16121 L
s
.57271 .19703 m
.61254 .22604 L
.61905 .21804 L
.57878 .18878 L
.57271 .19703 L
s
.61254 .22604 m
.65752 .24668 L
.66452 .23828 L
.61905 .21804 L
.61254 .22604 L
s
.65752 .24668 m
.70568 .258 L
.71321 .24863 L
.66452 .23828 L
.65752 .24668 L
s
.70568 .258 m
.75491 .25955 L
.76298 .24863 L
.71321 .24863 L
.70568 .258 L
s
.75491 .25955 m
.80306 .25147 L
.81167 .23828 L
.76298 .24863 L
.75491 .25955 L
s
.80306 .25147 m
.84804 .23445 L
.85714 .21804 L
.81167 .23828 L
.80306 .25147 L
s
.84804 .23445 m
.88787 .20986 L
.89741 .18878 L
.85714 .21804 L
.84804 .23445 L
s
.88787 .20986 m
.92081 .17995 L
.93072 .15179 L
.89741 .18878 L
.88787 .20986 L
s
.92081 .17995 m
.94543 .14844 L
.95561 .10868 L
.93072 .15179 L
.92081 .17995 L
s
.94543 .14844 m
.96064 .12193 L
.97099 .06134 L
.95561 .10868 L
.94543 .14844 L
s
.96064 .12193 m
.96578 .11085 L
.97619 .01184 L
.97099 .06134 L
.96064 .12193 L
s
.97619 .01184 m
.97099 .06134 L
.96064 .12193 L
.96578 .11085 L
.97619 .01184 L
s
.97099 .06134 m
.95561 .10868 L
.94543 .14844 L
.96064 .12193 L
.97099 .06134 L
s
.95561 .10868 m
.93072 .15179 L
.92081 .17995 L
.94543 .14844 L
.95561 .10868 L
s
.93072 .15179 m
.89741 .18878 L
.88787 .20986 L
.92081 .17995 L
.93072 .15179 L
s
.89741 .18878 m
.85714 .21804 L
.84804 .23445 L
.88787 .20986 L
.89741 .18878 L
s
.85714 .21804 m
.81167 .23828 L
.80306 .25147 L
.84804 .23445 L
.85714 .21804 L
s
.81167 .23828 m
.76298 .24863 L
.75491 .25955 L
.80306 .25147 L
.81167 .23828 L
s
.76298 .24863 m
.71321 .24863 L
.70568 .258 L
.75491 .25955 L
.76298 .24863 L
s
.71321 .24863 m
.66452 .23828 L
.65752 .24668 L
.70568 .258 L
.71321 .24863 L
s
.66452 .23828 m
.61905 .21804 L
.61254 .22604 L
.65752 .24668 L
.66452 .23828 L
s
.61905 .21804 m
.57878 .18878 L
.57271 .19703 L
.61254 .22604 L
.61905 .21804 L
s
.57878 .18878 m
.54547 .15179 L
.53977 .16121 L
.57271 .19703 L
.57878 .18878 L
s
.54547 .15179 m
.52058 .10868 L
.51516 .12112 L
.53977 .16121 L
.54547 .15179 L
s
.52058 .10868 m
.5052 .06134 L
.49994 .08204 L
.51516 .12112 L
.52058 .10868 L
s
.5052 .06134 m
.5 .01184 L
.4948 .06134 L
.49994 .08204 L
.5052 .06134 L
s
.5 .01184 m
.5052 .06134 L
.49994 .08204 L
.4948 .06134 L
.5 .01184 L
s
.5052 .06134 m
.52058 .10868 L
.51516 .12112 L
.49994 .08204 L
.5052 .06134 L
s
.52058 .10868 m
.54547 .15179 L
.53977 .16121 L
.51516 .12112 L
.52058 .10868 L
s
.54547 .15179 m
.57878 .18878 L
.57271 .19703 L
.53977 .16121 L
.54547 .15179 L
s
.57878 .18878 m
.61905 .21804 L
.61254 .22604 L
.57271 .19703 L
.57878 .18878 L
s
.61905 .21804 m
.66452 .23828 L
.65752 .24668 L
.61254 .22604 L
.61905 .21804 L
s
.66452 .23828 m
.71321 .24863 L
.70568 .258 L
.65752 .24668 L
.66452 .23828 L
s
.71321 .24863 m
.76298 .24863 L
.75491 .25955 L
.70568 .258 L
.71321 .24863 L
s
.76298 .24863 m
.81167 .23828 L
.80306 .25147 L
.75491 .25955 L
.76298 .24863 L
s
.81167 .23828 m
.85714 .21804 L
.84804 .23445 L
.80306 .25147 L
.81167 .23828 L
s
.85714 .21804 m
.89741 .18878 L
.88787 .20986 L
.84804 .23445 L
.85714 .21804 L
s
.89741 .18878 m
.93072 .15179 L
.92081 .17995 L
.88787 .20986 L
.89741 .18878 L
s
.93072 .15179 m
.95561 .10868 L
.94543 .14844 L
.92081 .17995 L
.93072 .15179 L
s
.95561 .10868 m
.97099 .06134 L
.96064 .12193 L
.94543 .14844 L
.95561 .10868 L
s
.97099 .06134 m
.97619 .01184 L
.96578 .11085 L
.96064 .12193 L
.97099 .06134 L
s
.97619 .01184 m
.97099 .06134 L
.96064 .12193 L
.96578 .11085 L
.97619 .01184 L
s
.97099 .06134 m
.95561 .10868 L
.94543 .14844 L
.96064 .12193 L
.97099 .06134 L
s
.95561 .10868 m
.93072 .15179 L
.92081 .17995 L
.94543 .14844 L
.95561 .10868 L
s
.93072 .15179 m
.89741 .18878 L
.88787 .20986 L
.92081 .17995 L
.93072 .15179 L
s
.89741 .18878 m
.85714 .21804 L
.84804 .23445 L
.88787 .20986 L
.89741 .18878 L
s
.85714 .21804 m
.81167 .23828 L
.80306 .25147 L
.84804 .23445 L
.85714 .21804 L
s
.81167 .23828 m
.76298 .24863 L
.75491 .25955 L
.80306 .25147 L
.81167 .23828 L
s
.76298 .24863 m
.71321 .24863 L
.70568 .258 L
.75491 .25955 L
.76298 .24863 L
s
.71321 .24863 m
.66452 .23828 L
.65752 .24668 L
.70568 .258 L
.71321 .24863 L
s
.66452 .23828 m
.61905 .21804 L
.61254 .22604 L
.65752 .24668 L
.66452 .23828 L
s
.61905 .21804 m
.57878 .18878 L
.57271 .19703 L
.61254 .22604 L
.61905 .21804 L
s
.57878 .18878 m
.54547 .15179 L
.53977 .16121 L
.57271 .19703 L
.57878 .18878 L
s
.54547 .15179 m
.52058 .10868 L
.51516 .12112 L
.53977 .16121 L
.54547 .15179 L
s
.52058 .10868 m
.5052 .06134 L
.49994 .08204 L
.51516 .12112 L
.52058 .10868 L
s
.5052 .06134 m
.5 .01184 L
.4948 .06134 L
.49994 .08204 L
.5052 .06134 L
s
.5 .01184 m
.5052 .06134 L
.49994 .08204 L
.4948 .06134 L
.5 .01184 L
s
.5052 .06134 m
.52058 .10868 L
.51516 .12112 L
.49994 .08204 L
.5052 .06134 L
s
.52058 .10868 m
.54547 .15179 L
.53977 .16121 L
.51516 .12112 L
.52058 .10868 L
s
.54547 .15179 m
.57878 .18878 L
.57271 .19703 L
.53977 .16121 L
.54547 .15179 L
s
.57878 .18878 m
.61905 .21804 L
.61254 .22604 L
.57271 .19703 L
.57878 .18878 L
s
.61905 .21804 m
.66452 .23828 L
.65752 .24668 L
.61254 .22604 L
.61905 .21804 L
s
.66452 .23828 m
.71321 .24863 L
.70568 .258 L
.65752 .24668 L
.66452 .23828 L
s
.71321 .24863 m
.76298 .24863 L
.75491 .25955 L
.70568 .258 L
.71321 .24863 L
s
.76298 .24863 m
.81167 .23828 L
.80306 .25147 L
.75491 .25955 L
.76298 .24863 L
s
.81167 .23828 m
.85714 .21804 L
.84804 .23445 L
.80306 .25147 L
.81167 .23828 L
s
.85714 .21804 m
.89741 .18878 L
.88787 .20986 L
.84804 .23445 L
.85714 .21804 L
s
.89741 .18878 m
.93072 .15179 L
.92081 .17995 L
.88787 .20986 L
.89741 .18878 L
s
.93072 .15179 m
.95561 .10868 L
.94543 .14844 L
.92081 .17995 L
.93072 .15179 L
s
.95561 .10868 m
.97099 .06134 L
.96064 .12193 L
.94543 .14844 L
.95561 .10868 L
s
.97099 .06134 m
.97619 .01184 L
.96578 .11085 L
.96064 .12193 L
.97099 .06134 L
s
.96578 .11085 m
.96064 .12193 L
.93004 .21046 L
.93502 .20552 L
.96578 .11085 L
s
.96064 .12193 m
.94543 .14844 L
.91533 .22369 L
.93004 .21046 L
.96064 .12193 L
s
.94543 .14844 m
.92081 .17995 L
.89152 .24153 L
.91533 .22369 L
.94543 .14844 L
s
.92081 .17995 m
.88787 .20986 L
.85965 .25987 L
.89152 .24153 L
.92081 .17995 L
s
.88787 .20986 m
.84804 .23445 L
.82112 .27528 L
.85965 .25987 L
.88787 .20986 L
s
.84804 .23445 m
.80306 .25147 L
.77761 .28521 L
.82112 .27528 L
.84804 .23445 L
s
.80306 .25147 m
.75491 .25955 L
.73103 .28796 L
.77761 .28521 L
.80306 .25147 L
s
.75491 .25955 m
.70568 .258 L
.68341 .28258 L
.73103 .28796 L
.75491 .25955 L
s
.70568 .258 m
.65752 .24668 L
.63682 .26882 L
.68341 .28258 L
.70568 .258 L
s
.65752 .24668 m
.61254 .22604 L
.59332 .24707 L
.63682 .26882 L
.65752 .24668 L
s
.61254 .22604 m
.57271 .19703 L
.55479 .21846 L
.59332 .24707 L
.61254 .22604 L
s
.57271 .19703 m
.53977 .16121 L
.52292 .18503 L
.55479 .21846 L
.57271 .19703 L
s
.53977 .16121 m
.51516 .12112 L
.49911 .15033 L
.52292 .18503 L
.53977 .16121 L
s
.51516 .12112 m
.49994 .08204 L
.48439 .12106 L
.49911 .15033 L
.51516 .12112 L
s
.49994 .08204 m
.4948 .06134 L
.47942 .10868 L
.48439 .12106 L
.49994 .08204 L
s
.4948 .06134 m
.49994 .08204 L
.48439 .12106 L
.47942 .10868 L
.4948 .06134 L
s
.49994 .08204 m
.51516 .12112 L
.49911 .15033 L
.48439 .12106 L
.49994 .08204 L
s
.51516 .12112 m
.53977 .16121 L
.52292 .18503 L
.49911 .15033 L
.51516 .12112 L
s
.53977 .16121 m
.57271 .19703 L
.55479 .21846 L
.52292 .18503 L
.53977 .16121 L
s
.57271 .19703 m
.61254 .22604 L
.59332 .24707 L
.55479 .21846 L
.57271 .19703 L
s
.61254 .22604 m
.65752 .24668 L
.63682 .26882 L
.59332 .24707 L
.61254 .22604 L
s
.65752 .24668 m
.70568 .258 L
.68341 .28258 L
.63682 .26882 L
.65752 .24668 L
s
.70568 .258 m
.75491 .25955 L
.73103 .28796 L
.68341 .28258 L
.70568 .258 L
s
.75491 .25955 m
.80306 .25147 L
.77761 .28521 L
.73103 .28796 L
.75491 .25955 L
s
.80306 .25147 m
.84804 .23445 L
.82112 .27528 L
.77761 .28521 L
.80306 .25147 L
s
.84804 .23445 m
.88787 .20986 L
.85965 .25987 L
.82112 .27528 L
.84804 .23445 L
s
.88787 .20986 m
.92081 .17995 L
.89152 .24153 L
.85965 .25987 L
.88787 .20986 L
s
.92081 .17995 m
.94543 .14844 L
.91533 .22369 L
.89152 .24153 L
.92081 .17995 L
s
.94543 .14844 m
.96064 .12193 L
.93004 .21046 L
.91533 .22369 L
.94543 .14844 L
s
.96064 .12193 m
.96578 .11085 L
.93502 .20552 L
.93004 .21046 L
.96064 .12193 L
s
.96578 .11085 m
.96064 .12193 L
.93004 .21046 L
.93502 .20552 L
.96578 .11085 L
s
.96064 .12193 m
.94543 .14844 L
.91533 .22369 L
.93004 .21046 L
.96064 .12193 L
s
.94543 .14844 m
.92081 .17995 L
.89152 .24153 L
.91533 .22369 L
.94543 .14844 L
s
.92081 .17995 m
.88787 .20986 L
.85965 .25987 L
.89152 .24153 L
.92081 .17995 L
s
.88787 .20986 m
.84804 .23445 L
.82112 .27528 L
.85965 .25987 L
.88787 .20986 L
s
.84804 .23445 m
.80306 .25147 L
.77761 .28521 L
.82112 .27528 L
.84804 .23445 L
s
.80306 .25147 m
.75491 .25955 L
.73103 .28796 L
.77761 .28521 L
.80306 .25147 L
s
.75491 .25955 m
.70568 .258 L
.68341 .28258 L
.73103 .28796 L
.75491 .25955 L
s
.70568 .258 m
.65752 .24668 L
.63682 .26882 L
.68341 .28258 L
.70568 .258 L
s
.65752 .24668 m
.61254 .22604 L
.59332 .24707 L
.63682 .26882 L
.65752 .24668 L
s
.61254 .22604 m
.57271 .19703 L
.55479 .21846 L
.59332 .24707 L
.61254 .22604 L
s
.57271 .19703 m
.53977 .16121 L
.52292 .18503 L
.55479 .21846 L
.57271 .19703 L
s
.53977 .16121 m
.51516 .12112 L
.49911 .15033 L
.52292 .18503 L
.53977 .16121 L
s
.51516 .12112 m
.49994 .08204 L
.48439 .12106 L
.49911 .15033 L
.51516 .12112 L
s
.49994 .08204 m
.4948 .06134 L
.47942 .10868 L
.48439 .12106 L
.49994 .08204 L
s
.4948 .06134 m
.49994 .08204 L
.48439 .12106 L
.47942 .10868 L
.4948 .06134 L
s
.49994 .08204 m
.51516 .12112 L
.49911 .15033 L
.48439 .12106 L
.49994 .08204 L
s
.51516 .12112 m
.53977 .16121 L
.52292 .18503 L
.49911 .15033 L
.51516 .12112 L
s
.53977 .16121 m
.57271 .19703 L
.55479 .21846 L
.52292 .18503 L
.53977 .16121 L
s
.57271 .19703 m
.61254 .22604 L
.59332 .24707 L
.55479 .21846 L
.57271 .19703 L
s
.61254 .22604 m
.65752 .24668 L
.63682 .26882 L
.59332 .24707 L
.61254 .22604 L
s
.65752 .24668 m
.70568 .258 L
.68341 .28258 L
.63682 .26882 L
.65752 .24668 L
s
.70568 .258 m
.75491 .25955 L
.73103 .28796 L
.68341 .28258 L
.70568 .258 L
s
.75491 .25955 m
.80306 .25147 L
.77761 .28521 L
.73103 .28796 L
.75491 .25955 L
s
.80306 .25147 m
.84804 .23445 L
.82112 .27528 L
.77761 .28521 L
.80306 .25147 L
s
.84804 .23445 m
.88787 .20986 L
.85965 .25987 L
.82112 .27528 L
.84804 .23445 L
s
.88787 .20986 m
.92081 .17995 L
.89152 .24153 L
.85965 .25987 L
.88787 .20986 L
s
.92081 .17995 m
.94543 .14844 L
.91533 .22369 L
.89152 .24153 L
.92081 .17995 L
s
.94543 .14844 m
.96064 .12193 L
.93004 .21046 L
.91533 .22369 L
.94543 .14844 L
s
.96064 .12193 m
.96578 .11085 L
.93502 .20552 L
.93004 .21046 L
.96064 .12193 L
s
.93502 .20552 m
.93004 .21046 L
.88054 .29416 L
.88525 .29174 L
.93502 .20552 L
s
.93004 .21046 m
.91533 .22369 L
.86663 .30076 L
.88054 .29416 L
.93004 .21046 L
s
.91533 .22369 m
.89152 .24153 L
.84412 .30976 L
.86663 .30076 L
.91533 .22369 L
s
.89152 .24153 m
.85965 .25987 L
.81399 .31882 L
.84412 .30976 L
.89152 .24153 L
s
.85965 .25987 m
.82112 .27528 L
.77757 .32559 L
.81399 .31882 L
.85965 .25987 L
s
.82112 .27528 m
.77761 .28521 L
.73644 .32806 L
.77757 .32559 L
.82112 .27528 L
s
.77761 .28521 m
.73103 .28796 L
.6924 .32474 L
.73644 .32806 L
.77761 .28521 L
s
.73103 .28796 m
.68341 .28258 L
.64738 .31477 L
.6924 .32474 L
.73103 .28796 L
s
.68341 .28258 m
.63682 .26882 L
.60334 .29791 L
.64738 .31477 L
.68341 .28258 L
s
.63682 .26882 m
.59332 .24707 L
.56221 .27463 L
.60334 .29791 L
.63682 .26882 L
s
.59332 .24707 m
.55479 .21846 L
.52578 .24619 L
.56221 .27463 L
.59332 .24707 L
s
.55479 .21846 m
.52292 .18503 L
.49566 .21487 L
.52578 .24619 L
.55479 .21846 L
s
.52292 .18503 m
.49911 .15033 L
.47315 .18446 L
.49566 .21487 L
.52292 .18503 L
s
.49911 .15033 m
.48439 .12106 L
.45923 .16095 L
.47315 .18446 L
.49911 .15033 L
s
.48439 .12106 m
.47942 .10868 L
.45453 .15179 L
.45923 .16095 L
.48439 .12106 L
s
.47942 .10868 m
.48439 .12106 L
.45923 .16095 L
.45453 .15179 L
.47942 .10868 L
s
.48439 .12106 m
.49911 .15033 L
.47315 .18446 L
.45923 .16095 L
.48439 .12106 L
s
.49911 .15033 m
.52292 .18503 L
.49566 .21487 L
.47315 .18446 L
.49911 .15033 L
s
.52292 .18503 m
.55479 .21846 L
.52578 .24619 L
.49566 .21487 L
.52292 .18503 L
s
.55479 .21846 m
.59332 .24707 L
.56221 .27463 L
.52578 .24619 L
.55479 .21846 L
s
.59332 .24707 m
.63682 .26882 L
.60334 .29791 L
.56221 .27463 L
.59332 .24707 L
s
.63682 .26882 m
.68341 .28258 L
.64738 .31477 L
.60334 .29791 L
.63682 .26882 L
s
.68341 .28258 m
.73103 .28796 L
.6924 .32474 L
.64738 .31477 L
.68341 .28258 L
s
.73103 .28796 m
.77761 .28521 L
.73644 .32806 L
.6924 .32474 L
.73103 .28796 L
s
.77761 .28521 m
.82112 .27528 L
.77757 .32559 L
.73644 .32806 L
.77761 .28521 L
s
.82112 .27528 m
.85965 .25987 L
.81399 .31882 L
.77757 .32559 L
.82112 .27528 L
s
.85965 .25987 m
.89152 .24153 L
.84412 .30976 L
.81399 .31882 L
.85965 .25987 L
s
.89152 .24153 m
.91533 .22369 L
.86663 .30076 L
.84412 .30976 L
.89152 .24153 L
s
.91533 .22369 m
.93004 .21046 L
.88054 .29416 L
.86663 .30076 L
.91533 .22369 L
s
.93004 .21046 m
.93502 .20552 L
.88525 .29174 L
.88054 .29416 L
.93004 .21046 L
s
.93502 .20552 m
.93004 .21046 L
.88054 .29416 L
.88525 .29174 L
.93502 .20552 L
s
.93004 .21046 m
.91533 .22369 L
.86663 .30076 L
.88054 .29416 L
.93004 .21046 L
s
.91533 .22369 m
.89152 .24153 L
.84412 .30976 L
.86663 .30076 L
.91533 .22369 L
s
.89152 .24153 m
.85965 .25987 L
.81399 .31882 L
.84412 .30976 L
.89152 .24153 L
s
.85965 .25987 m
.82112 .27528 L
.77757 .32559 L
.81399 .31882 L
.85965 .25987 L
s
.82112 .27528 m
.77761 .28521 L
.73644 .32806 L
.77757 .32559 L
.82112 .27528 L
s
.77761 .28521 m
.73103 .28796 L
.6924 .32474 L
.73644 .32806 L
.77761 .28521 L
s
.73103 .28796 m
.68341 .28258 L
.64738 .31477 L
.6924 .32474 L
.73103 .28796 L
s
.68341 .28258 m
.63682 .26882 L
.60334 .29791 L
.64738 .31477 L
.68341 .28258 L
s
.63682 .26882 m
.59332 .24707 L
.56221 .27463 L
.60334 .29791 L
.63682 .26882 L
s
.59332 .24707 m
.55479 .21846 L
.52578 .24619 L
.56221 .27463 L
.59332 .24707 L
s
.55479 .21846 m
.52292 .18503 L
.49566 .21487 L
.52578 .24619 L
.55479 .21846 L
s
.52292 .18503 m
.49911 .15033 L
.47315 .18446 L
.49566 .21487 L
.52292 .18503 L
s
.49911 .15033 m
.48439 .12106 L
.45923 .16095 L
.47315 .18446 L
.49911 .15033 L
s
.48439 .12106 m
.47942 .10868 L
.45453 .15179 L
.45923 .16095 L
.48439 .12106 L
s
.47942 .10868 m
.48439 .12106 L
.45923 .16095 L
.45453 .15179 L
.47942 .10868 L
s
.48439 .12106 m
.49911 .15033 L
.47315 .18446 L
.45923 .16095 L
.48439 .12106 L
s
.49911 .15033 m
.52292 .18503 L
.49566 .21487 L
.47315 .18446 L
.49911 .15033 L
s
.52292 .18503 m
.55479 .21846 L
.52578 .24619 L
.49566 .21487 L
.52292 .18503 L
s
.55479 .21846 m
.59332 .24707 L
.56221 .27463 L
.52578 .24619 L
.55479 .21846 L
s
.59332 .24707 m
.63682 .26882 L
.60334 .29791 L
.56221 .27463 L
.59332 .24707 L
s
.63682 .26882 m
.68341 .28258 L
.64738 .31477 L
.60334 .29791 L
.63682 .26882 L
s
.68341 .28258 m
.73103 .28796 L
.6924 .32474 L
.64738 .31477 L
.68341 .28258 L
s
.73103 .28796 m
.77761 .28521 L
.73644 .32806 L
.6924 .32474 L
.73103 .28796 L
s
.77761 .28521 m
.82112 .27528 L
.77757 .32559 L
.73644 .32806 L
.77761 .28521 L
s
.82112 .27528 m
.85965 .25987 L
.81399 .31882 L
.77757 .32559 L
.82112 .27528 L
s
.85965 .25987 m
.89152 .24153 L
.84412 .30976 L
.81399 .31882 L
.85965 .25987 L
s
.89152 .24153 m
.91533 .22369 L
.86663 .30076 L
.84412 .30976 L
.89152 .24153 L
s
.91533 .22369 m
.93004 .21046 L
.88054 .29416 L
.86663 .30076 L
.91533 .22369 L
s
.93004 .21046 m
.93502 .20552 L
.88525 .29174 L
.88054 .29416 L
.93004 .21046 L
s
.88525 .29174 m
.88054 .29416 L
.81429 .36668 L
.81863 .36572 L
.88525 .29174 L
s
.88054 .29416 m
.86663 .30076 L
.80145 .36919 L
.81429 .36668 L
.88054 .29416 L
s
.86663 .30076 m
.84412 .30976 L
.78068 .37226 L
.80145 .36919 L
.86663 .30076 L
s
.84412 .30976 m
.81399 .31882 L
.75289 .37447 L
.78068 .37226 L
.84412 .30976 L
s
.81399 .31882 m
.77757 .32559 L
.71928 .37428 L
.75289 .37447 L
.81399 .31882 L
s
.77757 .32559 m
.73644 .32806 L
.68133 .3703 L
.71928 .37428 L
.77757 .32559 L
s
.73644 .32806 m
.6924 .32474 L
.6407 .36145 L
.68133 .3703 L
.73644 .32806 L
s
.6924 .32474 m
.64738 .31477 L
.59916 .34712 L
.6407 .36145 L
.6924 .32474 L
s
.64738 .31477 m
.60334 .29791 L
.55852 .32723 L
.59916 .34712 L
.64738 .31477 L
s
.60334 .29791 m
.56221 .27463 L
.52057 .30236 L
.55852 .32723 L
.60334 .29791 L
s
.56221 .27463 m
.52578 .24619 L
.48697 .27385 L
.52057 .30236 L
.56221 .27463 L
s
.52578 .24619 m
.49566 .21487 L
.45917 .24404 L
.48697 .27385 L
.52578 .24619 L
s
.49566 .21487 m
.47315 .18446 L
.4384 .21653 L
.45917 .24404 L
.49566 .21487 L
s
.47315 .18446 m
.45923 .16095 L
.42556 .19634 L
.4384 .21653 L
.47315 .18446 L
s
.45923 .16095 m
.45453 .15179 L
.42122 .18878 L
.42556 .19634 L
.45923 .16095 L
s
.45453 .15179 m
.45923 .16095 L
.42556 .19634 L
.42122 .18878 L
.45453 .15179 L
s
.45923 .16095 m
.47315 .18446 L
.4384 .21653 L
.42556 .19634 L
.45923 .16095 L
s
.47315 .18446 m
.49566 .21487 L
.45917 .24404 L
.4384 .21653 L
.47315 .18446 L
s
.49566 .21487 m
.52578 .24619 L
.48697 .27385 L
.45917 .24404 L
.49566 .21487 L
s
.52578 .24619 m
.56221 .27463 L
.52057 .30236 L
.48697 .27385 L
.52578 .24619 L
s
.56221 .27463 m
.60334 .29791 L
.55852 .32723 L
.52057 .30236 L
.56221 .27463 L
s
.60334 .29791 m
.64738 .31477 L
.59916 .34712 L
.55852 .32723 L
.60334 .29791 L
s
.64738 .31477 m
.6924 .32474 L
.6407 .36145 L
.59916 .34712 L
.64738 .31477 L
s
.6924 .32474 m
.73644 .32806 L
.68133 .3703 L
.6407 .36145 L
.6924 .32474 L
s
.73644 .32806 m
.77757 .32559 L
.71928 .37428 L
.68133 .3703 L
.73644 .32806 L
s
.77757 .32559 m
.81399 .31882 L
.75289 .37447 L
.71928 .37428 L
.77757 .32559 L
s
.81399 .31882 m
.84412 .30976 L
.78068 .37226 L
.75289 .37447 L
.81399 .31882 L
s
.84412 .30976 m
.86663 .30076 L
.80145 .36919 L
.78068 .37226 L
.84412 .30976 L
s
.86663 .30076 m
.88054 .29416 L
.81429 .36668 L
.80145 .36919 L
.86663 .30076 L
s
.88054 .29416 m
.88525 .29174 L
.81863 .36572 L
.81429 .36668 L
.88054 .29416 L
s
.88525 .29174 m
.88054 .29416 L
.81429 .36668 L
.81863 .36572 L
.88525 .29174 L
s
.88054 .29416 m
.86663 .30076 L
.80145 .36919 L
.81429 .36668 L
.88054 .29416 L
s
.86663 .30076 m
.84412 .30976 L
.78068 .37226 L
.80145 .36919 L
.86663 .30076 L
s
.84412 .30976 m
.81399 .31882 L
.75289 .37447 L
.78068 .37226 L
.84412 .30976 L
s
.81399 .31882 m
.77757 .32559 L
.71928 .37428 L
.75289 .37447 L
.81399 .31882 L
s
.77757 .32559 m
.73644 .32806 L
.68133 .3703 L
.71928 .37428 L
.77757 .32559 L
s
.73644 .32806 m
.6924 .32474 L
.6407 .36145 L
.68133 .3703 L
.73644 .32806 L
s
.6924 .32474 m
.64738 .31477 L
.59916 .34712 L
.6407 .36145 L
.6924 .32474 L
s
.64738 .31477 m
.60334 .29791 L
.55852 .32723 L
.59916 .34712 L
.64738 .31477 L
s
.60334 .29791 m
.56221 .27463 L
.52057 .30236 L
.55852 .32723 L
.60334 .29791 L
s
.56221 .27463 m
.52578 .24619 L
.48697 .27385 L
.52057 .30236 L
.56221 .27463 L
s
.52578 .24619 m
.49566 .21487 L
.45917 .24404 L
.48697 .27385 L
.52578 .24619 L
s
.49566 .21487 m
.47315 .18446 L
.4384 .21653 L
.45917 .24404 L
.49566 .21487 L
s
.47315 .18446 m
.45923 .16095 L
.42556 .19634 L
.4384 .21653 L
.47315 .18446 L
s
.45923 .16095 m
.45453 .15179 L
.42122 .18878 L
.42556 .19634 L
.45923 .16095 L
s
.45453 .15179 m
.45923 .16095 L
.42556 .19634 L
.42122 .18878 L
.45453 .15179 L
s
.45923 .16095 m
.47315 .18446 L
.4384 .21653 L
.42556 .19634 L
.45923 .16095 L
s
.47315 .18446 m
.49566 .21487 L
.45917 .24404 L
.4384 .21653 L
.47315 .18446 L
s
.49566 .21487 m
.52578 .24619 L
.48697 .27385 L
.45917 .24404 L
.49566 .21487 L
s
.52578 .24619 m
.56221 .27463 L
.52057 .30236 L
.48697 .27385 L
.52578 .24619 L
s
.56221 .27463 m
.60334 .29791 L
.55852 .32723 L
.52057 .30236 L
.56221 .27463 L
s
.60334 .29791 m
.64738 .31477 L
.59916 .34712 L
.55852 .32723 L
.60334 .29791 L
s
.64738 .31477 m
.6924 .32474 L
.6407 .36145 L
.59916 .34712 L
.64738 .31477 L
s
.6924 .32474 m
.73644 .32806 L
.68133 .3703 L
.6407 .36145 L
.6924 .32474 L
s
.73644 .32806 m
.77757 .32559 L
.71928 .37428 L
.68133 .3703 L
.73644 .32806 L
s
.77757 .32559 m
.81399 .31882 L
.75289 .37447 L
.71928 .37428 L
.77757 .32559 L
s
.81399 .31882 m
.84412 .30976 L
.78068 .37226 L
.75289 .37447 L
.81399 .31882 L
s
.84412 .30976 m
.86663 .30076 L
.80145 .36919 L
.78068 .37226 L
.84412 .30976 L
s
.86663 .30076 m
.88054 .29416 L
.81429 .36668 L
.80145 .36919 L
.86663 .30076 L
s
.88054 .29416 m
.88525 .29174 L
.81863 .36572 L
.81429 .36668 L
.88054 .29416 L
s
.81863 .36572 m
.81429 .36668 L
.73419 .42421 L
.7381 .42423 L
.81863 .36572 L
s
.81429 .36668 m
.80145 .36919 L
.72266 .42394 L
.73419 .42421 L
.81429 .36668 L
s
.80145 .36919 m
.78068 .37226 L
.70399 .42282 L
.72266 .42394 L
.80145 .36919 L
s
.78068 .37226 m
.75289 .37447 L
.67901 .41998 L
.70399 .42282 L
.78068 .37226 L
s
.75289 .37447 m
.71928 .37428 L
.64881 .41445 L
.67901 .41998 L
.75289 .37447 L
s
.71928 .37428 m
.68133 .3703 L
.61471 .40534 L
.64881 .41445 L
.71928 .37428 L
s
.68133 .3703 m
.6407 .36145 L
.57819 .39197 L
.61471 .40534 L
.68133 .3703 L
s
.6407 .36145 m
.59916 .34712 L
.54086 .37401 L
.57819 .39197 L
.6407 .36145 L
s
.59916 .34712 m
.55852 .32723 L
.50434 .35159 L
.54086 .37401 L
.59916 .34712 L
s
.55852 .32723 m
.52057 .30236 L
.47024 .3254 L
.50434 .35159 L
.55852 .32723 L
s
.52057 .30236 m
.48697 .27385 L
.44004 .29685 L
.47024 .3254 L
.52057 .30236 L
s
.48697 .27385 m
.45917 .24404 L
.41506 .26819 L
.44004 .29685 L
.48697 .27385 L
s
.45917 .24404 m
.4384 .21653 L
.39639 .24272 L
.41506 .26819 L
.45917 .24404 L
s
.4384 .21653 m
.42556 .19634 L
.38485 .22465 L
.39639 .24272 L
.4384 .21653 L
s
.42556 .19634 m
.42122 .18878 L
.38095 .21804 L
.38485 .22465 L
.42556 .19634 L
s
.42122 .18878 m
.42556 .19634 L
.38485 .22465 L
.38095 .21804 L
.42122 .18878 L
s
.42556 .19634 m
.4384 .21653 L
.39639 .24272 L
.38485 .22465 L
.42556 .19634 L
s
.4384 .21653 m
.45917 .24404 L
.41506 .26819 L
.39639 .24272 L
.4384 .21653 L
s
.45917 .24404 m
.48697 .27385 L
.44004 .29685 L
.41506 .26819 L
.45917 .24404 L
s
.48697 .27385 m
.52057 .30236 L
.47024 .3254 L
.44004 .29685 L
.48697 .27385 L
s
.52057 .30236 m
.55852 .32723 L
.50434 .35159 L
.47024 .3254 L
.52057 .30236 L
s
.55852 .32723 m
.59916 .34712 L
.54086 .37401 L
.50434 .35159 L
.55852 .32723 L
s
.59916 .34712 m
.6407 .36145 L
.57819 .39197 L
.54086 .37401 L
.59916 .34712 L
s
.6407 .36145 m
.68133 .3703 L
.61471 .40534 L
.57819 .39197 L
.6407 .36145 L
s
.68133 .3703 m
.71928 .37428 L
.64881 .41445 L
.61471 .40534 L
.68133 .3703 L
s
.71928 .37428 m
.75289 .37447 L
.67901 .41998 L
.64881 .41445 L
.71928 .37428 L
s
.75289 .37447 m
.78068 .37226 L
.70399 .42282 L
.67901 .41998 L
.75289 .37447 L
s
.78068 .37226 m
.80145 .36919 L
.72266 .42394 L
.70399 .42282 L
.78068 .37226 L
s
.80145 .36919 m
.81429 .36668 L
.73419 .42421 L
.72266 .42394 L
.80145 .36919 L
s
.81429 .36668 m
.81863 .36572 L
.7381 .42423 L
.73419 .42421 L
.81429 .36668 L
s
.81863 .36572 m
.81429 .36668 L
.73419 .42421 L
.7381 .42423 L
.81863 .36572 L
s
.81429 .36668 m
.80145 .36919 L
.72266 .42394 L
.73419 .42421 L
.81429 .36668 L
s
.80145 .36919 m
.78068 .37226 L
.70399 .42282 L
.72266 .42394 L
.80145 .36919 L
s
.78068 .37226 m
.75289 .37447 L
.67901 .41998 L
.70399 .42282 L
.78068 .37226 L
s
.75289 .37447 m
.71928 .37428 L
.64881 .41445 L
.67901 .41998 L
.75289 .37447 L
s
.71928 .37428 m
.68133 .3703 L
.61471 .40534 L
.64881 .41445 L
.71928 .37428 L
s
.68133 .3703 m
.6407 .36145 L
.57819 .39197 L
.61471 .40534 L
.68133 .3703 L
s
.6407 .36145 m
.59916 .34712 L
.54086 .37401 L
.57819 .39197 L
.6407 .36145 L
s
.59916 .34712 m
.55852 .32723 L
.50434 .35159 L
.54086 .37401 L
.59916 .34712 L
s
.55852 .32723 m
.52057 .30236 L
.47024 .3254 L
.50434 .35159 L
.55852 .32723 L
s
.52057 .30236 m
.48697 .27385 L
.44004 .29685 L
.47024 .3254 L
.52057 .30236 L
s
.48697 .27385 m
.45917 .24404 L
.41506 .26819 L
.44004 .29685 L
.48697 .27385 L
s
.45917 .24404 m
.4384 .21653 L
.39639 .24272 L
.41506 .26819 L
.45917 .24404 L
s
.4384 .21653 m
.42556 .19634 L
.38485 .22465 L
.39639 .24272 L
.4384 .21653 L
s
.42556 .19634 m
.42122 .18878 L
.38095 .21804 L
.38485 .22465 L
.42556 .19634 L
s
.42122 .18878 m
.42556 .19634 L
.38485 .22465 L
.38095 .21804 L
.42122 .18878 L
s
.42556 .19634 m
.4384 .21653 L
.39639 .24272 L
.38485 .22465 L
.42556 .19634 L
s
.4384 .21653 m
.45917 .24404 L
.41506 .26819 L
.39639 .24272 L
.4384 .21653 L
s
.45917 .24404 m
.48697 .27385 L
.44004 .29685 L
.41506 .26819 L
.45917 .24404 L
s
.48697 .27385 m
.52057 .30236 L
.47024 .3254 L
.44004 .29685 L
.48697 .27385 L
s
.52057 .30236 m
.55852 .32723 L
.50434 .35159 L
.47024 .3254 L
.52057 .30236 L
s
.55852 .32723 m
.59916 .34712 L
.54086 .37401 L
.50434 .35159 L
.55852 .32723 L
s
.59916 .34712 m
.6407 .36145 L
.57819 .39197 L
.54086 .37401 L
.59916 .34712 L
s
.6407 .36145 m
.68133 .3703 L
.61471 .40534 L
.57819 .39197 L
.6407 .36145 L
s
.68133 .3703 m
.71928 .37428 L
.64881 .41445 L
.61471 .40534 L
.68133 .3703 L
s
.71928 .37428 m
.75289 .37447 L
.67901 .41998 L
.64881 .41445 L
.71928 .37428 L
s
.75289 .37447 m
.78068 .37226 L
.70399 .42282 L
.67901 .41998 L
.75289 .37447 L
s
.78068 .37226 m
.80145 .36919 L
.72266 .42394 L
.70399 .42282 L
.78068 .37226 L
s
.80145 .36919 m
.81429 .36668 L
.73419 .42421 L
.72266 .42394 L
.80145 .36919 L
s
.81429 .36668 m
.81863 .36572 L
.7381 .42423 L
.73419 .42421 L
.81429 .36668 L
s
.7381 .42423 m
.73419 .42421 L
.64375 .46403 L
.64715 .46472 L
.7381 .42423 L
s
.73419 .42421 m
.72266 .42394 L
.63368 .46181 L
.64375 .46403 L
.73419 .42421 L
s
.72266 .42394 m
.70399 .42282 L
.61739 .45771 L
.63368 .46181 L
.72266 .42394 L
s
.70399 .42282 m
.67901 .41998 L
.59559 .45123 L
.61739 .45771 L
.70399 .42282 L
s
.67901 .41998 m
.64881 .41445 L
.56923 .44179 L
.59559 .45123 L
.67901 .41998 L
s
.64881 .41445 m
.61471 .40534 L
.53947 .42888 L
.56923 .44179 L
.64881 .41445 L
s
.61471 .40534 m
.57819 .39197 L
.5076 .41215 L
.53947 .42888 L
.61471 .40534 L
s
.57819 .39197 m
.54086 .37401 L
.47503 .39154 L
.5076 .41215 L
.57819 .39197 L
s
.54086 .37401 m
.50434 .35159 L
.44316 .36735 L
.47503 .39154 L
.54086 .37401 L
s
.50434 .35159 m
.47024 .3254 L
.4134 .34039 L
.44316 .36735 L
.50434 .35159 L
s
.47024 .3254 m
.44004 .29685 L
.38704 .31207 L
.4134 .34039 L
.47024 .3254 L
s
.44004 .29685 m
.41506 .26819 L
.36524 .28452 L
.38704 .31207 L
.44004 .29685 L
s
.41506 .26819 m
.39639 .24272 L
.34895 .26072 L
.36524 .28452 L
.41506 .26819 L
s
.39639 .24272 m
.38485 .22465 L
.33889 .24423 L
.34895 .26072 L
.39639 .24272 L
s
.38485 .22465 m
.38095 .21804 L
.33548 .23828 L
.33889 .24423 L
.38485 .22465 L
s
.38095 .21804 m
.38485 .22465 L
.33889 .24423 L
.33548 .23828 L
.38095 .21804 L
s
.38485 .22465 m
.39639 .24272 L
.34895 .26072 L
.33889 .24423 L
.38485 .22465 L
s
.39639 .24272 m
.41506 .26819 L
.36524 .28452 L
.34895 .26072 L
.39639 .24272 L
s
.41506 .26819 m
.44004 .29685 L
.38704 .31207 L
.36524 .28452 L
.41506 .26819 L
s
.44004 .29685 m
.47024 .3254 L
.4134 .34039 L
.38704 .31207 L
.44004 .29685 L
s
.47024 .3254 m
.50434 .35159 L
.44316 .36735 L
.4134 .34039 L
.47024 .3254 L
s
.50434 .35159 m
.54086 .37401 L
.47503 .39154 L
.44316 .36735 L
.50434 .35159 L
s
.54086 .37401 m
.57819 .39197 L
.5076 .41215 L
.47503 .39154 L
.54086 .37401 L
s
.57819 .39197 m
.61471 .40534 L
.53947 .42888 L
.5076 .41215 L
.57819 .39197 L
s
.61471 .40534 m
.64881 .41445 L
.56923 .44179 L
.53947 .42888 L
.61471 .40534 L
s
.64881 .41445 m
.67901 .41998 L
.59559 .45123 L
.56923 .44179 L
.64881 .41445 L
s
.67901 .41998 m
.70399 .42282 L
.61739 .45771 L
.59559 .45123 L
.67901 .41998 L
s
.70399 .42282 m
.72266 .42394 L
.63368 .46181 L
.61739 .45771 L
.70399 .42282 L
s
.72266 .42394 m
.73419 .42421 L
.64375 .46403 L
.63368 .46181 L
.72266 .42394 L
s
.73419 .42421 m
.7381 .42423 L
.64715 .46472 L
.64375 .46403 L
.73419 .42421 L
s
.7381 .42423 m
.73419 .42421 L
.64375 .46403 L
.64715 .46472 L
.7381 .42423 L
s
.73419 .42421 m
.72266 .42394 L
.63368 .46181 L
.64375 .46403 L
.73419 .42421 L
s
.72266 .42394 m
.70399 .42282 L
.61739 .45771 L
.63368 .46181 L
.72266 .42394 L
s
.70399 .42282 m
.67901 .41998 L
.59559 .45123 L
.61739 .45771 L
.70399 .42282 L
s
.67901 .41998 m
.64881 .41445 L
.56923 .44179 L
.59559 .45123 L
.67901 .41998 L
s
.64881 .41445 m
.61471 .40534 L
.53947 .42888 L
.56923 .44179 L
.64881 .41445 L
s
.61471 .40534 m
.57819 .39197 L
.5076 .41215 L
.53947 .42888 L
.61471 .40534 L
s
.57819 .39197 m
.54086 .37401 L
.47503 .39154 L
.5076 .41215 L
.57819 .39197 L
s
.54086 .37401 m
.50434 .35159 L
.44316 .36735 L
.47503 .39154 L
.54086 .37401 L
s
.50434 .35159 m
.47024 .3254 L
.4134 .34039 L
.44316 .36735 L
.50434 .35159 L
s
.47024 .3254 m
.44004 .29685 L
.38704 .31207 L
.4134 .34039 L
.47024 .3254 L
s
.44004 .29685 m
.41506 .26819 L
.36524 .28452 L
.38704 .31207 L
.44004 .29685 L
s
.41506 .26819 m
.39639 .24272 L
.34895 .26072 L
.36524 .28452 L
.41506 .26819 L
s
.39639 .24272 m
.38485 .22465 L
.33889 .24423 L
.34895 .26072 L
.39639 .24272 L
s
.38485 .22465 m
.38095 .21804 L
.33548 .23828 L
.33889 .24423 L
.38485 .22465 L
s
.38095 .21804 m
.38485 .22465 L
.33889 .24423 L
.33548 .23828 L
.38095 .21804 L
s
.38485 .22465 m
.39639 .24272 L
.34895 .26072 L
.33889 .24423 L
.38485 .22465 L
s
.39639 .24272 m
.41506 .26819 L
.36524 .28452 L
.34895 .26072 L
.39639 .24272 L
s
.41506 .26819 m
.44004 .29685 L
.38704 .31207 L
.36524 .28452 L
.41506 .26819 L
s
.44004 .29685 m
.47024 .3254 L
.4134 .34039 L
.38704 .31207 L
.44004 .29685 L
s
.47024 .3254 m
.50434 .35159 L
.44316 .36735 L
.4134 .34039 L
.47024 .3254 L
s
.50434 .35159 m
.54086 .37401 L
.47503 .39154 L
.44316 .36735 L
.50434 .35159 L
s
.54086 .37401 m
.57819 .39197 L
.5076 .41215 L
.47503 .39154 L
.54086 .37401 L
s
.57819 .39197 m
.61471 .40534 L
.53947 .42888 L
.5076 .41215 L
.57819 .39197 L
s
.61471 .40534 m
.64881 .41445 L
.56923 .44179 L
.53947 .42888 L
.61471 .40534 L
s
.64881 .41445 m
.67901 .41998 L
.59559 .45123 L
.56923 .44179 L
.64881 .41445 L
s
.67901 .41998 m
.70399 .42282 L
.61739 .45771 L
.59559 .45123 L
.67901 .41998 L
s
.70399 .42282 m
.72266 .42394 L
.63368 .46181 L
.61739 .45771 L
.70399 .42282 L
s
.72266 .42394 m
.73419 .42421 L
.64375 .46403 L
.63368 .46181 L
.72266 .42394 L
s
.73419 .42421 m
.7381 .42423 L
.64715 .46472 L
.64375 .46403 L
.73419 .42421 L
s
.64715 .46472 m
.64375 .46403 L
.5469 .48427 L
.54978 .48542 L
.64715 .46472 L
s
.64375 .46403 m
.63368 .46181 L
.53841 .48074 L
.5469 .48427 L
.64375 .46403 L
s
.63368 .46181 m
.61739 .45771 L
.52466 .47465 L
.53841 .48074 L
.63368 .46181 L
s
.61739 .45771 m
.59559 .45123 L
.50627 .46571 L
.52466 .47465 L
.61739 .45771 L
s
.59559 .45123 m
.56923 .44179 L
.48403 .45365 L
.50627 .46571 L
.59559 .45123 L
s
.56923 .44179 m
.53947 .42888 L
.45892 .43822 L
.48403 .45365 L
.56923 .44179 L
s
.53947 .42888 m
.5076 .41215 L
.43203 .41935 L
.45892 .43822 L
.53947 .42888 L
s
.5076 .41215 m
.47503 .39154 L
.40454 .39718 L
.43203 .41935 L
.5076 .41215 L
s
.47503 .39154 m
.44316 .36735 L
.37765 .37215 L
.40454 .39718 L
.47503 .39154 L
s
.44316 .36735 m
.4134 .34039 L
.35254 .34514 L
.37765 .37215 L
.44316 .36735 L
s
.4134 .34039 m
.38704 .31207 L
.3303 .31753 L
.35254 .34514 L
.4134 .34039 L
s
.38704 .31207 m
.36524 .28452 L
.31191 .29131 L
.3303 .31753 L
.38704 .31207 L
s
.36524 .28452 m
.34895 .26072 L
.29816 .26914 L
.31191 .29131 L
.36524 .28452 L
s
.34895 .26072 m
.33889 .24423 L
.28967 .25403 L
.29816 .26914 L
.34895 .26072 L
s
.33889 .24423 m
.33548 .23828 L
.28679 .24863 L
.28967 .25403 L
.33889 .24423 L
s
.33548 .23828 m
.33889 .24423 L
.28967 .25403 L
.28679 .24863 L
.33548 .23828 L
s
.33889 .24423 m
.34895 .26072 L
.29816 .26914 L
.28967 .25403 L
.33889 .24423 L
s
.34895 .26072 m
.36524 .28452 L
.31191 .29131 L
.29816 .26914 L
.34895 .26072 L
s
.36524 .28452 m
.38704 .31207 L
.3303 .31753 L
.31191 .29131 L
.36524 .28452 L
s
.38704 .31207 m
.4134 .34039 L
.35254 .34514 L
.3303 .31753 L
.38704 .31207 L
s
.4134 .34039 m
.44316 .36735 L
.37765 .37215 L
.35254 .34514 L
.4134 .34039 L
s
.44316 .36735 m
.47503 .39154 L
.40454 .39718 L
.37765 .37215 L
.44316 .36735 L
s
.47503 .39154 m
.5076 .41215 L
.43203 .41935 L
.40454 .39718 L
.47503 .39154 L
s
.5076 .41215 m
.53947 .42888 L
.45892 .43822 L
.43203 .41935 L
.5076 .41215 L
s
.53947 .42888 m
.56923 .44179 L
.48403 .45365 L
.45892 .43822 L
.53947 .42888 L
s
.56923 .44179 m
.59559 .45123 L
.50627 .46571 L
.48403 .45365 L
.56923 .44179 L
s
.59559 .45123 m
.61739 .45771 L
.52466 .47465 L
.50627 .46571 L
.59559 .45123 L
s
.61739 .45771 m
.63368 .46181 L
.53841 .48074 L
.52466 .47465 L
.61739 .45771 L
s
.63368 .46181 m
.64375 .46403 L
.5469 .48427 L
.53841 .48074 L
.63368 .46181 L
s
.64375 .46403 m
.64715 .46472 L
.54978 .48542 L
.5469 .48427 L
.64375 .46403 L
s
.64715 .46472 m
.64375 .46403 L
.5469 .48427 L
.54978 .48542 L
.64715 .46472 L
s
.64375 .46403 m
.63368 .46181 L
.53841 .48074 L
.5469 .48427 L
.64375 .46403 L
s
.63368 .46181 m
.61739 .45771 L
.52466 .47465 L
.53841 .48074 L
.63368 .46181 L
s
.61739 .45771 m
.59559 .45123 L
.50627 .46571 L
.52466 .47465 L
.61739 .45771 L
s
.59559 .45123 m
.56923 .44179 L
.48403 .45365 L
.50627 .46571 L
.59559 .45123 L
s
.56923 .44179 m
.53947 .42888 L
.45892 .43822 L
.48403 .45365 L
.56923 .44179 L
s
.53947 .42888 m
.5076 .41215 L
.43203 .41935 L
.45892 .43822 L
.53947 .42888 L
s
.5076 .41215 m
.47503 .39154 L
.40454 .39718 L
.43203 .41935 L
.5076 .41215 L
s
.47503 .39154 m
.44316 .36735 L
.37765 .37215 L
.40454 .39718 L
.47503 .39154 L
s
.44316 .36735 m
.4134 .34039 L
.35254 .34514 L
.37765 .37215 L
.44316 .36735 L
s
.4134 .34039 m
.38704 .31207 L
.3303 .31753 L
.35254 .34514 L
.4134 .34039 L
s
.38704 .31207 m
.36524 .28452 L
.31191 .29131 L
.3303 .31753 L
.38704 .31207 L
s
.36524 .28452 m
.34895 .26072 L
.29816 .26914 L
.31191 .29131 L
.36524 .28452 L
s
.34895 .26072 m
.33889 .24423 L
.28967 .25403 L
.29816 .26914 L
.34895 .26072 L
s
.33889 .24423 m
.33548 .23828 L
.28679 .24863 L
.28967 .25403 L
.33889 .24423 L
s
.33548 .23828 m
.33889 .24423 L
.28967 .25403 L
.28679 .24863 L
.33548 .23828 L
s
.33889 .24423 m
.34895 .26072 L
.29816 .26914 L
.28967 .25403 L
.33889 .24423 L
s
.34895 .26072 m
.36524 .28452 L
.31191 .29131 L
.29816 .26914 L
.34895 .26072 L
s
.36524 .28452 m
.38704 .31207 L
.3303 .31753 L
.31191 .29131 L
.36524 .28452 L
s
.38704 .31207 m
.4134 .34039 L
.35254 .34514 L
.3303 .31753 L
.38704 .31207 L
s
.4134 .34039 m
.44316 .36735 L
.37765 .37215 L
.35254 .34514 L
.4134 .34039 L
s
.44316 .36735 m
.47503 .39154 L
.40454 .39718 L
.37765 .37215 L
.44316 .36735 L
s
.47503 .39154 m
.5076 .41215 L
.43203 .41935 L
.40454 .39718 L
.47503 .39154 L
s
.5076 .41215 m
.53947 .42888 L
.45892 .43822 L
.43203 .41935 L
.5076 .41215 L
s
.53947 .42888 m
.56923 .44179 L
.48403 .45365 L
.45892 .43822 L
.53947 .42888 L
s
.56923 .44179 m
.59559 .45123 L
.50627 .46571 L
.48403 .45365 L
.56923 .44179 L
s
.59559 .45123 m
.61739 .45771 L
.52466 .47465 L
.50627 .46571 L
.59559 .45123 L
s
.61739 .45771 m
.63368 .46181 L
.53841 .48074 L
.52466 .47465 L
.61739 .45771 L
s
.63368 .46181 m
.64375 .46403 L
.5469 .48427 L
.53841 .48074 L
.63368 .46181 L
s
.64375 .46403 m
.64715 .46472 L
.54978 .48542 L
.5469 .48427 L
.64375 .46403 L
s
.54978 .48542 m
.5469 .48427 L
.44789 .484 L
.45022 .48542 L
.54978 .48542 L
s
.5469 .48427 m
.53841 .48074 L
.44101 .47969 L
.44789 .484 L
.5469 .48427 L
s
.53841 .48074 m
.52466 .47465 L
.42987 .47243 L
.44101 .47969 L
.53841 .48074 L
s
.52466 .47465 m
.50627 .46571 L
.41495 .46209 L
.42987 .47243 L
.52466 .47465 L
s
.50627 .46571 m
.48403 .45365 L
.39692 .44859 L
.41495 .46209 L
.50627 .46571 L
s
.48403 .45365 m
.45892 .43822 L
.37656 .43189 L
.39692 .44859 L
.48403 .45365 L
s
.45892 .43822 m
.43203 .41935 L
.35476 .4121 L
.37656 .43189 L
.45892 .43822 L
s
.43203 .41935 m
.40454 .39718 L
.33248 .3895 L
.35476 .4121 L
.43203 .41935 L
s
.40454 .39718 m
.37765 .37215 L
.31068 .36463 L
.33248 .3895 L
.40454 .39718 L
s
.37765 .37215 m
.35254 .34514 L
.29032 .33841 L
.31068 .36463 L
.37765 .37215 L
s
.35254 .34514 m
.3303 .31753 L
.27229 .31213 L
.29032 .33841 L
.35254 .34514 L
s
.3303 .31753 m
.31191 .29131 L
.25738 .28763 L
.27229 .31213 L
.3303 .31753 L
s
.31191 .29131 m
.29816 .26914 L
.24623 .26722 L
.25738 .28763 L
.31191 .29131 L
s
.29816 .26914 m
.28967 .25403 L
.23935 .2535 L
.24623 .26722 L
.29816 .26914 L
s
.28967 .25403 m
.28679 .24863 L
.23702 .24863 L
.23935 .2535 L
.28967 .25403 L
s
.28679 .24863 m
.28967 .25403 L
.23935 .2535 L
.23702 .24863 L
.28679 .24863 L
s
.28967 .25403 m
.29816 .26914 L
.24623 .26722 L
.23935 .2535 L
.28967 .25403 L
s
.29816 .26914 m
.31191 .29131 L
.25738 .28763 L
.24623 .26722 L
.29816 .26914 L
s
.31191 .29131 m
.3303 .31753 L
.27229 .31213 L
.25738 .28763 L
.31191 .29131 L
s
.3303 .31753 m
.35254 .34514 L
.29032 .33841 L
.27229 .31213 L
.3303 .31753 L
s
.35254 .34514 m
.37765 .37215 L
.31068 .36463 L
.29032 .33841 L
.35254 .34514 L
s
.37765 .37215 m
.40454 .39718 L
.33248 .3895 L
.31068 .36463 L
.37765 .37215 L
s
.40454 .39718 m
.43203 .41935 L
.35476 .4121 L
.33248 .3895 L
.40454 .39718 L
s
.43203 .41935 m
.45892 .43822 L
.37656 .43189 L
.35476 .4121 L
.43203 .41935 L
s
.45892 .43822 m
.48403 .45365 L
.39692 .44859 L
.37656 .43189 L
.45892 .43822 L
s
.48403 .45365 m
.50627 .46571 L
.41495 .46209 L
.39692 .44859 L
.48403 .45365 L
s
.50627 .46571 m
.52466 .47465 L
.42987 .47243 L
.41495 .46209 L
.50627 .46571 L
s
.52466 .47465 m
.53841 .48074 L
.44101 .47969 L
.42987 .47243 L
.52466 .47465 L
s
.53841 .48074 m
.5469 .48427 L
.44789 .484 L
.44101 .47969 L
.53841 .48074 L
s
.5469 .48427 m
.54978 .48542 L
.45022 .48542 L
.44789 .484 L
.5469 .48427 L
s
.54978 .48542 m
.5469 .48427 L
.44789 .484 L
.45022 .48542 L
.54978 .48542 L
s
.5469 .48427 m
.53841 .48074 L
.44101 .47969 L
.44789 .484 L
.5469 .48427 L
s
.53841 .48074 m
.52466 .47465 L
.42987 .47243 L
.44101 .47969 L
.53841 .48074 L
s
.52466 .47465 m
.50627 .46571 L
.41495 .46209 L
.42987 .47243 L
.52466 .47465 L
s
.50627 .46571 m
.48403 .45365 L
.39692 .44859 L
.41495 .46209 L
.50627 .46571 L
s
.48403 .45365 m
.45892 .43822 L
.37656 .43189 L
.39692 .44859 L
.48403 .45365 L
s
.45892 .43822 m
.43203 .41935 L
.35476 .4121 L
.37656 .43189 L
.45892 .43822 L
s
.43203 .41935 m
.40454 .39718 L
.33248 .3895 L
.35476 .4121 L
.43203 .41935 L
s
.40454 .39718 m
.37765 .37215 L
.31068 .36463 L
.33248 .3895 L
.40454 .39718 L
s
.37765 .37215 m
.35254 .34514 L
.29032 .33841 L
.31068 .36463 L
.37765 .37215 L
s
.35254 .34514 m
.3303 .31753 L
.27229 .31213 L
.29032 .33841 L
.35254 .34514 L
s
.3303 .31753 m
.31191 .29131 L
.25738 .28763 L
.27229 .31213 L
.3303 .31753 L
s
.31191 .29131 m
.29816 .26914 L
.24623 .26722 L
.25738 .28763 L
.31191 .29131 L
s
.29816 .26914 m
.28967 .25403 L
.23935 .2535 L
.24623 .26722 L
.29816 .26914 L
s
.28967 .25403 m
.28679 .24863 L
.23702 .24863 L
.23935 .2535 L
.28967 .25403 L
s
.28679 .24863 m
.28967 .25403 L
.23935 .2535 L
.23702 .24863 L
.28679 .24863 L
s
.28967 .25403 m
.29816 .26914 L
.24623 .26722 L
.23935 .2535 L
.28967 .25403 L
s
.29816 .26914 m
.31191 .29131 L
.25738 .28763 L
.24623 .26722 L
.29816 .26914 L
s
.31191 .29131 m
.3303 .31753 L
.27229 .31213 L
.25738 .28763 L
.31191 .29131 L
s
.3303 .31753 m
.35254 .34514 L
.29032 .33841 L
.27229 .31213 L
.3303 .31753 L
s
.35254 .34514 m
.37765 .37215 L
.31068 .36463 L
.29032 .33841 L
.35254 .34514 L
s
.37765 .37215 m
.40454 .39718 L
.33248 .3895 L
.31068 .36463 L
.37765 .37215 L
s
.40454 .39718 m
.43203 .41935 L
.35476 .4121 L
.33248 .3895 L
.40454 .39718 L
s
.43203 .41935 m
.45892 .43822 L
.37656 .43189 L
.35476 .4121 L
.43203 .41935 L
s
.45892 .43822 m
.48403 .45365 L
.39692 .44859 L
.37656 .43189 L
.45892 .43822 L
s
.48403 .45365 m
.50627 .46571 L
.41495 .46209 L
.39692 .44859 L
.48403 .45365 L
s
.50627 .46571 m
.52466 .47465 L
.42987 .47243 L
.41495 .46209 L
.50627 .46571 L
s
.52466 .47465 m
.53841 .48074 L
.44101 .47969 L
.42987 .47243 L
.52466 .47465 L
s
.53841 .48074 m
.5469 .48427 L
.44789 .484 L
.44101 .47969 L
.53841 .48074 L
s
.5469 .48427 m
.54978 .48542 L
.45022 .48542 L
.44789 .484 L
.5469 .48427 L
s
.45022 .48542 m
.44789 .484 L
.35105 .46319 L
.35285 .46472 L
.45022 .48542 L
s
.44789 .484 m
.44101 .47969 L
.34574 .45858 L
.35105 .46319 L
.44789 .484 L
s
.44101 .47969 m
.42987 .47243 L
.33714 .45088 L
.34574 .45858 L
.44101 .47969 L
s
.42987 .47243 m
.41495 .46209 L
.32563 .44008 L
.33714 .45088 L
.42987 .47243 L
s
.41495 .46209 m
.39692 .44859 L
.31172 .42623 L
.32563 .44008 L
.41495 .46209 L
s
.39692 .44859 m
.37656 .43189 L
.29601 .40943 L
.31172 .42623 L
.39692 .44859 L
s
.37656 .43189 m
.35476 .4121 L
.27919 .38989 L
.29601 .40943 L
.37656 .43189 L
s
.35476 .4121 m
.33248 .3895 L
.26199 .36799 L
.27919 .38989 L
.35476 .4121 L
s
.33248 .3895 m
.31068 .36463 L
.24517 .34432 L
.26199 .36799 L
.33248 .3895 L
s
.31068 .36463 m
.29032 .33841 L
.22946 .31975 L
.24517 .34432 L
.31068 .36463 L
s
.29032 .33841 m
.27229 .31213 L
.21555 .2955 L
.22946 .31975 L
.29032 .33841 L
s
.27229 .31213 m
.25738 .28763 L
.20404 .27319 L
.21555 .2955 L
.27229 .31213 L
s
.25738 .28763 m
.24623 .26722 L
.19544 .25483 L
.20404 .27319 L
.25738 .28763 L
s
.24623 .26722 m
.23935 .2535 L
.19013 .2426 L
.19544 .25483 L
.24623 .26722 L
s
.23935 .2535 m
.23702 .24863 L
.18833 .23828 L
.19013 .2426 L
.23935 .2535 L
s
.23702 .24863 m
.23935 .2535 L
.19013 .2426 L
.18833 .23828 L
.23702 .24863 L
s
.23935 .2535 m
.24623 .26722 L
.19544 .25483 L
.19013 .2426 L
.23935 .2535 L
s
.24623 .26722 m
.25738 .28763 L
.20404 .27319 L
.19544 .25483 L
.24623 .26722 L
s
.25738 .28763 m
.27229 .31213 L
.21555 .2955 L
.20404 .27319 L
.25738 .28763 L
s
.27229 .31213 m
.29032 .33841 L
.22946 .31975 L
.21555 .2955 L
.27229 .31213 L
s
.29032 .33841 m
.31068 .36463 L
.24517 .34432 L
.22946 .31975 L
.29032 .33841 L
s
.31068 .36463 m
.33248 .3895 L
.26199 .36799 L
.24517 .34432 L
.31068 .36463 L
s
.33248 .3895 m
.35476 .4121 L
.27919 .38989 L
.26199 .36799 L
.33248 .3895 L
s
.35476 .4121 m
.37656 .43189 L
.29601 .40943 L
.27919 .38989 L
.35476 .4121 L
s
.37656 .43189 m
.39692 .44859 L
.31172 .42623 L
.29601 .40943 L
.37656 .43189 L
s
.39692 .44859 m
.41495 .46209 L
.32563 .44008 L
.31172 .42623 L
.39692 .44859 L
s
.41495 .46209 m
.42987 .47243 L
.33714 .45088 L
.32563 .44008 L
.41495 .46209 L
s
.42987 .47243 m
.44101 .47969 L
.34574 .45858 L
.33714 .45088 L
.42987 .47243 L
s
.44101 .47969 m
.44789 .484 L
.35105 .46319 L
.34574 .45858 L
.44101 .47969 L
s
.44789 .484 m
.45022 .48542 L
.35285 .46472 L
.35105 .46319 L
.44789 .484 L
s
.45022 .48542 m
.44789 .484 L
.35105 .46319 L
.35285 .46472 L
.45022 .48542 L
s
.44789 .484 m
.44101 .47969 L
.34574 .45858 L
.35105 .46319 L
.44789 .484 L
s
.44101 .47969 m
.42987 .47243 L
.33714 .45088 L
.34574 .45858 L
.44101 .47969 L
s
.42987 .47243 m
.41495 .46209 L
.32563 .44008 L
.33714 .45088 L
.42987 .47243 L
s
.41495 .46209 m
.39692 .44859 L
.31172 .42623 L
.32563 .44008 L
.41495 .46209 L
s
.39692 .44859 m
.37656 .43189 L
.29601 .40943 L
.31172 .42623 L
.39692 .44859 L
s
.37656 .43189 m
.35476 .4121 L
.27919 .38989 L
.29601 .40943 L
.37656 .43189 L
s
.35476 .4121 m
.33248 .3895 L
.26199 .36799 L
.27919 .38989 L
.35476 .4121 L
s
.33248 .3895 m
.31068 .36463 L
.24517 .34432 L
.26199 .36799 L
.33248 .3895 L
s
.31068 .36463 m
.29032 .33841 L
.22946 .31975 L
.24517 .34432 L
.31068 .36463 L
s
.29032 .33841 m
.27229 .31213 L
.21555 .2955 L
.22946 .31975 L
.29032 .33841 L
s
.27229 .31213 m
.25738 .28763 L
.20404 .27319 L
.21555 .2955 L
.27229 .31213 L
s
.25738 .28763 m
.24623 .26722 L
.19544 .25483 L
.20404 .27319 L
.25738 .28763 L
s
.24623 .26722 m
.23935 .2535 L
.19013 .2426 L
.19544 .25483 L
.24623 .26722 L
s
.23935 .2535 m
.23702 .24863 L
.18833 .23828 L
.19013 .2426 L
.23935 .2535 L
s
.23702 .24863 m
.23935 .2535 L
.19013 .2426 L
.18833 .23828 L
.23702 .24863 L
s
.23935 .2535 m
.24623 .26722 L
.19544 .25483 L
.19013 .2426 L
.23935 .2535 L
s
.24623 .26722 m
.25738 .28763 L
.20404 .27319 L
.19544 .25483 L
.24623 .26722 L
s
.25738 .28763 m
.27229 .31213 L
.21555 .2955 L
.20404 .27319 L
.25738 .28763 L
s
.27229 .31213 m
.29032 .33841 L
.22946 .31975 L
.21555 .2955 L
.27229 .31213 L
s
.29032 .33841 m
.31068 .36463 L
.24517 .34432 L
.22946 .31975 L
.29032 .33841 L
s
.31068 .36463 m
.33248 .3895 L
.26199 .36799 L
.24517 .34432 L
.31068 .36463 L
s
.33248 .3895 m
.35476 .4121 L
.27919 .38989 L
.26199 .36799 L
.33248 .3895 L
s
.35476 .4121 m
.37656 .43189 L
.29601 .40943 L
.27919 .38989 L
.35476 .4121 L
s
.37656 .43189 m
.39692 .44859 L
.31172 .42623 L
.29601 .40943 L
.37656 .43189 L
s
.39692 .44859 m
.41495 .46209 L
.32563 .44008 L
.31172 .42623 L
.39692 .44859 L
s
.41495 .46209 m
.42987 .47243 L
.33714 .45088 L
.32563 .44008 L
.41495 .46209 L
s
.42987 .47243 m
.44101 .47969 L
.34574 .45858 L
.33714 .45088 L
.42987 .47243 L
s
.44101 .47969 m
.44789 .484 L
.35105 .46319 L
.34574 .45858 L
.44101 .47969 L
s
.44789 .484 m
.45022 .48542 L
.35285 .46472 L
.35105 .46319 L
.44789 .484 L
s
.35285 .46472 m
.35105 .46319 L
.2606 .42273 L
.2619 .42423 L
.35285 .46472 L
s
.35105 .46319 m
.34574 .45858 L
.25676 .41821 L
.2606 .42273 L
.35105 .46319 L
s
.34574 .45858 m
.33714 .45088 L
.25054 .41073 L
.25676 .41821 L
.34574 .45858 L
s
.33714 .45088 m
.32563 .44008 L
.24221 .40033 L
.25054 .41073 L
.33714 .45088 L
s
.32563 .44008 m
.31172 .42623 L
.23214 .38712 L
.24221 .40033 L
.32563 .44008 L
s
.31172 .42623 m
.29601 .40943 L
.22077 .37129 L
.23214 .38712 L
.31172 .42623 L
s
.29601 .40943 m
.27919 .38989 L
.2086 .35311 L
.22077 .37129 L
.29601 .40943 L
s
.27919 .38989 m
.26199 .36799 L
.19616 .33298 L
.2086 .35311 L
.27919 .38989 L
s
.26199 .36799 m
.24517 .34432 L
.18399 .31149 L
.19616 .33298 L
.26199 .36799 L
s
.24517 .34432 m
.22946 .31975 L
.17262 .28944 L
.18399 .31149 L
.24517 .34432 L
s
.22946 .31975 m
.21555 .2955 L
.16255 .26792 L
.17262 .28944 L
.22946 .31975 L
s
.21555 .2955 m
.20404 .27319 L
.15423 .24832 L
.16255 .26792 L
.21555 .2955 L
s
.20404 .27319 m
.19544 .25483 L
.148 .23233 L
.15423 .24832 L
.20404 .27319 L
s
.19544 .25483 m
.19013 .2426 L
.14416 .22175 L
.148 .23233 L
.19544 .25483 L
s
.19013 .2426 m
.18833 .23828 L
.14286 .21804 L
.14416 .22175 L
.19013 .2426 L
s
.18833 .23828 m
.19013 .2426 L
.14416 .22175 L
.14286 .21804 L
.18833 .23828 L
s
.19013 .2426 m
.19544 .25483 L
.148 .23233 L
.14416 .22175 L
.19013 .2426 L
s
.19544 .25483 m
.20404 .27319 L
.15423 .24832 L
.148 .23233 L
.19544 .25483 L
s
.20404 .27319 m
.21555 .2955 L
.16255 .26792 L
.15423 .24832 L
.20404 .27319 L
s
.21555 .2955 m
.22946 .31975 L
.17262 .28944 L
.16255 .26792 L
.21555 .2955 L
s
.22946 .31975 m
.24517 .34432 L
.18399 .31149 L
.17262 .28944 L
.22946 .31975 L
s
.24517 .34432 m
.26199 .36799 L
.19616 .33298 L
.18399 .31149 L
.24517 .34432 L
s
.26199 .36799 m
.27919 .38989 L
.2086 .35311 L
.19616 .33298 L
.26199 .36799 L
s
.27919 .38989 m
.29601 .40943 L
.22077 .37129 L
.2086 .35311 L
.27919 .38989 L
s
.29601 .40943 m
.31172 .42623 L
.23214 .38712 L
.22077 .37129 L
.29601 .40943 L
s
.31172 .42623 m
.32563 .44008 L
.24221 .40033 L
.23214 .38712 L
.31172 .42623 L
s
.32563 .44008 m
.33714 .45088 L
.25054 .41073 L
.24221 .40033 L
.32563 .44008 L
s
.33714 .45088 m
.34574 .45858 L
.25676 .41821 L
.25054 .41073 L
.33714 .45088 L
s
.34574 .45858 m
.35105 .46319 L
.2606 .42273 L
.25676 .41821 L
.34574 .45858 L
s
.35105 .46319 m
.35285 .46472 L
.2619 .42423 L
.2606 .42273 L
.35105 .46319 L
s
.35285 .46472 m
.35105 .46319 L
.2606 .42273 L
.2619 .42423 L
.35285 .46472 L
s
.35105 .46319 m
.34574 .45858 L
.25676 .41821 L
.2606 .42273 L
.35105 .46319 L
s
.34574 .45858 m
.33714 .45088 L
.25054 .41073 L
.25676 .41821 L
.34574 .45858 L
s
.33714 .45088 m
.32563 .44008 L
.24221 .40033 L
.25054 .41073 L
.33714 .45088 L
s
.32563 .44008 m
.31172 .42623 L
.23214 .38712 L
.24221 .40033 L
.32563 .44008 L
s
.31172 .42623 m
.29601 .40943 L
.22077 .37129 L
.23214 .38712 L
.31172 .42623 L
s
.29601 .40943 m
.27919 .38989 L
.2086 .35311 L
.22077 .37129 L
.29601 .40943 L
s
.27919 .38989 m
.26199 .36799 L
.19616 .33298 L
.2086 .35311 L
.27919 .38989 L
s
.26199 .36799 m
.24517 .34432 L
.18399 .31149 L
.19616 .33298 L
.26199 .36799 L
s
.24517 .34432 m
.22946 .31975 L
.17262 .28944 L
.18399 .31149 L
.24517 .34432 L
s
.22946 .31975 m
.21555 .2955 L
.16255 .26792 L
.17262 .28944 L
.22946 .31975 L
s
.21555 .2955 m
.20404 .27319 L
.15423 .24832 L
.16255 .26792 L
.21555 .2955 L
s
.20404 .27319 m
.19544 .25483 L
.148 .23233 L
.15423 .24832 L
.20404 .27319 L
s
.19544 .25483 m
.19013 .2426 L
.14416 .22175 L
.148 .23233 L
.19544 .25483 L
s
.19013 .2426 m
.18833 .23828 L
.14286 .21804 L
.14416 .22175 L
.19013 .2426 L
s
.18833 .23828 m
.19013 .2426 L
.14416 .22175 L
.14286 .21804 L
.18833 .23828 L
s
.19013 .2426 m
.19544 .25483 L
.148 .23233 L
.14416 .22175 L
.19013 .2426 L
s
.19544 .25483 m
.20404 .27319 L
.15423 .24832 L
.148 .23233 L
.19544 .25483 L
s
.20404 .27319 m
.21555 .2955 L
.16255 .26792 L
.15423 .24832 L
.20404 .27319 L
s
.21555 .2955 m
.22946 .31975 L
.17262 .28944 L
.16255 .26792 L
.21555 .2955 L
s
.22946 .31975 m
.24517 .34432 L
.18399 .31149 L
.17262 .28944 L
.22946 .31975 L
s
.24517 .34432 m
.26199 .36799 L
.19616 .33298 L
.18399 .31149 L
.24517 .34432 L
s
.26199 .36799 m
.27919 .38989 L
.2086 .35311 L
.19616 .33298 L
.26199 .36799 L
s
.27919 .38989 m
.29601 .40943 L
.22077 .37129 L
.2086 .35311 L
.27919 .38989 L
s
.29601 .40943 m
.31172 .42623 L
.23214 .38712 L
.22077 .37129 L
.29601 .40943 L
s
.31172 .42623 m
.32563 .44008 L
.24221 .40033 L
.23214 .38712 L
.31172 .42623 L
s
.32563 .44008 m
.33714 .45088 L
.25054 .41073 L
.24221 .40033 L
.32563 .44008 L
s
.33714 .45088 m
.34574 .45858 L
.25676 .41821 L
.25054 .41073 L
.33714 .45088 L
s
.34574 .45858 m
.35105 .46319 L
.2606 .42273 L
.25676 .41821 L
.34574 .45858 L
s
.35105 .46319 m
.35285 .46472 L
.2619 .42423 L
.2606 .42273 L
.35105 .46319 L
s
.2619 .42423 m
.2606 .42273 L
.18051 .36436 L
.18137 .36572 L
.2619 .42423 L
s
.2606 .42273 m
.25676 .41821 L
.17796 .3603 L
.18051 .36436 L
.2606 .42273 L
s
.25676 .41821 m
.25054 .41073 L
.17384 .3536 L
.17796 .3603 L
.25676 .41821 L
s
.25054 .41073 m
.24221 .40033 L
.16833 .34433 L
.17384 .3536 L
.25054 .41073 L
s
.24221 .40033 m
.23214 .38712 L
.16167 .33264 L
.16833 .34433 L
.24221 .40033 L
s
.23214 .38712 m
.22077 .37129 L
.15415 .31873 L
.16167 .33264 L
.23214 .38712 L
s
.22077 .37129 m
.2086 .35311 L
.14609 .30289 L
.15415 .31873 L
.22077 .37129 L
s
.2086 .35311 m
.19616 .33298 L
.13786 .28551 L
.14609 .30289 L
.2086 .35311 L
s
.19616 .33298 m
.18399 .31149 L
.12981 .2671 L
.13786 .28551 L
.19616 .33298 L
s
.18399 .31149 m
.17262 .28944 L
.12228 .24838 L
.12981 .2671 L
.18399 .31149 L
s
.17262 .28944 m
.16255 .26792 L
.11562 .23025 L
.12228 .24838 L
.17262 .28944 L
s
.16255 .26792 m
.15423 .24832 L
.11011 .21386 L
.11562 .23025 L
.16255 .26792 L
s
.15423 .24832 m
.148 .23233 L
.10599 .20058 L
.11011 .21386 L
.15423 .24832 L
s
.148 .23233 m
.14416 .22175 L
.10345 .19184 L
.10599 .20058 L
.148 .23233 L
s
.14416 .22175 m
.14286 .21804 L
.10259 .18878 L
.10345 .19184 L
.14416 .22175 L
s
.14286 .21804 m
.14416 .22175 L
.10345 .19184 L
.10259 .18878 L
.14286 .21804 L
s
.14416 .22175 m
.148 .23233 L
.10599 .20058 L
.10345 .19184 L
.14416 .22175 L
s
.148 .23233 m
.15423 .24832 L
.11011 .21386 L
.10599 .20058 L
.148 .23233 L
s
.15423 .24832 m
.16255 .26792 L
.11562 .23025 L
.11011 .21386 L
.15423 .24832 L
s
.16255 .26792 m
.17262 .28944 L
.12228 .24838 L
.11562 .23025 L
.16255 .26792 L
s
.17262 .28944 m
.18399 .31149 L
.12981 .2671 L
.12228 .24838 L
.17262 .28944 L
s
.18399 .31149 m
.19616 .33298 L
.13786 .28551 L
.12981 .2671 L
.18399 .31149 L
s
.19616 .33298 m
.2086 .35311 L
.14609 .30289 L
.13786 .28551 L
.19616 .33298 L
s
.2086 .35311 m
.22077 .37129 L
.15415 .31873 L
.14609 .30289 L
.2086 .35311 L
s
.22077 .37129 m
.23214 .38712 L
.16167 .33264 L
.15415 .31873 L
.22077 .37129 L
s
.23214 .38712 m
.24221 .40033 L
.16833 .34433 L
.16167 .33264 L
.23214 .38712 L
s
.24221 .40033 m
.25054 .41073 L
.17384 .3536 L
.16833 .34433 L
.24221 .40033 L
s
.25054 .41073 m
.25676 .41821 L
.17796 .3603 L
.17384 .3536 L
.25054 .41073 L
s
.25676 .41821 m
.2606 .42273 L
.18051 .36436 L
.17796 .3603 L
.25676 .41821 L
s
.2606 .42273 m
.2619 .42423 L
.18137 .36572 L
.18051 .36436 L
.2606 .42273 L
s
.2619 .42423 m
.2606 .42273 L
.18051 .36436 L
.18137 .36572 L
.2619 .42423 L
s
.2606 .42273 m
.25676 .41821 L
.17796 .3603 L
.18051 .36436 L
.2606 .42273 L
s
.25676 .41821 m
.25054 .41073 L
.17384 .3536 L
.17796 .3603 L
.25676 .41821 L
s
.25054 .41073 m
.24221 .40033 L
.16833 .34433 L
.17384 .3536 L
.25054 .41073 L
s
.24221 .40033 m
.23214 .38712 L
.16167 .33264 L
.16833 .34433 L
.24221 .40033 L
s
.23214 .38712 m
.22077 .37129 L
.15415 .31873 L
.16167 .33264 L
.23214 .38712 L
s
.22077 .37129 m
.2086 .35311 L
.14609 .30289 L
.15415 .31873 L
.22077 .37129 L
s
.2086 .35311 m
.19616 .33298 L
.13786 .28551 L
.14609 .30289 L
.2086 .35311 L
s
.19616 .33298 m
.18399 .31149 L
.12981 .2671 L
.13786 .28551 L
.19616 .33298 L
s
.18399 .31149 m
.17262 .28944 L
.12228 .24838 L
.12981 .2671 L
.18399 .31149 L
s
.17262 .28944 m
.16255 .26792 L
.11562 .23025 L
.12228 .24838 L
.17262 .28944 L
s
.16255 .26792 m
.15423 .24832 L
.11011 .21386 L
.11562 .23025 L
.16255 .26792 L
s
.15423 .24832 m
.148 .23233 L
.10599 .20058 L
.11011 .21386 L
.15423 .24832 L
s
.148 .23233 m
.14416 .22175 L
.10345 .19184 L
.10599 .20058 L
.148 .23233 L
s
.14416 .22175 m
.14286 .21804 L
.10259 .18878 L
.10345 .19184 L
.14416 .22175 L
s
.14286 .21804 m
.14416 .22175 L
.10345 .19184 L
.10259 .18878 L
.14286 .21804 L
s
.14416 .22175 m
.148 .23233 L
.10599 .20058 L
.10345 .19184 L
.14416 .22175 L
s
.148 .23233 m
.15423 .24832 L
.11011 .21386 L
.10599 .20058 L
.148 .23233 L
s
.15423 .24832 m
.16255 .26792 L
.11562 .23025 L
.11011 .21386 L
.15423 .24832 L
s
.16255 .26792 m
.17262 .28944 L
.12228 .24838 L
.11562 .23025 L
.16255 .26792 L
s
.17262 .28944 m
.18399 .31149 L
.12981 .2671 L
.12228 .24838 L
.17262 .28944 L
s
.18399 .31149 m
.19616 .33298 L
.13786 .28551 L
.12981 .2671 L
.18399 .31149 L
s
.19616 .33298 m
.2086 .35311 L
.14609 .30289 L
.13786 .28551 L
.19616 .33298 L
s
.2086 .35311 m
.22077 .37129 L
.15415 .31873 L
.14609 .30289 L
.2086 .35311 L
s
.22077 .37129 m
.23214 .38712 L
.16167 .33264 L
.15415 .31873 L
.22077 .37129 L
s
.23214 .38712 m
.24221 .40033 L
.16833 .34433 L
.16167 .33264 L
.23214 .38712 L
s
.24221 .40033 m
.25054 .41073 L
.17384 .3536 L
.16833 .34433 L
.24221 .40033 L
s
.25054 .41073 m
.25676 .41821 L
.17796 .3603 L
.17384 .3536 L
.25054 .41073 L
s
.25676 .41821 m
.2606 .42273 L
.18051 .36436 L
.17796 .3603 L
.25676 .41821 L
s
.2606 .42273 m
.2619 .42423 L
.18137 .36572 L
.18051 .36436 L
.2606 .42273 L
s
.18137 .36572 m
.18051 .36436 L
.11426 .29063 L
.11475 .29174 L
.18137 .36572 L
s
.18051 .36436 m
.17796 .3603 L
.11279 .28732 L
.11426 .29063 L
.18051 .36436 L
s
.17796 .3603 m
.17384 .3536 L
.11041 .28186 L
.11279 .28732 L
.17796 .3603 L
s
.17384 .3536 m
.16833 .34433 L
.10723 .27434 L
.11041 .28186 L
.17384 .3536 L
s
.16833 .34433 m
.16167 .33264 L
.10339 .2649 L
.10723 .27434 L
.16833 .34433 L
s
.16167 .33264 m
.15415 .31873 L
.09904 .25373 L
.10339 .2649 L
.16167 .33264 L
s
.15415 .31873 m
.14609 .30289 L
.09439 .24107 L
.09904 .25373 L
.15415 .31873 L
s
.14609 .30289 m
.13786 .28551 L
.08964 .22726 L
.09439 .24107 L
.14609 .30289 L
s
.13786 .28551 m
.12981 .2671 L
.08499 .21272 L
.08964 .22726 L
.13786 .28551 L
s
.12981 .2671 m
.12228 .24838 L
.08065 .19802 L
.08499 .21272 L
.12981 .2671 L
s
.12228 .24838 m
.11562 .23025 L
.0768 .18386 L
.08065 .19802 L
.12228 .24838 L
s
.11562 .23025 m
.11011 .21386 L
.07362 .17114 L
.0768 .18386 L
.11562 .23025 L
s
.11011 .21386 m
.10599 .20058 L
.07125 .16087 L
.07362 .17114 L
.11011 .21386 L
s
.10599 .20058 m
.10345 .19184 L
.06978 .15414 L
.07125 .16087 L
.10599 .20058 L
s
.10345 .19184 m
.10259 .18878 L
.06928 .15179 L
.06978 .15414 L
.10345 .19184 L
s
.10259 .18878 m
.10345 .19184 L
.06978 .15414 L
.06928 .15179 L
.10259 .18878 L
s
.10345 .19184 m
.10599 .20058 L
.07125 .16087 L
.06978 .15414 L
.10345 .19184 L
s
.10599 .20058 m
.11011 .21386 L
.07362 .17114 L
.07125 .16087 L
.10599 .20058 L
s
.11011 .21386 m
.11562 .23025 L
.0768 .18386 L
.07362 .17114 L
.11011 .21386 L
s
.11562 .23025 m
.12228 .24838 L
.08065 .19802 L
.0768 .18386 L
.11562 .23025 L
s
.12228 .24838 m
.12981 .2671 L
.08499 .21272 L
.08065 .19802 L
.12228 .24838 L
s
.12981 .2671 m
.13786 .28551 L
.08964 .22726 L
.08499 .21272 L
.12981 .2671 L
s
.13786 .28551 m
.14609 .30289 L
.09439 .24107 L
.08964 .22726 L
.13786 .28551 L
s
.14609 .30289 m
.15415 .31873 L
.09904 .25373 L
.09439 .24107 L
.14609 .30289 L
s
.15415 .31873 m
.16167 .33264 L
.10339 .2649 L
.09904 .25373 L
.15415 .31873 L
s
.16167 .33264 m
.16833 .34433 L
.10723 .27434 L
.10339 .2649 L
.16167 .33264 L
s
.16833 .34433 m
.17384 .3536 L
.11041 .28186 L
.10723 .27434 L
.16833 .34433 L
s
.17384 .3536 m
.17796 .3603 L
.11279 .28732 L
.11041 .28186 L
.17384 .3536 L
s
.17796 .3603 m
.18051 .36436 L
.11426 .29063 L
.11279 .28732 L
.17796 .3603 L
s
.18051 .36436 m
.18137 .36572 L
.11475 .29174 L
.11426 .29063 L
.18051 .36436 L
s
.18137 .36572 m
.18051 .36436 L
.11426 .29063 L
.11475 .29174 L
.18137 .36572 L
s
.18051 .36436 m
.17796 .3603 L
.11279 .28732 L
.11426 .29063 L
.18051 .36436 L
s
.17796 .3603 m
.17384 .3536 L
.11041 .28186 L
.11279 .28732 L
.17796 .3603 L
s
.17384 .3536 m
.16833 .34433 L
.10723 .27434 L
.11041 .28186 L
.17384 .3536 L
s
.16833 .34433 m
.16167 .33264 L
.10339 .2649 L
.10723 .27434 L
.16833 .34433 L
s
.16167 .33264 m
.15415 .31873 L
.09904 .25373 L
.10339 .2649 L
.16167 .33264 L
s
.15415 .31873 m
.14609 .30289 L
.09439 .24107 L
.09904 .25373 L
.15415 .31873 L
s
.14609 .30289 m
.13786 .28551 L
.08964 .22726 L
.09439 .24107 L
.14609 .30289 L
s
.13786 .28551 m
.12981 .2671 L
.08499 .21272 L
.08964 .22726 L
.13786 .28551 L
s
.12981 .2671 m
.12228 .24838 L
.08065 .19802 L
.08499 .21272 L
.12981 .2671 L
s
.12228 .24838 m
.11562 .23025 L
.0768 .18386 L
.08065 .19802 L
.12228 .24838 L
s
.11562 .23025 m
.11011 .21386 L
.07362 .17114 L
.0768 .18386 L
.11562 .23025 L
s
.11011 .21386 m
.10599 .20058 L
.07125 .16087 L
.07362 .17114 L
.11011 .21386 L
s
.10599 .20058 m
.10345 .19184 L
.06978 .15414 L
.07125 .16087 L
.10599 .20058 L
s
.10345 .19184 m
.10259 .18878 L
.06928 .15179 L
.06978 .15414 L
.10345 .19184 L
s
.10259 .18878 m
.10345 .19184 L
.06978 .15414 L
.06928 .15179 L
.10259 .18878 L
s
.10345 .19184 m
.10599 .20058 L
.07125 .16087 L
.06978 .15414 L
.10345 .19184 L
s
.10599 .20058 m
.11011 .21386 L
.07362 .17114 L
.07125 .16087 L
.10599 .20058 L
s
.11011 .21386 m
.11562 .23025 L
.0768 .18386 L
.07362 .17114 L
.11011 .21386 L
s
.11562 .23025 m
.12228 .24838 L
.08065 .19802 L
.0768 .18386 L
.11562 .23025 L
s
.12228 .24838 m
.12981 .2671 L
.08499 .21272 L
.08065 .19802 L
.12228 .24838 L
s
.12981 .2671 m
.13786 .28551 L
.08964 .22726 L
.08499 .21272 L
.12981 .2671 L
s
.13786 .28551 m
.14609 .30289 L
.09439 .24107 L
.08964 .22726 L
.13786 .28551 L
s
.14609 .30289 m
.15415 .31873 L
.09904 .25373 L
.09439 .24107 L
.14609 .30289 L
s
.15415 .31873 m
.16167 .33264 L
.10339 .2649 L
.09904 .25373 L
.15415 .31873 L
s
.16167 .33264 m
.16833 .34433 L
.10723 .27434 L
.10339 .2649 L
.16167 .33264 L
s
.16833 .34433 m
.17384 .3536 L
.11041 .28186 L
.10723 .27434 L
.16833 .34433 L
s
.17384 .3536 m
.17796 .3603 L
.11279 .28732 L
.11041 .28186 L
.17384 .3536 L
s
.17796 .3603 m
.18051 .36436 L
.11426 .29063 L
.11279 .28732 L
.17796 .3603 L
s
.18051 .36436 m
.18137 .36572 L
.11475 .29174 L
.11426 .29063 L
.18051 .36436 L
s
.11475 .29174 m
.11426 .29063 L
.06475 .20474 L
.06498 .20552 L
.11475 .29174 L
s
.11426 .29063 m
.11279 .28732 L
.06409 .2024 L
.06475 .20474 L
.11426 .29063 L
s
.11279 .28732 m
.11041 .28186 L
.06301 .19856 L
.06409 .2024 L
.11279 .28732 L
s
.11041 .28186 m
.10723 .27434 L
.06157 .19327 L
.06301 .19856 L
.11041 .28186 L
s
.10723 .27434 m
.10339 .2649 L
.05983 .18665 L
.06157 .19327 L
.10723 .27434 L
s
.10339 .2649 m
.09904 .25373 L
.05787 .17884 L
.05983 .18665 L
.10339 .2649 L
s
.09904 .25373 m
.09439 .24107 L
.05576 .17002 L
.05787 .17884 L
.09904 .25373 L
s
.09439 .24107 m
.08964 .22726 L
.05361 .16043 L
.05576 .17002 L
.09439 .24107 L
s
.08964 .22726 m
.08499 .21272 L
.05151 .15038 L
.05361 .16043 L
.08964 .22726 L
s
.08499 .21272 m
.08065 .19802 L
.04954 .14026 L
.05151 .15038 L
.08499 .21272 L
s
.08065 .19802 m
.0768 .18386 L
.0478 .13055 L
.04954 .14026 L
.08065 .19802 L
s
.0768 .18386 m
.07362 .17114 L
.04636 .12185 L
.0478 .13055 L
.0768 .18386 L
s
.07362 .17114 m
.07125 .16087 L
.04528 .11485 L
.04636 .12185 L
.07362 .17114 L
s
.07125 .16087 m
.06978 .15414 L
.04462 .11028 L
.04528 .11485 L
.07125 .16087 L
s
.06978 .15414 m
.06928 .15179 L
.04439 .10868 L
.04462 .11028 L
.06978 .15414 L
s
.06928 .15179 m
.06978 .15414 L
.04462 .11028 L
.04439 .10868 L
.06928 .15179 L
s
.06978 .15414 m
.07125 .16087 L
.04528 .11485 L
.04462 .11028 L
.06978 .15414 L
s
.07125 .16087 m
.07362 .17114 L
.04636 .12185 L
.04528 .11485 L
.07125 .16087 L
s
.07362 .17114 m
.0768 .18386 L
.0478 .13055 L
.04636 .12185 L
.07362 .17114 L
s
.0768 .18386 m
.08065 .19802 L
.04954 .14026 L
.0478 .13055 L
.0768 .18386 L
s
.08065 .19802 m
.08499 .21272 L
.05151 .15038 L
.04954 .14026 L
.08065 .19802 L
s
.08499 .21272 m
.08964 .22726 L
.05361 .16043 L
.05151 .15038 L
.08499 .21272 L
s
.08964 .22726 m
.09439 .24107 L
.05576 .17002 L
.05361 .16043 L
.08964 .22726 L
s
.09439 .24107 m
.09904 .25373 L
.05787 .17884 L
.05576 .17002 L
.09439 .24107 L
s
.09904 .25373 m
.10339 .2649 L
.05983 .18665 L
.05787 .17884 L
.09904 .25373 L
s
.10339 .2649 m
.10723 .27434 L
.06157 .19327 L
.05983 .18665 L
.10339 .2649 L
s
.10723 .27434 m
.11041 .28186 L
.06301 .19856 L
.06157 .19327 L
.10723 .27434 L
s
.11041 .28186 m
.11279 .28732 L
.06409 .2024 L
.06301 .19856 L
.11041 .28186 L
s
.11279 .28732 m
.11426 .29063 L
.06475 .20474 L
.06409 .2024 L
.11279 .28732 L
s
.11426 .29063 m
.11475 .29174 L
.06498 .20552 L
.06475 .20474 L
.11426 .29063 L
s
.11475 .29174 m
.11426 .29063 L
.06475 .20474 L
.06498 .20552 L
.11475 .29174 L
s
.11426 .29063 m
.11279 .28732 L
.06409 .2024 L
.06475 .20474 L
.11426 .29063 L
s
.11279 .28732 m
.11041 .28186 L
.06301 .19856 L
.06409 .2024 L
.11279 .28732 L
s
.11041 .28186 m
.10723 .27434 L
.06157 .19327 L
.06301 .19856 L
.11041 .28186 L
s
.10723 .27434 m
.10339 .2649 L
.05983 .18665 L
.06157 .19327 L
.10723 .27434 L
s
.10339 .2649 m
.09904 .25373 L
.05787 .17884 L
.05983 .18665 L
.10339 .2649 L
s
.09904 .25373 m
.09439 .24107 L
.05576 .17002 L
.05787 .17884 L
.09904 .25373 L
s
.09439 .24107 m
.08964 .22726 L
.05361 .16043 L
.05576 .17002 L
.09439 .24107 L
s
.08964 .22726 m
.08499 .21272 L
.05151 .15038 L
.05361 .16043 L
.08964 .22726 L
s
.08499 .21272 m
.08065 .19802 L
.04954 .14026 L
.05151 .15038 L
.08499 .21272 L
s
.08065 .19802 m
.0768 .18386 L
.0478 .13055 L
.04954 .14026 L
.08065 .19802 L
s
.0768 .18386 m
.07362 .17114 L
.04636 .12185 L
.0478 .13055 L
.0768 .18386 L
s
.07362 .17114 m
.07125 .16087 L
.04528 .11485 L
.04636 .12185 L
.07362 .17114 L
s
.07125 .16087 m
.06978 .15414 L
.04462 .11028 L
.04528 .11485 L
.07125 .16087 L
s
.06978 .15414 m
.06928 .15179 L
.04439 .10868 L
.04462 .11028 L
.06978 .15414 L
s
.06928 .15179 m
.06978 .15414 L
.04462 .11028 L
.04439 .10868 L
.06928 .15179 L
s
.06978 .15414 m
.07125 .16087 L
.04528 .11485 L
.04462 .11028 L
.06978 .15414 L
s
.07125 .16087 m
.07362 .17114 L
.04636 .12185 L
.04528 .11485 L
.07125 .16087 L
s
.07362 .17114 m
.0768 .18386 L
.0478 .13055 L
.04636 .12185 L
.07362 .17114 L
s
.0768 .18386 m
.08065 .19802 L
.04954 .14026 L
.0478 .13055 L
.0768 .18386 L
s
.08065 .19802 m
.08499 .21272 L
.05151 .15038 L
.04954 .14026 L
.08065 .19802 L
s
.08499 .21272 m
.08964 .22726 L
.05361 .16043 L
.05151 .15038 L
.08499 .21272 L
s
.08964 .22726 m
.09439 .24107 L
.05576 .17002 L
.05361 .16043 L
.08964 .22726 L
s
.09439 .24107 m
.09904 .25373 L
.05787 .17884 L
.05576 .17002 L
.09439 .24107 L
s
.09904 .25373 m
.10339 .2649 L
.05983 .18665 L
.05787 .17884 L
.09904 .25373 L
s
.10339 .2649 m
.10723 .27434 L
.06157 .19327 L
.05983 .18665 L
.10339 .2649 L
s
.10723 .27434 m
.11041 .28186 L
.06301 .19856 L
.06157 .19327 L
.10723 .27434 L
s
.11041 .28186 m
.11279 .28732 L
.06409 .2024 L
.06301 .19856 L
.11041 .28186 L
s
.11279 .28732 m
.11426 .29063 L
.06475 .20474 L
.06409 .2024 L
.11279 .28732 L
s
.11426 .29063 m
.11475 .29174 L
.06498 .20552 L
.06475 .20474 L
.11426 .29063 L
s
.06498 .20552 m
.06475 .20474 L
.03416 .11044 L
.03422 .11085 L
.06498 .20552 L
s
.06475 .20474 m
.06409 .2024 L
.03399 .10923 L
.03416 .11044 L
.06475 .20474 L
s
.06409 .2024 m
.06301 .19856 L
.03372 .10725 L
.03399 .10923 L
.06409 .2024 L
s
.06301 .19856 m
.06157 .19327 L
.03335 .10452 L
.03372 .10725 L
.06301 .19856 L
s
.06157 .19327 m
.05983 .18665 L
.03291 .10111 L
.03335 .10452 L
.06157 .19327 L
s
.05983 .18665 m
.05787 .17884 L
.03242 .09709 L
.03291 .10111 L
.05983 .18665 L
s
.05787 .17884 m
.05576 .17002 L
.03189 .09257 L
.03242 .09709 L
.05787 .17884 L
s
.05576 .17002 m
.05361 .16043 L
.03134 .08766 L
.03189 .09257 L
.05576 .17002 L
s
.05361 .16043 m
.05151 .15038 L
.03081 .08253 L
.03134 .08766 L
.05361 .16043 L
s
.05151 .15038 m
.04954 .14026 L
.03031 .07736 L
.03081 .08253 L
.05151 .15038 L
s
.04954 .14026 m
.0478 .13055 L
.02987 .07242 L
.03031 .07736 L
.04954 .14026 L
s
.0478 .13055 m
.04636 .12185 L
.02951 .06801 L
.02987 .07242 L
.0478 .13055 L
s
.04636 .12185 m
.04528 .11485 L
.02924 .06446 L
.02951 .06801 L
.04636 .12185 L
s
.04528 .11485 m
.04462 .11028 L
.02907 .06215 L
.02924 .06446 L
.04528 .11485 L
s
.04462 .11028 m
.04439 .10868 L
.02901 .06134 L
.02907 .06215 L
.04462 .11028 L
s
.04439 .10868 m
.04462 .11028 L
.02907 .06215 L
.02901 .06134 L
.04439 .10868 L
s
.04462 .11028 m
.04528 .11485 L
.02924 .06446 L
.02907 .06215 L
.04462 .11028 L
s
.04528 .11485 m
.04636 .12185 L
.02951 .06801 L
.02924 .06446 L
.04528 .11485 L
s
.04636 .12185 m
.0478 .13055 L
.02987 .07242 L
.02951 .06801 L
.04636 .12185 L
s
.0478 .13055 m
.04954 .14026 L
.03031 .07736 L
.02987 .07242 L
.0478 .13055 L
s
.04954 .14026 m
.05151 .15038 L
.03081 .08253 L
.03031 .07736 L
.04954 .14026 L
s
.05151 .15038 m
.05361 .16043 L
.03134 .08766 L
.03081 .08253 L
.05151 .15038 L
s
.05361 .16043 m
.05576 .17002 L
.03189 .09257 L
.03134 .08766 L
.05361 .16043 L
s
.05576 .17002 m
.05787 .17884 L
.03242 .09709 L
.03189 .09257 L
.05576 .17002 L
s
.05787 .17884 m
.05983 .18665 L
.03291 .10111 L
.03242 .09709 L
.05787 .17884 L
s
.05983 .18665 m
.06157 .19327 L
.03335 .10452 L
.03291 .10111 L
.05983 .18665 L
s
.06157 .19327 m
.06301 .19856 L
.03372 .10725 L
.03335 .10452 L
.06157 .19327 L
s
.06301 .19856 m
.06409 .2024 L
.03399 .10923 L
.03372 .10725 L
.06301 .19856 L
s
.06409 .2024 m
.06475 .20474 L
.03416 .11044 L
.03399 .10923 L
.06409 .2024 L
s
.06475 .20474 m
.06498 .20552 L
.03422 .11085 L
.03416 .11044 L
.06475 .20474 L
s
.06498 .20552 m
.06475 .20474 L
.03416 .11044 L
.03422 .11085 L
.06498 .20552 L
s
.06475 .20474 m
.06409 .2024 L
.03399 .10923 L
.03416 .11044 L
.06475 .20474 L
s
.06409 .2024 m
.06301 .19856 L
.03372 .10725 L
.03399 .10923 L
.06409 .2024 L
s
.06301 .19856 m
.06157 .19327 L
.03335 .10452 L
.03372 .10725 L
.06301 .19856 L
s
.06157 .19327 m
.05983 .18665 L
.03291 .10111 L
.03335 .10452 L
.06157 .19327 L
s
.05983 .18665 m
.05787 .17884 L
.03242 .09709 L
.03291 .10111 L
.05983 .18665 L
s
.05787 .17884 m
.05576 .17002 L
.03189 .09257 L
.03242 .09709 L
.05787 .17884 L
s
.05576 .17002 m
.05361 .16043 L
.03134 .08766 L
.03189 .09257 L
.05576 .17002 L
s
.05361 .16043 m
.05151 .15038 L
.03081 .08253 L
.03134 .08766 L
.05361 .16043 L
s
.05151 .15038 m
.04954 .14026 L
.03031 .07736 L
.03081 .08253 L
.05151 .15038 L
s
.04954 .14026 m
.0478 .13055 L
.02987 .07242 L
.03031 .07736 L
.04954 .14026 L
s
.0478 .13055 m
.04636 .12185 L
.02951 .06801 L
.02987 .07242 L
.0478 .13055 L
s
.04636 .12185 m
.04528 .11485 L
.02924 .06446 L
.02951 .06801 L
.04636 .12185 L
s
.04528 .11485 m
.04462 .11028 L
.02907 .06215 L
.02924 .06446 L
.04528 .11485 L
s
.04462 .11028 m
.04439 .10868 L
.02901 .06134 L
.02907 .06215 L
.04462 .11028 L
s
.04439 .10868 m
.04462 .11028 L
.02907 .06215 L
.02901 .06134 L
.04439 .10868 L
s
.04462 .11028 m
.04528 .11485 L
.02924 .06446 L
.02907 .06215 L
.04462 .11028 L
s
.04528 .11485 m
.04636 .12185 L
.02951 .06801 L
.02924 .06446 L
.04528 .11485 L
s
.04636 .12185 m
.0478 .13055 L
.02987 .07242 L
.02951 .06801 L
.04636 .12185 L
s
.0478 .13055 m
.04954 .14026 L
.03031 .07736 L
.02987 .07242 L
.0478 .13055 L
s
.04954 .14026 m
.05151 .15038 L
.03081 .08253 L
.03031 .07736 L
.04954 .14026 L
s
.05151 .15038 m
.05361 .16043 L
.03134 .08766 L
.03081 .08253 L
.05151 .15038 L
s
.05361 .16043 m
.05576 .17002 L
.03189 .09257 L
.03134 .08766 L
.05361 .16043 L
s
.05576 .17002 m
.05787 .17884 L
.03242 .09709 L
.03189 .09257 L
.05576 .17002 L
s
.05787 .17884 m
.05983 .18665 L
.03291 .10111 L
.03242 .09709 L
.05787 .17884 L
s
.05983 .18665 m
.06157 .19327 L
.03335 .10452 L
.03291 .10111 L
.05983 .18665 L
s
.06157 .19327 m
.06301 .19856 L
.03372 .10725 L
.03335 .10452 L
.06157 .19327 L
s
.06301 .19856 m
.06409 .2024 L
.03399 .10923 L
.03372 .10725 L
.06301 .19856 L
s
.06409 .2024 m
.06475 .20474 L
.03416 .11044 L
.03399 .10923 L
.06409 .2024 L
s
.06475 .20474 m
.06498 .20552 L
.03422 .11085 L
.03416 .11044 L
.06475 .20474 L
s
.03422 .11085 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
.03422 .11085 L
s
.03416 .11044 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
.03416 .11044 L
s
.03399 .10923 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
.03399 .10923 L
s
.03372 .10725 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
.03372 .10725 L
s
.03335 .10452 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
.03335 .10452 L
s
.03291 .10111 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
.03291 .10111 L
s
.03242 .09709 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
.03242 .09709 L
s
.03189 .09257 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
.03189 .09257 L
s
.03134 .08766 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
.03134 .08766 L
s
.03081 .08253 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
.03081 .08253 L
s
.03031 .07736 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
.03031 .07736 L
s
.02987 .07242 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
.02987 .07242 L
s
.02951 .06801 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
.02951 .06801 L
s
.02924 .06446 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
.02924 .06446 L
s
.02907 .06215 m
.02901 .06134 L
.02381 .01184 L
.02381 .01184 L
.02907 .06215 L
s
.02901 .06134 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
.02901 .06134 L
s
.02907 .06215 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
.02907 .06215 L
s
.02924 .06446 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
.02924 .06446 L
s
.02951 .06801 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
.02951 .06801 L
s
.02987 .07242 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
.02987 .07242 L
s
.03031 .07736 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
.03031 .07736 L
s
.03081 .08253 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
.03081 .08253 L
s
.03134 .08766 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
.03134 .08766 L
s
.03189 .09257 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
.03189 .09257 L
s
.03242 .09709 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
.03242 .09709 L
s
.03291 .10111 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
.03291 .10111 L
s
.03335 .10452 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
.03335 .10452 L
s
.03372 .10725 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
.03372 .10725 L
s
.03399 .10923 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
.03399 .10923 L
s
.03416 .11044 m
.03422 .11085 L
.02381 .01184 L
.02381 .01184 L
.03416 .11044 L
s
.03422 .11085 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
.03422 .11085 L
s
.03416 .11044 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
.03416 .11044 L
s
.03399 .10923 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
.03399 .10923 L
s
.03372 .10725 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
.03372 .10725 L
s
.03335 .10452 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
.03335 .10452 L
s
.03291 .10111 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
.03291 .10111 L
s
.03242 .09709 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
.03242 .09709 L
s
.03189 .09257 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
.03189 .09257 L
s
.03134 .08766 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
.03134 .08766 L
s
.03081 .08253 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
.03081 .08253 L
s
.03031 .07736 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
.03031 .07736 L
s
.02987 .07242 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
.02987 .07242 L
s
.02951 .06801 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
.02951 .06801 L
s
.02924 .06446 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
.02924 .06446 L
s
.02907 .06215 m
.02901 .06134 L
.02381 .01184 L
.02381 .01184 L
.02907 .06215 L
s
.02901 .06134 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
.02901 .06134 L
s
.02907 .06215 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
.02907 .06215 L
s
.02924 .06446 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
.02924 .06446 L
s
.02951 .06801 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
.02951 .06801 L
s
.02987 .07242 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
.02987 .07242 L
s
.03031 .07736 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
.03031 .07736 L
s
.03081 .08253 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
.03081 .08253 L
s
.03134 .08766 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
.03134 .08766 L
s
.03189 .09257 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
.03189 .09257 L
s
.03242 .09709 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
.03242 .09709 L
s
.03291 .10111 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
.03291 .10111 L
s
.03335 .10452 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
.03335 .10452 L
s
.03372 .10725 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
.03372 .10725 L
s
.03399 .10923 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
.03399 .10923 L
s
.03416 .11044 m
.03422 .11085 L
.02381 .01184 L
.02381 .01184 L
.03416 .11044 L
s
0 0 m
1 0 L
1 .49726 L
0 .49726 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 143.188},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {142.188, 0}} -> {-1.43316, -0.294083, \
0.0239245, 0.0239245}}],

Cell[OutputFormData["\<\
Graphics[{{{Hue[0.7499552304743847], Polygon[{{-1, 0}, {-1, 0}, \
{-Cos[Pi/30]^2 + 5*Cos[Pi/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^4, 
       0.6211835161491764}, {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, \
0.623735072453278}}]}, 
   {Hue[0.7498228629086993], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[Pi/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[Pi/15]^2, 
       0.613577092391689}, {-Cos[Pi/30]^2 + 5*Cos[Pi/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^4, 0.6211835161491764}}]}, 
   {Hue[0.7496086381819954], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((-1 \
+ Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, 
       0.6010618457721149}, {-Cos[Pi/30]^2 + 5*Cos[Pi/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 0.613577092391689}}]}, 
   {Hue[0.749321853715356], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 
       0.5838857533279119}, {-Cos[Pi/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, \
0.6010618457721149}}]}, 
   {Hue[0.7489749683244399], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(17*Sin[Pi/30]^2)/4, 0.5624063276196118}, 
      {-Cos[Pi/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 0.5838857533279119}}]}, 
   {Hue[0.7485830706165225], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((5 \
- Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 
       0.5371028573756111}, {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}}]}, 
   {Hue[0.7481632319599271], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 
       0.508595070176279}, {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}}]}, 
   {Hue[0.7477337701680052], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 
       0.4776706018498101}, {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 0.508595070176279}}]}, 
   {Hue[0.7473134543768909], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 
       0.4453237472356564}, {-Cos[Pi/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 0.4776706018498101}}]}, 
   {Hue[0.7469206848988633], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(11*Sin[Pi/30]^2)/4, 0.4128060526669481}, 
      {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}}]}, 
   {Hue[0.7465726838365876], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 
       0.3816816923272188}, {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}}]}, 
   {Hue[0.7462847327054983], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 
       0.35386023041001824}, {-Cos[Pi/30]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, \
0.3816816923272188}}]}, 
   {Hue[0.7460694920486863], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 
       0.33154008354139414}, {-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, \
0.35386023041001824}}]}, 
   {Hue[0.7459364349530697], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 
       0.31695593148714024}, {-Cos[Pi/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, \
0.33154008354139414}}]}, 
   {Hue[0.745891421526205], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
2*Sin[Pi/30]^2, 0.311867536226639}, 
      {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.31695593148714024}}]}, 
   {Hue[0.7459364349530697], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 
       0.31695593148714024}, {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, \
0.311867536226639}}]}, 
   {Hue[0.7460694920486863], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 
       0.33154008354139414}, {-Cos[Pi/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.31695593148714024}}]}, 
   {Hue[0.7462847327054983], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 
       0.35386023041001824}, {-Cos[Pi/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, \
0.33154008354139414}}]}, 
   {Hue[0.7465726838365876], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 
       0.38168169232721855}, {-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, \
0.35386023041001824}}]}, 
   {Hue[0.7469206848988633], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(11*Sin[Pi/30]^2)/4, 0.4128060526669481}, 
      {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 0.38168169232721855}}]}, 
   {Hue[0.7473134543768909], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 
       0.4453237472356564}, {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}}]}, 
   {Hue[0.7477337701680052], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 
       0.47767060184980986}, {-Cos[Pi/30]^2 + (5*(5 - \
Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, \
0.4453237472356564}}]}, 
   {Hue[0.7481632319599271], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 
       0.508595070176279}, {-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 0.47767060184980986}}]}, 
   {Hue[0.7485830706165225], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((5 \
- Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 
       0.5371028573756111}, {-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 0.508595070176279}}]}, 
   {Hue[0.7489749683244399], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(17*Sin[Pi/30]^2)/4, 0.5624063276196118}, 
      {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}}]}, 
   {Hue[0.749321853715356], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 
       0.5838857533279119}, {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}}]}, 
   {Hue[0.7496086381819954], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((-1 \
+ Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, 
       0.6010618457721149}, {-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 0.5838857533279119}}]}, 
   {Hue[0.7498228629086993], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 
       0.613577092391689}, {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 \
+ (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}}]}, 
   {Hue[0.7499552304743847], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 
       0.6211835161491764}, {-Cos[Pi/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 0.613577092391689}}]}, 
   {Hue[0.75], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, \
0.623735072453278}, 
      {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491764}}]}, 
   {Hue[0.7499552304743847], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(31*Pi)/30]^2, 
       0.6211835161491764}, {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, \
0.623735072453278}}]}, 
   {Hue[0.7498228629086993], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(16*Pi)/15]^2, 
       0.613577092391689}, {-Cos[Pi/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491764}}]}, 
   {Hue[0.7496086381819954], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((-1 \
+ Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, 
       0.6010618457721149}, {-Cos[Pi/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(16*Pi)/15]^2, 0.613577092391689}}]}, 
   {Hue[0.749321853715356], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(17*Pi)/15]^2, 
       0.5838857533279119}, {-Cos[Pi/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, \
0.6010618457721149}}]}, 
   {Hue[0.7489749683244399], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(17*Sin[Pi/30]^2)/4, 0.5624063276196118}, 
      {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279119}}]}, 
   {Hue[0.7485830706165225], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((5 \
- Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 
       0.5371028573756111}, {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}}]}, 
   {Hue[0.7481632319599271], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(37*Pi)/30]^2, 
       0.508595070176279}, {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}}]}, 
   {Hue[0.7477337701680052], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(19*Pi)/15]^2, 
       0.4776706018498101}, {-Cos[Pi/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(37*Pi)/30]^2, 0.508595070176279}}]}, 
   {Hue[0.7473134543768909], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 
       0.4453237472356564}, {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498101}}]}, 
   {Hue[0.7469206848988633], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(11*Sin[Pi/30]^2)/4, 0.4128060526669481}, 
      {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}}]}, 
   {Hue[0.7465726838365876], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(41*Pi)/30]^2, 
       0.3816816923272188}, {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}}]}, 
   {Hue[0.7462847327054983], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 
       0.35386023041001824}, {-Cos[Pi/30]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(41*Pi)/30]^2, \
0.3816816923272188}}]}, 
   {Hue[0.7460694920486863], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(43*Pi)/30]^2, 
       0.33154008354139414}, {-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, \
0.35386023041001824}}]}, 
   {Hue[0.7459364349530698], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(22*Pi)/15]^2, 
       0.31695593148714096}, {-Cos[Pi/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(43*Pi)/30]^2, \
0.33154008354139414}}]}, 
   {Hue[0.745891421526205], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
2*Sin[Pi/30]^2, 0.311867536226639}, 
      {-Cos[Pi/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714096}}]}, 
   {Hue[0.7459364349530697], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(23*Pi)/15]^2, 
       0.31695593148714024}, {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, \
0.311867536226639}}]}, 
   {Hue[0.7460694920486863], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(47*Pi)/30]^2, 
       0.33154008354139414}, {-Cos[Pi/30]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(23*Pi)/15]^2, \
0.31695593148714024}}]}, 
   {Hue[0.7462847327054983], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 
       0.35386023041001824}, {-Cos[Pi/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(47*Pi)/30]^2, \
0.33154008354139414}}]}, 
   {Hue[0.7465726838365876], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(49*Pi)/30]^2, 
       0.38168169232721827}, {-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, \
0.35386023041001824}}]}, 
   {Hue[0.7469206848988633], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(11*Sin[Pi/30]^2)/4, 0.4128060526669481}, 
      {-Cos[Pi/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721827}}]}, 
   {Hue[0.7473134543768909], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 
       0.4453237472356564}, {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}}]}, 
   {Hue[0.7477337701680052], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(26*Pi)/15]^2, 
       0.4776706018498101}, {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 \
+ ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}}]}, 
   {Hue[0.7481632319599271], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(53*Pi)/30]^2, 
       0.5085950701762788}, {-Cos[Pi/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498101}}]}, 
   {Hue[0.7485830706165225], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((5 \
- Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 
       0.5371028573756111}, {-Cos[Pi/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(53*Pi)/30]^2, 0.5085950701762788}}]}, 
   {Hue[0.7489749683244399], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
(17*Sin[Pi/30]^2)/4, 0.5624063276196118}, 
      {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}}]}, 
   {Hue[0.749321853715356], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(28*Pi)/15]^2, 
       0.5838857533279119}, {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}}]}, 
   {Hue[0.7496086381819954], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((-1 \
+ Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, 
       0.6010618457721149}, {-Cos[Pi/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279119}}]}, 
   {Hue[0.7498228629086992], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(29*Pi)/15]^2, 
       0.6135770923916888}, {-Cos[Pi/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, \
0.6010618457721149}}]}, 
   {Hue[0.7499552304743847], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(59*Pi)/30]^2, 
       0.6211835161491764}, {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916888}}]}, 
   {Hue[0.75], Polygon[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, \
0.623735072453278}, 
      {-Cos[Pi/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491764}}]}, 
   {Hue[0.8969191687728886], Polygon[{{-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, \
0.623735072453278}, 
      {-Cos[Pi/30]^2 + 5*Cos[Pi/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^4, \
0.6211835161491764}, 
      {-Cos[Pi/15]^2 + 5*Cos[Pi/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 1.2152748245287444}, 
      {-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}}]}, \
{Hue[0.893691477787979], 
    Polygon[{{-Cos[Pi/30]^2 + 5*Cos[Pi/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^4, \
0.6211835161491764}, 
      {-Cos[Pi/30]^2 + 5*Cos[Pi/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 0.613577092391689}, 
      {-Cos[Pi/15]^2 + 5*Cos[Pi/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^4, \
1.2005567894684717}, 
      {-Cos[Pi/15]^2 + 5*Cos[Pi/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 1.2152748245287444}}]}, 
   {Hue[0.887937987383099], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[Pi/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[Pi/15]^2, \
0.613577092391689}, 
      {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
      {-Cos[Pi/15]^2 + 5*Cos[Pi/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^4, \
1.2005567894684717}}]}, 
   {Hue[0.8798631619746441], Polygon[{{-Cos[Pi/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, \
0.6010618457721149}, 
      {-Cos[Pi/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 0.5838857533279119}, 
      {-Cos[Pi/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 1.143020501605284}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}}]}, 
   {Hue[0.8697605603773894], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, \
0.5838857533279119}, 
      {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
      {-Cos[Pi/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 1.143020501605284}}]}, 
   {Hue[0.8580086804224359], Polygon[{{-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}, 
      {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
      {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}}]}, \
{Hue[0.8450643457028333], 
    Polygon[{{-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
      {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 0.508595070176279}, 
      {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 0.9965396214846546}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}}]}, 
   {Hue[0.8314526857108315], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, \
0.508595070176279}, 
      {-Cos[Pi/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 0.4776706018498101}, 
      {-Cos[Pi/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 0.9361441841071271}, 
      {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 0.9965396214846546}}]}, 
   {Hue[0.8177525894173021], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, \
0.4776706018498101}, 
      {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
      {-Cos[Pi/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 0.9361441841071271}}]}, 
   {Hue[0.8045764873265254], Polygon[{{-Cos[Pi/30]^2 + (5*(5 - \
Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, \
0.4453237472356564}, 
      {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}}]}, 
   {Hue[0.7925435675439291], Polygon[{{-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}, 
      {-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 0.3816816923272188}, 
      {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 0.7478557941640108}, 
      {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}}]}, \
{Hue[0.7822462397883191], 
    Polygon[{{-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 0.3816816923272188}, 
      {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
      {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 0.7478557941640108}}]}, 
   {Hue[0.7742111483969316], Polygon[{{-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 
       0.35386023041001824}, {-Cos[Pi/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, \
0.33154008354139414}, 
      {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 0.6489952411032603}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}}]}, 
   {Hue[0.7688588308269239], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, \
0.33154008354139414}, 
      {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.31695593148714024}, 
      {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.6201700772082609}, 
      {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 0.6489952411032603}}]}, 
   {Hue[0.7664699507766723], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, \
0.31695593148714024}, 
      {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.311867536226639}, {-Cos[Pi/15]^2 + \
2*Sin[Pi/15]^2, 0.6101049646137003}, 
      {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.6201700772082609}}]}, 
   {Hue[0.7671666583943296], Polygon[{{-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, \
0.311867536226639}, 
      {-Cos[Pi/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.31695593148714024}, 
      {-Cos[Pi/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.6201700772082606}, 
      {-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}}]}, \
{Hue[0.7709093296001086], 
    Polygon[{{-Cos[Pi/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.31695593148714024}, 
      {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 0.33154008354139414}, 
      {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 0.6489952411032603}, 
      {-Cos[Pi/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.6201700772082606}}]}, 
   {Hue[0.7775006594645982], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, \
0.33154008354139414}, 
      {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
      {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 0.6489952411032603}}]}, 
   {Hue[0.786595922850486], Polygon[{{-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, \
0.35386023041001824}, 
      {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 0.38168169232721855}, 
      {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 0.7478557941640107}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}}]}, 
   {Hue[0.7977259842781645], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, \
0.38168169232721855}, 
      {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
      {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 0.7478557941640107}}]}, 
   {Hue[0.8103327834064996], Polygon[{{-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}, 
      {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
      {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}}]}, \
{Hue[0.8238092860352659], 
    Polygon[{{-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
      {-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 0.47767060184980986}, 
      {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 0.9361441841071267}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}}]}, 
   {Hue[0.837536614223645], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, \
0.47767060184980986}, 
      {-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 0.508595070176279}, 
      {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 0.9965396214846544}, 
      {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 0.9361441841071267}}]}, 
   {Hue[0.8509149369537166], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, \
0.508595070176279}, 
      {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
      {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 0.9965396214846544}}]}, 
   {Hue[0.8633874255499318], Polygon[{{-Cos[Pi/30]^2 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, \
0.5371028573756111}, 
      {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}}]}, 
   {Hue[0.8744578813272784], Polygon[{{-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}, 
      {-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 0.5838857533279119}, 
      {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 1.143020501605284}, 
      {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}}]}, \
{Hue[0.8837031443066281], 
    Polygon[{{-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 0.5838857533279119}, 
      {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
      {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 1.143020501605284}}]}, 
   {Hue[0.89078148032837], Polygon[{{-Cos[Pi/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, \
0.6010618457721149}, 
      {-Cos[Pi/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 0.613577092391689}, 
      {-Cos[Pi/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}}]}, 
   {Hue[0.8954380203639133], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, \
0.613577092391689}, 
      {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491764}, 
      {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
      {-Cos[Pi/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}}]}, 
   {Hue[0.8975081080777266], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, \
0.6211835161491764}, 
      {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, 0.623735072453278}, {-Cos[Pi/15]^2 + \
5*Sin[Pi/15]^2, 1.2202099292274005}, 
      {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}}]}, 
   {Hue[0.8969191687728886], Polygon[{{-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, \
0.623735072453278}, 
      {-Cos[Pi/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491764}, 
      {-Cos[Pi/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, 
      {-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}}]}, \
{Hue[0.893691477787979], 
    Polygon[{{-Cos[Pi/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491764}, 
      {-Cos[Pi/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(16*Pi)/15]^2, 0.613577092391689}, 
      {-Cos[Pi/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
      {-Cos[Pi/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}}]}, 
   {Hue[0.887937987383099], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(16*Pi)/15]^2, \
0.613577092391689}, 
      {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
      {-Cos[Pi/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}}]}, 
   {Hue[0.8798631619746441], Polygon[{{-Cos[Pi/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, \
0.6010618457721149}, 
      {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279119}, 
      {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}}]}, 
   {Hue[0.8697605603773894], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(17*Pi)/15]^2, \
0.5838857533279119}, 
      {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
      {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}}]}, 
   {Hue[0.8580086804224359], Polygon[{{-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}, 
      {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
      {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}}]}, \
{Hue[0.8450643457028333], 
    Polygon[{{-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
      {-Cos[Pi/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(37*Pi)/30]^2, 0.508595070176279}, 
      {-Cos[Pi/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}}]}, 
   {Hue[0.8314526857108315], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(37*Pi)/30]^2, \
0.508595070176279}, 
      {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498101}, 
      {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
      {-Cos[Pi/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}}]}, 
   {Hue[0.8177525894173021], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(19*Pi)/15]^2, \
0.4776706018498101}, 
      {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
      {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}}]}, 
   {Hue[0.8045764873265254], Polygon[{{-Cos[Pi/30]^2 + (5*(5 - \
Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, \
0.4453237472356564}, 
      {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}}]}, 
   {Hue[0.792543567543929], Polygon[{{-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}, 
      {-Cos[Pi/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272188}, 
      {-Cos[Pi/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, 
      {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}}]}, \
{Hue[0.7822462397883191], 
    Polygon[{{-Cos[Pi/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272188}, 
      {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
      {-Cos[Pi/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}}]}, 
   {Hue[0.7742111483969316], Polygon[{{-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 
       0.35386023041001824}, {-Cos[Pi/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(43*Pi)/30]^2, \
0.33154008354139414}, 
      {-Cos[Pi/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}}]}, 
   {Hue[0.768858830826924], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(43*Pi)/30]^2, \
0.33154008354139414}, 
      {-Cos[Pi/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714096}, 
      {-Cos[Pi/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
      {-Cos[Pi/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}}]}, 
   {Hue[0.7664699507766725], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(22*Pi)/15]^2, \
0.31695593148714096}, 
      {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.311867536226639}, {-Cos[Pi/15]^2 + \
2*Sin[Pi/15]^2, 0.6101049646137003}, 
      {-Cos[Pi/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}}]}, 
   {Hue[0.7671666583943297], Polygon[{{-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, \
0.311867536226639}, 
      {-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714024}, 
      {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, 
      {-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}}]}, \
{Hue[0.7709093296001086], 
    Polygon[{{-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714024}, 
      {-Cos[Pi/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(47*Pi)/30]^2, 0.33154008354139414}, 
      {-Cos[Pi/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
      {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}}]}, 
   {Hue[0.7775006594645982], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(47*Pi)/30]^2, \
0.33154008354139414}, 
      {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
      {-Cos[Pi/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}}]}, 
   {Hue[0.7865959228504857], Polygon[{{-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 
       0.35386023041001824}, {-Cos[Pi/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(49*Pi)/30]^2, \
0.38168169232721827}, 
      {-Cos[Pi/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}}]}, 
   {Hue[0.7977259842781644], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(49*Pi)/30]^2, \
0.38168169232721827}, 
      {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
      {-Cos[Pi/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}}]}, 
   {Hue[0.8103327834064996], Polygon[{{-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}, 
      {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
      {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}}]}, \
{Hue[0.8238092860352662], 
    Polygon[{{-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
      {-Cos[Pi/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498101}, 
      {-Cos[Pi/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}}]}, 
   {Hue[0.837536614223645], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(26*Pi)/15]^2, \
0.4776706018498101}, 
      {-Cos[Pi/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(53*Pi)/30]^2, 0.5085950701762788}, 
      {-Cos[Pi/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
      {-Cos[Pi/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}}]}, 
   {Hue[0.8509149369537166], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(53*Pi)/30]^2, \
0.5085950701762788}, 
      {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
      {-Cos[Pi/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}}]}, 
   {Hue[0.8633874255499318], Polygon[{{-Cos[Pi/30]^2 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, \
0.5371028573756111}, 
      {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}}]}, 
   {Hue[0.8744578813272784], Polygon[{{-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}, 
      {-Cos[Pi/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279119}, 
      {-Cos[Pi/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, 
      {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}}]}, \
{Hue[0.8837031443066281], 
    Polygon[{{-Cos[Pi/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279119}, 
      {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
      {-Cos[Pi/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}}]}, 
   {Hue[0.8907814803283699], Polygon[{{-Cos[Pi/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, \
0.6010618457721149}, 
      {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916888}, 
      {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}}]}, 
   {Hue[0.8954380203639133], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(29*Pi)/15]^2, \
0.6135770923916888}, 
      {-Cos[Pi/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491764}, 
      {-Cos[Pi/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
      {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}}]}, 
   {Hue[0.8975081080777266], Polygon[{{-Cos[Pi/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(59*Pi)/30]^2, \
0.6211835161491764}, 
      {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, 0.623735072453278}, {-Cos[Pi/15]^2 + \
5*Sin[Pi/15]^2, 1.2202099292274005}, 
      {-Cos[Pi/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}}]}, 
   {Hue[1.1519197804957575], Polygon[{{-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, \
1.2202099292274005}, 
      {-Cos[Pi/15]^2 + 5*Cos[Pi/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 1.2152748245287444}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}}]}, \
{Hue[1.1442741458824044], 
    Polygon[{{-Cos[Pi/15]^2 + 5*Cos[Pi/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 1.2152748245287444}, 
      {-Cos[Pi/15]^2 + 5*Cos[Pi/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^4, \
1.2005567894684717}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}}]}, 
   {Hue[1.1304565417582846], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[Pi/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^4, 1.2005567894684717}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}}]}, 
   {Hue[1.1108534295112928], Polygon[{{-Cos[Pi/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/15]^2)/8, \
1.1763209525760518}, 
      {-Cos[Pi/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 1.143020501605284}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}]}, 
   {Hue[1.0860345379554115], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, \
1.143020501605284}, 
      {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}}]}, 
   {Hue[1.0567599664643168], Polygon[{{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, \
1.1013148858947206}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}]}, \
{Hue[1.0239881909680149], 
    Polygon[{{-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
      {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 0.9965396214846546}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}]}, 
   {Hue[0.9888828411415257], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, \
0.9965396214846546}, 
      {-Cos[Pi/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 0.9361441841071271}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}}]}, 
   {Hue[0.952814038658589], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, \
0.9361441841071271}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}}]}, 
   {Hue[0.9173468112486896], Polygon[{{-Cos[Pi/15]^2 + (5*(5 - \
Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, \
0.8728320775698118}, 
      {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}]}, 
   {Hue[0.8842048193073804], Polygon[{{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, \
0.8090441125945327}, 
      {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 0.7478557941640108}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, 
      {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}]}, \
{Hue[0.8551940086640635], 
    Polygon[{{-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 0.7478557941640108}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}}]}, 
   {Hue[0.8320725131325242], Polygon[{{-Cos[Pi/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/15]^2)/4, \
0.6930472461935369}, 
      {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 0.6489952411032603}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}]}, 
   {Hue[0.8163682357879115], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, \
0.6489952411032603}, 
      {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.6201700772082609}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}}]}, 
   {Hue[0.8091779336960356], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, \
0.6201700772082609}, 
      {-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}, {(-5 - Sqrt[5])/8 \
+ (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}}]}, 
   {Hue[0.811010615627256], Polygon[{{-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, \
0.6101049646137003}, 
      {-Cos[Pi/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.6201700772082606}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}}]}, \
{Hue[0.8217225854417508], 
    Polygon[{{-Cos[Pi/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.6201700772082606}, 
      {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 0.6489952411032603}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}}]}, 
   {Hue[0.8405451657800196], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, \
0.6489952411032603}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}}]}, 
   {Hue[0.8661922839356144], Polygon[{{-Cos[Pi/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/15]^2)/4, \
0.6930472461935369}, 
      {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 0.7478557941640107}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}]}, 
   {Hue[0.8970319181359683], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, \
0.7478557941640107}, 
      {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}}]}, 
   {Hue[0.9312777207973922], Polygon[{{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, \
0.8090441125945327}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}]}, \
{Hue[0.9671505573061644], 
    Polygon[{{-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
      {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 0.9361441841071267}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}]}, 
   {Hue[1.0029870065533808], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, \
0.9361441841071267}, 
      {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 0.9965396214846544}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}}]}, 
   {Hue[1.037298903804603], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, \
0.9965396214846544}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}}]}, 
   {Hue[1.0687987231149985], Polygon[{{-Cos[Pi/15]^2 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[Pi/15]^2)/16, \
1.0520980143876293}, 
      {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}]}, 
   {Hue[1.0964051301930586], Polygon[{{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, \
1.1013148858947206}, 
      {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 1.143020501605284}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, 
      {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}]}, 
   {Hue[1.119238894068329], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, \
1.143020501605284}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}}]}, 
   {Hue[1.1366153167311264], Polygon[{{-Cos[Pi/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/15]^2)/8, \
1.1763209525760518}, 
      {-Cos[Pi/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}]}, 
   {Hue[1.1480364954725761], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, \
1.2005567894684717}, 
      {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}}]}, 
   {Hue[1.1531850191953645], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, \
1.2152748245287444}, 
      {-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}, {(-5 - Sqrt[5])/8 \
+ (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}}]}, 
   {Hue[1.1519197804957575], Polygon[{{-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, \
1.2202099292274005}, 
      {-Cos[Pi/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}}]}, \
{Hue[1.1442741458824042], 
    Polygon[{{-Cos[Pi/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, 
      {-Cos[Pi/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}}]}, 
   {Hue[1.1304565417582846], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(16*Pi)/15]^2, \
1.2005567894684717}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}}]}, 
   {Hue[1.110853429511293], Polygon[{{-Cos[Pi/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/15]^2)/8, \
1.1763209525760518}, 
      {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}]}, 
   {Hue[1.0860345379554117], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(17*Pi)/15]^2, \
1.1430205016052841}, 
      {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}}]}, 
   {Hue[1.0567599664643168], Polygon[{{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, \
1.1013148858947206}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}]}, \
{Hue[1.0239881909680149], 
    Polygon[{{-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
      {-Cos[Pi/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}]}, 
   {Hue[0.9888828411415257], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(37*Pi)/30]^2, \
0.9965396214846546}, 
      {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}}]}, 
   {Hue[0.9528140386585892], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(19*Pi)/15]^2, \
0.9361441841071272}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}}]}, 
   {Hue[0.9173468112486896], Polygon[{{-Cos[Pi/15]^2 + (5*(5 - \
Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, \
0.8728320775698118}, 
      {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}]}, 
   {Hue[0.8842048193073804], Polygon[{{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, \
0.8090441125945327}, 
      {-Cos[Pi/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, 
      {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}]}, \
{Hue[0.8551940086640635], 
    Polygon[{{-Cos[Pi/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}}]}, 
   {Hue[0.8320725131325242], Polygon[{{-Cos[Pi/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/15]^2)/4, \
0.6930472461935369}, 
      {-Cos[Pi/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}]}, 
   {Hue[0.8163682357879115], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(43*Pi)/30]^2, \
0.6489952411032606}, 
      {-Cos[Pi/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}}]}, 
   {Hue[0.8091779336960356], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(22*Pi)/15]^2, \
0.6201700772082609}, 
      {-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}, {(-5 - Sqrt[5])/8 \
+ (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}}]}, 
   {Hue[0.811010615627256], Polygon[{{-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, \
0.6101049646137003}, 
      {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}}]}, \
{Hue[0.8217225854417511], 
    Polygon[{{-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, 
      {-Cos[Pi/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}}]}, 
   {Hue[0.8405451657800197], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(47*Pi)/30]^2, \
0.6489952411032603}, 
      {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}}]}, 
   {Hue[0.8661922839356144], Polygon[{{-Cos[Pi/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/15]^2)/4, \
0.6930472461935369}, 
      {-Cos[Pi/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}]}, 
   {Hue[0.897031918135968], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(49*Pi)/30]^2, \
0.7478557941640104}, 
      {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}}]}, 
   {Hue[0.9312777207973922], Polygon[{{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, \
0.8090441125945327}, 
      {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}]}, \
{Hue[0.9671505573061646], 
    Polygon[{{-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
      {-Cos[Pi/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}]}, 
   {Hue[1.0029870065533808], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(26*Pi)/15]^2, \
0.9361441841071272}, 
      {-Cos[Pi/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}}]}, 
   {Hue[1.037298903804603], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(53*Pi)/30]^2, \
0.9965396214846538}, 
      {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}}]}, 
   {Hue[1.0687987231149985], Polygon[{{-Cos[Pi/15]^2 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[Pi/15]^2)/16, \
1.0520980143876293}, 
      {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}]}, 
   {Hue[1.0964051301930586], Polygon[{{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, \
1.1013148858947206}, 
      {-Cos[Pi/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, 
      {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}]}, 
   {Hue[1.119238894068329], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(28*Pi)/15]^2, \
1.143020501605284}, 
      {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}}]}, 
   {Hue[1.1366153167311266], Polygon[{{-Cos[Pi/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[Pi/15]^2)/8, \
1.1763209525760518}, 
      {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}]}, 
   {Hue[1.1480364954725761], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(29*Pi)/15]^2, \
1.2005567894684717}, 
      {-Cos[Pi/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}}]}, 
   {Hue[1.1531850191953645], Polygon[{{-Cos[Pi/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(59*Pi)/30]^2, \
1.2152748245287444}, 
      {-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}, {(-5 - Sqrt[5])/8 \
+ (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}}]}, 
   {Hue[1.4515405710526808], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2)/16, 1.7633557568774196}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 2.2208803408437956}, 
      {-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}}]}, \
{Hue[1.4394331917269496], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 2.195318553032826}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 2.2208803408437956}}]}, 
   {Hue[1.4174060855258936], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, 
       1.7355139912456734}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, 
      {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 2.195318553032826}}]}, 
   {Hue[1.3859755640136666], Polygon[{{(-5 - Sqrt[5])/8 + (-1 + \
Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, \

      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^4, 2.0946793219544757}, 
      {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}}]}, 
   {Hue[1.3459114956645708], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
       1.6537682358032735}, {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, \
1.5943005668830776}, {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 
       2.021043485921703}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^4, \
2.0946793219544757}}]}, 
   {Hue[1.2982570195785088], Polygon[{{(-5 - Sqrt[5])/8 + (17*(-1 + \
Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
      {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}}]}, \
{Hue[1.2443563673933402], 
    Polygon[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 \
+ Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 1.8336364565828087}, 
      {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}}]}, 
   {Hue[1.1858912253960032], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 
       1.4441489417584883}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
       1.3571288512592454}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, \
1.7241122839361493}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 1.8336364565828087}}]}, 
   {Hue[1.1249235208921113], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
       1.3571288512592454}, {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}, {-Cos[(2*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, \
1.6081701375219566}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 1.7241122839361493}}]}, 
   {Hue[1.0639360445333357], Polygon[{{(-5 - Sqrt[5])/8 + (5*(5 - \
Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}, {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, \
1.1729281630054869}, {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 
       1.4902097135042385}, {-Cos[(2*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
       1.6081701375219566}}]}, {Hue[1.0058489043932322], Polygon[{{(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.3759750672106554}, 
      {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}}]}, \
{Hue[0.9539675647357949], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
      {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.3759750672106554}}]}, 
   {Hue[0.9117944533080236], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.1890852819516717}, 
      {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}}]}, 
   {Hue[0.8826420709680411], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       0.9389137397717193}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       0.8965062230902947}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, \
1.1340136417284856}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.1890852819516717}}]}, 
   {Hue[0.8690722332949067], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       0.8965062230902947}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, \
0.8816778784387096}, {-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 
       1.1147172382160913}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 
       1.1340136417284856}}]}, {Hue[0.8723433184533051], Polygon[{{(-5 - \
Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.1340136417284856}, 
      {-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}}]}, \
{Hue[0.8921194046283185], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.1890852819516717}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.1340136417284856}}]}, 
   {Hue[0.9265683688708142], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       0.9389137397717193}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.1890852819516717}}]}, 
   {Hue[0.9727853055690071], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.375975067210655}, 
      {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}}]}, 
   {Hue[1.0273535543716572], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.0837396094369778}, {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, \
1.1729281630054869}, {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 
       1.4902097135042385}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       1.375975067210655}}]}, {Hue[1.0868332016797415], Polygon[{{(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
      {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}}]}, 
   {Hue[1.148064896825753], Polygon[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 \
+ Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 
       1.357128851259245}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, \
1.724112283936149}, 
      {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}}]}, 
   {Hue[1.2083001265871505], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 
       1.357128851259245}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       1.4441489417584883}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
1.833636456582809}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.724112283936149}}]}, 
   {Hue[1.2652229802289379], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       1.4441489417584883}, {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/64 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 
       1.5239001577085332}, {-Cos[(2*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, \
1.933432094411191}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.833636456582809}}]}, 
   {Hue[1.3169221647270715], Polygon[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 \
+ Sqrt[5])^2)/64 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 
       1.5239001577085332}, {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, \
1.5943005668830776}, {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 
       2.021043485921703}, {-Cos[(2*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 
       1.933432094411191}}]}, {Hue[1.3618484677321423], Polygon[{{(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.094679321954476}, 
      {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}}]}, \
{Hue[1.398774042451259], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
      {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.094679321954476}}]}, 
   {Hue[1.4267593111135977], Polygon[{{(-5 - Sqrt[5])/8 + (-1 + \
Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, \

      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.195318553032826}, 
      {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}}]}, 
   {Hue[1.445128461459208], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       1.7355139912456734}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       1.7563683493937294}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, \
2.2208803408437956}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.195318553032826}}]}, 
   {Hue[1.4534527605311989], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       1.7563683493937294}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, \
1.7633557568774196}, {-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 
       2.2294344764321825}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       2.2208803408437956}}]}, {Hue[1.4515405710526808], Polygon[{{(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.2208803408437956}, 
      {-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}}]}, \
{Hue[1.4394331917269496], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.195318553032826}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.2208803408437956}}]}, 
   {Hue[1.4174060855258936], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 
       1.7355139912456734}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, 
      {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.195318553032826}}]}, 
   {Hue[1.3859755640136666], Polygon[{{(-5 - Sqrt[5])/8 + (-1 + \
Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, \

      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.094679321954476}, 
      {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}}]}, 
   {Hue[1.3459114956645708], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 
       1.653768235803274}, {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, \
1.5943005668830776}, {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 
       2.021043485921703}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       2.094679321954476}}]}, {Hue[1.2982570195785088], Polygon[{{(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
      {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}}]}, \
{Hue[1.2443563673933402], 
    Polygon[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 \
+ Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828087}, 
      {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}}]}, 
   {Hue[1.1858912253960032], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 
       1.4441489417584883}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 
       1.3571288512592459}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/15]^2, \
1.7241122839361496}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828087}}]}, 
   {Hue[1.1249235208921116], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 
       1.3571288512592459}, {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}, {-Cos[(2*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, \
1.6081701375219566}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361496}}]}, 
   {Hue[1.0639360445333357], Polygon[{{(-5 - Sqrt[5])/8 + (5*(5 - \
Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}, {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, \
1.1729281630054869}, {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 
       1.4902097135042385}, {-Cos[(2*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
       1.6081701375219566}}]}, {Hue[1.0058489043932322], Polygon[{{(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.375975067210655}, 
      {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}}]}, \
{Hue[0.9539675647357949], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
      {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.375975067210655}}]}, 
   {Hue[0.9117944533080238], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.1890852819516722}, 
      {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}}]}, 
   {Hue[0.8826420709680414], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 
       0.9389137397717198}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 
       0.896506223090295}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(22*Pi)/15]^2, \
1.1340136417284858}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.1890852819516722}}]}, 
   {Hue[0.8690722332949069], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 
       0.896506223090295}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, \
0.8816778784387096}, {-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 
       1.1147172382160913}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       1.1340136417284858}}]}, {Hue[0.8723433184533051], Polygon[{{(-5 - \
Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284856}, 
      {-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}}]}, \
{Hue[0.8921194046283186], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.189085281951672}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284856}}]}, 
   {Hue[0.9265683688708142], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 
       0.9389137397717195}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.189085281951672}}]}, 
   {Hue[0.9727853055690069], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106545}, 
      {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}}]}, 
   {Hue[1.0273535543716572], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 
       1.0837396094369776}, {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, \
1.1729281630054869}, {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 
       1.4902097135042385}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.3759750672106545}}]}, {Hue[1.0868332016797415], Polygon[{{(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
      {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}}]}, \
{Hue[1.1480648968257532], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + \
((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361496}, 
      {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}}]}, 
   {Hue[1.2083001265871505], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 
       1.3571288512592459}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 
       1.4441489417584876}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(53*Pi)/30]^2, \
1.833636456582808}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361496}}]}, 
   {Hue[1.2652229802289374], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 
       1.4441489417584876}, {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/64 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 
       1.5239001577085332}, {-Cos[(2*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, \
1.933432094411191}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.833636456582808}}]}, 
   {Hue[1.3169221647270715], Polygon[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 \
+ Sqrt[5])^2)/64 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 
       1.5239001577085332}, {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, \
1.5943005668830776}, {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 
       2.021043485921703}, {-Cos[(2*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 
       1.933432094411191}}]}, {Hue[1.3618484677321423], Polygon[{{(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.094679321954476}, 
      {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}}]}, \
{Hue[1.398774042451259], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
      {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.094679321954476}}]}, 
   {Hue[1.4267593111135977], Polygon[{{(-5 - Sqrt[5])/8 + (-1 + \
Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, \

      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.1953185530328256}, 
      {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}}]}, 
   {Hue[1.445128461459208], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 
       1.7355139912456732}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 
       1.7563683493937294}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(59*Pi)/30]^2, \
2.2208803408437956}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.1953185530328256}}]}, 
   {Hue[1.4534527605311989], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 
       1.7563683493937294}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, \
1.7633557568774196}, {-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 
       2.2294344764321825}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       2.2208803408437956}}]}, {Hue[1.7636697581916874], \
Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 2.2208803408437956}, 
      {-3/4 + (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, {1/2, \
2.598076211353316}}]}, 
   {Hue[1.7473374329103815], Polygon[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[Pi/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, \
2.2208803408437956}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 2.195318553032826}, 
      {-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, {-3/4 \
+ (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}}]}, 
   {Hue[1.7175088614508085], Polygon[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[Pi/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, \
2.195318553032826}, 
      {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 
       2.5601613609103286}}]}, {Hue[1.674806673768865], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^4, 2.0946793219544757}, 
      {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, \
2.447478090794556}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}}]}, {Hue[1.620163576965886], \
Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^4, 
       2.0946793219544757}, {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, \
2.021043485921703}, {5/16, 2.3642850399222173}, 
      {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, \
2.447478090794556}}]}, 
   {Hue[1.5548510715317754], Polygon[{{-Cos[(2*Pi)/15]^2 + \
(17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
      {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{5/16, 2.3642850399222173}}]}, 
   {Hue[1.48052278832171], Polygon[{{-Cos[(2*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 
       1.933432094411191}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, \
1.8336364565828087}, 
      {-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
       2.264540963292246}}]}, {Hue[1.399276952243562], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 1.8336364565828087}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 1.7241122839361493}, 
      {-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 2.02317839809799}, \
{-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, 
       2.1499828315181597}}]}, {Hue[1.313741699296113], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 1.7241122839361493}, 
      {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 
       2.02317839809799}}]}, {Hue[1.2271811168333424], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 \
+ Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
      {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, \
{-1/16, 1.7488835724541527}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}}]}, 
   {Hue[1.143601496008457], Polygon[{{-Cos[(2*Pi)/15]^2 + \
(11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.3759750672106554}, 
      {-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, \
1.6132809148526017}, {-1/16, 1.7488835724541527}}]}, 
   {Hue[1.067794362092841], Polygon[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 
       1.3759750672106554}, {-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       1.2727298803122147}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + \
Sqrt[5])/16, 1.4898021598760776}, 
      {-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, \
1.6132809148526017}}]}, 
   {Hue[1.0051797586990607], Polygon[{{-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       1.2727298803122147}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, \
1.1890852819516717}, 
      {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
       1.4898021598760776}}]}, {Hue[0.9612539387259397], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.1890852819516717}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.1340136417284856}, 
      {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, \
1.3224570770546993}, {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, 
       1.389101261457407}}]}, {Hue[0.9405480917548931], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.1340136417284856}, 
      {-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, {-1/4, \
1.299038105676658}, 
      {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, \
1.3224570770546993}}]}, 
   {Hue[0.9453953640910937], Polygon[{{-Cos[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.1340136417284856}, 
      {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, \
1.3224570770546993}, {-1/4, 1.299038105676658}}]}, 
   {Hue[0.9751878443500579], Polygon[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 
       1.1340136417284856}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, \
1.1890852819516717}, 
      {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, \
1.3891012614574068}, {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, 
       1.3224570770546993}}]}, {Hue[1.0266086237085132], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.1890852819516717}, 
      {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, 
       1.3891012614574068}}]}, {Hue[1.0946509767260355], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.375975067210655}, 
      {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, \
1.6132809148526013}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
       1.4898021598760776}}]}, {Hue[1.1737986055100307], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.375975067210655}, 
      {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, \
{-1/16, 1.7488835724541527}, 
      {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, \
1.6132809148526013}}]}, 
   {Hue[1.2588612594171278], Polygon[{{-Cos[(2*Pi)/15]^2 + \
(11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
      {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-1/16, 1.7488835724541527}}]}, 
   {Hue[1.3453542168955448], Polygon[{{-Cos[(2*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
       1.6081701375219566}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, \
1.724112283936149}, 
      {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, \
2.0231783980979894}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
       1.8877889819588956}}]}, {Hue[1.4295657570946312], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.724112283936149}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.833636456582809}, 
      {-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, 
       2.0231783980979894}}]}, {Hue[1.5084842930584448], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.833636456582809}, 
      {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, 
       2.1499828315181597}}]}, {Hue[1.5796902483451727], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 \
+ Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
      {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, \
{5/16, 2.3642850399222173}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}}]}, 
   {Hue[1.6412574855504396], Polygon[{{-Cos[(2*Pi)/15]^2 + \
(17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.094679321954476}, 
      {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, \
2.4474780907945566}, {5/16, 2.3642850399222173}}]}, 
   {Hue[1.6916767985456147], Polygon[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
       2.094679321954476}, {-Cos[(2*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/8, \
2.1530633066599703}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, 
       2.4474780907945566}}]}, {Hue[1.7298010440057505], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.195318553032826}, 
      {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}}]}, {Hue[1.754807826634276], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.195318553032826}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.2208803408437956}, 
      {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, 
       2.5601613609103286}}]}, {Hue[1.7661755651964026], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.2208803408437956}, 
      {-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, {1/2, \
2.598076211353316}, 
      {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}}]}, 
   {Hue[1.7636697581916874], Polygon[{{-Cos[(2*Pi)/15]^2 + \
5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.2208803408437956}, 
      {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, \
2.588583579753018}, {1/2, 2.598076211353316}}]}, 
   {Hue[1.7473374329103815], Polygon[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(31*Pi)/30]^2, 
       2.2208803408437956}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(16*Pi)/15]^2, \
2.195318553032826}, 
      {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, 
       2.588583579753018}}]}, {Hue[1.7175088614508085], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.195318553032826}, 
      {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, 
       2.5601613609103286}}]}, {Hue[1.674806673768865], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.094679321954476}, 
      {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}}]}, {Hue[1.620163576965886], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.094679321954476}, 
      {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, \
{5/16, 2.3642850399222173}, 
      {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, \
2.4474780907945566}}]}, 
   {Hue[1.5548510715317754], Polygon[{{-Cos[(2*Pi)/15]^2 + \
(17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
      {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{5/16, 2.3642850399222173}}]}, 
   {Hue[1.48052278832171], Polygon[{{-Cos[(2*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 
       1.933432094411191}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(37*Pi)/30]^2, \
1.8336364565828087}, 
      {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
       2.264540963292246}}]}, {Hue[1.3992769522435617], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828087}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361496}, 
      {-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, 
       2.1499828315181597}}]}, {Hue[1.313741699296113], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361496}, 
      {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, 
       2.0231783980979903}}]}, {Hue[1.2271811168333424], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 \
+ Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
      {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, \
{-1/16, 1.7488835724541527}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}}]}, 
   {Hue[1.1436014960084568], Polygon[{{-Cos[(2*Pi)/15]^2 + \
(11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.375975067210655}, 
      {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, \
1.6132809148526013}, {-1/16, 1.7488835724541527}}]}, 
   {Hue[1.0677943620928405], Polygon[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(41*Pi)/30]^2, 
       1.375975067210655}, {-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       1.2727298803122147}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + \
Sqrt[5])/16, 1.4898021598760776}, 
      {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, \
1.6132809148526013}}]}, 
   {Hue[1.005179758699061], Polygon[{{-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       1.2727298803122147}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(43*Pi)/30]^2, \
1.1890852819516722}, 
      {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, \
1.3891012614574074}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
       1.4898021598760776}}]}, {Hue[0.9612539387259398], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.1890852819516722}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284858}, 
      {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}, {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, 
       1.3891012614574074}}]}, {Hue[0.9405480917548931], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284858}, 
      {-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, {-1/4, \
1.299038105676658}, 
      {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}}]}, 
   {Hue[0.9453953640910937], Polygon[{{-Cos[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284856}, 
      {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, \
1.3224570770546995}, {-1/4, 1.299038105676658}}]}, 
   {Hue[0.975187844350058], Polygon[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/15]^2, 
       1.1340136417284856}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(47*Pi)/30]^2, \
1.189085281951672}, 
      {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, 
       1.3224570770546995}}]}, {Hue[1.0266086237085132], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.189085281951672}, 
      {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, 
       1.389101261457407}}]}, {Hue[1.0946509767260353], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106545}, 
      {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, \
1.6132809148526008}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
       1.4898021598760776}}]}, {Hue[1.173798605510031], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106545}, 
      {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, \
{-1/16, 1.7488835724541527}, 
      {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, \
1.6132809148526008}}]}, 
   {Hue[1.2588612594171278], Polygon[{{-Cos[(2*Pi)/15]^2 + \
(11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
      {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-1/16, 1.7488835724541527}}]}, 
   {Hue[1.3453542168955452], Polygon[{{-Cos[(2*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
       1.6081701375219566}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(26*Pi)/15]^2, \
1.7241122839361496}, 
      {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
       1.8877889819588956}}]}, {Hue[1.4295657570946307], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361496}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.833636456582808}, 
      {-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}, {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, 
       2.0231783980979903}}]}, {Hue[1.5084842930584448], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.833636456582808}, 
      {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, 
       2.149982831518159}}]}, {Hue[1.5796902483451727], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 \
+ Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
      {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, \
{5/16, 2.3642850399222173}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}}]}, 
   {Hue[1.6412574855504396], Polygon[{{-Cos[(2*Pi)/15]^2 + \
(17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.094679321954476}, 
      {-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, \
2.4474780907945566}, {5/16, 2.3642850399222173}}]}, 
   {Hue[1.6916767985456147], Polygon[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(28*Pi)/15]^2, 
       2.094679321954476}, {-Cos[(2*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/8, \
2.1530633066599703}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, 
       2.4474780907945566}}]}, {Hue[1.7298010440057505], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.1953185530328256}, 
      {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}}]}, {Hue[1.7548078266342755], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.1953185530328256}, 
      {-Cos[(2*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.2208803408437956}, 
      {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, 
       2.5601613609103286}}]}, {Hue[1.7661755651964026], 
    Polygon[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.2208803408437956}, 
      {-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, {1/2, \
2.598076211353316}, 
      {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}}]}, 
   {Hue[2.0721365189125516], Polygon[{{1/2, 2.598076211353316}, {-3/4 + \
(5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, 
      {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}}]}, \
{Hue[2.051868478433417], 
    Polygon[{{-3/4 + (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, \
{-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}}]}, 
   {Hue[2.0147568451722315], Polygon[{{-3/4 + (5*Cos[Pi/15]^2)/4 + \
Sin[Pi/15]^2/2, 2.5601613609103286}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + 
        (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}}]}, \
{Hue[1.9615196424132235], 
    Polygon[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, 
       2.447478090794556}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4, \
2.697933958917173}, 
      {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}]}, 
   {Hue[1.8932349633164782], Polygon[{{-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + \
Sin[(2*Pi)/15]^2/2, 2.447478090794556}, {5/16, 2.3642850399222173}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {-(1 \
+ Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}}]}, \
{Hue[1.8113761446845897], 
    Polygon[{{5/16, 2.3642850399222173}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + \
Sqrt[5])^2)/64, 2.264540963292246}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}]}, \
{Hue[1.7178666273624303], 
    Polygon[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, 
       2.1499828315181597}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4, \
2.381720267244781}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}}]}, 
   {Hue[1.6151629473862272], Polygon[{{-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + \
Sin[(7*Pi)/30]^2/2, 2.1499828315181597}, 
      {-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 2.02317839809799}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}}]}, \
{Hue[1.5063761715826158], 
    Polygon[{{-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, \
2.02317839809799}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
       1.8877889819588956}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + \
((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}}]}, 
   {Hue[1.3954393603985642], Polygon[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + \
Sqrt[5])^2/32, 1.8877889819588956}, {-1/16, 1.7488835724541527}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + 
        ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}}]}, \
{Hue[1.2873106528742468], 
    Polygon[{{-1/16, 1.7488835724541527}, {-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + \
Sin[(11*Pi)/30]^2/2, 1.6132809148526017}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}]}, \
{Hue[1.188144968126433], 
    Polygon[{{-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, \
1.6132809148526017}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
       1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}}]}, 
   {Hue[1.1052413197670452], Polygon[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + \
Sqrt[5])/16, 1.4898021598760776}, 
      {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, \
1.389101261457407}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}, {(5*(5 - \
Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + 
        ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}]}, \
{Hue[1.0464047878099396], 
    Polygon[{{-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, 
       1.3224570770546993}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4, \
1.453775372348889}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}}]}, 
   {Hue[1.0184018581582586], Polygon[{{-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + \
Sin[(7*Pi)/15]^2/2, 1.3224570770546993}, {-1/4, 1.299038105676658}, 
      {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}}]}, \
{Hue[1.0248466814226267], 
    Polygon[{{-1/4, 1.299038105676658}, {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + \
Sin[(8*Pi)/15]^2/2, 1.3224570770546993}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, 
      {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}}]}, \
{Hue[1.0648056546824212], 
    Polygon[{{-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, \
1.3224570770546993}, {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, 
       1.3891012614574068}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.5308481540548224}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 
       1.453775372348889}}]}, {Hue[1.1332229451546125], Polygon[{{-3/4 + \
(5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, 1.3891012614574068}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + 
        ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}}]}, \
{Hue[1.222768384388119], 
    Polygon[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, 
       1.6132809148526013}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.7870411277345808}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
       1.646496168027179}}]}, {Hue[1.3257686724185094], Polygon[{{-3/4 + \
(5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, 1.6132809148526013}, 
      {-1/16, 1.7488835724541527}, {(11*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 1.9398272078772507}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}}]}, 
   {Hue[1.4353603526016758], Polygon[{{-1/16, 1.7488835724541527}, {-3/4 + \
(5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}]}, \
{Hue[1.5458630674738991], 
    Polygon[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, 
       2.0231783980979894}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       2.243746859528865}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}}]}, 
   {Hue[1.6527278635300764], Polygon[{{-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + \
Sin[(11*Pi)/15]^2/2, 2.0231783980979894}, 
      {-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, \
2.1499828315181597}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}}]}, 
   {Hue[1.752348055371332], Polygon[{{-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + \
Sin[(23*Pi)/30]^2/2, 2.1499828315181597}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}}]}, 
   {Hue[1.841869011422735], Polygon[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + \
Sqrt[5])^2)/64, 2.264540963292246}, {5/16, 2.3642850399222173}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {(5 - \
Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + 
        (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}}]}, \
{Hue[1.9190385870681022], 
    Polygon[{{5/16, 2.3642850399222173}, {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + \
Sin[(13*Pi)/15]^2/2, 2.4474780907945566}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}]}, \
{Hue[1.982100731892576], 
    Polygon[{{-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}}]}, 
   {Hue[2.0297235902456667], Polygon[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + \
Sqrt[5]))/32, 2.5129980122544064}, 
      {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, \
2.5601613609103286}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}, 
      {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}]}, 
   {Hue[2.0609526623086087], Polygon[{{-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + \
Sin[(14*Pi)/15]^2/2, 2.5601613609103286}, 
      {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}}]}, \
{Hue[2.07518171512851], 
    Polygon[{{-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, {1/2, 2.598076211353316}, 
      {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}}]}, \
{Hue[2.0721365189125516], 
    Polygon[{{1/2, 2.598076211353316}, {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + \
Sin[(31*Pi)/30]^2/2, 2.588583579753018}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, 
      {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}}]}, \
{Hue[2.0518684784334167], 
    Polygon[{{-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, 
       2.5601613609103286}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 
       2.814442407752401}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 
       2.8434972909653364}}]}, {Hue[2.0147568451722315], Polygon[{{-3/4 + \
(5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, 2.5601613609103286}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + 
        (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}}]}, \
{Hue[1.9615196424132237], 
    Polygon[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, 
       2.4474780907945566}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 
       2.697933958917174}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}]}, 
   {Hue[1.8932349633164782], Polygon[{{-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + \
Sin[(17*Pi)/15]^2/2, 2.4474780907945566}, {5/16, 2.3642850399222173}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {-(1 \
+ Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}}]}, \
{Hue[1.8113761446845897], 
    Polygon[{{5/16, 2.3642850399222173}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + \
Sqrt[5])^2)/64, 2.264540963292246}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}]}, \
{Hue[1.7178666273624303], 
    Polygon[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, 
       2.1499828315181597}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 
       2.381720267244781}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}}]}, 
   {Hue[1.6151629473862275], Polygon[{{-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + \
Sin[(37*Pi)/30]^2/2, 2.1499828315181597}, 
      {-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, \
2.0231783980979903}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}}]}, 
   {Hue[1.506376171582616], Polygon[{{-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + \
Sin[(19*Pi)/15]^2/2, 2.0231783980979903}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + 
        ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}}]}, \
{Hue[1.3954393603985642], 
    Polygon[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-1/16, 1.7488835724541527}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + 
        ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}}]}, \
{Hue[1.2873106528742466], 
    Polygon[{{-1/16, 1.7488835724541527}, {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + \
Sin[(41*Pi)/30]^2/2, 1.6132809148526013}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}]}, \
{Hue[1.188144968126433], 
    Polygon[{{-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, \
1.6132809148526013}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
       1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}}]}, 
   {Hue[1.1052413197670452], Polygon[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + \
Sqrt[5])/16, 1.4898021598760776}, 
      {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, \
1.3891012614574074}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.530848154054823}, 
      {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}]}, 
   {Hue[1.04640478780994], Polygon[{{-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + \
Sin[(43*Pi)/30]^2/2, 1.3891012614574074}, 
      {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.530848154054823}}]}, 
   {Hue[1.0184018581582586], Polygon[{{-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + \
Sin[(22*Pi)/15]^2/2, 1.3224570770546997}, {-1/4, 1.299038105676658}, 
      {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}}]}, \
{Hue[1.0248466814226267], 
    Polygon[{{-1/4, 1.299038105676658}, {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + \
Sin[(23*Pi)/15]^2/2, 1.3224570770546995}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, 
      {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}}]}, \
{Hue[1.0648056546824214], 
    Polygon[{{-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, \
1.3224570770546995}, {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, 
       1.389101261457407}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 
       1.5308481540548229}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 
       1.4537753723488893}}]}, {Hue[1.1332229451546125], Polygon[{{-3/4 + \
(5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, 1.389101261457407}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + 
        ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}}]}, \
{Hue[1.2227683843881187], 
    Polygon[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, 
       1.6132809148526008}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
       1.7870411277345801}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
       1.646496168027179}}]}, {Hue[1.3257686724185092], Polygon[{{-3/4 + \
(5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, 1.6132809148526008}, 
      {-1/16, 1.7488835724541527}, {(11*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 1.9398272078772507}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}}]}, 
   {Hue[1.4353603526016758], Polygon[{{-1/16, 1.7488835724541527}, {-3/4 + \
(5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}]}, \
{Hue[1.5458630674738996], 
    Polygon[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, 
       2.0231783980979903}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 
       2.243746859528866}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}}]}, 
   {Hue[1.6527278635300762], Polygon[{{-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + \
Sin[(26*Pi)/15]^2/2, 2.0231783980979903}, 
      {-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}}]}, \
{Hue[1.7523480553713318], 
    Polygon[{{-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
       2.264540963292246}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}}]}, 
   {Hue[1.841869011422735], Polygon[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + \
Sqrt[5])^2)/64, 2.264540963292246}, {5/16, 2.3642850399222173}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {(5 - \
Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + 
        (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}}]}, \
{Hue[1.9190385870681022], 
    Polygon[{{5/16, 2.3642850399222173}, {-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + \
Sin[(28*Pi)/15]^2/2, 2.4474780907945566}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}]}, \
{Hue[1.982100731892576], 
    Polygon[{{-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}}]}, 
   {Hue[2.0297235902456667], Polygon[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + \
Sqrt[5]))/32, 2.5129980122544064}, 
      {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, \
2.5601613609103286}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}, 
      {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}]}, 
   {Hue[2.0609526623086087], Polygon[{{-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + \
Sin[(29*Pi)/15]^2/2, 2.5601613609103286}, 
      {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}}]}, \
{Hue[2.07518171512851], 
    Polygon[{{-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, {1/2, 2.598076211353316}, 
      {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + 
        ((5 - Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}}]}, \
{Hue[2.3674721828927865], 
    Polygon[{{(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + 
        ((5 - Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/30]^2 + 
        2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 2.9745950829027943}, \
{-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}}]}, 
   {Hue[2.3435791873940444], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4, 
       2.8434972909653364}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4, \
2.8144424077524013}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 2.947488384456562}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 2.9745950829027943}}]}, 
   {Hue[2.2997463231769975], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4, 
       2.8144424077524013}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 2.947488384456562}}]}, 
   {Hue[2.2367790521701387], Polygon[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - \
(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 
       2.7659262761959793}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4, \
2.697933958917173}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 2.836596676593442}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}}]}, 
   {Hue[2.1558889625845437], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       2.697933958917173}, {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, \
2.6106791787633683}, {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 
       2.751525170659194}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, \
2.836596676593442}}]}, 
   {Hue[2.0587340081576357], Polygon[{{(17*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 2.6106791787633683}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
      {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}}]}, \
{Hue[1.9474823172746014], 
    Polygon[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^4, 2.521624931409047}, 
      {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}}]}, 
   {Hue[1.8249114602817478], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 
       2.381720267244781}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4, \
2.2437468595288657}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.379229777665829}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^4, 2.521624931409047}}]}, 
   {Hue[1.694559669296126], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 
       2.2437468595288657}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + \
((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.379229777665829}}]}, 
   {Hue[1.560946791808028], Polygon[{{(5*(5 - Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
      {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}}]}, 
   {Hue[1.4298683161332582], Polygon[{{(11*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 1.9398272078772507}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 1.891824180835019}, 
      {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}}]}, \
{Hue[1.3087026433935276], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, 
      {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 1.891824180835019}}]}, 
   {Hue[1.2064998853248192], Polygon[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 \
- (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
       1.646496168027179}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.5308481540548224}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, \
1.6089224974238359}, 
      {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}}]}, 
   {Hue[1.1333264119645146], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.5308481540548224}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4, \
1.453775372348889}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5224519023538965}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.6089224974238359}}]}, 
   {Hue[1.0982478764835666], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       1.453775372348889}, {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, \
1.4265847744427302}, {-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, \
1.49178284305241}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5224519023538965}}]}, 
   {Hue[1.1062396024958523], Polygon[{{(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, \
1.4265847744427302}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5224519023538965}, 
      {-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}}]}, \
{Hue[1.1560150919952359], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.6089224974238356}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5224519023538965}}]}, 
   {Hue[1.2406889106312275], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.5308481540548224}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.6089224974238356}}]}, 
   {Hue[1.3505881937813558], Polygon[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 \
- (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
       1.646496168027179}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.7870411277345808}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, \
1.8918241808350182}, 
      {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}}]}, 
   {Hue[1.4759703218853508], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.7870411277345808}, {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, \
1.9398272078772507}, {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 
       2.0573688751735335}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.8918241808350182}}]}, {Hue[1.6084361749140887], Polygon[{{(11*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}}]}, \
{Hue[1.7412405609975297], 
    Polygon[{{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 \
+ Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.3792297776658287}, 
      {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}}]}, 
   {Hue[1.869098630343711], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       2.243746859528865}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4, \
2.381720267244781}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409047}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.3792297776658287}}]}, 
   {Hue[1.9878801423853205], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       2.381720267244781}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
      {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409047}}]}, 
   {Hue[2.0943441888726686], Polygon[{{(5 - Sqrt[5])^2/32 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
      {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}}]}, 
   {Hue[2.185945733107094], Polygon[{{(17*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 2.6106791787633683}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}}]}, \
{Hue[2.2607044902137936], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, 
      {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}}]}, 
   {Hue[2.3171192479561684], Polygon[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - \
(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 
       2.7659262761959793}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       2.8144424077524013}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, \
2.947488384456562}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}}]}, 
   {Hue[2.354113390574855], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       2.8144424077524013}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       2.8434972909653364}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, \
2.9745950829027943}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}}]}, 
   {Hue[2.3710017050171284], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       2.8434972909653364}, {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, \
2.8531695488854605}, {-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 
       2.98356568610482}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       2.9745950829027943}}]}, {Hue[2.3674721828927865], Polygon[{{(5*(5 - \
Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.9745950829027943}, 
      {-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}}]}, \
{Hue[2.3435791873940444], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.9745950829027943}}]}, 
   {Hue[2.2997463231769975], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 
       2.814442407752401}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}}]}, 
   {Hue[2.236779052170139], Polygon[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - \
(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 
       2.7659262761959793}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 
       2.697933958917174}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/15]^2, \
2.8365966765934423}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}}]}, 
   {Hue[2.1558889625845437], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 
       2.697933958917174}, {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, \
2.6106791787633683}, {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 
       2.751525170659194}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       2.8365966765934423}}]}, {Hue[2.0587340081576357], Polygon[{{(17*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
      {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}}]}, \
{Hue[1.9474823172746014], 
    Polygon[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409047}, 
      {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}}]}, 
   {Hue[1.824911460281748], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 
       2.381720267244781}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/15]^2)/4, \
2.243746859528866}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409047}}]}, 
   {Hue[1.6945596692961264], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 
       2.243746859528866}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}}]}, 
   {Hue[1.560946791808028], Polygon[{{(5*(5 - Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
      {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}}]}, 
   {Hue[1.429868316133258], Polygon[{{(11*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 1.9398272078772507}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350185}, 
      {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}}]}, \
{Hue[1.3087026433935276], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, 
      {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350185}}]}, 
   {Hue[1.2064998853248192], Polygon[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 \
- (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
       1.646496168027179}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(43*Pi)/30]^2)/4, \
1.530848154054823}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}, 
      {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}}]}, 
   {Hue[1.1333264119645148], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 
       1.530848154054823}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 
       1.4537753723488895}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(22*Pi)/15]^2, \
1.522451902353897}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}}]}, 
   {Hue[1.0982478764835666], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 
       1.4537753723488895}, {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, \
1.4265847744427302}, {-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 
       1.49178284305241}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(22*Pi)/15]^2, \
1.522451902353897}}]}, 
   {Hue[1.1062396024958523], Polygon[{{(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, \
1.4265847744427302}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538967}, 
      {-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}}]}, \
{Hue[1.1560150919952359], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238359}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538967}}]}, 
   {Hue[1.2406889106312275], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 
       1.5308481540548229}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238359}}]}, 
   {Hue[1.3505881937813555], Polygon[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 \
- (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
       1.646496168027179}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
       1.7870411277345801}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(49*Pi)/30]^2, \
1.891824180835018}, 
      {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}}]}, 
   {Hue[1.4759703218853506], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
       1.7870411277345801}, {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, \
1.9398272078772507}, {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 
       2.0573688751735335}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.891824180835018}}]}, {Hue[1.6084361749140887], Polygon[{{(11*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}}]}, 
   {Hue[1.74124056099753], Polygon[{{(5*(5 - Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
      {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}}]}, 
   {Hue[1.8690986303437105], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 
       2.243746859528866}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 
       2.3817202672447797}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(53*Pi)/30]^2, \
2.5216249314090455}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}}]}, 
   {Hue[1.98788014238532], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 
       2.3817202672447797}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
      {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.5216249314090455}}]}, 
   {Hue[2.0943441888726686], Polygon[{{(5 - Sqrt[5])^2/32 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
      {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}}]}, 
   {Hue[2.185945733107094], Polygon[{{(17*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 2.6106791787633683}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}}]}, \
{Hue[2.2607044902137936], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, 
      {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}}]}, 
   {Hue[2.317119247956168], Polygon[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - \
(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 
       2.7659262761959793}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
       2.8144424077524013}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/15]^2, \
2.9474883844565616}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}}]}, 
   {Hue[2.354113390574855], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
       2.8144424077524013}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 
       2.8434972909653364}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(59*Pi)/30]^2, \
2.9745950829027943}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.9474883844565616}}]}, 
   {Hue[2.3710017050171284], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 
       2.8434972909653364}, {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, \
2.8531695488854605}, {-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 
       2.98356568610482}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       2.9745950829027943}}]}, {Hue[2.643249087454164], \
Polygon[{{-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 2.9745950829027943}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 2.9763034938899464}, 
      {-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}}]}, \
{Hue[2.616064463928478], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 2.9745950829027943}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 2.947488384456562}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 2.9540812792513704}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 2.9763034938899464}}]}, 
   {Hue[2.5661135568553854], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, \
2.947488384456562}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 2.9540812792513704}}]}, 
   {Hue[2.494280885530732], Polygon[{{-Cos[(7*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 
       2.901719090978228}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, \
2.836596676593442}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 2.859399797409293}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}}]}, 
   {Hue[2.4018999600279107], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 
       2.836596676593442}, {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, \
2.751525170659194}, {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 
       2.7833940695732022}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, \
2.859399797409293}}]}, 
   {Hue[2.2907978016564354], Polygon[{{-Cos[(7*Pi)/30]^2 + \
(17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
      {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
      {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}}]}, \
{Hue[2.1633659277062467], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 \
+ Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^4, 2.521624931409047}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.567335508777075}, 
      {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}}]}, 
   {Hue[2.0226727106138203], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^4, 2.521624931409047}, \

      {-Cos[(7*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.379229777665829}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^4, 2.427623046285348}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.567335508777075}}]}, 
   {Hue[1.8726391742163386], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 
       2.379229777665829}, {-Cos[(7*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, \
2.222607239695348}, 
      {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^4, 2.427623046285348}}]}, 
   {Hue[1.7183056497815727], Polygon[{{-Cos[(7*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 
       2.222607239695348}, {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, \
2.0573688751735335}, {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 
       2.0997996262255536}, {-Cos[(4*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
       2.2699589047379565}}]}, {Hue[1.5662071797520178], \
Polygon[{{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 1.891824180835019}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.9258466260207312}, 
      {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}}]}, \
{Hue[1.4248106904194633], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 1.891824180835019}, 
      {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
      {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.9258466260207312}}]}, 
   {Hue[1.3047580498304077], Polygon[{{-Cos[(7*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 
       1.737462364751998}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, \
1.6089224974238359}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.6209688555409114}, 
      {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}}]}, 
   {Hue[1.2182377214890119], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 
       1.6089224974238359}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, \
1.5224519023538965}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5257871330867276}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.6209688555409114}}]}, 
   {Hue[1.1765426572242061], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 
       1.5224519023538965}, {-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, \
1.49178284305241}, {-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 
       1.4917828430524098}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 
       1.5257871330867276}}]}, {Hue[1.1859894567721738], \
Polygon[{{-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5224519023538965}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5257871330867279}, 
      {-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}}]}, \
{Hue[1.2449301398141799], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5224519023538965}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.6089224974238356}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.6209688555409114}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5257871330867279}}]}, 
   {Hue[1.3446817155625337], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 
       1.6089224974238356}, {-Cos[(7*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 
       1.737462364751998}, {-Cos[(4*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, \
1.760690570377689}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.6209688555409114}}]}, 
   {Hue[1.4733390657214926], Polygon[{{-Cos[(7*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 
       1.737462364751998}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, \
1.8918241808350182}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.9258466260207305}, 
      {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}}]}, 
   {Hue[1.6192491332979304], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.8918241808350182}, {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, \
2.0573688751735335}, {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 
       2.0997996262255536}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       1.9258466260207305}}]}, {Hue[1.772630463448878], \
Polygon[{{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
      {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}}]}, \
{Hue[1.9257927156434174], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 \
+ Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.3792297776658287}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.4276230462853476}, 
      {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}}]}, 
   {Hue[2.0727994531886242], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       2.3792297776658287}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, \
2.521624931409047}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.4276230462853476}}]}, 
   {Hue[2.209054340726577], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       2.521624931409047}, {-Cos[(7*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, \
2.646328981764321}, 
      {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}}]}, 
   {Hue[2.330969731229093], Polygon[{{-Cos[(7*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 
       2.646328981764321}, {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, \
2.751525170659194}, {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 
       2.7833940695732022}, {-Cos[(4*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 
       2.686221801523239}}]}, {Hue[2.4357357054445568], \
Polygon[{{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.859399797409293}, 
      {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}}]}, \
{Hue[2.5211680993536665], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.859399797409293}}]}, 
   {Hue[2.585611107353495], Polygon[{{-Cos[(7*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 
       2.901719090978228}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, \
2.947488384456562}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.9540812792513704}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}}]}, 
   {Hue[2.6278761118839737], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       2.947488384456562}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, \
2.9745950829027943}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.9763034938899464}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.9540812792513704}}]}, 
   {Hue[2.6472047657119675], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       2.9745950829027943}, {-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, \
2.98356568610482}, {-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 
       2.98356568610482}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       2.9763034938899464}}]}, {Hue[2.6432490874541643], \
Polygon[{{-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.9745950829027943}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.9763034938899464}, 
      {-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}}]}, \
{Hue[2.616064463928478], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.9745950829027943}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.9763034938899464}}]}, 
   {Hue[2.5661135568553854], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       2.9474883844565616}, {-Cos[(7*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/8, \
2.901719090978228}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}}]}, 
   {Hue[2.4942808855307326], Polygon[{{-Cos[(7*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 
       2.901719090978228}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/15]^2, \
2.8365966765934423}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}}]}, 
   {Hue[2.401899960027911], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       2.8365966765934423}, {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, \
2.751525170659194}, {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 
       2.7833940695732022}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       2.859399797409293}}]}, {Hue[2.2907978016564354], \
Polygon[{{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
      {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
      {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}}]}, 
   {Hue[2.163365927706247], Polygon[{{-Cos[(7*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 
       2.646328981764321}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(37*Pi)/30]^2, \
2.521624931409047}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.567335508777075}, 
      {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}}]}, 
   {Hue[2.0226727106138207], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       2.521624931409047}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/15]^2, \
2.379229777665829}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.567335508777075}}]}, 
   {Hue[1.8726391742163386], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       2.379229777665829}, {-Cos[(7*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, \
2.222607239695348}, 
      {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}}]}, 
   {Hue[1.7183056497815727], Polygon[{{-Cos[(7*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 
       2.222607239695348}, {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, \
2.0573688751735335}, {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 
       2.0997996262255536}, {-Cos[(4*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
       2.2699589047379565}}]}, {Hue[1.5662071797520174], \
Polygon[{{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350185}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.9258466260207308}, 
      {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}}]}, \
{Hue[1.4248106904194628], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350185}, 
      {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
      {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.9258466260207308}}]}, 
   {Hue[1.3047580498304079], Polygon[{{-Cos[(7*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 
       1.737462364751998}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(43*Pi)/30]^2, \
1.6089224974238363}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}, 
      {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}}]}, 
   {Hue[1.2182377214890123], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       1.6089224974238363}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(22*Pi)/15]^2, \
1.522451902353897}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867285}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}}]}, 
   {Hue[1.1765426572242061], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       1.522451902353897}, {-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, \
1.49178284305241}, {-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 
       1.4917828430524098}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       1.5257871330867285}}]}, {Hue[1.1859894567721738], \
Polygon[{{-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538967}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, 
      {-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}}]}, \
{Hue[1.24493013981418], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538967}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238359}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}}]}, 
   {Hue[1.344681715562534], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       1.6089224974238359}, {-Cos[(7*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 
       1.737462364751998}, {-Cos[(4*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, \
1.760690570377689}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}}]}, 
   {Hue[1.4733390657214926], Polygon[{{-Cos[(7*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 
       1.737462364751998}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(49*Pi)/30]^2, \
1.891824180835018}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.92584662602073}, 
      {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}}]}, 
   {Hue[1.6192491332979304], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.891824180835018}, {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, \
2.0573688751735335}, {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 
       2.0997996262255536}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.92584662602073}}]}, {Hue[1.772630463448878], \
Polygon[{{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
      {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}}]}, \
{Hue[1.9257927156434178], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 \
+ Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
      {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}}]}, 
   {Hue[2.0727994531886234], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       2.379229777665829}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(53*Pi)/30]^2, \
2.5216249314090455}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}}]}, 
   {Hue[2.2090543407265764], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       2.5216249314090455}, {-Cos[(7*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, \
2.646328981764321}, 
      {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}}]}, 
   {Hue[2.330969731229093], Polygon[{{-Cos[(7*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 
       2.646328981764321}, {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, \
2.751525170659194}, {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 
       2.7833940695732022}, {-Cos[(4*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 
       2.686221801523239}}]}, {Hue[2.4357357054445568], \
Polygon[{{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
      {-Cos[(7*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.859399797409293}, 
      {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}}]}, \
{Hue[2.5211680993536665], 
    Polygon[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.859399797409293}}]}, 
   {Hue[2.5856111073534946], Polygon[{{-Cos[(7*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 
       2.901719090978228}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/15]^2, \
2.9474883844565616}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.95408127925137}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}}]}, 
   {Hue[2.6278761118839733], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       2.9474883844565616}, {-Cos[(7*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(59*Pi)/30]^2, \
2.9745950829027943}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.95408127925137}}]}, 
   {Hue[2.6472047657119675], Polygon[{{-Cos[(7*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       2.9745950829027943}, {-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, \
2.98356568610482}, {-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 
       2.98356568610482}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       2.9763034938899455}}]}, {Hue[2.89463350450927], \
Polygon[{{-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 2.9763034938899464}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}}]}, \
{Hue[2.8645173966660127], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 2.9763034938899464}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 2.9540812792513704}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}}]}, 
   {Hue[2.809098185076654], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[Pi/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, \
2.9540812792513704}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}}]}, 
   {Hue[2.7293292620169383], Polygon[{{-Cos[(4*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 
       2.9156867970745455}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, \
2.859399797409293}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}]}, 
   {Hue[2.6266530666787644], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 
       2.859399797409293}, {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, \
2.7833940695732022}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 
       2.70871038548537}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
       2.768181798733441}}]}, {Hue[2.503049345238686], \
Polygon[{{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
      {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}]}, \
{Hue[2.3611117233560748], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 \
+ Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.567335508777075}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}}]}, 
   {Hue[2.2041703456886026], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 
       2.567335508777075}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^4, 2.427623046285348}, \

      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}}]}, 
   {Hue[2.0364877170885], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^4, 2.427623046285348}, \

      {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}}]}, 
   {Hue[1.863563942783131], Polygon[{{-Cos[(4*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
       2.2699589047379565}, {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, \
2.0997996262255536}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 
       2.0698782028004867}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}}]}, 
   {Hue[1.6925833193883624], Polygon[{{-Cos[(4*Pi)/15]^2 + \
(11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.9258466260207312}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}]}, \
{Hue[1.532970803129081], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.9258466260207312}, 
      {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}}]}, 
   {Hue[1.3967891337741858], Polygon[{{-Cos[(4*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, \
1.6209688555409114}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}]}, 
   {Hue[1.2981640862502626], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 
       1.6209688555409114}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, \
1.5257871330867276}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}}]}, 
   {Hue[1.2504628061541887], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 
       1.5257871330867276}, {-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, \
1.4917828430524098}, {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 
       1.4265847744427302}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       1.4640759018681937}}]}, {Hue[1.2612517763670301], \
Polygon[{{-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5257871330867279}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, 
      {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}}]}, \
{Hue[1.328521144442033], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5257871330867279}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.6209688555409114}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}}]}, 
   {Hue[1.4419055368838853], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
       1.6209688555409114}, {-Cos[(4*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 
       1.760690570377689}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}}]}, 
   {Hue[1.5874575963028892], Polygon[{{-Cos[(4*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, \
1.9258466260207305}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}]}, 
   {Hue[1.7518079887640008], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       1.9258466260207305}, {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, \
2.0997996262255536}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 
       2.0698782028004867}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.8914277190459856}}]}, {Hue[1.9239496991480405], \
Polygon[{{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
      {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}]}, \
{Hue[2.0953593484978716], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 \
+ Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.4276230462853476}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}}]}, 
   {Hue[2.2595254681489227], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 
       2.4276230462853476}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
2.567335508777075}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}}]}, 
   {Hue[2.4114382564713237], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       2.567335508777075}, {-Cos[(4*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, \
2.686221801523239}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}}]}, 
   {Hue[2.5472009337122237], Polygon[{{-Cos[(4*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 
       2.686221801523239}, {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, \
2.7833940695732022}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 
       2.70871038548537}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}}]}, 
   {Hue[2.663766907007236], Polygon[{{-Cos[(4*Pi)/15]^2 + \
(17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.859399797409293}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}]}, \
{Hue[2.7587700374951427], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.859399797409293}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}}]}, 
   {Hue[2.8304168564229024], Polygon[{{-Cos[(4*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 
       2.9156867970745455}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, \
2.9540812792513704}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}]}, 
   {Hue[2.877418907257412], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       2.9540812792513704}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, \
2.9763034938899464}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}}]}, 
   {Hue[2.8989518145205597], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       2.9763034938899464}, {-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, \
2.98356568610482}, {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 
       2.8531695488854605}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       2.8487773266631815}}]}, {Hue[2.89463350450927], \
Polygon[{{-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.9763034938899464}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}}]}, \
{Hue[2.8645173966660127], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.9763034938899464}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}}]}, 
   {Hue[2.809098185076654], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(16*Pi)/15]^2, 
       2.9540812792513704}, {-Cos[(4*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 
       2.9156867970745455}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       2.809014835019403}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 
       2.834803496770629}}]}, {Hue[2.7293292620169387], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}]}, 
   {Hue[2.6266530666787644], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       2.859399797409293}, {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, \
2.7833940695732022}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 
       2.70871038548537}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 
       2.7681817987334423}}]}, {Hue[2.503049345238686], \
Polygon[{{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
      {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}]}, \
{Hue[2.3611117233560748], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 \
+ Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.567335508777075}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}}]}, 
   {Hue[2.204170345688603], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
       2.567335508777075}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/15]^2, \
2.4276230462853485}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}}]}, 
   {Hue[2.0364877170885003], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
       2.4276230462853485}, {-Cos[(4*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, \
2.2699589047379565}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}}]}, 
   {Hue[1.863563942783131], Polygon[{{-Cos[(4*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
       2.2699589047379565}, {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, \
2.0997996262255536}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 
       2.0698782028004867}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}}]}, 
   {Hue[1.692583319388362], Polygon[{{-Cos[(4*Pi)/15]^2 + \
(11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.9258466260207308}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}]}, \
{Hue[1.532970803129081], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.9258466260207308}, 
      {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}}]}, 
   {Hue[1.396789133774186], Polygon[{{-Cos[(4*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(43*Pi)/30]^2, \
1.620968855540912}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}]}, 
   {Hue[1.2981640862502632], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
       1.620968855540912}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(22*Pi)/15]^2, \
1.5257871330867285}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}}]}, 
   {Hue[1.250462806154189], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       1.5257871330867285}, {-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, \
1.4917828430524098}, {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 
       1.4265847744427302}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 
       1.4640759018681944}}]}, {Hue[1.2612517763670303], \
Polygon[{{-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, 
      {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}}]}, \
{Hue[1.3285211444420333], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}}]}, 
   {Hue[1.4419055368838856], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
       1.6209688555409116}, {-Cos[(4*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 
       1.760690570377689}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}}]}, 
   {Hue[1.587457596302889], Polygon[{{-Cos[(4*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(49*Pi)/30]^2, \
1.92584662602073}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}]}, 
   {Hue[1.7518079887640006], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.92584662602073}, {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, \
2.0997996262255536}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 
       2.0698782028004867}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 
       1.8914277190459852}}]}, {Hue[1.9239496991480405], \
Polygon[{{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
      {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}]}, \
{Hue[2.095359348497872], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 \
+ Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}}]}, 
   {Hue[2.259525468148922], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
       2.4276230462853485}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(53*Pi)/30]^2, \
2.5673355087770737}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}}]}, 
   {Hue[2.411438256471323], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
       2.5673355087770737}, {-Cos[(4*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, \
2.686221801523239}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}}]}, 
   {Hue[2.5472009337122237], Polygon[{{-Cos[(4*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 
       2.686221801523239}, {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, \
2.7833940695732022}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 
       2.70871038548537}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}}]}, 
   {Hue[2.6637669070072354], Polygon[{{-Cos[(4*Pi)/15]^2 + \
(17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
      {-Cos[(4*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.859399797409293}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}]}, \
{Hue[2.7587700374951427], 
    Polygon[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.859399797409293}, 
      {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}}]}, 
   {Hue[2.830416856422902], Polygon[{{-Cos[(4*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 
       2.9156867970745455}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/15]^2, \
2.95408127925137}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}]}, 
   {Hue[2.877418907257412], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
       2.95408127925137}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(59*Pi)/30]^2, \
2.9763034938899455}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}}]}, 
   {Hue[2.8989518145205593], Polygon[{{-Cos[(4*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       2.9763034938899455}, {-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, \
2.98356568610482}, {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 
       2.8531695488854605}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 
       2.8487773266631806}}]}, {Hue[3.1177767577704367], Polygon[{{(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, 
      {-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 2.5979598975817524}, \
{7/2, 2.598076211353316}}]}, 
   {Hue[3.085120487690447], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 
       2.8487773266631815}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, \
2.834803496770628}, 
      {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 2.5962550390555568}, \
{-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 
       2.5979598975817524}}]}, {Hue[3.0249334970135027], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 
       2.5962550390555568}}]}, {Hue[2.938224877580542], 
    Polygon[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + \
(5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}, 
      {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

       2.5891768866299354}}]}, {Hue[2.826531088590269], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {47/16, \
2.536452985962878}, 
      {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}}]}, 
   {Hue[2.69196725818493], Polygon[{{(-5 + Sqrt[5])/8 + (17*(1 + \
Sqrt[5])^2)/64, 2.70871038548537}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {47/16, 2.536452985962878}}]}, 
   {Hue[2.537307220286228], Polygon[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
      {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
       2.4790558351445977}}]}, {Hue[2.3661132933384383], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}, 
      {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}, {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \

       2.3948140222646948}}]}, {Hue[2.1829477607468397], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, 
       2.281657041700859}}]}, {Hue[1.9937099695278044], Polygon[{{(-5 + \
Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 
       2.239718051509763}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, \
2.0698782028004867}, {29/16, 1.9754350786598884}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}}]}, 
   {Hue[1.8061438546494695], Polygon[{{(-5 + Sqrt[5])/8 + (11*(1 + \
Sqrt[5])^2)/64, 2.0698782028004867}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, 
      {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, \
1.7955424168801202}, {29/16, 1.9754350786598884}}]}, 
   {Hue[1.630501146388733], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 
       1.8914277190459863}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.7178957504272219}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, \
1.7955424168801202}}]}, 
   {Hue[1.4800871500221224], Polygon[{{(-5 + Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.7178957504272219}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.5679671136605227}, {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 1.454550222063749}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}}]}, 
   {Hue[1.3707588649994245], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.5679671136605227}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       1.4640759018681937}, {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + \
(3*Sin[(7*Pi)/15]^2)/2, 1.3407174947497689}, 
      {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + (3*Sin[(13*Pi)/30]^2)/2, \
1.454550222063749}}]}, 
   {Hue[1.317763474340189], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       1.4640759018681937}, {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427302}, {5/4, 1.299038105676658}, 
      {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}}]}, 
   {Hue[1.3297758895707945], Polygon[{{(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427302}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, 
      {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, \
1.3407174947497686}, {5/4, 1.299038105676658}}]}, 
   {Hue[1.404418766893761], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 
       1.4640759018681935}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       1.5679671136605227}, {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + \
(3*Sin[(17*Pi)/30]^2)/2, 1.4545502220637487}, 
      {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, \
1.3407174947497686}}]}, 
   {Hue[1.5298146998911126], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       1.5679671136605227}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.7178957504272219}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}}]}, 
   {Hue[1.690216072241159], Polygon[{{(-5 + Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.7178957504272219}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.8914277190459856}, {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + \
(3*Sin[(19*Pi)/30]^2)/2, 1.7955424168801195}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}}]}, 
   {Hue[1.8707511295341432], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.8914277190459856}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, \
2.0698782028004867}, {29/16, 1.9754350786598884}, 
      {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, \
1.7955424168801195}}]}, 
   {Hue[2.0593455190716576], Polygon[{{(-5 + Sqrt[5])/8 + (11*(1 + \
Sqrt[5])^2)/64, 2.0698782028004867}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}}]}, 
   {Hue[2.2467519135423104], Polygon[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 \
+ Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
      {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 
       2.14040166785146}}]}, {Hue[2.425958020447293], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
      {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + (3*Sin[(23*Pi)/30]^2)/2, \
2.394814022264696}, {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + \
(3*Sin[(11*Pi)/15]^2)/2, 
       2.281657041700858}}]}, {Hue[2.5915924537970874], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + \
(3*Sin[(23*Pi)/30]^2)/2, 
       2.394814022264696}}]}, {Hue[2.739487584847168], Polygon[{{(-5 + \
Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 
       2.6273597595826383}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, \
2.70871038548537}, {47/16, 2.536452985962878}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}}]}, 
   {Hue[2.8663902825748693], Polygon[{{(-5 + Sqrt[5])/8 + (17*(1 + \
Sqrt[5])^2)/64, 2.70871038548537}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, 
      {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + (3*Sin[(13*Pi)/15]^2)/2, \
2.5712732770958877}, {47/16, 2.536452985962878}}]}, 
   {Hue[2.9697774235284013], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
       2.7681817987334414}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       2.809014835019403}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + \
Sqrt[5]))/32, 2.5891768866299354}, 
      {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + (3*Sin[(13*Pi)/15]^2)/2, \
2.5712732770958877}}]}, 
   {Hue[3.047738712887886], Polygon[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 \
+ Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       2.809014835019403}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       2.834803496770628}, {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + \
(3*Sin[(14*Pi)/15]^2)/2, 2.5962550390555568}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}}]}, 
   {Hue[3.098901843567922], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       2.834803496770628}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       2.8487773266631815}, {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + \
(3*Sin[(29*Pi)/30]^2)/2, 2.5979598975817524}, 
      {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + (3*Sin[(14*Pi)/15]^2)/2, \
2.5962550390555568}}]}, 
   {Hue[3.122385943707933], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       2.8487773266631815}, {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, \
2.8531695488854605}, {7/2, 2.598076211353316}, 
      {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}}]}, 
   {Hue[3.1177767577704367], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2)/16, 2.8531695488854605}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, 
      {-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, \
2.5979598975817524}, {7/2, 2.598076211353316}}]}, 
   {Hue[3.0851204876904474], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 
       2.8487773266631815}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 
       2.834803496770629}, {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + \
(3*Sin[(16*Pi)/15]^2)/2, 2.5962550390555568}, 
      {-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, \
2.5979598975817524}}]}, 
   {Hue[3.0249334970135027], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 
       2.834803496770629}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + \
(3*Sin[(16*Pi)/15]^2)/2, 
       2.5962550390555568}}]}, {Hue[2.938224877580543], 
    Polygon[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + \
(5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, 
      {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

       2.5891768866299354}}]}, {Hue[2.826531088590269], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {47/16, \
2.536452985962878}, 
      {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}}]}, 
   {Hue[2.69196725818493], Polygon[{{(-5 + Sqrt[5])/8 + (17*(1 + \
Sqrt[5])^2)/64, 2.70871038548537}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {47/16, 2.536452985962878}}]}, 
   {Hue[2.537307220286228], Polygon[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
      {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
       2.4790558351445977}}]}, {Hue[2.366113293338439], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
      {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}, {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + \
(3*Sin[(37*Pi)/30]^2)/2, 
       2.3948140222646948}}]}, {Hue[2.1829477607468397], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + \
(3*Sin[(19*Pi)/15]^2)/2, 
       2.2816570417008593}}]}, {Hue[1.9937099695278044], Polygon[{{(-5 + \
Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 
       2.239718051509763}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, \
2.0698782028004867}, {29/16, 1.9754350786598884}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}}]}, 
   {Hue[1.8061438546494692], Polygon[{{(-5 + Sqrt[5])/8 + (11*(1 + \
Sqrt[5])^2)/64, 2.0698782028004867}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, 
      {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + (3*Sin[(41*Pi)/30]^2)/2, \
1.7955424168801195}, {29/16, 1.9754350786598884}}]}, 
   {Hue[1.630501146388733], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 
       1.891427719045986}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + \
(3*Sin[(41*Pi)/30]^2)/2, 
       1.7955424168801195}}]}, {Hue[1.4800871500221229], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + \
((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
      {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + (3*Sin[(43*Pi)/30]^2)/2, \
1.4545502220637496}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \

       1.61498867371741}}]}, {Hue[1.3707588649994251], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
      {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + \
(3*Sin[(43*Pi)/30]^2)/2, 
       1.4545502220637496}}]}, {Hue[1.317763474340189], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
      {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {5/4, \
1.299038105676658}, 
      {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}}]}, 
   {Hue[1.3297758895707947], Polygon[{{(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427302}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, 
      {-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, \
1.340717494749769}, {5/4, 1.299038105676658}}]}, 
   {Hue[1.4044187668937613], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 
       1.464075901868194}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 
       1.5679671136605229}, {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + \
(3*Sin[(47*Pi)/30]^2)/2, 1.454550222063749}, 
      {-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, \
1.340717494749769}}]}, 
   {Hue[1.5298146998911126], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 
       1.5679671136605229}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.7178957504272219}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}}]}, 
   {Hue[1.6902160722411583], Polygon[{{(-5 + Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.7178957504272219}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 
       1.8914277190459852}, {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + \
(3*Sin[(49*Pi)/30]^2)/2, 1.795542416880119}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}}]}, 
   {Hue[1.8707511295341432], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 
       1.8914277190459852}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, \
2.0698782028004867}, {29/16, 1.9754350786598884}, 
      {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, \
1.795542416880119}}]}, 
   {Hue[2.0593455190716576], Polygon[{{(-5 + Sqrt[5])/8 + (11*(1 + \
Sqrt[5])^2)/64, 2.0698782028004867}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}}]}, 
   {Hue[2.2467519135423113], Polygon[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 \
+ Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
      {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 
       2.14040166785146}}]}, {Hue[2.425958020447292], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
      {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + (3*Sin[(53*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + \
(3*Sin[(26*Pi)/15]^2)/2, 
       2.2816570417008593}}]}, {Hue[2.591592453797087], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + \
(3*Sin[(53*Pi)/30]^2)/2, 
       2.3948140222646948}}]}, {Hue[2.739487584847168], Polygon[{{(-5 + \
Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 
       2.6273597595826383}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, \
2.70871038548537}, {47/16, 2.536452985962878}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}}]}, 
   {Hue[2.866390282574869], Polygon[{{(-5 + Sqrt[5])/8 + (17*(1 + \
Sqrt[5])^2)/64, 2.70871038548537}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, 
      {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + (3*Sin[(28*Pi)/15]^2)/2, \
2.5712732770958877}, {47/16, 2.536452985962878}}]}, 
   {Hue[2.969777423528401], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 
       2.768181798733441}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + \
(3*Sin[(28*Pi)/15]^2)/2, 
       2.5712732770958877}}]}, {Hue[3.047738712887886], 
    Polygon[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + \
(5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
      {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + (3*Sin[(29*Pi)/15]^2)/2, \
2.596255039055556}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, 
       2.5891768866299354}}]}, {Hue[3.0989018435679214], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
      {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + \
(3*Sin[(29*Pi)/15]^2)/2, 
       2.596255039055556}}]}, {Hue[3.1223859437079327], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, {7/2, \
2.598076211353316}, 
      {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}}]}, 
   {Hue[3.309545133160371], Polygon[{{7/2, 2.598076211353316}, {-1/4 + \
(15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 2.5979598975817524}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 2.235484296800204}, 
      {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}}]}, \
{Hue[3.27477818588327], 
    Polygon[{{-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, \
2.5979598975817524}, {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 
       2.5962550390555568}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, \
2.251331326578102}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 2.235484296800204}}]}, 
   {Hue[3.2105789098807223], Polygon[{{-1/4 + (15*Cos[Pi/15]^2)/4 + \
(3*Sin[Pi/15]^2)/2, 2.5962550390555568}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, 
      {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 2.251331326578102}}]}, 
   {Hue[3.1179937808791536], Polygon[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + \
(15*(5 + Sqrt[5]))/32, 2.5891768866299354}, 
      {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.284543605895154}, 
      {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}}]}, 
   {Hue[2.9986370210445124], Polygon[{{-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + \
(3*Sin[(2*Pi)/15]^2)/2, 2.5712732770958873}, {47/16, 2.536452985962878}, 
      {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
        2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.284543605895154}}]}, \
{Hue[2.854742676289618], 
    Polygon[{{47/16, 2.536452985962878}, {-1/4 + (3*(5 - Sqrt[5]))/16 + \
(15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}, 
      {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
      {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}}]}, \

   {Hue[2.689243823723982], Polygon[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}, 
      {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \
2.3948140222646948}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 2.202570463435661}, 
      {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}}]}, 
   {Hue[2.5059051705048945], Polygon[{{-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + \
(3*Sin[(7*Pi)/30]^2)/2, 2.3948140222646948}, 
      {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.112263515546569}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 2.202570463435661}}]}, 
   {Hue[2.3095456808650536], Polygon[{{-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + \
(3*Sin[(4*Pi)/15]^2)/2, 2.281657041700859}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-Cos[(11*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
        2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.112263515546569}}]}, \
{Hue[2.106401090958621], 
    Polygon[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}, 
      {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}}]}, \
{Hue[1.9046817761942598], 
    Polygon[{{29/16, 1.9754350786598884}, {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + \
(3*Sin[(11*Pi)/30]^2)/2, 1.7955424168801202}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^4, 1.6506863454327518}, 
      {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}}]}, \

   {Hue[1.71532829321509], Polygon[{{-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + \
(3*Sin[(11*Pi)/30]^2)/2, 1.7955424168801202}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
      {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^4, 1.6506863454327518}}]}, 
   {Hue[1.5526988086795988], Polygon[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + \
(3*(5 + Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + (3*Sin[(13*Pi)/30]^2)/2, \
1.454550222063749}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.2895708590441464}, 
      {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}}]}, 
   {Hue[1.4341662705105798], Polygon[{{-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 1.454550222063749}, 
      {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1623542887261817}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.2895708590441464}}]}, 
   {Hue[1.376660472761332], Polygon[{{-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + \
(3*Sin[(7*Pi)/15]^2)/2, 1.3407174947497689}, {5/4, 1.299038105676658}, 
      {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
        2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1623542887261817}}]}, \
{Hue[1.38978912215778], 
    Polygon[{{5/4, 1.299038105676658}, {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + \
(3*Sin[(8*Pi)/15]^2)/2, 1.3407174947497686}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1623542887261817}, 
      {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}}]}, \
{Hue[1.4707716405548008], 
    Polygon[{{-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, \
1.3407174947497686}, 
      {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.2895708590441464}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1623542887261817}}]}, 
   {Hue[1.606428761640884], Polygon[{{-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + \
(3*Sin[(17*Pi)/30]^2)/2, 1.4545502220637487}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
      {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.2895708590441464}}]}, 
   {Hue[1.7794965411592742], Polygon[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + \
(3*(5 + Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, \
1.7955424168801195}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}, 
      {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}}]}, 
   {Hue[1.9738275822275577], Polygon[{{-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + \
(3*Sin[(19*Pi)/30]^2)/2, 1.7955424168801195}, 
      {29/16, 1.9754350786598884}, {-Cos[(11*Pi)/30]^2 + \
(11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}}]}, 
   {Hue[2.176439858714008], Polygon[{{29/16, 1.9754350786598884}, {-1/4 + \
(15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
      {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
      {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}}]}, \

   {Hue[2.377470908295482], Polygon[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + \
Sqrt[5])^2)/32, 2.14040166785146}, 
      {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}, 
      {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}}]}, 
   {Hue[2.5694817175835882], Polygon[{{-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + \
(3*Sin[(11*Pi)/15]^2)/2, 2.281657041700858}, 
      {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + (3*Sin[(23*Pi)/30]^2)/2, \
2.394814022264696}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}}]}, 
   {Hue[2.746791263647233], Polygon[{{-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + \
(3*Sin[(23*Pi)/30]^2)/2, 2.394814022264696}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, 
      {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}}]}, 
   {Hue[2.9049996392327064], Polygon[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}, {47/16, 2.536452985962878}, 
      {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + 
        (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}}]}, \
{Hue[3.040678492615705], 
    Polygon[{{47/16, 2.536452985962878}, {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + \
(3*Sin[(13*Pi)/15]^2)/2, 2.5712732770958877}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895155}, 
      {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}}]}, \

   {Hue[3.1511759705326146], Polygon[{{-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + \
(3*Sin[(13*Pi)/15]^2)/2, 2.5712732770958877}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, 
      {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895155}}]}, 
   {Hue[3.2344918856547364], Polygon[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + \
(15*(5 + Sqrt[5]))/32, 2.5891768866299354}, 
      {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + (3*Sin[(14*Pi)/15]^2)/2, \
2.5962550390555568}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.251331326578102}, 
      {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}}]}, 
   {Hue[3.2891938072125857], Polygon[{{-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + \
(3*Sin[(14*Pi)/15]^2)/2, 2.5962550390555568}, 
      {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800204}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.251331326578102}}]}, 
   {Hue[3.31435968666402], Polygon[{{-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + \
(3*Sin[(29*Pi)/30]^2)/2, 2.5979598975817524}, {7/2, 2.598076211353316}, 
      {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 
        2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800204}}]}, \
{Hue[3.309545133160371], 
    Polygon[{{7/2, 2.598076211353316}, {-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + \
(3*Sin[(31*Pi)/30]^2)/2, 2.5979598975817524}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800204}, 
      {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}}]}, \
{Hue[3.27477818588327], 
    Polygon[{{-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, \
2.5979598975817524}, 
      {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + (3*Sin[(16*Pi)/15]^2)/2, \
2.5962550390555568}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578102}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800204}}]}, 
   {Hue[3.2105789098807223], Polygon[{{-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + \
(3*Sin[(16*Pi)/15]^2)/2, 2.5962550390555568}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, 
      {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578102}}]}, 
   {Hue[3.117993780879154], Polygon[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 \
+ Sqrt[5]))/32, 2.5891768866299354}, 
      {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895154}, 
      {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}}]}, 
   {Hue[2.998637021044513], Polygon[{{-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + \
(3*Sin[(17*Pi)/15]^2)/2, 2.5712732770958877}, {47/16, 2.536452985962878}, 
      {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
        2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895154}}]}, \
{Hue[2.854742676289618], 
    Polygon[{{47/16, 2.536452985962878}, {-1/4 + (3*(5 - Sqrt[5]))/16 + \
(15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}, 
      {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
      {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}}]}, \

   {Hue[2.6892438237239826], Polygon[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}, 
      {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.202570463435661}, 
      {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}}]}, 
   {Hue[2.5059051705048945], Polygon[{{-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + \
(3*Sin[(37*Pi)/30]^2)/2, 2.3948140222646948}, 
      {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.112263515546569}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.202570463435661}}]}, 
   {Hue[2.309545680865054], Polygon[{{-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + \
(3*Sin[(19*Pi)/15]^2)/2, 2.2816570417008593}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-Cos[(11*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
        2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.112263515546569}}]}, \
{Hue[2.106401090958621], 
    Polygon[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}, 
      {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}}]}, \
{Hue[1.9046817761942594], 
    Polygon[{{29/16, 1.9754350786598884}, {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + \
(3*Sin[(41*Pi)/30]^2)/2, 1.7955424168801195}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.6506863454327514}, 
      {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}}]}, \

   {Hue[1.7153282932150897], Polygon[{{-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + \
(3*Sin[(41*Pi)/30]^2)/2, 1.7955424168801195}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
      {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.6506863454327514}}]}, 
   {Hue[1.552698808679599], Polygon[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 \
+ Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + (3*Sin[(43*Pi)/30]^2)/2, \
1.4545502220637496}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.2895708590441473}, 
      {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}}]}, 
   {Hue[1.4341662705105804], Polygon[{{-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + \
(3*Sin[(43*Pi)/30]^2)/2, 1.4545502220637496}, 
      {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261822}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.2895708590441473}}]}, 
   {Hue[1.3766604727613323], Polygon[{{-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + \
(3*Sin[(22*Pi)/15]^2)/2, 1.3407174947497693}, {5/4, 1.299038105676658}, 
      {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
        2*Sin[(11*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261822}}]}, \
{Hue[1.38978912215778], 
    Polygon[{{5/4, 1.299038105676658}, {-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + \
(3*Sin[(23*Pi)/15]^2)/2, 1.340717494749769}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726182}, 
      {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}}]}, \
{Hue[1.470771640554801], 
    Polygon[{{-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, \
1.340717494749769}, 
      {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441468}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726182}}]}, 
   {Hue[1.606428761640884], Polygon[{{-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + \
(3*Sin[(47*Pi)/30]^2)/2, 1.454550222063749}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
      {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441468}}]}, 
   {Hue[1.7794965411592738], Polygon[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + \
(3*(5 + Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, \
1.795542416880119}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327507}, 
      {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}}]}, 
   {Hue[1.9738275822275573], Polygon[{{-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + \
(3*Sin[(49*Pi)/30]^2)/2, 1.795542416880119}, {29/16, 1.9754350786598884}, 
      {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 
        2*Sin[(11*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327507}}]}, \
{Hue[2.176439858714008], 
    Polygon[{{29/16, 1.9754350786598884}, {-1/4 + (15*(5 - Sqrt[5]))/32 + \
(3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
      {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
      {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}}]}, \

   {Hue[2.377470908295483], Polygon[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + \
Sqrt[5])^2)/32, 2.14040166785146}, 
      {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.112263515546569}, 
      {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}}]}, 
   {Hue[2.5694817175835873], Polygon[{{-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + \
(3*Sin[(26*Pi)/15]^2)/2, 2.2816570417008593}, 
      {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + (3*Sin[(53*Pi)/30]^2)/2, \
2.3948140222646948}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.112263515546569}}]}, 
   {Hue[2.7467912636472325], Polygon[{{-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + \
(3*Sin[(53*Pi)/30]^2)/2, 2.3948140222646948}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, 
      {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}}]}, 
   {Hue[2.9049996392327064], Polygon[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}, {47/16, 2.536452985962878}, 
      {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + 
        (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}}]}, \
{Hue[3.040678492615705], 
    Polygon[{{47/16, 2.536452985962878}, {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + \
(3*Sin[(28*Pi)/15]^2)/2, 2.5712732770958877}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.2845436058951543}, 
      {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}}]}, \

   {Hue[3.1511759705326146], Polygon[{{-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + \
(3*Sin[(28*Pi)/15]^2)/2, 2.5712732770958877}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, 
      {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.2845436058951543}}]}, 
   {Hue[3.2344918856547356], Polygon[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + \
(15*(5 + Sqrt[5]))/32, 2.5891768866299354}, 
      {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + (3*Sin[(29*Pi)/15]^2)/2, \
2.596255039055556}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578102}, 
      {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}}]}, 
   {Hue[3.2891938072125853], Polygon[{{-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + \
(3*Sin[(29*Pi)/15]^2)/2, 2.596255039055556}, 
      {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800204}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578102}}]}, 
   {Hue[3.3143596866640195], Polygon[{{-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + \
(3*Sin[(59*Pi)/30]^2)/2, 2.5979598975817515}, {7/2, 2.598076211353316}, 
      {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 
        2*Sin[(11*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800204}}]}, \
{Hue[3.467400772934102], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/30]^2 + 
        2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 2.235484296800204}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + 
        ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}}]}, 
   {Hue[3.4310082059729385], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[Pi/30]^2*Sin[(11*Pi)/30]^2 + 2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 
       2.235484296800204}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, \
2.251331326578102}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}}]}, 
   {Hue[3.363613575731937], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 
       2.251331326578102}, {-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
       2.2706462108209013}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}}]}, 
   {Hue[3.2662734356912804], Polygon[{{-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
       2.2706462108209013}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, \
2.284543605895154}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
      {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}}]}, 
   {Hue[3.140667577644415], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 
       2.284543605895154}, {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, \
2.2833691489150687}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 
       1.976615915035449}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       1.9339672857886054}}]}, {Hue[2.9891404922624196], \
Polygon[{{-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \

      {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}]}, \
{Hue[2.8147687456130015], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 2.202570463435661}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}]}, 
   {Hue[2.6214907189017604], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 
       2.202570463435661}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, \
2.112263515546569}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}}]}, 
   {Hue[2.4143372278878736], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 
       2.112263515546569}, {-Cos[(11*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 
       1.9869545564435858}, {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + \
Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}}]}, 
   {Hue[2.1998142555806046], Polygon[{{-Cos[(11*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 
       1.9869545564435858}, {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, \
1.8302685290560394}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 
       1.6555895184432492}, {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + \
Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}}]}, {Hue[1.986499821436085], \
Polygon[{{-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \

      {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^4, 1.6506863454327518}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, 
      {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}]}, \
{Hue[1.7858728052853214], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^4, 1.6506863454327518}, 
      {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}}]}, 
   {Hue[1.6131293084709537], Polygon[{{-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
       1.462871819562226}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 
       1.2895708590441464}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.0875191232355919}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}}]}, 
   {Hue[1.4869288353484795], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 
       1.2895708590441464}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 
       1.1623542887261817}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9393665425693402}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.0875191232355919}}]}, {Hue[1.4257409501630394], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1623542887261817}, 
      {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}}]}, 
   {Hue[1.4399220845337348], Polygon[{{-Cos[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1623542887261817}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, 
      {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}}]}, \
{Hue[1.5261542062447164], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1623542887261817}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.2895708590441464}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}}]}, 
   {Hue[1.6702121853838643], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 
       1.2895708590441464}, {-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
       1.462871819562226}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}}]}, 
   {Hue[1.85365101577133], Polygon[{{-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
       1.462871819562226}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.6506863454327514}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4764049667388979}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}}]}, 
   {Hue[2.05928126093413], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.6506863454327514}, {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, \
1.8302685290560394}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 
       1.6555895184432492}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4764049667388979}}]}, {Hue[2.273372914523169], \
Polygon[{{-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \

      {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}]}, \
{Hue[2.4855581354286147], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}]}, 
   {Hue[2.688045858477412], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       2.112263515546568}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       2.2025704634356615}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.9712852585698495}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.9084543807995193}}]}, {Hue[2.874896387786731], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}, 
      {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}}]}, 
   {Hue[3.0415131246211304], Polygon[{{-Cos[(11*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 
       2.2583039834915457}, {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, \
2.2833691489150687}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 
       1.976615915035449}, {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + \
Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}]}, 
   {Hue[3.184319965257541], Polygon[{{-Cos[(11*Pi)/30]^2 + \
(17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895155}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, 
      {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}]}, \
{Hue[3.3005637707443847], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895155}, 
      {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
      {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}}]}, 
   {Hue[3.3881894451764825], Polygon[{{-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
       2.2706462108209013}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       2.251331326578102}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       1.8202053857959208}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}}]}, 
   {Hue[3.445746846686327], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       2.251331326578102}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       2.235484296800204}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       1.778627524809822}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       1.8202053857959208}}]}, {Hue[3.4723072841329174], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800204}, 
      {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}}]}, 
   {Hue[3.4674007729341025], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Sin[(11*Pi)/30]^2, 2.229434476432184}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800204}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}}]}, \
{Hue[3.431008205972938], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800204}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578102}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}}]}, 
   {Hue[3.363613575731937], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       2.251331326578102}, {-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
       2.2706462108209013}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}}]}, 
   {Hue[3.2662734356912804], Polygon[{{-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
       2.2706462108209013}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       2.284543605895154}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 
       1.9339672857886046}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}}]}, 
   {Hue[3.140667577644415], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       2.284543605895154}, {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, \
2.2833691489150687}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 
       1.976615915035449}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 
       1.9339672857886046}}]}, {Hue[2.9891404922624196], \
Polygon[{{-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \

      {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}]}, \
{Hue[2.8147687456130015], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.202570463435661}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}]}, 
   {Hue[2.6214907189017613], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       2.202570463435661}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       2.112263515546569}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 
       1.9084543807995193}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 
       1.971285258569849}}]}, {Hue[2.414337227887874], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.112263515546569}, 
      {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}}]}, 
   {Hue[2.1998142555806046], Polygon[{{-Cos[(11*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 
       1.9869545564435858}, {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, \
1.8302685290560394}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 
       1.6555895184432492}, {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + \
Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}}]}, {Hue[1.9864998214360843], \
Polygon[{{-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \

      {-Cos[(11*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.6506863454327514}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, 
      {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}]}, \
{Hue[1.7858728052853214], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.6506863454327514}, 
      {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}}]}, 
   {Hue[1.6131293084709541], Polygon[{{-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
       1.462871819562226}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       1.2895708590441473}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 
       1.0875191232355927}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}}]}, 
   {Hue[1.4869288353484802], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       1.2895708590441473}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       1.1623542887261822}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 
       0.9393665425693406}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 
       1.0875191232355927}}]}, {Hue[1.4257409501630396], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261822}, 
      {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}}]}, 
   {Hue[1.439922084533735], Polygon[{{-Cos[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726182}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, 
      {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}}]}, \
{Hue[1.5261542062447166], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726182}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441468}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}}]}, 
   {Hue[1.6702121853838645], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       1.2895708590441468}, {-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
       1.462871819562226}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}}]}, 
   {Hue[1.8536510157713295], Polygon[{{-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
       1.462871819562226}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.6506863454327507}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
       1.4764049667388974}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}}]}, 
   {Hue[2.05928126093413], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.6506863454327507}, {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, \
1.8302685290560394}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 
       1.6555895184432492}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
       1.4764049667388974}}]}, {Hue[2.273372914523169], \
Polygon[{{-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \

      {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}]}, \
{Hue[2.4855581354286156], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.112263515546569}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}]}, 
   {Hue[2.6880458584774116], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       2.112263515546569}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       2.2025704634356607}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 
       1.9712852585698486}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 
       1.9084543807995193}}]}, {Hue[2.8748963877867304], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}, 
      {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}}]}, 
   {Hue[3.0415131246211304], Polygon[{{-Cos[(11*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 
       2.2583039834915457}, {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, \
2.2833691489150687}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 
       1.976615915035449}, {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + \
Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}]}, 
   {Hue[3.184319965257541], Polygon[{{-Cos[(11*Pi)/30]^2 + \
(17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, 
      {-Cos[(11*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.2845436058951543}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, 
      {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}]}, \
{Hue[3.3005637707443847], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.2845436058951543}, 
      {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
      {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}}]}, 
   {Hue[3.3881894451764816], Polygon[{{-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
       2.2706462108209013}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       2.251331326578102}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
       1.8202053857959217}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}}]}, 
   {Hue[3.445746846686327], Polygon[{{-Cos[(11*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       2.251331326578102}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       2.235484296800204}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 
       1.778627524809822}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
       1.8202053857959217}}]}, {Hue[3.4723072841329174], 
    Polygon[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800204}, 
      {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}}]}, 
   {Hue[3.5893709301014813], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5]))/8, 1.763355756877422}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}}]}, \
{Hue[3.5519448267327203], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 1.3346849311080466}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 1.2512975557014567}}]}, 
   {Hue[3.4822322824841914], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + Sqrt[5])*Sin[Pi/15]^2)/4, 
       1.8202053857959208}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 1.3346849311080466}}]}, 
   {Hue[3.3812725653793394], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.5625819810819546}, 
      {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}}]}, 
   {Hue[3.250837088112233], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       1.9339672857886054}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, \
1.976615915035449}, {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 
       1.6596693760099315}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 
       1.5625819810819546}}]}, {Hue[3.0934004279935157], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}}]}, \

   {Hue[2.912175305029343], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       1.99216913656241}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/4, \
1.971285258569849}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.7395717696563637}, 
      {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}}]}, 
   {Hue[2.711242586700889], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 
       1.971285258569849}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, \
1.908454380799519}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.705691841463222}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.7395717696563637}}]}, 
   {Hue[2.495795212462075], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 
       1.908454380799519}, {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + \
Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.705691841463222}}]}, 
   {Hue[2.272539791617155], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, \
1.6555895184432492}, {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 
       1.4819447816621787}, {-Cos[(13*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.6189603147994467}}]}, {Hue[2.0503204313987236], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.3017122836390151}, 
      {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}}]}, \

   {Hue[1.8409923414769445], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
       1.476404966738898}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.3017122836390151}}]}, 
   {Hue[1.6603252465056206], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^4, 0.8724918816600722}, 
      {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}}]}, 
   {Hue[1.5279504647343058], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.0875191232355919}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9393665425693402}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 
       0.6880869119781076}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^4, \
0.8724918816600722}}]}, 
   {Hue[1.463890467502354], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9393665425693402}, {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, \
0.8816778784387097}, {-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 
       0.6101049646136991}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 
       0.6880869119781076}}]}, {Hue[1.4791883208248788], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6880869119781069}, 
      {-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}}]}, \
{Hue[1.5695019075201666], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600716}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6880869119781069}}]}, 
   {Hue[1.7199704848953705], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0875191232355914}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600716}}]}, 
   {Hue[1.9113874874346408], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
      {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}}]}, 
   {Hue[2.1257358600466287], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4764049667388979}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, \
1.6555895184432492}, {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 
       1.4819447816621787}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.301712283639015}}]}, {Hue[2.3486915190005164], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}}]}, \

   {Hue[2.569493529990003], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.9084543807995193}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       1.705691841463221}, {-Cos[(13*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.6189603147994467}}]}, {Hue[2.7800763901623426], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}}]}, 
   {Hue[2.974292764562182], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.9712852585698495}, {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + \
Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}}]}, 
   {Hue[3.147378555703615], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       1.99216913656241}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, \
1.976615915035449}, {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 
       1.6596693760099315}, {-Cos[(13*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 
       1.7222389198769947}}]}, {Hue[3.2956209910178464], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, 
      {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}}]}, \

   {Hue[3.4161696021569146], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.9339672857886046}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}}]}, 
   {Hue[3.5069401575921857], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}, 
      {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}}]}, 
   {Hue[3.566549061742503], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       1.8202053857959208}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       1.778627524809822}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       1.2512975557014567}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       1.3346849311080466}}]}, {Hue[3.594180591134923], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + \
((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}}]}, 
   {Hue[3.5893709301014813], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5]))/8, 1.763355756877422}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}}]}, \
{Hue[3.5519448267327194], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + \
((5 + Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}}]}, 
   {Hue[3.4822322824841905], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 
       1.82020538579592}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}}]}, 
   {Hue[3.38127256537934], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}, 
      {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}}]}, 
   {Hue[3.250837088112233], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 
       1.9339672857886046}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, \
1.976615915035449}, {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 
       1.6596693760099315}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       1.5625819810819535}}]}, {Hue[3.0934004279935157], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}}]}, \

   {Hue[2.912175305029343], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       1.99216913656241}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(37*Pi)/30]^2)/4, \
1.971285258569849}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
      {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}}]}, 
   {Hue[2.7112425867008896], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 
       1.971285258569849}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 
       1.9084543807995193}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       1.705691841463221}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       1.7395717696563637}}]}, {Hue[2.4957952124620753], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}}]}, 
   {Hue[2.272539791617155], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, \
1.6555895184432492}, {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 
       1.4819447816621787}, {-Cos[(13*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.6189603147994467}}]}, {Hue[2.050320431398723], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, 
      {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}}]}, \

   {Hue[1.8409923414769445], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 
       1.4764049667388972}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}}]}, 
   {Hue[1.660325246505621], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.872491881660073}, 
      {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}}]}, 
   {Hue[1.5279504647343065], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 
       1.0875191232355927}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 
       0.9393665425693406}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       0.6880869119781086}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       0.872491881660073}}]}, {Hue[1.463890467502354], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}, 
      {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, \
{-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781086}}]}, 
   {Hue[1.479188320824879], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, \
0.8816778784387097}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, 
      {-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}}]}, \
{Hue[1.5695019075201668], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}}]}, 
   {Hue[1.7199704848953705], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 
       1.0875191232355923}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}}]}, 
   {Hue[1.9113874874346404], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
      {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}}]}, 
   {Hue[2.1257358600466287], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
       1.4764049667388974}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, \
1.6555895184432492}, {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 
       1.4819447816621787}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.3017122836390145}}]}, {Hue[2.3486915190005164], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}}]}, \

   {Hue[2.569493529990004], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 
       1.9084543807995193}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       1.705691841463221}, {-Cos[(13*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.6189603147994467}}]}, {Hue[2.7800763901623418], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}}]}, 
   {Hue[2.9742927645621817], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 
       1.9712852585698486}, {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + \
Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}}]}, 
   {Hue[3.147378555703615], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       1.99216913656241}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, \
1.976615915035449}, {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 
       1.6596693760099315}, {-Cos[(13*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 
       1.7222389198769947}}]}, {Hue[3.2956209910178464], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, 
      {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}}]}, \

   {Hue[3.4161696021569146], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 
       1.9339672857886046}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}}]}, 
   {Hue[3.5069401575921852], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}, 
      {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}}]}, 
   {Hue[3.5665490617425024], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
       1.8202053857959217}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 
       1.778627524809822}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       1.2512975557014525}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       1.3346849311080493}}]}, {Hue[3.594180591134923], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + \
((5 + Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}}]}, 
   {Hue[3.674196778362416], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.693545187289426}, 
      {-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}}]}, \
{Hue[3.63655464596223], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 1.3346849311080466}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.8605642566348376}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.693545187289426}}]}, 
   {Hue[3.5652840475980696], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(13*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 
       1.3346849311080466}, {-Cos[(13*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(7*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/8, \
1.05907701923914}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.8605642566348376}}]}, 
   {Hue[3.461642308625995], Polygon[{{-Cos[(13*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 
       1.5625819810819546}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, \
1.2475429541754062}, 
      {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}}]}, 
   {Hue[3.327681351343377], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 
       1.5625819810819546}, {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, \
1.6596693760099315}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 
       1.4024710170213426}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 
       1.2475429541754062}}]}, {Hue[3.1660388050789643], \
Polygon[{{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \

      {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
      {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}}]}, \
{Hue[2.9800235401726507], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.7395717696563637}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5605942189297979}, 
      {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}}]}, 
   {Hue[2.7737994417055862], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 
       1.7395717696563637}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, \
1.705691841463222}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5507915961279441}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5605942189297979}}]}, 
   {Hue[2.5526577229571097], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 
       1.705691841463222}, {-Cos[(13*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.6189603147994467}, {-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, \
1.4795217391705875}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5507915961279441}}]}, 
   {Hue[2.3234347339739982], Polygon[{{-Cos[(13*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.6189603147994467}, {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, \
1.4819447816621787}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 
       1.3494565251821802}, {-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       1.4795217391705875}}]}, {Hue[2.095150226569375], \
Polygon[{{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \

      {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.3017122836390151}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1666712321091814}, 
      {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}}]}, 
   {Hue[1.879895323616312], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 
       1.3017122836390151}, {-Cos[(13*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(7*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9410557119019617}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 
       1.1666712321091814}}]}, {Hue[1.6937347734402723], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^4, 0.8724918816600722}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6884858883697308}, 
      {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}}]}, 
   {Hue[1.5566559424580668], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^4, \
0.8724918816600722}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6880869119781076}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^4, 0.442263528432697}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6884858883697308}}]}, 
   {Hue[1.4901956904623828], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 
       0.6880869119781076}, {-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, \
0.6101049646136991}, {-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 
       0.311867536226639}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^4, \
0.442263528432697}}]}, 
   {Hue[1.5070876740566161], Polygon[{{-Cos[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6880869119781069}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432695}, 
      {-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}}]}, \
{Hue[1.5999431117873124], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6880869119781069}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600716}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697308}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432695}}]}, 
   {Hue[1.754653172897731], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 
       0.8724918816600716}, {-Cos[(13*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(7*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9410557119019617}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
       0.6884858883697308}}]}, {Hue[1.9516030563006994], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.166671232109181}, 
      {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}}]}, 
   {Hue[2.1720412589504656], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.301712283639015}, {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, \
1.4819447816621787}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 
       1.3494565251821802}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       1.166671232109181}}]}, {Hue[2.4011979321429577], \
Polygon[{{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \

      {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
      {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}}]}, \
{Hue[2.6280424380545697], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5507915961279435}, 
      {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}}]}, 
   {Hue[2.844325136564316], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       1.705691841463221}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       1.7395717696563633}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
1.5605942189298}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5507915961279435}}]}, 
   {Hue[3.0437563105382046], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       1.7395717696563633}, {-Cos[(13*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 
       1.7222389198769947}, {-Cos[(7*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 
       1.5096856680207968}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
1.5605942189298}}]}, 
   {Hue[3.221445491689051], Polygon[{{-Cos[(13*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 
       1.7222389198769947}, {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, \
1.6596693760099315}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 
       1.4024710170213426}, {-Cos[(7*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 
       1.5096856680207968}}]}, {Hue[3.373547680433126], \
Polygon[{{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \

      {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, 
      {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}}]}, \
{Hue[3.4970557633951485], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, 
      {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
      {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}}]}, 
   {Hue[3.5897280565172363], Polygon[{{-Cos[(13*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       1.3346849311080466}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, \
0.8605642566348376}, 
      {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}}]}, 
   {Hue[3.6502331092705833], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       1.3346849311080466}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       1.2512975557014567}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, \
0.693545187289426}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348376}}]}, 
   {Hue[3.6784011726575327], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       1.2512975557014567}, {-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, \
1.2202099292273982}, {-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 
       0.6237350724532809}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.693545187289426}}]}, {Hue[3.674196778362416], \
Polygon[{{-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.693545187289426}, 
      {-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}}]}, \
{Hue[3.63655464596223], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348376}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.693545187289426}}]}, 
   {Hue[3.5652840475980696], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       1.3346849311080466}, {-Cos[(13*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(7*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/8, \
1.05907701923914}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348376}}]}, 
   {Hue[3.4616423086259953], Polygon[{{-Cos[(13*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       1.5625819810819535}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/15]^2, \
1.247542954175402}, 
      {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}}]}, 
   {Hue[3.327681351343377], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       1.5625819810819535}, {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, \
1.6596693760099315}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 
       1.4024710170213426}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       1.247542954175402}}]}, {Hue[3.1660388050789643], \
Polygon[{{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \

      {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
      {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}}]}, \
{Hue[2.9800235401726507], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297979}, 
      {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}}]}, 
   {Hue[2.773799441705587], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       1.7395717696563637}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       1.705691841463221}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/15]^2, \
1.5507915961279446}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297979}}]}, 
   {Hue[2.5526577229571092], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       1.705691841463221}, {-Cos[(13*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.6189603147994467}, {-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, \
1.4795217391705875}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.5507915961279446}}]}, 
   {Hue[2.3234347339739982], Polygon[{{-Cos[(13*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.6189603147994467}, {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, \
1.4819447816621787}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 
       1.3494565251821802}, {-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       1.4795217391705875}}]}, {Hue[2.095150226569375], \
Polygon[{{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \

      {-Cos[(13*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.166671232109181}, 
      {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}}]}, \
{Hue[1.8798953236163116], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, 
      {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.166671232109181}}]}, 
   {Hue[1.6937347734402726], Polygon[{{-Cos[(13*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       0.872491881660073}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(43*Pi)/30]^2, \
0.6884858883697313}, 
      {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}}]}, 
   {Hue[1.5566559424580677], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       0.872491881660073}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       0.6880869119781086}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(22*Pi)/15]^2, \
0.442263528432698}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697313}}]}, 
   {Hue[1.490195690462383], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       0.6880869119781086}, {-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, \
0.6101049646136991}, {-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 
       0.311867536226639}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       0.442263528432698}}]}, {Hue[1.5070876740566164], \
Polygon[{{-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, 
      {-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}}]}, \
{Hue[1.5999431117873124], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697313}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}}]}, 
   {Hue[1.754653172897731], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       0.8724918816600722}, {-Cos[(13*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(7*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9410557119019617}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
       0.6884858883697313}}]}, {Hue[1.951603056300699], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091806}, 
      {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}}]}, 
   {Hue[2.1720412589504656], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.3017122836390145}, {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, \
1.4819447816621787}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 
       1.3494565251821802}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.1666712321091806}}]}, {Hue[2.4011979321429577], \
Polygon[{{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \

      {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
      {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}}]}, \
{Hue[2.6280424380545706], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.5507915961279446}, 
      {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}}]}, 
   {Hue[2.844325136564315], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       1.705691841463221}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       1.7395717696563637}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(53*Pi)/30]^2, \
1.560594218929799}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.5507915961279446}}]}, 
   {Hue[3.0437563105382037], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       1.7395717696563637}, {-Cos[(13*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 
       1.7222389198769947}, {-Cos[(7*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 
       1.5096856680207968}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
       1.560594218929799}}]}, {Hue[3.221445491689051], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
      {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}}]}, 
   {Hue[3.3735476804331266], Polygon[{{-Cos[(13*Pi)/30]^2 + \
(17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, 
      {-Cos[(13*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.247542954175402}, 
      {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}}]}, \
{Hue[3.4970557633951485], 
    Polygon[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, 
      {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
      {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.247542954175402}}]}, 
   {Hue[3.5897280565172354], Polygon[{{-Cos[(13*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       1.3346849311080493}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/15]^2, \
0.8605642566348355}, 
      {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}}]}, 
   {Hue[3.6502331092705824], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       1.3346849311080493}, {-Cos[(13*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       1.2512975557014525}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(59*Pi)/30]^2, \
0.6935451872894184}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348355}}]}, 
   {Hue[3.6784011726575327], Polygon[{{-Cos[(13*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       1.2512975557014525}, {-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, \
1.2202099292273982}, {-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 
       0.6237350724532809}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       0.6935451872894184}}]}, {Hue[3.723265183902061], \
Polygon[{{-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.693545187289426}, 
      {5*Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.3118675362266461}, {5, 0}}]}, \
{Hue[3.684571076633355], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.693545187289426}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.8605642566348376}, 
      {5*Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646136962}, {5*Cos[Pi/30]^2 \
+ 2*Sin[Pi/30]^2, 0.3118675362266461}}]}, 
   {Hue[3.6112585420629335], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[Pi/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, \
0.8605642566348376}, 
      {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
      {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646136962}}]}, 
   {Hue[3.5055387098405193], Polygon[{{-Cos[(7*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 
       1.05907701923914}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, \
1.2475429541754062}, 
      {5*Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160924}, {(-1 + \
Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}}]}, 
   {Hue[3.369431831858425], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 
       1.2475429541754062}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, \
1.4024710170213426}, {17/4, 1.299038105676658}, 
      {5*Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160924}}]}, \
{Hue[3.205463159660706], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, \
1.4024710170213426}, {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 \
+ 
        (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, {(5 - \
Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, 
      {17/4, 1.299038105676658}}]}, {Hue[3.016889348536348], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 \
+ Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5605942189297979}, 
      {5*Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.491782843052409}, {(5 - \
Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}}]}, 
   {Hue[2.8078745733945154], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 
       1.5605942189297979}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, \
1.5507915961279441}, 
      {5*Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524107}, \
{5*Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.491782843052409}}]}, 
   {Hue[2.5837481640387963], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 
       1.5507915961279441}, {-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, \
1.4795217391705875}, 
      {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{5*Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524107}}]}, 
   {Hue[2.351417739656536], Polygon[{{-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       1.4795217391705875}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, \
1.3494565251821802}, {11/4, 1.299038105676658}, 
      {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}}]}, \
{Hue[2.120012531885397], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, \
1.3494565251821802}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 
        2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1666712321091814}, \
{5*Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, 
      {11/4, 1.299038105676658}}]}, {Hue[1.9017848258609582], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1666712321091814}, 
      {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
      {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}}]}, 
   {Hue[1.713022669805623], Polygon[{{-Cos[(7*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9410557119019617}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, \
0.6884858883697308}, 
      {5*Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646137006}, \
{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}}]}, 
   {Hue[1.5738564235382932], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 
       0.6884858883697308}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^4, 0.442263528432697}, \

      {5*Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, \
{5*Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646137006}}]}, 
   {Hue[1.5035826127440568], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^4, 0.442263528432697}, \

      {-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, {2, 0}, \
{5*Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}}]}, 
   {Hue[1.5234019372603185], Polygon[{{-Cos[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2, 0.311867536226639}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432695}, 
      {5*Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.311867536226639}, {2, \
0}}]}, 
   {Hue[1.615913691454404], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 
       0.442263528432695}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, \
0.6884858883697308}, 
      {5*Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, \
{5*Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.311867536226639}}]}, 
   {Hue[1.7730029735772388], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
       0.6884858883697308}, {-Cos[(7*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9410557119019617}, {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, \
0.88167787843871}, {5*Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 
       0.6101049646136991}}]}, {Hue[1.9731918631737326], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.166671232109181}, 
      {5*Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.1147172382160913}, \
{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}}]}, 
   {Hue[2.197106484723111], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       1.166671232109181}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, \
1.3494565251821802}, {11/4, 1.299038105676658}, 
      {5*Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.1147172382160913}}]}, \
{Hue[2.4297663415065562], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, \
1.3494565251821802}, {-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, {(5*(5 - \
Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, 
      {11/4, 1.299038105676658}}]}, {Hue[2.660026920589875], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 \
+ Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5507915961279435}, 
      {5*Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524107}, {(5*(5 \
- Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}}]}, 
   {Hue[2.8795634843478326], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 
       1.5507915961279435}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
1.5605942189298}, 
      {5*Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.49178284305241}, \
{5*Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524107}}]}, 
   {Hue[3.082035020603707], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       1.5605942189298}, {-Cos[(7*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, \
1.5096856680207968}, 
      {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, \
{5*Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.49178284305241}}]}, 
   {Hue[3.262517700883737], Polygon[{{-Cos[(7*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 
       1.5096856680207968}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, \
1.4024710170213426}, {17/4, 1.299038105676658}, 
      {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}}]}, \
{Hue[3.4171446065371214], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, \
1.4024710170213426}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 
        2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, \
{5*Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.1147172382160893}, 
      {17/4, 1.299038105676658}}]}, {Hue[3.5428733418193668], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, 
      {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
      {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.1147172382160893}}]}, 
   {Hue[3.637303083230126], Polygon[{{-Cos[(7*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 
       1.05907701923914}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, \
0.8605642566348376}, 
      {5*Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646136962}, {(-1 + \
Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}}]}, 
   {Hue[3.698393834009952], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       0.8605642566348376}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, \
0.693545187289426}, 
      {5*Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266461}, \
{5*Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646136962}}]}, 
   {Hue[3.723707204018122], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.693545187289426}, {-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, \
0.6237350724532809}, {5, 0}, {5*Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 
       0.3118675362266461}}]}, {Hue[3.723265183902061], \
Polygon[{{-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.693545187289426}, 
      {5*Cos[(31*Pi)/30]^2 + 2*Sin[(31*Pi)/30]^2, 0.3118675362266461}, {5, \
0}}]}, 
   {Hue[3.684571076633355], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(31*Pi)/30]^2, 
       0.693545187289426}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(16*Pi)/15]^2, \
0.8605642566348376}, 
      {5*Cos[(16*Pi)/15]^2 + 2*Sin[(16*Pi)/15]^2, 0.6101049646136962}, \
{5*Cos[(31*Pi)/30]^2 + 2*Sin[(31*Pi)/30]^2, 0.3118675362266461}}]}, 
   {Hue[3.6112585420629335], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(16*Pi)/15]^2, 
       0.8605642566348376}, {-Cos[(7*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/8, \
1.05907701923914}, 
      {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(16*Pi)/15]^2 + 2*Sin[(16*Pi)/15]^2, 0.6101049646136962}}]}, 
   {Hue[3.5055387098405197], Polygon[{{-Cos[(7*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 
       1.05907701923914}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/15]^2, \
1.247542954175402}, 
      {5*Cos[(17*Pi)/15]^2 + 2*Sin[(17*Pi)/15]^2, 1.1147172382160924}, {(-1 + \
Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}}]}, 
   {Hue[3.369431831858425], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       1.247542954175402}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, \
1.4024710170213426}, {17/4, 1.299038105676658}, 
      {5*Cos[(17*Pi)/15]^2 + 2*Sin[(17*Pi)/15]^2, 1.1147172382160924}}]}, \
{Hue[3.205463159660706], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, \
1.4024710170213426}, {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 \
+ 
        (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, {(5 - \
Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, 
      {17/4, 1.299038105676658}}]}, {Hue[3.016889348536348], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 \
+ Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297979}, 
      {5*Cos[(37*Pi)/30]^2 + 2*Sin[(37*Pi)/30]^2, 1.491782843052409}, {(5 - \
Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}}]}, 
   {Hue[2.807874573394516], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
       1.5605942189297979}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/15]^2, \
1.5507915961279446}, 
      {5*Cos[(19*Pi)/15]^2 + 2*Sin[(19*Pi)/15]^2, 1.49178284305241}, \
{5*Cos[(37*Pi)/30]^2 + 2*Sin[(37*Pi)/30]^2, 1.491782843052409}}]}, 
   {Hue[2.5837481640387967], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
       1.5507915961279446}, {-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, \
1.4795217391705875}, 
      {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{5*Cos[(19*Pi)/15]^2 + 2*Sin[(19*Pi)/15]^2, 1.49178284305241}}]}, 
   {Hue[2.351417739656536], Polygon[{{-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       1.4795217391705875}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, \
1.3494565251821802}, {11/4, 1.299038105676658}, 
      {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}}]}, \
{Hue[2.1200125318853966], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, \
1.3494565251821802}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 
        2*Sin[(7*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.166671232109181}, \
{5*Cos[(41*Pi)/30]^2 + 2*Sin[(41*Pi)/30]^2, 1.1147172382160913}, 
      {11/4, 1.299038105676658}}]}, {Hue[1.901784825860958], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.166671232109181}, 
      {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
      {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(41*Pi)/30]^2 + 2*Sin[(41*Pi)/30]^2, 1.1147172382160913}}]}, 
   {Hue[1.7130226698056232], Polygon[{{-Cos[(7*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9410557119019617}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(43*Pi)/30]^2, \
0.6884858883697313}, 
      {5*Cos[(43*Pi)/30]^2 + 2*Sin[(43*Pi)/30]^2, 0.6101049646137006}, \
{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}}]}, 
   {Hue[1.573856423538294], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
       0.6884858883697313}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(22*Pi)/15]^2, \
0.442263528432698}, 
      {5*Cos[(22*Pi)/15]^2 + 2*Sin[(22*Pi)/15]^2, 0.31186753622664043}, \
{5*Cos[(43*Pi)/30]^2 + 2*Sin[(43*Pi)/30]^2, 0.6101049646137006}}]}, 
   {Hue[1.5035826127440572], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       0.442263528432698}, {-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, \
0.311867536226639}, {2, 0}, {5*Cos[(22*Pi)/15]^2 + 2*Sin[(22*Pi)/15]^2, 
       0.31186753622664043}}]}, {Hue[1.5234019372603187], \
Polygon[{{-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, 
      {5*Cos[(23*Pi)/15]^2 + 2*Sin[(23*Pi)/15]^2, 0.31186753622664043}, {2, \
0}}]}, 
   {Hue[1.6159136914544043], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/15]^2, 
       0.442263528432697}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(47*Pi)/30]^2, \
0.6884858883697313}, 
      {5*Cos[(47*Pi)/30]^2 + 2*Sin[(47*Pi)/30]^2, 0.6101049646137013}, \
{5*Cos[(23*Pi)/15]^2 + 2*Sin[(23*Pi)/15]^2, 0.31186753622664043}}]}, 
   {Hue[1.7730029735772388], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
       0.6884858883697313}, {-Cos[(7*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9410557119019617}, {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, \
0.88167787843871}, {5*Cos[(47*Pi)/30]^2 + 2*Sin[(47*Pi)/30]^2, 
       0.6101049646137013}}]}, {Hue[1.973191863173732], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091806}, 
      {5*Cos[(49*Pi)/30]^2 + 2*Sin[(49*Pi)/30]^2, 1.1147172382160908}, \
{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}}]}, 
   {Hue[2.197106484723111], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.1666712321091806}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, \
1.3494565251821802}, {11/4, 1.299038105676658}, 
      {5*Cos[(49*Pi)/30]^2 + 2*Sin[(49*Pi)/30]^2, 1.1147172382160908}}]}, \
{Hue[2.4297663415065562], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, \
1.3494565251821802}, {-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, {(5*(5 - \
Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, 
      {11/4, 1.299038105676658}}]}, {Hue[2.6600269205898766], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 \
+ Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
      {-Cos[(7*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.5507915961279446}, 
      {5*Cos[(26*Pi)/15]^2 + 2*Sin[(26*Pi)/15]^2, 1.49178284305241}, {(5*(5 - \
Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}}]}, 
   {Hue[2.8795634843478317], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
       1.5507915961279446}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(53*Pi)/30]^2, \
1.560594218929799}, 
      {5*Cos[(53*Pi)/30]^2 + 2*Sin[(53*Pi)/30]^2, 1.49178284305241}, \
{5*Cos[(26*Pi)/15]^2 + 2*Sin[(26*Pi)/15]^2, 1.49178284305241}}]}, 
   {Hue[3.0820350206037066], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
       1.560594218929799}, {-Cos[(7*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, \
1.5096856680207968}, 
      {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, \
{5*Cos[(53*Pi)/30]^2 + 2*Sin[(53*Pi)/30]^2, 1.49178284305241}}]}, 
   {Hue[3.262517700883737], Polygon[{{-Cos[(7*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 
       1.5096856680207968}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, \
1.4024710170213426}, {17/4, 1.299038105676658}, 
      {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}}]}, \
{Hue[3.4171446065371223], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, \
1.4024710170213426}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 
        2*Sin[(7*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.247542954175402}, \
{5*Cos[(28*Pi)/15]^2 + 2*Sin[(28*Pi)/15]^2, 1.1147172382160893}, 
      {17/4, 1.299038105676658}}]}, {Hue[3.5428733418193676], 
    Polygon[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.247542954175402}, 
      {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
      {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(28*Pi)/15]^2 + 2*Sin[(28*Pi)/15]^2, 1.1147172382160893}}]}, 
   {Hue[3.637303083230125], Polygon[{{-Cos[(7*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 
       1.05907701923914}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/15]^2, \
0.8605642566348355}, 
      {5*Cos[(29*Pi)/15]^2 + 2*Sin[(29*Pi)/15]^2, 0.6101049646136991}, {(-1 + \
Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}}]}, 
   {Hue[3.698393834009952], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
       0.8605642566348355}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(59*Pi)/30]^2, \
0.6935451872894184}, 
      {5*Cos[(59*Pi)/30]^2 + 2*Sin[(59*Pi)/30]^2, 0.3118675362266461}, \
{5*Cos[(29*Pi)/15]^2 + 2*Sin[(29*Pi)/15]^2, 0.6101049646136991}}]}, 
   {Hue[3.723707204018122], Polygon[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       0.6935451872894184}, {-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, \
0.6237350724532809}, {5, 0}, {5*Cos[(59*Pi)/30]^2 + 2*Sin[(59*Pi)/30]^2, 
       0.3118675362266461}}]}, {Hue[3.725799112598921], Polygon[{{5, 0}, \
{5*Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.3118675362266461}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.6935451872894184}, 
      {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}}]}, \
{Hue[3.687952511861754], 
    Polygon[{{5*Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.3118675362266461}, \
{5*Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646136962}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.8605642566348314}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.6935451872894184}}]}, 
   {Hue[3.615422357661949], Polygon[{{5*Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, \
0.6101049646136962}, {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 
       0.8816778784387135}, {-Cos[(8*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 
       1.0590770192391334}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[Pi/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, \
0.8605642566348314}}]}, 
   {Hue[3.5101648977206876], Polygon[{{(-1 + Sqrt[5])^2/8 + (5*(5 + \
Sqrt[5]))/8, 0.8816778784387135}, 
      {5*Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160924}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.247542954175402}, \
{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + 
        (5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}}]}, \
{Hue[3.374269653790886], 
    Polygon[{{5*Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160924}, \
{17/4, 1.299038105676658}, 
      {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.247542954175402}}]}, \
{Hue[3.210340394630078], 
    Polygon[{{17/4, 1.299038105676658}, {(5 - Sqrt[5])/4 + (5*(1 + \
Sqrt[5])^2)/16, 1.4265847744427318}, 
      {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
      {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}}]}, \
{Hue[3.0216855337124566], 
    Polygon[{{(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, \
{5*Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.491782843052409}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5605942189297972}, 
      {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}}]}, 
   {Hue[2.812504629301177], Polygon[{{5*Cos[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2, 1.491782843052409}, {5*Cos[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2, 
       1.4917828430524107}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, \
1.5507915961279435}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5605942189297972}}]}, 
   {Hue[2.5881558123898643], Polygon[{{5*Cos[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2, 1.4917828430524107}, 
      {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5507915961279435}}]}, \
{Hue[2.355576015211104], 
    Polygon[{{(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{11/4, 1.299038105676658}, 
      {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}}]}, \
{Hue[2.123931195907306], 
    Polygon[{{11/4, 1.299038105676658}, {5*Cos[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1666712321091803}, 
      {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}}]}, \
{Hue[1.9055273425618375], 
    Polygon[{{5*Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, \
{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, 
      {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1666712321091803}}]}, 
   {Hue[1.7167385718541868], Polygon[{{(5*(-1 + Sqrt[5])^2)/16 + (5 + \
Sqrt[5])/4, 0.88167787843871}, 
      {5*Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646137006}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6884858883697301}, \
{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + 
        ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}}]}, \
{Hue[1.5778277054931564], 
    Polygon[{{5*Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646137006}, \
{5*Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432696}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6884858883697301}}]}, 
   {Hue[1.508083333253842], Polygon[{{5*Cos[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2, 0.311867536226639}, {2, 0}, 
      {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432696}}]}, \
{Hue[1.5198439514694047], 
    Polygon[{{2, 0}, {5*Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, \
0.311867536226639}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^4, 0.442263528432694}, 
      {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}}]}, \
{Hue[1.6154618746369844], 
    Polygon[{{5*Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.311867536226639}, \
{5*Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697295}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^4, 0.442263528432694}}]}, 
   {Hue[1.7741879781856067], Polygon[{{5*Cos[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, 
      {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + 
        ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697295}}]}, \
{Hue[1.9754010950778647], 
    Polygon[{{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.1147172382160913}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.16667123210918}, 
      {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}}]}, 
   {Hue[2.200128581109507], Polygon[{{5*Cos[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2, 1.1147172382160913}, {11/4, 1.299038105676658}, 
      {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.16667123210918}}]}, \
{Hue[2.433507922323691], 
    Polygon[{{11/4, 1.299038105676658}, {(5*(5 - Sqrt[5]))/8 + (1 + \
Sqrt[5])^2/8, 1.4265847744427305}, 
      {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
      {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}}]}, \
{Hue[2.6644349107414005], 
    Polygon[{{(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{5*Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524107}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.550791596127943}, 
      {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}}]}, 
   {Hue[2.8846008295491536], Polygon[{{5*Cos[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2, 1.4917828430524107}, 
      {5*Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.49178284305241}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189297979}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.550791596127943}}]}, \
{Hue[3.087672975906379], 
    Polygon[{{5*Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.49178284305241}, \
{(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, 
      {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189297979}}]}, 
   {Hue[3.268734829830972], Polygon[{{(5 - Sqrt[5])/4 + (5*(1 + \
Sqrt[5])^2)/16, 1.4265847744427318}, {17/4, 1.299038105676658}, 
      {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + 
        (5*(1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}}]}, \
{Hue[3.4239296365364598], 
    Polygon[{{17/4, 1.299038105676658}, {5*Cos[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2, 1.1147172382160893}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, 
      {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}}]}, \
{Hue[3.5502306552397824], 
    Polygon[{{5*Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.1147172382160893}, \
{(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, 
      {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}}]}, 
   {Hue[3.645255978776691], Polygon[{{(-1 + Sqrt[5])^2/8 + (5*(5 + \
Sqrt[5]))/8, 0.8816778784387135}, 
      {5*Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646136962}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348314}, \
{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + 
        (5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}}]}, \
{Hue[3.7069578453657703], 
    Polygon[{{5*Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646136962}, \
{5*Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266461}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6935451872894184}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348314}}]}, 
   {Hue[3.7327515677893754], Polygon[{{5*Cos[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2, 0.3118675362266461}, {5, 0}, 
      {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6935451872894184}}]}, \
{Hue[3.725799112598921], 
    Polygon[{{5, 0}, {5*Cos[(31*Pi)/30]^2 + 2*Sin[(31*Pi)/30]^2, \
0.3118675362266461}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.6935451872894184}, 
      {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}}]}, \
{Hue[3.687952511861754], 
    Polygon[{{5*Cos[(31*Pi)/30]^2 + 2*Sin[(31*Pi)/30]^2, 0.3118675362266461}, \
{5*Cos[(16*Pi)/15]^2 + 2*Sin[(16*Pi)/15]^2, 0.6101049646136962}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348314}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.6935451872894184}}]}, 
   {Hue[3.615422357661949], Polygon[{{5*Cos[(16*Pi)/15]^2 + \
2*Sin[(16*Pi)/15]^2, 0.6101049646136962}, 
      {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + 
        (5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348314}}]}, \
{Hue[3.510164897720688], 
    Polygon[{{(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(17*Pi)/15]^2 + 2*Sin[(17*Pi)/15]^2, 1.1147172382160924}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.2475429541753962}, 
      {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}}]}, 
   {Hue[3.374269653790886], Polygon[{{5*Cos[(17*Pi)/15]^2 + \
2*Sin[(17*Pi)/15]^2, 1.1147172382160924}, {17/4, 1.299038105676658}, 
      {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.2475429541753962}}]}, \
{Hue[3.210340394630078], 
    Polygon[{{17/4, 1.299038105676658}, {(5 - Sqrt[5])/4 + (5*(1 + \
Sqrt[5])^2)/16, 1.4265847744427318}, 
      {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
      {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}}]}, \
{Hue[3.0216855337124566], 
    Polygon[{{(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, \
{5*Cos[(37*Pi)/30]^2 + 2*Sin[(37*Pi)/30]^2, 1.491782843052409}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297972}, 
      {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}}]}, 
   {Hue[2.8125046293011775], Polygon[{{5*Cos[(37*Pi)/30]^2 + \
2*Sin[(37*Pi)/30]^2, 1.491782843052409}, 
      {5*Cos[(19*Pi)/15]^2 + 2*Sin[(19*Pi)/15]^2, 1.49178284305241}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.550791596127943}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297972}}]}, \
{Hue[2.588155812389865], 
    Polygon[{{5*Cos[(19*Pi)/15]^2 + 2*Sin[(19*Pi)/15]^2, 1.49178284305241}, \
{(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, 
      {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.550791596127943}}]}, 
   {Hue[2.355576015211104], Polygon[{{(5*(5 - Sqrt[5]))/8 + (1 + \
Sqrt[5])^2/8, 1.4265847744427305}, {11/4, 1.299038105676658}, 
      {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}}]}, \
{Hue[2.1239311959073057], 
    Polygon[{{11/4, 1.299038105676658}, {5*Cos[(41*Pi)/30]^2 + \
2*Sin[(41*Pi)/30]^2, 1.1147172382160913}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.16667123210918}, 
      {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}}]}, \
{Hue[1.9055273425618373], 
    Polygon[{{5*Cos[(41*Pi)/30]^2 + 2*Sin[(41*Pi)/30]^2, 1.1147172382160913}, \
{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, 
      {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.16667123210918}}]}, 
   {Hue[1.7167385718541874], Polygon[{{(5*(-1 + Sqrt[5])^2)/16 + (5 + \
Sqrt[5])/4, 0.88167787843871}, 
      {5*Cos[(43*Pi)/30]^2 + 2*Sin[(43*Pi)/30]^2, 0.6101049646137006}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697308}, \
{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + 
        ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}}]}, \
{Hue[1.577827705493157], 
    Polygon[{{5*Cos[(43*Pi)/30]^2 + 2*Sin[(43*Pi)/30]^2, 0.6101049646137006}, \
{5*Cos[(22*Pi)/15]^2 + 2*Sin[(22*Pi)/15]^2, 0.31186753622664043}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432697}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697308}}]}, 
   {Hue[1.5080833332538421], Polygon[{{5*Cos[(22*Pi)/15]^2 + \
2*Sin[(22*Pi)/15]^2, 0.31186753622664043}, {2, 0}, 
      {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432697}}]}, \
{Hue[1.5198439514694049], 
    Polygon[{{2, 0}, {5*Cos[(23*Pi)/15]^2 + 2*Sin[(23*Pi)/15]^2, \
0.31186753622664043}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, 
      {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}}]}, \
{Hue[1.6154618746369849], 
    Polygon[{{5*Cos[(23*Pi)/15]^2 + 2*Sin[(23*Pi)/15]^2, \
0.31186753622664043}, {5*Cos[(47*Pi)/30]^2 + 2*Sin[(47*Pi)/30]^2, \
0.6101049646137013}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697308}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}}]}, 
   {Hue[1.774187978185607], Polygon[{{5*Cos[(47*Pi)/30]^2 + \
2*Sin[(47*Pi)/30]^2, 0.6101049646137013}, 
      {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + 
        ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697308}}]}, \
{Hue[1.9754010950778644], 
    Polygon[{{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(49*Pi)/30]^2 + 2*Sin[(49*Pi)/30]^2, 1.1147172382160908}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091794}, 
      {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}}]}, 
   {Hue[2.200128581109507], Polygon[{{5*Cos[(49*Pi)/30]^2 + \
2*Sin[(49*Pi)/30]^2, 1.1147172382160908}, {11/4, 1.299038105676658}, 
      {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091794}}]}, \
{Hue[2.433507922323691], 
    Polygon[{{11/4, 1.299038105676658}, {(5*(5 - Sqrt[5]))/8 + (1 + \
Sqrt[5])^2/8, 1.4265847744427305}, 
      {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
      {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}}]}, \
{Hue[2.664434910741402], 
    Polygon[{{(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{5*Cos[(26*Pi)/15]^2 + 2*Sin[(26*Pi)/15]^2, 1.49178284305241}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.550791596127943}, 
      {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}}]}, 
   {Hue[2.8846008295491528], Polygon[{{5*Cos[(26*Pi)/15]^2 + \
2*Sin[(26*Pi)/15]^2, 1.49178284305241}, 
      {5*Cos[(53*Pi)/30]^2 + 2*Sin[(53*Pi)/30]^2, 1.49178284305241}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.5605942189297983}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.550791596127943}}]}, \
{Hue[3.087672975906378], 
    Polygon[{{5*Cos[(53*Pi)/30]^2 + 2*Sin[(53*Pi)/30]^2, 1.49178284305241}, \
{(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, 
      {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.5605942189297983}}]}, 
   {Hue[3.268734829830972], Polygon[{{(5 - Sqrt[5])/4 + (5*(1 + \
Sqrt[5])^2)/16, 1.4265847744427318}, {17/4, 1.299038105676658}, 
      {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + 
        (5*(1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}}]}, \
{Hue[3.42392963653646], 
    Polygon[{{17/4, 1.299038105676658}, {5*Cos[(28*Pi)/15]^2 + \
2*Sin[(28*Pi)/15]^2, 1.1147172382160893}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.2475429541754004}, 
      {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}}]}, \
{Hue[3.5502306552397824], 
    Polygon[{{5*Cos[(28*Pi)/15]^2 + 2*Sin[(28*Pi)/15]^2, 1.1147172382160893}, \
{(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, 
      {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.2475429541754004}}]}, 
   {Hue[3.64525597877669], Polygon[{{(-1 + Sqrt[5])^2/8 + (5*(5 + \
Sqrt[5]))/8, 0.8816778784387135}, 
      {5*Cos[(29*Pi)/15]^2 + 2*Sin[(29*Pi)/15]^2, 0.6101049646136991}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348294}, \
{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + 
        (5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}}]}, \
{Hue[3.7069578453657694], 
    Polygon[{{5*Cos[(29*Pi)/15]^2 + 2*Sin[(29*Pi)/15]^2, 0.6101049646136991}, \
{5*Cos[(59*Pi)/30]^2 + 2*Sin[(59*Pi)/30]^2, 0.3118675362266461}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894107}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348294}}]}, 
   {Hue[3.7327515677893754], Polygon[{{5*Cos[(59*Pi)/30]^2 + \
2*Sin[(59*Pi)/30]^2, 0.3118675362266461}, {5, 0}, 
      {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894107}}]}, \
{Hue[3.6926966764375626], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(8*Pi)/15]^2 + 
        2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.6935451872894184}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(17*Pi)/30]^2 + 
        2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 1.2512975557014567}, \
{-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}}]}, 
   {Hue[3.6532853337842393], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[Pi/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, \
0.6935451872894184}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.8605642566348314}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 1.3346849311080466}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 1.2512975557014567}}]}, 
   {Hue[3.5812641847135596], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[Pi/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, \
0.8605642566348314}, 
      {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
      {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 1.3346849311080466}}]}, 
   {Hue[3.4773574725783654], Polygon[{{-Cos[(8*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 
       1.0590770192391334}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, \
1.247542954175402}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.5625819810819546}, 
      {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}}]}, 
   {Hue[3.3431845374423643], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 
       1.247542954175402}, {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, \
1.4024710170213388}, {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 
       1.6596693760099315}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
       1.5625819810819546}}]}, {Hue[3.1812081607157228], \
Polygon[{{-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, 
      {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
      {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}}]}, \

   {Hue[2.9946918033186365], Polygon[{{-Cos[(8*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 
       1.5096856680207957}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, \
1.5605942189297972}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.7395717696563637}, 
      {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}}]}, 
   {Hue[2.787808623673761], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 
       1.5605942189297972}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, \
1.5507915961279435}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.705691841463222}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.7395717696563637}}]}, 
   {Hue[2.5658856127101246], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 
       1.5507915961279435}, {-Cos[(8*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, \
1.4795217391705868}, 
      {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.705691841463222}}]}, 
   {Hue[2.335814635156496], Polygon[{{-Cos[(8*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 
       1.4795217391705868}, {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, \
1.34945652518218}, {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 
       1.4819447816621787}, {-Cos[(17*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       1.6189603147994467}}]}, {Hue[2.1066935405250993], \
Polygon[{{-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1666712321091803}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.3017122836390151}, 
      {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}}]}, \

   {Hue[1.8907185639696549], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 
       1.1666712321091803}, {-Cos[(8*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 
       0.9410557119019617}, {-Cos[(17*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 
       1.3017122836390151}}]}, {Hue[1.7040655643224893], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6884858883697301}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600714}, 
      {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}}]}, 
   {Hue[1.5666419447419322], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 
       0.6884858883697301}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, \
0.442263528432696}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781076}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600714}}]}, 
   {Hue[1.4986207644650278], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 
       0.442263528432696}, {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, \
0.31186753622663826}, {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 
       0.6101049646136991}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
       0.6880869119781076}}]}, {Hue[1.510790168761761], \
Polygon[{{-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^4, 0.442263528432694}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781069}, 
      {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}}]}, \
{Hue[1.602639583168425], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^4, 0.442263528432694}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697295}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^4, 0.8724918816600716}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781069}}]}, 
   {Hue[1.7594013872733996], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
       0.6884858883697295}, {-Cos[(8*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 
       0.9410557119019617}, {-Cos[(17*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^4, \
0.8724918816600716}}]}, 
   {Hue[1.9586489672213119], Polygon[{{-Cos[(8*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 
       0.9410557119019617}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, \
1.16667123210918}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
      {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}}]}, 
   {Hue[2.181241501501948], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       1.16667123210918}, {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, \
1.34945652518218}, {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 
       1.4819447816621787}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.301712283639015}}]}, {Hue[2.4124125470838833], \
Polygon[{{-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, 
      {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
      {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}}]}, \

   {Hue[2.641153421955621], Polygon[{{-Cos[(8*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 
       1.4795217391705868}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, \
1.550791596127943}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
      {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}}]}, 
   {Hue[2.8592227896649756], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 
       1.550791596127943}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
1.5605942189297979}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}}]}, 
   {Hue[3.0603285519536843], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       1.5605942189297979}, {-Cos[(8*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 
       1.5096856680207957}, {-Cos[(17*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 
       1.7222389198769947}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       1.7395717696563633}}]}, {Hue[3.2395689387538718], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 \
+ Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
      {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
      {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}}]}, 
   {Hue[3.3930736665476173], Polygon[{{-Cos[(8*Pi)/15]^2 + \
(17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, 
      {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}}]}, \

   {Hue[3.517777488190929], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
       1.2475429541754004}, {-Cos[(8*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 
       1.0590770192391334}, {-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.5625819810819546}}]}, {Hue[3.611297523268627], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348314}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}, 
      {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}}]}, 
   {Hue[3.6719706302623347], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       0.8605642566348314}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, \
0.6935451872894184}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}}]}, 
   {Hue[3.6990771256031394], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.6935451872894184}, {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, \
0.6237350724532723}, {-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 
       1.2202099292273982}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       1.2512975557014567}}]}, {Hue[3.6926966764375626], \
Polygon[{{-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.6935451872894184}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}}]}, \
{Hue[3.6532853337842393], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.6935451872894184}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348314}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}}]}, 
   {Hue[3.5812641847135605], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(16*Pi)/15]^2, 
       0.8605642566348314}, {-Cos[(8*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 
       1.0590770192391334}, {-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       1.3346849311080466}}]}, {Hue[3.477357472578366], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.2475429541753962}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}, 
      {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}}]}, 
   {Hue[3.343184537442364], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       1.2475429541753962}, {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, \
1.4024710170213388}, {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 
       1.6596693760099315}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       1.5625819810819535}}]}, {Hue[3.1812081607157228], \
Polygon[{{-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, 
      {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
      {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}}]}, \

   {Hue[2.9946918033186365], Polygon[{{-Cos[(8*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 
       1.5096856680207957}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(37*Pi)/30]^2, \
1.5605942189297972}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
      {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}}]}, 
   {Hue[2.787808623673762], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
       1.5605942189297972}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/15]^2, \
1.550791596127943}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}}]}, 
   {Hue[2.5658856127101246], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
       1.550791596127943}, {-Cos[(8*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, \
1.4795217391705868}, 
      {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}}]}, 
   {Hue[2.335814635156496], Polygon[{{-Cos[(8*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 
       1.4795217391705868}, {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, \
1.34945652518218}, {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 
       1.4819447816621787}, {-Cos[(17*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       1.6189603147994467}}]}, {Hue[2.106693540525099], \
Polygon[{{-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.16667123210918}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, 
      {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}}]}, \

   {Hue[1.8907185639696549], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(41*Pi)/30]^2, 
       1.16667123210918}, {-Cos[(8*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, \
0.9410557119019617}, 
      {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}}]}, 
   {Hue[1.7040655643224898], Polygon[{{-Cos[(8*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 
       0.9410557119019617}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(43*Pi)/30]^2, \
0.6884858883697308}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.8724918816600724}, 
      {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}}]}, 
   {Hue[1.566641944741933], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
       0.6884858883697308}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(22*Pi)/15]^2, \
0.442263528432697}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781079}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.8724918816600724}}]}, 
   {Hue[1.4986207644650282], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       0.442263528432697}, {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, \
0.31186753622663826}, {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 
       0.6101049646136991}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       0.6880869119781079}}]}, {Hue[1.5107901687617615], \
Polygon[{{-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, 
      {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}}]}, \
{Hue[1.6026395831684253], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697308}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}}]}, 
   {Hue[1.7594013872734], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
       0.6884858883697308}, {-Cos[(8*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 
       0.9410557119019617}, {-Cos[(17*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       0.8724918816600722}}]}, {Hue[1.9586489672213117], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091794}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
      {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}}]}, 
   {Hue[2.181241501501948], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.1666712321091794}, {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, \
1.34945652518218}, {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 
       1.4819447816621787}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.3017122836390145}}]}, {Hue[2.4124125470838833], \
Polygon[{{-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, 
      {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
      {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}}]}, \

   {Hue[2.641153421955622], Polygon[{{-Cos[(8*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 
       1.4795217391705868}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(26*Pi)/15]^2, \
1.550791596127943}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
      {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}}]}, 
   {Hue[2.859222789664975], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
       1.550791596127943}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(53*Pi)/30]^2, \
1.5605942189297983}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}}]}, 
   {Hue[3.060328551953684], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
       1.5605942189297983}, {-Cos[(8*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 
       1.5096856680207957}, {-Cos[(17*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 
       1.7222389198769947}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       1.7395717696563637}}]}, {Hue[3.2395689387538718], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 \
+ Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
      {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
      {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}}]}, 
   {Hue[3.3930736665476178], Polygon[{{-Cos[(8*Pi)/15]^2 + \
(17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.2475429541754004}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, 
      {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}}]}, \

   {Hue[3.517777488190929], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(28*Pi)/15]^2, 
       1.2475429541754004}, {-Cos[(8*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 
       1.0590770192391334}, {-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(28*Pi)/15]^2, 
       1.5625819810819546}}]}, {Hue[3.6112975232686266], 
    Polygon[{{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
      {-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348294}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}, 
      {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}}]}, 
   {Hue[3.6719706302623343], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
       0.8605642566348294}, {-Cos[(8*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(59*Pi)/30]^2, \
0.6935451872894107}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}}]}, 
   {Hue[3.6990771256031394], Polygon[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       0.6935451872894107}, {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, \
0.6237350724532723}, {-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 
       1.2202099292273982}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       1.2512975557014525}}]}, {Hue[3.6212199241689773], \
Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 1.2512975557014567}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}}]}, \
{Hue[3.5824550279451413], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 1.3346849311080466}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}}]}, 
   {Hue[3.511521710658543], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(17*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 
       1.3346849311080466}, {-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}}]}, 
   {Hue[3.4094996365369017], Polygon[{{-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
       1.5625819810819546}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       1.9339672857886054}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}}]}, 
   {Hue[3.2780513483629594], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
       1.5625819810819546}, {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, \
1.6596693760099315}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 
       1.976615915035449}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       1.9339672857886054}}]}, {Hue[3.1195327080646447], \
Polygon[{{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, \

      {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}]}, \
{Hue[2.9370839307777055], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.7395717696563637}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}]}, 
   {Hue[2.7347632145488108], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 
       1.7395717696563637}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, \
1.705691841463222}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}}]}, 
   {Hue[2.51778134322685], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
       1.705691841463222}, {-Cos[(17*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       1.6189603147994467}, {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + \
Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}}]}, 
   {Hue[2.2928961437634507], Polygon[{{-Cos[(17*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       1.6189603147994467}, {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, \
1.4819447816621787}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 
       1.6555895184432492}, {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + \
Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}}]}, {Hue[2.0690319276054914], \
Polygon[{{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \

      {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.3017122836390151}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, 
      {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}]}, \
{Hue[1.8581399199785265], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.3017122836390151}, 
      {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}}]}, 
   {Hue[1.6760375485097965], Polygon[{{-Cos[(17*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 
       0.8724918816600714}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.0875191232355919}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}}]}, 
   {Hue[1.5421341861115043], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 
       0.8724918816600714}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
       0.6880869119781076}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9393665425693402}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.0875191232355919}}]}, {Hue[1.4756947641499008], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781076}, 
      {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}}]}, 
   {Hue[1.4879472117236476], Polygon[{{-Cos[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781069}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, 
      {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}}]}, \
{Hue[1.577374829890902], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781069}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^4, 0.8724918816600716}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}}]}, 
   {Hue[1.7296056495897847], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^4, \
0.8724918816600716}, 
      {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}}]}, 
   {Hue[1.9238635223078886], Polygon[{{-Cos[(17*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.301712283639015}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4764049667388979}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}}]}, 
   {Hue[2.1412925378915046], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.301712283639015}, {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, \
1.4819447816621787}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 
       1.6555895184432492}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4764049667388979}}]}, {Hue[2.3672988511716944], \
Polygon[{{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \

      {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}]}, \
{Hue[2.5910286308075343], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}]}, 
   {Hue[2.804366804067533], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       1.705691841463221}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       1.7395717696563633}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.9712852585698495}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.9084543807995193}}]}, {Hue[3.0011219345668203], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
      {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}}]}, 
   {Hue[3.1764773334583425], Polygon[{{-Cos[(17*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 
       1.7222389198769947}, {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, \
1.6596693760099315}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 
       1.976615915035449}, {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + \
Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}]}, 
   {Hue[3.326648606019325], Polygon[{{-Cos[(17*Pi)/30]^2 + \
(17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, 
      {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}]}, 
   {Hue[3.448683197046157], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.5625819810819546}, {-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}}]}, 
   {Hue[3.5403590876777082], Polygon[{{-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       1.3346849311080466}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       1.8202053857959208}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}}]}, 
   {Hue[3.6001481606978487], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       1.3346849311080466}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       1.2512975557014567}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       1.778627524809822}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       1.8202053857959208}}]}, {Hue[3.627190223477249], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}}]}, 
   {Hue[3.621219924168978], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}}]}, \
{Hue[3.582455027945141], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}}]}, 
   {Hue[3.511521710658543], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       1.3346849311080466}, {-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}}]}, 
   {Hue[3.409499636536902], Polygon[{{-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       1.5625819810819535}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 
       1.9339672857886046}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}}]}, 
   {Hue[3.2780513483629603], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       1.5625819810819535}, {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, \
1.6596693760099315}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 
       1.976615915035449}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 
       1.9339672857886046}}]}, {Hue[3.1195327080646447], \
Polygon[{{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, \

      {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}]}, \
{Hue[2.9370839307777055], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}]}, 
   {Hue[2.734763214548811], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       1.7395717696563637}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       1.705691841463221}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 
       1.9084543807995193}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 
       1.971285258569849}}]}, {Hue[2.5177813432268503], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}, 
      {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}}]}, 
   {Hue[2.2928961437634507], Polygon[{{-Cos[(17*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       1.6189603147994467}, {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, \
1.4819447816621787}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 
       1.6555895184432492}, {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + \
Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}}]}, {Hue[2.069031927605491], \
Polygon[{{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \

      {-Cos[(17*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, 
      {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}]}, 
   {Hue[1.858139919978526], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(41*Pi)/30]^2, 
       1.3017122836390156}, {-Cos[(17*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0910840571723004}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}}]}, 
   {Hue[1.676037548509797], Polygon[{{-Cos[(17*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       0.8724918816600724}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 
       1.0875191232355927}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}}]}, 
   {Hue[1.542134186111505], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       0.8724918816600724}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       0.6880869119781079}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 
       0.9393665425693406}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 
       1.0875191232355927}}]}, {Hue[1.475694764149901], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781079}, 
      {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}}]}, 
   {Hue[1.487947211723648], Polygon[{{-Cos[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, 
      {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}}]}, \
{Hue[1.5773748298909023], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}}]}, 
   {Hue[1.7296056495897845], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       0.8724918816600722}, {-Cos[(17*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0910840571723004}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}}]}, 
   {Hue[1.9238635223078884], Polygon[{{-Cos[(17*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0910840571723004}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.3017122836390145}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
       1.4764049667388974}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}}]}, 
   {Hue[2.1412925378915046], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.3017122836390145}, {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, \
1.4819447816621787}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 
       1.6555895184432492}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
       1.4764049667388974}}]}, {Hue[2.3672988511716944], \
Polygon[{{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \

      {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}]}, 
   {Hue[2.591028630807535], Polygon[{{-Cos[(17*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       1.6189603147994467}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       1.705691841463221}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 
       1.9084543807995193}, {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + \
Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}}]}, {Hue[2.804366804067532], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}}]}, 
   {Hue[3.0011219345668194], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       1.7395717696563637}, {-Cos[(17*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 
       1.7222389198769947}, {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + \
Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}}]}, 
   {Hue[3.1764773334583425], Polygon[{{-Cos[(17*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 
       1.7222389198769947}, {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, \
1.6596693760099315}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 
       1.976615915035449}, {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + \
Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}]}, 
   {Hue[3.326648606019325], Polygon[{{-Cos[(17*Pi)/30]^2 + \
(17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
      {-Cos[(17*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, 
      {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}]}, 
   {Hue[3.448683197046157], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(28*Pi)/15]^2, 
       1.5625819810819546}, {-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}}]}, 
   {Hue[3.540359087677708], Polygon[{{-Cos[(17*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 
       1.4470248504530066}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       1.3346849311080493}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
       1.8202053857959217}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}}]}, 
   {Hue[3.6001481606978487], Polygon[{{-Cos[(17*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       1.3346849311080493}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       1.2512975557014525}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 
       1.778627524809822}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
       1.8202053857959217}}]}, {Hue[3.6271902234772484], 
    Polygon[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}, 
      {-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}}]}, 
   {Hue[3.511891228151561], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5]))/8, 1.763355756877422}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 2.235484296800203}, 
      {-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}}]}, \
{Hue[3.4744037332934523], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 2.2513313265781}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 2.235484296800203}}]}, 
   {Hue[3.405678429599371], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + Sqrt[5])*Sin[Pi/15]^2)/4, 
       1.8202053857959208}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 2.2513313265781}}]}, 
   {Hue[3.3068514386592778], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.284543605895154}, 
      {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}}]}, 
   {Hue[3.1796114872027594], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       1.9339672857886054}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, \
1.976615915035449}, {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 
       2.283369148915068}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       2.284543605895154}}]}, {Hue[3.0262769448449225], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
      {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}}]}, \
{Hue[2.8498980520953263], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 2.2025704634356607}, 
      {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}}]}, 
   {Hue[2.6544067170007684], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 
       1.971285258569849}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, \
1.908454380799519}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.1122635155465685}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 2.2025704634356607}}]}, 
   {Hue[2.444855197898489], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 
       1.908454380799519}, {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + \
Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.1122635155465685}}]}, 
   {Hue[2.227800853020168], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, \
1.6555895184432492}, {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 
       1.8302685290560392}, {-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.9869545564435855}}]}, {Hue[2.0119004829740796], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}, 
      {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}}]}, \

   {Hue[1.808723757466036], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
       1.476404966738898}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}}]}, 
   {Hue[1.6335162459063992], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.289570859044146}, 
      {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}}]}, 
   {Hue[1.5048418289073748], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.0875191232355919}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       0.9393665425693402}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       1.1623542887261809}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.289570859044146}}]}, {Hue[1.4410113458510994], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}, 
      {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, \
{-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261809}}]}, 
   {Hue[1.4529782096660304], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5 + \
Sqrt[5])/4, 0.8816778784387097}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261806}, 
      {-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}}]}, \
{Hue[1.538925504332944], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.289570859044146}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261806}}]}, 
   {Hue[1.6849637099678545], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.0875191232355914}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.289570859044146}}]}, 
   {Hue[1.8717104688250281], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^4, 1.650686345432751}, 
      {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}}]}, 
   {Hue[2.0811568661566735], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4764049667388979}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, \
1.6555895184432492}, {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 
       1.8302685290560392}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^4, \
1.650686345432751}}]}, 
   {Hue[2.2991581677310036], Polygon[{{-(-1 + Sqrt[5])^2/16 + (11*(5 + \
Sqrt[5]))/32, 1.6555895184432492}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
      {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}}]}, \

   {Hue[2.515148251406263], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.9084543807995193}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       2.112263515546568}, {-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.9869545564435855}}]}, {Hue[2.721221661116884], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}}]}, 
   {Hue[2.9113518456338032], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.9712852585698495}, {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + \
Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}}]}, 
   {Hue[3.0808604176080947], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       1.99216913656241}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, \
1.976615915035449}, {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 
       2.283369148915068}, {-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
       2.2583039834915453}}]}, {Hue[3.2260857032032626], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895153}, 
      {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}}]}, 
   {Hue[3.344185060824171], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.9339672857886046}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895153}}]}, 
   {Hue[3.433021273054938], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.2513313265781}, 
      {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}}]}, 
   {Hue[3.4910964859696265], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       1.8202053857959208}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       1.778627524809822}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       2.235484296800203}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       2.2513313265781}}]}, {Hue[3.5175054710373046], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + \
((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800203}}]}, 
   {Hue[3.511891228151561], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5]))/8, 1.763355756877422}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800203}, 
      {-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}}]}, \
{Hue[3.4744037332934514], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + \
((5 + Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578101}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800203}}]}, 
   {Hue[3.4056784295993703], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 
       1.82020538579592}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578101}}]}, 
   {Hue[3.306851438659277], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895153}, 
      {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}}]}, 
   {Hue[3.179611487202759], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 
       1.9339672857886046}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, \
1.976615915035449}, {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 
       2.283369148915068}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       2.284543605895153}}]}, {Hue[3.0262769448449225], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
      {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
      {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}}]}, \
{Hue[2.8498980520953263], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.2025704634356607}, 
      {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}}]}, 
   {Hue[2.654406717000769], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 
       1.971285258569849}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 
       1.9084543807995193}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       2.1122635155465685}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       2.2025704634356607}}]}, {Hue[2.444855197898489], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.1122635155465685}}]}, 
   {Hue[2.227800853020168], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, \
1.6555895184432492}, {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 
       1.8302685290560392}, {-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.9869545564435855}}]}, {Hue[2.011900482974079], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.650686345432751}, 
      {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}}]}, \

   {Hue[1.808723757466036], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 
       1.4764049667388972}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.650686345432751}}]}, 
   {Hue[1.6335162459063999], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.2895708590441464}, 
      {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}}]}, 
   {Hue[1.5048418289073755], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 
       1.0875191232355927}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 
       0.9393665425693406}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       1.1623542887261817}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       1.2895708590441464}}]}, {Hue[1.4410113458510994], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}, 
      {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, \
{-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261817}}]}, 
   {Hue[1.4529782096660306], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5 + \
Sqrt[5])/4, 0.8816778784387097}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726181}, 
      {-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}}]}, \
{Hue[1.5389255043329444], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441461}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726181}}]}, 
   {Hue[1.6849637099678545], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 
       1.0875191232355923}, {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441461}}]}, 
   {Hue[1.8717104688250275], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + Sqrt[5])^2/32, 1.2790742990138142}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327505}, 
      {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}}]}, 
   {Hue[2.081156866156673], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
       1.4764049667388974}, {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, \
1.6555895184432492}, {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 
       1.8302685290560392}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.6506863454327505}}]}, {Hue[2.2991581677310036], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
      {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
      {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}}]}, \

   {Hue[2.5151482514062637], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.8022456366013615}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 
       1.9084543807995193}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       2.1122635155465685}, {-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.9869545564435855}}]}, {Hue[2.7212216611168825], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + \
((5 + Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.1122635155465685}}]}, 
   {Hue[2.9113518456338023], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 
       1.9712852585698486}, {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + \
Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
      {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}}]}, 
   {Hue[3.0808604176080947], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       1.99216913656241}, {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, \
1.976615915035449}, {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 
       2.283369148915068}, {-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
       2.2583039834915453}}]}, {Hue[3.2260857032032626], Polygon[{{-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.284543605895153}, 
      {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}}]}, 
   {Hue[3.344185060824171], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 
       1.9339672857886046}, {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.284543605895153}}]}, 
   {Hue[3.4330212730549374], Polygon[{{-(-1 + Sqrt[5])^2/16 + ((-1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + Sqrt[5])^2)/64, 1.8768892930626264}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578101}, 
      {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}}]}, 
   {Hue[3.491096485969627], Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
       1.8202053857959217}, {-(-1 + Sqrt[5])^2/16 + (5*(5 + \
Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 
       1.778627524809822}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       2.235484296800203}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       2.251331326578101}}]}, {Hue[3.5175054710373046], 
    Polygon[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + \
((5 + Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}, 
      {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800203}}]}, 
   {Hue[3.3660162217118086], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 2.235484296800203}, 
      {-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 2.5979598975817524}, \
{7/2, 2.598076211353316}}]}, 
   {Hue[3.3302780036297976], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[Pi/30]^2*Sin[(19*Pi)/30]^2 + 2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 
       2.235484296800203}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, \
2.2513313265781}, 
      {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 2.5962550390555568}, \
{-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 
       2.5979598975817524}}]}, {Hue[3.2646627040530793], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 2.2513313265781}, 
      {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 
       2.5962550390555568}}]}, {Hue[3.170285684892035], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.284543605895154}, 
      {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

       2.5891768866299354}}]}, {Hue[3.0488005625562526], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.284543605895154}, 
      {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, \
{47/16, 2.536452985962878}, 
      {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}}]}, 
   {Hue[2.902459761400264], Polygon[{{-Cos[(19*Pi)/30]^2 + \
(17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
      {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {47/16, 2.536452985962878}}]}, 
   {Hue[2.7342086636853264], Polygon[{{-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
       2.2583039834915453}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       2.2025704634356607}, {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + \
(3*Sin[(7*Pi)/30]^2)/2, 2.3948140222646948}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}}]}, 
   {Hue[2.5478321728968756], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       2.2025704634356607}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       2.1122635155465685}, {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + \
(3*Sin[(4*Pi)/15]^2)/2, 2.281657041700859}, 
      {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \
2.3948140222646948}}]}, 
   {Hue[2.3481874792582], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       2.1122635155465685}, {-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.9869545564435855}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + \
Sqrt[5])^2)/32, 2.14040166785146}, 
      {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}}]}, 
   {Hue[2.1415729629771003], Polygon[{{-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.9869545564435855}, {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, \
1.8302685290560392}, {29/16, 1.9754350786598884}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}}]}, 
   {Hue[1.9362883056840317], Polygon[{{-Cos[(19*Pi)/30]^2 + \
(11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}, 
      {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, \
1.7955424168801202}, {29/16, 1.9754350786598884}}]}, 
   {Hue[1.7433837064235544], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.6506863454327514}, {-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4628718195622255}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, \
1.7955424168801202}}]}, 
   {Hue[1.5773245444742745], Polygon[{{-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4628718195622255}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.289570859044146}, {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 1.454550222063749}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}}]}, 
   {Hue[1.455570570242257], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.289570859044146}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, \
1.1623542887261809}, 
      {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}, {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 
       1.454550222063749}}]}, {Hue[1.3952513877576367], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261809}, 
      {-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}, {5/4, \
1.299038105676658}, 
      {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}}]}, 
   {Hue[1.406652424009319], Polygon[{{-Cos[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2, 1.114717238216091}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261806}, 
      {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, \
1.3407174947497686}, {5/4, 1.299038105676658}}]}, 
   {Hue[1.4879259506634934], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
       1.1623542887261806}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.289570859044146}, {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + \
(3*Sin[(17*Pi)/30]^2)/2, 1.4545502220637487}, 
      {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, \
1.3407174947497686}}]}, 
   {Hue[1.6260110210568826], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
       1.289570859044146}, {-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4628718195622255}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}}]}, 
   {Hue[1.8029194769422463], Polygon[{{-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4628718195622255}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^4, \
1.650686345432751}, 
      {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, \
1.7955424168801195}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \

       1.61498867371741}}]}, {Hue[2.001748533339087], \
Polygon[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^4, 
       1.650686345432751}, {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, \
1.8302685290560392}, {29/16, 1.9754350786598884}, 
      {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, \
1.7955424168801195}}]}, 
   {Hue[2.209040479620565], Polygon[{{-Cos[(19*Pi)/30]^2 + \
(11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
      {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}}]}, 
   {Hue[2.4146638850887987], Polygon[{{-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.9869545564435855}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       2.112263515546568}, {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + \
(3*Sin[(11*Pi)/15]^2)/2, 2.281657041700858}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}}]}, 
   {Hue[2.6110140014975016], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       2.112263515546568}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       2.2025704634356615}, {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + \
(3*Sin[(23*Pi)/30]^2)/2, 2.394814022264696}, 
      {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}}]}, 
   {Hue[2.7922898567425496], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       2.2025704634356615}, {-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
       2.2583039834915453}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}, 
      {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + (3*Sin[(23*Pi)/30]^2)/2, \
2.394814022264696}}]}, 
   {Hue[2.9539918841979755], Polygon[{{-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
       2.2583039834915453}, {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, \
2.283369148915068}, {47/16, 2.536452985962878}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}}]}, 
   {Hue[3.0926034561056945], Polygon[{{-Cos[(19*Pi)/30]^2 + \
(17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895153}, 
      {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + (3*Sin[(13*Pi)/15]^2)/2, \
2.5712732770958877}, {47/16, 2.536452985962878}}]}, 
   {Hue[3.2053966901369635], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       2.284543605895153}, {-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, \
2.2706462108209}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + \
(3*Sin[(13*Pi)/15]^2)/2, 
       2.5712732770958877}}]}, {Hue[3.2903157442569695], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.2513313265781}, 
      {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + (3*Sin[(14*Pi)/15]^2)/2, \
2.5962550390555568}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

       2.5891768866299354}}]}, {Hue[3.345905572843674], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.2513313265781}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800203}, 
      {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + \
(3*Sin[(14*Pi)/15]^2)/2, 
       2.5962550390555568}}]}, {Hue[3.371265476610336], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800203}, 
      {-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, {7/2, \
2.598076211353316}, 
      {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}}]}, 
   {Hue[3.3660162217118086], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800203}, 
      {-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, \
2.5979598975817524}, {7/2, 2.598076211353316}}]}, 
   {Hue[3.330278003629797], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(31*Pi)/30]^2, 
       2.235484296800203}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       2.251331326578101}, {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + \
(3*Sin[(16*Pi)/15]^2)/2, 2.5962550390555568}, 
      {-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, \
2.5979598975817524}}]}, 
   {Hue[3.2646627040530793], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       2.251331326578101}, {-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, \
2.2706462108209}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + \
(3*Sin[(16*Pi)/15]^2)/2, 
       2.5962550390555568}}]}, {Hue[3.1702856848920358], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895153}, 
      {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

       2.5891768866299354}}]}, {Hue[3.0488005625562526], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895153}, 
      {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, \
{47/16, 2.536452985962878}, 
      {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}}]}, 
   {Hue[2.902459761400264], Polygon[{{-Cos[(19*Pi)/30]^2 + \
(17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
      {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {47/16, 2.536452985962878}}]}, 
   {Hue[2.7342086636853264], Polygon[{{-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
       2.2583039834915453}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       2.2025704634356607}, {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + \
(3*Sin[(37*Pi)/30]^2)/2, 2.3948140222646948}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}}]}, 
   {Hue[2.547832172896876], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       2.2025704634356607}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       2.1122635155465685}, {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + \
(3*Sin[(19*Pi)/15]^2)/2, 2.2816570417008593}, 
      {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}}]}, 
   {Hue[2.3481874792582], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       2.1122635155465685}, {-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.9869545564435855}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + \
Sqrt[5])^2)/32, 2.14040166785146}, 
      {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}}]}, 
   {Hue[2.1415729629771003], Polygon[{{-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.9869545564435855}, {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, \
1.8302685290560392}, {29/16, 1.9754350786598884}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}}]}, 
   {Hue[1.9362883056840314], Polygon[{{-Cos[(19*Pi)/30]^2 + \
(11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.650686345432751}, 
      {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + (3*Sin[(41*Pi)/30]^2)/2, \
1.7955424168801195}, {29/16, 1.9754350786598884}}]}, 
   {Hue[1.743383706423554], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(41*Pi)/30]^2, 
       1.650686345432751}, {-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4628718195622255}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + (3*Sin[(41*Pi)/30]^2)/2, \
1.7955424168801195}}]}, 
   {Hue[1.577324544474275], Polygon[{{-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4628718195622255}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       1.2895708590441464}, {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + \
(3*Sin[(43*Pi)/30]^2)/2, 1.4545502220637496}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}}]}, 
   {Hue[1.4555705702422577], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       1.2895708590441464}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       1.1623542887261817}, {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + \
(3*Sin[(22*Pi)/15]^2)/2, 1.3407174947497693}, 
      {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + (3*Sin[(43*Pi)/30]^2)/2, \
1.4545502220637496}}]}, 
   {Hue[1.395251387757637], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       1.1623542887261817}, {-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, \
1.114717238216091}, {5/4, 1.299038105676658}, 
      {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}}]}, 
   {Hue[1.4066524240093192], Polygon[{{-Cos[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2, 1.114717238216091}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726181}, 
      {-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, \
1.340717494749769}, {5/4, 1.299038105676658}}]}, 
   {Hue[1.4879259506634936], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/15]^2, 
       1.162354288726181}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       1.2895708590441461}, {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + \
(3*Sin[(47*Pi)/30]^2)/2, 1.454550222063749}, 
      {-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, \
1.340717494749769}}]}, 
   {Hue[1.6260110210568826], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       1.2895708590441461}, {-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4628718195622255}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}}]}, 
   {Hue[1.802919476942246], Polygon[{{-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.4628718195622255}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.6506863454327505}, {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + \
(3*Sin[(49*Pi)/30]^2)/2, 1.795542416880119}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}}]}, 
   {Hue[2.001748533339087], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.6506863454327505}, {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, \
1.8302685290560392}, {29/16, 1.9754350786598884}, 
      {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, \
1.795542416880119}}]}, 
   {Hue[2.209040479620565], Polygon[{{-Cos[(19*Pi)/30]^2 + \
(11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
      {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}}]}, 
   {Hue[2.4146638850887996], Polygon[{{-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.9869545564435855}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       2.1122635155465685}, {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + \
(3*Sin[(26*Pi)/15]^2)/2, 2.2816570417008593}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}}]}, 
   {Hue[2.6110140014975007], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       2.1122635155465685}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       2.2025704634356607}, {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + \
(3*Sin[(53*Pi)/30]^2)/2, 2.3948140222646948}, 
      {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}}]}, 
   {Hue[2.792289856742549], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       2.2025704634356607}, {-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
       2.2583039834915453}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}, 
      {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + (3*Sin[(53*Pi)/30]^2)/2, \
2.3948140222646948}}]}, 
   {Hue[2.9539918841979755], Polygon[{{-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
       2.2583039834915453}, {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, \
2.283369148915068}, {47/16, 2.536452985962878}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}}]}, 
   {Hue[3.0926034561056945], Polygon[{{-Cos[(19*Pi)/30]^2 + \
(17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.284543605895153}, 
      {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + (3*Sin[(28*Pi)/15]^2)/2, \
2.5712732770958877}, {47/16, 2.536452985962878}}]}, 
   {Hue[3.2053966901369635], Polygon[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(28*Pi)/15]^2, 
       2.284543605895153}, {-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, \
2.2706462108209}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + \
(3*Sin[(28*Pi)/15]^2)/2, 
       2.5712732770958877}}]}, {Hue[3.2903157442569686], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578101}, 
      {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + (3*Sin[(29*Pi)/15]^2)/2, \
2.596255039055556}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, 
       2.5891768866299354}}]}, {Hue[3.3459055728436735], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578101}, 
      {-Cos[(19*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800203}, 
      {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + \
(3*Sin[(29*Pi)/15]^2)/2, 
       2.596255039055556}}]}, {Hue[3.371265476610336], 
    Polygon[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800203}, 
      {-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, {7/2, \
2.598076211353316}, 
      {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}}]}, 
   {Hue[3.185449775247516], Polygon[{{7/2, 2.598076211353316}, {-1/4 + \
(15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 2.5979598975817524}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}}]}, 
   {Hue[3.15188346496672], Polygon[{{-1/4 + (15*Cos[Pi/30]^2)/4 + \
(3*Sin[Pi/30]^2)/2, 2.5979598975817524}, 
      {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 2.5962550390555568}, \
{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}}]}, \
{Hue[3.0901829027871046], 
    Polygon[{{-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, \
2.5962550390555568}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

       2.5891768866299354}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       2.809014835019403}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, \
2.834803496770628}}]}, 
   {Hue[3.001414312236429], Polygon[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 \
+ Sqrt[5]))/32, 2.5891768866299354}, 
      {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}]}, 
   {Hue[2.8871611292425245], Polygon[{{-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + \
(3*Sin[(2*Pi)/15]^2)/2, 2.5712732770958873}, {47/16, 2.536452985962878}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}}]}, \
{Hue[2.7495769531447127], 
    Polygon[{{47/16, 2.536452985962878}, {-1/4 + (3*(5 - Sqrt[5]))/16 + \
(15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}]}, \
{Hue[2.591472008770863], 
    Polygon[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, 
      {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \
2.3948140222646948}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}}]}, 
   {Hue[2.4164513253807796], Polygon[{{-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + \
(3*Sin[(7*Pi)/30]^2)/2, 2.3948140222646948}, 
      {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}}]}, 
   {Hue[2.2291347236479813], Polygon[{{-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + \
(3*Sin[(4*Pi)/15]^2)/2, 2.281657041700859}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 \
+ 
        (1 + Sqrt[5])^4/128, 2.239718051509763}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}}]}, \
{Hue[2.0355018953489505], 
    Polygon[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, {(-5 \
+ Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + 
        (1 + Sqrt[5])^4/128, 2.239718051509763}}]}, {Hue[1.843407182752852], 
    Polygon[{{29/16, 1.9754350786598884}, {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + \
(3*Sin[(11*Pi)/30]^2)/2, 1.7955424168801202}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}]}, \
{Hue[1.663248581380093], 
    Polygon[{{-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, \
1.7955424168801202}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}}]}, 
   {Hue[1.508519165256403], Polygon[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 \
+ Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + (3*Sin[(13*Pi)/30]^2)/2, \
1.454550222063749}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}]}, 
   {Hue[1.395331328918824], Polygon[{{-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 1.454550222063749}, 
      {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}}]}, 
   {Hue[1.3393569239295602], Polygon[{{-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + \
(3*Sin[(7*Pi)/15]^2)/2, 1.3407174947497689}, {5/4, 1.299038105676658}, 
      {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}}]}, \
{Hue[1.3499645282808221], 
    Polygon[{{5/4, 1.299038105676658}, {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + \
(3*Sin[(8*Pi)/15]^2)/2, 1.3407174947497686}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, 
      {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}}]}, \
{Hue[1.4254065941220633], 
    Polygon[{{-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, \
1.3407174947497686}, 
      {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}}]}, 
   {Hue[1.5537460944075079], Polygon[{{-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + \
(3*Sin[(17*Pi)/30]^2)/2, 1.4545502220637487}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}}]}, 
   {Hue[1.7185619608377327], Polygon[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + \
(3*(5 + Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, \
1.7955424168801195}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}]}, 
   {Hue[1.9042589712777056], Polygon[{{-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + \
(3*Sin[(19*Pi)/30]^2)/2, 1.7955424168801195}, 
      {29/16, 1.9754350786598884}, {(-5 + Sqrt[5])/8 + (11*(1 + \
Sqrt[5])^2)/64, 2.0698782028004867}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}}]}, 
   {Hue[2.0982552214828982], Polygon[{{29/16, 1.9754350786598884}, {-1/4 + \
(15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}]}, \
{Hue[2.2909875132838655], 
    Polygon[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, 
      {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}}]}, 
   {Hue[2.4752398502012634], Polygon[{{-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + \
(3*Sin[(11*Pi)/15]^2)/2, 2.281657041700858}, 
      {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + (3*Sin[(23*Pi)/30]^2)/2, \
2.394814022264696}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}}]}, 
   {Hue[2.6454958435575158], Polygon[{{-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + \
(3*Sin[(23*Pi)/30]^2)/2, 2.394814022264696}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}}]}, 
   {Hue[2.7974749590967125], Polygon[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}, {47/16, 2.536452985962878}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 + \
Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + 
        (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}}]}, \
{Hue[2.9278327129754085], 
    Polygon[{{47/16, 2.536452985962878}, {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + \
(3*Sin[(13*Pi)/15]^2)/2, 2.5712732770958877}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}]}, \
{Hue[3.0339745505460076], 
    Polygon[{{-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + (3*Sin[(13*Pi)/15]^2)/2, \
2.5712732770958877}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}}]}, 
   {Hue[3.11394185027841], Polygon[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 \
+ Sqrt[5]))/32, 2.5891768866299354}, 
      {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + (3*Sin[(14*Pi)/15]^2)/2, \
2.5962550390555568}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}]}, 
   {Hue[3.166341775973294], Polygon[{{-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + \
(3*Sin[(14*Pi)/15]^2)/2, 2.5962550390555568}, 
      {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}}]}, 
   {Hue[3.1903033268833147], Polygon[{{-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + \
(3*Sin[(29*Pi)/30]^2)/2, 2.5979598975817524}, {7/2, 2.598076211353316}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}}]}, \
{Hue[3.185449775247516], 
    Polygon[{{7/2, 2.598076211353316}, {-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + \
(3*Sin[(31*Pi)/30]^2)/2, 2.5979598975817524}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}}]}, 
   {Hue[3.15188346496672], Polygon[{{-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + \
(3*Sin[(31*Pi)/30]^2)/2, 2.5979598975817524}, 
      {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + (3*Sin[(16*Pi)/15]^2)/2, \
2.5962550390555568}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}}]}, 
   {Hue[3.0901829027871046], Polygon[{{-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + \
(3*Sin[(16*Pi)/15]^2)/2, 2.5962550390555568}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}}]}, 
   {Hue[3.0014143122364296], Polygon[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + \
(15*(5 + Sqrt[5]))/32, 2.5891768866299354}, 
      {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}]}, 
   {Hue[2.887161129242525], Polygon[{{-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + \
(3*Sin[(17*Pi)/15]^2)/2, 2.5712732770958877}, {47/16, 2.536452985962878}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}}]}, \
{Hue[2.7495769531447127], 
    Polygon[{{47/16, 2.536452985962878}, {-1/4 + (3*(5 - Sqrt[5]))/16 + \
(15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}]}, \
{Hue[2.591472008770863], 
    Polygon[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, 
      {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}}]}, 
   {Hue[2.41645132538078], Polygon[{{-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + \
(3*Sin[(37*Pi)/30]^2)/2, 2.3948140222646948}, 
      {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}}]}, 
   {Hue[2.2291347236479813], Polygon[{{-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + \
(3*Sin[(19*Pi)/15]^2)/2, 2.2816570417008593}, 
      {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 \
+ 
        (1 + Sqrt[5])^4/128, 2.239718051509763}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}}]}, \
{Hue[2.0355018953489505], 
    Polygon[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, {(-5 \
+ Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + 
        (1 + Sqrt[5])^4/128, 2.239718051509763}}]}, {Hue[1.8434071827528515], \

    Polygon[{{29/16, 1.9754350786598884}, {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + \
(3*Sin[(41*Pi)/30]^2)/2, 1.7955424168801195}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}]}, \
{Hue[1.663248581380093], 
    Polygon[{{-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + (3*Sin[(41*Pi)/30]^2)/2, \
1.7955424168801195}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}}]}, 
   {Hue[1.5085191652564034], Polygon[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + \
(3*(5 + Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + (3*Sin[(43*Pi)/30]^2)/2, \
1.4545502220637496}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}]}, 
   {Hue[1.3953313289188247], Polygon[{{-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + \
(3*Sin[(43*Pi)/30]^2)/2, 1.4545502220637496}, 
      {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}}]}, 
   {Hue[1.3393569239295602], Polygon[{{-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + \
(3*Sin[(22*Pi)/15]^2)/2, 1.3407174947497693}, {5/4, 1.299038105676658}, 
      {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}}]}, \
{Hue[1.3499645282808221], 
    Polygon[{{5/4, 1.299038105676658}, {-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + \
(3*Sin[(23*Pi)/15]^2)/2, 1.340717494749769}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, 
      {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}}]}, \
{Hue[1.4254065941220633], 
    Polygon[{{-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, \
1.340717494749769}, 
      {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}}]}, 
   {Hue[1.5537460944075083], Polygon[{{-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + \
(3*Sin[(47*Pi)/30]^2)/2, 1.454550222063749}, 
      {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}}]}, 
   {Hue[1.7185619608377325], Polygon[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + \
(3*(5 + Sqrt[5]))/16, 1.61498867371741}, 
      {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, \
1.795542416880119}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}, 
      {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}]}, 
   {Hue[1.9042589712777054], Polygon[{{-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + \
(3*Sin[(49*Pi)/30]^2)/2, 1.795542416880119}, {29/16, 1.9754350786598884}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, {(-5 \
+ Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}}]}, \
{Hue[2.0982552214828982], 
    Polygon[{{29/16, 1.9754350786598884}, {-1/4 + (15*(5 - Sqrt[5]))/32 + \
(3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}]}, \
{Hue[2.2909875132838664], 
    Polygon[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, 
      {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}}]}, 
   {Hue[2.4752398502012625], Polygon[{{-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + \
(3*Sin[(26*Pi)/15]^2)/2, 2.2816570417008593}, 
      {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + (3*Sin[(53*Pi)/30]^2)/2, \
2.3948140222646948}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}}]}, 
   {Hue[2.6454958435575158], Polygon[{{-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + \
(3*Sin[(53*Pi)/30]^2)/2, 2.3948140222646948}, 
      {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}}]}, 
   {Hue[2.7974749590967125], Polygon[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}, {47/16, 2.536452985962878}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 + \
Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + 
        (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}}]}, \
{Hue[2.9278327129754085], 
    Polygon[{{47/16, 2.536452985962878}, {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + \
(3*Sin[(28*Pi)/15]^2)/2, 2.5712732770958877}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}]}, \
{Hue[3.0339745505460076], 
    Polygon[{{-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + (3*Sin[(28*Pi)/15]^2)/2, \
2.5712732770958877}, 
      {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}}]}, 
   {Hue[3.1139418502784095], Polygon[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + \
(15*(5 + Sqrt[5]))/32, 2.5891768866299354}, 
      {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + (3*Sin[(29*Pi)/15]^2)/2, \
2.596255039055556}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
      {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}]}, 
   {Hue[3.1663417759732932], Polygon[{{-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + \
(3*Sin[(29*Pi)/15]^2)/2, 2.596255039055556}, 
      {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}}]}, 
   {Hue[3.1903033268833143], Polygon[{{-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + \
(3*Sin[(59*Pi)/30]^2)/2, 2.5979598975817515}, {7/2, 2.598076211353316}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}}]}, \
{Hue[2.9725677413038847], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, \
{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + 
        ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/15]^2 + 
        2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 2.976303493889946}, \
{-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}}]}, 
   {Hue[2.94156744000882], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 
       2.8487773266631815}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, \
2.834803496770628}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 2.95408127925137}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 2.976303493889946}}]}, 
   {Hue[2.884525986283146], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, 
       2.834803496770628}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 2.95408127925137}}]}, 
   {Hue[2.8024450817817876], Polygon[{{(-5 + Sqrt[5])/8 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       2.809014835019403}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, \
2.768181798733441}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.8593997974092926}, 
      {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}}]}, 
   {Hue[2.6968154501978696], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
       2.768181798733441}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, \
2.70871038548537}, {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 
       2.7833940695732022}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 
       2.8593997974092926}}]}, {Hue[2.5696651064366005], Polygon[{{(-5 + \
Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}}]}, \

   {Hue[2.423639048647253], Polygon[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.5673355087770746}, 
      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}}]}, 
   {Hue[2.2621273449531207], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 
       2.5219601128218545}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
       2.392089327116677}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, \
2.427623046285348}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.5673355087770746}}]}, 
   {Hue[2.089468202494362], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
       2.392089327116677}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.427623046285348}}]}, 
   {Hue[1.9112623963307638], Polygon[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 \
+ Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}}]}, 
   {Hue[1.734832105361034], Polygon[{{(-5 + Sqrt[5])/8 + (11*(1 + \
Sqrt[5])^2)/64, 2.0698782028004867}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207314}, 
      {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}}]}, \

   {Hue[1.5697948831204007], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 
       1.8914277190459863}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.7178957504272219}, {-Cos[(11*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       1.9258466260207314}}]}, {Hue[1.4284879569907039], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + \
((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409114}, 
      {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}}]}, 
   {Hue[1.3254382425167153], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       1.5679671136605227}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       1.4640759018681937}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 
       1.5257871330867276}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       1.6209688555409114}}]}, {Hue[1.2745927418690974], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}, 
      {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, \
{-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}}]}, 
   {Hue[1.2842127646634727], Polygon[{{(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427302}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, 
      {-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}}]}, \
{Hue[1.3527293177077004], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409112}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}}]}, 
   {Hue[1.4695768254043384], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       1.5679671136605227}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.7178957504272219}, {-Cos[(11*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       1.6209688555409112}}]}, {Hue[1.6201239789943034], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + \
((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207308}, 
      {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}}]}, 
   {Hue[1.7902819981261253], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.8914277190459856}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, \
2.0698782028004867}, {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 
       2.0997996262255536}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       1.9258466260207308}}]}, {Hue[1.968511801052169], Polygon[{{(-5 + \
Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}}]}, \

   {Hue[2.1459397256652433], Polygon[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 \
+ Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^4, 2.4276230462853476}, 
      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}}]}, 
   {Hue[2.315821390987116], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 
       2.3920893271166768}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       2.521960112821855}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       2.567335508777075}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^4, \
2.4276230462853476}}]}, 
   {Hue[2.4729818798019734], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       2.521960112821855}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}}]}, 
   {Hue[2.6133998079674794], Polygon[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}}]}, 
   {Hue[2.7339319857049826], Polygon[{{(-5 + Sqrt[5])/8 + (17*(1 + \
Sqrt[5])^2)/64, 2.70871038548537}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.8593997974092926}, 
      {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}}]}, \

   {Hue[2.8321393685425207], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
       2.7681817987334414}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       2.809014835019403}, {-Cos[(11*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 
       2.9156867970745455}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
       2.8593997974092926}}]}, {Hue[2.906178942229958], 
    Polygon[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + \
(5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.95408127925137}, 
      {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}}]}, 
   {Hue[2.954736856245055], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       2.834803496770628}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       2.8487773266631815}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       2.976303493889946}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       2.95408127925137}}]}, {Hue[2.976987240099013], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, \
{-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.976303493889946}}]}, 
   {Hue[2.972567741303885], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2)/16, 2.8531695488854605}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.976303493889946}, 
      {-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}}]}, \
{Hue[2.94156744000882], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.976303493889946}}]}, 
   {Hue[2.884525986283146], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 
       2.834803496770629}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}}]}, 
   {Hue[2.8024450817817876], Polygon[{{(-5 + Sqrt[5])/8 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       2.809014835019403}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 
       2.7681817987334423}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       2.859399797409293}, {-Cos[(11*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 
       2.9156867970745455}}]}, {Hue[2.69681545019787], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}}]}, 
   {Hue[2.5696651064366005], Polygon[{{(-5 + Sqrt[5])/8 + (17*(1 + \
Sqrt[5])^2)/64, 2.70871038548537}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}}]}, \

   {Hue[2.423639048647253], Polygon[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.5673355087770746}, 
      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}}]}, 
   {Hue[2.262127344953121], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 
       2.5219601128218545}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 
       2.3920893271166777}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
       2.4276230462853485}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
       2.5673355087770746}}]}, {Hue[2.089468202494362], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}}]}, 
   {Hue[1.9112623963307638], Polygon[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 \
+ Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}}]}, 
   {Hue[1.7348321053610336], Polygon[{{(-5 + Sqrt[5])/8 + (11*(1 + \
Sqrt[5])^2)/64, 2.0698782028004867}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.925846626020731}, 
      {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}}]}, \

   {Hue[1.5697948831204007], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 
       1.891427719045986}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.925846626020731}}]}, 
   {Hue[1.4284879569907043], Polygon[{{(-5 + Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.7178957504272219}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 
       1.5679671136605233}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
       1.620968855540912}, {-Cos[(11*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.760690570377689}}]}, {Hue[1.325438242516716], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867283}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}}]}, 
   {Hue[1.2745927418690977], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 
       1.4640759018681944}, {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427302}, {-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 
       1.4917828430524098}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       1.5257871330867283}}]}, {Hue[1.2842127646634731], Polygon[{{(-5 + \
Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, 
      {-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}}]}, \
{Hue[1.3527293177077007], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}}]}, 
   {Hue[1.4695768254043384], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 
       1.5679671136605229}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
       1.7178957504272219}, {-Cos[(11*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
       1.6209688555409116}}]}, {Hue[1.6201239789943027], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + \
((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.9258466260207303}, 
      {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}}]}, 
   {Hue[1.790281998126125], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 
       1.8914277190459852}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, \
2.0698782028004867}, {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 
       2.0997996262255536}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.9258466260207303}}]}, {Hue[1.968511801052169], Polygon[{{(-5 + \
Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, 
      {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}}]}, \

   {Hue[2.145939725665244], Polygon[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 \
+ Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}}]}, 
   {Hue[2.315821390987115], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 
       2.3920893271166777}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 
       2.5219601128218536}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
       2.5673355087770737}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
       2.4276230462853485}}]}, {Hue[2.472981879801973], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
      {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}}]}, 
   {Hue[2.6133998079674794], Polygon[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
      {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}}]}, 
   {Hue[2.733931985704982], Polygon[{{(-5 + Sqrt[5])/8 + (17*(1 + \
Sqrt[5])^2)/64, 2.70871038548537}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.8593997974092926}, 
      {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}}]}, \

   {Hue[2.8321393685425202], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 
       2.768181798733441}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
      {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.8593997974092926}}]}, 
   {Hue[2.9061789422299578], Polygon[{{(-5 + Sqrt[5])/8 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
       2.809014835019403}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 
       2.834803496770629}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
       2.9540812792513695}, {-Cos[(11*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 
       2.9156867970745455}}]}, {Hue[2.954736856245055], 
    Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + \
((1 + Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
      {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.9540812792513695}}]}, 
   {Hue[2.976987240099013], Polygon[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 
       2.8487773266631806}, {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, \
2.8531695488854605}, {-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 
       2.9835656861048196}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       2.9763034938899455}}]}, {Hue[2.7303065946159704], \
Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 2.976303493889946}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 2.974595082902794}, 
      {-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}}]}, \
{Hue[2.7022413770678395], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 2.976303493889946}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 2.95408127925137}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 2.947488384456562}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 2.974595082902794}}]}, 
   {Hue[2.6505527149620645], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[Pi/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 
       2.95408127925137}, {-Cos[(11*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 
       2.9156867970745455}, {-Cos[(23*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 
       2.901719090978228}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, \
2.947488384456562}}]}, 
   {Hue[2.576166980525242], Polygon[{{-Cos[(11*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 
       2.9156867970745455}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 
       2.8593997974092926}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
2.836596676593441}, 
      {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}}]}, 
   {Hue[2.4804654683565746], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 
       2.8593997974092926}, {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, \
2.7833940695732022}, {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 
       2.751525170659194}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       2.836596676593441}}]}, {Hue[2.365328741116177], \
Polygon[{{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \

      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
      {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}}]}, \
{Hue[2.2332095951572275], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.5673355087770746}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409046}, 
      {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}}]}, 
   {Hue[2.0872496777327814], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       2.5673355087770746}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, \
2.427623046285348}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.3792297776658287}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409046}}]}, 
   {Hue[1.9314622356509639], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 
       2.427623046285348}, {-Cos[(11*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 
       2.2699589047379565}, {-Cos[(23*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       2.222607239695348}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       2.3792297776658287}}]}, {Hue[1.7710096391550896], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
      {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}}]}, 
   {Hue[1.6125961159988456], Polygon[{{-Cos[(11*Pi)/15]^2 + \
(11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207314}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350187}, 
      {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}}]}, \
{Hue[1.4649327763746829], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207314}, 
      {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
      {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350187}}]}, 
   {Hue[1.3390225985223116], Polygon[{{-Cos[(11*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       1.6209688555409114}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       1.6089224974238354}, {-Cos[(23*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.7374623647519978}}]}, {Hue[1.247579964038373], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409114}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}}]}, 
   {Hue[1.2025893050720429], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 
       1.5257871330867276}, {-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, \
1.4917828430524098}, {-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 
       1.4917828430524098}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       1.5224519023538963}}]}, {Hue[1.2110545459957367], \
Polygon[{{-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
      {-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}}]}, \
{Hue[1.271637130175175], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409112}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}}]}, 
   {Hue[1.3753447935304375], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       1.6209688555409112}, {-Cos[(11*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(23*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.7374623647519978}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       1.6089224974238354}}]}, {Hue[1.5095581508816243], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207308}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350182}, 
      {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}}]}, 
   {Hue[1.6618929420028645], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
       1.9258466260207308}, {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, \
2.0997996262255536}, {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 
       2.057368875173533}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       1.8918241808350182}}]}, {Hue[1.8220117234085094], \
Polygon[{{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \

      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}}]}, \
{Hue[1.9818451269996646], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^4, 2.4276230462853476}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.379229777665828}, 
      {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}}]}, 
   {Hue[2.135199366625502], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^4, \
2.4276230462853476}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^4, 2.5216249314090464}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.379229777665828}}]}, 
   {Hue[2.277295540875845], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       2.567335508777075}, {-Cos[(11*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 
       2.686221801523239}, {-Cos[(23*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 
       2.6463289817643205}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^4, \
2.5216249314090464}}]}, 
   {Hue[2.404410189906922], Polygon[{{-Cos[(11*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 
       2.686221801523239}, {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, \
2.7833940695732022}, {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 
       2.751525170659194}, {-Cos[(23*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 
       2.6463289817643205}}]}, {Hue[2.5136299853598194], \
Polygon[{{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \

      {-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.8593997974092926}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}}]}, \
{Hue[2.6026932528050426], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.8593997974092926}, 
      {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}}]}, 
   {Hue[2.669889968450967], Polygon[{{-Cos[(11*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 
       2.9156867970745455}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       2.95408127925137}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}, 
      {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}}]}, 
   {Hue[2.7139993999855907], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       2.95408127925137}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.976303493889946}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.974595082902794}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}}]}, 
   {Hue[2.734251870690963], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       2.976303493889946}, {-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, \
2.9835656861048196}, {-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 
       2.9835656861048196}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       2.974595082902794}}]}, {Hue[2.7303065946159704], \
Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.976303493889946}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.974595082902794}, 
      {-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}}]}, \
{Hue[2.7022413770678395], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.976303493889946}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.974595082902794}}]}, 
   {Hue[2.650552714962065], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(16*Pi)/15]^2, 
       2.9540812792513704}, {-Cos[(11*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 
       2.9156867970745455}, {-Cos[(23*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 
       2.901719090978228}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       2.9474883844565616}}]}, {Hue[2.5761669805252425], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}}]}, 
   {Hue[2.4804654683565746], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       2.859399797409293}, {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, \
2.7833940695732022}, {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 
       2.751525170659194}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       2.836596676593442}}]}, {Hue[2.365328741116177], \
Polygon[{{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \

      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
      {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}}]}, \
{Hue[2.2332095951572275], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.5673355087770746}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409046}, 
      {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}}]}, 
   {Hue[2.087249677732782], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
       2.5673355087770746}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
       2.4276230462853485}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       2.379229777665829}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       2.521624931409046}}]}, {Hue[1.9314622356509643], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}, 
      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}}]}, 
   {Hue[1.7710096391550896], Polygon[{{-Cos[(11*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 
       2.2699589047379565}, {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, \
2.0997996262255536}, {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 
       2.057368875173533}, {-Cos[(23*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       2.222607239695348}}]}, {Hue[1.6125961159988451], \
Polygon[{{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \

      {-Cos[(11*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.925846626020731}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350182}, 
      {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}}]}, \
{Hue[1.4649327763746824], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.925846626020731}, 
      {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
      {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350182}}]}, 
   {Hue[1.3390225985223119], Polygon[{{-Cos[(11*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
       1.620968855540912}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       1.6089224974238363}, {-Cos[(23*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.7374623647519978}}]}, {Hue[1.2475799640383733], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867283}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}}]}, 
   {Hue[1.202589305072043], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       1.5257871330867283}, {-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, \
1.4917828430524098}, {-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 
       1.4917828430524098}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       1.522451902353897}}]}, {Hue[1.2110545459957367], \
Polygon[{{-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538965}, 
      {-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}}]}, \
{Hue[1.2716371301751754], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238356}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538965}}]}, 
   {Hue[1.3753447935304377], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
       1.6209688555409116}, {-Cos[(11*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
       1.760690570377689}, {-Cos[(23*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.7374623647519978}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       1.6089224974238356}}]}, {Hue[1.5095581508816236], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.9258466260207303}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.8918241808350176}, 
      {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}}]}, 
   {Hue[1.6618929420028645], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.9258466260207303}, {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, \
2.0997996262255536}, {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 
       2.057368875173533}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.8918241808350176}}]}, {Hue[1.8220117234085094], \
Polygon[{{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \

      {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}}]}, \
{Hue[1.9818451269996653], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
      {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}}]}, 
   {Hue[2.135199366625501], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
       2.4276230462853485}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
       2.5673355087770737}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       2.521624931409045}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       2.379229777665829}}]}, {Hue[2.2772955408758446], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}, 
      {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
      {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.521624931409045}}]}, 
   {Hue[2.404410189906922], Polygon[{{-Cos[(11*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 
       2.686221801523239}, {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, \
2.7833940695732022}, {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 
       2.751525170659194}, {-Cos[(23*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 
       2.6463289817643205}}]}, {Hue[2.5136299853598194], \
Polygon[{{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \

      {-Cos[(11*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.8593997974092926}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}}]}, \
{Hue[2.6026932528050426], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.8593997974092926}, 
      {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
      {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}}]}, 
   {Hue[2.6698899684509665], Polygon[{{-Cos[(11*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 
       2.9156867970745455}, {-Cos[(11*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
       2.9540812792513695}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       2.947488384456561}, {-Cos[(23*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 
       2.901719090978228}}]}, {Hue[2.71399939998559], 
    Polygon[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.9540812792513695}, 
      {-Cos[(11*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027934}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.947488384456561}}]}, 
   {Hue[2.734251870690963], Polygon[{{-Cos[(11*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       2.9763034938899455}, {-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, \
2.9835656861048196}, {-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 
       2.9835656861048196}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       2.9745950829027934}}]}, {Hue[2.4622603500805886], \
Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 2.974595082902794}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, 
      {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}}]}, \
{Hue[2.4374743847286338], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 2.974595082902794}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 2.947488384456562}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}}]}, 
   {Hue[2.3917839479847176], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 
       2.947488384456562}, {-Cos[(23*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 
       2.901719090978228}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}}]}, 
   {Hue[2.326031524014277], Polygon[{{-Cos[(23*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 
       2.901719090978228}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
2.836596676593441}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}, 
      {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}]}, 
   {Hue[2.2414755262272803], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       2.836596676593441}, {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, \
2.751525170659194}, {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 
       2.6106791787633683}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
       2.697933958917173}}]}, {Hue[2.139830640103943], \
Polygon[{{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
      {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}]}, 
   {Hue[2.02333346019408], Polygon[{{-Cos[(23*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 
       2.6463289817643205}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, \
2.521624931409046}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}}]}, 
   {Hue[1.8948459214992808], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       2.521624931409046}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
2.3792297776658287}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}}]}, 
   {Hue[1.7580141449946027], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       2.3792297776658287}, {-Cos[(23*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       2.222607239695348}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}}]}, 
   {Hue[1.617502636388636], Polygon[{{-Cos[(23*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       2.222607239695348}, {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, \
2.057368875173533}, {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 
       1.9398272078772507}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + \
((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}}]}, 
   {Hue[1.479310853186373], Polygon[{{-Cos[(23*Pi)/30]^2 + \
(11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350187}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}]}, \
{Hue[1.3511168546552912], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350187}, 
      {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
      {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}}]}, 
   {Hue[1.2424159492854718], Polygon[{{-Cos[(23*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.7374623647519978}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       1.6089224974238354}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
       1.5308481540548224}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
       1.646496168027179}}]}, {Hue[1.1639043096778316], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}}]}, 
   {Hue[1.125413272288383], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       1.5224519023538963}, {-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, \
1.4917828430524098}, {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 
       1.4265847744427302}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
       1.453775372348889}}]}, {Hue[1.1325841756867863], \
Polygon[{{-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, 
      {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}}]}, \
{Hue[1.184341742158827], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}}]}, 
   {Hue[1.273413510043344], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       1.6089224974238354}, {-Cos[(23*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.7374623647519978}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}}]}, 
   {Hue[1.3893843507924304], Polygon[{{-Cos[(23*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.7374623647519978}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
       1.8918241808350182}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
       1.7870411277345808}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
       1.646496168027179}}]}, {Hue[1.5217635632324358], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350182}, 
      {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, \
{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}}]}, 
   {Hue[1.6615712709495278], Polygon[{{-Cos[(23*Pi)/30]^2 + \
(11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
      {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}]}, \
{Hue[1.8016560909014314], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.379229777665828}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}}]}, 
   {Hue[1.9364529882925654], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 
       2.379229777665828}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^4, \
2.5216249314090464}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}}]}, 
   {Hue[2.061632510001721], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^4, \
2.5216249314090464}, 
      {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}}]}, 
   {Hue[2.173806567578889], Polygon[{{-Cos[(23*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 
       2.6463289817643205}, {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, \
2.751525170659194}, {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 
       2.6106791787633683}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}}]}, 
   {Hue[2.270318884855764], Polygon[{{-Cos[(23*Pi)/30]^2 + \
(17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}]}, \
{Hue[2.3491055777975274], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
      {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}}]}, 
   {Hue[2.4086053006207275], Polygon[{{-Cos[(23*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 
       2.901719090978228}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       2.947488384456562}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       2.8144424077524013}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 
       2.7659262761959793}}]}, {Hue[2.447702450148663], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.974595082902794}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}}]}, 
   {Hue[2.4656921907005467], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       2.974595082902794}, {-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, \
2.9835656861048196}, {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 
       2.8531695488854605}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       2.8434972909653364}}]}, {Hue[2.4622603500805886], \
Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.974595082902794}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, 
      {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}}]}, \
{Hue[2.4374743847286338], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.974595082902794}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}}]}, 
   {Hue[2.3917839479847176], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       2.9474883844565616}, {-Cos[(23*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 
       2.901719090978228}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}}]}, 
   {Hue[2.3260315240142773], Polygon[{{-Cos[(23*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 
       2.901719090978228}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       2.836596676593442}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/15]^2)/4, \
2.697933958917174}, 
      {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}]}, 
   {Hue[2.2414755262272803], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       2.836596676593442}, {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, \
2.751525170659194}, {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 
       2.6106791787633683}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 
       2.697933958917174}}]}, {Hue[2.139830640103943], \
Polygon[{{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
      {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}]}, 
   {Hue[2.02333346019408], Polygon[{{-Cos[(23*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 
       2.6463289817643205}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       2.521624931409046}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(37*Pi)/30]^2)/4, \
2.381720267244781}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}}]}, 
   {Hue[1.8948459214992812], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       2.521624931409046}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       2.379229777665829}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/15]^2)/4, \
2.243746859528866}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}}]}, 
   {Hue[1.7580141449946027], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       2.379229777665829}, {-Cos[(23*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       2.222607239695348}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}}]}, 
   {Hue[1.617502636388636], Polygon[{{-Cos[(23*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       2.222607239695348}, {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, \
2.057368875173533}, {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 
       1.9398272078772507}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + \
((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}}]}, 
   {Hue[1.4793108531863728], Polygon[{{-Cos[(23*Pi)/30]^2 + \
(11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350182}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}]}, \
{Hue[1.351116854655291], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350182}, 
      {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
      {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}}]}, 
   {Hue[1.242415949285472], Polygon[{{-Cos[(23*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.7374623647519978}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       1.6089224974238363}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 
       1.530848154054823}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}]}, 
   {Hue[1.163904309677832], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       1.6089224974238363}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       1.522451902353897}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 
       1.4537753723488895}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 
       1.530848154054823}}]}, {Hue[1.1254132722883832], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}, 
      {-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, {(5 - \
Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}}]}, 
   {Hue[1.1325841756867863], Polygon[{{-Cos[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538965}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, 
      {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}}]}, \
{Hue[1.184341742158827], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538965}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238356}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}}]}, 
   {Hue[1.273413510043344], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       1.6089224974238356}, {-Cos[(23*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.7374623647519978}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}}]}, 
   {Hue[1.38938435079243], Polygon[{{-Cos[(23*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
       1.7374623647519978}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       1.8918241808350176}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
       1.7870411277345801}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
       1.646496168027179}}]}, {Hue[1.5217635632324358], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.8918241808350176}, 
      {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, \
{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}}]}, 
   {Hue[1.6615712709495278], Polygon[{{-Cos[(23*Pi)/30]^2 + \
(11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
      {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}]}, \
{Hue[1.8016560909014319], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}}]}, 
   {Hue[1.936452988292565], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       2.379229777665829}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       2.521624931409045}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 
       2.3817202672447797}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 
       2.243746859528866}}]}, {Hue[2.0616325100017203], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.521624931409045}, 
      {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}}]}, 
   {Hue[2.173806567578889], Polygon[{{-Cos[(23*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 
       2.6463289817643205}, {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, \
2.751525170659194}, {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 
       2.6106791787633683}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}}]}, 
   {Hue[2.270318884855764], Polygon[{{-Cos[(23*Pi)/30]^2 + \
(17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}]}, \
{Hue[2.3491055777975274], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, 
      {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
      {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}}]}, 
   {Hue[2.4086053006207275], Polygon[{{-Cos[(23*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 
       2.901719090978228}, {-Cos[(23*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       2.947488384456561}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
       2.8144424077524013}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 
       2.7659262761959793}}]}, {Hue[2.447702450148663], 
    Polygon[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.947488384456561}, 
      {-Cos[(23*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027934}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}}]}, 
   {Hue[2.4656921907005467], Polygon[{{-Cos[(23*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       2.9745950829027934}, {-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, \
2.9835656861048196}, {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 
       2.8531695488854605}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 
       2.8434972909653364}}]}, {Hue[2.172890347031398], Polygon[{{(5*(5 - \
Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, 
      {-3/4 + (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, {1/2, \
2.598076211353316}}]}, 
   {Hue[2.1517030807433164], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4, 
       2.8434972909653364}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4, \
2.8144424077524013}, 
      {-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, {-3/4 \
+ (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}}]}, 
   {Hue[2.1126097496228944], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4, 
       2.8144424077524013}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 
       2.5601613609103286}}]}, {Hue[2.0563617745078453], 
    Polygon[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + \
(5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}, 
      {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, \
2.447478090794556}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}}]}, {Hue[1.9840832598684028], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{5/16, 2.3642850399222173}, 
      {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, \
2.447478090794556}}]}, 
   {Hue[1.8973067738519358], Polygon[{{(17*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 2.6106791787633683}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{5/16, 2.3642850399222173}}]}, 
   {Hue[1.798030475058808], Polygon[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 \
+ (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
      {-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
       2.264540963292246}}]}, {Hue[1.6888059938250897], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, 
      {-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 2.02317839809799}, \
{-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, 
       2.1499828315181597}}]}, {Hue[1.5728690605319655], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 
       2.02317839809799}}]}, {Hue[1.454323301999184], Polygon[{{(5*(5 - \
Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 
       2.0946223601372336}, {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, \
1.9398272078772507}, {-1/16, 1.7488835724541527}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}}]}, 
   {Hue[1.3383708666452816], Polygon[{{(11*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 1.9398272078772507}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, 
      {-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, \
1.6132809148526017}, {-1/16, 1.7488835724541527}}]}, 
   {Hue[1.231525984933484], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
       1.7870411277345812}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, 
       1.6132809148526017}}]}, {Hue[1.1416114157580919], 
    Polygon[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + \
((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}, 
      {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
       1.4898021598760776}}]}, {Hue[1.0771388851319934], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}, 
      {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, \
1.3224570770546993}, {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, 
       1.389101261457407}}]}, {Hue[1.0456706862276695], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}, 
      {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-1/4, \
1.299038105676658}, {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, 
       1.3224570770546993}}]}, {Hue[1.0514421294093586], Polygon[{{(5 - \
Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, 
      {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, \
1.3224570770546993}, {-1/4, 1.299038105676658}}]}, 
   {Hue[1.0936550271688519], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 
       1.453775372348889}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.5308481540548224}, {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + \
Sin[(17*Pi)/30]^2/2, 1.3891012614574068}, 
      {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, \
1.3224570770546993}}]}, 
   {Hue[1.1668260021514532], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
       1.5308481540548224}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, 
       1.3891012614574068}}]}, {Hue[1.2628753539387554], 
    Polygon[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + \
((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}, 
      {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, \
1.6132809148526013}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
       1.4898021598760776}}]}, {Hue[1.373371129380275], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}, 
      {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, \
1.6132809148526013}}]}, 
   {Hue[1.4908450022416582], Polygon[{{(11*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 1.9398272078772507}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-1/16, 1.7488835724541527}}]}, 
   {Hue[1.6091821267556559], Polygon[{{(5*(5 - Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
      {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, \
2.0231783980979894}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
       1.8877889819588956}}]}, {Hue[1.72352898092796], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}, 
      {-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, 
       2.0231783980979894}}]}, {Hue[1.8300615207780884], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, 
       2.1499828315181597}}]}, {Hue[1.9257651836591856], 
    Polygon[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{5/16, 2.3642850399222173}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}}]}, 
   {Hue[2.008267490854751], Polygon[{{(17*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 2.6106791787633683}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, 
      {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, \
2.4474780907945566}, {5/16, 2.3642850399222173}}]}, 
   {Hue[2.0757216825378677], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       2.6979339589171736}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, 
       2.4474780907945566}}]}, {Hue[2.126729341791054], 
    Polygon[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + \
(5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}, 
      {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}}]}, {Hue[2.1602904039830624], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}, 
      {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, 
       2.5601613609103286}}]}, {Hue[2.175771972083489], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}, 
      {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {1/2, \
2.598076211353316}, 
      {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}}]}, 
   {Hue[2.172890347031398], Polygon[{{(5*(5 - Sqrt[5]))/8 - (1 + \
Sqrt[5])^2/16, 2.8531695488854605}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, 
      {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, \
2.588583579753018}, {1/2, 2.598076211353316}}]}, 
   {Hue[2.151703080743316], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 
       2.8434972909653364}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 
       2.814442407752401}, {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + \
Sin[(16*Pi)/15]^2/2, 2.5601613609103286}, 
      {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, \
2.588583579753018}}]}, 
   {Hue[2.1126097496228944], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 
       2.814442407752401}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, 
       2.5601613609103286}}]}, {Hue[2.0563617745078457], 
    Polygon[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + \
(5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}, 
      {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}}]}, {Hue[1.9840832598684028], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}, 
      {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{5/16, 2.3642850399222173}, 
      {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, \
2.4474780907945566}}]}, 
   {Hue[1.8973067738519358], Polygon[{{(17*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 2.6106791787633683}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{5/16, 2.3642850399222173}}]}, 
   {Hue[1.798030475058808], Polygon[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 \
+ (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}, 
      {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
       2.264540963292246}}]}, {Hue[1.6888059938250901], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}, 
      {-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, 
       2.1499828315181597}}]}, {Hue[1.572869060531966], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, 
       2.0231783980979903}}]}, {Hue[1.454323301999184], 
    Polygon[{{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 \
+ Sqrt[5])^2)/64, 2.0946223601372336}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}}]}, 
   {Hue[1.3383708666452816], Polygon[{{(11*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 1.9398272078772507}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, 
      {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, \
1.6132809148526013}, {-1/16, 1.7488835724541527}}]}, 
   {Hue[1.2315259849334839], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 
       1.7870411277345808}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, 
       1.6132809148526013}}]}, {Hue[1.141611415758092], 
    Polygon[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + \
((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.530848154054823}, 
      {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, \
1.3891012614574074}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
       1.4898021598760776}}]}, {Hue[1.0771388851319936], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.530848154054823}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}, 
      {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}, {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, 
       1.3891012614574074}}]}, {Hue[1.0456706862276697], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}, 
      {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-1/4, \
1.299038105676658}, 
      {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}}]}, 
   {Hue[1.0514421294093586], Polygon[{{(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, \
1.4265847744427302}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, 
      {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, \
1.3224570770546995}, {-1/4, 1.299038105676658}}]}, 
   {Hue[1.093655027168852], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 
       1.4537753723488893}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 
       1.5308481540548229}, {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + \
Sin[(47*Pi)/30]^2/2, 1.389101261457407}, 
      {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, \
1.3224570770546995}}]}, 
   {Hue[1.1668260021514532], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 
       1.5308481540548229}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, 
       1.389101261457407}}]}, {Hue[1.262875353938755], 
    Polygon[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + \
((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}, 
      {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, \
1.6132809148526008}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
       1.4898021598760776}}]}, {Hue[1.373371129380275], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}, 
      {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}, 
      {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, \
1.6132809148526008}}]}, 
   {Hue[1.4908450022416582], Polygon[{{(11*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 1.9398272078772507}, 
      {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-1/16, 1.7488835724541527}}]}, 
   {Hue[1.6091821267556563], Polygon[{{(5*(5 - Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
      {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
       1.8877889819588956}}]}, {Hue[1.7235289809279595], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}, 
      {-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}, {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, 
       2.0231783980979903}}]}, {Hue[1.830061520778088], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}, 
      {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, 
       2.149982831518159}}]}, {Hue[1.9257651836591856], Polygon[{{(5 - \
Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 
       2.504820390287959}, {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, \
2.6106791787633683}, {5/16, 2.3642850399222173}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}}]}, 
   {Hue[2.008267490854751], Polygon[{{(17*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 2.6106791787633683}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, 
      {-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, \
2.4474780907945566}, {5/16, 2.3642850399222173}}]}, 
   {Hue[2.0757216825378677], Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 
       2.6979339589171736}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, 
       2.4474780907945566}}]}, {Hue[2.126729341791054], 
    Polygon[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + \
(5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}, 
      {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}}]}, {Hue[2.1602904039830624], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + \
((5 - Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}, 
      {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}, 
      {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, 
       2.5601613609103286}}]}, {Hue[2.175771972083489], 
    Polygon[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + \
((5 - Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}, 
      {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {1/2, \
2.598076211353316}, 
      {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}}]}, 
   {Hue[1.8679881192679393], Polygon[{{1/2, 2.598076211353316}, {-3/4 + \
(5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 2.220880340843795}, 
      {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}}]}, \
{Hue[1.8506953391549752], 
    Polygon[{{-3/4 + (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, \
{-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 2.1953185530328256}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 2.220880340843795}}]}, 
   {Hue[1.818754239640532], Polygon[{{-3/4 + (5*Cos[Pi/15]^2)/4 + \
Sin[Pi/15]^2/2, 2.5601613609103286}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + 
        (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 2.1953185530328256}}]}, \
{Hue[1.7728185185716392], 
    Polygon[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, 
       2.447478090794556}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, \
2.0946793219544753}, 
      {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}}]}, 
   {Hue[1.713867089316295], Polygon[{{-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + \
Sin[(2*Pi)/15]^2/2, 2.447478090794556}, {5/16, 2.3642850399222173}, 
      {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.0946793219544753}}]}, \
{Hue[1.6432341795295382], 
    Polygon[{{5/16, 2.3642850399222173}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + \
Sqrt[5])^2)/64, 2.264540963292246}, 
      {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
      {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}}]}, \
{Hue[1.5626559497046293], 
    Polygon[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, 
       2.1499828315181597}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.8336364565828083}, {-Cos[(13*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 
       1.9334320944111905}}]}, {Hue[1.4743393872630854], Polygon[{{-3/4 + \
(5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, 2.1499828315181597}, 
      {-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 2.02317839809799}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.724112283936149}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828083}}]}, \
{Hue[1.3810592258556948], 
    Polygon[{{-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, \
2.02317839809799}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
       1.8877889819588956}, {-Cos[(13*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
       1.6081701375219564}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
       1.724112283936149}}]}, {Hue[1.2862836944101006], Polygon[{{-3/4 + \
(5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, 
      {-1/16, 1.7488835724541527}, {-Cos[(13*Pi)/15]^2 + \
(11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, 
      {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}}]}, 
   {Hue[1.1943116082576908], Polygon[{{-1/16, 1.7488835724541527}, {-3/4 + \
(5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, 1.6132809148526017}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.375975067210655}, 
      {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}}]}, \

   {Hue[1.1103564802286106], Polygon[{{-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + \
Sin[(11*Pi)/30]^2/2, 1.6132809148526017}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + 
        ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.375975067210655}}]}, \
{Hue[1.0404257699581023], 
    Polygon[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, 
       1.389101261457407}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.1890852819516715}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.2727298803122145}}]}, {Hue[0.9907551687465268], Polygon[{{-3/4 + \
(5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, 1.389101261457407}, 
      {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, \
1.3224570770546993}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.1890852819516715}}]}, \
{Hue[0.9666406394290289], 
    Polygon[{{-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, \
1.3224570770546993}, {-1/4, 1.299038105676658}, 
      {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}}]}, \
{Hue[0.9709564244343211], 
    Polygon[{{-1/4, 1.299038105676658}, {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + \
Sin[(8*Pi)/15]^2/2, 1.3224570770546993}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, 
      {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}}]}, \
{Hue[1.0031725281089194], 
    Polygon[{{-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, \
1.3224570770546993}, {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, 
       1.3891012614574068}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.1890852819516715}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
       1.1340136417284854}}]}, {Hue[1.0595521756432598], Polygon[{{-3/4 + \
(5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, 1.3891012614574068}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + 
        ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.1890852819516715}}]}, \
{Hue[1.1343744390625083], 
    Polygon[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, 
       1.6132809148526013}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.3759750672106548}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.2727298803122145}}]}, {Hue[1.2213775321454008], Polygon[{{-3/4 + \
(5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, 1.6132809148526013}, 
      {-1/16, 1.7488835724541527}, {-Cos[(13*Pi)/15]^2 + \
(11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.3759750672106548}}]}, 
   {Hue[1.314749708341348], Polygon[{{-1/16, 1.7488835724541527}, {-3/4 + \
(5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, 
      {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
      {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}}]}, \

   {Hue[1.4095417769346792], Polygon[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + \
Sqrt[5])^2/32, 1.8877889819588956}, 
      {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, \
2.0231783980979894}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.7241122839361485}, 
      {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}}]}, 
   {Hue[1.5017080775429708], Polygon[{{-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + \
Sin[(11*Pi)/15]^2/2, 2.0231783980979894}, 
      {-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, \
2.1499828315181597}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828085}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.7241122839361485}}]}, 
   {Hue[1.5879963585017756], Polygon[{{-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + \
Sin[(23*Pi)/30]^2/2, 2.1499828315181597}, 
      {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + 
        (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828085}}]}, \
{Hue[1.6658101491907882], 
    Polygon[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {5/16, 2.3642850399222173}, 
      {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + 
        (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}}]}, \
{Hue[1.733090808261767], 
    Polygon[{{5/16, 2.3642850399222173}, {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + \
Sin[(13*Pi)/15]^2/2, 2.4474780907945566}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^4, 2.0946793219544757}, 
      {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}}]}, \
{Hue[1.7882292957145098], 
    Polygon[{{-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
       2.1530633066599694}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^4, \
2.0946793219544757}}]}, 
   {Hue[1.8300044430249003], Polygon[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + \
Sqrt[5]))/32, 2.5129980122544064}, 
      {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, \
2.5601613609103286}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.1953185530328256}, 
      {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}}]}, 
   {Hue[1.8575415916729945], Polygon[{{-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + \
Sin[(14*Pi)/15]^2/2, 2.5601613609103286}, 
      {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.220880340843795}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.1953185530328256}}]}, \
{Hue[1.870286144307612], 
    Polygon[{{-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, {1/2, 2.598076211353316}, 
      {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.220880340843795}}]}, \
{Hue[1.8679881192679393], 
    Polygon[{{1/2, 2.598076211353316}, {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + \
Sin[(31*Pi)/30]^2/2, 2.588583579753018}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.220880340843795}, 
      {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}}]}, \
{Hue[1.8506953391549752], 
    Polygon[{{-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, 
       2.5601613609103286}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(16*Pi)/15]^2, 
       2.1953185530328256}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(31*Pi)/30]^2, 
       2.220880340843795}}]}, {Hue[1.818754239640532], Polygon[{{-3/4 + \
(5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, 2.5601613609103286}, 
      {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + 
        (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.1953185530328256}}]}, \
{Hue[1.7728185185716394], 
    Polygon[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, 
       2.4474780907945566}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       2.0946793219544757}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
       2.1530633066599694}}]}, {Hue[1.713867089316295], Polygon[{{-3/4 + \
(5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, 2.4474780907945566}, 
      {5/16, 2.3642850399222173}, {-Cos[(13*Pi)/15]^2 + \
(17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.0946793219544757}}]}, 
   {Hue[1.6432341795295382], Polygon[{{5/16, 2.3642850399222173}, {-3/4 + (5 \
- Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, 
      {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
      {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}}]}, \
{Hue[1.5626559497046293], 
    Polygon[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, 
       2.1499828315181597}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
       1.8336364565828083}, {-Cos[(13*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 
       1.9334320944111905}}]}, {Hue[1.4743393872630854], Polygon[{{-3/4 + \
(5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, 2.1499828315181597}, 
      {-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, \
2.0231783980979903}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361493}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828083}}]}, 
   {Hue[1.381059225855695], Polygon[{{-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + \
Sin[(19*Pi)/15]^2/2, 2.0231783980979903}, 
      {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361493}}]}, \
{Hue[1.2862836944101006], 
    Polygon[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-1/16, 1.7488835724541527}, 
      {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}}]}, \
{Hue[1.1943116082576906], 
    Polygon[{{-1/16, 1.7488835724541527}, {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + \
Sin[(41*Pi)/30]^2/2, 1.6132809148526013}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.3759750672106548}, 
      {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}}]}, \

   {Hue[1.1103564802286106], Polygon[{{-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + \
Sin[(41*Pi)/30]^2/2, 1.6132809148526013}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + 
        ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.3759750672106548}}]}, \
{Hue[1.0404257699581025], 
    Polygon[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, 
       1.3891012614574074}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
       1.189085281951672}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.2727298803122145}}]}, {Hue[0.9907551687465271], Polygon[{{-3/4 + \
(5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, 1.3891012614574074}, 
      {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284856}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.189085281951672}}]}, 
   {Hue[0.9666406394290289], Polygon[{{-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + \
Sin[(22*Pi)/15]^2/2, 1.3224570770546997}, {-1/4, 1.299038105676658}, 
      {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284856}}]}, \
{Hue[0.9709564244343211], 
    Polygon[{{-1/4, 1.299038105676658}, {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + \
Sin[(23*Pi)/15]^2/2, 1.3224570770546995}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284854}, 
      {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}}]}, \
{Hue[1.0031725281089192], 
    Polygon[{{-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, \
1.3224570770546995}, {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, 
       1.389101261457407}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
       1.1890852819516715}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(23*Pi)/15]^2, 
       1.1340136417284854}}]}, {Hue[1.0595521756432598], Polygon[{{-3/4 + \
(5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, 1.389101261457407}, 
      {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + 
        ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.1890852819516715}}]}, \
{Hue[1.1343744390625081], 
    Polygon[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, 
       1.6132809148526008}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.3759750672106543}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.2727298803122145}}]}, {Hue[1.2213775321454008], Polygon[{{-3/4 + \
(5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, 1.6132809148526008}, 
      {-1/16, 1.7488835724541527}, {-Cos[(13*Pi)/15]^2 + \
(11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106543}}]}, 
   {Hue[1.314749708341348], Polygon[{{-1/16, 1.7488835724541527}, {-3/4 + \
(5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, 
      {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
      {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}}]}, \

   {Hue[1.4095417769346796], Polygon[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + \
Sqrt[5])^2/32, 1.8877889819588956}, 
      {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, \
2.0231783980979903}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361493}, 
      {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}}]}, 
   {Hue[1.5017080775429703], Polygon[{{-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + \
Sin[(26*Pi)/15]^2/2, 2.0231783980979903}, 
      {-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.8336364565828074}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361493}}]}, \
{Hue[1.5879963585017753], 
    Polygon[{{-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
       2.264540963292246}, {-Cos[(13*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 
       1.9334320944111905}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
       1.8336364565828074}}]}, {Hue[1.6658101491907882], Polygon[{{-3/4 + (5 \
- Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, 
      {5/16, 2.3642850399222173}, {-Cos[(13*Pi)/15]^2 + \
(17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, 
      {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}}]}, 
   {Hue[1.733090808261767], Polygon[{{5/16, 2.3642850399222173}, {-3/4 + \
(5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, 2.4474780907945566}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.0946793219544757}, 
      {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}}]}, \
{Hue[1.7882292957145098], 
    Polygon[{{-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
       2.5129980122544064}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
       2.1530633066599694}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(28*Pi)/15]^2, 
       2.0946793219544757}}]}, {Hue[1.8300044430249003], Polygon[{{-3/4 + (-1 \
+ Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, 
      {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, \
2.5601613609103286}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.195318553032825}, 
      {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}}]}, 
   {Hue[1.8575415916729945], Polygon[{{-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + \
Sin[(29*Pi)/15]^2/2, 2.5601613609103286}, 
      {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.220880340843795}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.195318553032825}}]}, \
{Hue[1.870286144307612], 
    Polygon[{{-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, {1/2, 2.598076211353316}, 
      {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.220880340843795}}]}, \
{Hue[1.5557507182301678], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/15]^2 + 
        2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 2.220880340843795}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + 
        ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}}]}, 
   {Hue[1.5426240540096567], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[Pi/30]^2*Sin[(13*Pi)/15]^2 + 2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 
       2.220880340843795}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[Pi/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, \
2.1953185530328256}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}}]}, 
   {Hue[1.5183459853464474], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[Pi/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 
       2.1953185530328256}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
       2.1530633066599694}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}}]}, 
   {Hue[1.483464116829665], Polygon[{{-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
       2.1530633066599694}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
       2.0946793219544753}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
       1.6537682358032735}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}}]}, 
   {Hue[1.4387981474074434], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
       2.0946793219544753}, {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, \
2.021043485921703}, {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 
       1.5943005668830776}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
       1.6537682358032735}}]}, {Hue[1.3854622138882695], \
Polygon[{{-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, 
      {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}]}, \
{Hue[1.3248976948729934], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828083}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}]}, 
   {Hue[1.2589182215315744], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.8336364565828083}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, \
1.724112283936149}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}}]}, 
   {Hue[1.1897665424371353], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
       1.724112283936149}, {-Cos[(13*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
       1.6081701375219564}, {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
       1.3571288512592454}}]}, {Hue[1.1201763684222978], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
      {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}]}, 
   {Hue[1.0534169651842968], Polygon[{{-Cos[(13*Pi)/15]^2 + \
(11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.375975067210655}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, 
      {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}]}, \
{Hue[0.9932694398648354], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.375975067210655}, 
      {-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}}]}, 
   {Hue[0.9438462158088111], Polygon[{{-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.2727298803122145}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.1890852819516715}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       0.9389137397717193}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}}]}, 
   {Hue[0.9091560683795868], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.1890852819516715}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
       1.1340136417284854}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       0.8965062230902947}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       0.9389137397717193}}]}, {Hue[0.892411784625235], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, 
      {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, {(-5 - \
Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}}]}, 
   {Hue[0.8952900601168499], Polygon[{{-Cos[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2, 1.114717238216091}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}}]}, \
{Hue[0.9174931058826711], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.1890852819516715}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}}]}, 
   {Hue[0.9568352042133021], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.1890852819516715}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.2727298803122145}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}}]}, 
   {Hue[1.0098006572519989], Polygon[{{-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.2727298803122145}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.3759750672106548}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.0837396094369778}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}}]}, 
   {Hue[1.0722936663251332], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.3759750672106548}, {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, \
1.4902097135042385}, {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 
       1.1729281630054869}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.0837396094369778}}]}, {Hue[1.1402641452027922], \
Polygon[{{-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \

      {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}]}, \
{Hue[1.2100647790952233], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.7241122839361485}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}]}, 
   {Hue[1.2785782400117465], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
       1.7241122839361485}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
       1.8336364565828085}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       1.4441489417584883}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 
       1.357128851259245}}]}, {Hue[1.3432149733623238], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828085}, 
      {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}}]}, 
   {Hue[1.4018602526048467], Polygon[{{-Cos[(13*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 
       1.9334320944111905}, {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, \
2.021043485921703}, {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 
       1.5943005668830776}, {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/64 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 
       1.5239001577085332}}]}, {Hue[1.4528123828148776], \
Polygon[{{-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^4, 2.0946793219544757}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, 
      {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}]}, \
{Hue[1.4947288740848965], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^4, 2.0946793219544757}, 
      {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}}]}, 
   {Hue[1.526584945614504], Polygon[{{-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
       2.1530633066599694}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       2.1953185530328256}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       1.7355139912456734}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}}]}, 
   {Hue[1.5476437851977167], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       2.1953185530328256}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       2.220880340843795}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       1.7563683493937294}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       1.7355139912456734}}]}, {Hue[1.5574366185188362], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.220880340843795}, 
      {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}}]}, 
   {Hue[1.5557507182301678], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Sin[(13*Pi)/15]^2, 2.229434476432182}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.220880340843795}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}}]}, \
{Hue[1.5426240540096567], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.220880340843795}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.1953185530328256}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}}]}, 
   {Hue[1.5183459853464474], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(16*Pi)/15]^2, 
       2.1953185530328256}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
       2.1530633066599694}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}}]}, 
   {Hue[1.4834641168296652], Polygon[{{-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
       2.1530633066599694}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       2.0946793219544757}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 
       1.653768235803274}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}}]}, 
   {Hue[1.4387981474074434], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       2.0946793219544757}, {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, \
2.021043485921703}, {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 
       1.5943005668830776}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 
       1.653768235803274}}]}, {Hue[1.3854622138882695], \
Polygon[{{-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, 
      {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}]}, \
{Hue[1.3248976948729934], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828083}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}]}, 
   {Hue[1.2589182215315744], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
       1.8336364565828083}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
       1.7241122839361493}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 
       1.3571288512592459}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 
       1.4441489417584883}}]}, {Hue[1.1897665424371355], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361493}, 
      {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}}]}, 
   {Hue[1.1201763684222978], Polygon[{{-Cos[(13*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
       1.6081701375219564}, {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, \
1.4902097135042385}, {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 
       1.1729281630054869}, {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}}]}, {Hue[1.0534169651842968], \
Polygon[{{-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \

      {-Cos[(13*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.3759750672106548}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, 
      {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}]}, \
{Hue[0.9932694398648354], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.3759750672106548}, 
      {-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}}]}, 
   {Hue[0.9438462158088112], Polygon[{{-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.2727298803122145}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
       1.189085281951672}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 
       0.9389137397717198}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}}]}, 
   {Hue[0.909156068379587], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
       1.189085281951672}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       1.1340136417284856}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 
       0.896506223090295}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 
       0.9389137397717198}}]}, {Hue[0.8924117846252351], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284856}, 
      {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, {(-5 - \
Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}}]}, 
   {Hue[0.8952900601168499], Polygon[{{-Cos[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2, 1.114717238216091}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284854}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}}]}, \
{Hue[0.9174931058826712], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284854}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.1890852819516715}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}}]}, 
   {Hue[0.9568352042133021], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
       1.1890852819516715}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.2727298803122145}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}}]}, 
   {Hue[1.0098006572519986], Polygon[{{-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
       1.2727298803122145}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.3759750672106543}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 
       1.0837396094369776}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}}]}, 
   {Hue[1.0722936663251332], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       1.3759750672106543}, {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, \
1.4902097135042385}, {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 
       1.1729281630054869}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 
       1.0837396094369776}}]}, {Hue[1.1402641452027922], \
Polygon[{{-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \

      {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}]}, \
{Hue[1.2100647790952237], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361493}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}]}, 
   {Hue[1.2785782400117462], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
       1.7241122839361493}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
       1.8336364565828074}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 
       1.4441489417584876}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 
       1.3571288512592459}}]}, {Hue[1.3432149733623233], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.8336364565828074}, 
      {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}}]}, 
   {Hue[1.4018602526048467], Polygon[{{-Cos[(13*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 
       1.9334320944111905}, {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, \
2.021043485921703}, {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 
       1.5943005668830776}, {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/64 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 
       1.5239001577085332}}]}, {Hue[1.4528123828148776], \
Polygon[{{-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, 
      {-Cos[(13*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.0946793219544757}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, 
      {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}]}, \
{Hue[1.4947288740848965], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.0946793219544757}, 
      {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}}]}, 
   {Hue[1.526584945614504], Polygon[{{-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
       2.1530633066599694}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
       2.195318553032825}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 
       1.7355139912456732}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}}]}, 
   {Hue[1.5476437851977167], Polygon[{{-Cos[(13*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
       2.195318553032825}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       2.220880340843795}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 
       1.7563683493937294}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 
       1.7355139912456732}}]}, {Hue[1.5574366185188362], 
    Polygon[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.220880340843795}, 
      {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}}]}, 
   {Hue[1.2494480904919072], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2)/16, 1.7633557568774196}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 1.2152748245287444}, 
      {-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}}]}, \
{Hue[1.2407150447905448], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 1.2152748245287444}}]}, 
   {Hue[1.224528799876307], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, 
       1.7355139912456734}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, 
      {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}}]}, 
   {Hue[1.2013141437186707], Polygon[{{(-5 - Sqrt[5])/8 + (-1 + \
Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, \

      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, 
      {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}}]}, 
   {Hue[1.1717041272345776], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
       1.6537682358032735}, {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, \
1.5943005668830776}, {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 
       1.1013148858947206}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       1.143020501605284}}]}, {Hue[1.1365513044182407], Polygon[{{(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
      {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}}]}, \

   {Hue[1.0969422723069358], Polygon[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 \
+ Sqrt[5])^2)/64 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 
       1.5239001577085332}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 
       1.4441489417584883}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.9965396214846546}, {-Cos[(14*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 
       1.0520980143876293}}]}, {Hue[1.054213978628462], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071271}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846546}}]}, 
   {Hue[1.00996778569236], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
       1.3571288512592454}, {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}, {-Cos[(14*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       0.8728320775698118}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       0.9361441841071271}}]}, {Hue[0.9660726724111424], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + \
((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
      {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}}]}, 
   {Hue[0.9246416897154036], Polygon[{{(-5 - Sqrt[5])/8 + (11*(-1 + \
Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640108}, 
      {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}}]}, \

   {Hue[0.8879572012051125], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 
       1.083739609436978}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640108}}]}, 
   {Hue[0.8583171958600148], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
      {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}}]}, 
   {Hue[0.8377918479221859], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
       0.9389137397717193}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
       0.8965062230902947}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       0.6201700772082609}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.6489952411032603}}]}, {Hue[0.827928804092991], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, \
{-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082609}}]}, 
   {Hue[0.8295004609584335], Polygon[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, \
0.8816778784387096}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082606}, 
      {-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}}]}, \
{Hue[0.8423787750684033], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082606}}]}, 
   {Hue[0.8655602548112958], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
       0.9389137397717193}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}}]}, 
   {Hue[0.8973312027049051], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640107}, 
      {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}}]}, 
   {Hue[0.9355358127211648], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
       1.0837396094369778}, {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, \
1.1729281630054869}, {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 
       0.8090441125945327}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.7478557941640107}}]}, {Hue[0.9778611811204214], Polygon[{{(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
      {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}}]}, \

   {Hue[1.0220583162871242], Polygon[{{(-5 - Sqrt[5])/8 + (5*(5 - \
Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 
       1.357128851259245}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       0.9361441841071267}, {-Cos[(14*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       0.8728320775698118}}]}, {Hue[1.0660736562881798], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846544}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071267}}]}, 
   {Hue[1.108108092626211], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
       1.4441489417584883}, {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/64 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 
       1.5239001577085332}, {-Cos[(14*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 
       1.0520980143876293}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.9965396214846544}}]}, {Hue[1.1466315881244185], 
    Polygon[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 \
+ Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
      {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}}]}, 
   {Hue[1.1803759206354025], Polygon[{{(-5 - Sqrt[5])/8 + (17*(-1 + \
Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, 
      {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}}]}, \

   {Hue[1.2083193915192814], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
       1.6537682358032735}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, 
      {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}}]}, 
   {Hue[1.2296706795254004], Polygon[{{(-5 - Sqrt[5])/8 + (-1 + \
Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, \

      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^4, 1.2005567894684717}, 
      {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}}]}, 
   {Hue[1.2438550227971525], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       1.7355139912456734}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       1.7563683493937294}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       1.2152748245287444}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^4, \
1.2005567894684717}}]}, 
   {Hue[1.2505038519141247], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       1.7563683493937294}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, \
1.7633557568774196}, {-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 
       1.2202099292274005}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       1.2152748245287444}}]}, {Hue[1.2494480904919072], Polygon[{{(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, 
      {-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}}]}, \
{Hue[1.2407150447905448], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}}]}, 
   {Hue[1.224528799876307], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 
       1.7355139912456734}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, 
      {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}}]}, 
   {Hue[1.2013141437186705], Polygon[{{(-5 - Sqrt[5])/8 + (-1 + \
Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, \

      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
      {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}}]}, 
   {Hue[1.1717041272345778], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 
       1.653768235803274}, {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, \
1.5943005668830776}, {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 
       1.1013148858947206}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       1.1430205016052841}}]}, {Hue[1.1365513044182407], Polygon[{{(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
      {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}}]}, \

   {Hue[1.0969422723069358], Polygon[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 \
+ Sqrt[5])^2)/64 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 
       1.5239001577085332}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 
       1.4441489417584883}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
       0.9965396214846546}, {-Cos[(14*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 
       1.0520980143876293}}]}, {Hue[1.054213978628462], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}}]}, 
   {Hue[1.00996778569236], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 
       1.3571288512592459}, {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}, {-Cos[(14*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       0.8728320775698118}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
       0.9361441841071272}}]}, {Hue[0.9660726724111424], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + \
((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
      {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}}]}, 
   {Hue[0.9246416897154035], Polygon[{{(-5 - Sqrt[5])/8 + (11*(-1 + \
Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, 
      {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}}]}, \

   {Hue[0.8879572012051125], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 
       1.0837396094369778}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}}]}, 
   {Hue[0.8583171958600149], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
      {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}}]}, 
   {Hue[0.837791847922186], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 
       0.9389137397717198}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 
       0.896506223090295}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       0.6201700772082609}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
       0.6489952411032606}}]}, {Hue[0.8279288040929911], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}, 
      {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, \
{-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}}]}, 
   {Hue[0.8295004609584337], Polygon[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, \
0.8816778784387096}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, 
      {-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}}]}, \
{Hue[0.8423787750684033], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}}]}, 
   {Hue[0.8655602548112958], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 
       0.9389137397717195}, {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + \
((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}}]}, 
   {Hue[0.8973312027049051], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.0035621274868154}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
      {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}}]}, 
   {Hue[0.9355358127211646], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 
       1.0837396094369776}, {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, \
1.1729281630054869}, {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 
       0.8090441125945327}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       0.7478557941640104}}]}, {Hue[0.9778611811204214], Polygon[{{(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
      {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
      {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
      {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}}]}, \

   {Hue[1.0220583162871246], Polygon[{{(-5 - Sqrt[5])/8 + (5*(5 - \
Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 
       1.2655525104241707}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 
       1.3571288512592459}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
       0.9361441841071272}, {-Cos[(14*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       0.8728320775698118}}]}, {Hue[1.06607365628818], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}}]}, 
   {Hue[1.108108092626211], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 
       1.4441489417584876}, {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + \
Sqrt[5])^2)/64 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 
       1.5239001577085332}, {-Cos[(14*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 
       1.0520980143876293}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
       0.9965396214846538}}]}, {Hue[1.1466315881244185], 
    Polygon[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 \
+ Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
      {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
      {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}}]}, 
   {Hue[1.1803759206354025], Polygon[{{(-5 - Sqrt[5])/8 + (17*(-1 + \
Sqrt[5])^2)/64, 1.5943005668830776}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, 
      {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}}]}, \

   {Hue[1.2083193915192814], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 
       1.6537682358032735}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 \
+ Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, 
      {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}}]}, 
   {Hue[1.2296706795254004], Polygon[{{(-5 - Sqrt[5])/8 + (-1 + \
Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.7011229525643674}, \

      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
      {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}}]}, 
   {Hue[1.2438550227971523], Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 
       1.7355139912456732}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 
       1.7563683493937294}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       1.2152748245287444}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
       1.2005567894684717}}]}, {Hue[1.2505038519141247], 
    Polygon[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + \
((-1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}, 
      {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, \
{-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}}]}, 
   {Hue[0.9742779962722735], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 1.2152748245287444}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491779}, 
      {-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}}]}, \
{Hue[0.9699821368554069], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 1.2152748245287444}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491779}}]}, 
   {Hue[0.961973513621909], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[Pi/15]^2*Sin[(14*Pi)/15]^2 + 2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 
       1.2005567894684717}, {-Cos[(14*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 
       1.1763209525760518}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
       0.6010618457721164}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(29*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, \
0.6135770923916904}}]}, 
   {Hue[0.9505141257708084], Polygon[{{-Cos[(14*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 
       1.1763209525760518}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, \
1.143020501605284}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279131}, 
      {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}}]}, 
   {Hue[0.935989289341174], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       1.143020501605284}, {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, \
1.1013148858947206}, {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 
       0.5624063276196133}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.5838857533279131}}]}, {Hue[0.9189061669051399], \
Polygon[{{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \

      {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
      {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, 
      {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}}]}, \

   {Hue[0.8998902542628765], Polygon[{{-Cos[(14*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 
       1.0520980143876293}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.9965396214846546}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, \
0.50859507017628}, 
      {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}}]}, 
   {Hue[0.8796781954889527], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.9965396214846546}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       0.9361441841071271}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.47767060184981125}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       0.50859507017628}}]}, {Hue[0.8591045959305742], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071271}, 
      {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
      {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}}]}, 
   {Hue[0.8390797960636258], Polygon[{{-Cos[(14*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       0.8728320775698118}, {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, \
0.8090441125945327}, {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 
       0.41280605266694914}, {-Cos[(29*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       0.44532374723565715}}]}, {Hue[0.820555168967837], \
Polygon[{{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \

      {-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640108}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, 
      {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}}]}, 
   {Hue[0.8044730521176584], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.7478557941640108}, {-Cos[(14*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       0.6930472461935369}, {-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       0.3538602304100192}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       0.3816816923272197}}]}, {Hue[0.7917011082781473], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}, 
      {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}}]}, 
   {Hue[0.7829573803388594], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.6489952411032603}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       0.6201700772082609}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.31695593148714096}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       0.33154008354139486}}]}, {Hue[0.7787420054402369], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082609}, 
      {-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, \
{-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}}]}, 
   {Hue[0.7792948438851816], Polygon[{{-Cos[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082606}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, 
      {-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}}]}, \
{Hue[0.7845825320489381], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082606}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}}]}, 
   {Hue[0.7943019430083454], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.6489952411032603}, {-Cos[(14*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       0.6930472461935369}, {-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       0.3538602304100192}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       0.33154008354139486}}]}, {Hue[0.8078996167469834], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640107}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, 
      {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}}]}, 
   {Hue[0.8246188489880423], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.7478557941640107}, {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, \
0.8090441125945327}, {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 
       0.41280605266694914}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       0.3816816923272197}}]}, {Hue[0.8435696942738822], \
Polygon[{{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \

      {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
      {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
      {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}}]}, 
   {Hue[0.8638027459021623], Polygon[{{-Cos[(14*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       0.8728320775698118}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       0.9361441841071267}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.47767060184981125}, {-Cos[(29*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       0.44532374723565715}}]}, {Hue[0.8843719148353492], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071267}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846544}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.5085950701762803}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}}]}, 
   {Hue[0.9043811933167686], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
       0.9965396214846544}, {-Cos[(14*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 
       1.0520980143876293}, {-Cos[(29*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 
       0.5371028573756126}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       0.5085950701762803}}]}, {Hue[0.9230164017047113], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
      {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
      {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}}]}, 
   {Hue[0.9395651302812518], Polygon[{{-Cos[(14*Pi)/15]^2 + \
(17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279134}, 
      {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}}]}, \

   {Hue[0.9534283328642148], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
       1.143020501605284}, {-Cos[(14*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 
       1.1763209525760518}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
       0.6010618457721164}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.5838857533279134}}]}, {Hue[0.9641264893155267], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^4, 1.2005567894684717}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}, 
      {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}}]}, 
   {Hue[0.9713025124696918], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^4, \
1.2005567894684717}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^4, 0.6211835161491779}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}}]}, 
   {Hue[0.9747228887795004], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       1.2152748245287444}, {-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, \
1.2202099292274005}, {-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 
       0.6237350724532796}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^4, \
0.6211835161491779}}]}, 
   {Hue[0.9742779962722735], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491779}, 
      {-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}}]}, \
{Hue[0.9699821368554069], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(16*Pi)/15]^2, 0.6135770923916904}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491779}}]}, 
   {Hue[0.961973513621909], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(16*Pi)/15]^2, 
       1.2005567894684717}, {-Cos[(14*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 
       1.1763209525760518}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
       0.6010618457721164}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       0.6135770923916904}}]}, {Hue[0.9505141257708084], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279135}, 
      {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}}]}, 
   {Hue[0.9359892893411741], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
       1.1430205016052841}, {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, \
1.1013148858947206}, {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 
       0.5624063276196133}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
       0.5838857533279135}}]}, {Hue[0.9189061669051399], \
Polygon[{{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \

      {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
      {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, 
      {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}}]}, \

   {Hue[0.8998902542628765], Polygon[{{-Cos[(14*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 
       1.0520980143876293}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
       0.9965396214846546}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       0.50859507017628}, {-Cos[(29*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 
       0.5371028573756126}}]}, {Hue[0.8796781954889527], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498115}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(37*Pi)/30]^2, 0.50859507017628}}]}, 
   {Hue[0.8591045959305742], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
       0.9361441841071272}, {-Cos[(14*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       0.8728320775698118}, {-Cos[(29*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       0.44532374723565715}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       0.4776706018498115}}]}, {Hue[0.8390797960636258], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + \
((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
      {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
      {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}}]}, 
   {Hue[0.8205551689678369], Polygon[{{-Cos[(14*Pi)/15]^2 + \
(11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272197}, 
      {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}}]}, 
   {Hue[0.8044730521176584], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(41*Pi)/30]^2, 
       0.7478557941640107}, {-Cos[(14*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       0.6930472461935369}, {-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       0.3538602304100192}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(41*Pi)/30]^2, 
       0.3816816923272197}}]}, {Hue[0.7917011082781473], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139486}, 
      {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}}]}, 
   {Hue[0.7829573803388594], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
       0.6489952411032606}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
       0.6201700772082609}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
       0.31695593148714163}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       0.33154008354139486}}]}, {Hue[0.7787420054402369], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
      {-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, \
{-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714163}}]}, 
   {Hue[0.7792948438851817], Polygon[{{-Cos[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714163}, 
      {-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}}]}, \
{Hue[0.7845825320489384], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.33154008354139486}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714163}}]}, 
   {Hue[0.7943019430083456], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
       0.6489952411032603}, {-Cos[(14*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
       0.6930472461935369}, {-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       0.3538602304100192}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       0.33154008354139486}}]}, {Hue[0.8078996167469832], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721944}, 
      {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}}]}, 
   {Hue[0.824618848988042], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
       0.7478557941640104}, {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, \
0.8090441125945327}, {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 
       0.41280605266694914}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
       0.38168169232721944}}]}, {Hue[0.8435696942738822], \
Polygon[{{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \

      {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
      {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
      {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}}]}, 
   {Hue[0.8638027459021625], Polygon[{{-Cos[(14*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
       0.8728320775698118}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
       0.9361441841071272}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       0.4776706018498115}, {-Cos[(29*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
       0.44532374723565715}}]}, {Hue[0.8843719148353494], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(53*Pi)/30]^2, 0.50859507017628}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498115}}]}, 
   {Hue[0.9043811933167686], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
       0.9965396214846538}, {-Cos[(14*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 
       1.0520980143876293}, {-Cos[(29*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 
       0.5371028573756126}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       0.50859507017628}}]}, {Hue[0.9230164017047113], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
      {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
      {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}}]}, 
   {Hue[0.9395651302812518], Polygon[{{-Cos[(14*Pi)/15]^2 + \
(17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279134}, 
      {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}}]}, \

   {Hue[0.9534283328642148], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(28*Pi)/15]^2, 
       1.143020501605284}, {-Cos[(14*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 
       1.1763209525760518}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
       0.6010618457721164}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(28*Pi)/15]^2, 
       0.5838857533279134}}]}, {Hue[0.9641264893155267], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
      {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916908}, 
      {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}}]}, 
   {Hue[0.9713025124696918], Polygon[{{-Cos[(14*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
       1.2005567894684717}, {-Cos[(14*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
       1.2152748245287444}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
       0.6211835161491779}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       0.6135770923916908}}]}, {Hue[0.9747228887795004], 
    Polygon[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
      {-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, \
{-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491779}}]}, 
   {Hue[0.78191999225832], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491779}, {-1, 0}, {-1, 0}}]}, 
   {Hue[0.7812380597524521], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[Pi/30]^2*Sin[(29*Pi)/30]^2 + 2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 
       0.6211835161491779}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(29*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, \
0.6135770923916904}, 
      {-1, 0}, {-1, 0}}]}, {Hue[0.7799023465584685], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}, 
      {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7779682093582194], Polygon[{{-Cos[(29*Pi)/30]^2 + \
((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + 
        (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279131}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7755163165875046], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.5838857533279131}, {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, \
0.5624063276196133}, {-1, 0}, {-1, 0}}]}, 
   {Hue[0.7726498149698404], Polygon[{{-Cos[(29*Pi)/30]^2 + \
(17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
      {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7694905743784063], Polygon[{{-Cos[(29*Pi)/30]^2 + \
((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + 
        (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.50859507017628}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7661745527514453], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       0.50859507017628}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, \
0.47767060184981125}, 
      {-1, 0}, {-1, 0}}]}, {Hue[0.7628463554203855], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}, 
      {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7596531004172754], Polygon[{{-Cos[(29*Pi)/30]^2 + \
(5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
      {-1, 0}, {-1, 0}}]}, {Hue[0.7567377352052338], \
Polygon[{{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7542319873943025], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, \
{-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + 
        ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7522492506142925], Polygon[{{-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       0.3538602304100192}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       0.33154008354139486}, {-1, 0}, {-1, 0}}]}, {Hue[0.750878114288136], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7501779674745798], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, \
{-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7501779674745798], Polygon[{{-Cos[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7508781142881359], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7522492506142925], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       0.33154008354139486}, {-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       0.3538602304100192}, {-1, 0}, {-1, 0}}]}, {Hue[0.7542319873943025], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7567377352052338], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, {-1, \
0}, 
      {-1, 0}}]}, {Hue[0.7596531004172754], Polygon[{{-Cos[(29*Pi)/30]^2 + \
(11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
      {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7628463554203855], Polygon[{{-Cos[(29*Pi)/30]^2 + \
(5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7661745527514453], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.47767060184981125}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
       0.5085950701762803}, {-1, 0}, {-1, 0}}]}, {Hue[0.7694905743784063], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.5085950701762803}, 
      {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7726498149698404], Polygon[{{-Cos[(29*Pi)/30]^2 + \
((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + 
        (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
      {-1, 0}, {-1, 0}}]}, {Hue[0.7755163165875048], \
Polygon[{{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, \

      {-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279134}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7779682093582194], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279134}, \
{-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + 
        (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7799023465584685], Polygon[{{-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
       0.6010618457721164}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
       0.6135770923916904}, {-1, 0}, {-1, 0}}]}, {Hue[0.7812380597524521], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^4, 0.6211835161491779}, {-1, 0}, {-1, 0}}]}, 
   {Hue[0.78191999225832], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^4, \
0.6211835161491779}, 
      {-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, {-1, \
0}, {-1, 0}}]}, 
   {Hue[0.78191999225832], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491779}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7812380597524521], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491779}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(16*Pi)/15]^2, 0.6135770923916904}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7799023465584685], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
       0.6135770923916904}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
       0.6010618457721164}, {-1, 0}, {-1, 0}}]}, {Hue[0.7779682093582194], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + \
(5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279135}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7755163165875048], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279135}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, {-1, 0}, \

      {-1, 0}}]}, {Hue[0.7726498149698404], Polygon[{{-Cos[(29*Pi)/30]^2 + \
(17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
      {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7694905743784063], Polygon[{{-Cos[(29*Pi)/30]^2 + \
((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + 
        (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(37*Pi)/30]^2, 0.50859507017628}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7661745527514453], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
       0.50859507017628}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
       0.4776706018498115}, {-1, 0}, {-1, 0}}]}, {Hue[0.7628463554203855], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498115}, 
      {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7596531004172754], Polygon[{{-Cos[(29*Pi)/30]^2 + \
(5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
      {-1, 0}, {-1, 0}}]}, {Hue[0.7567377352052338], \
Polygon[{{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272197}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7542319873943025], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272197}, \
{-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + 
        ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7522492506142926], Polygon[{{-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       0.3538602304100192}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
       0.33154008354139486}, {-1, 0}, {-1, 0}}]}, {Hue[0.750878114288136], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139486}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714163}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7501779674745798], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714163}, \
{-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7501779674745798], Polygon[{{-Cos[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714163}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.750878114288136], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714163}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.33154008354139486}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7522492506142926], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
       0.33154008354139486}, {-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
       0.3538602304100192}, {-1, 0}, {-1, 0}}]}, {Hue[0.7542319873943025], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 \
+ ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721944}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7567377352052337], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721944}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
      {-1, 0}, {-1, 0}}]}, {Hue[0.7596531004172754], \
Polygon[{{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}, 
      {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7628463554203855], Polygon[{{-Cos[(29*Pi)/30]^2 + \
(5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + 
        ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498115}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7661745527514453], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
       0.4776706018498115}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
       0.50859507017628}, {-1, 0}, {-1, 0}}]}, {Hue[0.7694905743784063], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(53*Pi)/30]^2, 0.50859507017628}, 
      {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7726498149698404], Polygon[{{-Cos[(29*Pi)/30]^2 + \
((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + 
        (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
      {-1, 0}, {-1, 0}}]}, {Hue[0.7755163165875048], \
Polygon[{{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, \

      {-Cos[(29*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279134}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.7779682093582194], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279134}, \
{-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + 
        (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, {-1, 0}, \
{-1, 0}}]}, 
   {Hue[0.7799023465584685], Polygon[{{-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
       0.6010618457721164}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
       0.6135770923916908}, {-1, 0}, {-1, 0}}]}, {Hue[0.7812380597524521], 
    Polygon[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916908}, 
      {-Cos[(29*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491779}, {-1, 0}, 
      {-1, 0}}]}, {Hue[0.78191999225832], Polygon[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
        2*Sin[(29*Pi)/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491779}, \
{-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, {-1, 0}, 
      {-1, 0}}]}}, {Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + \
5*Cos[Pi/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^4, 0.6211835161491764}, 
     {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, 0.623735072453278}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[Pi/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 0.613577092391689}, 
     {-Cos[Pi/30]^2 + 5*Cos[Pi/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^4, \
0.6211835161491764}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 \
+ (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/30]^2 + 5*Cos[Pi/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 0.613577092391689}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 0.5838857533279119}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}, 
     {-Cos[Pi/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 0.5838857533279119}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 0.508595070176279}, 
     {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 0.4776706018498101}, 
     {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 0.508595070176279}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 \
+ ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
     {-Cos[Pi/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 0.4776706018498101}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}, 
     {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 0.3816816923272188}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, \
0.35386023041001824}, 
     {-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 0.3816816923272188}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.31695593148714024}, 
     {-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 0.33154008354139414}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, \
0.311867536226639}, 
     {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.31695593148714024}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.31695593148714024}, 
     {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.311867536226639}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.31695593148714024}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, \
0.35386023041001824}, 
     {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 0.33154008354139414}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 0.38168169232721855}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}, 
     {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 0.38168169232721855}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 \
+ ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 0.47767060184980986}, 
     {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 0.508595070176279}, 
     {-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 0.47767060184980986}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
     {-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 0.508595070176279}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}, 
     {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 0.5838857533279119}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 \
+ (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 0.5838857533279119}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 0.613577092391689}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491764}, 
     {-Cos[Pi/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 0.613577092391689}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, \
0.623735072453278}, 
     {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491764}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491764}, 
     {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, 0.623735072453278}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(16*Pi)/15]^2, 0.613577092391689}, 
     {-Cos[Pi/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491764}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 \
+ (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(16*Pi)/15]^2, 0.613577092391689}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279119}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}, 
     {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279119}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(37*Pi)/30]^2, 0.508595070176279}, 
     {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498101}, 
     {-Cos[Pi/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(37*Pi)/30]^2, 0.508595070176279}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 \
+ ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
     {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498101}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}, 
     {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272188}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, \
0.35386023041001824}, 
     {-Cos[Pi/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272188}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714096}, 
     {-Cos[Pi/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139414}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, \
0.311867536226639}, 
     {-Cos[Pi/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714096}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714024}, 
     {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.311867536226639}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(47*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714024}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, \
0.35386023041001824}, 
     {-Cos[Pi/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(47*Pi)/30]^2, 0.33154008354139414}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721827}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, \
0.4128060526669481}, 
     {-Cos[Pi/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721827}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 \
+ ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498101}, 
     {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(53*Pi)/30]^2, 0.5085950701762788}, 
     {-Cos[Pi/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498101}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + \
(5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
     {-Cos[Pi/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(53*Pi)/30]^2, 0.5085950701762788}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, \
0.5624063276196118}, 
     {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279119}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 \
+ (5*(5 + Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279119}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916888}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/30]^2 \
+ 2*Sin[Pi/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491764}, 
     {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916888}, {-1, 0}}], 
   Line[{{-1, 0}, {-1, 0}, {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, \
0.623735072453278}, 
     {-Cos[Pi/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491764}, {-1, 0}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, 0.623735072453278}, {-Cos[Pi/30]^2 \
+ 5*Cos[Pi/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^4, 0.6211835161491764}, 
     {-Cos[Pi/15]^2 + 5*Cos[Pi/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 1.2152748245287444}, 
     {-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}, {-Cos[Pi/30]^2 + \
5*Sin[Pi/30]^2, 0.623735072453278}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[Pi/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^4, \
0.6211835161491764}, 
     {-Cos[Pi/30]^2 + 5*Cos[Pi/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 0.613577092391689}, 
     {-Cos[Pi/15]^2 + 5*Cos[Pi/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^4, \
1.2005567894684717}, 
     {-Cos[Pi/15]^2 + 5*Cos[Pi/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 1.2152748245287444}, 
     {-Cos[Pi/30]^2 + 5*Cos[Pi/30]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^4, \
0.6211835161491764}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[Pi/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 0.613577092391689}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/15]^2 + 5*Cos[Pi/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^4, \
1.2005567894684717}, 
     {-Cos[Pi/30]^2 + 5*Cos[Pi/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 0.613577092391689}}], 
   Line[{{-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 0.5838857533279119}, 
     {-Cos[Pi/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 0.5838857533279119}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
     {-Cos[Pi/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[Pi/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 0.5838857533279119}}], 
   Line[{{-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, \
{-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, \
{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}}], 
   Line[{{-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
     {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 0.508595070176279}, 
     {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 0.9965396214846546}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 0.508595070176279}, 
     {-Cos[Pi/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 0.4776706018498101}, 
     {-Cos[Pi/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 0.9361441841071271}, 
     {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 0.9965396214846546}, 
     {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 0.508595070176279}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 0.4776706018498101}, 
     {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {-Cos[Pi/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 0.9361441841071271}, 
     {-Cos[Pi/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 0.4776706018498101}}], 
   Line[{{-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}}], 
   Line[{{-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 0.3816816923272188}, {-Cos[Pi/15]^2 \
+ 5*Cos[(11*Pi)/30]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 0.7478557941640108}, {-Cos[Pi/15]^2 \
+ (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 0.3816816923272188}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 0.7478557941640108}, 
     {-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 0.3816816923272188}}], 
   Line[{{-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
     {-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.31695593148714024}, 
     {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 0.33154008354139414}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.31695593148714024}, 
     {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.311867536226639}, {-Cos[Pi/15]^2 + \
2*Sin[Pi/15]^2, 0.6101049646137003}, 
     {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[Pi/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.31695593148714024}}], 
   Line[{{-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.311867536226639}, {-Cos[Pi/30]^2 \
+ 5*Cos[(8*Pi)/15]^2*Sin[Pi/30]^2 + 2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 
      0.31695593148714024}, {-Cos[Pi/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/15]^2 \
+ 2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.6201700772082606}, 
     {-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}, {-Cos[Pi/30]^2 + \
2*Sin[Pi/30]^2, 0.311867536226639}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.31695593148714024}, 
     {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[Pi/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.6201700772082606}, 
     {-Cos[Pi/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.31695593148714024}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 0.33154008354139414}}], 
   Line[{{-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
     {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 0.38168169232721855}, 
     {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 0.7478557941640107}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 0.38168169232721855}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
     {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 0.7478557941640107}, 
     {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 0.38168169232721855}}], 
   Line[{{-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, {-Cos[Pi/15]^2 \
+ (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, {-Cos[Pi/15]^2 \
+ (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}}], 
   Line[{{-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
     {-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 0.47767060184980986}, 
     {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 0.9361441841071267}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 0.47767060184980986}, 
     {-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 0.508595070176279}, 
     {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 0.9965396214846544}, 
     {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 0.9361441841071267}, 
     {-Cos[Pi/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 0.47767060184980986}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 0.508595070176279}, 
     {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 0.9965396214846544}, 
     {-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 0.508595070176279}}], 
   Line[{{-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}}], 
   Line[{{-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 0.5838857533279119}, {-Cos[Pi/15]^2 \
+ 5*Cos[(13*Pi)/15]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 1.143020501605284}, {-Cos[Pi/15]^2 + \
(17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 0.5838857533279119}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[Pi/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 0.5838857533279119}}], 
   Line[{{-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 0.613577092391689}, 
     {-Cos[Pi/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 0.613577092391689}, 
     {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491764}, 
     {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[Pi/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[Pi/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 0.613577092391689}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491764}, 
     {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, 0.623735072453278}, {-Cos[Pi/15]^2 + \
5*Sin[Pi/15]^2, 1.2202099292274005}, 
     {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491764}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, 0.623735072453278}, {-Cos[Pi/30]^2 \
+ 5*Cos[(31*Pi)/30]^2*Sin[Pi/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491764}, {-Cos[Pi/15]^2 \
+ 5*Cos[(31*Pi)/30]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, {-Cos[Pi/15]^2 \
+ 5*Sin[Pi/15]^2, 1.2202099292274005}, 
     {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, 0.623735072453278}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491764}, 
     {-Cos[Pi/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(16*Pi)/15]^2, 0.613577092391689}, 
     {-Cos[Pi/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[Pi/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[Pi/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491764}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(16*Pi)/15]^2, 0.613577092391689}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[Pi/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(16*Pi)/15]^2, 0.613577092391689}}], 
   Line[{{-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279119}, 
     {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279119}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
     {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
     {-Cos[Pi/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279119}}], 
   Line[{{-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, \
{-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, \
{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}}], 
   Line[{{-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
     {-Cos[Pi/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(37*Pi)/30]^2, 0.508595070176279}, 
     {-Cos[Pi/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(37*Pi)/30]^2, 0.508595070176279}, 
     {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498101}, 
     {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[Pi/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
     {-Cos[Pi/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(37*Pi)/30]^2, 0.508595070176279}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498101}, 
     {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[Pi/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498101}}], 
   Line[{{-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}}], 
   Line[{{-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272188}, {-Cos[Pi/15]^2 \
+ 5*Cos[(41*Pi)/30]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, {-Cos[Pi/15]^2 \
+ (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272188}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, 
     {-Cos[Pi/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272188}}], 
   Line[{{-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
     {-Cos[Pi/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714096}, 
     {-Cos[Pi/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[Pi/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
     {-Cos[Pi/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139414}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714096}, 
     {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.311867536226639}, {-Cos[Pi/15]^2 + \
2*Sin[Pi/15]^2, 0.6101049646137003}, 
     {-Cos[Pi/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[Pi/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714096}}], 
   Line[{{-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.311867536226639}, {-Cos[Pi/30]^2 \
+ 5*Cos[(23*Pi)/15]^2*Sin[Pi/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714024}, {-Cos[Pi/15]^2 \
+ 5*Cos[(23*Pi)/15]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, {-Cos[Pi/15]^2 \
+ 2*Sin[Pi/15]^2, 0.6101049646137003}, 
     {-Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.311867536226639}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714024}, 
     {-Cos[Pi/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(47*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[Pi/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714024}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(47*Pi)/30]^2, 0.33154008354139414}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[Pi/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(47*Pi)/30]^2, 0.33154008354139414}}], 
   Line[{{-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}, 
     {-Cos[Pi/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721827}, 
     {-Cos[Pi/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 0.35386023041001824}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721827}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
     {-Cos[Pi/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
     {-Cos[Pi/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721827}}], 
   Line[{{-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}, \
{-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, {-Cos[Pi/15]^2 \
+ (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, {-Cos[Pi/15]^2 \
+ (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, 
     {-Cos[Pi/30]^2 + (11*Sin[Pi/30]^2)/4, 0.4128060526669481}}], 
   Line[{{-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}, 
     {-Cos[Pi/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498101}, 
     {-Cos[Pi/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {-Cos[Pi/30]^2 + (5*(5 - Sqrt[5])*Sin[Pi/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 0.4453237472356564}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498101}, 
     {-Cos[Pi/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(53*Pi)/30]^2, 0.5085950701762788}, 
     {-Cos[Pi/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
     {-Cos[Pi/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[Pi/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498101}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(53*Pi)/30]^2, 0.5085950701762788}, 
     {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {-Cos[Pi/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
     {-Cos[Pi/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(53*Pi)/30]^2, 0.5085950701762788}}], 
   Line[{{-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {-Cos[Pi/30]^2 + ((5 - Sqrt[5])*Sin[Pi/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/16, 0.5371028573756111}}], 
   Line[{{-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}, \
{-Cos[Pi/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279119}, {-Cos[Pi/15]^2 \
+ 5*Cos[(28*Pi)/15]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, {-Cos[Pi/15]^2 + \
(17*Sin[Pi/15]^2)/4, 1.1013148858947206}, 
     {-Cos[Pi/30]^2 + (17*Sin[Pi/30]^2)/4, 0.5624063276196118}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279119}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[Pi/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279119}}], 
   Line[{{-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}, 
     {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916888}, 
     {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/30]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/30]^2)/8, 0.6010618457721149}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916888}, 
     {-Cos[Pi/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491764}, 
     {-Cos[Pi/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[Pi/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916888}}], 
   Line[{{-Cos[Pi/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491764}, 
     {-Cos[Pi/30]^2 + 5*Sin[Pi/30]^2, 0.623735072453278}, {-Cos[Pi/15]^2 + \
5*Sin[Pi/15]^2, 1.2202099292274005}, 
     {-Cos[Pi/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[Pi/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/30]^2 + \
2*Sin[Pi/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491764}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}, {-Cos[Pi/15]^2 \
+ 5*Cos[Pi/30]^2*Sin[Pi/15]^2 + 2*Sin[Pi/30]^2*Sin[Pi/15]^2, 
      1.2152748245287444}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, \
1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, \
{-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[Pi/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 1.2152748245287444}, 
     {-Cos[Pi/15]^2 + 5*Cos[Pi/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^4, \
1.2005567894684717}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, 
     {-Cos[Pi/15]^2 + 5*Cos[Pi/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/30]^2*Sin[Pi/15]^2, 1.2152748245287444}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[Pi/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^4, \
1.2005567894684717}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
     {-Cos[Pi/15]^2 + 5*Cos[Pi/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^4, \
1.2005567894684717}}], 
   Line[{{-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 1.143020501605284}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
     {-Cos[Pi/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 1.143020501605284}}], 
   Line[{{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, \
{-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, {(-5 - \
Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + 
       (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}}], 
   Line[{{-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 0.9965396214846546}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 0.9965396214846546}, 
     {-Cos[Pi/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 0.9361441841071271}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 0.9965396214846546}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 0.9361441841071271}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
     {-Cos[Pi/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 0.9361441841071271}}], 
   Line[{{-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}}], 
   Line[{{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, \
{-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 0.7478557941640108}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 0.7478557941640108}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, 
     {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 0.7478557941640108}}], 
   Line[{{-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 0.6489952411032603}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.6201700772082609}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
     {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 0.6489952411032603}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}, {(-5 - Sqrt[5])/8 \
+ (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}, 
     {-Cos[Pi/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.6201700772082609}}], 
   Line[{{-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}, {-Cos[Pi/15]^2 \
+ 5*Cos[(8*Pi)/15]^2*Sin[Pi/15]^2 + 2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 
      0.6201700772082606}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 
      0.8965062230902947}, {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, \
0.8816778784387096}, {-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.6201700772082606}, 
     {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 0.6489952411032603}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, 
     {-Cos[Pi/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.6201700772082606}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
     {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 0.6489952411032603}}], 
   Line[{{-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 0.7478557941640107}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 0.7478557941640107}, 
     {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
     {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 0.7478557941640107}}], 
   Line[{{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, \
{-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, {(-5 - \
Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + 
       ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}}], 
   Line[{{-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 0.9361441841071267}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 0.9361441841071267}, 
     {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 0.9965396214846544}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
     {-Cos[Pi/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 0.9361441841071267}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 0.9965396214846544}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 0.9965396214846544}}], 
   Line[{{-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}}], 
   Line[{{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, \
{-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 1.143020501605284}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, 
     {-Cos[Pi/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 1.143020501605284}}], 
   Line[{{-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
     {-Cos[Pi/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}, {(-5 - Sqrt[5])/8 \
+ (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}, 
     {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}, {-Cos[Pi/15]^2 \
+ 5*Cos[(31*Pi)/30]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
     {-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[Pi/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, 
     {-Cos[Pi/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
     {-Cos[Pi/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}}], 
   Line[{{-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
     {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
     {-Cos[Pi/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}}], 
   Line[{{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, \
{-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, {(-5 - \
Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + 
       (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}}], 
   Line[{{-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {-Cos[Pi/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
     {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[Pi/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}, 
     {-Cos[Pi/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}}], 
   Line[{{-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}}], 
   Line[{{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, \
{-Cos[Pi/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, 
     {-Cos[Pi/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}}], 
   Line[{{-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
     {-Cos[Pi/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
     {-Cos[Pi/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}, {(-5 - Sqrt[5])/8 \
+ (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}, 
     {-Cos[Pi/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}}], 
   Line[{{-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}, {-Cos[Pi/15]^2 \
+ 5*Cos[(23*Pi)/15]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, {(-5 - \
Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
     {-Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646137003}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[Pi/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, 
     {-Cos[Pi/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
     {-Cos[Pi/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}}], 
   Line[{{-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}, 
     {-Cos[Pi/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[Pi/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[Pi/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 0.6930472461935369}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
     {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
     {-Cos[Pi/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}}], 
   Line[{{-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}, \
{-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, {(-5 - \
Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + 
       ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {-Cos[Pi/15]^2 + (11*Sin[Pi/15]^2)/4, 0.8090441125945327}}], 
   Line[{{-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}, 
     {-Cos[Pi/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[Pi/15]^2 + (5*(5 - Sqrt[5])*Sin[Pi/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 0.8728320775698118}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[Pi/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
     {-Cos[Pi/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}, 
     {-Cos[Pi/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}}], 
   Line[{{-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}, 
     {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[Pi/15]^2 + ((5 - Sqrt[5])*Sin[Pi/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/16, 1.0520980143876293}}], 
   Line[{{-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}, \
{-Cos[Pi/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {-Cos[Pi/15]^2 + (17*Sin[Pi/15]^2)/4, 1.1013148858947206}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, 
     {-Cos[Pi/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}}], 
   Line[{{-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}, 
     {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[Pi/15]^2 + ((-1 + Sqrt[5])^2*Sin[Pi/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[Pi/15]^2)/8, 1.1763209525760518}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[Pi/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
     {-Cos[Pi/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}}], 
   Line[{{-Cos[Pi/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[Pi/15]^2 + 5*Sin[Pi/15]^2, 1.2202099292274005}, {(-5 - Sqrt[5])/8 \
+ (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}, 
     {-Cos[Pi/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[Pi/15]^2 + \
2*Sin[Pi/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 2.2208803408437956}, \
{-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 2.195318553032826}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 2.2208803408437956}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 2.195318553032826}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^4, 2.0946793219544757}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^4, 2.0946793219544757}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}}], 
   Line[{{(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + 
       (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, \
{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, \
{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}], 
   Line[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 1.8336364565828087}, 
     {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 1.7241122839361493}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 1.8336364565828087}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 1.7241122839361493}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
     {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}], 
   Line[{{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.3759750672106554}, \
{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.3759750672106554}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 \
+ Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.1890852819516717}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.1340136417284856}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.1890852819516717}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, \
{-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.1340136417284856}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.1340136417284856}, \
{-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.1890852819516717}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.1340136417284856}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.1890852819516717}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 \
+ Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.375975067210655}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.375975067210655}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}}], 
   Line[{{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + 
       ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, \
{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, \
{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.724112283936149}, 
     {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.833636456582809}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.724112283936149}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.833636456582809}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}}], 
   Line[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}], 
   Line[{{(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.094679321954476}, \
{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.094679321954476}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.195318553032826}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.2208803408437956}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.195318553032826}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, \
{-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.2208803408437956}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.2208803408437956}, \
{-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.195318553032826}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.2208803408437956}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.195318553032826}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.094679321954476}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.094679321954476}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}}], 
   Line[{{(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + 
       (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, \
{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, \
{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}], 
   Line[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828087}, 
     {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361496}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828087}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361496}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
     {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}], 
   Line[{{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.375975067210655}, \
{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.375975067210655}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 \
+ Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.1890852819516722}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284858}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.1890852819516722}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, \
{-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284858}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284856}, \
{-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.189085281951672}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284856}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.189085281951672}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 \
+ Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106545}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106545}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}}], 
   Line[{{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + 
       ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, \
{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, \
{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361496}, 
     {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.833636456582808}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361496}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.833636456582808}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}}], 
   Line[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}], 
   Line[{{(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.094679321954476}, \
{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.094679321954476}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.1953185530328256}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.2208803408437956}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.1953185530328256}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, \
{-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.2208803408437956}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 2.2208803408437956}, {-3/4 + \
(5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, 
     {1/2, 2.598076211353316}, {-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, \
2.2294344764321825}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 2.2208803408437956}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 2.195318553032826}, 
     {-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, {-3/4 \
+ (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(2*Pi)/15]^2, 2.2208803408437956}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 2.195318553032826}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, \
{-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(2*Pi)/15]^2, 2.195318553032826}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^4, 2.0946793219544757}, 
     {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, 2.447478090794556}, \
{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {-Cos[(2*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 
      2.1530633066599703}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^4, \
2.0946793219544757}, 
     {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, {5/16, \
2.3642850399222173}, 
     {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, 2.447478090794556}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^4, 2.0946793219544757}}], Line[{{-Cos[(2*Pi)/15]^2 + \
(17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{5/16, 2.3642850399222173}, 
     {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 1.8336364565828087}, 
     {-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
      2.264540963292246}, {-Cos[(2*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, \
1.933432094411191}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 1.8336364565828087}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 1.7241122839361493}, 
     {-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 2.02317839809799}, \
{-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, 
      2.1499828315181597}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, \
1.8336364565828087}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 1.7241122839361493}, 
     {-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 
      2.02317839809799}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, \
1.7241122839361493}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
     {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, \
{-1/16, 1.7488835724541527}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}}], \
Line[{{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.3759750672106554}, 
     {-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, \
1.6132809148526017}, {-1/16, 1.7488835724541527}, 
     {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.3759750672106554}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 1.4898021598760776}, \
{-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, 
      1.6132809148526017}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 
      1.3759750672106554}}], Line[{{-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
      1.2727298803122147}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, \
1.1890852819516717}, 
     {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
      1.2727298803122147}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 
      1.1890852819516717}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, \
1.1340136417284856}, 
     {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, \
1.3224570770546993}, {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, 
      1.389101261457407}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, \
1.1890852819516717}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.1340136417284856}, 
     {-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, {-1/4, \
1.299038105676658}, {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, 
      1.3224570770546993}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, \
1.1340136417284856}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.1340136417284856}, {-3/4 + \
(5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, 1.3224570770546993}, 
     {-1/4, 1.299038105676658}, {-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, \
1.1147172382160913}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.1340136417284856}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.1890852819516717}, 
     {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, \
1.3891012614574068}, {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, 
      1.3224570770546993}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, \
1.1340136417284856}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.1890852819516717}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 1.4898021598760776}, \
{-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, 
      1.3891012614574068}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
      1.1890852819516717}}], Line[{{-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
      1.2727298803122147}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, \
1.375975067210655}, 
     {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, \
1.6132809148526013}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
      1.2727298803122147}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
      1.375975067210655}, {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, \
1.4902097135042385}, {-1/16, 1.7488835724541527}, 
     {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, \
1.6132809148526013}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.375975067210655}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, {-3/4 + \
(5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, 
     {-1/16, 1.7488835724541527}, {-Cos[(2*Pi)/15]^2 + \
(11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.724112283936149}, 
     {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, \
2.0231783980979894}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
      1.8877889819588956}, {-Cos[(2*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
      1.6081701375219566}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 
      1.724112283936149}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
1.833636456582809}, 
     {-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, 
      2.0231783980979894}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, \
1.724112283936149}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.833636456582809}, 
     {-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, 
      2.1499828315181597}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, \
1.833636456582809}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, {5/16, \
2.3642850399222173}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}}], \
Line[{{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.094679321954476}, 
     {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, \
2.4474780907945566}, {5/16, 2.3642850399222173}, 
     {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.094679321954476}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, \
{-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, 
      2.4474780907945566}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, \
2.094679321954476}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.195318553032826}, 
     {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {-Cos[(2*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 
      2.1530633066599703}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
      2.195318553032826}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, \
2.2208803408437956}, 
     {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, 
      2.5601613609103286}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, \
2.195318553032826}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.2208803408437956}, 
     {-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, {1/2, \
2.598076211353316}, 
     {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.2208803408437956}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, 2.2294344764321825}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.2208803408437956}, {-3/4 + \
(5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, 2.588583579753018}, 
     {1/2, 2.598076211353316}, {-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, \
2.2294344764321825}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.2208803408437956}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.195318553032826}, 
     {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, 
      2.588583579753018}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(31*Pi)/30]^2, \
2.2208803408437956}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.195318553032826}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, \
{-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, 
      2.5601613609103286}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(16*Pi)/15]^2, \
2.195318553032826}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.094679321954476}, 
     {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {-Cos[(2*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 
      2.1530633066599703}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
      2.094679321954476}, {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, \
2.021043485921703}, {5/16, 2.3642850399222173}, 
     {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, \
2.4474780907945566}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.094679321954476}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, {-3/4 + \
(5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, 
     {5/16, 2.3642850399222173}, {-Cos[(2*Pi)/15]^2 + \
(17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828087}, 
     {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
      2.264540963292246}, {-Cos[(2*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, \
1.933432094411191}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828087}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361496}, 
     {-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, 
      2.1499828315181597}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
      1.8336364565828087}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
      1.7241122839361496}, {-Cos[(2*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, \
1.6081701375219566}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, 
      2.0231783980979903}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
      1.7241122839361496}}], Line[{{-Cos[(2*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
      1.6081701375219566}, {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, \
1.4902097135042385}, {-1/16, 1.7488835724541527}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}}], \
Line[{{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.375975067210655}, 
     {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, \
1.6132809148526013}, {-1/16, 1.7488835724541527}, 
     {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.375975067210655}, 
     {-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 1.4898021598760776}, \
{-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, 
      1.6132809148526013}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(41*Pi)/30]^2, \
1.375975067210655}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.1890852819516722}, 
     {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, \
1.3891012614574074}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
      1.2727298803122147}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
      1.1890852819516722}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(22*Pi)/15]^2, \
1.1340136417284858}, 
     {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}, {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, 
      1.3891012614574074}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
      1.1890852819516722}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
      1.1340136417284858}, {-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, \
1.1147172382160913}, {-1/4, 1.299038105676658}, 
     {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284858}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160913}, \
{-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284856}, {-3/4 + \
(5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, 1.3224570770546995}, 
     {-1/4, 1.299038105676658}, {-Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, \
1.1147172382160913}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284856}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.189085281951672}, 
     {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, 
      1.3224570770546995}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/15]^2, 
      1.1340136417284856}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
      1.189085281951672}, {-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, \
1.2727298803122147}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 1.4898021598760776}, \
{-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, 
      1.389101261457407}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(47*Pi)/30]^2, \
1.189085281951672}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.2727298803122147}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106545}, 
     {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, \
1.6132809148526008}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {-Cos[(2*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 
      1.2727298803122147}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
      1.3759750672106545}, {-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, \
1.4902097135042385}, {-1/16, 1.7488835724541527}, 
     {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, \
1.6132809148526008}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106545}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + (11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, {-3/4 + \
(5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, 
     {-1/16, 1.7488835724541527}, {-Cos[(2*Pi)/15]^2 + \
(11*Sin[(2*Pi)/15]^2)/4, 1.4902097135042385}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6081701375219566}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361496}, 
     {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
      1.8877889819588956}, {-Cos[(2*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
      1.6081701375219566}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
      1.7241122839361496}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(53*Pi)/30]^2, \
1.833636456582808}, 
     {-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}, {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, 
      2.0231783980979903}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
      1.7241122839361496}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
      1.833636456582808}, {-Cos[(2*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, \
1.933432094411191}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, 
      2.149982831518159}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(53*Pi)/30]^2, \
1.833636456582808}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}, 
     {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, {5/16, \
2.3642850399222173}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-Cos[(2*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/16, 1.933432094411191}}], \
Line[{{-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.094679321954476}, 
     {-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, \
2.4474780907945566}, {5/16, 2.3642850399222173}, 
     {-Cos[(2*Pi)/15]^2 + (17*Sin[(2*Pi)/15]^2)/4, 2.021043485921703}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.094679321954476}, 
     {-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, \
{-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, 
      2.4474780907945566}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(28*Pi)/15]^2, \
2.094679321954476}}], 
   Line[{{-Cos[(2*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 2.1530633066599703}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.1953185530328256}, 
     {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {-Cos[(2*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(2*Pi)/15]^2)/8, 
      2.1530633066599703}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
      2.1953185530328256}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(59*Pi)/30]^2, \
2.2208803408437956}, 
     {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, 
      2.5601613609103286}, {-Cos[(2*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
      2.1953185530328256}}], Line[{{-Cos[(2*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(59*Pi)/30]^2, 
      2.2208803408437956}, {-Cos[(2*Pi)/15]^2 + 5*Sin[(2*Pi)/15]^2, \
2.2294344764321825}, {1/2, 2.598076211353316}, 
     {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, 
     {-Cos[(2*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(2*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.2208803408437956}}], 
   Line[{{1/2, 2.598076211353316}, {-3/4 + (5*Cos[Pi/30]^2)/4 + \
Sin[Pi/30]^2/2, 2.588583579753018}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, 
     {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {1/2, \
2.598076211353316}}], 
   Line[{{-3/4 + (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, \
{-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, 
     {-3/4 + (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}}], 
   Line[{{-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, \
{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}, 
     {-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}}], 
   Line[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, 
      2.447478090794556}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4, \
2.697933958917173}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}}], 
   Line[{{-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, \
2.447478090794556}, {5/16, 2.3642850399222173}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}, {-3/4 + \
(5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, 2.447478090794556}}], 
   Line[{{5/16, 2.3642850399222173}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + \
Sqrt[5])^2)/64, 2.264540963292246}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {5/16, \
2.3642850399222173}}], 
   Line[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, 
      2.1499828315181597}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4, \
2.381720267244781}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}}], \

   Line[{{-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 
      2.02317839809799}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4, \
2.2437468595288657}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
     {-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, \
2.1499828315181597}}], 
   Line[{{-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, \
2.02317839809799}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
      1.8877889819588956}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, 
     {-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, \
2.02317839809799}}], 
   Line[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-1/16, 1.7488835724541527}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, {(5*(5 \
- Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + 
       ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, {-3/4 + (5*(5 \
- Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}}], 
   Line[{{-1/16, 1.7488835724541527}, {-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + \
Sin[(11*Pi)/30]^2/2, 1.6132809148526017}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}}], 
   Line[{{-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, \
1.6132809148526017}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, 
     {-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, \
1.6132809148526017}}], 
   Line[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, 
      1.389101261457407}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4, \
1.5308481540548224}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}}], 
   Line[{{-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, 
      1.3224570770546993}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4, \
1.453775372348889}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}, 
     {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, \
1.389101261457407}}], 
   Line[{{-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, \
1.3224570770546993}, {-1/4, 1.299038105676658}, 
     {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}, {-3/4 + \
(5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, 1.3224570770546993}}], 
   Line[{{-1/4, 1.299038105676658}, {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + \
Sin[(8*Pi)/15]^2/2, 1.3224570770546993}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, 
     {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-1/4, \
1.299038105676658}}], 
   Line[{{-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, \
1.3224570770546993}, {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, 
      1.3891012614574068}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
      1.5308481540548224}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4, \
1.453775372348889}, 
     {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, \
1.3224570770546993}}], 
   Line[{{-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, \
1.3891012614574068}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}, 
     {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, \
1.3891012614574068}}], 
   Line[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, 
      1.6132809148526013}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
      1.7870411277345808}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}}], 
   Line[{{-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, \
1.6132809148526013}, {-1/16, 1.7488835724541527}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}, {-3/4 + \
(5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, 1.6132809148526013}}], 
   Line[{{-1/16, 1.7488835724541527}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + \
Sqrt[5])^2/32, 1.8877889819588956}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}}], 
   Line[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, 
      2.0231783980979894}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4, \
2.243746859528865}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}}], 
   Line[{{-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, \
2.0231783980979894}, {-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, 
      2.1499828315181597}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4, \
2.381720267244781}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
     {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, \
2.0231783980979894}}], 
   Line[{{-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
      2.264540963292246}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}, 
     {-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, \
2.1499828315181597}}], 
   Line[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {5/16, 2.3642850399222173}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {(5 - \
Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + 
       (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, {-3/4 + (5 \
- Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}}], 
   Line[{{5/16, 2.3642850399222173}, {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + \
Sin[(13*Pi)/15]^2/2, 2.4474780907945566}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {5/16, \
2.3642850399222173}}], 
   Line[{{-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, 
     {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, \
2.4474780907945566}}], 
   Line[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, 
      2.5601613609103286}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
      2.8144424077524013}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}}], 
   Line[{{-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, 
      2.588583579753018}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4, \
2.8434972909653364}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}, 
     {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, \
2.5601613609103286}}], 
   Line[{{-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, {1/2, 2.598076211353316}, 
     {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}, {-3/4 + \
(5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, 2.588583579753018}}], 
   Line[{{1/2, 2.598076211353316}, {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + \
Sin[(31*Pi)/30]^2/2, 2.588583579753018}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, 
     {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {1/2, \
2.598076211353316}}], 
   Line[{{-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, 
      2.5601613609103286}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(16*Pi)/15]^2)/4, \
2.814442407752401}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, \
2.588583579753018}}], 
   Line[{{-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}, 
     {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, \
2.5601613609103286}}], 
   Line[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, 
      2.4474780907945566}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/15]^2)/4, \
2.697933958917174}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}}], 
   Line[{{-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, \
2.4474780907945566}, {5/16, 2.3642850399222173}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}, {-3/4 + \
(5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, 2.4474780907945566}}], 
   Line[{{5/16, 2.3642850399222173}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + \
Sqrt[5])^2)/64, 2.264540963292246}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {5/16, \
2.3642850399222173}}], 
   Line[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, 
      2.1499828315181597}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(37*Pi)/30]^2)/4, \
2.381720267244781}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}}], \

   Line[{{-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, 
      2.0231783980979903}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/15]^2)/4, \
2.243746859528866}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}, 
     {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, \
2.1499828315181597}}], 
   Line[{{-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
      1.8877889819588956}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}, 
     {-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, \
2.0231783980979903}}], 
   Line[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-1/16, 1.7488835724541527}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, {(5*(5 \
- Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + 
       ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, {-3/4 + (5*(5 \
- Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}}], 
   Line[{{-1/16, 1.7488835724541527}, {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + \
Sin[(41*Pi)/30]^2/2, 1.6132809148526013}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}}], 
   Line[{{-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, \
1.6132809148526013}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, 
     {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, \
1.6132809148526013}}], 
   Line[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, 
      1.3891012614574074}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(43*Pi)/30]^2)/4, \
1.530848154054823}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}}], 
   Line[{{-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, \
1.3891012614574074}, {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, 
      1.3224570770546997}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 
      1.4537753723488895}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(43*Pi)/30]^2)/4, \
1.530848154054823}, 
     {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, \
1.3891012614574074}}], 
   Line[{{-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}, {-1/4, 1.299038105676658}, 
     {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}, {-3/4 + \
(5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, 1.3224570770546997}}], 
   Line[{{-1/4, 1.299038105676658}, {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + \
Sin[(23*Pi)/15]^2/2, 1.3224570770546995}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, 
     {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-1/4, \
1.299038105676658}}], 
   Line[{{-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, \
1.3224570770546995}, {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, 
      1.389101261457407}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(47*Pi)/30]^2)/4, \
1.5308481540548229}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, 
     {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, \
1.3224570770546995}}], 
   Line[{{-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}, 
     {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, \
1.389101261457407}}], 
   Line[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, 
      1.6132809148526008}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 
      1.7870411277345801}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}}], 
   Line[{{-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, \
1.6132809148526008}, {-1/16, 1.7488835724541527}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}, {-3/4 + \
(5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, 1.6132809148526008}}], 
   Line[{{-1/16, 1.7488835724541527}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + \
Sqrt[5])^2/32, 1.8877889819588956}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}}], 
   Line[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, 
      2.0231783980979903}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(26*Pi)/15]^2)/4, \
2.243746859528866}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}}], 
   Line[{{-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, 
      2.149982831518159}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(53*Pi)/30]^2)/4, \
2.3817202672447797}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
     {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, \
2.0231783980979903}}], 
   Line[{{-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
      2.264540963292246}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}, 
     {-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}}], 
   Line[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {5/16, 2.3642850399222173}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {(5 - \
Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + 
       (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, {-3/4 + (5 \
- Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}}], 
   Line[{{5/16, 2.3642850399222173}, {-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + \
Sin[(28*Pi)/15]^2/2, 2.4474780907945566}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {5/16, \
2.3642850399222173}}], 
   Line[{{-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, 
     {-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, \
2.4474780907945566}}], 
   Line[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, 
      2.5601613609103286}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
      2.8144424077524013}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}}], 
   Line[{{-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, 
      2.588583579753018}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(59*Pi)/30]^2)/4, \
2.8434972909653364}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}, 
     {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, \
2.5601613609103286}}], 
   Line[{{-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, {1/2, 2.598076211353316}, 
     {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}, {-3/4 + \
(5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, 2.588583579753018}}], 
   Line[{{(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {-(1 \
+ Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 2.9745950829027943}, \
{-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}, 
     {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 2.947488384456562}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 2.9745950829027943}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 2.947488384456562}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}}], 
   Line[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 2.836596676593442}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 2.836596676593442}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}}], 
   Line[{{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, \
{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}], 
   Line[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^4, 2.521624931409047}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^4, 2.521624931409047}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.379229777665829}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}}], 
   Line[{{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}}], 
   Line[{{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 1.891824180835019}, \
{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 1.891824180835019}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}}], 
   Line[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.6089224974238359}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5224519023538965}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.6089224974238359}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}, 
     {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, \
{-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5224519023538965}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}}], 
   Line[{{(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5224519023538965}, \
{-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}, 
     {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.6089224974238356}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5224519023538965}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.6089224974238356}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}}], 
   Line[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.8918241808350182}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.8918241808350182}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}}], 
   Line[{{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, \
{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}], 
   Line[{{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.3792297776658287}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409047}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.3792297776658287}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409047}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}}], 
   Line[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}}], 
   Line[{{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, \
{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}}], 
   Line[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.9745950829027943}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}, 
     {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, \
{-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.9745950829027943}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}}], 
   Line[{{(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {-(1 \
+ Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.9745950829027943}, \
{-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}, 
     {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.9745950829027943}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}}], 
   Line[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.8365966765934423}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.8365966765934423}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}}], 
   Line[{{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, \
{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}], 
   Line[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409047}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409047}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}}], 
   Line[{{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}}], 
   Line[{{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350185}, \
{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350185}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}}], 
   Line[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.530848154054823}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.530848154054823}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.530848154054823}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}, 
     {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, \
{-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}}], 
   Line[{{(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538967}, \
{-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}, 
     {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238359}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538967}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238359}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}}], 
   Line[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.891824180835018}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.891824180835018}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}}], 
   Line[{{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, \
{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}], 
   Line[{{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.5216249314090455}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.5216249314090455}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}}], 
   Line[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}}], 
   Line[{{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, \
{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}}], 
   Line[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.9474883844565616}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027943}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.9474883844565616}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}, 
     {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, \
{-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027943}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 2.9745950829027943}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 2.9763034938899464}, \
{-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}, 
     {-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 2.9745950829027943}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 2.947488384456562}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 2.9763034938899464}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/30]^2, 2.9745950829027943}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 2.947488384456562}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/30]^2, 2.947488384456562}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 2.836596676593442}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 2.836596676593442}, 
     {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/30]^2, 2.836596676593442}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, \
{-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, \
{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^4, 2.521624931409047}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.567335508777075}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^4, 2.521624931409047}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^4, 2.427623046285348}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.567335508777075}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^4, 2.521624931409047}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^4, 2.427623046285348}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.379229777665829}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, \
{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 1.891824180835019}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.9258466260207312}, \
{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 1.891824180835019}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.9258466260207312}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 1.891824180835019}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.6089224974238359}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.6209688555409114}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.6089224974238359}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5224519023538965}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5257871330867276}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.6209688555409114}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.6089224974238359}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5224519023538965}, 
     {-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}, \
{-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5257871330867276}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5224519023538965}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5224519023538965}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5257871330867279}, \
{-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}, 
     {-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5224519023538965}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.6089224974238356}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.6209688555409114}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5257871330867279}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5224519023538965}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.6089224974238356}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.6209688555409114}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.6089224974238356}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.8918241808350182}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.9258466260207305}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.8918241808350182}, 
     {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, \
{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.9258466260207305}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.8918241808350182}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, \
{-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, \
{-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, \
{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.3792297776658287}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.4276230462853476}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.3792297776658287}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409047}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.4276230462853476}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.3792297776658287}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409047}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409047}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.859399797409293}, \
{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.9745950829027943}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.9763034938899464}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.9745950829027943}, 
     {-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}, \
{-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.9763034938899464}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.9745950829027943}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.9745950829027943}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.9763034938899464}, \
{-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}, 
     {-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.9745950829027943}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.9763034938899464}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.9745950829027943}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.8365966765934423}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.8365966765934423}, 
     {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.8365966765934423}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, \
{-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, \
{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409047}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.567335508777075}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409047}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.567335508777075}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409047}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, \
{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350185}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.9258466260207308}, \
{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350185}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.9258466260207308}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350185}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867285}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}, 
     {-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}, \
{-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867285}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538967}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, \
{-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}, 
     {-Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.49178284305241}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538967}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238359}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538967}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238359}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238359}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.891824180835018}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.92584662602073}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(7*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.737462364751998}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.891824180835018}, 
     {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, \
{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.92584662602073}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.891824180835018}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}, \
{-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, \
{-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, \
{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(7*Pi)/30]^2 + (11*Sin[(7*Pi)/30]^2)/4, 2.0573688751735335}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(7*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.222607239695348}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.5216249314090455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.5216249314090455}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.5216249314090455}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}, 
     {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(7*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/16, 2.646328981764321}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(7*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/30]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.859399797409293}, \
{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(7*Pi)/30]^2 + (17*Sin[(7*Pi)/30]^2)/4, 2.751525170659194}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.9474883844565616}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.95408127925137}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(7*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/8, 2.901719090978228}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.9474883844565616}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027943}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.95408127925137}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.9474883844565616}}], 
   Line[{{-Cos[(7*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027943}, 
     {-Cos[(7*Pi)/30]^2 + 5*Sin[(7*Pi)/30]^2, 2.98356568610482}, \
{-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
     {-Cos[(7*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027943}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 2.9763034938899464}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, 
     {-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 2.9763034938899464}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 2.9540812792513704}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(4*Pi)/15]^2, 2.9763034938899464}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(4*Pi)/15]^2, 2.9540812792513704}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 2.859399797409293}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, {(-5 \
+ Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(4*Pi)/15]^2, 2.859399797409293}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, {(-5 + \
Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + 
       (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, {(-5 + Sqrt[5])/8 + \
(17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, 
     {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.567335508777075}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.567335508777075}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^4, 2.427623046285348}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(4*Pi)/15]^2, 2.567335508777075}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^4, 2.427623046285348}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^4, 2.427623046285348}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, {(-5 \
+ Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.9258466260207312}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, {(-5 + \
Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, 
     {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.9258466260207312}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 1.9258466260207312}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.6209688555409114}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.6209688555409114}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5257871330867276}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.6209688555409114}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5257871330867276}, 
     {-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}, {(-5 + \
Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5257871330867276}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5257871330867279}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, {(-5 + \
Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, 
     {-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5257871330867279}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.6209688555409114}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5257871330867279}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.6209688555409114}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.6209688555409114}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.9258466260207305}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.9258466260207305}, 
     {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, {(-5 \
+ Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.9258466260207305}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, {(-5 + \
Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 
      2.239718051509763}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, \
2.0698782028004867}, {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 
      2.0997996262255536}}], Line[{{-Cos[(4*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
      2.2699589047379565}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, \
2.4276230462853476}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.4276230462853476}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.4276230462853476}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, {(-5 \
+ Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.859399797409293}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, {(-5 + \
Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, 
     {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.859399797409293}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.9540812792513704}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.9763034938899464}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.9540812792513704}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.9763034938899464}, 
     {-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.9763034938899464}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.9763034938899464}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, 
     {-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.9763034938899464}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.9763034938899464}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, {(-5 \
+ Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, {(-5 + \
Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + 
       (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, {(-5 + Sqrt[5])/8 + \
(17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, 
     {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.567335508777075}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.567335508777075}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.567335508777075}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, {(-5 \
+ Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.9258466260207308}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, {(-5 + \
Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, 
     {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.9258466260207308}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.9258466260207308}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867285}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867285}, 
     {-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}, {(-5 + \
Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867285}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, {(-5 + \
Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, 
     {-Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524098}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.92584662602073}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-Cos[(4*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.760690570377689}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.92584662602073}, 
     {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, {(-5 \
+ Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.92584662602073}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}, {(-5 + \
Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 
      2.239718051509763}, {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, \
2.0698782028004867}, {-Cos[(4*Pi)/15]^2 + (11*Sin[(4*Pi)/15]^2)/4, 
      2.0997996262255536}}], Line[{{-Cos[(4*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
      2.2699589047379565}, {-Cos[(4*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(26*Pi)/15]^2, \
2.4276230462853485}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {-Cos[(4*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.2699589047379565}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, {(-5 \
+ Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {-Cos[(4*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/16, 2.686221801523239}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(4*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(4*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.859399797409293}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, {(-5 + \
Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, 
     {-Cos[(4*Pi)/15]^2 + (17*Sin[(4*Pi)/15]^2)/4, 2.7833940695732022}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.859399797409293}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.95408127925137}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-Cos[(4*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/8, 2.9156867970745455}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.95408127925137}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.95408127925137}}], 
   Line[{{-Cos[(4*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
     {-Cos[(4*Pi)/15]^2 + 5*Sin[(4*Pi)/15]^2, 2.98356568610482}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
     {-Cos[(4*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(4*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, \
{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, {-1/4 + \
(15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 2.5979598975817524}, 
     {7/2, 2.598076211353316}, {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, \
2.8531695488854605}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}, 
     {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 2.5962550390555568}, \
{-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 2.5979598975817524}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 
      2.5962550390555568}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, \
2.834803496770628}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}, 
     {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
      2.809014835019403}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 
      2.768181798733441}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, \
2.70871038548537}, {47/16, 2.536452985962878}, 
     {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}}], 
   Line[{{(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 \
+ Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + 
       (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, {-1/4 + (3*(5 - \
Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}, 
     {47/16, 2.536452985962878}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, \
2.70871038548537}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
     {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
      2.4790558351445977}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}, 
     {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}, {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \

      2.3948140222646948}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 
      2.5219601128218545}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
      2.392089327116677}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
     {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, 
      2.281657041700859}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 
      2.392089327116677}}], Line[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{29/16, 1.9754350786598884}, 
     {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}}], 
   Line[{{(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, {-1/4 + \
(15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, 
      1.7955424168801202}, {29/16, 1.9754350786598884}, {(-5 + Sqrt[5])/8 + \
(11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + \
(3*Sin[(11*Pi)/30]^2)/2, 
      1.7955424168801202}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 
      1.8914277190459863}}], Line[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 \
+ Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
      1.7178957504272219}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
      1.5679671136605227}, {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 1.454550222063749}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}, 
     {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}, {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 
      1.454550222063749}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
      1.5679671136605227}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
      1.4640759018681937}, {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427302}, {5/4, 1.299038105676658}, 
     {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}}], 
   Line[{{(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, {-1/4 + \
(15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, 1.3407174947497686}, 
     {5/4, 1.299038105676658}, {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427302}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}, 
     {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}, {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + \
(3*Sin[(8*Pi)/15]^2)/2, 
      1.3407174947497686}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 
      1.4640759018681935}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
      1.5679671136605227}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + \
(3*Sin[(17*Pi)/30]^2)/2, 
      1.4545502220637487}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 
      1.5679671136605227}}], Line[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 \
+ Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
      1.7178957504272219}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
      1.8914277190459856}, {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + \
(3*Sin[(19*Pi)/30]^2)/2, 1.7955424168801195}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{29/16, 1.9754350786598884}, 
     {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, \
1.7955424168801195}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}}], 
   Line[{{(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + 
       (1 + Sqrt[5])^4/128, 2.239718051509763}, {-1/4 + (15*(5 - Sqrt[5]))/32 \
+ (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
     {29/16, 1.9754350786598884}, {(-5 + Sqrt[5])/8 + (11*(1 + \
Sqrt[5])^2)/64, 2.0698782028004867}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
     {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 
      2.14040166785146}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
     {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + (3*Sin[(23*Pi)/30]^2)/2, \
2.394814022264696}, {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + \
(3*Sin[(11*Pi)/15]^2)/2, 
      2.281657041700858}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 
      2.3920893271166768}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
      2.521960112821855}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + \
(3*Sin[(23*Pi)/30]^2)/2, 
      2.394814022264696}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 
      2.521960112821855}}], Line[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {47/16, \
2.536452985962878}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}}], 
   Line[{{(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 \
+ Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, {-1/4 + \
(15*Cos[(13*Pi)/15]^2)/4 + (3*Sin[(13*Pi)/15]^2)/2, 
      2.5712732770958877}, {47/16, 2.536452985962878}, {(-5 + Sqrt[5])/8 + \
(17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + \
(3*Sin[(13*Pi)/15]^2)/2, 
      2.5712732770958877}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
      2.7681817987334414}}], Line[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
      2.809014835019403}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
      2.834803496770628}, {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + \
(3*Sin[(14*Pi)/15]^2)/2, 2.5962550390555568}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}, 
     {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + \
(3*Sin[(14*Pi)/15]^2)/2, 
      2.5962550390555568}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
      2.834803496770628}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 
      2.8487773266631815}, {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, \
2.8531695488854605}, {7/2, 2.598076211353316}, 
     {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, \
{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, {-1/4 + \
(15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, 
      2.5979598975817524}, {7/2, 2.598076211353316}, {(-5 + Sqrt[5])/8 + \
(5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}, 
     {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + (3*Sin[(16*Pi)/15]^2)/2, \
2.5962550390555568}, {-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + \
(3*Sin[(31*Pi)/30]^2)/2, 
      2.5979598975817524}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 
      2.8487773266631815}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 
      2.834803496770629}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + \
(3*Sin[(16*Pi)/15]^2)/2, 
      2.5962550390555568}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 
      2.834803496770629}}], Line[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
      2.809014835019403}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 
      2.7681817987334423}, {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + \
(3*Sin[(17*Pi)/15]^2)/2, 2.5712732770958877}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {47/16, \
2.536452985962878}, 
     {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}}], 
   Line[{{(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 \
+ Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + 
       (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, {-1/4 + (3*(5 - \
Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}, 
     {47/16, 2.536452985962878}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, \
2.70871038548537}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
     {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
      2.4790558351445977}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
     {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}, {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + \
(3*Sin[(37*Pi)/30]^2)/2, 
      2.3948140222646948}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 
      2.5219601128218545}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 
      2.3920893271166777}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
     {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + \
(3*Sin[(19*Pi)/15]^2)/2, 
      2.2816570417008593}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 
      2.3920893271166777}}], Line[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{29/16, 1.9754350786598884}, 
     {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}}], 
   Line[{{(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, {-1/4 + \
(15*Cos[(41*Pi)/30]^2)/4 + (3*Sin[(41*Pi)/30]^2)/2, 1.7955424168801195}, 
     {29/16, 1.9754350786598884}, {(-5 + Sqrt[5])/8 + (11*(1 + \
Sqrt[5])^2)/64, 2.0698782028004867}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + \
(3*Sin[(41*Pi)/30]^2)/2, 
      1.7955424168801195}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 
      1.891427719045986}}], Line[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 \
+ Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
      1.7178957504272219}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 
      1.5679671136605233}, {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + \
(3*Sin[(43*Pi)/30]^2)/2, 1.4545502220637496}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
     {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + \
(3*Sin[(43*Pi)/30]^2)/2, 
      1.4545502220637496}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 
      1.5679671136605233}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 
      1.4640759018681944}, {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427302}, {5/4, 1.299038105676658}, 
     {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}}], 
   Line[{{(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, {-1/4 + \
(15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, 1.340717494749769}, 
     {5/4, 1.299038105676658}, {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427302}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}, 
     {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}, {-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + \
(3*Sin[(23*Pi)/15]^2)/2, 
      1.340717494749769}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 
      1.464075901868194}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 
      1.5679671136605229}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + \
(3*Sin[(47*Pi)/30]^2)/2, 
      1.454550222063749}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 
      1.5679671136605229}}], Line[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 \
+ Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 
      1.7178957504272219}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 
      1.8914277190459852}, {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + \
(3*Sin[(49*Pi)/30]^2)/2, 1.795542416880119}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{29/16, 1.9754350786598884}, 
     {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, \
1.795542416880119}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}}], 
   Line[{{(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + 
       (1 + Sqrt[5])^4/128, 2.239718051509763}, {-1/4 + (15*(5 - Sqrt[5]))/32 \
+ (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
     {29/16, 1.9754350786598884}, {(-5 + Sqrt[5])/8 + (11*(1 + \
Sqrt[5])^2)/64, 2.0698782028004867}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
     {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 
      2.14040166785146}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
     {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + (3*Sin[(53*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + \
(3*Sin[(26*Pi)/15]^2)/2, 
      2.2816570417008593}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 
      2.3920893271166777}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 
      2.5219601128218536}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + \
(3*Sin[(53*Pi)/30]^2)/2, 
      2.3948140222646948}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 
      2.5219601128218536}}], Line[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {47/16, \
2.536452985962878}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}}], 
   Line[{{(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 \
+ Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, {-1/4 + \
(15*Cos[(28*Pi)/15]^2)/4 + (3*Sin[(28*Pi)/15]^2)/2, 2.5712732770958877}, 
     {47/16, 2.536452985962878}, {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, \
2.70871038548537}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + \
(3*Sin[(28*Pi)/15]^2)/2, 
      2.5712732770958877}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 
      2.768181798733441}}], Line[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 
      2.809014835019403}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 
      2.834803496770629}, {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + \
(3*Sin[(29*Pi)/15]^2)/2, 2.596255039055556}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
     {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + \
(3*Sin[(29*Pi)/15]^2)/2, 
      2.596255039055556}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 
      2.834803496770629}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 
      2.8487773266631806}, {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, \
2.8531695488854605}, {7/2, 2.598076211353316}, 
     {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}}], 
   Line[{{7/2, 2.598076211353316}, {-1/4 + (15*Cos[Pi/30]^2)/4 + \
(3*Sin[Pi/30]^2)/2, 2.5979598975817524}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 2.235484296800204}, 
     {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, {7/2, \
2.598076211353316}}], 
   Line[{{-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, \
2.5979598975817524}, {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 
      2.5962550390555568}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, \
2.251331326578102}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 2.235484296800204}, 
     {-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 2.5979598975817524}}], \

   Line[{{-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, \
2.5962550390555568}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
      2.2706462108209013}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, \
2.251331326578102}, 
     {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 2.5962550390555568}}], \

   Line[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + \
(3*Sin[(2*Pi)/15]^2)/2, 
      2.5712732770958873}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, \
2.284543605895154}, 
     {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}}], 
   Line[{{-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}, {47/16, 2.536452985962878}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.284543605895154}, {-1/4 + \
(15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, 2.5712732770958873}}], 
   Line[{{47/16, 2.536452985962878}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}, 
     {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{47/16, 2.536452985962878}}], 
   Line[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + \
(3*Sin[(7*Pi)/30]^2)/2, 
      2.3948140222646948}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, \
2.202570463435661}, 
     {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}}], 
   Line[{{-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + \
(3*Sin[(4*Pi)/15]^2)/2, 
      2.281657041700859}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, \
2.112263515546569}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 2.202570463435661}, 
     {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \
2.3948140222646948}}], 
   Line[{{-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 
      2.14040166785146}, {-Cos[(11*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, \
1.9869545564435858}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.112263515546569}, 
     {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}}], 
   Line[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, {-1/4 + \
(15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}}], 
   Line[{{29/16, 1.9754350786598884}, {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + \
(3*Sin[(11*Pi)/30]^2)/2, 1.7955424168801202}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^4, 1.6506863454327518}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{29/16, 1.9754350786598884}}], 
   Line[{{-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, \
1.7955424168801202}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \

      1.61498867371741}, {-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
      1.462871819562226}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^4, \
1.6506863454327518}, 
     {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, \
1.7955424168801202}}], 
   Line[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 
      1.454550222063749}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 
      1.2895708590441464}, {-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
      1.462871819562226}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}}], 
   Line[{{-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + (3*Sin[(13*Pi)/30]^2)/2, \
1.454550222063749}, {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \

      1.3407174947497689}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, \
1.1623542887261817}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.2895708590441464}, 
     {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + (3*Sin[(13*Pi)/30]^2)/2, \
1.454550222063749}}], 
   Line[{{-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}, {5/4, 1.299038105676658}, 
     {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1623542887261817}, {-1/4 + \
(15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, 1.3407174947497689}}], 
   Line[{{5/4, 1.299038105676658}, {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + \
(3*Sin[(8*Pi)/15]^2)/2, 1.3407174947497686}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1623542887261817}, 
     {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, {5/4, \
1.299038105676658}}], 
   Line[{{-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, \
1.3407174947497686}, 
     {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.2895708590441464}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1623542887261817}, 
     {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, \
1.3407174947497686}}], 
   Line[{{-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \

      1.61498867371741}, {-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
      1.462871819562226}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 
      1.2895708590441464}, {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + \
(3*Sin[(17*Pi)/30]^2)/2, 1.4545502220637487}}], 
   Line[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + \
(3*Sin[(19*Pi)/30]^2)/2, 
      1.7955424168801195}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
      1.6506863454327514}, {-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
      1.462871819562226}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}}], 
   Line[{{-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, \
1.7955424168801195}, {29/16, 1.9754350786598884}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}, {-1/4 + \
(15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, 
      1.7955424168801195}}], Line[{{29/16, 1.9754350786598884}, {-1/4 + \
(15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
     {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{29/16, 1.9754350786598884}}], 
   Line[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + \
(3*Sin[(11*Pi)/15]^2)/2, 
      2.281657041700858}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}, 
     {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
     {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}}], 
   Line[{{-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}, 
     {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + (3*Sin[(23*Pi)/30]^2)/2, \
2.394814022264696}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}, 
     {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}}], 
   Line[{{-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + (3*Sin[(23*Pi)/30]^2)/2, \
2.394814022264696}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
      2.4790558351445977}, {-Cos[(11*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 
      2.2583039834915457}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
      2.2025704634356615}, {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + \
(3*Sin[(23*Pi)/30]^2)/2, 2.394814022264696}}], 
   Line[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {47/16, 2.536452985962878}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, {-1/4 + \
(3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
      2.4790558351445977}}], Line[{{47/16, 2.536452985962878}, {-1/4 + \
(15*Cos[(13*Pi)/15]^2)/4 + (3*Sin[(13*Pi)/15]^2)/2, 2.5712732770958877}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895155}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{47/16, 2.536452985962878}}], 
   Line[{{-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + (3*Sin[(13*Pi)/15]^2)/2, \
2.5712732770958877}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
      2.2706462108209013}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
      2.284543605895155}, {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + \
(3*Sin[(13*Pi)/15]^2)/2, 2.5712732770958877}}], 
   Line[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + \
(3*Sin[(14*Pi)/15]^2)/2, 
      2.5962550390555568}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
      2.251331326578102}, {-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
      2.2706462108209013}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + \
Sqrt[5]))/32, 2.5891768866299354}}], 
   Line[{{-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + (3*Sin[(14*Pi)/15]^2)/2, \
2.5962550390555568}, 
     {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800204}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.251331326578102}, 
     {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + (3*Sin[(14*Pi)/15]^2)/2, \
2.5962550390555568}}], 
   Line[{{-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, {7/2, 2.598076211353316}, 
     {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800204}, {-1/4 + \
(15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, 
      2.5979598975817524}}], Line[{{7/2, 2.598076211353316}, {-1/4 + \
(15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, 2.5979598975817524}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800204}, 
     {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, {7/2, \
2.598076211353316}}], 
   Line[{{-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, \
2.5979598975817524}, 
     {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + (3*Sin[(16*Pi)/15]^2)/2, \
2.5962550390555568}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578102}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800204}, 
     {-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, \
2.5979598975817524}}], 
   Line[{{-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + (3*Sin[(16*Pi)/15]^2)/2, \
2.5962550390555568}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
      2.2706462108209013}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
      2.251331326578102}, {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + \
(3*Sin[(16*Pi)/15]^2)/2, 2.5962550390555568}}], 
   Line[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + \
(3*Sin[(17*Pi)/15]^2)/2, 
      2.5712732770958877}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
      2.284543605895154}, {-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
      2.2706462108209013}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + \
Sqrt[5]))/32, 2.5891768866299354}}], 
   Line[{{-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}, {47/16, 2.536452985962878}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895154}, {-1/4 + \
(15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, 
      2.5712732770958877}}], Line[{{47/16, 2.536452985962878}, {-1/4 + (3*(5 \
- Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}, 
     {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{47/16, 2.536452985962878}}], 
   Line[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + \
(3*Sin[(37*Pi)/30]^2)/2, 
      2.3948140222646948}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
      2.202570463435661}, {-Cos[(11*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 
      2.2583039834915457}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}}], 
   Line[{{-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}, 
     {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.112263515546569}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.202570463435661}, 
     {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}}], 
   Line[{{-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 
      2.14040166785146}, {-Cos[(11*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, \
1.9869545564435858}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.112263515546569}, 
     {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}}], 
   Line[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, {-1/4 + \
(15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}}], 
   Line[{{29/16, 1.9754350786598884}, {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + \
(3*Sin[(41*Pi)/30]^2)/2, 1.7955424168801195}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.6506863454327514}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{29/16, 1.9754350786598884}}], 
   Line[{{-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + (3*Sin[(41*Pi)/30]^2)/2, \
1.7955424168801195}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \

      1.61498867371741}, {-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
      1.462871819562226}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(41*Pi)/30]^2, 
      1.6506863454327514}, {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + \
(3*Sin[(41*Pi)/30]^2)/2, 1.7955424168801195}}], 
   Line[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + \
(3*Sin[(43*Pi)/30]^2)/2, 
      1.4545502220637496}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
      1.2895708590441473}, {-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
      1.462871819562226}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}}], 
   Line[{{-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + (3*Sin[(43*Pi)/30]^2)/2, \
1.4545502220637496}, 
     {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261822}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.2895708590441473}, 
     {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + (3*Sin[(43*Pi)/30]^2)/2, \
1.4545502220637496}}], 
   Line[{{-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, {5/4, 1.299038105676658}, 
     {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261822}, {-1/4 + \
(15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, 
      1.3407174947497693}}], Line[{{5/4, 1.299038105676658}, {-1/4 + \
(15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, 1.340717494749769}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726182}, 
     {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, {5/4, \
1.299038105676658}}], 
   Line[{{-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, \
1.340717494749769}, 
     {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441468}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726182}, 
     {-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, \
1.340717494749769}}], 
   Line[{{-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, 
      1.61498867371741}, {-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
      1.462871819562226}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
      1.2895708590441468}, {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + \
(3*Sin[(47*Pi)/30]^2)/2, 1.454550222063749}}], 
   Line[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + \
(3*Sin[(49*Pi)/30]^2)/2, 
      1.795542416880119}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
      1.6506863454327507}, {-Cos[(11*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
      1.462871819562226}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}}], 
   Line[{{-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, \
1.795542416880119}, {29/16, 1.9754350786598884}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327507}, {-1/4 + \
(15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, 
      1.795542416880119}}], Line[{{29/16, 1.9754350786598884}, {-1/4 + (15*(5 \
- Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
     {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{29/16, 1.9754350786598884}}], 
   Line[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + \
(3*Sin[(26*Pi)/15]^2)/2, 
      2.2816570417008593}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
      2.112263515546569}, {-Cos[(11*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 
      1.9869545564435858}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + \
Sqrt[5])^2)/32, 2.14040166785146}}], 
   Line[{{-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}, 
     {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + (3*Sin[(53*Pi)/30]^2)/2, \
2.3948140222646948}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.112263515546569}, 
     {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}}], 
   Line[{{-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + (3*Sin[(53*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
      2.4790558351445977}, {-Cos[(11*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 
      2.2583039834915457}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
      2.2025704634356607}, {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + \
(3*Sin[(53*Pi)/30]^2)/2, 2.3948140222646948}}], 
   Line[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {47/16, 2.536452985962878}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, {-1/4 + \
(3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
      2.4790558351445977}}], Line[{{47/16, 2.536452985962878}, {-1/4 + \
(15*Cos[(28*Pi)/15]^2)/4 + (3*Sin[(28*Pi)/15]^2)/2, 2.5712732770958877}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.2845436058951543}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{47/16, 2.536452985962878}}], 
   Line[{{-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + (3*Sin[(28*Pi)/15]^2)/2, \
2.5712732770958877}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {-Cos[(11*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 
      2.2706462108209013}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(28*Pi)/15]^2, 
      2.2845436058951543}, {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + \
(3*Sin[(28*Pi)/15]^2)/2, 2.5712732770958877}}], 
   Line[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + \
(3*Sin[(29*Pi)/15]^2)/2, 
      2.596255039055556}, {-Cos[(11*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578102}, 
     {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}}], 
   Line[{{-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + (3*Sin[(29*Pi)/15]^2)/2, \
2.596255039055556}, 
     {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800204}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578102}, 
     {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + (3*Sin[(29*Pi)/15]^2)/2, \
2.596255039055556}}], 
   Line[{{-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, {7/2, 2.598076211353316}, 
     {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800204}, {-1/4 + \
(15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, 
      2.5979598975817515}}], Line[{{-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, \
2.229434476432184}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 2.235484296800204}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 2.235484296800204}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 2.251331326578102}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/30]^2, 2.235484296800204}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 2.251331326578102}, 
     {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/30]^2, 2.251331326578102}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.284543605895154}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.284543605895154}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.284543605895154}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, {-(-1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + 
       (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, {-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 2.202570463435661}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 2.202570463435661}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.112263515546569}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/30]^2, 2.202570463435661}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.112263515546569}, 
     {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/30]^2, 2.112263515546569}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^4, 1.6506863454327518}, {-(-1 + Sqrt[5])^2/16 + \
(5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, {-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^4, 1.6506863454327518}, 
     {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^4, 1.6506863454327518}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.2895708590441464}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.2895708590441464}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1623542887261817}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.2895708590441464}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1623542887261817}, 
     {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1623542887261817}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1623542887261817}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
     {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1623542887261817}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.2895708590441464}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1623542887261817}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.2895708590441464}, 
     {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.2895708590441464}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + 
       ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, {-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}, 
     {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895155}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, {-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895155}, 
     {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895155}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.251331326578102}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.251331326578102}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800204}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.251331326578102}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800204}, 
     {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800204}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800204}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
     {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800204}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578102}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800204}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578102}, 
     {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578102}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895154}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895154}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895154}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, {-(-1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + 
       (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, {-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.202570463435661}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.202570463435661}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.112263515546569}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.202570463435661}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.112263515546569}, 
     {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.112263515546569}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.6506863454327514}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, {-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.6506863454327514}, 
     {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.6506863454327514}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.2895708590441473}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.2895708590441473}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.2895708590441473}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261822}, 
     {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261822}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726182}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
     {-Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726182}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441468}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726182}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441468}, 
     {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441468}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327507}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(11*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.462871819562226}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327507}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327507}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}, \
{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + 
       ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, {-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-Cos[(11*Pi)/30]^2 + (11*Sin[(11*Pi)/30]^2)/4, 1.8302685290560394}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.112263515546569}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(11*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.9869545564435858}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.112263515546569}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.112263515546569}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}, 
     {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(11*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/16, 2.2583039834915457}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}, \
{-Cos[(11*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.2845436058951543}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, {-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-Cos[(11*Pi)/30]^2 + (17*Sin[(11*Pi)/30]^2)/4, 2.2833691489150687}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.2845436058951543}, 
     {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.2845436058951543}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578102}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(11*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/8, 2.2706462108209013}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578102}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800204}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578102}}], 
   Line[{{-Cos[(11*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800204}, 
     {-Cos[(11*Pi)/30]^2 + 5*Sin[(11*Pi)/30]^2, 2.229434476432184}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}, 
     {-Cos[(11*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800204}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 1.2512975557014567}, \
{-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 1.3346849311080466}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 1.2512975557014567}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 1.3346849311080466}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 \
+ Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.5625819810819546}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.5625819810819546}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + 
       (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, \
{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, \
{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.705691841463222}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.7395717696563637}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.705691841463222}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.3017122836390151}, \
{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.3017122836390151}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 \
+ Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^4, 0.8724918816600722}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6880869119781076}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^4, 0.8724918816600722}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, \
{-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6880869119781076}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, {-(-1 \
+ Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6880869119781069}, \
{-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, 
     {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600716}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6880869119781069}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600716}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 \
+ Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + 
       ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, \
{-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, \
{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, \
{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 \
+ Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, \
{-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 \
+ Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + 
       (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, \
{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, \
{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, \
{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 \
+ Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.872491881660073}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781086}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.872491881660073}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}, 
     {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, \
{-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781086}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, {-(-1 \
+ Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, \
{-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, 
     {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 \
+ Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + 
       ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, \
{-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, \
{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, \
{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 \
+ Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 1.2512975557014567}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.693545187289426}, \
{-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}, 
     {-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 1.3346849311080466}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.8605642566348376}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.693545187289426}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/30]^2, 1.2512975557014567}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 1.3346849311080466}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.8605642566348376}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/30]^2, 1.3346849311080466}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.5625819810819546}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.2475429541754062}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.5625819810819546}, 
     {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.2475429541754062}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.5625819810819546}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, \
{-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, \
{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5605942189297979}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.705691841463222}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5507915961279441}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5605942189297979}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.7395717696563637}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.705691841463222}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5507915961279441}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/30]^2, 1.705691841463222}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.3017122836390151}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1666712321091814}, \
{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.3017122836390151}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1666712321091814}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/30]^2, 1.3017122836390151}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^4, 0.8724918816600722}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6884858883697308}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^4, 0.8724918816600722}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6880869119781076}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^4, 0.442263528432697}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6884858883697308}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^4, 0.8724918816600722}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6880869119781076}, 
     {-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, \
{-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^4, 0.442263528432697}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6880869119781076}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6880869119781069}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432695}, \
{-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, 
     {-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6880869119781069}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600716}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697308}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432695}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6880869119781069}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600716}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697308}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600716}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.166671232109181}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
     {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.166671232109181}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, \
{-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, \
{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5507915961279435}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189298}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5507915961279435}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189298}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, \
{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348376}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.693545187289426}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348376}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, \
{-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.693545187289426}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.693545187289426}, \
{-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}, 
     {-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348376}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.693545187289426}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348376}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.247542954175402}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}, 
     {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.247542954175402}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, \
{-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, \
{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297979}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.5507915961279446}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297979}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.5507915961279446}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.166671232109181}, \
{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.166671232109181}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.872491881660073}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697313}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.872491881660073}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781086}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432698}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697313}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.872491881660073}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781086}, 
     {-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, \
{-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432698}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781086}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, \
{-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, 
     {-Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646136991}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697313}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697313}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091806}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(13*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0910840571723004}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
     {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091806}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, \
{-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, \
{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(13*Pi)/30]^2 + (11*Sin[(13*Pi)/30]^2)/4, 1.4819447816621787}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.5507915961279446}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {-Cos[(13*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.6189603147994467}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.560594218929799}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.5507915961279446}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.560594218929799}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {-Cos[(13*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/16, 1.7222389198769947}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(13*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/30]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.247542954175402}, \
{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(13*Pi)/30]^2 + (17*Sin[(13*Pi)/30]^2)/4, 1.6596693760099315}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.247542954175402}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348355}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(13*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/8, 1.4470248504530066}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894184}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348355}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}}], 
   Line[{{-Cos[(13*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}, 
     {-Cos[(13*Pi)/30]^2 + 5*Sin[(13*Pi)/30]^2, 1.2202099292273982}, \
{-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894184}, 
     {-Cos[(13*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.693545187289426}, {5*Cos[Pi/30]^2 + \
2*Sin[Pi/30]^2, 0.3118675362266461}, {5, 0}, 
     {-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.693545187289426}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.8605642566348376}, 
     {5*Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646136962}, {5*Cos[Pi/30]^2 + \
2*Sin[Pi/30]^2, 0.3118675362266461}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(7*Pi)/15]^2, 0.693545187289426}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.8605642566348376}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646136962}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(7*Pi)/15]^2, 0.8605642566348376}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.2475429541754062}, 
     {5*Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160924}, {(-1 + \
Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.2475429541754062}, 
     {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, \
{17/4, 1.299038105676658}, 
     {5*Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160924}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.2475429541754062}}], \
Line[{{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, {17/4, \
1.299038105676658}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 
      1.4024710170213426}}], Line[{{-Cos[(7*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 
      1.5096856680207968}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, \
1.5605942189297979}, 
     {5*Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.491782843052409}, {(5 - \
Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5605942189297979}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5507915961279441}, 
     {5*Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524107}, \
{5*Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.491782843052409}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.5605942189297979}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5507915961279441}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{5*Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524107}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(7*Pi)/15]^2, 1.5507915961279441}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, \
{11/4, 1.299038105676658}, 
     {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}}], \
Line[{{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 1.1666712321091814}, 
     {5*Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, {11/4, \
1.299038105676658}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 
      1.3494565251821802}}], Line[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 
      1.1666712321091814}, {-Cos[(7*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
      0.9410557119019617}, {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, \
0.88167787843871}, {5*Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 
      1.1147172382160917}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(11*Pi)/30]^2*Sin[(7*Pi)/15]^2, 
      1.1666712321091814}}], Line[{{-Cos[(7*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
      0.9410557119019617}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, \
0.6884858883697308}, 
     {5*Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646137006}, {(5*(-1 \
+ Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6884858883697308}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^4, 0.442263528432697}, 
     {5*Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, \
{5*Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646137006}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(7*Pi)/15]^2, 0.6884858883697308}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^4, 0.442263528432697}, 
     {-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, {2, 0}, \
{5*Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^4, 0.442263528432697}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432695}, \
{5*Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.311867536226639}, {2, 0}, 
     {-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432695}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697308}, 
     {5*Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, \
{5*Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.311867536226639}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432695}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697308}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697308}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.166671232109181}, 
     {5*Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.1147172382160913}, {(5*(-1 \
+ Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.166671232109181}, 
     {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, \
{11/4, 1.299038105676658}, 
     {5*Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.1147172382160913}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.166671232109181}}], \
Line[{{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, {11/4, \
1.299038105676658}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 
      1.3494565251821802}}], Line[{{-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
      1.4795217391705875}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, \
1.5507915961279435}, 
     {5*Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524107}, {(5*(5 \
- Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5507915961279435}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189298}, 
     {5*Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.49178284305241}, \
{5*Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524107}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5507915961279435}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189298}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, \
{5*Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.49178284305241}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189298}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, \
{17/4, 1.299038105676658}, 
     {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, \
{-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}}], \
Line[{{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, 
     {5*Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.1147172382160893}, {17/4, \
1.299038105676658}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 
      1.4024710170213426}}], Line[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
      1.2475429541754004}, {-Cos[(7*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/8, \
1.05907701923914}, 
     {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.1147172382160893}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348376}, 
     {5*Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646136962}, {(-1 + \
Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348376}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.693545187289426}, 
     {5*Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266461}, \
{5*Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646136962}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348376}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.693545187289426}, 
     {-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}, {5, 0}, \
{5*Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266461}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.693545187289426}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.693545187289426}, \
{5*Cos[(31*Pi)/30]^2 + 2*Sin[(31*Pi)/30]^2, 0.3118675362266461}, {5, 0}, 
     {-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.693545187289426}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348376}, 
     {5*Cos[(16*Pi)/15]^2 + 2*Sin[(16*Pi)/15]^2, 0.6101049646136962}, \
{5*Cos[(31*Pi)/30]^2 + 2*Sin[(31*Pi)/30]^2, 0.3118675362266461}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.693545187289426}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348376}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(16*Pi)/15]^2 + 2*Sin[(16*Pi)/15]^2, 0.6101049646136962}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348376}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.247542954175402}, 
     {5*Cos[(17*Pi)/15]^2 + 2*Sin[(17*Pi)/15]^2, 1.1147172382160924}, {(-1 + \
Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.247542954175402}, 
     {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, \
{17/4, 1.299038105676658}, 
     {5*Cos[(17*Pi)/15]^2 + 2*Sin[(17*Pi)/15]^2, 1.1147172382160924}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.247542954175402}}], \
Line[{{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, {17/4, \
1.299038105676658}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 
      1.4024710170213426}}], Line[{{-Cos[(7*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 
      1.5096856680207968}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(37*Pi)/30]^2, \
1.5605942189297979}, 
     {5*Cos[(37*Pi)/30]^2 + 2*Sin[(37*Pi)/30]^2, 1.491782843052409}, {(5 - \
Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297979}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.5507915961279446}, 
     {5*Cos[(19*Pi)/15]^2 + 2*Sin[(19*Pi)/15]^2, 1.49178284305241}, \
{5*Cos[(37*Pi)/30]^2 + 2*Sin[(37*Pi)/30]^2, 1.491782843052409}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297979}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.5507915961279446}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{5*Cos[(19*Pi)/15]^2 + 2*Sin[(19*Pi)/15]^2, 1.49178284305241}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.5507915961279446}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, \
{11/4, 1.299038105676658}, 
     {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}}], \
Line[{{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.166671232109181}, 
     {5*Cos[(41*Pi)/30]^2 + 2*Sin[(41*Pi)/30]^2, 1.1147172382160913}, {11/4, \
1.299038105676658}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 
      1.3494565251821802}}], Line[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(41*Pi)/30]^2, 
      1.166671232109181}, {-Cos[(7*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/4, \
0.9410557119019617}, 
     {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(41*Pi)/30]^2 + 2*Sin[(41*Pi)/30]^2, 1.1147172382160913}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.166671232109181}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697313}, 
     {5*Cos[(43*Pi)/30]^2 + 2*Sin[(43*Pi)/30]^2, 0.6101049646137006}, {(5*(-1 \
+ Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697313}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432698}, 
     {5*Cos[(22*Pi)/15]^2 + 2*Sin[(22*Pi)/15]^2, 0.31186753622664043}, \
{5*Cos[(43*Pi)/30]^2 + 2*Sin[(43*Pi)/30]^2, 0.6101049646137006}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697313}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432698}, 
     {-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, {2, 0}, \
{5*Cos[(22*Pi)/15]^2 + 2*Sin[(22*Pi)/15]^2, 0.31186753622664043}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432698}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, \
{5*Cos[(23*Pi)/15]^2 + 2*Sin[(23*Pi)/15]^2, 0.31186753622664043}, {2, 0}, 
     {-Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697313}, 
     {5*Cos[(47*Pi)/30]^2 + 2*Sin[(47*Pi)/30]^2, 0.6101049646137013}, \
{5*Cos[(23*Pi)/15]^2 + 2*Sin[(23*Pi)/15]^2, 0.31186753622664043}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697313}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(47*Pi)/30]^2 + 2*Sin[(47*Pi)/30]^2, 0.6101049646137013}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697313}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091806}, 
     {5*Cos[(49*Pi)/30]^2 + 2*Sin[(49*Pi)/30]^2, 1.1147172382160908}, {(5*(-1 \
+ Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, 
     {-Cos[(7*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9410557119019617}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091806}, 
     {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, \
{11/4, 1.299038105676658}, 
     {5*Cos[(49*Pi)/30]^2 + 2*Sin[(49*Pi)/30]^2, 1.1147172382160908}, \
{-Cos[(7*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(7*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091806}}], \
Line[{{-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 1.3494565251821802}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}, 
     {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, {11/4, \
1.299038105676658}, {-Cos[(7*Pi)/15]^2 + (11*Sin[(7*Pi)/15]^2)/4, 
      1.3494565251821802}}], Line[{{-Cos[(7*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
      1.4795217391705875}, {-Cos[(7*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(26*Pi)/15]^2, \
1.5507915961279446}, 
     {5*Cos[(26*Pi)/15]^2 + 2*Sin[(26*Pi)/15]^2, 1.49178284305241}, {(5*(5 - \
Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, 
     {-Cos[(7*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4795217391705875}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.5507915961279446}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.560594218929799}, 
     {5*Cos[(53*Pi)/30]^2 + 2*Sin[(53*Pi)/30]^2, 1.49178284305241}, \
{5*Cos[(26*Pi)/15]^2 + 2*Sin[(26*Pi)/15]^2, 1.49178284305241}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.5507915961279446}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.560594218929799}, 
     {-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, \
{5*Cos[(53*Pi)/30]^2 + 2*Sin[(53*Pi)/30]^2, 1.49178284305241}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.560594218929799}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}, 
     {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, \
{17/4, 1.299038105676658}, 
     {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, \
{-Cos[(7*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/16, 1.5096856680207968}}], \
Line[{{-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 1.4024710170213426}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.247542954175402}, 
     {5*Cos[(28*Pi)/15]^2 + 2*Sin[(28*Pi)/15]^2, 1.1147172382160893}, {17/4, \
1.299038105676658}, {-Cos[(7*Pi)/15]^2 + (17*Sin[(7*Pi)/15]^2)/4, 
      1.4024710170213426}}], Line[{{-Cos[(7*Pi)/15]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(28*Pi)/15]^2, 
      1.247542954175402}, {-Cos[(7*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(7*Pi)/15]^2)/8, \
1.05907701923914}, 
     {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(28*Pi)/15]^2 + 2*Sin[(28*Pi)/15]^2, 1.1147172382160893}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.247542954175402}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348355}, 
     {5*Cos[(29*Pi)/15]^2 + 2*Sin[(29*Pi)/15]^2, 0.6101049646136991}, {(-1 + \
Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, 
     {-Cos[(7*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/8, 1.05907701923914}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348355}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894184}, 
     {5*Cos[(59*Pi)/30]^2 + 2*Sin[(59*Pi)/30]^2, 0.3118675362266461}, \
{5*Cos[(29*Pi)/15]^2 + 2*Sin[(29*Pi)/15]^2, 0.6101049646136991}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348355}}], 
   Line[{{-Cos[(7*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894184}, 
     {-Cos[(7*Pi)/15]^2 + 5*Sin[(7*Pi)/15]^2, 0.6237350724532809}, {5, 0}, \
{5*Cos[(59*Pi)/30]^2 + 2*Sin[(59*Pi)/30]^2, 0.3118675362266461}, 
     {-Cos[(7*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(7*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894184}}], 
   Line[{{5, 0}, {5*Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.3118675362266461}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.6935451872894184}, \
{-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, {5, 0}}], 
   Line[{{5*Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.3118675362266461}, \
{5*Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646136962}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.8605642566348314}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.6935451872894184}, 
     {5*Cos[Pi/30]^2 + 2*Sin[Pi/30]^2, 0.3118675362266461}}], \
Line[{{5*Cos[Pi/15]^2 + 2*Sin[Pi/15]^2, 0.6101049646136962}, 
     {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + 
       (5*(5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.8605642566348314}, {5*Cos[Pi/15]^2 \
+ 2*Sin[Pi/15]^2, 0.6101049646136962}}], 
   Line[{{(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160924}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.247542954175402}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}}], \
Line[{{5*Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160924}, 
     {17/4, 1.299038105676658}, {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, \
1.4024710170213388}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.247542954175402}, 
     {5*Cos[(2*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2, 1.1147172382160924}}], 
   Line[{{17/4, 1.299038105676658}, {(5 - Sqrt[5])/4 + (5*(1 + \
Sqrt[5])^2)/16, 1.4265847744427318}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{17/4, 1.299038105676658}}], 
   Line[{{(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, \
{5*Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.491782843052409}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5605942189297972}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}}], \
Line[{{5*Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.491782843052409}, 
     {5*Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524107}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5507915961279435}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5605942189297972}, \
{5*Cos[(7*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2, 1.491782843052409}}], 
   Line[{{5*Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524107}, \
{(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5507915961279435}, 
     {5*Cos[(4*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2, 1.4917828430524107}}], \
Line[{{(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, 
     {11/4, 1.299038105676658}, {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, \
1.34945652518218}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}}], 
   Line[{{11/4, 1.299038105676658}, {5*Cos[(11*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1666712321091803}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, {11/4, \
1.299038105676658}}], 
   Line[{{5*Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}, \
{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1666712321091803}, 
     {5*Cos[(11*Pi)/30]^2 + 2*Sin[(11*Pi)/30]^2, 1.1147172382160917}}], 
   Line[{{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646137006}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6884858883697301}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}}], \
Line[{{5*Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646137006}, 
     {5*Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432696}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6884858883697301}, \
{5*Cos[(13*Pi)/30]^2 + 2*Sin[(13*Pi)/30]^2, 0.6101049646137006}}], 
   Line[{{5*Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}, {2, \
0}, {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432696}, 
     {5*Cos[(7*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2, 0.311867536226639}}], \
Line[{{2, 0}, {5*Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.311867536226639}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^4, 0.442263528432694}, 
     {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, {2, 0}}], \

   Line[{{5*Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.311867536226639}, \
{5*Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697295}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^4, 0.442263528432694}, 
     {5*Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.311867536226639}}], \
Line[{{5*Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, 
     {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + 
       ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697295}, \
{5*Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}}], 
   Line[{{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.1147172382160913}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.16667123210918}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}}], \
Line[{{5*Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.1147172382160913}, 
     {11/4, 1.299038105676658}, {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, \
1.34945652518218}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.16667123210918}, 
     {5*Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.1147172382160913}}], 
   Line[{{11/4, 1.299038105676658}, {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427305}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, {11/4, \
1.299038105676658}}], 
   Line[{{(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{5*Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524107}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.550791596127943}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}}], \
Line[{{5*Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524107}, 
     {5*Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.49178284305241}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189297979}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.550791596127943}, \
{5*Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524107}}], 
   Line[{{5*Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.49178284305241}, {(5 - \
Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189297979}, 
     {5*Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.49178284305241}}], \
Line[{{(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, 
     {17/4, 1.299038105676658}, {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, \
1.4024710170213388}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}}], 
   Line[{{17/4, 1.299038105676658}, {5*Cos[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2, 1.1147172382160893}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{17/4, 1.299038105676658}}], 
   Line[{{5*Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.1147172382160893}, \
{(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, 
     {5*Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.1147172382160893}}], 
   Line[{{(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646136962}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348314}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}}], \
Line[{{5*Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646136962}, 
     {5*Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266461}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6935451872894184}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348314}, \
{5*Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646136962}}], 
   Line[{{5*Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266461}, {5, \
0}, {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6935451872894184}, 
     {5*Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266461}}], 
   Line[{{5, 0}, {5*Cos[(31*Pi)/30]^2 + 2*Sin[(31*Pi)/30]^2, \
0.3118675362266461}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.6935451872894184}, 
     {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, {5, 0}}], 
   Line[{{5*Cos[(31*Pi)/30]^2 + 2*Sin[(31*Pi)/30]^2, 0.3118675362266461}, \
{5*Cos[(16*Pi)/15]^2 + 2*Sin[(16*Pi)/15]^2, 0.6101049646136962}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348314}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.6935451872894184}, 
     {5*Cos[(31*Pi)/30]^2 + 2*Sin[(31*Pi)/30]^2, 0.3118675362266461}}], 
   Line[{{5*Cos[(16*Pi)/15]^2 + 2*Sin[(16*Pi)/15]^2, 0.6101049646136962}, \
{(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348314}, 
     {5*Cos[(16*Pi)/15]^2 + 2*Sin[(16*Pi)/15]^2, 0.6101049646136962}}], 
   Line[{{(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(17*Pi)/15]^2 + 2*Sin[(17*Pi)/15]^2, 1.1147172382160924}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.2475429541753962}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}}], \
Line[{{5*Cos[(17*Pi)/15]^2 + 2*Sin[(17*Pi)/15]^2, 1.1147172382160924}, 
     {17/4, 1.299038105676658}, {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, \
1.4024710170213388}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.2475429541753962}, 
     {5*Cos[(17*Pi)/15]^2 + 2*Sin[(17*Pi)/15]^2, 1.1147172382160924}}], 
   Line[{{17/4, 1.299038105676658}, {(5 - Sqrt[5])/4 + (5*(1 + \
Sqrt[5])^2)/16, 1.4265847744427318}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{17/4, 1.299038105676658}}], 
   Line[{{(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, \
{5*Cos[(37*Pi)/30]^2 + 2*Sin[(37*Pi)/30]^2, 1.491782843052409}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297972}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}}], \
Line[{{5*Cos[(37*Pi)/30]^2 + 2*Sin[(37*Pi)/30]^2, 1.491782843052409}, 
     {5*Cos[(19*Pi)/15]^2 + 2*Sin[(19*Pi)/15]^2, 1.49178284305241}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.550791596127943}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297972}, \
{5*Cos[(37*Pi)/30]^2 + 2*Sin[(37*Pi)/30]^2, 1.491782843052409}}], 
   Line[{{5*Cos[(19*Pi)/15]^2 + 2*Sin[(19*Pi)/15]^2, 1.49178284305241}, \
{(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.550791596127943}, 
     {5*Cos[(19*Pi)/15]^2 + 2*Sin[(19*Pi)/15]^2, 1.49178284305241}}], \
Line[{{(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, 
     {11/4, 1.299038105676658}, {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, \
1.34945652518218}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}}], 
   Line[{{11/4, 1.299038105676658}, {5*Cos[(41*Pi)/30]^2 + \
2*Sin[(41*Pi)/30]^2, 1.1147172382160913}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.16667123210918}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, {11/4, \
1.299038105676658}}], 
   Line[{{5*Cos[(41*Pi)/30]^2 + 2*Sin[(41*Pi)/30]^2, 1.1147172382160913}, \
{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.16667123210918}, 
     {5*Cos[(41*Pi)/30]^2 + 2*Sin[(41*Pi)/30]^2, 1.1147172382160913}}], 
   Line[{{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(43*Pi)/30]^2 + 2*Sin[(43*Pi)/30]^2, 0.6101049646137006}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697308}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}}], \
Line[{{5*Cos[(43*Pi)/30]^2 + 2*Sin[(43*Pi)/30]^2, 0.6101049646137006}, 
     {5*Cos[(22*Pi)/15]^2 + 2*Sin[(22*Pi)/15]^2, 0.31186753622664043}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432697}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697308}, \
{5*Cos[(43*Pi)/30]^2 + 2*Sin[(43*Pi)/30]^2, 0.6101049646137006}}], 
   Line[{{5*Cos[(22*Pi)/15]^2 + 2*Sin[(22*Pi)/15]^2, 0.31186753622664043}, \
{2, 0}, {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432697}, 
     {5*Cos[(22*Pi)/15]^2 + 2*Sin[(22*Pi)/15]^2, 0.31186753622664043}}], 
   Line[{{2, 0}, {5*Cos[(23*Pi)/15]^2 + 2*Sin[(23*Pi)/15]^2, \
0.31186753622664043}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, 
     {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, {2, 0}}], \

   Line[{{5*Cos[(23*Pi)/15]^2 + 2*Sin[(23*Pi)/15]^2, 0.31186753622664043}, \
{5*Cos[(47*Pi)/30]^2 + 2*Sin[(47*Pi)/30]^2, 0.6101049646137013}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697308}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, 
     {5*Cos[(23*Pi)/15]^2 + 2*Sin[(23*Pi)/15]^2, 0.31186753622664043}}], 
   Line[{{5*Cos[(47*Pi)/30]^2 + 2*Sin[(47*Pi)/30]^2, 0.6101049646137013}, \
{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697308}, 
     {5*Cos[(47*Pi)/30]^2 + 2*Sin[(47*Pi)/30]^2, 0.6101049646137013}}], 
   Line[{{(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}, \
{5*Cos[(49*Pi)/30]^2 + 2*Sin[(49*Pi)/30]^2, 1.1147172382160908}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091794}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {(5*(-1 + Sqrt[5])^2)/16 + (5 + Sqrt[5])/4, 0.88167787843871}}], \
Line[{{5*Cos[(49*Pi)/30]^2 + 2*Sin[(49*Pi)/30]^2, 1.1147172382160908}, 
     {11/4, 1.299038105676658}, {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, \
1.34945652518218}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091794}, 
     {5*Cos[(49*Pi)/30]^2 + 2*Sin[(49*Pi)/30]^2, 1.1147172382160908}}], 
   Line[{{11/4, 1.299038105676658}, {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, \
1.4265847744427305}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, {11/4, \
1.299038105676658}}], 
   Line[{{(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}, \
{5*Cos[(26*Pi)/15]^2 + 2*Sin[(26*Pi)/15]^2, 1.49178284305241}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.550791596127943}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {(5*(5 - Sqrt[5]))/8 + (1 + Sqrt[5])^2/8, 1.4265847744427305}}], \
Line[{{5*Cos[(26*Pi)/15]^2 + 2*Sin[(26*Pi)/15]^2, 1.49178284305241}, 
     {5*Cos[(53*Pi)/30]^2 + 2*Sin[(53*Pi)/30]^2, 1.49178284305241}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.5605942189297983}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.550791596127943}, \
{5*Cos[(26*Pi)/15]^2 + 2*Sin[(26*Pi)/15]^2, 1.49178284305241}}], 
   Line[{{5*Cos[(53*Pi)/30]^2 + 2*Sin[(53*Pi)/30]^2, 1.49178284305241}, {(5 - \
Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.5605942189297983}, 
     {5*Cos[(53*Pi)/30]^2 + 2*Sin[(53*Pi)/30]^2, 1.49178284305241}}], \
Line[{{(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}, 
     {17/4, 1.299038105676658}, {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, \
1.4024710170213388}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {(5 - Sqrt[5])/4 + (5*(1 + Sqrt[5])^2)/16, 1.4265847744427318}}], 
   Line[{{17/4, 1.299038105676658}, {5*Cos[(28*Pi)/15]^2 + \
2*Sin[(28*Pi)/15]^2, 1.1147172382160893}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.2475429541754004}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{17/4, 1.299038105676658}}], 
   Line[{{5*Cos[(28*Pi)/15]^2 + 2*Sin[(28*Pi)/15]^2, 1.1147172382160893}, \
{(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.2475429541754004}, 
     {5*Cos[(28*Pi)/15]^2 + 2*Sin[(28*Pi)/15]^2, 1.1147172382160893}}], 
   Line[{{(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}, \
{5*Cos[(29*Pi)/15]^2 + 2*Sin[(29*Pi)/15]^2, 0.6101049646136991}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348294}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {(-1 + Sqrt[5])^2/8 + (5*(5 + Sqrt[5]))/8, 0.8816778784387135}}], \
Line[{{5*Cos[(29*Pi)/15]^2 + 2*Sin[(29*Pi)/15]^2, 0.6101049646136991}, 
     {5*Cos[(59*Pi)/30]^2 + 2*Sin[(59*Pi)/30]^2, 0.3118675362266461}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894107}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348294}, \
{5*Cos[(29*Pi)/15]^2 + 2*Sin[(29*Pi)/15]^2, 0.6101049646136991}}], 
   Line[{{5*Cos[(59*Pi)/30]^2 + 2*Sin[(59*Pi)/30]^2, 0.3118675362266461}, {5, \
0}, {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894107}, 
     {5*Cos[(59*Pi)/30]^2 + 2*Sin[(59*Pi)/30]^2, 0.3118675362266461}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.6935451872894184}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 1.2512975557014567}, \
{-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, 
     {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.6935451872894184}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.8605642566348314}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 1.3346849311080466}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(8*Pi)/15]^2, 0.6935451872894184}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.8605642566348314}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 1.3346849311080466}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(8*Pi)/15]^2, 0.8605642566348314}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.247542954175402}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.5625819810819546}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.247542954175402}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.5625819810819546}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.247542954175402}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, \
{-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, \
{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5605942189297972}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5605942189297972}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5507915961279435}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.705691841463222}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.5605942189297972}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5507915961279435}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.705691841463222}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(8*Pi)/15]^2, 1.5507915961279435}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1666712321091803}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.3017122836390151}, \
{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1666712321091803}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.3017122836390151}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(8*Pi)/15]^2, 1.1666712321091803}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6884858883697301}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600714}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6884858883697301}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432696}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781076}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600714}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(8*Pi)/15]^2, 0.6884858883697301}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432696}, 
     {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, \
{-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781076}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(8*Pi)/15]^2, 0.442263528432696}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^4, 0.442263528432694}, {-Cos[(17*Pi)/30]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 
      0.6880869119781069}, {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, \
0.6101049646136991}, {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 
      0.31186753622663826}}], Line[{{-Cos[(8*Pi)/15]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^4, 0.442263528432694}, \

     {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697295}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^4, 0.8724918816600716}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781069}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^4, 0.442263528432694}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697295}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^4, 0.8724918816600716}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6884858883697295}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.16667123210918}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.16667123210918}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.16667123210918}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, \
{-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, \
{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.550791596127943}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.550791596127943}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189297979}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.550791596127943}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189297979}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5605942189297979}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, \
{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.2475429541754004}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348314}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348314}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6935451872894184}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.8605642566348314}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6935451872894184}, 
     {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, \
{-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6935451872894184}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.6935451872894184}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(17*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, \
{-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, 
     {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.6935451872894184}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348314}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(31*Pi)/30]^2, 0.6935451872894184}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348314}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(16*Pi)/15]^2, 0.8605642566348314}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.2475429541753962}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.2475429541753962}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.2475429541753962}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, \
{-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, \
{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297972}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297972}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.550791596127943}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.5605942189297972}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.550791596127943}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.550791596127943}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.16667123210918}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(17*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, \
{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.16667123210918}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.16667123210918}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697308}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.8724918816600724}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697308}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432697}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781079}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.8724918816600724}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6884858883697308}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432697}, 
     {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, \
{-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781079}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.442263528432697}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, \
{-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, 
     {-Cos[(8*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2, 0.31186753622663826}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697308}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.442263528432697}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697308}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6884858883697308}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 \
+ Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091794}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(8*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9410557119019617}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091794}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.1666712321091794}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}, \
{-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, \
{-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, \
{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, 
     {-Cos[(8*Pi)/15]^2 + (11*Sin[(8*Pi)/15]^2)/4, 1.34945652518218}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.550791596127943}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(8*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4795217391705868}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.550791596127943}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.5605942189297983}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.550791596127943}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.5605942189297983}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.5605942189297983}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(8*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/16, 1.5096856680207957}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}, \
{-Cos[(8*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(8*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.2475429541754004}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(17*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, \
{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, 
     {-Cos[(8*Pi)/15]^2 + (17*Sin[(8*Pi)/15]^2)/4, 1.4024710170213388}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.2475429541754004}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.2475429541754004}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348294}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(8*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/8, 1.0590770192391334}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348294}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894107}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/15]^2, 0.8605642566348294}}], 
   Line[{{-Cos[(8*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894107}, 
     {-Cos[(8*Pi)/15]^2 + 5*Sin[(8*Pi)/15]^2, 0.6237350724532723}, \
{-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}, 
     {-Cos[(8*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(8*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(59*Pi)/30]^2, 0.6935451872894107}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 1.2512975557014567}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
     {-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 1.3346849311080466}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(17*Pi)/30]^2, 1.2512975557014567}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 1.3346849311080466}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(17*Pi)/30]^2, 1.3346849311080466}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.5625819810819546}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.5625819810819546}, 
     {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, \
{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.5625819810819546}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, {-(-1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + 
       (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, {-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.7395717696563637}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.705691841463222}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.7395717696563637}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.705691841463222}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(17*Pi)/30]^2, 1.705691841463222}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \
{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.3017122836390151}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, {-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.3017122836390151}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(17*Pi)/30]^2, 1.3017122836390151}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600714}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600714}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781076}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(17*Pi)/30]^2, 0.8724918816600714}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781076}, 
     {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781076}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781069}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
     {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781069}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^4, 0.8724918816600716}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(17*Pi)/30]^2, 0.6880869119781069}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^4, 0.8724918816600716}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^4, 0.8724918816600716}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}, 
     {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \
{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.301712283639015}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + 
       ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, {-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.705691841463221}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.7395717696563633}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, \
{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, {-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.5625819810819546}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 1.3346849311080466}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 1.2512975557014567}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(17*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
     {-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(31*Pi)/30]^2, 1.2512975557014567}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(16*Pi)/15]^2, 1.3346849311080466}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}, 
     {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, \
{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(17*Pi)/15]^2, 1.5625819810819535}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, {-(-1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + 
       (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, {-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(37*Pi)/30]^2, 1.7395717696563637}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/15]^2, 1.705691841463221}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \
{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(17*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, {-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.3017122836390156}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.8724918816600724}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.8724918816600724}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781079}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.8724918816600724}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781079}, 
     {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.6880869119781079}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, {-(-1 + \
Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, 
     {-Cos[(17*Pi)/30]^2 + 2*Sin[(17*Pi)/30]^2, 0.6101049646136991}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.6880869119781079}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.8724918816600722}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(17*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0910840571723004}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}, 
     {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \
{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.3017122836390145}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}, \
{-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + 
       ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, {-(-1 + \
Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, 
     {-Cos[(17*Pi)/30]^2 + (11*Sin[(17*Pi)/30]^2)/4, 1.4819447816621787}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(17*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.6189603147994467}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(26*Pi)/15]^2, 1.705691841463221}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(53*Pi)/30]^2, 1.7395717696563637}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}, 
     {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, \
{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(17*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/16, 1.7222389198769947}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}, \
{-Cos[(17*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(17*Pi)/30]^2 + 
       2*Sin[(17*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, {-(-1 + \
Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, 
     {-Cos[(17*Pi)/30]^2 + (17*Sin[(17*Pi)/30]^2)/4, 1.6596693760099315}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(28*Pi)/15]^2, 1.5625819810819546}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(17*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/8, 1.4470248504530066}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/15]^2, 1.3346849311080493}}], 
   Line[{{-Cos[(17*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}, 
     {-Cos[(17*Pi)/30]^2 + 5*Sin[(17*Pi)/30]^2, 1.2202099292273982}, {-(-1 + \
Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}, 
     {-Cos[(17*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(17*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(59*Pi)/30]^2, 1.2512975557014525}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 2.235484296800203}, \
{-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 2.2513313265781}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 2.235484296800203}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/30]^2)/4, 1.778627524809822}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 2.2513313265781}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[Pi/15]^2)/4, 1.8202053857959208}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 \
+ Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.284543605895154}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.284543605895154}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 1.9339672857886054}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + 
       (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, \
{-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, \
{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 2.2025704634356607}, 
     {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.1122635155465685}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 2.2025704634356607}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 1.971285258569849}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.1122635155465685}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 1.908454380799519}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
     {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}, \
{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.476404966738898}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 \
+ Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.289570859044146}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261809}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.289570859044146}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.0875191232355919}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, \
{-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261809}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 0.9393665425693402}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, {-(-1 \
+ Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261806}, \
{-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}, 
     {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.289570859044146}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261806}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 0.9393665425693396}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.289570859044146}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.0875191232355914}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 \
+ Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^4, 1.650686345432751}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^4, 1.650686345432751}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4764049667388979}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + 
       ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, \
{-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, \
{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}, 
     {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.9084543807995193}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.9712852585698495}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
     {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895153}, \
{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895153}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.9339672857886046}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 \
+ Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.2513313265781}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800203}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.2513313265781}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 1.8202053857959208}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800203}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 1.778627524809822}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800203}, \
{-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578101}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800203}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 1.778627524809822}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578101}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 1.82020538579592}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 \
+ Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895153}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895153}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 1.9339672857886046}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + 
       (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, \
{-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, \
{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.2025704634356607}, 
     {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.1122635155465685}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.2025704634356607}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 1.971285258569849}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.1122635155465685}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 1.9084543807995193}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
     {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.650686345432751}, \
{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.650686345432751}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.4764049667388972}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 \
+ Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.2895708590441464}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261817}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.2895708590441464}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.0875191232355927}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}, 
     {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, \
{-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261817}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 0.9393665425693406}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}, {-(-1 \
+ Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726181}, \
{-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}, 
     {-(-1 + Sqrt[5])^2/16 + (5 + Sqrt[5])/4, 0.8816778784387097}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441461}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726181}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 0.9393665425693402}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441461}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.0875191232355923}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 \
+ Sqrt[5])^2/32, 1.2790742990138142}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327505}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(-1 + Sqrt[5])^2*(5 + Sqrt[5]))/128 + (5 + \
Sqrt[5])^2/32, 1.2790742990138142}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327505}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.4764049667388974}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + 
       ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, \
{-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, \
{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, 
     {-(-1 + Sqrt[5])^2/16 + (11*(5 + Sqrt[5]))/32, 1.6555895184432492}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.1122635155465685}, 
     {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.8022456366013615}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.1122635155465685}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 1.9084543807995193}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 1.9712852585698486}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
     {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
     {-(-1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 1.99216913656241}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}, \
{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + 
       ((5 + Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.284543605895153}, \
{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, 
     {-(-1 + Sqrt[5])^2/16 + (17*(5 + Sqrt[5]))/32, 1.976615915035449}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.284543605895153}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 1.9339672857886046}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 \
+ Sqrt[5])^2)/64, 1.8768892930626264}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578101}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-(-1 + Sqrt[5])^2/16 + ((-1 + Sqrt[5])^2*(5 + Sqrt[5]))/64 + (5*(5 + \
Sqrt[5])^2)/64, 1.8768892930626264}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800203}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578101}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 1.8202053857959217}}], 
   Line[{{-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 \
+ Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5]))/8, 1.763355756877422}, \
{-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800203}, 
     {-(-1 + Sqrt[5])^2/16 + (5*(5 + Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 + \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 1.778627524809822}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 2.235484296800203}, {-1/4 + \
(15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 2.5979598975817524}, 
     {7/2, 2.598076211353316}, {-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, \
2.2294344764321816}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 2.235484296800203}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 2.2513313265781}, 
     {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 2.5962550390555568}, \
{-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 2.5979598975817524}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(19*Pi)/30]^2, 2.235484296800203}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, 2.2513313265781}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 
      2.5962550390555568}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[Pi/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[Pi/15]^2*Sin[(19*Pi)/30]^2, \
2.2513313265781}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.284543605895154}, 
     {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 
      2.2706462108209}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
      2.284543605895154}, {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, \
2.283369148915068}, {47/16, 2.536452985962878}, 
     {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.284543605895154}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, \
{-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, {-1/4 + \
(3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}, 
     {47/16, 2.536452985962878}, {-Cos[(19*Pi)/30]^2 + \
(17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 2.2025704634356607}, 
     {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
      2.4790558351445977}, {-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
      2.2583039834915453}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
      2.2025704634356607}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, \
2.1122635155465685}, 
     {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}, {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \

      2.3948140222646948}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
      2.2025704634356607}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
      2.1122635155465685}, {-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
      1.9869545564435855}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + \
Sqrt[5])^2)/32, 2.14040166785146}, 
     {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(19*Pi)/30]^2, 2.1122635155465685}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
     {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, \
{29/16, 1.9754350786598884}, 
     {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, 
     {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}, {-1/4 + \
(15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, 
      1.7955424168801202}, {29/16, 1.9754350786598884}, {-Cos[(19*Pi)/30]^2 + \
(11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.6506863454327514}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + \
(3*Sin[(11*Pi)/30]^2)/2, 
      1.7955424168801202}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
      1.6506863454327514}}], Line[{{-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
      1.4628718195622255}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
      1.289570859044146}, {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 1.454550222063749}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.289570859044146}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261809}, 
     {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}, {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 
      1.454550222063749}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
      1.289570859044146}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
      1.1623542887261809}, {-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, \
1.114717238216091}, {5/4, 1.299038105676658}, 
     {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261809}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261806}, {-1/4 + \
(15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, 1.3407174947497686}, 
     {5/4, 1.299038105676658}, {-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, \
1.114717238216091}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 1.1623542887261806}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.289570859044146}, 
     {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}, {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + \
(3*Sin[(8*Pi)/15]^2)/2, 
      1.3407174947497686}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(19*Pi)/30]^2, 
      1.1623542887261806}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 
      1.289570859044146}, {-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
      1.4628718195622255}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}, 
     {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(19*Pi)/30]^2, 1.289570859044146}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^4, 1.650686345432751}, 
     {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, \
1.7955424168801195}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \

      1.61498867371741}, {-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
      1.4628718195622255}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^4, \
1.650686345432751}, 
     {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, \
{29/16, 1.9754350786598884}, 
     {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, \
1.7955424168801195}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^4, 1.650686345432751}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, \
{-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, {-1/4 + \
(15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
     {29/16, 1.9754350786598884}, {-Cos[(19*Pi)/30]^2 + \
(11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}, 
     {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 
      2.14040166785146}, {-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
      1.9869545564435855}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 
      2.112263515546568}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
      2.2025704634356615}, {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + \
(3*Sin[(23*Pi)/30]^2)/2, 2.394814022264696}, 
     {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.112263515546568}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.2025704634356615}, 
     {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + \
(3*Sin[(23*Pi)/30]^2)/2, 
      2.394814022264696}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 
      2.2025704634356615}}], Line[{{-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
      2.2583039834915453}, {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, \
2.283369148915068}, {47/16, 2.536452985962878}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, 
     {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895153}, {-1/4 + \
(15*Cos[(13*Pi)/15]^2)/4 + (3*Sin[(13*Pi)/15]^2)/2, 2.5712732770958877}, 
     {47/16, 2.536452985962878}, {-Cos[(19*Pi)/30]^2 + \
(17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.284543605895153}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + \
(3*Sin[(13*Pi)/15]^2)/2, 
      2.5712732770958877}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
      2.284543605895153}}], Line[{{-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 
      2.2706462108209}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.2513313265781}, 
     {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + (3*Sin[(14*Pi)/15]^2)/2, \
2.5962550390555568}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 
      2.2706462108209}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
      2.2513313265781}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800203}, 
     {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + \
(3*Sin[(14*Pi)/15]^2)/2, 
      2.5962550390555568}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 
      2.2513313265781}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
      2.235484296800203}, {-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, \
2.2294344764321816}, {7/2, 2.598076211353316}, 
     {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.235484296800203}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, 2.2294344764321816}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800203}, {-1/4 + \
(15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, 2.5979598975817524}, 
     {7/2, 2.598076211353316}, {-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, \
2.2294344764321816}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.235484296800203}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.251331326578101}, 
     {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + (3*Sin[(16*Pi)/15]^2)/2, \
2.5962550390555568}, {-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + \
(3*Sin[(31*Pi)/30]^2)/2, 
      2.5979598975817524}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(31*Pi)/30]^2, 
      2.235484296800203}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
      2.251331326578101}, {-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, \
2.2706462108209}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + \
(3*Sin[(16*Pi)/15]^2)/2, 
      2.5962550390555568}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
      2.251331326578101}}], Line[{{-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 
      2.2706462108209}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895153}, 
     {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 
      2.2706462108209}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
      2.284543605895153}, {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, \
2.283369148915068}, {47/16, 2.536452985962878}, 
     {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.284543605895153}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, \
{-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, {-1/4 + \
(3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}, 
     {47/16, 2.536452985962878}, {-Cos[(19*Pi)/30]^2 + \
(17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.2025704634356607}, 
     {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
      2.4790558351445977}, {-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
      2.2583039834915453}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
      2.2025704634356607}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
      2.1122635155465685}, {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + \
(3*Sin[(19*Pi)/15]^2)/2, 2.2816570417008593}, 
     {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.2025704634356607}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.1122635155465685}, 
     {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
     {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + \
(3*Sin[(19*Pi)/15]^2)/2, 
      2.2816570417008593}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(19*Pi)/15]^2, 
      2.1122635155465685}}], Line[{{-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
      1.9869545564435855}, {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, \
1.8302685290560392}, {29/16, 1.9754350786598884}, 
     {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, 
     {-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.650686345432751}, {-1/4 + \
(15*Cos[(41*Pi)/30]^2)/4 + (3*Sin[(41*Pi)/30]^2)/2, 1.7955424168801195}, 
     {29/16, 1.9754350786598884}, {-Cos[(19*Pi)/30]^2 + \
(11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.650686345432751}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + \
(3*Sin[(41*Pi)/30]^2)/2, 
      1.7955424168801195}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(41*Pi)/30]^2, 
      1.650686345432751}}], Line[{{-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
      1.4628718195622255}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
      1.2895708590441464}, {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + \
(3*Sin[(43*Pi)/30]^2)/2, 1.4545502220637496}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, 
     {-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.2895708590441464}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261817}, 
     {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + \
(3*Sin[(43*Pi)/30]^2)/2, 
      1.4545502220637496}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(43*Pi)/30]^2, 
      1.2895708590441464}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(22*Pi)/15]^2, 
      1.1623542887261817}, {-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, \
1.114717238216091}, {5/4, 1.299038105676658}, 
     {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.1623542887261817}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, 1.114717238216091}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726181}, {-1/4 + \
(15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, 1.340717494749769}, 
     {5/4, 1.299038105676658}, {-Cos[(19*Pi)/30]^2 + 2*Sin[(19*Pi)/30]^2, \
1.114717238216091}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.162354288726181}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441461}, 
     {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}, {-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + \
(3*Sin[(23*Pi)/15]^2)/2, 
      1.340717494749769}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/15]^2, 
      1.162354288726181}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
      1.2895708590441461}, {-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
      1.4628718195622255}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + \
Sqrt[5]))/16, 1.61498867371741}, 
     {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.2895708590441461}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.4628718195622255}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327505}, 
     {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, \
1.795542416880119}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, 
      1.61498867371741}, {-Cos[(19*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 
      1.4628718195622255}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
      1.6506863454327505}, {-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, \
1.8302685290560392}, {29/16, 1.9754350786598884}, 
     {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, \
1.795542416880119}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.6506863454327505}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}, \
{-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, {-1/4 + \
(15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
     {29/16, 1.9754350786598884}, {-Cos[(19*Pi)/30]^2 + \
(11*Sin[(19*Pi)/30]^2)/4, 1.8302685290560392}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.9869545564435855}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.1122635155465685}, 
     {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 
      2.14040166785146}, {-Cos[(19*Pi)/30]^2 + (5*(5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
      1.9869545564435855}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(26*Pi)/15]^2, 
      2.1122635155465685}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
      2.2025704634356607}, {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + \
(3*Sin[(53*Pi)/30]^2)/2, 2.3948140222646948}, 
     {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.1122635155465685}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.2025704634356607}, 
     {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + \
(3*Sin[(53*Pi)/30]^2)/2, 
      2.3948140222646948}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(53*Pi)/30]^2, 
      2.2025704634356607}}], Line[{{-Cos[(19*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 
      2.2583039834915453}, {-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, \
2.283369148915068}, {47/16, 2.536452985962878}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, 
     {-Cos[(19*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/16, 2.2583039834915453}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + (17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}, \
{-Cos[(19*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(19*Pi)/30]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.284543605895153}, {-1/4 + \
(15*Cos[(28*Pi)/15]^2)/4 + (3*Sin[(28*Pi)/15]^2)/2, 2.5712732770958877}, 
     {47/16, 2.536452985962878}, {-Cos[(19*Pi)/30]^2 + \
(17*Sin[(19*Pi)/30]^2)/4, 2.283369148915068}}], 
   Line[{{-Cos[(19*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.284543605895153}, 
     {-Cos[(19*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 2.2706462108209}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + \
(3*Sin[(28*Pi)/15]^2)/2, 
      2.5712732770958877}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(28*Pi)/15]^2, 
      2.284543605895153}}], Line[{{-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 
      2.2706462108209}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.251331326578101}, 
     {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + (3*Sin[(29*Pi)/15]^2)/2, \
2.596255039055556}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, 
      2.5891768866299354}, {-Cos[(19*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(19*Pi)/30]^2)/8, 
      2.2706462108209}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
      2.251331326578101}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800203}, 
     {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + \
(3*Sin[(29*Pi)/15]^2)/2, 
      2.596255039055556}, {-Cos[(19*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
      2.251331326578101}}], Line[{{-Cos[(19*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
      2.235484296800203}, {-Cos[(19*Pi)/30]^2 + 5*Sin[(19*Pi)/30]^2, \
2.2294344764321816}, {7/2, 2.598076211353316}, 
     {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, 
     {-Cos[(19*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(19*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.235484296800203}}], 
   Line[{{7/2, 2.598076211353316}, {-1/4 + (15*Cos[Pi/30]^2)/4 + \
(3*Sin[Pi/30]^2)/2, 2.5979598975817524}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, {7/2, \
2.598076211353316}}], 
   Line[{{-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, \
2.5979598975817524}, {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 
      2.5962550390555568}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[Pi/15]^2)/8, \
2.834803496770628}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, 
     {-1/4 + (15*Cos[Pi/30]^2)/4 + (3*Sin[Pi/30]^2)/2, 2.5979598975817524}}], \

   Line[{{-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, \
2.5962550390555568}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}, 
     {-1/4 + (15*Cos[Pi/15]^2)/4 + (3*Sin[Pi/15]^2)/2, 2.5962550390555568}}], \

   Line[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + \
(3*Sin[(2*Pi)/15]^2)/2, 
      2.5712732770958873}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, \
2.768181798733441}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}}], 
   Line[{{-1/4 + (15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, \
2.5712732770958873}, {47/16, 2.536452985962878}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}, {-1/4 + \
(15*Cos[(2*Pi)/15]^2)/4 + (3*Sin[(2*Pi)/15]^2)/2, 2.5712732770958873}}], 
   Line[{{47/16, 2.536452985962878}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + \
Sqrt[5])^2)/64, 2.4790558351445977}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {47/16, \
2.536452985962878}}], 
   Line[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + \
(3*Sin[(7*Pi)/30]^2)/2, 
      2.3948140222646948}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 
      2.5219601128218545}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}}], 
   Line[{{-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + \
(3*Sin[(4*Pi)/15]^2)/2, 
      2.281657041700859}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, \
2.392089327116677}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
     {-1/4 + (15*Cos[(7*Pi)/30]^2)/4 + (3*Sin[(7*Pi)/30]^2)/2, \
2.3948140222646948}}], 
   Line[{{-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 
      2.14040166785146}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}, 
     {-1/4 + (15*Cos[(4*Pi)/15]^2)/4 + (3*Sin[(4*Pi)/15]^2)/2, \
2.281657041700859}}], 
   Line[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, {(-5 + \
Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + 
       (1 + Sqrt[5])^4/128, 2.239718051509763}, {-1/4 + (15*(5 - Sqrt[5]))/32 \
+ (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}}], 
   Line[{{29/16, 1.9754350786598884}, {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + \
(3*Sin[(11*Pi)/30]^2)/2, 1.7955424168801202}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{29/16, 1.9754350786598884}}], 
   Line[{{-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, \
1.7955424168801202}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \

      1.61498867371741}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, 
     {-1/4 + (15*Cos[(11*Pi)/30]^2)/4 + (3*Sin[(11*Pi)/30]^2)/2, \
1.7955424168801202}}], 
   Line[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 
      1.454550222063749}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
      1.5679671136605227}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}}], 
   Line[{{-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + (3*Sin[(13*Pi)/30]^2)/2, \
1.454550222063749}, {-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \

      1.3407174947497689}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 
      1.4640759018681937}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 
      1.5679671136605227}, {-1/4 + (15*Cos[(13*Pi)/30]^2)/4 + \
(3*Sin[(13*Pi)/30]^2)/2, 1.454550222063749}}], 
   Line[{{-1/4 + (15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, \
1.3407174947497689}, {5/4, 1.299038105676658}, 
     {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}, {-1/4 + \
(15*Cos[(7*Pi)/15]^2)/4 + (3*Sin[(7*Pi)/15]^2)/2, 1.3407174947497689}}], 
   Line[{{5/4, 1.299038105676658}, {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + \
(3*Sin[(8*Pi)/15]^2)/2, 1.3407174947497686}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, 
     {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {5/4, \
1.299038105676658}}], 
   Line[{{-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, \
1.3407174947497686}, 
     {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, 
     {-1/4 + (15*Cos[(8*Pi)/15]^2)/4 + (3*Sin[(8*Pi)/15]^2)/2, \
1.3407174947497686}}], 
   Line[{{-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \

      1.61498867371741}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}, 
     {-1/4 + (15*Cos[(17*Pi)/30]^2)/4 + (3*Sin[(17*Pi)/30]^2)/2, \
1.4545502220637487}}], 
   Line[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + \
(3*Sin[(19*Pi)/30]^2)/2, 
      1.7955424168801195}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 
      1.8914277190459856}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}}], 
   Line[{{-1/4 + (15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, \
1.7955424168801195}, {29/16, 1.9754350786598884}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}, {-1/4 + \
(15*Cos[(19*Pi)/30]^2)/4 + (3*Sin[(19*Pi)/30]^2)/2, 
      1.7955424168801195}}], Line[{{29/16, 1.9754350786598884}, {-1/4 + \
(15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{29/16, 1.9754350786598884}}], 
   Line[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + \
(3*Sin[(11*Pi)/15]^2)/2, 
      2.281657041700858}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 
      2.3920893271166768}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
     {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}}], 
   Line[{{-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}, 
     {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + (3*Sin[(23*Pi)/30]^2)/2, \
2.394814022264696}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
     {-1/4 + (15*Cos[(11*Pi)/15]^2)/4 + (3*Sin[(11*Pi)/15]^2)/2, \
2.281657041700858}}], 
   Line[{{-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + (3*Sin[(23*Pi)/30]^2)/2, \
2.394814022264696}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
      2.4790558351445977}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
     {-1/4 + (15*Cos[(23*Pi)/30]^2)/4 + (3*Sin[(23*Pi)/30]^2)/2, \
2.394814022264696}}], 
   Line[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {47/16, 2.536452985962878}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 + \
Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + 
       (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, {-1/4 + (3*(5 - \
Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}}], 
   Line[{{47/16, 2.536452985962878}, {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + \
(3*Sin[(13*Pi)/15]^2)/2, 2.5712732770958877}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {47/16, \
2.536452985962878}}], 
   Line[{{-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + (3*Sin[(13*Pi)/15]^2)/2, \
2.5712732770958877}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, 
     {-1/4 + (15*Cos[(13*Pi)/15]^2)/4 + (3*Sin[(13*Pi)/15]^2)/2, \
2.5712732770958877}}], 
   Line[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + \
(3*Sin[(14*Pi)/15]^2)/2, 
      2.5962550390555568}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 
      2.834803496770628}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}}], 
   Line[{{-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + (3*Sin[(14*Pi)/15]^2)/2, \
2.5962550390555568}, 
     {-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}, 
     {-1/4 + (15*Cos[(14*Pi)/15]^2)/4 + (3*Sin[(14*Pi)/15]^2)/2, \
2.5962550390555568}}], 
   Line[{{-1/4 + (15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, \
2.5979598975817524}, {7/2, 2.598076211353316}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}, {-1/4 + \
(15*Cos[(29*Pi)/30]^2)/4 + (3*Sin[(29*Pi)/30]^2)/2, 
      2.5979598975817524}}], Line[{{7/2, 2.598076211353316}, {-1/4 + \
(15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, 2.5979598975817524}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, {7/2, \
2.598076211353316}}], 
   Line[{{-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, \
2.5979598975817524}, 
     {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + (3*Sin[(16*Pi)/15]^2)/2, \
2.5962550390555568}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, 
     {-1/4 + (15*Cos[(31*Pi)/30]^2)/4 + (3*Sin[(31*Pi)/30]^2)/2, \
2.5979598975817524}}], 
   Line[{{-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + (3*Sin[(16*Pi)/15]^2)/2, \
2.5962550390555568}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}, 
     {-1/4 + (15*Cos[(16*Pi)/15]^2)/4 + (3*Sin[(16*Pi)/15]^2)/2, \
2.5962550390555568}}], 
   Line[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + \
(3*Sin[(17*Pi)/15]^2)/2, 
      2.5712732770958877}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 
      2.7681817987334423}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}}], 
   Line[{{-1/4 + (15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, \
2.5712732770958877}, {47/16, 2.536452985962878}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, {-1/4 + \
(15*Cos[(17*Pi)/15]^2)/4 + (3*Sin[(17*Pi)/15]^2)/2, 
      2.5712732770958877}}], Line[{{47/16, 2.536452985962878}, {-1/4 + (3*(5 \
- Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {47/16, \
2.536452985962878}}], 
   Line[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + \
(3*Sin[(37*Pi)/30]^2)/2, 
      2.3948140222646948}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 
      2.5219601128218545}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
     {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}}], 
   Line[{{-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}, 
     {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
     {-1/4 + (15*Cos[(37*Pi)/30]^2)/4 + (3*Sin[(37*Pi)/30]^2)/2, \
2.3948140222646948}}], 
   Line[{{-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}, {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 
      2.14040166785146}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
     {-1/4 + (15*Cos[(19*Pi)/15]^2)/4 + (3*Sin[(19*Pi)/15]^2)/2, \
2.2816570417008593}}], 
   Line[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {29/16, 1.9754350786598884}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, {(-5 + \
Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + 
       (1 + Sqrt[5])^4/128, 2.239718051509763}, {-1/4 + (15*(5 - Sqrt[5]))/32 \
+ (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}}], 
   Line[{{29/16, 1.9754350786598884}, {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + \
(3*Sin[(41*Pi)/30]^2)/2, 1.7955424168801195}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{29/16, 1.9754350786598884}}], 
   Line[{{-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + (3*Sin[(41*Pi)/30]^2)/2, \
1.7955424168801195}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \

      1.61498867371741}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, 
     {-1/4 + (15*Cos[(41*Pi)/30]^2)/4 + (3*Sin[(41*Pi)/30]^2)/2, \
1.7955424168801195}}], 
   Line[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + \
(3*Sin[(43*Pi)/30]^2)/2, 
      1.4545502220637496}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 
      1.5679671136605233}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}}], 
   Line[{{-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + (3*Sin[(43*Pi)/30]^2)/2, \
1.4545502220637496}, 
     {-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
     {-1/4 + (15*Cos[(43*Pi)/30]^2)/4 + (3*Sin[(43*Pi)/30]^2)/2, \
1.4545502220637496}}], 
   Line[{{-1/4 + (15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, \
1.3407174947497693}, {5/4, 1.299038105676658}, 
     {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, {-1/4 + \
(15*Cos[(22*Pi)/15]^2)/4 + (3*Sin[(22*Pi)/15]^2)/2, 
      1.3407174947497693}}], Line[{{5/4, 1.299038105676658}, {-1/4 + \
(15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, 1.340717494749769}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, 
     {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {5/4, \
1.299038105676658}}], 
   Line[{{-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, \
1.340717494749769}, 
     {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, 
     {-1/4 + (15*Cos[(23*Pi)/15]^2)/4 + (3*Sin[(23*Pi)/15]^2)/2, \
1.340717494749769}}], 
   Line[{{-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}, {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, 
      1.61498867371741}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}, 
     {-1/4 + (15*Cos[(47*Pi)/30]^2)/4 + (3*Sin[(47*Pi)/30]^2)/2, \
1.454550222063749}}], 
   Line[{{-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}, {-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + \
(3*Sin[(49*Pi)/30]^2)/2, 
      1.795542416880119}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 
      1.8914277190459852}, {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/256 + ((1 + Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-1/4 + (15*(-1 + Sqrt[5])^2)/64 + (3*(5 + Sqrt[5]))/16, \
1.61498867371741}}], 
   Line[{{-1/4 + (15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, \
1.795542416880119}, {29/16, 1.9754350786598884}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}, {-1/4 + \
(15*Cos[(49*Pi)/30]^2)/4 + (3*Sin[(49*Pi)/30]^2)/2, 
      1.795542416880119}}], Line[{{29/16, 1.9754350786598884}, {-1/4 + (15*(5 \
- Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, 2.14040166785146}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{29/16, 1.9754350786598884}}], 
   Line[{{-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}, {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + \
(3*Sin[(26*Pi)/15]^2)/2, 
      2.2816570417008593}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 
      2.3920893271166777}, {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128 + (1 + Sqrt[5])^4/128, 2.239718051509763}, 
     {-1/4 + (15*(5 - Sqrt[5]))/32 + (3*(1 + Sqrt[5])^2)/32, \
2.14040166785146}}], 
   Line[{{-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}, 
     {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + (3*Sin[(53*Pi)/30]^2)/2, \
2.3948140222646948}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
     {-1/4 + (15*Cos[(26*Pi)/15]^2)/4 + (3*Sin[(26*Pi)/15]^2)/2, \
2.2816570417008593}}], 
   Line[{{-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + (3*Sin[(53*Pi)/30]^2)/2, \
2.3948140222646948}, {-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 
      2.4790558351445977}, {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64 + (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
     {-1/4 + (15*Cos[(53*Pi)/30]^2)/4 + (3*Sin[(53*Pi)/30]^2)/2, \
2.3948140222646948}}], 
   Line[{{-1/4 + (3*(5 - Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, \
2.4790558351445977}, {47/16, 2.536452985962878}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 + \
Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + 
       (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, {-1/4 + (3*(5 - \
Sqrt[5]))/16 + (15*(1 + Sqrt[5])^2)/64, 2.4790558351445977}}], 
   Line[{{47/16, 2.536452985962878}, {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + \
(3*Sin[(28*Pi)/15]^2)/2, 2.5712732770958877}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {47/16, \
2.536452985962878}}], 
   Line[{{-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + (3*Sin[(28*Pi)/15]^2)/2, \
2.5712732770958877}, {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \

      2.5891768866299354}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, 
     {-1/4 + (15*Cos[(28*Pi)/15]^2)/4 + (3*Sin[(28*Pi)/15]^2)/2, \
2.5712732770958877}}], 
   Line[{{-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}, {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + \
(3*Sin[(29*Pi)/15]^2)/2, 
      2.596255039055556}, {(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 
      2.834803496770629}, {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + \
Sqrt[5])^2)/128 + (5*(1 + Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-1/4 + (3*(-1 + Sqrt[5])^2)/32 + (15*(5 + Sqrt[5]))/32, \
2.5891768866299354}}], 
   Line[{{-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + (3*Sin[(29*Pi)/15]^2)/2, \
2.596255039055556}, 
     {-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
     {-1/4 + (15*Cos[(29*Pi)/15]^2)/4 + (3*Sin[(29*Pi)/15]^2)/2, \
2.596255039055556}}], 
   Line[{{-1/4 + (15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, \
2.5979598975817515}, {7/2, 2.598076211353316}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, {-1/4 + \
(15*Cos[(59*Pi)/30]^2)/4 + (3*Sin[(59*Pi)/30]^2)/2, 
      2.5979598975817515}}], Line[{{(-5 + Sqrt[5])/8 + (5*(1 + \
Sqrt[5])^2)/16, 2.8531695488854605}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 2.976303493889946}, 
     {-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 2.95408127925137}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 2.976303493889946}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 2.8487773266631815}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 2.95408127925137}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 2.834803496770628}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.8593997974092926}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.8593997974092926}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 2.768181798733441}}], 
   Line[{{(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 \
+ Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + 
       (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, {-Cos[(11*Pi)/15]^2 + \
((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.5673355087770746}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.427623046285348}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.5673355087770746}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 2.5219601128218545}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.427623046285348}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 2.392089327116677}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}}], 
   Line[{{(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207314}, \
{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207314}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.8914277190459863}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409114}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409114}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 1.5679671136605227}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}, 
     {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, \
{-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 1.4640759018681937}}], 
   Line[{{(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, \
{-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, 
     {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409112}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 1.4640759018681935}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409112}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 1.5679671136605227}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207308}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207308}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.8914277190459856}}], 
   Line[{{(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + 
       (1 + Sqrt[5])^4/128, 2.239718051509763}, {-Cos[(11*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, \
{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^4, 2.4276230462853476}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^4, 2.4276230462853476}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.3920893271166768}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.521960112821855}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}}], 
   Line[{{(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 \
+ Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.8593997974092926}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.8593997974092926}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 2.7681817987334414}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.95408127925137}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.976303493889946}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.95408127925137}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 2.834803496770628}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, \
{-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.976303493889946}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 2.8487773266631815}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, \
{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.976303493889946}, \
{-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.976303493889946}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 2.8487773266631815}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 2.834803496770629}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 2.7681817987334423}}], 
   Line[{{(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 \
+ Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + 
       (5*(1 + Sqrt[5])^4)/256, 2.6273597595826383}, {-Cos[(11*Pi)/15]^2 + \
((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.5673355087770746}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.5673355087770746}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 2.5219601128218545}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 2.3920893271166777}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}}], 
   Line[{{(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.925846626020731}, \
{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.925846626020731}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.891427719045986}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867283}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 1.5679671136605233}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}, 
     {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, \
{-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867283}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 1.4640759018681944}}], 
   Line[{{(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}, {(-5 + \
Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, \
{-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, 
     {(-5 + Sqrt[5])/8 + (1 + Sqrt[5])^2/8, 1.4265847744427302}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 1.464075901868194}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 1.5679671136605229}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.9258466260207303}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {(-5 + Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256 + ((1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/64, 1.7178957504272219}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.9258466260207303}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.8914277190459852}}], 
   Line[{{(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}, \
{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + 
       (1 + Sqrt[5])^4/128, 2.239718051509763}, {-Cos[(11*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, \
{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, 
     {(-5 + Sqrt[5])/8 + (11*(1 + Sqrt[5])^2)/64, 2.0698782028004867}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {(-5 + Sqrt[5])/8 + (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128 + (1 + \
Sqrt[5])^4/128, 2.239718051509763}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 2.3920893271166777}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 2.5219601128218536}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {(-5 + Sqrt[5])/8 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64 + (5*(1 + \
Sqrt[5])^4)/256, 2.6273597595826383}}], 
   Line[{{(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}, {(-5 \
+ Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + 
       ((1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.8593997974092926}, \
{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, 
     {(-5 + Sqrt[5])/8 + (17*(1 + Sqrt[5])^2)/64, 2.70871038548537}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.8593997974092926}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 2.768181798733441}}], 
   Line[{{(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.9540812792513695}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {(-5 + Sqrt[5])/8 + ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128 + (5*(1 + \
Sqrt[5])^2*(5 + Sqrt[5]))/128, 2.809014835019403}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.9540812792513695}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 2.834803496770629}}], 
   Line[{{(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2)/16, 2.8531695488854605}, \
{-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
     {(-5 + Sqrt[5])/8 + (5*(1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 2.8487773266631806}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 2.976303493889946}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 2.974595082902794}, \
{-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}, 
     {-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 2.976303493889946}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 2.95408127925137}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 2.947488384456562}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 2.974595082902794}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(11*Pi)/15]^2, 2.976303493889946}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 2.95408127925137}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 2.947488384456562}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(11*Pi)/15]^2, 2.95408127925137}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.8593997974092926}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.836596676593441}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.8593997974092926}, 
     {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.836596676593441}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.8593997974092926}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, \
{-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, \
{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.5673355087770746}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409046}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.5673355087770746}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.427623046285348}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.3792297776658287}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409046}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(11*Pi)/15]^2, 2.5673355087770746}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.427623046285348}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.3792297776658287}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(11*Pi)/15]^2, 2.427623046285348}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207314}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350187}, \
{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
     {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207314}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350187}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207314}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409114}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409114}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409114}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, 
     {-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, \
{-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, \
{-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, 
     {-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409112}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(11*Pi)/15]^2, 1.5257871330867276}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409112}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.6209688555409112}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207308}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350182}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207308}, 
     {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350182}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(11*Pi)/15]^2, 1.9258466260207308}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, \
{-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, \
{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
     {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^4, 2.4276230462853476}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.379229777665828}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^4, 2.4276230462853476}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^4, 2.5216249314090464}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.379229777665828}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^4, 2.4276230462853476}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^4, 2.5216249314090464}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.567335508777075}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.8593997974092926}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, \
{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.8593997974092926}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.8593997974092926}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.95408127925137}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.95408127925137}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.976303493889946}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.974595082902794}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.95408127925137}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.976303493889946}, 
     {-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, \
{-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.974595082902794}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.976303493889946}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.976303493889946}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(23*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.974595082902794}, \
{-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}, 
     {-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.976303493889946}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.974595082902794}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.976303493889946}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.9540812792513704}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.836596676593442}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}, 
     {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.836596676593442}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.859399797409293}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, \
{-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, \
{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.5673355087770746}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409046}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.5673355087770746}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409046}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(37*Pi)/30]^2, 2.5673355087770746}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(19*Pi)/15]^2, 2.4276230462853485}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.925846626020731}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(23*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350182}, \
{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
     {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.925846626020731}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350182}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.925846626020731}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867283}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.620968855540912}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867283}, 
     {-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, \
{-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.5257871330867283}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(23*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538965}, \
{-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, 
     {-Cos[(11*Pi)/15]^2 + 2*Sin[(11*Pi)/15]^2, 1.4917828430524098}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238356}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538965}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.525787133086728}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238356}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.6209688555409116}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.9258466260207303}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.8918241808350176}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(11*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 1.760690570377689}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.9258466260207303}, 
     {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.8918241808350176}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.9258466260207303}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}, \
{-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, \
{-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, \
{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, 
     {-Cos[(11*Pi)/15]^2 + (11*Sin[(11*Pi)/15]^2)/4, 2.0997996262255536}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(11*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 2.2699589047379565}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.521624931409045}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(26*Pi)/15]^2, 2.4276230462853485}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.521624931409045}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(53*Pi)/30]^2, 2.5673355087770737}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}, 
     {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {-Cos[(11*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/16, 2.686221801523239}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}, \
{-Cos[(11*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/15]^2 + 
       2*Sin[(11*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.8593997974092926}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(23*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, \
{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, 
     {-Cos[(11*Pi)/15]^2 + (17*Sin[(11*Pi)/15]^2)/4, 2.7833940695732022}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.8593997974092926}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.8593997974092926}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.9540812792513695}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.947488384456561}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(11*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(11*Pi)/15]^2)/8, 2.9156867970745455}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.9540812792513695}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027934}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.947488384456561}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.9540812792513695}}], 
   Line[{{-Cos[(11*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}, 
     {-Cos[(11*Pi)/15]^2 + 5*Sin[(11*Pi)/15]^2, 2.9835656861048196}, \
{-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027934}, 
     {-Cos[(11*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(11*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.9763034938899455}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 2.974595082902794}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, {(5*(5 - \
Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, 
     {-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 2.974595082902794}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 2.947488384456562}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(23*Pi)/30]^2, 2.974595082902794}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 2.947488384456562}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(23*Pi)/30]^2, 2.947488384456562}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.836596676593441}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.836596676593441}, 
     {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, \
{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.836596676593441}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, {(5 - \
Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + 
       (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, {(17*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409046}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409046}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.3792297776658287}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(23*Pi)/30]^2, 2.521624931409046}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.3792297776658287}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.3792297776658287}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, \
{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350187}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, {(11*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350187}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350187}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
     {-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, {(5 - \
Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, {(5 - \
Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, 
     {-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(23*Pi)/30]^2, 1.5224519023538963}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.6089224974238354}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350182}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350182}, 
     {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, \
{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(23*Pi)/30]^2, 1.8918241808350182}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, \
{-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, {(5*(5 - \
Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + 
       ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, {(11*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.379229777665828}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.379229777665828}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^4, 2.5216249314090464}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(23*Pi)/30]^2, 2.379229777665828}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^4, 2.5216249314090464}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^4, 2.5216249314090464}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, \
{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, {(17*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 2.836596676593442}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.974595082902794}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 2.947488384456562}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.974595082902794}, 
     {-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}, {(5*(5 - \
Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 2.974595082902794}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(23*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.974595082902794}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, {(5*(5 - \
Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, 
     {-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.974595082902794}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(31*Pi)/30]^2, 2.974595082902794}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(16*Pi)/15]^2, 2.9474883844565616}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.836596676593442}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.836596676593442}, 
     {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, \
{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(17*Pi)/15]^2, 2.836596676593442}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, {(5 - \
Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + 
       (5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, {(17*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409046}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409046}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(37*Pi)/30]^2, 2.521624931409046}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(19*Pi)/15]^2, 2.379229777665829}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, \
{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(23*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350182}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, {(11*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350182}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(41*Pi)/30]^2, 1.8918241808350182}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.530848154054823}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.530848154054823}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(43*Pi)/30]^2, 1.6089224974238363}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}, 
     {-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, {(5 - \
Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(22*Pi)/15]^2, 1.522451902353897}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(23*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538965}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, {(5 - \
Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, 
     {-Cos[(23*Pi)/30]^2 + 2*Sin[(23*Pi)/30]^2, 1.4917828430524098}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538965}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238356}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(23*Pi)/15]^2, 1.5224519023538965}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238356}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(47*Pi)/30]^2, 1.6089224974238356}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.8918241808350176}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-Cos[(23*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 1.7374623647519978}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.8918241808350176}, 
     {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, \
{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(49*Pi)/30]^2, 1.8918241808350176}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}, \
{-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, {(5*(5 - \
Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + 
       ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, {(11*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {-Cos[(23*Pi)/30]^2 + (11*Sin[(23*Pi)/30]^2)/4, 2.057368875173533}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-Cos[(23*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 2.222607239695348}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.521624931409045}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(26*Pi)/15]^2, 2.379229777665829}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.521624931409045}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(53*Pi)/30]^2, 2.521624931409045}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}, 
     {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, \
{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-Cos[(23*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/16, 2.6463289817643205}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}, \
{-Cos[(23*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(23*Pi)/30]^2 + 
       2*Sin[(23*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, {(17*(5 - \
Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {-Cos[(23*Pi)/30]^2 + (17*Sin[(23*Pi)/30]^2)/4, 2.751525170659194}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(28*Pi)/15]^2, 2.836596676593442}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.947488384456561}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-Cos[(23*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(23*Pi)/30]^2)/8, 2.901719090978228}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.947488384456561}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027934}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/15]^2, 2.947488384456561}}], 
   Line[{{-Cos[(23*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027934}, 
     {-Cos[(23*Pi)/30]^2 + 5*Sin[(23*Pi)/30]^2, 2.9835656861048196}, {(5*(5 - \
Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-Cos[(23*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(23*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(59*Pi)/30]^2, 2.9745950829027934}}], 
   Line[{{(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {-(1 \
+ Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, {-3/4 + \
(5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, 
     {1/2, 2.598076211353316}, {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, \
2.8531695488854605}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}, 
     {-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, {-3/4 \
+ (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/30]^2)/4, 2.8434972909653364}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, \
{-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[Pi/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[Pi/15]^2)/4, 2.8144424077524013}}], 
   Line[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}, 
     {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, 2.447478090794556}, \
{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {5/16, \
2.3642850399222173}, 
     {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, 2.447478090794556}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(2*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(2*Pi)/15]^2)/4, 2.697933958917173}}], \
Line[{{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{5/16, 2.3642850399222173}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}], 
   Line[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
     {-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
      2.264540963292246}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/30]^2)/4, 2.381720267244781}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, 
     {-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 2.02317839809799}, \
{-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, 
      2.1499828315181597}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(7*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(7*Pi)/30]^2)/4, \
2.381720267244781}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(4*Pi)/15]^2)/4, 2.2437468595288657}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 
      2.02317839809799}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(4*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(4*Pi)/15]^2)/4, \
2.2437468595288657}}], 
   Line[{{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}}], 
   Line[{{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, {-3/4 + \
(5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, 1.6132809148526017}, 
     {-1/16, 1.7488835724541527}, {(11*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 1.9398272078772507}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 1.7870411277345812}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 1.4898021598760776}, \
{-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, 
      1.6132809148526017}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(11*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(11*Pi)/30]^2)/4, 
      1.7870411277345812}}], Line[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - \
(1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
      1.646496168027179}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4, \
1.5308481540548224}, 
     {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 1.5308481540548224}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}, 
     {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, \
1.3224570770546993}, {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, 
      1.389101261457407}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(13*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(13*Pi)/30]^2)/4, 
      1.5308481540548224}}], Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 
      1.453775372348889}, {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, \
1.4265847744427302}, {-1/4, 1.299038105676658}, 
     {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, \
1.3224570770546993}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(7*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(7*Pi)/15]^2)/4, 1.453775372348889}}], 
   Line[{{(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, {-3/4 + \
(5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, 1.3224570770546993}, 
     {-1/4, 1.299038105676658}, {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, \
1.4265847744427302}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(8*Pi)/15]^2)/4, 1.453775372348889}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}, 
     {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, \
1.3891012614574068}, {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, 
      1.3224570770546993}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(8*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(8*Pi)/15]^2)/4, \
1.453775372348889}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 1.5308481540548224}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 1.4898021598760776}, \
{-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, 
      1.3891012614574068}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/30]^2)/4, 
      1.5308481540548224}}], Line[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - \
(1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
      1.646496168027179}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/30]^2)/4, \
1.7870411277345808}, 
     {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, \
1.6132809148526013}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}, 
     {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, \
1.6132809148526013}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/30]^2)/4, 1.7870411277345808}}], 
   Line[{{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-1/16, 1.7488835724541527}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}], 
   Line[{{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
     {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, \
2.0231783980979894}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
      1.8877889819588956}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 2.243746859528865}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 2.381720267244781}, 
     {-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, 
      2.0231783980979894}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(11*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(11*Pi)/15]^2)/4, 
      2.243746859528865}}], Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
      2.381720267244781}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, 
      2.1499828315181597}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(23*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(23*Pi)/30]^2)/4, 
      2.381720267244781}}], Line[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + \
(5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {5/16, \
2.3642850399222173}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}}], 
   Line[{{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, {-3/4 + \
(5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, 2.4474780907945566}, 
     {5/16, 2.3642850399222173}, {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, \
2.6106791787633683}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 2.6979339589171736}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, \
{-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, 
      2.4474780907945566}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(13*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
      2.6979339589171736}}], Line[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 \
+ Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 
      2.7659262761959793}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
      2.8144424077524013}, {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + \
Sin[(14*Pi)/15]^2/2, 2.5601613609103286}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, \
{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + 
       (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 2.8144424077524013}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, 
      2.5601613609103286}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(14*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 
      2.8144424077524013}}], Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
      2.8434972909653364}, {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, \
2.8531695488854605}, {1/2, 2.598076211353316}, 
     {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 2.8434972909653364}}], 
   Line[{{(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, 2.8531695488854605}, {-(1 \
+ Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, {-3/4 + \
(5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, 2.588583579753018}, 
     {1/2, 2.598076211353316}, {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, \
2.8531695488854605}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 2.814442407752401}, 
     {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, 
      2.588583579753018}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(31*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(31*Pi)/30]^2)/4, 
      2.8434972909653364}}], Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 
      2.814442407752401}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, \
{-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, 
      2.5601613609103286}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(16*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(16*Pi)/15]^2)/4, 
      2.814442407752401}}], Line[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 
      2.7659262761959793}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(17*Pi)/15]^2)/4, \
2.697933958917174}, 
     {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {5/16, \
2.3642850399222173}, 
     {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, \
2.4474780907945566}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(17*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(17*Pi)/15]^2)/4, 2.697933958917174}}], 
   Line[{{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{5/16, 2.3642850399222173}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}}], 
   Line[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}, 
     {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
      2.264540963292246}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 2.381720267244781}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 2.243746859528866}, 
     {-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, 
      2.1499828315181597}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(37*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(37*Pi)/30]^2)/4, 
      2.381720267244781}}], Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 
      2.243746859528866}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, 
      2.0231783980979903}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(19*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(19*Pi)/15]^2)/4, 
      2.243746859528866}}], Line[{{(5*(5 - Sqrt[5])^2)/64 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}}], 
   Line[{{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, {-3/4 + \
(5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, 1.6132809148526013}, 
     {-1/16, 1.7488835724541527}, {(11*(5 - Sqrt[5]))/32 - (1 + \
Sqrt[5])^2/16, 1.9398272078772507}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 1.7870411277345808}, 
     {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + Sqrt[5])^2/16 + ((5 - \
Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 1.4898021598760776}, \
{-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, 
      1.6132809148526013}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(41*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(41*Pi)/30]^2)/4, 
      1.7870411277345808}}], Line[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - \
(1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
      1.646496168027179}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(43*Pi)/30]^2)/4, \
1.530848154054823}, 
     {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, \
1.3891012614574074}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 1.530848154054823}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}, 
     {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}, {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, 
      1.3891012614574074}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(43*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(43*Pi)/30]^2)/4, 
      1.530848154054823}}], Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 
      1.4537753723488895}, {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, \
1.4265847744427302}, {-1/4, 1.299038105676658}, 
     {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(22*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(22*Pi)/15]^2)/4, 1.4537753723488895}}], 
   Line[{{(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, 1.4265847744427302}, {-(1 + \
Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, {-3/4 + \
(5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, 1.3224570770546995}, 
     {-1/4, 1.299038105676658}, {(5 - Sqrt[5])/4 - (1 + Sqrt[5])^2/16, \
1.4265847744427302}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 1.4537753723488893}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 1.5308481540548229}, 
     {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, 
      1.3224570770546995}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(23*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(23*Pi)/15]^2)/4, 
      1.4537753723488893}}], Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 
      1.5308481540548229}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}, 
     {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 1.4898021598760776}, \
{-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, 
      1.389101261457407}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(47*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(47*Pi)/30]^2)/4, 
      1.5308481540548229}}], Line[{{(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - \
(1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 
      1.646496168027179}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(49*Pi)/30]^2)/4, \
1.7870411277345801}, 
     {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, \
1.6132809148526008}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {(5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 - (1 + \
Sqrt[5])^2/16 + ((5 - Sqrt[5])*(5 + Sqrt[5]))/32, 1.646496168027179}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, \
{-1/16, 1.7488835724541527}, 
     {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, \
1.6132809148526008}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(49*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(49*Pi)/30]^2)/4, 1.7870411277345801}}], 
   Line[{{(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}, 
     {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}, \
{-1/16, 1.7488835724541527}, 
     {(11*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 1.9398272078772507}}], 
   Line[{{(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/64, 2.0946223601372336}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
     {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
      1.8877889819588956}, {(5*(5 - Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + ((5 \
- Sqrt[5])*(1 + Sqrt[5])^2)/64, 2.0946223601372336}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 2.243746859528866}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 2.3817202672447797}, 
     {-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}, {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, 
      2.0231783980979903}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(26*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(26*Pi)/15]^2)/4, 
      2.243746859528866}}], Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 
      2.3817202672447797}, {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, \
{-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, 
      2.149982831518159}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(53*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(53*Pi)/30]^2)/4, 
      2.3817202672447797}}], Line[{{(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + \
(5*(5 - Sqrt[5])*(1 + Sqrt[5])^2)/128, 2.504820390287959}, 
     {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, {5/16, \
2.3642850399222173}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}, 
     {(5 - Sqrt[5])^2/32 - (1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(1 + \
Sqrt[5])^2)/128, 2.504820390287959}}], 
   Line[{{(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, 2.6106791787633683}, \
{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + 
       ((5 - Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, {-3/4 + \
(5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, 2.4474780907945566}, 
     {5/16, 2.3642850399222173}, {(17*(5 - Sqrt[5]))/32 - (1 + Sqrt[5])^2/16, \
2.6106791787633683}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 2.6979339589171736}, 
     {((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, \
{-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, 
      2.4474780907945566}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(28*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(28*Pi)/15]^2)/4, 
      2.6979339589171736}}], Line[{{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 \
+ Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 
      2.7659262761959793}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
      2.8144424077524013}, {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + \
Sin[(29*Pi)/15]^2/2, 2.5601613609103286}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 2.5129980122544064}, \
{((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 - (1 + Sqrt[5])^2/16 + 
       (5*(5 - Sqrt[5])*(5 + Sqrt[5]))/64, 2.7659262761959793}}], 
   Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 2.8144424077524013}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}, 
     {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, 
      2.5601613609103286}, {-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(29*Pi)/15]^2)/8 + ((5 - Sqrt[5])*Sin[(29*Pi)/15]^2)/4, 
      2.8144424077524013}}], Line[{{-(1 + Sqrt[5])^2/16 + (5*(5 - \
Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 
      2.8434972909653364}, {(5*(5 - Sqrt[5]))/8 - (1 + Sqrt[5])^2/16, \
2.8531695488854605}, {1/2, 2.598076211353316}, 
     {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, 
     {-(1 + Sqrt[5])^2/16 + (5*(5 - Sqrt[5])*Cos[(59*Pi)/30]^2)/8 + ((5 - \
Sqrt[5])*Sin[(59*Pi)/30]^2)/4, 2.8434972909653364}}], 
   Line[{{1/2, 2.598076211353316}, {-3/4 + (5*Cos[Pi/30]^2)/4 + \
Sin[Pi/30]^2/2, 2.588583579753018}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 2.220880340843795}, 
     {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, {1/2, \
2.598076211353316}}], 
   Line[{{-3/4 + (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}, \
{-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 2.1953185530328256}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 2.220880340843795}, 
     {-3/4 + (5*Cos[Pi/30]^2)/4 + Sin[Pi/30]^2/2, 2.588583579753018}}], 
   Line[{{-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}, \
{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
      2.1530633066599694}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[Pi/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, \
2.1953185530328256}, 
     {-3/4 + (5*Cos[Pi/15]^2)/4 + Sin[Pi/15]^2/2, 2.5601613609103286}}], 
   Line[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, 
      2.447478090794556}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, \
2.0946793219544753}, 
     {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
     {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}}], 
   Line[{{-3/4 + (5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, \
2.447478090794556}, {5/16, 2.3642850399222173}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.0946793219544753}, {-3/4 + \
(5*Cos[(2*Pi)/15]^2)/4 + Sin[(2*Pi)/15]^2/2, 2.447478090794556}}], 
   Line[{{5/16, 2.3642850399222173}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + \
Sqrt[5])^2)/64, 2.264540963292246}, 
     {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{5/16, 2.3642850399222173}}], 
   Line[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, 
      2.1499828315181597}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, \
1.8336364565828083}, 
     {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
     {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}}], \

   Line[{{-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, 
      2.02317839809799}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, \
1.724112283936149}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828083}, 
     {-3/4 + (5*Cos[(7*Pi)/30]^2)/4 + Sin[(7*Pi)/30]^2/2, \
2.1499828315181597}}], 
   Line[{{-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, \
2.02317839809799}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
      1.8877889819588956}, {-Cos[(13*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
      1.6081701375219564}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, \
1.724112283936149}, 
     {-3/4 + (5*Cos[(4*Pi)/15]^2)/4 + Sin[(4*Pi)/15]^2/2, \
2.02317839809799}}], 
   Line[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-1/16, 1.7488835724541527}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, {-3/4 + \
(5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}}], 
   Line[{{-1/16, 1.7488835724541527}, {-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + \
Sin[(11*Pi)/30]^2/2, 1.6132809148526017}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.375975067210655}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-1/16, 1.7488835724541527}}], 
   Line[{{-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + Sin[(11*Pi)/30]^2/2, \
1.6132809148526017}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
      1.2727298803122145}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
      1.375975067210655}, {-3/4 + (5*Cos[(11*Pi)/30]^2)/4 + \
Sin[(11*Pi)/30]^2/2, 1.6132809148526017}}], 
   Line[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, 
      1.389101261457407}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
      1.1890852819516715}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
      1.2727298803122145}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + \
Sqrt[5])/16, 1.4898021598760776}}], 
   Line[{{-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, 
      1.3224570770546993}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, \
1.1340136417284854}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.1890852819516715}, 
     {-3/4 + (5*Cos[(13*Pi)/30]^2)/4 + Sin[(13*Pi)/30]^2/2, \
1.389101261457407}}], 
   Line[{{-3/4 + (5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, \
1.3224570770546993}, {-1/4, 1.299038105676658}, 
     {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, {-3/4 + \
(5*Cos[(7*Pi)/15]^2)/4 + Sin[(7*Pi)/15]^2/2, 1.3224570770546993}}], 
   Line[{{-1/4, 1.299038105676658}, {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + \
Sin[(8*Pi)/15]^2/2, 1.3224570770546993}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, 
     {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, {-1/4, \
1.299038105676658}}], 
   Line[{{-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, \
1.3224570770546993}, {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, 
      1.3891012614574068}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
      1.1890852819516715}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, \
1.1340136417284854}, 
     {-3/4 + (5*Cos[(8*Pi)/15]^2)/4 + Sin[(8*Pi)/15]^2/2, \
1.3224570770546993}}], 
   Line[{{-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + Sin[(17*Pi)/30]^2/2, \
1.3891012614574068}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
      1.2727298803122145}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
      1.1890852819516715}, {-3/4 + (5*Cos[(17*Pi)/30]^2)/4 + \
Sin[(17*Pi)/30]^2/2, 1.3891012614574068}}], 
   Line[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, 
      1.6132809148526013}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
      1.3759750672106548}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
      1.2727298803122145}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + \
Sqrt[5])/16, 1.4898021598760776}}], 
   Line[{{-3/4 + (5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, \
1.6132809148526013}, {-1/16, 1.7488835724541527}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.3759750672106548}, {-3/4 + \
(5*Cos[(19*Pi)/30]^2)/4 + Sin[(19*Pi)/30]^2/2, 1.6132809148526013}}], 
   Line[{{-1/16, 1.7488835724541527}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + \
Sqrt[5])^2/32, 1.8877889819588956}, 
     {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-1/16, 1.7488835724541527}}], 
   Line[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, 
      2.0231783980979894}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
      1.7241122839361485}, {-Cos[(13*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
      1.6081701375219564}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}}], 
   Line[{{-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + Sin[(11*Pi)/15]^2/2, \
2.0231783980979894}, {-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, 
      2.1499828315181597}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
      1.8336364565828085}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 
      1.7241122839361485}, {-3/4 + (5*Cos[(11*Pi)/15]^2)/4 + \
Sin[(11*Pi)/15]^2/2, 2.0231783980979894}}], 
   Line[{{-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + Sin[(23*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
      2.264540963292246}, {-Cos[(13*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 
      1.9334320944111905}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 
      1.8336364565828085}, {-3/4 + (5*Cos[(23*Pi)/30]^2)/4 + \
Sin[(23*Pi)/30]^2/2, 2.1499828315181597}}], 
   Line[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {5/16, 2.3642850399222173}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, {-3/4 + \
(5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}}], 
   Line[{{5/16, 2.3642850399222173}, {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + \
Sin[(13*Pi)/15]^2/2, 2.4474780907945566}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^4, 2.0946793219544757}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{5/16, 2.3642850399222173}}], 
   Line[{{-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
      2.1530633066599694}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^4, \
2.0946793219544757}, 
     {-3/4 + (5*Cos[(13*Pi)/15]^2)/4 + Sin[(13*Pi)/15]^2/2, \
2.4474780907945566}}], 
   Line[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, 
      2.5601613609103286}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 
      2.1953185530328256}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
      2.1530633066599694}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + \
Sqrt[5]))/32, 2.5129980122544064}}], 
   Line[{{-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, 
      2.588583579753018}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.220880340843795}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.1953185530328256}, 
     {-3/4 + (5*Cos[(14*Pi)/15]^2)/4 + Sin[(14*Pi)/15]^2/2, \
2.5601613609103286}}], 
   Line[{{-3/4 + (5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, \
2.588583579753018}, {1/2, 2.598076211353316}, 
     {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.220880340843795}, {-3/4 + \
(5*Cos[(29*Pi)/30]^2)/4 + Sin[(29*Pi)/30]^2/2, 2.588583579753018}}], 
   Line[{{1/2, 2.598076211353316}, {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + \
Sin[(31*Pi)/30]^2/2, 2.588583579753018}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.220880340843795}, 
     {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, {1/2, \
2.598076211353316}}], 
   Line[{{-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + Sin[(31*Pi)/30]^2/2, \
2.588583579753018}, {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, 
      2.5601613609103286}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(16*Pi)/15]^2, 
      2.1953185530328256}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(31*Pi)/30]^2, 
      2.220880340843795}, {-3/4 + (5*Cos[(31*Pi)/30]^2)/4 + \
Sin[(31*Pi)/30]^2/2, 2.588583579753018}}], 
   Line[{{-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + Sin[(16*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
      2.1530633066599694}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(16*Pi)/15]^2, 
      2.1953185530328256}, {-3/4 + (5*Cos[(16*Pi)/15]^2)/4 + \
Sin[(16*Pi)/15]^2/2, 2.5601613609103286}}], 
   Line[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, 
      2.4474780907945566}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(17*Pi)/15]^2, 
      2.0946793219544757}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
      2.1530633066599694}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + \
Sqrt[5]))/32, 2.5129980122544064}}], 
   Line[{{-3/4 + (5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, \
2.4474780907945566}, {5/16, 2.3642850399222173}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.0946793219544757}, {-3/4 + \
(5*Cos[(17*Pi)/15]^2)/4 + Sin[(17*Pi)/15]^2/2, 2.4474780907945566}}], 
   Line[{{5/16, 2.3642850399222173}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + \
Sqrt[5])^2)/64, 2.264540963292246}, 
     {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{5/16, 2.3642850399222173}}], 
   Line[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, 
      2.1499828315181597}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
      1.8336364565828083}, {-Cos[(13*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 
      1.9334320944111905}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}}], 
   Line[{{-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + Sin[(37*Pi)/30]^2/2, \
2.1499828315181597}, {-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, 
      2.0231783980979903}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
      1.7241122839361493}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(37*Pi)/30]^2, 
      1.8336364565828083}, {-3/4 + (5*Cos[(37*Pi)/30]^2)/4 + \
Sin[(37*Pi)/30]^2/2, 2.1499828315181597}}], 
   Line[{{-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + Sin[(19*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 
      1.8877889819588956}, {-Cos[(13*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
      1.6081701375219564}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(19*Pi)/15]^2, 
      1.7241122839361493}, {-3/4 + (5*Cos[(19*Pi)/15]^2)/4 + \
Sin[(19*Pi)/15]^2/2, 2.0231783980979903}}], 
   Line[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-1/16, 1.7488835724541527}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, {-3/4 + \
(5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, 1.8877889819588956}}], 
   Line[{{-1/16, 1.7488835724541527}, {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + \
Sin[(41*Pi)/30]^2/2, 1.6132809148526013}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.3759750672106548}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-1/16, 1.7488835724541527}}], 
   Line[{{-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + Sin[(41*Pi)/30]^2/2, \
1.6132809148526013}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
      1.2727298803122145}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(41*Pi)/30]^2, 
      1.3759750672106548}, {-3/4 + (5*Cos[(41*Pi)/30]^2)/4 + \
Sin[(41*Pi)/30]^2/2, 1.6132809148526013}}], 
   Line[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, 
      1.3891012614574074}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
      1.189085281951672}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
      1.2727298803122145}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + \
Sqrt[5])/16, 1.4898021598760776}}], 
   Line[{{-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + Sin[(43*Pi)/30]^2/2, \
1.3891012614574074}, {-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, 
      1.3224570770546997}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(22*Pi)/15]^2, 
      1.1340136417284856}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(43*Pi)/30]^2, 
      1.189085281951672}, {-3/4 + (5*Cos[(43*Pi)/30]^2)/4 + \
Sin[(43*Pi)/30]^2/2, 1.3891012614574074}}], 
   Line[{{-3/4 + (5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, \
1.3224570770546997}, {-1/4, 1.299038105676658}, 
     {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284856}, {-3/4 + \
(5*Cos[(22*Pi)/15]^2)/4 + Sin[(22*Pi)/15]^2/2, 1.3224570770546997}}], 
   Line[{{-1/4, 1.299038105676658}, {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + \
Sin[(23*Pi)/15]^2/2, 1.3224570770546995}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284854}, 
     {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, {-1/4, \
1.299038105676658}}], 
   Line[{{-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + Sin[(23*Pi)/15]^2/2, \
1.3224570770546995}, {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, 
      1.389101261457407}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
      1.1890852819516715}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(23*Pi)/15]^2, 
      1.1340136417284854}, {-3/4 + (5*Cos[(23*Pi)/15]^2)/4 + \
Sin[(23*Pi)/15]^2/2, 1.3224570770546995}}], 
   Line[{{-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + Sin[(47*Pi)/30]^2/2, \
1.389101261457407}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, 
      1.4898021598760776}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
      1.2727298803122145}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(47*Pi)/30]^2, 
      1.1890852819516715}, {-3/4 + (5*Cos[(47*Pi)/30]^2)/4 + \
Sin[(47*Pi)/30]^2/2, 1.389101261457407}}], 
   Line[{{-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + Sqrt[5])/16, \
1.4898021598760776}, {-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, 
      1.6132809148526008}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(49*Pi)/30]^2, 
      1.3759750672106543}, {-Cos[(13*Pi)/15]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 
      1.2727298803122145}, {-3/4 + (5*(-1 + Sqrt[5])^2)/64 + (5 + \
Sqrt[5])/16, 1.4898021598760776}}], 
   Line[{{-3/4 + (5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, \
1.6132809148526008}, {-1/16, 1.7488835724541527}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106543}, {-3/4 + \
(5*Cos[(49*Pi)/30]^2)/4 + Sin[(49*Pi)/30]^2/2, 1.6132809148526008}}], 
   Line[{{-1/16, 1.7488835724541527}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + \
Sqrt[5])^2/32, 1.8877889819588956}, 
     {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-1/16, 1.7488835724541527}}], 
   Line[{{-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}, {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, 
      2.0231783980979903}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
      1.7241122839361493}, {-Cos[(13*Pi)/15]^2 + (5*(5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 
      1.6081701375219564}, {-3/4 + (5*(5 - Sqrt[5]))/32 + (1 + Sqrt[5])^2/32, \
1.8877889819588956}}], 
   Line[{{-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + Sin[(26*Pi)/15]^2/2, \
2.0231783980979903}, {-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, 
      2.149982831518159}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
      1.8336364565828074}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(26*Pi)/15]^2, 
      1.7241122839361493}, {-3/4 + (5*Cos[(26*Pi)/15]^2)/4 + \
Sin[(26*Pi)/15]^2/2, 2.0231783980979903}}], 
   Line[{{-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + Sin[(53*Pi)/30]^2/2, \
2.149982831518159}, {-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 
      2.264540963292246}, {-Cos[(13*Pi)/15]^2 + ((5 - \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 
      1.9334320944111905}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(53*Pi)/30]^2, 
      1.8336364565828074}, {-3/4 + (5*Cos[(53*Pi)/30]^2)/4 + \
Sin[(53*Pi)/30]^2/2, 2.149982831518159}}], 
   Line[{{-3/4 + (5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, \
2.264540963292246}, {5/16, 2.3642850399222173}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, {-3/4 + \
(5 - Sqrt[5])/16 + (5*(1 + Sqrt[5])^2)/64, 2.264540963292246}}], 
   Line[{{5/16, 2.3642850399222173}, {-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + \
Sin[(28*Pi)/15]^2/2, 2.4474780907945566}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.0946793219544757}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{5/16, 2.3642850399222173}}], 
   Line[{{-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + Sin[(28*Pi)/15]^2/2, \
2.4474780907945566}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, 
      2.5129980122544064}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
      2.1530633066599694}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(28*Pi)/15]^2, 
      2.0946793219544757}, {-3/4 + (5*Cos[(28*Pi)/15]^2)/4 + \
Sin[(28*Pi)/15]^2/2, 2.4474780907945566}}], 
   Line[{{-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + Sqrt[5]))/32, \
2.5129980122544064}, {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, 
      2.5601613609103286}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/15]^2, 
      2.195318553032825}, {-Cos[(13*Pi)/15]^2 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 
      2.1530633066599694}, {-3/4 + (-1 + Sqrt[5])^2/32 + (5*(5 + \
Sqrt[5]))/32, 2.5129980122544064}}], 
   Line[{{-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, \
2.5601613609103286}, {-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, 
      2.588583579753018}, {-Cos[(13*Pi)/15]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.220880340843795}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.195318553032825}, 
     {-3/4 + (5*Cos[(29*Pi)/15]^2)/4 + Sin[(29*Pi)/15]^2/2, \
2.5601613609103286}}], 
   Line[{{-3/4 + (5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, \
2.588583579753018}, {1/2, 2.598076211353316}, 
     {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.220880340843795}, {-3/4 + \
(5*Cos[(59*Pi)/30]^2)/4 + Sin[(59*Pi)/30]^2/2, 2.588583579753018}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 2.220880340843795}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
     {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 2.220880340843795}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 2.1953185530328256}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(13*Pi)/15]^2, 2.220880340843795}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 2.1953185530328256}, 
     {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(13*Pi)/15]^2, 2.1953185530328256}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.0946793219544753}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.0946793219544753}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, {(-5 \
- Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(13*Pi)/15]^2, 2.0946793219544753}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, {(-5 - \
Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + 
       (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828083}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828083}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.724112283936149}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828083}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.724112283936149}, 
     {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.724112283936149}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.375975067210655}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.375975067210655}, 
     {-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.375975067210655}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.1890852819516715}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.1890852819516715}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.1890852819516715}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, 
     {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, {(-5 - \
Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, {(-5 - \
Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
     {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.1890852819516715}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.1340136417284854}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.1890852819516715}, 
     {-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.1890852819516715}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.3759750672106548}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.3759750672106548}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.3759750672106548}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, {(-5 - \
Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + 
       ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.7241122839361485}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.7241122839361485}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828085}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(13*Pi)/15]^2, 1.7241122839361485}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828085}, 
     {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(13*Pi)/15]^2, 1.8336364565828085}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, {(-5 \
- Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^4, 2.0946793219544757}, {(-5 - Sqrt[5])/8 + (5*(-1 + \
Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^4, 2.0946793219544757}, 
     {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^4, 2.0946793219544757}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.1953185530328256}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.1953185530328256}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.220880340843795}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 2.1953185530328256}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.220880340843795}, 
     {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 2.220880340843795}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.220880340843795}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
     {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.220880340843795}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.1953185530328256}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(31*Pi)/30]^2, 2.220880340843795}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.1953185530328256}, 
     {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(16*Pi)/15]^2, 2.1953185530328256}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.0946793219544757}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.0946793219544757}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, {(-5 \
- Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(17*Pi)/15]^2, 2.0946793219544757}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, {(-5 - \
Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + 
       (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828083}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828083}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361493}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(37*Pi)/30]^2, 1.8336364565828083}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361493}, 
     {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(19*Pi)/15]^2, 1.7241122839361493}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.3759750672106548}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.3759750672106548}, 
     {-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(41*Pi)/30]^2, 1.3759750672106548}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.189085281951672}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.189085281951672}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284856}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(43*Pi)/30]^2, 1.189085281951672}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284856}, 
     {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, {(-5 - \
Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(22*Pi)/15]^2, 1.1340136417284856}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284854}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, {(-5 - \
Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, 
     {-Cos[(13*Pi)/15]^2 + 2*Sin[(13*Pi)/15]^2, 1.114717238216091}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284854}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.1890852819516715}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(23*Pi)/15]^2, 1.1340136417284854}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.1890852819516715}, 
     {-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(47*Pi)/30]^2, 1.1890852819516715}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106543}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(13*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/4, 1.2727298803122145}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106543}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(49*Pi)/30]^2, 1.3759750672106543}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}, \
{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, {(-5 - \
Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + 
       ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, {(-5 - \
Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, 
     {-Cos[(13*Pi)/15]^2 + (11*Sin[(13*Pi)/15]^2)/4, 1.4902097135042385}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361493}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[(13*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6081701375219564}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361493}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.8336364565828074}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(26*Pi)/15]^2, 1.7241122839361493}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.8336364565828074}, 
     {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(53*Pi)/30]^2, 1.8336364565828074}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, {(-5 \
- Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[(13*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(13*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/16, 1.9334320944111905}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}, \
{-Cos[(13*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.0946793219544757}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, {(-5 - \
Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, 
     {-Cos[(13*Pi)/15]^2 + (17*Sin[(13*Pi)/15]^2)/4, 2.021043485921703}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.0946793219544757}, 
     {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(28*Pi)/15]^2, 2.0946793219544757}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.195318553032825}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(13*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(13*Pi)/15]^2)/8, 2.1530633066599694}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.195318553032825}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.220880340843795}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/15]^2, 2.195318553032825}}], 
   Line[{{-Cos[(13*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.220880340843795}, 
     {-Cos[(13*Pi)/15]^2 + 5*Sin[(13*Pi)/15]^2, 2.229434476432182}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}, 
     {-Cos[(13*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(13*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(59*Pi)/30]^2, 2.220880340843795}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 1.2152748245287444}, \
{-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 1.2152748245287444}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/30]^2)/8, 1.7563683493937294}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[Pi/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[Pi/15]^2)/8, 1.7355139912456734}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(2*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(2*Pi)/15]^2)/8, 1.6537682358032735}}], 
   Line[{{(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + 
       (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, \
{-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, \
{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}], 
   Line[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846546}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071271}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846546}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/30]^2)/8, 1.4441489417584883}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071271}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(4*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(4*Pi)/15]^2)/8, 1.3571288512592454}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}], 
   Line[{{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640108}, \
{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640108}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/30]^2)/8, 1.083739609436978}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 \
+ Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/30]^2)/8, 0.9389137397717193}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, \
{-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082609}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(7*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(7*Pi)/15]^2)/8, 0.8965062230902947}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082606}, \
{-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082606}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(8*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(8*Pi)/15]^2)/8, 0.8965062230902947}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/30]^2)/8, 0.9389137397717193}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 \
+ Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640107}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640107}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/30]^2)/8, 1.0837396094369778}}], 
   Line[{{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + 
       ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, \
{-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, \
{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071267}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846544}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071267}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(11*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(11*Pi)/15]^2)/8, 1.357128851259245}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846544}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/30]^2)/8, 1.4441489417584883}}], 
   Line[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}], 
   Line[{{(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, \
{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(13*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(13*Pi)/15]^2)/8, 1.6537682358032735}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^4, 1.2005567894684717}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^4, 1.2005567894684717}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(14*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 1.7355139912456734}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, \
{-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 1.7563683493937294}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(14*Pi)/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, \
{-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(31*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(31*Pi)/30]^2)/8, 1.7563683493937294}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(16*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(16*Pi)/15]^2)/8, 1.7355139912456734}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(17*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(17*Pi)/15]^2)/8, 1.653768235803274}}], 
   Line[{{(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + 
       (5*(-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, \
{-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, \
{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}], 
   Line[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(37*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(37*Pi)/30]^2)/8, 1.4441489417584883}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(19*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(19*Pi)/15]^2)/8, 1.3571288512592459}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}], 
   Line[{{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(14*Pi)/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, \
{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(41*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(41*Pi)/30]^2)/8, 1.0837396094369778}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 \
+ Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(43*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(43*Pi)/30]^2)/8, 0.9389137397717198}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, \
{-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(22*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(22*Pi)/15]^2)/8, 0.896506223090295}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}, {(-5 - \
Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(14*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, \
{-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^2/8, 0.8816778784387096}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(23*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(23*Pi)/15]^2)/8, 0.8965062230902948}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(47*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(47*Pi)/30]^2)/8, 0.9389137397717195}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 \
+ Sqrt[5]))/64, 1.0035621274868154}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^4)/256 + ((-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/64, 1.0035621274868154}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(49*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(49*Pi)/30]^2)/8, 1.0837396094369776}}], 
   Line[{{(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}, \
{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + 
       ((-1 + Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, \
{-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, \
{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, 
     {(-5 - Sqrt[5])/8 + (11*(-1 + Sqrt[5])^2)/64, 1.1729281630054869}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {(-5 - Sqrt[5])/8 + (5*(5 - Sqrt[5])*(-1 + Sqrt[5])^2)/128 + ((-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/128, 1.2655525104241707}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(26*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(26*Pi)/15]^2)/8, 1.3571288512592459}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(53*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(53*Pi)/30]^2)/8, 1.4441489417584876}}], 
   Line[{{(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {(-5 - Sqrt[5])/8 + ((5 - Sqrt[5])*(-1 + Sqrt[5])^2)/64 + (5*(-1 + \
Sqrt[5])^2*(1 + Sqrt[5])^2)/256, 1.5239001577085332}}], 
   Line[{{(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}, \
{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + 
       ((-1 + Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(14*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, \
{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, 
     {(-5 - Sqrt[5])/8 + (17*(-1 + Sqrt[5])^2)/64, 1.5943005668830776}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(28*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(28*Pi)/15]^2)/8, 1.6537682358032735}}], 
   Line[{{(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {(-5 - Sqrt[5])/8 + (-1 + Sqrt[5])^4/128 + (5*(-1 + Sqrt[5])^2*(5 + \
Sqrt[5]))/128, 1.7011229525643674}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(29*Pi)/15]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/15]^2)/8, 1.7355139912456732}}], 
   Line[{{(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 \
+ Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2)/16, 1.7633557568774196}, \
{-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
     {(-5 - Sqrt[5])/8 + (5*(-1 + Sqrt[5])^2*Cos[(59*Pi)/30]^2)/16 + ((-1 + \
Sqrt[5])^2*Sin[(59*Pi)/30]^2)/8, 1.7563683493937294}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 1.2152748245287444}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491779}, \
{-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, 
     {-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 1.2152748245287444}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491779}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/30]^2*Sin[(14*Pi)/15]^2, 1.2152748245287444}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[Pi/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[Pi/15]^2*Sin[(14*Pi)/15]^2, 1.2005567894684717}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279131}, 
     {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279131}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \
{-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, \
{-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
     {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846546}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.50859507017628}, 
     {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846546}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071271}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.50859507017628}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846546}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071271}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071271}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640108}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
     {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640108}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640108}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, \
{-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082609}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082606}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, \
{-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, 
     {-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082606}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(8*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.6201700772082606}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.6489952411032603}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640107}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640107}, 
     {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.7478557941640107}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \
{-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, \
{-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
     {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071267}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071267}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846544}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.5085950701762803}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(14*Pi)/15]^2, 0.9361441841071267}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846544}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.5085950701762803}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(14*Pi)/15]^2, 0.9965396214846544}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
     {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279134}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
     {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279134}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(14*Pi)/15]^2, 1.143020501605284}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^4, 1.2005567894684717}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}, 
     {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^4, 1.2005567894684717}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^4, 0.6211835161491779}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^4, 1.2005567894684717}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, \
{-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^4, 0.6211835161491779}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 1.2152748245287444}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(14*Pi)/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(29*Pi)/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491779}, \
{-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, 
     {-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(16*Pi)/15]^2, 0.6135770923916904}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491779}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(31*Pi)/30]^2, 1.2152748245287444}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(16*Pi)/15]^2, 0.6135770923916904}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(16*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(16*Pi)/15]^2, 1.2005567894684717}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279135}, 
     {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}, 
     {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279135}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(17*Pi)/15]^2, 1.1430205016052841}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \
{-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, \
{-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
     {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(37*Pi)/30]^2, 0.50859507017628}, 
     {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498115}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(37*Pi)/30]^2, 0.50859507017628}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(37*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(37*Pi)/30]^2, 0.9965396214846546}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498115}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(19*Pi)/15]^2, 0.9361441841071272}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(14*Pi)/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(29*Pi)/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272197}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
     {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272197}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(41*Pi)/30]^2, 0.7478557941640107}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139486}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714163}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139486}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(43*Pi)/30]^2, 0.6489952411032606}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, \
{-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714163}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(22*Pi)/15]^2, 0.6201700772082609}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(14*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(29*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714163}, \
{-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, 
     {-Cos[(14*Pi)/15]^2 + 2*Sin[(14*Pi)/15]^2, 0.6101049646137003}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.33154008354139486}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714163}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(23*Pi)/15]^2, 0.6201700772082609}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(47*Pi)/30]^2, 0.33154008354139486}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(47*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(47*Pi)/30]^2, 0.6489952411032603}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + \
((5 + Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721944}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
     {-Cos[(14*Pi)/15]^2 + (5*(-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16 + ((5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/4, 0.6930472461935369}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}, 
     {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721944}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(49*Pi)/30]^2, 0.7478557941640104}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}, \
{-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, \
{-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + 
       ((1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, \
{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, 
     {-Cos[(14*Pi)/15]^2 + (11*Sin[(14*Pi)/15]^2)/4, 0.8090441125945327}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498115}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
     {-Cos[(14*Pi)/15]^2 + (5*(5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8, 0.8728320775698118}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(53*Pi)/30]^2, 0.50859507017628}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498115}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(26*Pi)/15]^2, 0.9361441841071272}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(53*Pi)/30]^2, 0.50859507017628}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(53*Pi)/30]^2, 0.9965396214846538}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}, 
     {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
     {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, 
     {-Cos[(14*Pi)/15]^2 + ((5 - Sqrt[5])*Sin[(14*Pi)/15]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(14*Pi)/15]^2)/16, 1.0520980143876293}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}, \
{-Cos[(14*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(14*Pi)/15]^2 + 
       2*Sin[(14*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(29*Pi)/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279134}, \
{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, 
     {-Cos[(14*Pi)/15]^2 + (17*Sin[(14*Pi)/15]^2)/4, 1.1013148858947206}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279134}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(28*Pi)/15]^2, 1.143020501605284}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916908}, 
     {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, 
     {-Cos[(14*Pi)/15]^2 + ((-1 + Sqrt[5])^2*Sin[(14*Pi)/15]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(14*Pi)/15]^2)/8, 1.1763209525760518}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491779}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(29*Pi)/15]^2, 0.6135770923916908}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(29*Pi)/15]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/15]^2, 1.2005567894684717}}], 
   Line[{{-Cos[(14*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}, 
     {-Cos[(14*Pi)/15]^2 + 5*Sin[(14*Pi)/15]^2, 1.2202099292274005}, \
{-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491779}, 
     {-Cos[(14*Pi)/15]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(14*Pi)/15]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(59*Pi)/30]^2, 1.2152748245287444}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491779}, {-1, 0}, {-1, \
0}, {-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491779}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/30]^2*Sin[(29*Pi)/30]^2, 0.6211835161491779}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}, 
     {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[Pi/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[Pi/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 \
+ Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279131}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + ((-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 0.6010618457721164}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279131}, 
     {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, \
{-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(2*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279131}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, \
{-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, {-1, \
0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 
      0.5624063276196133}}], Line[{{-Cos[(29*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 
      0.5371028573756126}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, \
0.50859507017628}, 
     {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 
      0.5371028573756126}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
      0.50859507017628}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, \
0.47767060184981125}, 
     {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(7*Pi)/30]^2*Sin[(29*Pi)/30]^2, \
0.50859507017628}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(4*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
     {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, \
{-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, {-1, 0}, {-1, 0}, \

     {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}, {-1, 0}, {-1, \
0}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, {-1, 0}, {-1, 0}, \

     {-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.33154008354139486}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, 
     {-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, {-1, 0}, \
{-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(7*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.31695593148714096}, {-1, 0}, \
{-1, 0}, {-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 
      0.3118675362266397}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
      0.31695593148714096}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
      0.33154008354139486}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(8*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
      0.31695593148714096}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
      0.33154008354139486}, {-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
      0.3538602304100192}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(17*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
      0.33154008354139486}}], Line[{{-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
      0.3538602304100192}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 
      0.3816816923272197}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + 
       ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}, 
     {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, \
{-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(19*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.3816816923272197}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}, {-1, 0}, {-1, \
0}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.5085950701762803}, {-1, 0}, {-1, 0}, \

     {-Cos[(29*Pi)/30]^2 + 5*Cos[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(11*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.47767060184981125}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.5085950701762803}, 
     {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(23*Pi)/30]^2*Sin[(29*Pi)/30]^2, 0.5085950701762803}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, 
     {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, \
{-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.5838857533279134}, {-1, 0}, \
{-1, 0}, {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 
      0.5624063276196133}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
      0.5838857533279134}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
      0.6010618457721164}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(13*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
      0.5838857533279134}}], Line[{{-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
      0.6010618457721164}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
      0.6135770923916904}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
      0.6010618457721164}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 
      0.6135770923916904}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(29*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^4, \
0.6211835161491779}, {-1, 0}, 
     {-1, 0}, {-Cos[(29*Pi)/30]^2 + 5*Cos[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(14*Pi)/15]^2*Sin[(29*Pi)/30]^2, 0.6135770923916904}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^4, 0.6211835161491779}, 
     {-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, {-1, 0}, \
{-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(29*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^4, 0.6211835161491779}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 0.6237350724532796}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(31*Pi)/30]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(29*Pi)/30]^2*Sin[(31*Pi)/30]^2, 0.6211835161491779}, {-1, 0}, \
{-1, 0}, {-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, 
      0.6237350724532796}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(31*Pi)/30]^2, 
      0.6211835161491779}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
      0.6135770923916904}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(31*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(31*Pi)/30]^2, 
      0.6211835161491779}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
      0.6135770923916904}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
      0.6010618457721164}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(16*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(16*Pi)/15]^2, 
      0.6135770923916904}}], Line[{{-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
      0.6010618457721164}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
      0.5838857533279135}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
      0.6010618457721164}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(17*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(17*Pi)/15]^2, 
      0.5838857533279135}, {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, \
0.5624063276196133}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(17*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(17*Pi)/15]^2, 0.5838857533279135}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, \
{-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + 
       (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, {-1, \
0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 
      0.5624063276196133}}], Line[{{-Cos[(29*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 
      0.5371028573756126}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(37*Pi)/30]^2, 0.50859507017628}, 
     {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + ((5 - \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 
      0.5371028573756126}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(37*Pi)/30]^2, 
      0.50859507017628}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(19*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498115}, 
     {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(37*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(37*Pi)/30]^2, 0.50859507017628}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498115}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(19*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(19*Pi)/15]^2, 0.4776706018498115}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
     {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, \
{-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272197}, {-1, 0}, {-1, 0}, \

     {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272197}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(41*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(41*Pi)/30]^2, 0.3816816923272197}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + \
((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139486}, {-1, 0}, {-1, \
0}, 
     {-Cos[(29*Pi)/30]^2 + (5*(-1 + Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + \
Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139486}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714163}, {-1, 0}, {-1, \
0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(43*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(43*Pi)/30]^2, 0.33154008354139486}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714163}, 
     {-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, {-1, 0}, \
{-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(22*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(22*Pi)/15]^2, 0.31695593148714163}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 0.3118675362266397}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(23*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(29*Pi)/30]^2*Sin[(23*Pi)/15]^2, 0.31695593148714163}, {-1, 0}, \
{-1, 0}, {-Cos[(29*Pi)/30]^2 + 2*Sin[(29*Pi)/30]^2, 
      0.3118675362266397}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(23*Pi)/15]^2, 
      0.31695593148714163}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
      0.33154008354139486}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(23*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(23*Pi)/15]^2, 
      0.31695593148714163}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
      0.33154008354139486}, {-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
      0.3538602304100192}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(47*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(47*Pi)/30]^2, 
      0.33154008354139486}}], Line[{{-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 
      0.3538602304100192}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(49*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(49*Pi)/30]^2, 
      0.38168169232721944}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + (5*(-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16 + 
       ((5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/4, 0.3538602304100192}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721944}, 
     {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}, \
{-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(49*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(49*Pi)/30]^2, 0.38168169232721944}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, \
0.41280605266694914}, 
     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + (11*Sin[(29*Pi)/30]^2)/4, 0.41280605266694914}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498115}, {-1, 0}, {-1, 0}, \

     {-Cos[(29*Pi)/30]^2 + (5*(5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/8 + ((1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8, 0.44532374723565715}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498115}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(53*Pi)/30]^2, 0.50859507017628}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(26*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(26*Pi)/15]^2, 0.4776706018498115}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(53*Pi)/30]^2, 0.50859507017628}, 
     {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(53*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(53*Pi)/30]^2, 0.50859507017628}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}, 
     {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, \
{-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + ((5 - Sqrt[5])*Sin[(29*Pi)/30]^2)/4 + (5*(1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/16, 0.5371028573756126}}], 
   Line[{{-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 0.5624063276196133}, \
{-Cos[(29*Pi)/30]^2 + 5*Cos[(28*Pi)/15]^2*Sin[(29*Pi)/30]^2 + 
       2*Sin[(29*Pi)/30]^2*Sin[(28*Pi)/15]^2, 0.5838857533279134}, {-1, 0}, \
{-1, 0}, {-Cos[(29*Pi)/30]^2 + (17*Sin[(29*Pi)/30]^2)/4, 
      0.5624063276196133}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(28*Pi)/15]^2, 
      0.5838857533279134}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
      0.6010618457721164}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(28*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(28*Pi)/15]^2, 
      0.5838857533279134}}], Line[{{-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
      0.6010618457721164}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
      0.6135770923916908}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + ((-1 + \
Sqrt[5])^2*Sin[(29*Pi)/30]^2)/8 + (5*(5 + Sqrt[5])*Sin[(29*Pi)/30]^2)/8, 
      0.6010618457721164}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
      0.6135770923916908}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
      0.6211835161491779}, {-1, 0}, {-1, 0}, {-Cos[(29*Pi)/30]^2 + \
5*Cos[(29*Pi)/15]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(29*Pi)/15]^2, 
      0.6135770923916908}}], Line[{{-Cos[(29*Pi)/30]^2 + \
5*Cos[(59*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(59*Pi)/30]^2, 
      0.6211835161491779}, {-Cos[(29*Pi)/30]^2 + 5*Sin[(29*Pi)/30]^2, \
0.6237350724532796}, {-1, 0}, {-1, 0}, 
     {-Cos[(29*Pi)/30]^2 + 5*Cos[(59*Pi)/30]^2*Sin[(29*Pi)/30]^2 + \
2*Sin[(29*Pi)/30]^2*Sin[(59*Pi)/30]^2, 0.6211835161491779}}]}}, 
 {Axes -> True, PlotRange -> All, AspectRatio -> Automatic}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ParametricMesh3D[ n , {t, 0, Pi, Pi / 30}, {p, 0,  2 Pi, Pi / 30}, Lighting \
-> False, FillColor -> ((RGBColor @@ Abs[ MeanNode[#] ] ) &)]  \
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 6.45642e-17 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.329 .489 .461 r
.49889 .55376 m .52065 .55481 L .52015 .58412 L p F P
0 g
s
.329 .489 .461 r
.52015 .58412 m .49647 .58301 L .49889 .55376 L p F P
0 g
s
.276 .521 .461 r
.54389 .58377 m .52015 .58412 L .52065 .55481 L p F P
0 g
s
.354 .526 .397 r
.49647 .58301 m .52015 .58412 L .51972 .61343 L p F P
0 g
s
.297 .56 .397 r
.52015 .58412 m .54389 .58377 L .54514 .61306 L p F P
0 g
s
.297 .56 .397 r
.54514 .61306 m .51972 .61343 L .52015 .58412 L p F P
0 g
s
.276 .521 .461 r
.52065 .55481 m .54246 .55448 L .54389 .58377 L p F P
0 g
s
.22 .547 .461 r
.56747 .58195 m .54389 .58377 L .54246 .55448 L p F P
0 g
s
.237 .588 .397 r
.54389 .58377 m .56747 .58195 L .57041 .61115 L p F P
0 g
s
.237 .588 .397 r
.57041 .61115 m .54514 .61306 L .54389 .58377 L p F P
0 g
s
.52015 .58412 m
.54389 .58377 L
s
.3 .447 .52 r
.50157 .52473 m .52121 .52569 L .52065 .55481 L p F P
0 g
s
.3 .447 .52 r
.52065 .55481 m .49889 .55376 L .50157 .52473 L p F P
0 g
s
.252 .475 .52 r
.54246 .55448 m .52065 .55481 L .52121 .52569 L p F P
0 g
s
.52015 .58412 m
.52065 .55481 L
s
.379 .452 .461 r
.47736 .55136 m .49889 .55376 L .49647 .58301 L p F P
0 g
s
.379 .452 .461 r
.49647 .58301 m .47304 .58043 L .47736 .55136 L p F P
0 g
s
.407 .486 .397 r
.47304 .58043 m .49647 .58301 L .49435 .61226 L p F P
0 g
s
.354 .526 .397 r
.51972 .61343 m .49435 .61226 L .49647 .58301 L p F P
0 g
s
.49647 .58301 m
.52015 .58412 L
s
.376 .558 .328 r
.49435 .61226 m .51972 .61343 L .51934 .64253 L p F P
0 g
s
.315 .594 .328 r
.51972 .61343 m .54514 .61306 L .54621 .64215 L p F P
0 g
s
.315 .594 .328 r
.54621 .64215 m .51934 .64253 L .51972 .61343 L p F P
0 g
s
.51972 .61343 m
.52015 .58412 L
s
.252 .475 .52 r
.52121 .52569 m .54088 .52538 L .54246 .55448 L p F P
0 g
s
.201 .499 .52 r
.56414 .55278 m .54246 .55448 L .54088 .52538 L p F P
0 g
s
.22 .547 .461 r
.54246 .55448 m .56414 .55278 L .56747 .58195 L p F P
0 g
s
.54246 .55448 m
.54389 .58377 L
s
.52065 .55481 m
.54246 .55448 L
s
.252 .624 .328 r
.54514 .61306 m .57041 .61115 L .57293 .64016 L p F P
0 g
s
.252 .624 .328 r
.57293 .64016 m .54621 .64215 L .54514 .61306 L p F P
0 g
s
.54389 .58377 m
.54514 .61306 L
s
.51972 .61343 m
.54514 .61306 L
s
.345 .413 .52 r
.48216 .52252 m .50157 .52473 L .49889 .55376 L p F P
0 g
s
.345 .413 .52 r
.49889 .55376 m .47736 .55136 L .48216 .52252 L p F P
0 g
s
.49889 .55376 m
.52065 .55481 L
s
.49647 .58301 m
.49889 .55376 L
s
.162 .567 .461 r
.59071 .57868 m .56747 .58195 L .56414 .55278 L p F P
0 g
s
.174 .61 .397 r
.56747 .58195 m .59071 .57868 L .59531 .6077 L p F P
0 g
s
.174 .61 .397 r
.59531 .6077 m .57041 .61115 L .56747 .58195 L p F P
0 g
s
.54389 .58377 m
.56747 .58195 L
s
.407 .486 .397 r
.49435 .61226 m .46924 .60955 L .47304 .58043 L p F P
0 g
s
.432 .515 .328 r
.46924 .60955 m .49435 .61226 L .49252 .64131 L p F P
0 g
s
.376 .558 .328 r
.51934 .64253 m .49252 .64131 L .49435 .61226 L p F P
0 g
s
.49435 .61226 m
.51972 .61343 L
s
.49435 .61226 m
.49647 .58301 L
s
.201 .499 .52 r
.54088 .52538 m .56043 .52382 L .56414 .55278 L p F P
0 g
s
.148 .518 .52 r
.58549 .54971 m .56414 .55278 L .56043 .52382 L p F P
0 g
s
.162 .567 .461 r
.56414 .55278 m .58549 .54971 L .59071 .57868 L p F P
0 g
s
.56414 .55278 m
.56747 .58195 L
s
.54246 .55448 m
.56414 .55278 L
s
.185 .647 .328 r
.57041 .61115 m .59531 .6077 L .59927 .63658 L p F P
0 g
s
.185 .647 .328 r
.59927 .63658 m .57293 .64016 L .57041 .61115 L p F P
0 g
s
.56747 .58195 m
.57041 .61115 L
s
.54514 .61306 m
.57041 .61115 L
s
.424 .41 .461 r
.45625 .5476 m .47736 .55136 L .47304 .58043 L p F P
0 g
s
.424 .41 .461 r
.47304 .58043 m .45006 .57641 L .45625 .5476 L p F P
0 g
s
.456 .441 .397 r
.45006 .57641 m .47304 .58043 L .46924 .60955 L p F P
0 g
s
.47304 .58043 m
.49647 .58301 L
s
.268 .399 .574 r
.50451 .49611 m .52181 .49696 L .52121 .52569 L p F P
0 g
s
.268 .399 .574 r
.52121 .52569 m .50157 .52473 L .50451 .49611 L p F P
0 g
s
.225 .425 .574 r
.54088 .52538 m .52121 .52569 L .52181 .49696 L p F P
0 g
s
.52065 .55481 m
.52121 .52569 L
s
.387 .374 .52 r
.46313 .51907 m .48216 .52252 L .47736 .55136 L p F P
0 g
s
.387 .374 .52 r
.47736 .55136 m .45625 .5476 L .46313 .51907 L p F P
0 g
s
.47736 .55136 m
.49889 .55376 L
s
.47304 .58043 m
.47736 .55136 L
s
.225 .425 .574 r
.52181 .49696 m .53916 .49669 L .54088 .52538 L p F P
0 g
s
.18 .446 .574 r
.56043 .52382 m .54088 .52538 L .53916 .49669 L p F P
0 g
s
.52121 .52569 m
.54088 .52538 L
s
.54088 .52538 m
.54246 .55448 L
s
.393 .583 .256 r
.49252 .64131 m .51934 .64253 L .51903 .67122 L p F P
0 g
s
.33 .621 .256 r
.51934 .64253 m .54621 .64215 L .5471 .67082 L p F P
0 g
s
.33 .621 .256 r
.5471 .67082 m .51903 .67122 L .51934 .64253 L p F P
0 g
s
.51934 .64253 m
.51972 .61343 L
s
.263 .652 .256 r
.54621 .64215 m .57293 .64016 L .57501 .66878 L p F P
0 g
s
.263 .652 .256 r
.57501 .66878 m .5471 .67082 L .54621 .64215 L p F P
0 g
s
.54514 .61306 m
.54621 .64215 L
s
.51934 .64253 m
.54621 .64215 L
s
.456 .441 .397 r
.46924 .60955 m .4446 .60531 L .45006 .57641 L p F P
0 g
s
.483 .467 .328 r
.4446 .60531 m .46924 .60955 L .46597 .6385 L p F P
0 g
s
.432 .515 .328 r
.49252 .64131 m .46597 .6385 L .46924 .60955 L p F P
0 g
s
.46924 .60955 m
.49435 .61226 L
s
.46924 .60955 m
.47304 .58043 L
s
.309 .369 .574 r
.48741 .49413 m .50451 .49611 L .50157 .52473 L p F P
0 g
s
.309 .369 .574 r
.50157 .52473 m .48216 .52252 L .48741 .49413 L p F P
0 g
s
.49889 .55376 m
.50157 .52473 L
s
.50157 .52473 m
.52121 .52569 L
s
.102 .581 .461 r
.61341 .57397 m .59071 .57868 L .58549 .54971 L p F P
0 g
s
.11 .625 .397 r
.59071 .57868 m .61341 .57397 L .61966 .60274 L p F P
0 g
s
.11 .625 .397 r
.61966 .60274 m .59531 .6077 L .59071 .57868 L p F P
0 g
s
.56747 .58195 m
.59071 .57868 L
s
.452 .539 .256 r
.46597 .6385 m .49252 .64131 L .49101 .66997 L p F P
0 g
s
.393 .583 .256 r
.51903 .67122 m .49101 .66997 L .49252 .64131 L p F P
0 g
s
.49252 .64131 m
.51934 .64253 L
s
.49252 .64131 m
.49435 .61226 L
s
.148 .518 .52 r
.56043 .52382 m .57968 .52101 L .58549 .54971 L p F P
0 g
s
.093 .53 .52 r
.60633 .54531 m .58549 .54971 L .57968 .52101 L p F P
0 g
s
.102 .581 .461 r
.58549 .54971 m .60633 .54531 L .61341 .57397 L p F P
0 g
s
.58549 .54971 m
.59071 .57868 L
s
.56414 .55278 m
.58549 .54971 L
s
.18 .446 .574 r
.53916 .49669 m .55638 .4953 L .56043 .52382 L p F P
0 g
s
.132 .462 .574 r
.57968 .52101 m .56043 .52382 L .55638 .4953 L p F P
0 g
s
.56043 .52382 m
.56414 .55278 L
s
.54088 .52538 m
.56043 .52382 L
s
.116 .662 .328 r
.59531 .6077 m .61966 .60274 L .62502 .63143 L p F P
0 g
s
.116 .662 .328 r
.62502 .63143 m .59927 .63658 L .59531 .6077 L p F P
0 g
s
.59071 .57868 m
.59531 .6077 L
s
.57041 .61115 m
.59531 .6077 L
s
.193 .676 .256 r
.57293 .64016 m .59927 .63658 L .60253 .66511 L p F P
0 g
s
.193 .676 .256 r
.60253 .66511 m .57501 .66878 L .57293 .64016 L p F P
0 g
s
.57041 .61115 m
.57293 .64016 L
s
.54621 .64215 m
.57293 .64016 L
s
.345 .335 .574 r
.47065 .49104 m .48741 .49413 L .48216 .52252 L p F P
0 g
s
.345 .335 .574 r
.48216 .52252 m .46313 .51907 L .47065 .49104 L p F P
0 g
s
.48216 .52252 m
.50157 .52473 L
s
.47736 .55136 m
.48216 .52252 L
s
.464 .363 .461 r
.43575 .54251 m .45625 .5476 L .45006 .57641 L p F P
0 g
s
.464 .363 .461 r
.45006 .57641 m .42772 .57097 L .43575 .54251 L p F P
0 g
s
.5 .391 .397 r
.42772 .57097 m .45006 .57641 L .4446 .60531 L p F P
0 g
s
.45006 .57641 m
.47304 .58043 L
s
.424 .332 .52 r
.44467 .51441 m .46313 .51907 L .45625 .5476 L p F P
0 g
s
.424 .332 .52 r
.45625 .5476 m .43575 .54251 L .44467 .51441 L p F P
0 g
s
.45625 .5476 m
.47736 .55136 L
s
.45006 .57641 m
.45625 .5476 L
s
.132 .462 .574 r
.55638 .4953 m .57334 .49278 L .57968 .52101 L p F P
0 g
s
.083 .474 .574 r
.59846 .51698 m .57968 .52101 L .57334 .49278 L p F P
0 g
s
.093 .53 .52 r
.57968 .52101 m .59846 .51698 L .60633 .54531 L p F P
0 g
s
.57968 .52101 m
.58549 .54971 L
s
.56043 .52382 m
.57968 .52101 L
s
.483 .467 .328 r
.46597 .6385 m .43991 .6341 L .4446 .60531 L p F P
0 g
s
.506 .489 .256 r
.43991 .6341 m .46597 .6385 L .46327 .66708 L p F P
0 g
s
.452 .539 .256 r
.49101 .66997 m .46327 .66708 L .46597 .6385 L p F P
0 g
s
.46597 .6385 m
.49252 .64131 L
s
.46597 .6385 m
.46924 .60955 L
s
.5 .391 .397 r
.4446 .60531 m .42063 .59958 L .42772 .57097 L p F P
0 g
s
.53 .414 .328 r
.42063 .59958 m .4446 .60531 L .43991 .6341 L p F P
0 g
s
.4446 .60531 m
.46924 .60955 L
s
.4446 .60531 m
.45006 .57641 L
s
.233 .347 .621 r
.50768 .46811 m .52247 .46885 L .52181 .49696 L p F P
0 g
s
.233 .347 .621 r
.52181 .49696 m .50451 .49611 L .50768 .46811 L p F P
0 g
s
.196 .37 .621 r
.53916 .49669 m .52181 .49696 L .52247 .46885 L p F P
0 g
s
.52121 .52569 m
.52181 .49696 L
s
.196 .37 .621 r
.52247 .46885 m .53729 .46862 L .53916 .49669 L p F P
0 g
s
.156 .388 .621 r
.55638 .4953 m .53916 .49669 L .53729 .46862 L p F P
0 g
s
.52181 .49696 m
.53916 .49669 L
s
.53916 .49669 m
.54088 .52538 L
s
.041 .588 .461 r
.63537 .56785 m .61341 .57397 L .60633 .54531 L p F P
0 g
s
.044 .633 .397 r
.61341 .57397 m .63537 .56785 L .64322 .59629 L p F P
0 g
s
.044 .633 .397 r
.64322 .59629 m .61966 .60274 L .61341 .57397 L p F P
0 g
s
.59071 .57868 m
.61341 .57397 L
s
.037 .537 .52 r
.62647 .5396 m .60633 .54531 L .59846 .51698 L p F P
0 g
s
.041 .588 .461 r
.60633 .54531 m .62647 .5396 L .63537 .56785 L p F P
0 g
s
.58549 .54971 m
.60633 .54531 L
s
.60633 .54531 m
.61341 .57397 L
s
.406 .602 .181 r
.49101 .66997 m .51903 .67122 L .51878 .69928 L p F P
0 g
s
.341 .641 .181 r
.51903 .67122 m .5471 .67082 L .54779 .69888 L p F P
0 g
s
.341 .641 .181 r
.54779 .69888 m .51878 .69928 L .51903 .67122 L p F P
0 g
s
.51903 .67122 m
.51934 .64253 L
s
.268 .321 .621 r
.49307 .46639 m .50768 .46811 L .50451 .49611 L p F P
0 g
s
.268 .321 .621 r
.50451 .49611 m .48741 .49413 L .49307 .46639 L p F P
0 g
s
.50157 .52473 m
.50451 .49611 L
s
.50451 .49611 m
.52181 .49696 L
s
.379 .297 .574 r
.45441 .48687 m .47065 .49104 L .46313 .51907 L p F P
0 g
s
.379 .297 .574 r
.46313 .51907 m .44467 .51441 L .45441 .48687 L p F P
0 g
s
.46313 .51907 m
.48216 .52252 L
s
.45625 .5476 m
.46313 .51907 L
s
.272 .673 .181 r
.5471 .67082 m .57501 .66878 L .57663 .69681 L p F P
0 g
s
.272 .673 .181 r
.57663 .69681 m .54779 .69888 L .5471 .67082 L p F P
0 g
s
.54621 .64215 m
.5471 .67082 L
s
.51903 .67122 m
.5471 .67082 L
s
.122 .692 .256 r
.59927 .63658 m .62502 .63143 L .62945 .65982 L p F P
0 g
s
.122 .692 .256 r
.62945 .65982 m .60253 .66511 L .59927 .63658 L p F P
0 g
s
.59531 .6077 m
.59927 .63658 L
s
.57293 .64016 m
.59927 .63658 L
s
.156 .388 .621 r
.53729 .46862 m .55201 .4674 L .55638 .4953 L p F P
0 g
s
.115 .402 .621 r
.57334 .49278 m .55638 .4953 L .55201 .4674 L p F P
0 g
s
.53916 .49669 m
.55638 .4953 L
s
.55638 .4953 m
.56043 .52382 L
s
.466 .556 .181 r
.46327 .66708 m .49101 .66997 L .48983 .69801 L p F P
0 g
s
.406 .602 .181 r
.51878 .69928 m .48983 .69801 L .49101 .66997 L p F P
0 g
s
.49101 .66997 m
.49252 .64131 L
s
.49101 .66997 m
.51903 .67122 L
s
.047 .671 .328 r
.61966 .60274 m .64322 .59629 L .64997 .62473 L p F P
0 g
s
.047 .671 .328 r
.64997 .62473 m .62502 .63143 L .61966 .60274 L p F P
0 g
s
.61341 .57397 m
.61966 .60274 L
s
.59531 .6077 m
.61966 .60274 L
s
.3 .291 .621 r
.47877 .46371 m .49307 .46639 L .48741 .49413 L p F P
0 g
s
.3 .291 .621 r
.48741 .49413 m .47065 .49104 L .47877 .46371 L p F P
0 g
s
.48741 .49413 m
.50451 .49611 L
s
.48216 .52252 m
.48741 .49413 L
s
.083 .474 .574 r
.57334 .49278 m .58986 .48917 L .59846 .51698 L p F P
0 g
s
.033 .48 .574 r
.6166 .51174 m .59846 .51698 L .58986 .48917 L p F P
0 g
s
.037 .537 .52 r
.59846 .51698 m .6166 .51174 L .62647 .5396 L p F P
0 g
s
.59846 .51698 m
.60633 .54531 L
s
.57968 .52101 m
.59846 .51698 L
s
.2 .698 .181 r
.57501 .66878 m .60253 .66511 L .60509 .69308 L p F P
0 g
s
.2 .698 .181 r
.60509 .69308 m .57663 .69681 L .57501 .66878 L p F P
0 g
s
.57293 .64016 m
.57501 .66878 L
s
.5471 .67082 m
.57501 .66878 L
s
.456 .286 .52 r
.42693 .50856 m .44467 .51441 L .43575 .54251 L p F P
0 g
s
.456 .286 .52 r
.43575 .54251 m .41604 .53612 L .42693 .50856 L p F P
0 g
s
.5 .313 .461 r
.41604 .53612 m .43575 .54251 L .42772 .57097 L p F P
0 g
s
.43575 .54251 m
.45625 .5476 L
s
.5 .313 .461 r
.42772 .57097 m .40622 .56413 L .41604 .53612 L p F P
0 g
s
.538 .337 .397 r
.40622 .56413 m .42772 .57097 L .42063 .59958 L p F P
0 g
s
.42772 .57097 m
.43575 .54251 L
s
.42772 .57097 m
.45006 .57641 L
s
.53 .414 .328 r
.43991 .6341 m .41455 .62814 L .42063 .59958 L p F P
0 g
s
.554 .433 .256 r
.41455 .62814 m .43991 .6341 L .43604 .66256 L p F P
0 g
s
.506 .489 .256 r
.46327 .66708 m .43604 .66256 L .43991 .6341 L p F P
0 g
s
.43991 .6341 m
.46597 .6385 L
s
.43991 .6341 m
.4446 .60531 L
s
.115 .402 .621 r
.55201 .4674 m .56648 .46522 L .57334 .49278 L p F P
0 g
s
.072 .412 .621 r
.58986 .48917 m .57334 .49278 L .56648 .46522 L p F P
0 g
s
.57334 .49278 m
.57968 .52101 L
s
.55638 .4953 m
.57334 .49278 L
s
.522 .504 .181 r
.43604 .66256 m .46327 .66708 L .46117 .69508 L p F P
0 g
s
.466 .556 .181 r
.48983 .69801 m .46117 .69508 L .46327 .66708 L p F P
0 g
s
.46327 .66708 m
.49101 .66997 L
s
.46327 .66708 m
.46597 .6385 L
s
.407 .255 .574 r
.43883 .48164 m .45441 .48687 L .44467 .51441 L p F P
0 g
s
.407 .255 .574 r
.44467 .51441 m .42693 .50856 L .43883 .48164 L p F P
0 g
s
.44467 .51441 m
.46313 .51907 L
s
.43575 .54251 m
.44467 .51441 L
s
.538 .337 .397 r
.42063 .59958 m .39755 .59237 L .40622 .56413 L p F P
0 g
s
.57 .357 .328 r
.39755 .59237 m .42063 .59958 L .41455 .62814 L p F P
0 g
s
.42063 .59958 m
.4446 .60531 L
s
.42063 .59958 m
.42772 .57097 L
s
.329 .258 .621 r
.46492 .46009 m .47877 .46371 L .47065 .49104 L p F P
0 g
s
.329 .258 .621 r
.47065 .49104 m .45441 .48687 L .46492 .46009 L p F P
0 g
s
.47065 .49104 m
.48741 .49413 L
s
.46313 .51907 m
.47065 .49104 L
s
.019 .538 .52 r
.64574 .5326 m .62647 .5396 L .6166 .51174 L p F P
0 g
s
.021 .589 .461 r
.62647 .5396 m .64574 .5326 L .6564 .56036 L p F P
0 g
s
.021 .589 .461 r
.6564 .56036 m .63537 .56785 L .62647 .5396 L p F P
0 g
s
.60633 .54531 m
.62647 .5396 L
s
.049 .701 .256 r
.62502 .63143 m .64997 .62473 L .65555 .65294 L p F P
0 g
s
.049 .701 .256 r
.65555 .65294 m .62945 .65982 L .62502 .63143 L p F P
0 g
s
.61966 .60274 m
.62502 .63143 L
s
.59927 .63658 m
.62502 .63143 L
s
.023 .634 .397 r
.63537 .56785 m .6564 .56036 L .66581 .5884 L p F P
0 g
s
.023 .634 .397 r
.66581 .5884 m .64322 .59629 L .63537 .56785 L p F P
0 g
s
.62647 .5396 m
.63537 .56785 L
s
.61341 .57397 m
.63537 .56785 L
s
.126 .715 .181 r
.60253 .66511 m .62945 .65982 L .63292 .68771 L p F P
0 g
s
.126 .715 .181 r
.63292 .68771 m .60509 .69308 L .60253 .66511 L p F P
0 g
s
.59927 .63658 m
.60253 .66511 L
s
.57501 .66878 m
.60253 .66511 L
s
.072 .412 .621 r
.56648 .46522 m .58059 .46208 L .58986 .48917 L p F P
0 g
s
.028 .417 .621 r
.60581 .48448 m .58986 .48917 L .58059 .46208 L p F P
0 g
s
.033 .48 .574 r
.58986 .48917 m .60581 .48448 L .6166 .51174 L p F P
0 g
s
.58986 .48917 m
.59846 .51698 L
s
.57334 .49278 m
.58986 .48917 L
s
.196 .292 .661 r
.51107 .44094 m .52317 .44156 L .52247 .46885 L p F P
0 g
s
.196 .292 .661 r
.52247 .46885 m .50768 .46811 L .51107 .44094 L p F P
0 g
s
.164 .311 .661 r
.53729 .46862 m .52247 .46885 L .52317 .44156 L p F P
0 g
s
.52181 .49696 m
.52247 .46885 L
s
.164 .311 .661 r
.52317 .44156 m .53529 .44136 L .53729 .46862 L p F P
0 g
s
.131 .326 .661 r
.55201 .4674 m .53729 .46862 L .53529 .44136 L p F P
0 g
s
.52247 .46885 m
.53729 .46862 L
s
.53729 .46862 m
.53916 .49669 L
s
.017 .481 .574 r
.63392 .50534 m .6166 .51174 L .60581 .48448 L p F P
0 g
s
.019 .538 .52 r
.6166 .51174 m .63392 .50534 L .64574 .5326 L p F P
0 g
s
.6166 .51174 m
.62647 .5396 L
s
.59846 .51698 m
.6166 .51174 L
s
.225 .27 .661 r
.49912 .43951 m .51107 .44094 L .50768 .46811 L p F P
0 g
s
.225 .27 .661 r
.50768 .46811 m .49307 .46639 L .49912 .43951 L p F P
0 g
s
.50451 .49611 m
.50768 .46811 L
s
.50768 .46811 m
.52247 .46885 L
s
.414 .614 .104 r
.48983 .69801 m .51878 .69928 L .51861 .72651 L p F P
0 g
s
.348 .654 .104 r
.51878 .69928 m .54779 .69888 L .54828 .7261 L p F P
0 g
s
.348 .654 .104 r
.54828 .7261 m .51861 .72651 L .51878 .69928 L p F P
0 g
s
.51878 .69928 m
.51903 .67122 L
s
.024 .672 .328 r
.64322 .59629 m .66581 .5884 L .67389 .61652 L p F P
0 g
s
.024 .672 .328 r
.67389 .61652 m .64997 .62473 L .64322 .59629 L p F P
0 g
s
.63537 .56785 m
.64322 .59629 L
s
.61966 .60274 m
.64322 .59629 L
s
.277 .687 .104 r
.54779 .69888 m .57663 .69681 L .57779 .72402 L p F P
0 g
s
.277 .687 .104 r
.57779 .72402 m .54828 .7261 L .54779 .69888 L p F P
0 g
s
.5471 .67082 m
.54779 .69888 L
s
.51878 .69928 m
.54779 .69888 L
s
.131 .326 .661 r
.53529 .44136 m .54733 .44035 L .55201 .4674 L p F P
0 g
s
.096 .338 .661 r
.56648 .46522 m .55201 .4674 L .54733 .44035 L p F P
0 g
s
.53729 .46862 m
.55201 .4674 L
s
.55201 .4674 m
.55638 .4953 L
s
.483 .236 .52 r
.4101 .50157 m .42693 .50856 L .41604 .53612 L p F P
0 g
s
.483 .236 .52 r
.41604 .53612 m .3973 .52849 L .4101 .50157 L p F P
0 g
s
.53 .259 .461 r
.3973 .52849 m .41604 .53612 L .40622 .56413 L p F P
0 g
s
.41604 .53612 m
.43575 .54251 L
s
.354 .222 .621 r
.45164 .45556 m .46492 .46009 L .45441 .48687 L p F P
0 g
s
.354 .222 .621 r
.45441 .48687 m .43883 .48164 L .45164 .45556 L p F P
0 g
s
.45441 .48687 m
.47065 .49104 L
s
.44467 .51441 m
.45441 .48687 L
s
.554 .433 .256 r
.43604 .66256 m .40952 .65645 L .41455 .62814 L p F P
0 g
s
.572 .447 .181 r
.40952 .65645 m .43604 .66256 L .43301 .69049 L p F P
0 g
s
.522 .504 .181 r
.46117 .69508 m .43301 .69049 L .43604 .66256 L p F P
0 g
s
.43604 .66256 m
.46327 .66708 L
s
.43604 .66256 m
.43991 .6341 L
s
.57 .357 .328 r
.41455 .62814 m .3901 .62065 L .39755 .59237 L p F P
0 g
s
.596 .373 .256 r
.3901 .62065 m .41455 .62814 L .40952 .65645 L p F P
0 g
s
.41455 .62814 m
.43991 .6341 L
s
.41455 .62814 m
.42063 .59958 L
s
.476 .568 .104 r
.46117 .69508 m .48983 .69801 L .489 .72523 L p F P
0 g
s
.414 .614 .104 r
.51861 .72651 m .489 .72523 L .48983 .69801 L p F P
0 g
s
.48983 .69801 m
.49101 .66997 L
s
.48983 .69801 m
.51878 .69928 L
s
.252 .245 .661 r
.48743 .43729 m .49912 .43951 L .49307 .46639 L p F P
0 g
s
.252 .245 .661 r
.49307 .46639 m .47877 .46371 L .48743 .43729 L p F P
0 g
s
.49307 .46639 m
.50768 .46811 L
s
.48741 .49413 m
.49307 .46639 L
s
.53 .259 .461 r
.40622 .56413 m .38576 .55595 L .3973 .52849 L p F P
0 g
s
.57 .279 .397 r
.38576 .55595 m .40622 .56413 L .39755 .59237 L p F P
0 g
s
.40622 .56413 m
.41604 .53612 L
s
.40622 .56413 m
.42772 .57097 L
s
.432 .211 .574 r
.42406 .47539 m .43883 .48164 L .42693 .50856 L p F P
0 g
s
.432 .211 .574 r
.42693 .50856 m .4101 .50157 L .42406 .47539 L p F P
0 g
s
.42693 .50856 m
.44467 .51441 L
s
.41604 .53612 m
.42693 .50856 L
s
.204 .712 .104 r
.57663 .69681 m .60509 .69308 L .60689 .72028 L p F P
0 g
s
.204 .712 .104 r
.60689 .72028 m .57779 .72402 L .57663 .69681 L p F P
0 g
s
.57501 .66878 m
.57663 .69681 L
s
.54779 .69888 m
.57663 .69681 L
s
.096 .338 .661 r
.54733 .44035 m .55917 .43854 L .56648 .46522 L p F P
0 g
s
.06 .346 .661 r
.58059 .46208 m .56648 .46522 L .55917 .43854 L p F P
0 g
s
.55201 .4674 m
.56648 .46522 L
s
.56648 .46522 m
.57334 .49278 L
s
.028 .417 .621 r
.58059 .46208 m .59418 .45802 L .60581 .48448 L p F P
0 g
s
.015 .418 .621 r
.62102 .47876 m .60581 .48448 L .59418 .45802 L p F P
0 g
s
.017 .481 .574 r
.60581 .48448 m .62102 .47876 L .63392 .50534 L p F P
0 g
s
.60581 .48448 m
.6166 .51174 L
s
.58986 .48917 m
.60581 .48448 L
s
.276 .217 .661 r
.47612 .43428 m .48743 .43729 L .47877 .46371 L p F P
0 g
s
.276 .217 .661 r
.47877 .46371 m .46492 .46009 L .47612 .43428 L p F P
0 g
s
.47877 .46371 m
.49307 .46639 L
s
.47065 .49104 m
.47877 .46371 L
s
.05 .724 .181 r
.62945 .65982 m .65555 .65294 L .65991 .68072 L p F P
0 g
s
.05 .724 .181 r
.65991 .68072 m .63292 .68771 L .62945 .65982 L p F P
0 g
s
.62502 .63143 m
.62945 .65982 L
s
.60253 .66511 m
.62945 .65982 L
s
.57 .279 .397 r
.39755 .59237 m .37556 .58374 L .38576 .55595 L p F P
0 g
s
.604 .295 .328 r
.37556 .58374 m .39755 .59237 L .3901 .62065 L p F P
0 g
s
.39755 .59237 m
.40622 .56413 L
s
.39755 .59237 m
.42063 .59958 L
s
.533 .515 .104 r
.43301 .69049 m .46117 .69508 L .45967 .72229 L p F P
0 g
s
.476 .568 .104 r
.489 .72523 m .45967 .72229 L .46117 .69508 L p F P
0 g
s
.46117 .69508 m
.46327 .66708 L
s
.46117 .69508 m
.48983 .69801 L
s
.076 .533 .52 r
.66395 .52438 m .64574 .5326 L .63392 .50534 L p F P
0 g
s
.083 .584 .461 r
.64574 .5326 m .66395 .52438 L .67629 .55154 L p F P
0 g
s
.083 .584 .461 r
.67629 .55154 m .6564 .56036 L .64574 .5326 L p F P
0 g
s
.62647 .5396 m
.64574 .5326 L
s
.025 .703 .256 r
.64997 .62473 m .67389 .61652 L .68059 .64451 L p F P
0 g
s
.025 .703 .256 r
.68059 .64451 m .65555 .65294 L .64997 .62473 L p F P
0 g
s
.64322 .59629 m
.64997 .62473 L
s
.62502 .63143 m
.64997 .62473 L
s
.089 .628 .397 r
.6564 .56036 m .67629 .55154 L .6872 .5791 L p F P
0 g
s
.089 .628 .397 r
.6872 .5791 m .66581 .5884 L .6564 .56036 L p F P
0 g
s
.64574 .5326 m
.6564 .56036 L
s
.63537 .56785 m
.6564 .56036 L
s
.06 .346 .661 r
.55917 .43854 m .57069 .43594 L .58059 .46208 L p F P
0 g
s
.024 .35 .661 r
.59418 .45802 m .58059 .46208 L .57069 .43594 L p F P
0 g
s
.58059 .46208 m
.58986 .48917 L
s
.56648 .46522 m
.58059 .46208 L
s
.068 .476 .574 r
.65026 .49781 m .63392 .50534 L .62102 .47876 L p F P
0 g
s
.076 .533 .52 r
.63392 .50534 m .65026 .49781 L .66395 .52438 L p F P
0 g
s
.6166 .51174 m
.63392 .50534 L
s
.63392 .50534 m
.64574 .5326 L
s
.376 .184 .621 r
.43908 .45015 m .45164 .45556 L .43883 .48164 L p F P
0 g
s
.376 .184 .621 r
.43883 .48164 m .42406 .47539 L .43908 .45015 L p F P
0 g
s
.43883 .48164 m
.45441 .48687 L
s
.42693 .50856 m
.43883 .48164 L
s
.129 .73 .104 r
.60509 .69308 m .63292 .68771 L .63537 .71488 L p F P
0 g
s
.129 .73 .104 r
.63537 .71488 m .60689 .72028 L .60509 .69308 L p F P
0 g
s
.60253 .66511 m
.60509 .69308 L
s
.57663 .69681 m
.60509 .69308 L
s
.297 .187 .661 r
.4653 .43053 m .47612 .43428 L .46492 .46009 L p F P
0 g
s
.297 .187 .661 r
.46492 .46009 m .45164 .45556 L .4653 .43053 L p F P
0 g
s
.46492 .46009 m
.47877 .46371 L
s
.45441 .48687 m
.46492 .46009 L
s
.596 .373 .256 r
.40952 .65645 m .38394 .64875 L .3901 .62065 L p F P
0 g
s
.616 .385 .181 r
.38394 .64875 m .40952 .65645 L .40558 .68428 L p F P
0 g
s
.572 .447 .181 r
.43301 .69049 m .40558 .68428 L .40952 .65645 L p F P
0 g
s
.40952 .65645 m
.43604 .66256 L
s
.40952 .65645 m
.41455 .62814 L
s
.094 .666 .328 r
.66581 .5884 m .6872 .5791 L .69658 .60684 L p F P
0 g
s
.094 .666 .328 r
.69658 .60684 m .67389 .61652 L .66581 .5884 L p F P
0 g
s
.6564 .56036 m
.66581 .5884 L
s
.64322 .59629 m
.66581 .5884 L
s
.506 .185 .52 r
.39432 .49349 m .4101 .50157 L .3973 .52849 L p F P
0 g
s
.506 .185 .52 r
.3973 .52849 m .37972 .51965 L .39432 .49349 L p F P
0 g
s
.554 .202 .461 r
.37972 .51965 m .3973 .52849 L .38576 .55595 L p F P
0 g
s
.3973 .52849 m
.41604 .53612 L
s
.015 .418 .621 r
.59418 .45802 m .60713 .45306 L .62102 .47876 L p F P
0 g
s
.059 .414 .621 r
.63535 .47204 m .62102 .47876 L .60713 .45306 L p F P
0 g
s
.068 .476 .574 r
.62102 .47876 m .63535 .47204 L .65026 .49781 L p F P
0 g
s
.62102 .47876 m
.63392 .50534 L
s
.60581 .48448 m
.62102 .47876 L
s
.604 .295 .328 r
.3901 .62065 m .36679 .61168 L .37556 .58374 L p F P
0 g
s
.632 .308 .256 r
.36679 .61168 m .3901 .62065 L .38394 .64875 L p F P
0 g
s
.3901 .62065 m
.41455 .62814 L
s
.3901 .62065 m
.39755 .59237 L
s
.156 .233 .695 r
.51465 .41481 m .52391 .41529 L .52317 .44156 L p F P
0 g
s
.156 .233 .695 r
.52317 .44156 m .51107 .44094 L .51465 .41481 L p F P
0 g
s
.131 .248 .695 r
.53529 .44136 m .52317 .44156 L .52391 .41529 L p F P
0 g
s
.52247 .46885 m
.52317 .44156 L
s
.452 .165 .574 r
.41024 .46818 m .42406 .47539 L .4101 .50157 L p F P
0 g
s
.452 .165 .574 r
.4101 .50157 m .39432 .49349 L .41024 .46818 L p F P
0 g
s
.4101 .50157 m
.42693 .50856 L
s
.3973 .52849 m
.4101 .50157 L
s
.131 .248 .695 r
.52391 .41529 m .53319 .41514 L .53529 .44136 L p F P
0 g
s
.104 .26 .695 r
.54733 .44035 m .53529 .44136 L .53319 .41514 L p F P
0 g
s
.52317 .44156 m
.53529 .44136 L
s
.53529 .44136 m
.53729 .46862 L
s
.024 .35 .661 r
.57069 .43594 m .58178 .43257 L .59418 .45802 L p F P
0 g
s
.013 .351 .661 r
.60713 .45306 m .59418 .45802 L .58178 .43257 L p F P
0 g
s
.59418 .45802 m
.60581 .48448 L
s
.58059 .46208 m
.59418 .45802 L
s
.584 .456 .104 r
.40558 .68428 m .43301 .69049 L .43086 .71768 L p F P
0 g
s
.533 .515 .104 r
.45967 .72229 m .43086 .71768 L .43301 .69049 L p F P
0 g
s
.43301 .69049 m
.46117 .69508 L
s
.43301 .69049 m
.43604 .66256 L
s
.18 .215 .695 r
.50551 .41371 m .51465 .41481 L .51107 .44094 L p F P
0 g
s
.18 .215 .695 r
.51107 .44094 m .49912 .43951 L .50551 .41371 L p F P
0 g
s
.50768 .46811 m
.51107 .44094 L
s
.51107 .44094 m
.52317 .44156 L
s
.554 .202 .461 r
.38576 .55595 m .36653 .54647 L .37972 .51965 L p F P
0 g
s
.596 .217 .397 r
.36653 .54647 m .38576 .55595 L .37556 .58374 L p F P
0 g
s
.38576 .55595 m
.3973 .52849 L
s
.38576 .55595 m
.40622 .56413 L
s
.418 .62 .026 r
.489 .72523 m .51861 .72651 L .51851 .75269 L p F P
0 g
s
.351 .66 .026 r
.51861 .72651 m .54828 .7261 L .54856 .75229 L p F P
0 g
s
.351 .66 .026 r
.54856 .75229 m .51851 .75269 L .51861 .72651 L p F P
0 g
s
.51861 .72651 m
.51878 .69928 L
s
.104 .26 .695 r
.53319 .41514 m .5424 .41436 L .54733 .44035 L p F P
0 g
s
.076 .27 .695 r
.55917 .43854 m .54733 .44035 L .5424 .41436 L p F P
0 g
s
.53529 .44136 m
.54733 .44035 L
s
.54733 .44035 m
.55201 .4674 L
s
.28 .693 .026 r
.54828 .7261 m .57779 .72402 L .57845 .75022 L p F P
0 g
s
.28 .693 .026 r
.57845 .75022 m .54856 .75229 L .54828 .7261 L p F P
0 g
s
.54779 .69888 m
.54828 .7261 L
s
.51861 .72651 m
.54828 .7261 L
s
.201 .195 .695 r
.49658 .41198 m .50551 .41371 L .49912 .43951 L p F P
0 g
s
.201 .195 .695 r
.49912 .43951 m .48743 .43729 L .49658 .41198 L p F P
0 g
s
.49912 .43951 m
.51107 .44094 L
s
.49307 .46639 m
.49912 .43951 L
s
.026 .725 .181 r
.65555 .65294 m .68059 .64451 L .68583 .67215 L p F P
0 g
s
.026 .725 .181 r
.68583 .67215 m .65991 .68072 L .65555 .65294 L p F P
0 g
s
.64997 .62473 m
.65555 .65294 L
s
.62945 .65982 m
.65555 .65294 L
s
.481 .573 .026 r
.45967 .72229 m .489 .72523 L .48852 .75142 L p F P
0 g
s
.418 .62 .026 r
.51851 .75269 m .48852 .75142 L .489 .72523 L p F P
0 g
s
.489 .72523 m
.48983 .69801 L
s
.489 .72523 m
.51861 .72651 L
s
.315 .155 .661 r
.45507 .42605 m .4653 .43053 L .45164 .45556 L p F P
0 g
s
.315 .155 .661 r
.45164 .45556 m .43908 .45015 L .45507 .42605 L p F P
0 g
s
.45164 .45556 m
.46492 .46009 L
s
.43883 .48164 m
.45164 .45556 L
s
.076 .27 .695 r
.5424 .41436 m .55145 .41295 L .55917 .43854 L p F P
0 g
s
.048 .276 .695 r
.57069 .43594 m .55917 .43854 L .55145 .41295 L p F P
0 g
s
.54733 .44035 m
.55917 .43854 L
s
.55917 .43854 m
.56648 .46522 L
s
.393 .144 .621 r
.42736 .44391 m .43908 .45015 L .42406 .47539 L p F P
0 g
s
.393 .144 .621 r
.42406 .47539 m .41024 .46818 L .42736 .44391 L p F P
0 g
s
.42406 .47539 m
.43883 .48164 L
s
.4101 .50157 m
.42406 .47539 L
s
.052 .739 .104 r
.63292 .68771 m .65991 .68072 L .663 .70786 L p F P
0 g
s
.052 .739 .104 r
.663 .70786 m .63537 .71488 L .63292 .68771 L p F P
0 g
s
.62945 .65982 m
.63292 .68771 L
s
.60509 .69308 m
.63292 .68771 L
s
.131 .522 .52 r
.68091 .51499 m .66395 .52438 L .65026 .49781 L p F P
0 g
s
.143 .572 .461 r
.66395 .52438 m .68091 .51499 L .69485 .54146 L p F P
0 g
s
.143 .572 .461 r
.69485 .54146 m .67629 .55154 L .66395 .52438 L p F P
0 g
s
.64574 .5326 m
.66395 .52438 L
s
.206 .719 .026 r
.57779 .72402 m .60689 .72028 L .60793 .74648 L p F P
0 g
s
.206 .719 .026 r
.60793 .74648 m .57845 .75022 L .57779 .72402 L p F P
0 g
s
.57663 .69681 m
.57779 .72402 L
s
.54828 .7261 m
.57779 .72402 L
s
.117 .466 .574 r
.66546 .48923 m .65026 .49781 L .63535 .47204 L p F P
0 g
s
.131 .522 .52 r
.65026 .49781 m .66546 .48923 L .68091 .51499 L p F P
0 g
s
.63392 .50534 m
.65026 .49781 L
s
.65026 .49781 m
.66395 .52438 L
s
.596 .217 .397 r
.37556 .58374 m .35487 .57374 L .36653 .54647 L p F P
0 g
s
.632 .23 .328 r
.35487 .57374 m .37556 .58374 L .36679 .61168 L p F P
0 g
s
.37556 .58374 m
.38576 .55595 L
s
.37556 .58374 m
.39755 .59237 L
s
.22 .173 .695 r
.48794 .40965 m .49658 .41198 L .48743 .43729 L p F P
0 g
s
.22 .173 .695 r
.48743 .43729 m .47612 .43428 L .48794 .40965 L p F P
0 g
s
.48743 .43729 m
.49912 .43951 L
s
.47877 .46371 m
.48743 .43729 L
s
.098 .696 .256 r
.67389 .61652 m .69658 .60684 L .70436 .63456 L p F P
0 g
s
.098 .696 .256 r
.70436 .63456 m .68059 .64451 L .67389 .61652 L p F P
0 g
s
.66581 .5884 m
.67389 .61652 L
s
.64997 .62473 m
.67389 .61652 L
s
.013 .351 .661 r
.58178 .43257 m .59233 .42846 L .60713 .45306 L p F P
0 g
s
.05 .348 .661 r
.6193 .44725 m .60713 .45306 L .59233 .42846 L p F P
0 g
s
.059 .414 .621 r
.60713 .45306 m .6193 .44725 L .63535 .47204 L p F P
0 g
s
.60713 .45306 m
.62102 .47876 L
s
.59418 .45802 m
.60713 .45306 L
s
.154 .616 .397 r
.67629 .55154 m .69485 .54146 L .70719 .56846 L p F P
0 g
s
.154 .616 .397 r
.70719 .56846 m .6872 .5791 L .67629 .55154 L p F P
0 g
s
.66395 .52438 m
.67629 .55154 L
s
.6564 .56036 m
.67629 .55154 L
s
.048 .276 .695 r
.55145 .41295 m .56025 .41094 L .57069 .43594 L p F P
0 g
s
.019 .28 .695 r
.58178 .43257 m .57069 .43594 L .56025 .41094 L p F P
0 g
s
.55917 .43854 m
.57069 .43594 L
s
.57069 .43594 m
.58059 .46208 L
s
.538 .519 .026 r
.43086 .71768 m .45967 .72229 L .45882 .74849 L p F P
0 g
s
.481 .573 .026 r
.48852 .75142 m .45882 .74849 L .45967 .72229 L p F P
0 g
s
.45967 .72229 m
.46117 .69508 L
s
.45967 .72229 m
.489 .72523 L
s
.102 .406 .621 r
.64865 .46438 m .63535 .47204 L .6193 .44725 L p F P
0 g
s
.117 .466 .574 r
.63535 .47204 m .64865 .46438 L .66546 .48923 L p F P
0 g
s
.63535 .47204 m
.65026 .49781 L
s
.62102 .47876 m
.63535 .47204 L
s
.632 .308 .256 r
.38394 .64875 m .35953 .63953 L .36679 .61168 L p F P
0 g
s
.652 .318 .181 r
.35953 .63953 m .38394 .64875 L .37912 .67647 L p F P
0 g
s
.616 .385 .181 r
.40558 .68428 m .37912 .67647 L .38394 .64875 L p F P
0 g
s
.38394 .64875 m
.40952 .65645 L
s
.38394 .64875 m
.3901 .62065 L
s
.237 .149 .695 r
.47969 .40674 m .48794 .40965 L .47612 .43428 L p F P
0 g
s
.237 .149 .695 r
.47612 .43428 m .4653 .43053 L .47969 .40674 L p F P
0 g
s
.47612 .43428 m
.48743 .43729 L
s
.46492 .46009 m
.47612 .43428 L
s
.628 .393 .104 r
.37912 .67647 m .40558 .68428 L .4028 .71143 L p F P
0 g
s
.584 .456 .104 r
.43086 .71768 m .4028 .71143 L .40558 .68428 L p F P
0 g
s
.40558 .68428 m
.43301 .69049 L
s
.40558 .68428 m
.40952 .65645 L
s
.33 .121 .661 r
.44555 .42089 m .45507 .42605 L .43908 .45015 L p F P
0 g
s
.33 .121 .661 r
.43908 .45015 m .42736 .44391 L .44555 .42089 L p F P
0 g
s
.43908 .45015 m
.45164 .45556 L
s
.42406 .47539 m
.43908 .45015 L
s
.13 .736 .026 r
.60689 .72028 m .63537 .71488 L .63678 .74111 L p F P
0 g
s
.13 .736 .026 r
.63678 .74111 m .60793 .74648 L .60689 .72028 L p F P
0 g
s
.60509 .69308 m
.60689 .72028 L
s
.57779 .72402 m
.60689 .72028 L
s
.466 .117 .574 r
.39754 .46005 m .41024 .46818 L .39432 .49349 L p F P
0 g
s
.466 .117 .574 r
.39432 .49349 m .37978 .48437 L .39754 .46005 L p F P
0 g
s
.522 .131 .52 r
.37978 .48437 m .39432 .49349 L .37972 .51965 L p F P
0 g
s
.39432 .49349 m
.4101 .50157 L
s
.522 .131 .52 r
.37972 .51965 m .36347 .50967 L .37978 .48437 L p F P
0 g
s
.572 .143 .461 r
.36347 .50967 m .37972 .51965 L .36653 .54647 L p F P
0 g
s
.37972 .51965 m
.39432 .49349 L
s
.37972 .51965 m
.3973 .52849 L
s
.019 .28 .695 r
.56025 .41094 m .56871 .40832 L .58178 .43257 L p F P
0 g
s
.011 .28 .695 r
.59233 .42846 m .58178 .43257 L .56871 .40832 L p F P
0 g
s
.57069 .43594 m
.58178 .43257 L
s
.58178 .43257 m
.59418 .45802 L
s
.163 .652 .328 r
.6872 .5791 m .70719 .56846 L .71782 .59576 L p F P
0 g
s
.163 .652 .328 r
.71782 .59576 m .69658 .60684 L .6872 .5791 L p F P
0 g
s
.67629 .55154 m
.6872 .5791 L
s
.66581 .5884 m
.6872 .5791 L
s
.632 .23 .328 r
.36679 .61168 m .34483 .60126 L .35487 .57374 L p F P
0 g
s
.661 .241 .256 r
.34483 .60126 m .36679 .61168 L .35953 .63953 L p F P
0 g
s
.36679 .61168 m
.3901 .62065 L
s
.36679 .61168 m
.37556 .58374 L
s
.406 .102 .621 r
.4166 .4369 m .42736 .44391 L .41024 .46818 L p F P
0 g
s
.406 .102 .621 r
.41024 .46818 m .39754 .46005 L .4166 .4369 L p F P
0 g
s
.41024 .46818 m
.42406 .47539 L
s
.39432 .49349 m
.41024 .46818 L
s
.572 .143 .461 r
.36653 .54647 m .34873 .53575 L .36347 .50967 L p F P
0 g
s
.616 .154 .397 r
.34873 .53575 m .36653 .54647 L .35487 .57374 L p F P
0 g
s
.36653 .54647 m
.37972 .51965 L
s
.36653 .54647 m
.38576 .55595 L
s
.252 .124 .695 r
.47191 .40328 m .47969 .40674 L .4653 .43053 L p F P
0 g
s
.252 .124 .695 r
.4653 .43053 m .45507 .42605 L .47191 .40328 L p F P
0 g
s
.4653 .43053 m
.47612 .43428 L
s
.45164 .45556 m
.4653 .43053 L
s
.05 .348 .661 r
.59233 .42846 m .60223 .42365 L .6193 .44725 L p F P
0 g
s
.086 .341 .661 r
.63057 .44063 m .6193 .44725 L .60223 .42365 L p F P
0 g
s
.102 .406 .621 r
.6193 .44725 m .63057 .44063 L .64865 .46438 L p F P
0 g
s
.6193 .44725 m
.63535 .47204 L
s
.60713 .45306 m
.6193 .44725 L
s
.589 .46 .026 r
.4028 .71143 m .43086 .71768 L .42963 .7439 L p F P
0 g
s
.538 .519 .026 r
.45882 .74849 m .42963 .7439 L .43086 .71768 L p F P
0 g
s
.43086 .71768 m
.45967 .72229 L
s
.43086 .71768 m
.43301 .69049 L
s
.026 .74 .104 r
.65991 .68072 m .68583 .67215 L .68954 .69924 L p F P
0 g
s
.026 .74 .104 r
.68954 .69924 m .663 .70786 L .65991 .68072 L p F P
0 g
s
.65555 .65294 m
.65991 .68072 L
s
.63292 .68771 m
.65991 .68072 L
s
.101 .719 .181 r
.68059 .64451 m .70436 .63456 L .71044 .66205 L p F P
0 g
s
.101 .719 .181 r
.71044 .66205 m .68583 .67215 L .68059 .64451 L p F P
0 g
s
.67389 .61652 m
.68059 .64451 L
s
.65555 .65294 m
.68059 .64451 L
s
.115 .171 .72 r
.5184 .38996 m .52468 .39029 L .52391 .41529 L p F P
0 g
s
.115 .171 .72 r
.52391 .41529 m .51465 .41481 L .5184 .38996 L p F P
0 g
s
.096 .182 .72 r
.53319 .41514 m .52391 .41529 L .52468 .39029 L p F P
0 g
s
.52317 .44156 m
.52391 .41529 L
s
.165 .452 .574 r
.67936 .47964 m .66546 .48923 L .64865 .46438 L p F P
0 g
s
.185 .506 .52 r
.66546 .48923 m .67936 .47964 L .69645 .50449 L p F P
0 g
s
.185 .506 .52 r
.69645 .50449 m .68091 .51499 L .66546 .48923 L p F P
0 g
s
.65026 .49781 m
.66546 .48923 L
s
.096 .182 .72 r
.52468 .39029 m .53098 .39018 L .53319 .41514 L p F P
0 g
s
.076 .192 .72 r
.5424 .41436 m .53319 .41514 L .53098 .39018 L p F P
0 g
s
.52391 .41529 m
.53319 .41514 L
s
.53319 .41514 m
.53529 .44136 L
s
.011 .28 .695 r
.56871 .40832 m .57675 .40515 L .59233 .42846 L p F P
0 g
s
.04 .277 .695 r
.60223 .42365 m .59233 .42846 L .57675 .40515 L p F P
0 g
s
.58178 .43257 m
.59233 .42846 L
s
.59233 .42846 m
.60713 .45306 L
s
.132 .159 .72 r
.51221 .38919 m .5184 .38996 L .51465 .41481 L p F P
0 g
s
.132 .159 .72 r
.51465 .41481 m .50551 .41371 L .51221 .38919 L p F P
0 g
s
.51107 .44094 m
.51465 .41481 L
s
.51465 .41481 m
.52391 .41529 L
s
.202 .554 .461 r
.68091 .51499 m .69645 .50449 L .7119 .53018 L p F P
0 g
s
.202 .554 .461 r
.7119 .53018 m .69485 .54146 L .68091 .51499 L p F P
0 g
s
.66546 .48923 m
.68091 .51499 L
s
.66395 .52438 m
.68091 .51499 L
s
.076 .192 .72 r
.53098 .39018 m .53722 .38964 L .5424 .41436 L p F P
0 g
s
.056 .198 .72 r
.55145 .41295 m .5424 .41436 L .53722 .38964 L p F P
0 g
s
.53319 .41514 m
.5424 .41436 L
s
.5424 .41436 m
.54733 .44035 L
s
.417 .619 .052 r
.48852 .75142 m .51851 .75269 L .51849 .7776 L p F P
0 g
s
.35 .659 .052 r
.51851 .75269 m .54856 .75229 L .54863 .7772 L p F P
0 g
s
.35 .659 .052 r
.54863 .7772 m .51849 .7776 L .51851 .75269 L p F P
0 g
s
.51851 .75269 m
.51861 .72651 L
s
.144 .393 .621 r
.66078 .45584 m .64865 .46438 L .63057 .44063 L p F P
0 g
s
.165 .452 .574 r
.64865 .46438 m .66078 .45584 L .67936 .47964 L p F P
0 g
s
.63535 .47204 m
.64865 .46438 L
s
.64865 .46438 m
.66546 .48923 L
s
.148 .144 .72 r
.50615 .38801 m .51221 .38919 L .50551 .41371 L p F P
0 g
s
.148 .144 .72 r
.50551 .41371 m .49658 .41198 L .50615 .38801 L p F P
0 g
s
.50551 .41371 m
.51465 .41481 L
s
.49912 .43951 m
.50551 .41371 L
s
.28 .692 .052 r
.54856 .75229 m .57845 .75022 L .5786 .77516 L p F P
0 g
s
.28 .692 .052 r
.5786 .77516 m .54863 .7772 L .54856 .75229 L p F P
0 g
s
.54828 .7261 m
.54856 .75229 L
s
.51851 .75269 m
.54856 .75229 L
s
.341 .086 .661 r
.43683 .41509 m .44555 .42089 L .42736 .44391 L p F P
0 g
s
.341 .086 .661 r
.42736 .44391 m .4166 .4369 L .43683 .41509 L p F P
0 g
s
.42736 .44391 m
.43908 .45015 L
s
.41024 .46818 m
.42736 .44391 L
s
.052 .746 .026 r
.63537 .71488 m .663 .70786 L .66477 .73412 L p F P
0 g
s
.052 .746 .026 r
.66477 .73412 m .63678 .74111 L .63537 .71488 L p F P
0 g
s
.63292 .68771 m
.63537 .71488 L
s
.60689 .72028 m
.63537 .71488 L
s
.616 .154 .397 r
.35487 .57374 m .33568 .56242 L .34873 .53575 L p F P
0 g
s
.652 .163 .328 r
.33568 .56242 m .35487 .57374 L .34483 .60126 L p F P
0 g
s
.35487 .57374 m
.36653 .54647 L
s
.35487 .57374 m
.37556 .58374 L
s
.17 .682 .256 r
.69658 .60684 m .71782 .59576 L .72662 .62317 L p F P
0 g
s
.17 .682 .256 r
.72662 .62317 m .70436 .63456 L .69658 .60684 L p F P
0 g
s
.6872 .5791 m
.69658 .60684 L
s
.67389 .61652 m
.69658 .60684 L
s
.056 .198 .72 r
.53722 .38964 m .54336 .38868 L .55145 .41295 L p F P
0 g
s
.035 .203 .72 r
.56025 .41094 m .55145 .41295 L .54336 .38868 L p F P
0 g
s
.5424 .41436 m
.55145 .41295 L
s
.55145 .41295 m
.55917 .43854 L
s
.263 .097 .695 r
.46468 .39929 m .47191 .40328 L .45507 .42605 L p F P
0 g
s
.263 .097 .695 r
.45507 .42605 m .44555 .42089 L .46468 .39929 L p F P
0 g
s
.45507 .42605 m
.4653 .43053 L
s
.43908 .45015 m
.45507 .42605 L
s
.48 .572 .052 r
.45882 .74849 m .48852 .75142 L .48841 .77635 L p F P
0 g
s
.417 .619 .052 r
.51849 .7776 m .48841 .77635 L .48852 .75142 L p F P
0 g
s
.48852 .75142 m
.489 .72523 L
s
.48852 .75142 m
.51851 .75269 L
s
.217 .596 .397 r
.69485 .54146 m .7119 .53018 L .72558 .55654 L p F P
0 g
s
.217 .596 .397 r
.72558 .55654 m .70719 .56846 L .69485 .54146 L p F P
0 g
s
.68091 .51499 m
.69485 .54146 L
s
.67629 .55154 m
.69485 .54146 L
s
.162 .128 .72 r
.50031 .38641 m .50615 .38801 L .49658 .41198 L p F P
0 g
s
.162 .128 .72 r
.49658 .41198 m .48794 .40965 L .50031 .38641 L p F P
0 g
s
.49658 .41198 m
.50551 .41371 L
s
.48743 .43729 m
.49658 .41198 L
s
.652 .318 .181 r
.37912 .67647 m .35385 .6671 L .35953 .63953 L p F P
0 g
s
.666 .325 .104 r
.35385 .6671 m .37912 .67647 L .37571 .70358 L p F P
0 g
s
.628 .393 .104 r
.4028 .71143 m .37571 .70358 L .37912 .67647 L p F P
0 g
s
.37912 .67647 m
.40558 .68428 L
s
.37912 .67647 m
.38394 .64875 L
s
.206 .717 .052 r
.57845 .75022 m .60793 .74648 L .60817 .77148 L p F P
0 g
s
.206 .717 .052 r
.60817 .77148 m .5786 .77516 L .57845 .75022 L p F P
0 g
s
.57779 .72402 m
.57845 .75022 L
s
.54856 .75229 m
.57845 .75022 L
s
.035 .203 .72 r
.54336 .38868 m .54932 .38729 L .56025 .41094 L p F P
0 g
s
.014 .206 .72 r
.56871 .40832 m .56025 .41094 L .54932 .38729 L p F P
0 g
s
.55145 .41295 m
.56025 .41094 L
s
.56025 .41094 m
.57069 .43594 L
s
.661 .241 .256 r
.35953 .63953 m .33652 .62883 L .34483 .60126 L p F P
0 g
s
.682 .249 .181 r
.33652 .62883 m .35953 .63953 L .35385 .6671 L p F P
0 g
s
.35953 .63953 m
.38394 .64875 L
s
.35953 .63953 m
.36679 .61168 L
s
.086 .341 .661 r
.60223 .42365 m .61138 .41818 L .63057 .44063 L p F P
0 g
s
.121 .33 .661 r
.64083 .43326 m .63057 .44063 L .61138 .41818 L p F P
0 g
s
.144 .393 .621 r
.63057 .44063 m .64083 .43326 L .66078 .45584 L p F P
0 g
s
.63057 .44063 m
.64865 .46438 L
s
.6193 .44725 m
.63057 .44063 L
s
.04 .277 .695 r
.57675 .40515 m .58427 .40143 L .60223 .42365 L p F P
0 g
s
.069 .272 .695 r
.61138 .41818 m .60223 .42365 L .58427 .40143 L p F P
0 g
s
.59233 .42846 m
.60223 .42365 L
s
.60223 .42365 m
.6193 .44725 L
s
.476 .068 .574 r
.38607 .45108 m .39754 .46005 L .37978 .48437 L p F P
0 g
s
.476 .068 .574 r
.37978 .48437 m .36662 .4743 L .38607 .45108 L p F P
0 g
s
.533 .076 .52 r
.36662 .4743 m .37978 .48437 L .36347 .50967 L p F P
0 g
s
.37978 .48437 m
.39432 .49349 L
s
.174 .11 .72 r
.49473 .38442 m .50031 .38641 L .48794 .40965 L p F P
0 g
s
.174 .11 .72 r
.48794 .40965 m .47969 .40674 L .49473 .38442 L p F P
0 g
s
.48794 .40965 m
.49658 .41198 L
s
.47612 .43428 m
.48794 .40965 L
s
.414 .059 .621 r
.40692 .42916 m .4166 .4369 L .39754 .46005 L p F P
0 g
s
.414 .059 .621 r
.39754 .46005 m .38607 .45108 L .40692 .42916 L p F P
0 g
s
.39754 .46005 m
.41024 .46818 L
s
.37978 .48437 m
.39754 .46005 L
s
.634 .396 .026 r
.37571 .70358 m .4028 .71143 L .4012 .73768 L p F P
0 g
s
.589 .46 .026 r
.42963 .7439 m .4012 .73768 L .4028 .71143 L p F P
0 g
s
.4028 .71143 m
.43086 .71768 L
s
.4028 .71143 m
.40558 .68428 L
s
.533 .076 .52 r
.36347 .50967 m .34873 .49863 L .36662 .4743 L p F P
0 g
s
.584 .083 .461 r
.34873 .49863 m .36347 .50967 L .34873 .53575 L p F P
0 g
s
.36347 .50967 m
.37978 .48437 L
s
.36347 .50967 m
.37972 .51965 L
s
.537 .518 .052 r
.42963 .7439 m .45882 .74849 L .45862 .77345 L p F P
0 g
s
.48 .572 .052 r
.48841 .77635 m .45862 .77345 L .45882 .74849 L p F P
0 g
s
.45882 .74849 m
.45967 .72229 L
s
.45882 .74849 m
.48852 .75142 L
s
.014 .206 .72 r
.54932 .38729 m .55504 .3855 L .56871 .40832 L p F P
0 g
s
.008 .206 .72 r
.57675 .40515 m .56871 .40832 L .55504 .3855 L p F P
0 g
s
.56025 .41094 m
.56871 .40832 L
s
.56871 .40832 m
.58178 .43257 L
s
.272 .069 .695 r
.45808 .39482 m .46468 .39929 L .44555 .42089 L p F P
0 g
s
.272 .069 .695 r
.44555 .42089 m .43683 .41509 L .45808 .39482 L p F P
0 g
s
.44555 .42089 m
.45507 .42605 L
s
.42736 .44391 m
.44555 .42089 L
s
.23 .632 .328 r
.70719 .56846 m .72558 .55654 L .73738 .58334 L p F P
0 g
s
.23 .632 .328 r
.73738 .58334 m .71782 .59576 L .70719 .56846 L p F P
0 g
s
.69485 .54146 m
.70719 .56846 L
s
.6872 .5791 m
.70719 .56846 L
s
.185 .091 .72 r
.48948 .38204 m .49473 .38442 L .47969 .40674 L p F P
0 g
s
.185 .091 .72 r
.47969 .40674 m .47191 .40328 L .48948 .38204 L p F P
0 g
s
.47969 .40674 m
.48794 .40965 L
s
.4653 .43053 m
.47969 .40674 L
s
.652 .163 .328 r
.34483 .60126 m .32444 .58948 L .33568 .56242 L p F P
0 g
s
.682 .17 .256 r
.32444 .58948 m .34483 .60126 L .33652 .62883 L p F P
0 g
s
.34483 .60126 m
.36679 .61168 L
s
.34483 .60126 m
.35487 .57374 L
s
.13 .735 .052 r
.60793 .74648 m .63678 .74111 L .63711 .76618 L p F P
0 g
s
.13 .735 .052 r
.63711 .76618 m .60817 .77148 L .60793 .74648 L p F P
0 g
s
.60689 .72028 m
.60793 .74648 L
s
.57845 .75022 m
.60793 .74648 L
s
.103 .734 .104 r
.68583 .67215 m .71044 .66205 L .71475 .68908 L p F P
0 g
s
.103 .734 .104 r
.71475 .68908 m .68954 .69924 L .68583 .67215 L p F P
0 g
s
.68059 .64451 m
.68583 .67215 L
s
.65991 .68072 m
.68583 .67215 L
s
.348 .05 .661 r
.42901 .40871 m .43683 .41509 L .4166 .4369 L p F P
0 g
s
.348 .05 .661 r
.4166 .4369 m .40692 .42916 L .42901 .40871 L p F P
0 g
s
.4166 .4369 m
.42736 .44391 L
s
.39754 .46005 m
.4166 .4369 L
s
.584 .083 .461 r
.34873 .53575 m .33254 .52388 L .34873 .49863 L p F P
0 g
s
.628 .089 .397 r
.33254 .52388 m .34873 .53575 L .33568 .56242 L p F P
0 g
s
.34873 .53575 m
.36347 .50967 L
s
.34873 .53575 m
.36653 .54647 L
s
.211 .432 .574 r
.6918 .46913 m .67936 .47964 L .66078 .45584 L p F P
0 g
s
.236 .483 .52 r
.67936 .47964 m .6918 .46913 L .7104 .49296 L p F P
0 g
s
.236 .483 .52 r
.7104 .49296 m .69645 .50449 L .67936 .47964 L p F P
0 g
s
.66546 .48923 m
.67936 .47964 L
s
.008 .206 .72 r
.55504 .3855 m .56047 .38332 L .57675 .40515 L p F P
0 g
s
.03 .204 .72 r
.58427 .40143 m .57675 .40515 L .56047 .38332 L p F P
0 g
s
.56871 .40832 m
.57675 .40515 L
s
.57675 .40515 m
.59233 .42846 L
s
.184 .376 .621 r
.6716 .44649 m .66078 .45584 L .64083 .43326 L p F P
0 g
s
.211 .432 .574 r
.66078 .45584 m .6716 .44649 L .6918 .46913 L p F P
0 g
s
.64865 .46438 m
.66078 .45584 L
s
.66078 .45584 m
.67936 .47964 L
s
.026 .747 .026 r
.663 .70786 m .68954 .69924 L .69166 .72554 L p F P
0 g
s
.026 .747 .026 r
.69166 .72554 m .66477 .73412 L .663 .70786 L p F P
0 g
s
.65991 .68072 m
.663 .70786 L
s
.63537 .71488 m
.663 .70786 L
s
.176 .704 .181 r
.70436 .63456 m .72662 .62317 L .73351 .65046 L p F P
0 g
s
.176 .704 .181 r
.73351 .65046 m .71044 .66205 L .70436 .63456 L p F P
0 g
s
.69658 .60684 m
.70436 .63456 L
s
.68059 .64451 m
.70436 .63456 L
s
.069 .272 .695 r
.58427 .40143 m .59121 .3972 L .61138 .41818 L p F P
0 g
s
.097 .263 .695 r
.61968 .41209 m .61138 .41818 L .59121 .3972 L p F P
0 g
s
.121 .33 .661 r
.61138 .41818 m .61968 .41209 L .64083 .43326 L p F P
0 g
s
.61138 .41818 m
.63057 .44063 L
s
.60223 .42365 m
.61138 .41818 L
s
.259 .53 .461 r
.69645 .50449 m .7104 .49296 L .72724 .51779 L p F P
0 g
s
.259 .53 .461 r
.72724 .51779 m .7119 .53018 L .69645 .50449 L p F P
0 g
s
.67936 .47964 m
.69645 .50449 L
s
.68091 .51499 m
.69645 .50449 L
s
.588 .459 .052 r
.4012 .73768 m .42963 .7439 L .42935 .76893 L p F P
0 g
s
.537 .518 .052 r
.45862 .77345 m .42935 .76893 L .42963 .7439 L p F P
0 g
s
.42963 .7439 m
.43086 .71768 L
s
.42963 .7439 m
.45882 .74849 L
s
.193 .071 .72 r
.48462 .37931 m .48948 .38204 L .47191 .40328 L p F P
0 g
s
.193 .071 .72 r
.47191 .40328 m .46468 .39929 L .48462 .37931 L p F P
0 g
s
.47191 .40328 m
.47969 .40674 L
s
.45507 .42605 m
.47191 .40328 L
s
.155 .315 .661 r
.64995 .4252 m .64083 .43326 L .61968 .41209 L p F P
0 g
s
.184 .376 .621 r
.64083 .43326 m .64995 .4252 L .6716 .44649 L p F P
0 g
s
.64083 .43326 m
.66078 .45584 L
s
.63057 .44063 m
.64083 .43326 L
s
.277 .04 .695 r
.45217 .38991 m .45808 .39482 L .43683 .41509 L p F P
0 g
s
.277 .04 .695 r
.43683 .41509 m .42901 .40871 L .45217 .38991 L p F P
0 g
s
.43683 .41509 m
.44555 .42089 L
s
.4166 .4369 m
.43683 .41509 L
s
.03 .204 .72 r
.56047 .38332 m .56554 .38077 L .58427 .40143 L p F P
0 g
s
.051 .2 .72 r
.59121 .3972 m .58427 .40143 L .56554 .38077 L p F P
0 g
s
.57675 .40515 m
.58427 .40143 L
s
.58427 .40143 m
.60223 .42365 L
s
.628 .089 .397 r
.33568 .56242 m .3182 .54988 L .33254 .52388 L p F P
0 g
s
.666 .094 .328 r
.3182 .54988 m .33568 .56242 L .32444 .58948 L p F P
0 g
s
.33568 .56242 m
.34873 .53575 L
s
.33568 .56242 m
.35487 .57374 L
s
.682 .249 .181 r
.35385 .6671 m .33001 .65622 L .33652 .62883 L p F P
0 g
s
.696 .254 .104 r
.33001 .65622 m .35385 .6671 L .34983 .69416 L p F P
0 g
s
.666 .325 .104 r
.37571 .70358 m .34983 .69416 L .35385 .6671 L p F P
0 g
s
.35385 .6671 m
.37912 .67647 L
s
.35385 .6671 m
.35953 .63953 L
s
.241 .661 .256 r
.71782 .59576 m .73738 .58334 L .74716 .61039 L p F P
0 g
s
.241 .661 .256 r
.74716 .61039 m .72662 .62317 L .71782 .59576 L p F P
0 g
s
.70719 .56846 m
.71782 .59576 L
s
.69658 .60684 m
.71782 .59576 L
s
.418 .015 .621 r
.39842 .42077 m .40692 .42916 L .38607 .45108 L p F P
0 g
s
.418 .015 .621 r
.38607 .45108 m .37597 .44134 L .39842 .42077 L p F P
0 g
s
.481 .017 .574 r
.37597 .44134 m .38607 .45108 L .36662 .4743 L p F P
0 g
s
.38607 .45108 m
.39754 .46005 L
s
.072 .108 .738 r
.5223 .36659 m .52549 .36676 L .52468 .39029 L p F P
0 g
s
.072 .108 .738 r
.52468 .39029 m .5184 .38996 L .5223 .36659 L p F P
0 g
s
.06 .115 .738 r
.53098 .39018 m .52468 .39029 L .52549 .36676 L p F P
0 g
s
.52391 .41529 m
.52468 .39029 L
s
.052 .745 .052 r
.63678 .74111 m .66477 .73412 L .66518 .75928 L p F P
0 g
s
.052 .745 .052 r
.66518 .75928 m .63711 .76618 L .63678 .74111 L p F P
0 g
s
.63537 .71488 m
.63678 .74111 L
s
.60793 .74648 m
.63678 .74111 L
s
.672 .328 .026 r
.34983 .69416 m .37571 .70358 L .37375 .72986 L p F P
0 g
s
.634 .396 .026 r
.4012 .73768 m .37375 .72986 L .37571 .70358 L p F P
0 g
s
.37571 .70358 m
.4028 .71143 L
s
.37571 .70358 m
.37912 .67647 L
s
.06 .115 .738 r
.52549 .36676 m .52868 .36671 L .53098 .39018 L p F P
0 g
s
.048 .121 .738 r
.53722 .38964 m .53098 .39018 L .52868 .36671 L p F P
0 g
s
.52468 .39029 m
.53098 .39018 L
s
.53098 .39018 m
.53319 .41514 L
s
.279 .57 .397 r
.7119 .53018 m .72724 .51779 L .74217 .54343 L p F P
0 g
s
.279 .57 .397 r
.74217 .54343 m .72558 .55654 L .7119 .53018 L p F P
0 g
s
.69645 .50449 m
.7119 .53018 L
s
.69485 .54146 m
.7119 .53018 L
s
.481 .017 .574 r
.36662 .4743 m .355 .46334 L .37597 .44134 L p F P
0 g
s
.538 .019 .52 r
.355 .46334 m .36662 .4743 L .34873 .49863 L p F P
0 g
s
.36662 .4743 m
.38607 .45108 L
s
.36662 .4743 m
.37978 .48437 L
s
.083 .1 .738 r
.51916 .3662 m .5223 .36659 L .5184 .38996 L p F P
0 g
s
.083 .1 .738 r
.5184 .38996 m .51221 .38919 L .51916 .3662 L p F P
0 g
s
.51465 .41481 m
.5184 .38996 L
s
.5184 .38996 m
.52468 .39029 L
s
.048 .121 .738 r
.52868 .36671 m .53185 .36643 L .53722 .38964 L p F P
0 g
s
.035 .125 .738 r
.54336 .38868 m .53722 .38964 L .53185 .36643 L p F P
0 g
s
.53098 .39018 m
.53722 .38964 L
s
.53722 .38964 m
.5424 .41436 L
s
.2 .051 .72 r
.48019 .37626 m .48462 .37931 L .46468 .39929 L p F P
0 g
s
.2 .051 .72 r
.46468 .39929 m .45808 .39482 L .48019 .37626 L p F P
0 g
s
.46468 .39929 m
.47191 .40328 L
s
.44555 .42089 m
.46468 .39929 L
s
.093 .091 .738 r
.51609 .36559 m .51916 .3662 L .51221 .38919 L p F P
0 g
s
.093 .091 .738 r
.51221 .38919 m .50615 .38801 L .51609 .36559 L p F P
0 g
s
.51221 .38919 m
.5184 .38996 L
s
.50551 .41371 m
.51221 .38919 L
s
.412 .611 .13 r
.48841 .77635 m .51849 .7776 L .51855 .80101 L p F P
0 g
s
.346 .65 .13 r
.51849 .7776 m .54863 .7772 L .54847 .80062 L p F P
0 g
s
.346 .65 .13 r
.54847 .80062 m .51855 .80101 L .51849 .7776 L p F P
0 g
s
.51849 .7776 m
.51851 .75269 L
s
.351 .013 .661 r
.42218 .40181 m .42901 .40871 L .40692 .42916 L p F P
0 g
s
.351 .013 .661 r
.40692 .42916 m .39842 .42077 L .42218 .40181 L p F P
0 g
s
.40692 .42916 m
.4166 .4369 L
s
.38607 .45108 m
.40692 .42916 L
s
.097 .263 .695 r
.59121 .3972 m .59749 .39251 L .61968 .41209 L p F P
0 g
s
.124 .252 .695 r
.62704 .40545 m .61968 .41209 L .59749 .39251 L p F P
0 g
s
.155 .315 .661 r
.61968 .41209 m .62704 .40545 L .64995 .4252 L p F P
0 g
s
.61968 .41209 m
.64083 .43326 L
s
.61138 .41818 m
.61968 .41209 L
s
.035 .125 .738 r
.53185 .36643 m .53496 .36593 L .54336 .38868 L p F P
0 g
s
.022 .128 .738 r
.54932 .38729 m .54336 .38868 L .53496 .36593 L p F P
0 g
s
.53722 .38964 m
.54336 .38868 L
s
.54336 .38868 m
.55145 .41295 L
s
.682 .17 .256 r
.33652 .62883 m .31512 .61671 L .32444 .58948 L p F P
0 g
s
.704 .176 .181 r
.31512 .61671 m .33652 .62883 L .33001 .65622 L p F P
0 g
s
.33652 .62883 m
.35953 .63953 L
s
.33652 .62883 m
.34483 .60126 L
s
.276 .683 .13 r
.54863 .7772 m .5786 .77516 L .57823 .79862 L p F P
0 g
s
.276 .683 .13 r
.57823 .79862 m .54847 .80062 L .54863 .7772 L p F P
0 g
s
.54856 .75229 m
.54863 .7772 L
s
.51849 .7776 m
.54863 .7772 L
s
.102 .081 .738 r
.51313 .36477 m .51609 .36559 L .50615 .38801 L p F P
0 g
s
.102 .081 .738 r
.50615 .38801 m .50031 .38641 L .51313 .36477 L p F P
0 g
s
.50615 .38801 m
.51221 .38919 L
s
.49658 .41198 m
.50615 .38801 L
s
.538 .019 .52 r
.34873 .49863 m .33567 .4866 L .355 .46334 L p F P
0 g
s
.589 .021 .461 r
.33567 .4866 m .34873 .49863 L .33254 .52388 L p F P
0 g
s
.34873 .49863 m
.36662 .4743 L
s
.34873 .49863 m
.36347 .50967 L
s
.051 .2 .72 r
.56554 .38077 m .5702 .37788 L .59121 .3972 L p F P
0 g
s
.071 .193 .72 r
.59749 .39251 m .59121 .3972 L .5702 .37788 L p F P
0 g
s
.58427 .40143 m
.59121 .3972 L
s
.59121 .3972 m
.61138 .41818 L
s
.474 .564 .13 r
.45862 .77345 m .48841 .77635 L .48868 .79978 L p F P
0 g
s
.412 .611 .13 r
.51855 .80101 m .48868 .79978 L .48841 .77635 L p F P
0 g
s
.48841 .77635 m
.48852 .75142 L
s
.48841 .77635 m
.51849 .7776 L
s
.022 .128 .738 r
.53496 .36593 m .53798 .36522 L .54932 .38729 L p F P
0 g
s
.008 .13 .738 r
.55504 .3855 m .54932 .38729 L .53798 .36522 L p F P
0 g
s
.54336 .38868 m
.54932 .38729 L
s
.54932 .38729 m
.56025 .41094 L
s
.11 .07 .738 r
.51031 .36375 m .51313 .36477 L .50031 .38641 L p F P
0 g
s
.11 .07 .738 r
.50031 .38641 m .49473 .38442 L .51031 .36375 L p F P
0 g
s
.50031 .38641 m
.50615 .38801 L
s
.48794 .40965 m
.50031 .38641 L
s
.633 .395 .052 r
.37375 .72986 m .4012 .73768 L .40083 .7628 L p F P
0 g
s
.588 .459 .052 r
.42935 .76893 m .40083 .7628 L .4012 .73768 L p F P
0 g
s
.4012 .73768 m
.42963 .7439 L
s
.4012 .73768 m
.4028 .71143 L
s
.203 .708 .13 r
.5786 .77516 m .60817 .77148 L .60759 .79503 L p F P
0 g
s
.203 .708 .13 r
.60759 .79503 m .57823 .79862 L .5786 .77516 L p F P
0 g
s
.57845 .75022 m
.5786 .77516 L
s
.54863 .7772 m
.5786 .77516 L
s
.222 .354 .621 r
.68099 .43641 m .6716 .44649 L .64995 .4252 L p F P
0 g
s
.255 .407 .574 r
.6716 .44649 m .68099 .43641 L .70264 .45778 L p F P
0 g
s
.255 .407 .574 r
.70264 .45778 m .6918 .46913 L .6716 .44649 L p F P
0 g
s
.66078 .45584 m
.6716 .44649 L
s
.008 .13 .738 r
.53798 .36522 m .54088 .3643 L .55504 .3855 L p F P
0 g
s
.005 .13 .738 r
.56047 .38332 m .55504 .3855 L .54088 .3643 L p F P
0 g
s
.54932 .38729 m
.55504 .3855 L
s
.55504 .3855 m
.56871 .40832 L
s
.28 .011 .695 r
.44704 .38459 m .45217 .38991 L .42901 .40871 L p F P
0 g
s
.28 .011 .695 r
.42901 .40871 m .42218 .40181 L .44704 .38459 L p F P
0 g
s
.42901 .40871 m
.43683 .41509 L
s
.40692 .42916 m
.42901 .40871 L
s
.204 .03 .72 r
.47624 .3729 m .48019 .37626 L .45808 .39482 L p F P
0 g
s
.204 .03 .72 r
.45808 .39482 m .45217 .38991 L .47624 .3729 L p F P
0 g
s
.45808 .39482 m
.46468 .39929 L
s
.43683 .41509 m
.45808 .39482 L
s
.179 .719 .104 r
.71044 .66205 m .73351 .65046 L .7384 .67742 L p F P
0 g
s
.179 .719 .104 r
.7384 .67742 m .71475 .68908 L .71044 .66205 L p F P
0 g
s
.70436 .63456 m
.71044 .66205 L
s
.68583 .67215 m
.71044 .66205 L
s
.104 .74 .026 r
.68954 .69924 m .71475 .68908 L .71722 .71542 L p F P
0 g
s
.104 .74 .026 r
.71722 .71542 m .69166 .72554 L .68954 .69924 L p F P
0 g
s
.68583 .67215 m
.68954 .69924 L
s
.663 .70786 m
.68954 .69924 L
s
.187 .297 .661 r
.65784 .41653 m .64995 .4252 L .62704 .40545 L p F P
0 g
s
.222 .354 .621 r
.64995 .4252 m .65784 .41653 L .68099 .43641 L p F P
0 g
s
.64083 .43326 m
.64995 .4252 L
s
.64995 .4252 m
.6716 .44649 L
s
.286 .456 .52 r
.6918 .46913 m .70264 .45778 L .7226 .4805 L p F P
0 g
s
.286 .456 .52 r
.7226 .4805 m .7104 .49296 L .6918 .46913 L p F P
0 g
s
.6716 .44649 m
.6918 .46913 L
s
.67936 .47964 m
.6918 .46913 L
s
.295 .604 .328 r
.72558 .55654 m .74217 .54343 L .75505 .56967 L p F P
0 g
s
.295 .604 .328 r
.75505 .56967 m .73738 .58334 L .72558 .55654 L p F P
0 g
s
.7119 .53018 m
.72558 .55654 L
s
.70719 .56846 m
.72558 .55654 L
s
.116 .058 .738 r
.50766 .36253 m .51031 .36375 L .49473 .38442 L p F P
0 g
s
.116 .058 .738 r
.49473 .38442 m .48948 .38204 L .50766 .36253 L p F P
0 g
s
.49473 .38442 m
.50031 .38641 L
s
.47969 .40674 m
.49473 .38442 L
s
.666 .094 .328 r
.32444 .58948 m .30584 .5764 L .3182 .54988 L p F P
0 g
s
.696 .098 .256 r
.30584 .5764 m .32444 .58948 L .31512 .61671 L p F P
0 g
s
.32444 .58948 m
.34483 .60126 L
s
.32444 .58948 m
.33568 .56242 L
s
.53 .512 .13 r
.42935 .76893 m .45862 .77345 L .4591 .79696 L p F P
0 g
s
.474 .564 .13 r
.48868 .79978 m .4591 .79696 L .45862 .77345 L p F P
0 g
s
.45862 .77345 m
.45882 .74849 L
s
.45862 .77345 m
.48841 .77635 L
s
.589 .021 .461 r
.33254 .52388 m .31816 .51095 L .33567 .4866 L p F P
0 g
s
.634 .023 .397 r
.31816 .51095 m .33254 .52388 L .3182 .54988 L p F P
0 g
s
.33254 .52388 m
.34873 .49863 L
s
.33254 .52388 m
.34873 .53575 L
s
.005 .13 .738 r
.54088 .3643 m .54362 .36319 L .56047 .38332 L p F P
0 g
s
.019 .129 .738 r
.56554 .38077 m .56047 .38332 L .54362 .36319 L p F P
0 g
s
.55504 .3855 m
.56047 .38332 L
s
.56047 .38332 m
.57675 .40515 L
s
.071 .193 .72 r
.5702 .37788 m .57441 .37468 L .59749 .39251 L p F P
0 g
s
.091 .185 .72 r
.60303 .3874 m .59749 .39251 L .57441 .37468 L p F P
0 g
s
.124 .252 .695 r
.59749 .39251 m .60303 .3874 L .62704 .40545 L p F P
0 g
s
.59749 .39251 m
.61968 .41209 L
s
.59121 .3972 m
.59749 .39251 L
s
.149 .237 .695 r
.63337 .39832 m .62704 .40545 L .60303 .3874 L p F P
0 g
s
.187 .297 .661 r
.62704 .40545 m .63337 .39832 L .65784 .41653 L p F P
0 g
s
.62704 .40545 m
.64995 .4252 L
s
.61968 .41209 m
.62704 .40545 L
s
.249 .682 .181 r
.72662 .62317 m .74716 .61039 L .75481 .63746 L p F P
0 g
s
.249 .682 .181 r
.75481 .63746 m .73351 .65046 L .72662 .62317 L p F P
0 g
s
.71782 .59576 m
.72662 .62317 L
s
.70436 .63456 m
.72662 .62317 L
s
.122 .045 .738 r
.50521 .36114 m .50766 .36253 L .48948 .38204 L p F P
0 g
s
.122 .045 .738 r
.48948 .38204 m .48462 .37931 L .50521 .36114 L p F P
0 g
s
.48948 .38204 m
.49473 .38442 L
s
.47191 .40328 m
.48948 .38204 L
s
.026 .746 .052 r
.66477 .73412 m .69166 .72554 L .69215 .75082 L p F P
0 g
s
.026 .746 .052 r
.69215 .75082 m .66518 .75928 L .66477 .73412 L p F P
0 g
s
.663 .70786 m
.66477 .73412 L
s
.63678 .74111 m
.66477 .73412 L
s
.313 .5 .461 r
.7104 .49296 m .7226 .4805 L .74069 .50437 L p F P
0 g
s
.313 .5 .461 r
.74069 .50437 m .72724 .51779 L .7104 .49296 L p F P
0 g
s
.6918 .46913 m
.7104 .49296 L
s
.69645 .50449 m
.7104 .49296 L
s
.128 .726 .13 r
.60817 .77148 m .63711 .76618 L .63632 .78985 L p F P
0 g
s
.128 .726 .13 r
.63632 .78985 m .60759 .79503 L .60817 .77148 L p F P
0 g
s
.60793 .74648 m
.60817 .77148 L
s
.5786 .77516 m
.60817 .77148 L
s
.019 .129 .738 r
.54362 .36319 m .54617 .36188 L .56554 .38077 L p F P
0 g
s
.032 .126 .738 r
.5702 .37788 m .56554 .38077 L .54617 .36188 L p F P
0 g
s
.56047 .38332 m
.56554 .38077 L
s
.56554 .38077 m
.58427 .40143 L
s
.417 .028 .621 r
.39122 .41181 m .39842 .42077 L .37597 .44134 L p F P
0 g
s
.417 .028 .621 r
.37597 .44134 m .36737 .43092 L .39122 .41181 L p F P
0 g
s
.48 .033 .574 r
.36737 .43092 m .37597 .44134 L .355 .46334 L p F P
0 g
s
.37597 .44134 m
.38607 .45108 L
s
.35 .024 .661 r
.41641 .39444 m .42218 .40181 L .39842 .42077 L p F P
0 g
s
.35 .024 .661 r
.39842 .42077 m .39122 .41181 L .41641 .39444 L p F P
0 g
s
.39842 .42077 m
.40692 .42916 L
s
.37597 .44134 m
.39842 .42077 L
s
.206 .008 .72 r
.47282 .36929 m .47624 .3729 L .45217 .38991 L p F P
0 g
s
.206 .008 .72 r
.45217 .38991 m .44704 .38459 L .47282 .36929 L p F P
0 g
s
.45217 .38991 m
.45808 .39482 L
s
.42901 .40871 m
.45217 .38991 L
s
.126 .032 .738 r
.50299 .35958 m .50521 .36114 L .48462 .37931 L p F P
0 g
s
.126 .032 .738 r
.48462 .37931 m .48019 .37626 L .50299 .35958 L p F P
0 g
s
.48462 .37931 m
.48948 .38204 L
s
.46468 .39929 m
.48462 .37931 L
s
.696 .254 .104 r
.34983 .69416 m .3254 .68321 L .33001 .65622 L p F P
0 g
s
.703 .256 .026 r
.3254 .68321 m .34983 .69416 L .34752 .72048 L p F P
0 g
s
.672 .328 .026 r
.37375 .72986 m .34752 .72048 L .34983 .69416 L p F P
0 g
s
.34983 .69416 m
.37571 .70358 L
s
.34983 .69416 m
.35385 .6671 L
s
.48 .033 .574 r
.355 .46334 m .34505 .4516 L .36737 .43092 L p F P
0 g
s
.537 .037 .52 r
.34505 .4516 m .355 .46334 L .33567 .4866 L p F P
0 g
s
.355 .46334 m
.37597 .44134 L
s
.355 .46334 m
.36662 .4743 L
s
.28 .019 .695 r
.44273 .37894 m .44704 .38459 L .42218 .40181 L p F P
0 g
s
.28 .019 .695 r
.42218 .40181 m .41641 .39444 L .44273 .37894 L p F P
0 g
s
.42218 .40181 m
.42901 .40871 L
s
.39842 .42077 m
.42218 .40181 L
s
.704 .176 .181 r
.33001 .65622 m .30783 .64389 L .31512 .61671 L p F P
0 g
s
.719 .179 .104 r
.30783 .64389 m .33001 .65622 L .3254 .68321 L p F P
0 g
s
.33001 .65622 m
.35385 .6671 L
s
.33001 .65622 m
.33652 .62883 L
s
.581 .454 .13 r
.40083 .7628 m .42935 .76893 L .43004 .79254 L p F P
0 g
s
.53 .512 .13 r
.4591 .79696 m .43004 .79254 L .42935 .76893 L p F P
0 g
s
.42935 .76893 m
.42963 .7439 L
s
.42935 .76893 m
.45862 .77345 L
s
.032 .126 .738 r
.54617 .36188 m .54852 .36041 L .5702 .37788 L p F P
0 g
s
.045 .122 .738 r
.57441 .37468 m .5702 .37788 L .54852 .36041 L p F P
0 g
s
.56554 .38077 m
.5702 .37788 L
s
.5702 .37788 m
.59121 .3972 L
s
.091 .185 .72 r
.57441 .37468 m .57811 .3712 L .60303 .3874 L p F P
0 g
s
.11 .174 .72 r
.60777 .38191 m .60303 .3874 L .57811 .3712 L p F P
0 g
s
.149 .237 .695 r
.60303 .3874 m .60777 .38191 L .63337 .39832 L p F P
0 g
s
.60303 .3874 m
.62704 .40545 L
s
.59749 .39251 m
.60303 .3874 L
s
.634 .023 .397 r
.3182 .54988 m .30263 .53618 L .31816 .51095 L p F P
0 g
s
.672 .024 .328 r
.30263 .53618 m .3182 .54988 L .30584 .5764 L p F P
0 g
s
.3182 .54988 m
.33254 .52388 L
s
.3182 .54988 m
.33568 .56242 L
s
.308 .632 .256 r
.73738 .58334 m .75505 .56967 L .76574 .59631 L p F P
0 g
s
.308 .632 .256 r
.76574 .59631 m .74716 .61039 L .73738 .58334 L p F P
0 g
s
.72558 .55654 m
.73738 .58334 L
s
.71782 .59576 m
.73738 .58334 L
s
.337 .538 .397 r
.72724 .51779 m .74069 .50437 L .75675 .52922 L p F P
0 g
s
.337 .538 .397 r
.75675 .52922 m .74217 .54343 L .72724 .51779 L p F P
0 g
s
.7104 .49296 m
.72724 .51779 L
s
.7119 .53018 m
.72724 .51779 L
s
.671 .327 .052 r
.34752 .72048 m .37375 .72986 L .3733 .75508 L p F P
0 g
s
.633 .395 .052 r
.40083 .7628 m .3733 .75508 L .37375 .72986 L p F P
0 g
s
.37375 .72986 m
.4012 .73768 L
s
.37375 .72986 m
.37571 .70358 L
s
.129 .019 .738 r
.50102 .35787 m .50299 .35958 L .48019 .37626 L p F P
0 g
s
.129 .019 .738 r
.48019 .37626 m .47624 .3729 L .50102 .35787 L p F P
0 g
s
.48019 .37626 m
.48462 .37931 L
s
.45808 .39482 m
.48019 .37626 L
s
.217 .276 .661 r
.66438 .40732 m .65784 .41653 L .63337 .39832 L p F P
0 g
s
.258 .329 .621 r
.65784 .41653 m .66438 .40732 L .68883 .42568 L p F P
0 g
s
.258 .329 .621 r
.68883 .42568 m .68099 .43641 L .65784 .41653 L p F P
0 g
s
.64995 .4252 m
.65784 .41653 L
s
.297 .379 .574 r
.68099 .43641 m .68883 .42568 L .71173 .4457 L p F P
0 g
s
.297 .379 .574 r
.71173 .4457 m .70264 .45778 L .68099 .43641 L p F P
0 g
s
.65784 .41653 m
.68099 .43641 L
s
.6716 .44649 m
.68099 .43641 L
s
.173 .22 .695 r
.63859 .39075 m .63337 .39832 L .60777 .38191 L p F P
0 g
s
.217 .276 .661 r
.63337 .39832 m .63859 .39075 L .66438 .40732 L p F P
0 g
s
.62704 .40545 m
.63337 .39832 L
s
.63337 .39832 m
.65784 .41653 L
s
.537 .037 .52 r
.33567 .4866 m .32445 .47369 L .34505 .4516 L p F P
0 g
s
.588 .041 .461 r
.32445 .47369 m .33567 .4866 L .31816 .51095 L p F P
0 g
s
.33567 .4866 m
.355 .46334 L
s
.33567 .4866 m
.34873 .49863 L
s
.206 .014 .72 r
.46997 .36545 m .47282 .36929 L .44704 .38459 L p F P
0 g
s
.206 .014 .72 r
.44704 .38459 m .44273 .37894 L .46997 .36545 L p F P
0 g
s
.44704 .38459 m
.45217 .38991 L
s
.42218 .40181 m
.44704 .38459 L
s
.045 .122 .738 r
.54852 .36041 m .55062 .35877 L .57441 .37468 L p F P
0 g
s
.058 .116 .738 r
.57811 .3712 m .57441 .37468 L .55062 .35877 L p F P
0 g
s
.5702 .37788 m
.57441 .37468 L
s
.57441 .37468 m
.59749 .39251 L
s
.696 .098 .256 r
.31512 .61671 m .29557 .60324 L .30584 .5764 L p F P
0 g
s
.719 .101 .181 r
.29557 .60324 m .31512 .61671 L .30783 .64389 L p F P
0 g
s
.31512 .61671 m
.33652 .62883 L
s
.31512 .61671 m
.32444 .58948 L
s
.052 .735 .13 r
.63711 .76618 m .66518 .75928 L .66419 .78311 L p F P
0 g
s
.052 .735 .13 r
.66419 .78311 m .63632 .78985 L .63711 .76618 L p F P
0 g
s
.63678 .74111 m
.63711 .76618 L
s
.60817 .77148 m
.63711 .76618 L
s
.13 .005 .738 r
.49932 .35603 m .50102 .35787 L .47624 .3729 L p F P
0 g
s
.13 .005 .738 r
.47624 .3729 m .47282 .36929 L .49932 .35603 L p F P
0 g
s
.47624 .3729 m
.48019 .37626 L
s
.45217 .38991 m
.47624 .3729 L
s
.181 .725 .026 r
.71475 .68908 m .7384 .67742 L .7412 .70381 L p F P
0 g
s
.181 .725 .026 r
.7412 .70381 m .71722 .71542 L .71475 .68908 L p F P
0 g
s
.71044 .66205 m
.71475 .68908 L
s
.68954 .69924 m
.71475 .68908 L
s
.028 .044 .747 r
.52549 .36676 m .5223 .36659 L .52632 .34495 L closepath p F P
0 g
s
.024 .047 .747 r
.52868 .36671 m .52549 .36676 L .52632 .34495 L closepath p F P
0 g
s
.52468 .39029 m
.52549 .36676 L
s
.332 .424 .52 r
.70264 .45778 m .71173 .4457 L .73287 .4672 L p F P
0 g
s
.332 .424 .52 r
.73287 .4672 m .7226 .4805 L .70264 .45778 L p F P
0 g
s
.68099 .43641 m
.70264 .45778 L
s
.6918 .46913 m
.70264 .45778 L
s
.019 .049 .747 r
.53185 .36643 m .52868 .36671 L .52632 .34495 L closepath p F P
0 g
s
.52868 .36671 m
.53098 .39018 L
s
.52549 .36676 m
.52868 .36671 L
s
.033 .041 .747 r
.5223 .36659 m .51916 .3662 L .52632 .34495 L closepath p F P
0 g
s
.5223 .36659 m
.52549 .36676 L
s
.5184 .38996 m
.5223 .36659 L
s
.014 .05 .747 r
.53496 .36593 m .53185 .36643 L .52632 .34495 L closepath p F P
0 g
s
.53185 .36643 m
.53722 .38964 L
s
.52868 .36671 m
.53185 .36643 L
s
.037 .037 .747 r
.51916 .3662 m .51609 .36559 L .52632 .34495 L closepath p F P
0 g
s
.51221 .38919 m
.51916 .3662 L
s
.51916 .3662 m
.5223 .36659 L
s
.11 .174 .72 r
.57811 .3712 m .58126 .36747 L .60777 .38191 L p F P
0 g
s
.128 .162 .72 r
.61166 .37611 m .60777 .38191 L .58126 .36747 L p F P
0 g
s
.173 .22 .695 r
.60777 .38191 m .61166 .37611 L .63859 .39075 L p F P
0 g
s
.60777 .38191 m
.63337 .39832 L
s
.60303 .3874 m
.60777 .38191 L
s
.008 .052 .747 r
.53798 .36522 m .53496 .36593 L .52632 .34495 L closepath p F P
0 g
s
.53496 .36593 m
.54336 .38868 L
s
.53185 .36643 m
.53496 .36593 L
s
.041 .033 .747 r
.51609 .36559 m .51313 .36477 L .52632 .34495 L closepath p F P
0 g
s
.50615 .38801 m
.51609 .36559 L
s
.51609 .36559 m
.51916 .3662 L
s
.254 .696 .104 r
.73351 .65046 m .75481 .63746 L .76025 .66434 L p F P
0 g
s
.254 .696 .104 r
.76025 .66434 m .7384 .67742 L .73351 .65046 L p F P
0 g
s
.72662 .62317 m
.73351 .65046 L
s
.71044 .66205 m
.73351 .65046 L
s
.058 .116 .738 r
.55062 .35877 m .55247 .357 L .57811 .3712 L p F P
0 g
s
.07 .11 .738 r
.58126 .36747 m .57811 .3712 L .55247 .357 L p F P
0 g
s
.57441 .37468 m
.57811 .3712 L
s
.57811 .3712 m
.60303 .3874 L
s
.346 .06 .661 r
.41179 .38669 m .41641 .39444 L .39122 .41181 L p F P
0 g
s
.346 .06 .661 r
.39122 .41181 m .38541 .40236 L .41179 .38669 L p F P
0 g
s
.412 .072 .621 r
.38541 .40236 m .39122 .41181 L .36737 .43092 L p F P
0 g
s
.39122 .41181 m
.39842 .42077 L
s
.402 .596 .206 r
.48868 .79978 m .51855 .80101 L .51868 .82268 L p F P
0 g
s
.338 .635 .206 r
.51855 .80101 m .54847 .80062 L .54809 .82231 L p F P
0 g
s
.338 .635 .206 r
.54809 .82231 m .51868 .82268 L .51855 .80101 L p F P
0 g
s
.51849 .7776 m
.51855 .80101 L
s
.003 .052 .747 r
.54088 .3643 m .53798 .36522 L .52632 .34495 L closepath p F P
0 g
s
.53798 .36522 m
.54932 .38729 L
s
.53496 .36593 m
.53798 .36522 L
s
.104 .739 .052 r
.69166 .72554 m .71722 .71542 L .71779 .74084 L p F P
0 g
s
.104 .739 .052 r
.71779 .74084 m .69215 .75082 L .69166 .72554 L p F P
0 g
s
.68954 .69924 m
.69166 .72554 L
s
.66477 .73412 m
.69166 .72554 L
s
.276 .048 .695 r
.43931 .373 m .44273 .37894 L .41641 .39444 L p F P
0 g
s
.276 .048 .695 r
.41641 .39444 m .41179 .38669 L .43931 .373 L p F P
0 g
s
.41641 .39444 m
.42218 .40181 L
s
.39122 .41181 m
.41641 .39444 L
s
.044 .028 .747 r
.51313 .36477 m .51031 .36375 L .52632 .34495 L closepath p F P
0 g
s
.50031 .38641 m
.51313 .36477 L
s
.51313 .36477 m
.51609 .36559 L
s
.27 .667 .206 r
.54847 .80062 m .57823 .79862 L .57733 .82038 L p F P
0 g
s
.27 .667 .206 r
.57733 .82038 m .54809 .82231 L .54847 .80062 L p F P
0 g
s
.54847 .80062 m
.54863 .7772 L
s
.51855 .80101 m
.54847 .80062 L
s
.003 .052 .747 r
.54362 .36319 m .54088 .3643 L .52632 .34495 L closepath p F P
0 g
s
.54088 .3643 m
.55504 .3855 L
s
.53798 .36522 m
.54088 .3643 L
s
.625 .39 .13 r
.3733 .75508 m .40083 .7628 L .40173 .78655 L p F P
0 g
s
.581 .454 .13 r
.43004 .79254 m .40173 .78655 L .40083 .7628 L p F P
0 g
s
.40083 .7628 m
.42935 .76893 L
s
.40083 .7628 m
.4012 .73768 L
s
.357 .57 .328 r
.74217 .54343 m .75675 .52922 L .77062 .55484 L p F P
0 g
s
.357 .57 .328 r
.77062 .55484 m .75505 .56967 L .74217 .54343 L p F P
0 g
s
.72724 .51779 m
.74217 .54343 L
s
.72558 .55654 m
.74217 .54343 L
s
.047 .024 .747 r
.51031 .36375 m .50766 .36253 L .52632 .34495 L closepath p F P
0 g
s
.49473 .38442 m
.51031 .36375 L
s
.51031 .36375 m
.51313 .36477 L
s
.462 .551 .206 r
.4591 .79696 m .48868 .79978 L .48933 .8215 L p F P
0 g
s
.402 .596 .206 r
.51868 .82268 m .48933 .8215 L .48868 .79978 L p F P
0 g
s
.48841 .77635 m
.48868 .79978 L
s
.48868 .79978 m
.51855 .80101 L
s
.412 .072 .621 r
.36737 .43092 m .36038 .4199 L .38541 .40236 L p F P
0 g
s
.474 .083 .574 r
.36038 .4199 m .36737 .43092 L .34505 .4516 L p F P
0 g
s
.36737 .43092 m
.39122 .41181 L
s
.36737 .43092 m
.37597 .44134 L
s
.588 .041 .461 r
.31816 .51095 m .30577 .49704 L .32445 .47369 L p F P
0 g
s
.633 .044 .397 r
.30577 .49704 m .31816 .51095 L .30263 .53618 L p F P
0 g
s
.31816 .51095 m
.33567 .4866 L
s
.31816 .51095 m
.33254 .52388 L
s
.13 .008 .738 r
.49791 .35408 m .49932 .35603 L .47282 .36929 L p F P
0 g
s
.13 .008 .738 r
.47282 .36929 m .46997 .36545 L .49791 .35408 L p F P
0 g
s
.47282 .36929 m
.47624 .3729 L
s
.44704 .38459 m
.47282 .36929 L
s
.008 .052 .747 r
.54617 .36188 m .54362 .36319 L .52632 .34495 L closepath p F P
0 g
s
.54362 .36319 m
.56047 .38332 L
s
.54088 .3643 m
.54362 .36319 L
s
.203 .035 .72 r
.46772 .36142 m .46997 .36545 L .44273 .37894 L p F P
0 g
s
.203 .035 .72 r
.44273 .37894 m .43931 .373 L .46772 .36142 L p F P
0 g
s
.44273 .37894 m
.44704 .38459 L
s
.41641 .39444 m
.44273 .37894 L
s
.672 .024 .328 r
.30584 .5764 m .28923 .56211 L .30263 .53618 L p F P
0 g
s
.703 .025 .256 r
.28923 .56211 m .30584 .5764 L .29557 .60324 L p F P
0 g
s
.30584 .5764 m
.32444 .58948 L
s
.30584 .5764 m
.3182 .54988 L
s
.049 .019 .747 r
.50766 .36253 m .50521 .36114 L .52632 .34495 L closepath p F P
0 g
s
.48948 .38204 m
.50766 .36253 L
s
.50766 .36253 m
.51031 .36375 L
s
.363 .464 .461 r
.7226 .4805 m .73287 .4672 L .75207 .49004 L p F P
0 g
s
.363 .464 .461 r
.75207 .49004 m .74069 .50437 L .7226 .4805 L p F P
0 g
s
.70264 .45778 m
.7226 .4805 L
s
.7104 .49296 m
.7226 .4805 L
s
.198 .691 .206 r
.57823 .79862 m .60759 .79503 L .60617 .8169 L p F P
0 g
s
.198 .691 .206 r
.60617 .8169 m .57733 .82038 L .57823 .79862 L p F P
0 g
s
.57823 .79862 m
.5786 .77516 L
s
.54847 .80062 m
.57823 .79862 L
s
.014 .05 .747 r
.54852 .36041 m .54617 .36188 L .52632 .34495 L closepath p F P
0 g
s
.54617 .36188 m
.56554 .38077 L
s
.54362 .36319 m
.54617 .36188 L
s
.07 .11 .738 r
.55247 .357 m .55403 .3551 L .58126 .36747 L p F P
0 g
s
.081 .102 .738 r
.58382 .36353 m .58126 .36747 L .55403 .3551 L p F P
0 g
s
.128 .162 .72 r
.58126 .36747 m .58382 .36353 L .61166 .37611 L p F P
0 g
s
.58126 .36747 m
.60777 .38191 L
s
.57811 .3712 m
.58126 .36747 L
s
.318 .652 .181 r
.74716 .61039 m .76574 .59631 L .77411 .62313 L p F P
0 g
s
.318 .652 .181 r
.77411 .62313 m .75481 .63746 L .74716 .61039 L p F P
0 g
s
.73738 .58334 m
.74716 .61039 L
s
.72662 .62317 m
.74716 .61039 L
s
.195 .201 .695 r
.64263 .38284 m .63859 .39075 L .61166 .37611 L p F P
0 g
s
.245 .252 .661 r
.63859 .39075 m .64263 .38284 L .6695 .39767 L p F P
0 g
s
.245 .252 .661 r
.6695 .39767 m .66438 .40732 L .63859 .39075 L p F P
0 g
s
.63337 .39832 m
.63859 .39075 L
s
.05 .014 .747 r
.50521 .36114 m .50299 .35958 L .52632 .34495 L closepath p F P
0 g
s
.48462 .37931 m
.50521 .36114 L
s
.50521 .36114 m
.50766 .36253 L
s
.291 .3 .621 r
.66438 .40732 m .6695 .39767 L .69501 .41442 L p F P
0 g
s
.291 .3 .621 r
.69501 .41442 m .68883 .42568 L .66438 .40732 L p F P
0 g
s
.63859 .39075 m
.66438 .40732 L
s
.65784 .41653 m
.66438 .40732 L
s
.019 .049 .747 r
.55062 .35877 m .54852 .36041 L .52632 .34495 L closepath p F P
0 g
s
.54852 .36041 m
.5702 .37788 L
s
.54617 .36188 m
.54852 .36041 L
s
.144 .148 .72 r
.61465 .37006 m .61166 .37611 L .58382 .36353 L p F P
0 g
s
.195 .201 .695 r
.61166 .37611 m .61465 .37006 L .64263 .38284 L p F P
0 g
s
.60777 .38191 m
.61166 .37611 L
s
.61166 .37611 m
.63859 .39075 L
s
.474 .083 .574 r
.34505 .4516 m .33691 .43917 L .36038 .4199 L p F P
0 g
s
.53 .093 .52 r
.33691 .43917 m .34505 .4516 L .32445 .47369 L p F P
0 g
s
.34505 .4516 m
.36737 .43092 L
s
.34505 .4516 m
.355 .46334 L
s
.518 .499 .206 r
.43004 .79254 m .4591 .79696 L .46027 .81876 L p F P
0 g
s
.462 .551 .206 r
.48933 .8215 m .46027 .81876 L .4591 .79696 L p F P
0 g
s
.45862 .77345 m
.4591 .79696 L
s
.4591 .79696 m
.48868 .79978 L
s
.026 .736 .13 r
.66518 .75928 m .69215 .75082 L .69096 .77485 L p F P
0 g
s
.026 .736 .13 r
.69096 .77485 m .66419 .78311 L .66518 .75928 L p F P
0 g
s
.66477 .73412 m
.66518 .75928 L
s
.63711 .76618 m
.66518 .75928 L
s
.719 .179 .104 r
.3254 .68321 m .30265 .6708 L .30783 .64389 L p F P
0 g
s
.725 .181 .026 r
.30265 .6708 m .3254 .68321 L .32275 .70957 L p F P
0 g
s
.703 .256 .026 r
.34752 .72048 m .32275 .70957 L .3254 .68321 L p F P
0 g
s
.3254 .68321 m
.34983 .69416 L
s
.3254 .68321 m
.33001 .65622 L
s
.052 .008 .747 r
.50299 .35958 m .50102 .35787 L .52632 .34495 L closepath p F P
0 g
s
.48019 .37626 m
.50299 .35958 L
s
.50299 .35958 m
.50521 .36114 L
s
.128 .022 .738 r
.4968 .35204 m .49791 .35408 L .46997 .36545 L p F P
0 g
s
.128 .022 .738 r
.46997 .36545 m .46772 .36142 L .4968 .35204 L p F P
0 g
s
.46997 .36545 m
.47282 .36929 L
s
.44273 .37894 m
.46997 .36545 L
s
.701 .255 .052 r
.32275 .70957 m .34752 .72048 L .34699 .74583 L p F P
0 g
s
.671 .327 .052 r
.3733 .75508 m .34699 .74583 L .34752 .72048 L p F P
0 g
s
.34752 .72048 m
.37375 .72986 L
s
.34752 .72048 m
.34983 .69416 L
s
.024 .047 .747 r
.55247 .357 m .55062 .35877 L .52632 .34495 L closepath p F P
0 g
s
.55062 .35877 m
.57441 .37468 L
s
.54852 .36041 m
.55062 .35877 L
s
.335 .345 .574 r
.68883 .42568 m .69501 .41442 L .71895 .43298 L p F P
0 g
s
.335 .345 .574 r
.71895 .43298 m .71173 .4457 L .68883 .42568 L p F P
0 g
s
.66438 .40732 m
.68883 .42568 L
s
.68099 .43641 m
.68883 .42568 L
s
.052 .003 .747 r
.50102 .35787 m .49932 .35603 L .52632 .34495 L closepath p F P
0 g
s
.47624 .3729 m
.50102 .35787 L
s
.50102 .35787 m
.50299 .35958 L
s
.719 .101 .181 r
.30783 .64389 m .28754 .63019 L .29557 .60324 L p F P
0 g
s
.734 .103 .104 r
.28754 .63019 m .30783 .64389 L .30265 .6708 L p F P
0 g
s
.30783 .64389 m
.33001 .65622 L
s
.30783 .64389 m
.31512 .61671 L
s
.081 .102 .738 r
.55403 .3551 m .55529 .35311 L .58382 .36353 L p F P
0 g
s
.091 .093 .738 r
.58577 .35942 m .58382 .36353 L .55529 .35311 L p F P
0 g
s
.144 .148 .72 r
.58382 .36353 m .58577 .35942 L .61465 .37006 L p F P
0 g
s
.58382 .36353 m
.61166 .37611 L
s
.58126 .36747 m
.58382 .36353 L
s
.125 .708 .206 r
.60759 .79503 m .63632 .78985 L .63439 .81189 L p F P
0 g
s
.125 .708 .206 r
.63439 .81189 m .60617 .8169 L .60759 .79503 L p F P
0 g
s
.60759 .79503 m
.60817 .77148 L
s
.57823 .79862 m
.60759 .79503 L
s
.27 .076 .695 r
.4368 .36683 m .43931 .373 L .41179 .38669 L p F P
0 g
s
.27 .076 .695 r
.41179 .38669 m .40838 .37862 L .4368 .36683 L p F P
0 g
s
.338 .096 .661 r
.40838 .37862 m .41179 .38669 L .38541 .40236 L p F P
0 g
s
.41179 .38669 m
.41641 .39444 L
s
.198 .056 .72 r
.4661 .35724 m .46772 .36142 L .43931 .373 L p F P
0 g
s
.198 .056 .72 r
.43931 .373 m .4368 .36683 L .4661 .35724 L p F P
0 g
s
.43931 .373 m
.44273 .37894 L
s
.41179 .38669 m
.43931 .373 L
s
.028 .044 .747 r
.55403 .3551 m .55247 .357 L .52632 .34495 L closepath p F P
0 g
s
.55247 .357 m
.57811 .3712 L
s
.55062 .35877 m
.55247 .357 L
s
.391 .5 .397 r
.74069 .50437 m .75207 .49004 L .76913 .51402 L p F P
0 g
s
.391 .5 .397 r
.76913 .51402 m .75675 .52922 L .74069 .50437 L p F P
0 g
s
.7226 .4805 m
.74069 .50437 L
s
.72724 .51779 m
.74069 .50437 L
s
.633 .044 .397 r
.30263 .53618 m .28917 .52144 L .30577 .49704 L p F P
0 g
s
.671 .047 .328 r
.28917 .52144 m .30263 .53618 L .28923 .56211 L p F P
0 g
s
.30263 .53618 m
.3182 .54988 L
s
.30263 .53618 m
.31816 .51095 L
s
.052 .003 .747 r
.49932 .35603 m .49791 .35408 L .52632 .34495 L closepath p F P
0 g
s
.47282 .36929 m
.49932 .35603 L
s
.49932 .35603 m
.50102 .35787 L
s
.373 .596 .256 r
.75505 .56967 m .77062 .55484 L .78214 .58102 L p F P
0 g
s
.373 .596 .256 r
.78214 .58102 m .76574 .59631 L .75505 .56967 L p F P
0 g
s
.74217 .54343 m
.75505 .56967 L
s
.73738 .58334 m
.75505 .56967 L
s
.338 .096 .661 r
.38541 .40236 m .38106 .39251 L .40838 .37862 L p F P
0 g
s
.402 .115 .621 r
.38106 .39251 m .38541 .40236 L .36038 .4199 L p F P
0 g
s
.38541 .40236 m
.41179 .38669 L
s
.38541 .40236 m
.39122 .41181 L
s
.125 .035 .738 r
.49602 .34992 m .4968 .35204 L .46772 .36142 L p F P
0 g
s
.125 .035 .738 r
.46772 .36142 m .4661 .35724 L .49602 .34992 L p F P
0 g
s
.46772 .36142 m
.46997 .36545 L
s
.43931 .373 m
.46772 .36142 L
s
.53 .093 .52 r
.32445 .47369 m .31523 .46001 L .33691 .43917 L p F P
0 g
s
.581 .102 .461 r
.31523 .46001 m .32445 .47369 L .30577 .49704 L p F P
0 g
s
.32445 .47369 m
.34505 .4516 L
s
.32445 .47369 m
.33567 .4866 L
s
.033 .041 .747 r
.55529 .35311 m .55403 .3551 L .52632 .34495 L closepath p F P
0 g
s
.55403 .3551 m
.58126 .36747 L
s
.55247 .357 m
.55403 .3551 L
s
.662 .323 .13 r
.34699 .74583 m .3733 .75508 L .3744 .77901 L p F P
0 g
s
.625 .39 .13 r
.40173 .78655 m .3744 .77901 L .3733 .75508 L p F P
0 g
s
.3733 .75508 m
.40083 .7628 L
s
.3733 .75508 m
.37375 .72986 L
s
.567 .443 .206 r
.40173 .78655 m .43004 .79254 L .43172 .81449 L p F P
0 g
s
.518 .499 .206 r
.46027 .81876 m .43172 .81449 L .43004 .79254 L p F P
0 g
s
.42935 .76893 m
.43004 .79254 L
s
.43004 .79254 m
.4591 .79696 L
s
.159 .132 .72 r
.61669 .3638 m .61465 .37006 L .58577 .35942 L p F P
0 g
s
.215 .18 .695 r
.61465 .37006 m .61669 .3638 L .64545 .37465 L p F P
0 g
s
.215 .18 .695 r
.64545 .37465 m .64263 .38284 L .61465 .37006 L p F P
0 g
s
.61166 .37611 m
.61465 .37006 L
s
.052 .008 .747 r
.49791 .35408 m .4968 .35204 L .52632 .34495 L closepath p F P
0 g
s
.46997 .36545 m
.49791 .35408 L
s
.49791 .35408 m
.49932 .35603 L
s
.374 .387 .52 r
.71173 .4457 m .71895 .43298 L .74109 .45319 L p F P
0 g
s
.374 .387 .52 r
.74109 .45319 m .73287 .4672 L .71173 .4457 L p F P
0 g
s
.68883 .42568 m
.71173 .4457 L
s
.70264 .45778 m
.71173 .4457 L
s
.091 .093 .738 r
.55529 .35311 m .55624 .35103 L .58577 .35942 L p F P
0 g
s
.1 .083 .738 r
.58708 .35519 m .58577 .35942 L .55624 .35103 L p F P
0 g
s
.159 .132 .72 r
.58577 .35942 m .58708 .35519 L .61669 .3638 L p F P
0 g
s
.58577 .35942 m
.61465 .37006 L
s
.58382 .36353 m
.58577 .35942 L
s
.27 .225 .661 r
.64263 .38284 m .64545 .37465 L .67311 .38766 L p F P
0 g
s
.27 .225 .661 r
.67311 .38766 m .6695 .39767 L .64263 .38284 L p F P
0 g
s
.61465 .37006 m
.64263 .38284 L
s
.63859 .39075 m
.64263 .38284 L
s
.703 .025 .256 r
.29557 .60324 m .2781 .58852 L .28923 .56211 L p F P
0 g
s
.725 .026 .181 r
.2781 .58852 m .29557 .60324 L .28754 .63019 L p F P
0 g
s
.29557 .60324 m
.31512 .61671 L
s
.29557 .60324 m
.30584 .5764 L
s
.037 .037 .747 r
.55624 .35103 m .55529 .35311 L .52632 .34495 L closepath p F P
0 g
s
.55529 .35311 m
.58382 .36353 L
s
.55403 .3551 m
.55529 .35311 L
s
.256 .703 .026 r
.7384 .67742 m .76025 .66434 L .76337 .69077 L p F P
0 g
s
.256 .703 .026 r
.76337 .69077 m .7412 .70381 L .7384 .67742 L p F P
0 g
s
.73351 .65046 m
.7384 .67742 L
s
.71475 .68908 m
.7384 .67742 L
s
.181 .724 .052 r
.71722 .71542 m .7412 .70381 L .74185 .72938 L p F P
0 g
s
.181 .724 .052 r
.74185 .72938 m .71779 .74084 L .71722 .71542 L p F P
0 g
s
.71475 .68908 m
.71722 .71542 L
s
.69166 .72554 m
.71722 .71542 L
s
.402 .115 .621 r
.36038 .4199 m .3551 .4084 L .38106 .39251 L p F P
0 g
s
.462 .132 .574 r
.3551 .4084 m .36038 .4199 L .33691 .43917 L p F P
0 g
s
.36038 .4199 m
.38541 .40236 L
s
.36038 .4199 m
.36737 .43092 L
s
.05 .014 .747 r
.4968 .35204 m .49602 .34992 L .52632 .34495 L closepath p F P
0 g
s
.46772 .36142 m
.4968 .35204 L
s
.4968 .35204 m
.49791 .35408 L
s
.121 .048 .738 r
.49557 .34777 m .49602 .34992 L .4661 .35724 L p F P
0 g
s
.121 .048 .738 r
.4661 .35724 m .46513 .35297 L .49557 .34777 L p F P
0 g
s
.192 .076 .72 r
.46513 .35297 m .4661 .35724 L .4368 .36683 L p F P
0 g
s
.4661 .35724 m
.46772 .36142 L
s
.041 .033 .747 r
.55687 .34889 m .55624 .35103 L .52632 .34495 L closepath p F P
0 g
s
.1 .083 .738 r
.55624 .35103 m .55687 .34889 L .58708 .35519 L p F P
0 g
s
.55529 .35311 m
.55624 .35103 L
s
.55624 .35103 m
.58577 .35942 L
s
.192 .076 .72 r
.4368 .36683 m .43527 .3605 L .46513 .35297 L p F P
0 g
s
.26 .104 .695 r
.43527 .3605 m .4368 .36683 L .40838 .37862 L p F P
0 g
s
.4368 .36683 m
.4661 .35724 L
s
.4368 .36683 m
.43931 .373 L
s
.321 .268 .621 r
.6695 .39767 m .67311 .38766 L .69944 .40272 L p F P
0 g
s
.321 .268 .621 r
.69944 .40272 m .69501 .41442 L .6695 .39767 L p F P
0 g
s
.64263 .38284 m
.6695 .39767 L
s
.66438 .40732 m
.6695 .39767 L
s
.05 .717 .206 r
.63632 .78985 m .66419 .78311 L .66176 .80537 L p F P
0 g
s
.05 .717 .206 r
.66176 .80537 m .63439 .81189 L .63632 .78985 L p F P
0 g
s
.63632 .78985 m
.63711 .76618 L
s
.60759 .79503 m
.63632 .78985 L
s
.325 .666 .104 r
.75481 .63746 m .77411 .62313 L .78006 .6499 L p F P
0 g
s
.325 .666 .104 r
.78006 .6499 m .76025 .66434 L .75481 .63746 L p F P
0 g
s
.74716 .61039 m
.75481 .63746 L
s
.73351 .65046 m
.75481 .63746 L
s
.049 .019 .747 r
.49602 .34992 m .49557 .34777 L .52632 .34495 L closepath p F P
0 g
s
.4661 .35724 m
.49602 .34992 L
s
.49602 .34992 m
.4968 .35204 L
s
.108 .072 .738 r
.58773 .35089 m .58708 .35519 L .55687 .34889 L p F P
0 g
s
.171 .115 .72 r
.58708 .35519 m .58773 .35089 L .61776 .35742 L p F P
0 g
s
.171 .115 .72 r
.61776 .35742 m .61669 .3638 L .58708 .35519 L p F P
0 g
s
.58577 .35942 m
.58708 .35519 L
s
.102 .73 .13 r
.69215 .75082 m .71779 .74084 L .7164 .76509 L p F P
0 g
s
.102 .73 .13 r
.7164 .76509 m .69096 .77485 L .69215 .75082 L p F P
0 g
s
.69166 .72554 m
.69215 .75082 L
s
.66518 .75928 m
.69215 .75082 L
s
.26 .104 .695 r
.40838 .37862 m .40622 .37032 L .43527 .3605 L p F P
0 g
s
.326 .131 .661 r
.40622 .37032 m .40838 .37862 L .38106 .39251 L p F P
0 g
s
.40838 .37862 m
.4368 .36683 L
s
.40838 .37862 m
.41179 .38669 L
s
.044 .028 .747 r
.55716 .34672 m .55687 .34889 L .52632 .34495 L closepath p F P
0 g
s
.108 .072 .738 r
.55687 .34889 m .55716 .34672 L .58773 .35089 L p F P
0 g
s
.55624 .35103 m
.55687 .34889 L
s
.55687 .34889 m
.58708 .35519 L
s
.414 .53 .328 r
.75675 .52922 m .76913 .51402 L .78388 .53895 L p F P
0 g
s
.414 .53 .328 r
.78388 .53895 m .77062 .55484 L .75675 .52922 L p F P
0 g
s
.74069 .50437 m
.75675 .52922 L
s
.74217 .54343 m
.75675 .52922 L
s
.581 .102 .461 r
.30577 .49704 m .29552 .48227 L .31523 .46001 L p F P
0 g
s
.625 .11 .397 r
.29552 .48227 m .30577 .49704 L .28917 .52144 L p F P
0 g
s
.30577 .49704 m
.32445 .47369 L
s
.30577 .49704 m
.31816 .51095 L
s
.41 .424 .461 r
.73287 .4672 m .74109 .45319 L .76122 .47491 L p F P
0 g
s
.41 .424 .461 r
.76122 .47491 m .75207 .49004 L .73287 .4672 L p F P
0 g
s
.71173 .4457 m
.73287 .4672 L
s
.7226 .4805 m
.73287 .4672 L
s
.233 .156 .695 r
.61669 .3638 m .61776 .35742 L .64699 .36627 L p F P
0 g
s
.233 .156 .695 r
.64699 .36627 m .64545 .37465 L .61669 .3638 L p F P
0 g
s
.58708 .35519 m
.61669 .3638 L
s
.61465 .37006 m
.61669 .3638 L
s
.047 .024 .747 r
.49557 .34777 m .49545 .34559 L .52632 .34495 L closepath p F P
0 g
s
.115 .06 .738 r
.49545 .34559 m .49557 .34777 L .46513 .35297 L p F P
0 g
s
.49557 .34777 m
.49602 .34992 L
s
.462 .132 .574 r
.33691 .43917 m .33071 .42616 L .3551 .4084 L p F P
0 g
s
.518 .148 .52 r
.33071 .42616 m .33691 .43917 L .31523 .46001 L p F P
0 g
s
.33691 .43917 m
.36038 .4199 L
s
.33691 .43917 m
.34505 .4516 L
s
.671 .047 .328 r
.28923 .56211 m .27483 .54672 L .28917 .52144 L p F P
0 g
s
.701 .049 .256 r
.27483 .54672 m .28923 .56211 L .2781 .58852 L p F P
0 g
s
.28923 .56211 m
.30584 .5764 L
s
.28923 .56211 m
.30263 .53618 L
s
.115 .06 .738 r
.46513 .35297 m .46483 .34864 L .49545 .34559 L p F P
0 g
s
.182 .096 .72 r
.46483 .34864 m .46513 .35297 L .43527 .3605 L p F P
0 g
s
.46513 .35297 m
.49557 .34777 L
s
.46513 .35297 m
.4661 .35724 L
s
.052 .003 .747 r
.55193 .33429 m .5536 .33618 L .52632 .34495 L closepath p F P
0 g
s
.052 .008 .747 r
.54997 .33254 m .55193 .33429 L .52632 .34495 L closepath p F P
0 g
s
.05 .014 .747 r
.54776 .33093 m .54997 .33254 L .52632 .34495 L closepath p F P
0 g
s
.049 .019 .747 r
.5453 .32949 m .54776 .33093 L .52632 .34495 L closepath p F P
0 g
s
.047 .024 .747 r
.54262 .32823 m .5453 .32949 L .52632 .34495 L closepath p F P
0 g
s
.044 .028 .747 r
.53976 .32717 m .54262 .32823 L .52632 .34495 L closepath p F P
0 g
s
.041 .033 .747 r
.53676 .32631 m .53976 .32717 L .52632 .34495 L closepath p F P
0 g
s
.037 .037 .747 r
.53363 .32568 m .53676 .32631 L .52632 .34495 L closepath p F P
0 g
s
.033 .041 .747 r
.53042 .32527 m .53363 .32568 L .52632 .34495 L closepath p F P
0 g
s
.028 .044 .747 r
.52716 .32509 m .53042 .32527 L .52632 .34495 L closepath p F P
0 g
s
.024 .047 .747 r
.5239 .32515 m .52716 .32509 L .52632 .34495 L closepath p F P
0 g
s
.019 .049 .747 r
.52066 .32544 m .5239 .32515 L .52632 .34495 L closepath p F P
0 g
s
.014 .05 .747 r
.51749 .32596 m .52066 .32544 L .52632 .34495 L closepath p F P
0 g
s
.008 .052 .747 r
.51441 .3267 m .51749 .32596 L .52632 .34495 L closepath p F P
0 g
s
.003 .052 .747 r
.51147 .32765 m .51441 .3267 L .52632 .34495 L closepath p F P
0 g
s
.003 .052 .747 r
.5087 .32881 m .51147 .32765 L .52632 .34495 L closepath p F P
0 g
s
.008 .052 .747 r
.50612 .33016 m .5087 .32881 L .52632 .34495 L closepath p F P
0 g
s
.014 .05 .747 r
.50378 .33169 m .50612 .33016 L .52632 .34495 L closepath p F P
0 g
s
.019 .049 .747 r
.50168 .33337 m .50378 .33169 L .52632 .34495 L closepath p F P
0 g
s
.024 .047 .747 r
.49986 .33519 m .50168 .33337 L .52632 .34495 L closepath p F P
0 g
s
.028 .044 .747 r
.49834 .33712 m .49986 .33519 L .52632 .34495 L closepath p F P
0 g
s
.033 .041 .747 r
.49712 .33915 m .49834 .33712 L .52632 .34495 L closepath p F P
0 g
s
.037 .037 .747 r
.49623 .34126 m .49712 .33915 L .52632 .34495 L closepath p F P
0 g
s
.041 .033 .747 r
.49567 .34341 m .49623 .34126 L .52632 .34495 L closepath p F P
0 g
s
.044 .028 .747 r
.49545 .34559 m .49567 .34341 L .52632 .34495 L closepath p F P
0 g
s
.047 .024 .747 r
.55712 .34454 m .55716 .34672 L .52632 .34495 L closepath p F P
0 g
s
.049 .019 .747 r
.55673 .34237 m .55712 .34454 L .52632 .34495 L closepath p F P
0 g
s
.05 .014 .747 r
.55601 .34024 m .55673 .34237 L .52632 .34495 L closepath p F P
0 g
s
.052 .008 .747 r
.55496 .33817 m .55601 .34024 L .52632 .34495 L closepath p F P
0 g
s
.052 .003 .747 r
.5536 .33618 m .55496 .33817 L .52632 .34495 L closepath p F P
0 g
s
.52632 .34495 m
.55687 .34889 L
s
.49602 .34992 m
.52632 .34495 L
s
.52632 .34495 m
.55624 .35103 L
s
.4968 .35204 m
.52632 .34495 L
s
.49791 .35408 m
.52632 .34495 L
s
.49932 .35603 m
.52632 .34495 L
s
.50102 .35787 m
.52632 .34495 L
s
.50299 .35958 m
.52632 .34495 L
s
.50521 .36114 m
.52632 .34495 L
s
.50766 .36253 m
.52632 .34495 L
s
.51031 .36375 m
.52632 .34495 L
s
.51313 .36477 m
.52632 .34495 L
s
.51609 .36559 m
.52632 .34495 L
s
.51916 .3662 m
.52632 .34495 L
s
.5223 .36659 m
.52632 .34495 L
s
.52549 .36676 m
.52632 .34495 L
s
.52632 .34495 m
.52868 .36671 L
s
.52632 .34495 m
.53185 .36643 L
s
.52632 .34495 m
.53496 .36593 L
s
.52632 .34495 m
.53798 .36522 L
s
.52632 .34495 m
.54088 .3643 L
s
.52632 .34495 m
.54362 .36319 L
s
.52632 .34495 m
.54617 .36188 L
s
.52632 .34495 m
.54852 .36041 L
s
.52632 .34495 m
.55062 .35877 L
s
.52632 .34495 m
.55247 .357 L
s
.52632 .34495 m
.55403 .3551 L
s
.52632 .34495 m
.55529 .35311 L
s
.49557 .34777 m
.52632 .34495 L
s
.52632 .34495 m
.52632 .34495 L
s
.115 .06 .738 r
.55716 .34672 m .55712 .34454 L .58771 .34655 L p F P
0 g
s
.115 .06 .738 r
.58771 .34655 m .58773 .35089 L .55716 .34672 L p F P
0 g
s
.55687 .34889 m
.55716 .34672 L
s
.52632 .34495 m
.55716 .34672 L
s
.369 .309 .574 r
.69501 .41442 m .69944 .40272 L .72418 .41974 L p F P
0 g
s
.369 .309 .574 r
.72418 .41974 m .71895 .43298 L .69501 .41442 L p F P
0 g
s
.6695 .39767 m
.69501 .41442 L
s
.68883 .42568 m
.69501 .41442 L
s
.61 .381 .206 r
.3744 .77901 m .40173 .78655 L .40391 .80869 L p F P
0 g
s
.567 .443 .206 r
.43172 .81449 m .40391 .80869 L .40173 .78655 L p F P
0 g
s
.40083 .7628 m
.40173 .78655 L
s
.40173 .78655 m
.43004 .79254 L
s
.108 .072 .738 r
.49567 .34341 m .49545 .34559 L .46483 .34864 L p F P
0 g
s
.49545 .34559 m
.52632 .34495 L
s
.49545 .34559 m
.49557 .34777 L
s
.326 .131 .661 r
.38106 .39251 m .37825 .38236 L .40622 .37032 L p F P
0 g
s
.388 .156 .621 r
.37825 .38236 m .38106 .39251 L .3551 .4084 L p F P
0 g
s
.38106 .39251 m
.40838 .37862 L
s
.38106 .39251 m
.38541 .40236 L
s
.725 .181 .026 r
.32275 .70957 m .29968 .69721 L .30265 .6708 L p F P
0 g
s
.724 .181 .052 r
.29968 .69721 m .32275 .70957 L .32214 .73507 L p F P
0 g
s
.701 .255 .052 r
.34699 .74583 m .32214 .73507 L .32275 .70957 L p F P
0 g
s
.32275 .70957 m
.34752 .72048 L
s
.32275 .70957 m
.3254 .68321 L
s
.388 .575 .281 r
.48933 .8215 m .51868 .82268 L .5189 .84239 L p F P
0 g
s
.326 .612 .281 r
.51868 .82268 m .54809 .82231 L .54747 .84203 L p F P
0 g
s
.326 .612 .281 r
.54747 .84203 m .5189 .84239 L .51868 .82268 L p F P
0 g
s
.51855 .80101 m
.51868 .82268 L
s
.385 .616 .181 r
.76574 .59631 m .78214 .58102 L .79118 .60756 L p F P
0 g
s
.385 .616 .181 r
.79118 .60756 m .77411 .62313 L .76574 .59631 L p F P
0 g
s
.75505 .56967 m
.76574 .59631 L
s
.74716 .61039 m
.76574 .59631 L
s
.292 .196 .661 r
.64545 .37465 m .64699 .36627 L .67516 .3774 L p F P
0 g
s
.292 .196 .661 r
.67516 .3774 m .67311 .38766 L .64545 .37465 L p F P
0 g
s
.61669 .3638 m
.64545 .37465 L
s
.64263 .38284 m
.64545 .37465 L
s
.182 .096 .72 r
.58773 .35089 m .58771 .34655 L .61783 .35097 L p F P
0 g
s
.182 .096 .72 r
.61783 .35097 m .61776 .35742 L .58773 .35089 L p F P
0 g
s
.55716 .34672 m
.58773 .35089 L
s
.58708 .35519 m
.58773 .35089 L
s
.26 .643 .281 r
.54809 .82231 m .57733 .82038 L .57588 .84018 L p F P
0 g
s
.26 .643 .281 r
.57588 .84018 m .54747 .84203 L .54809 .82231 L p F P
0 g
s
.54809 .82231 m
.54847 .80062 L
s
.51868 .82268 m
.54809 .82231 L
s
.734 .103 .104 r
.30265 .6708 m .28183 .65701 L .28754 .63019 L p F P
0 g
s
.74 .104 .026 r
.28183 .65701 m .30265 .6708 L .29968 .69721 L p F P
0 g
s
.30265 .6708 m
.3254 .68321 L
s
.30265 .6708 m
.30783 .64389 L
s
.182 .096 .72 r
.43527 .3605 m .43471 .35408 L .46483 .34864 L p F P
0 g
s
.248 .131 .695 r
.43471 .35408 m .43527 .3605 L .40622 .37032 L p F P
0 g
s
.43527 .3605 m
.46513 .35297 L
s
.43527 .3605 m
.4368 .36683 L
s
.121 .048 .738 r
.55712 .34454 m .55673 .34237 L .58701 .34222 L p F P
0 g
s
.121 .048 .738 r
.58701 .34222 m .58771 .34655 L .55712 .34454 L p F P
0 g
s
.52632 .34495 m
.55712 .34454 L
s
.55712 .34454 m
.55716 .34672 L
s
.446 .531 .281 r
.46027 .81876 m .48933 .8215 L .49038 .84126 L p F P
0 g
s
.388 .575 .281 r
.5189 .84239 m .49038 .84126 L .48933 .8215 L p F P
0 g
s
.48868 .79978 m
.48933 .8215 L
s
.48933 .8215 m
.51868 .82268 L
s
.1 .083 .738 r
.49623 .34126 m .49567 .34341 L .4652 .3443 L p F P
0 g
s
.108 .072 .738 r
.46483 .34864 m .4652 .3443 L .49567 .34341 L p F P
0 g
s
.49545 .34559 m
.49567 .34341 L
s
.49567 .34341 m
.52632 .34495 L
s
.692 .252 .13 r
.32214 .73507 m .34699 .74583 L .34828 .76997 L p F P
0 g
s
.662 .323 .13 r
.3744 .77901 m .34828 .76997 L .34699 .74583 L p F P
0 g
s
.34699 .74583 m
.3733 .75508 L
s
.34699 .74583 m
.34752 .72048 L
s
.171 .115 .72 r
.4652 .3443 m .46483 .34864 L .43471 .35408 L p F P
0 g
s
.46483 .34864 m
.46513 .35297 L
s
.46483 .34864 m
.49545 .34559 L
s
.125 .035 .738 r
.55673 .34237 m .55601 .34024 L .58564 .33796 L p F P
0 g
s
.125 .035 .738 r
.58564 .33796 m .58701 .34222 L .55673 .34237 L p F P
0 g
s
.52632 .34495 m
.55673 .34237 L
s
.55673 .34237 m
.55712 .34454 L
s
.192 .667 .281 r
.57733 .82038 m .60617 .8169 L .6039 .83685 L p F P
0 g
s
.192 .667 .281 r
.6039 .83685 m .57588 .84018 L .57733 .82038 L p F P
0 g
s
.57733 .82038 m
.57823 .79862 L
s
.54809 .82231 m
.57733 .82038 L
s
.025 .719 .206 r
.66419 .78311 m .69096 .77485 L .68805 .79737 L p F P
0 g
s
.025 .719 .206 r
.68805 .79737 m .66176 .80537 L .66419 .78311 L p F P
0 g
s
.66419 .78311 m
.66518 .75928 L
s
.63632 .78985 m
.66419 .78311 L
s
.725 .026 .181 r
.28754 .63019 m .26937 .6152 L .2781 .58852 L p F P
0 g
s
.74 .026 .104 r
.26937 .6152 m .28754 .63019 L .28183 .65701 L p F P
0 g
s
.28754 .63019 m
.30783 .64389 L
s
.28754 .63019 m
.29557 .60324 L
s
.248 .131 .695 r
.61776 .35742 m .61783 .35097 L .64721 .3578 L p F P
0 g
s
.248 .131 .695 r
.64721 .3578 m .64699 .36627 L .61776 .35742 L p F P
0 g
s
.58773 .35089 m
.61776 .35742 L
s
.61669 .3638 m
.61776 .35742 L
s
.091 .093 .738 r
.49712 .33915 m .49623 .34126 L .46625 .34 L p F P
0 g
s
.1 .083 .738 r
.4652 .3443 m .46625 .34 L .49623 .34126 L p F P
0 g
s
.49623 .34126 m
.52632 .34495 L
s
.49567 .34341 m
.49623 .34126 L
s
.441 .456 .397 r
.75207 .49004 m .76122 .47491 L .77914 .49795 L p F P
0 g
s
.441 .456 .397 r
.77914 .49795 m .76913 .51402 L .75207 .49004 L p F P
0 g
s
.73287 .4672 m
.75207 .49004 L
s
.74069 .50437 m
.75207 .49004 L
s
.413 .345 .52 r
.71895 .43298 m .72418 .41974 L .74711 .43859 L p F P
0 g
s
.413 .345 .52 r
.74711 .43859 m .74109 .45319 L .71895 .43298 L p F P
0 g
s
.69501 .41442 m
.71895 .43298 L
s
.71173 .4457 m
.71895 .43298 L
s
.248 .131 .695 r
.40622 .37032 m .40536 .36188 L .43471 .35408 L p F P
0 g
s
.311 .164 .661 r
.40536 .36188 m .40622 .37032 L .37825 .38236 L p F P
0 g
s
.40622 .37032 m
.43527 .3605 L
s
.40622 .37032 m
.40838 .37862 L
s
.518 .148 .52 r
.31523 .46001 m .30814 .44568 L .33071 .42616 L p F P
0 g
s
.567 .162 .461 r
.30814 .44568 m .31523 .46001 L .29552 .48227 L p F P
0 g
s
.31523 .46001 m
.33691 .43917 L
s
.31523 .46001 m
.32445 .47369 L
s
.192 .076 .72 r
.58771 .34655 m .58701 .34222 L .61689 .34454 L p F P
0 g
s
.192 .076 .72 r
.61689 .34454 m .61783 .35097 L .58771 .34655 L p F P
0 g
s
.55712 .34454 m
.58771 .34655 L
s
.58771 .34655 m
.58773 .35089 L
s
.347 .233 .621 r
.67311 .38766 m .67516 .3774 L .70203 .39071 L p F P
0 g
s
.347 .233 .621 r
.70203 .39071 m .69944 .40272 L .67311 .38766 L p F P
0 g
s
.64545 .37465 m
.67311 .38766 L
s
.6695 .39767 m
.67311 .38766 L
s
.388 .156 .621 r
.3551 .4084 m .35162 .39652 L .37825 .38236 L p F P
0 g
s
.446 .18 .574 r
.35162 .39652 m .3551 .4084 L .33071 .42616 L p F P
0 g
s
.3551 .4084 m
.38106 .39251 L
s
.3551 .4084 m
.36038 .4199 L
s
.128 .022 .738 r
.55601 .34024 m .55496 .33817 L .58361 .33381 L p F P
0 g
s
.128 .022 .738 r
.58361 .33381 m .58564 .33796 L .55601 .34024 L p F P
0 g
s
.52632 .34495 m
.55601 .34024 L
s
.55601 .34024 m
.55673 .34237 L
s
.499 .482 .281 r
.43172 .81449 m .46027 .81876 L .46215 .83864 L p F P
0 g
s
.446 .531 .281 r
.49038 .84126 m .46215 .83864 L .46027 .81876 L p F P
0 g
s
.4591 .79696 m
.46027 .81876 L
s
.46027 .81876 m
.48933 .8215 L
s
.625 .11 .397 r
.28917 .52144 m .278 .50578 L .29552 .48227 L p F P
0 g
s
.662 .116 .328 r
.278 .50578 m .28917 .52144 L .27483 .54672 L p F P
0 g
s
.28917 .52144 m
.30263 .53618 L
s
.28917 .52144 m
.30577 .49704 L
s
.081 .102 .738 r
.49834 .33712 m .49712 .33915 L .46796 .33579 L p F P
0 g
s
.091 .093 .738 r
.46625 .34 m .46796 .33579 L .49712 .33915 L p F P
0 g
s
.49712 .33915 m
.52632 .34495 L
s
.49623 .34126 m
.49712 .33915 L
s
.433 .554 .256 r
.77062 .55484 m .78388 .53895 L .79615 .56464 L p F P
0 g
s
.433 .554 .256 r
.79615 .56464 m .78214 .58102 L .77062 .55484 L p F P
0 g
s
.75675 .52922 m
.77062 .55484 L
s
.75505 .56967 m
.77062 .55484 L
s
.159 .132 .72 r
.46625 .34 m .4652 .3443 L .43517 .34763 L p F P
0 g
s
.171 .115 .72 r
.43471 .35408 m .43517 .34763 L .4652 .3443 L p F P
0 g
s
.4652 .3443 m
.49567 .34341 L
s
.46483 .34864 m
.4652 .3443 L
s
.255 .701 .052 r
.7412 .70381 m .76337 .69077 L .76409 .71653 L p F P
0 g
s
.255 .701 .052 r
.76409 .71653 m .74185 .72938 L .7412 .70381 L p F P
0 g
s
.7384 .67742 m
.7412 .70381 L
s
.71722 .71542 m
.7412 .70381 L
s
.13 .008 .738 r
.55496 .33817 m .5536 .33618 L .58093 .32982 L p F P
0 g
s
.13 .008 .738 r
.58093 .32982 m .58361 .33381 L .55496 .33817 L p F P
0 g
s
.52632 .34495 m
.55496 .33817 L
s
.55496 .33817 m
.55601 .34024 L
s
.233 .156 .695 r
.43517 .34763 m .43471 .35408 L .40536 .36188 L p F P
0 g
s
.43471 .35408 m
.43527 .3605 L
s
.43471 .35408 m
.46483 .34864 L
s
.121 .683 .281 r
.60617 .8169 m .63439 .81189 L .63131 .83205 L p F P
0 g
s
.121 .683 .281 r
.63131 .83205 m .6039 .83685 L .60617 .8169 L p F P
0 g
s
.60617 .8169 m
.60759 .79503 L
s
.57733 .82038 m
.60617 .8169 L
s
.07 .11 .738 r
.49986 .33519 m .49834 .33712 L .47033 .33172 L p F P
0 g
s
.081 .102 .738 r
.46796 .33579 m .47033 .33172 L .49834 .33712 L p F P
0 g
s
.49834 .33712 m
.52632 .34495 L
s
.49712 .33915 m
.49834 .33712 L
s
.328 .672 .026 r
.76025 .66434 m .78006 .6499 L .78347 .67639 L p F P
0 g
s
.328 .672 .026 r
.78347 .67639 m .76337 .69077 L .76025 .66434 L p F P
0 g
s
.75481 .63746 m
.76025 .66434 L
s
.7384 .67742 m
.76025 .66434 L
s
.647 .315 .206 r
.34828 .76997 m .3744 .77901 L .37708 .8014 L p F P
0 g
s
.61 .381 .206 r
.40391 .80869 m .37708 .8014 L .3744 .77901 L p F P
0 g
s
.3744 .77901 m
.40173 .78655 L
s
.3733 .75508 m
.3744 .77901 L
s
.311 .164 .661 r
.64699 .36627 m .64721 .3578 L .6756 .36699 L p F P
0 g
s
.311 .164 .661 r
.6756 .36699 m .67516 .3774 L .64699 .36627 L p F P
0 g
s
.61776 .35742 m
.64699 .36627 L
s
.64545 .37465 m
.64699 .36627 L
s
.178 .715 .13 r
.71779 .74084 m .74185 .72938 L .74028 .75391 L p F P
0 g
s
.178 .715 .13 r
.74028 .75391 m .7164 .76509 L .71779 .74084 L p F P
0 g
s
.71722 .71542 m
.71779 .74084 L
s
.69215 .75082 m
.71779 .74084 L
s
.701 .049 .256 r
.2781 .58852 m .26291 .57265 L .27483 .54672 L p F P
0 g
s
.724 .05 .181 r
.26291 .57265 m .2781 .58852 L .26937 .6152 L p F P
0 g
s
.2781 .58852 m
.29557 .60324 L
s
.2781 .58852 m
.28923 .56211 L
s
.198 .056 .72 r
.58701 .34222 m .58564 .33796 L .61494 .33818 L p F P
0 g
s
.198 .056 .72 r
.61494 .33818 m .61689 .34454 L .58701 .34222 L p F P
0 g
s
.55673 .34237 m
.58701 .34222 L
s
.58701 .34222 m
.58771 .34655 L
s
.13 .005 .738 r
.5536 .33618 m .55193 .33429 L .57764 .32604 L p F P
0 g
s
.13 .005 .738 r
.57764 .32604 m .58093 .32982 L .5536 .33618 L p F P
0 g
s
.52632 .34495 m
.5536 .33618 L
s
.5536 .33618 m
.55496 .33817 L
s
.058 .116 .738 r
.50168 .33337 m .49986 .33519 L .47333 .32783 L p F P
0 g
s
.07 .11 .738 r
.47033 .33172 m .47333 .32783 L .49986 .33519 L p F P
0 g
s
.49986 .33519 m
.52632 .34495 L
s
.49834 .33712 m
.49986 .33519 L
s
.311 .164 .661 r
.37825 .38236 m .37704 .37201 L .40536 .36188 L p F P
0 g
s
.37 .196 .621 r
.37704 .37201 m .37825 .38236 L .35162 .39652 L p F P
0 g
s
.37825 .38236 m
.38106 .39251 L
s
.37825 .38236 m
.40622 .37032 L
s
.26 .104 .695 r
.61783 .35097 m .61689 .34454 L .6461 .34932 L p F P
0 g
s
.26 .104 .695 r
.6461 .34932 m .64721 .3578 L .61783 .35097 L p F P
0 g
s
.58771 .34655 m
.61783 .35097 L
s
.61776 .35742 m
.61783 .35097 L
s
.399 .268 .574 r
.69944 .40272 m .70203 .39071 L .72733 .40612 L p F P
0 g
s
.399 .268 .574 r
.72733 .40612 m .72418 .41974 L .69944 .40272 L p F P
0 g
s
.67311 .38766 m
.69944 .40272 L
s
.69501 .41442 m
.69944 .40272 L
s
.547 .427 .281 r
.40391 .80869 m .43172 .81449 L .43442 .83454 L p F P
0 g
s
.499 .482 .281 r
.46215 .83864 m .43442 .83454 L .43172 .81449 L p F P
0 g
s
.43004 .79254 m
.43172 .81449 L
s
.43172 .81449 m
.46027 .81876 L
s
.129 .019 .738 r
.55193 .33429 m .54997 .33254 L .57377 .3225 L p F P
0 g
s
.129 .019 .738 r
.57377 .3225 m .57764 .32604 L .55193 .33429 L p F P
0 g
s
.52632 .34495 m
.55193 .33429 L
s
.55193 .33429 m
.5536 .33618 L
s
.144 .148 .72 r
.46796 .33579 m .46625 .34 L .43663 .34122 L p F P
0 g
s
.159 .132 .72 r
.43517 .34763 m .43663 .34122 L .46625 .34 L p F P
0 g
s
.46625 .34 m
.49623 .34126 L
s
.4652 .3443 m
.46625 .34 L
s
.446 .18 .574 r
.33071 .42616 m .32655 .41271 L .35162 .39652 L p F P
0 g
s
.499 .201 .52 r
.32655 .41271 m .33071 .42616 L .30814 .44568 L p F P
0 g
s
.33071 .42616 m
.3551 .4084 L
s
.33071 .42616 m
.33691 .43917 L
s
.045 .122 .738 r
.50378 .33169 m .50168 .33337 L .47693 .32417 L p F P
0 g
s
.058 .116 .738 r
.47333 .32783 m .47693 .32417 L .50168 .33337 L p F P
0 g
s
.50168 .33337 m
.52632 .34495 L
s
.49986 .33519 m
.50168 .33337 L
s
.452 .379 .461 r
.74109 .45319 m .74711 .43859 L .76799 .45911 L p F P
0 g
s
.452 .379 .461 r
.76799 .45911 m .76122 .47491 L .74109 .45319 L p F P
0 g
s
.71895 .43298 m
.74109 .45319 L
s
.73287 .4672 m
.74109 .45319 L
s
.393 .628 .104 r
.77411 .62313 m .79118 .60756 L .7976 .63422 L p F P
0 g
s
.393 .628 .104 r
.7976 .63422 m .78006 .6499 L .77411 .62313 L p F P
0 g
s
.76574 .59631 m
.77411 .62313 L
s
.75481 .63746 m
.77411 .62313 L
s
.126 .032 .738 r
.54997 .33254 m .54776 .33093 L .56935 .31926 L p F P
0 g
s
.126 .032 .738 r
.56935 .31926 m .57377 .3225 L .54997 .33254 L p F P
0 g
s
.52632 .34495 m
.54997 .33254 L
s
.54997 .33254 m
.55193 .33429 L
s
.567 .162 .461 r
.29552 .48227 m .28759 .46678 L .30814 .44568 L p F P
0 g
s
.61 .174 .397 r
.28759 .46678 m .29552 .48227 L .278 .50578 L p F P
0 g
s
.29552 .48227 m
.30577 .49704 L
s
.29552 .48227 m
.31523 .46001 L
s
.233 .156 .695 r
.40536 .36188 m .40583 .35339 L .43517 .34763 L p F P
0 g
s
.292 .196 .661 r
.40583 .35339 m .40536 .36188 L .37704 .37201 L p F P
0 g
s
.40536 .36188 m
.40622 .37032 L
s
.40536 .36188 m
.43471 .35408 L
s
.203 .035 .72 r
.58564 .33796 m .58361 .33381 L .612 .33197 L p F P
0 g
s
.203 .035 .72 r
.612 .33197 m .61494 .33818 L .58564 .33796 L p F P
0 g
s
.55601 .34024 m
.58564 .33796 L
s
.58564 .33796 m
.58701 .34222 L
s
.032 .126 .738 r
.50612 .33016 m .50378 .33169 L .48109 .32078 L p F P
0 g
s
.045 .122 .738 r
.47693 .32417 m .48109 .32078 L .50378 .33169 L p F P
0 g
s
.50378 .33169 m
.52632 .34495 L
s
.50168 .33337 m
.50378 .33169 L
s
.467 .483 .328 r
.76913 .51402 m .77914 .49795 L .79465 .52215 L p F P
0 g
s
.467 .483 .328 r
.79465 .52215 m .78388 .53895 L .76913 .51402 L p F P
0 g
s
.75207 .49004 m
.76913 .51402 L
s
.75675 .52922 m
.76913 .51402 L
s
.215 .18 .695 r
.43663 .34122 m .43517 .34763 L .40583 .35339 L p F P
0 g
s
.43517 .34763 m
.4652 .3443 L
s
.43471 .35408 m
.43517 .34763 L
s
.1 .712 .206 r
.69096 .77485 m .7164 .76509 L .71302 .78794 L p F P
0 g
s
.1 .712 .206 r
.71302 .78794 m .68805 .79737 L .69096 .77485 L p F P
0 g
s
.69096 .77485 m
.69215 .75082 L
s
.66419 .78311 m
.69096 .77485 L
s
.122 .045 .738 r
.54776 .33093 m .5453 .32949 L .56445 .31634 L p F P
0 g
s
.122 .045 .738 r
.56445 .31634 m .56935 .31926 L .54776 .33093 L p F P
0 g
s
.52632 .34495 m
.54776 .33093 L
s
.54776 .33093 m
.54997 .33254 L
s
.049 .692 .281 r
.63439 .81189 m .66176 .80537 L .65788 .8258 L p F P
0 g
s
.049 .692 .281 r
.65788 .8258 m .63131 .83205 L .63439 .81189 L p F P
0 g
s
.63439 .81189 m
.63632 .78985 L
s
.60617 .8169 m
.63439 .81189 L
s
.019 .129 .738 r
.5087 .32881 m .50612 .33016 L .48577 .3177 L p F P
0 g
s
.032 .126 .738 r
.48109 .32078 m .48577 .3177 L .50612 .33016 L p F P
0 g
s
.50612 .33016 m
.52632 .34495 L
s
.50378 .33169 m
.50612 .33016 L
s
.74 .104 .026 r
.29968 .69721 m .27856 .68347 L .28183 .65701 L p F P
0 g
s
.739 .104 .052 r
.27856 .68347 m .29968 .69721 L .299 .72288 L p F P
0 g
s
.724 .181 .052 r
.32214 .73507 m .299 .72288 L .29968 .69721 L p F P
0 g
s
.29968 .69721 m
.32275 .70957 L
s
.29968 .69721 m
.30265 .6708 L
s
.37 .196 .621 r
.67516 .3774 m .6756 .36699 L .70272 .3785 L p F P
0 g
s
.37 .196 .621 r
.70272 .3785 m .70203 .39071 L .67516 .3774 L p F P
0 g
s
.64699 .36627 m
.67516 .3774 L
s
.67311 .38766 m
.67516 .3774 L
s
.128 .162 .72 r
.47033 .33172 m .46796 .33579 L .43909 .33493 L p F P
0 g
s
.144 .148 .72 r
.43663 .34122 m .43909 .33493 L .46796 .33579 L p F P
0 g
s
.46796 .33579 m
.49712 .33915 L
s
.46625 .34 m
.46796 .33579 L
s
.662 .116 .328 r
.27483 .54672 m .26283 .53034 L .278 .50578 L p F P
0 g
s
.692 .122 .256 r
.26283 .53034 m .27483 .54672 L .26291 .57265 L p F P
0 g
s
.27483 .54672 m
.28923 .56211 L
s
.27483 .54672 m
.28917 .52144 L
s
.116 .058 .738 r
.5453 .32949 m .54262 .32823 L .5591 .31379 L p F P
0 g
s
.116 .058 .738 r
.5591 .31379 m .56445 .31634 L .5453 .32949 L p F P
0 g
s
.52632 .34495 m
.5453 .32949 L
s
.5453 .32949 m
.54776 .33093 L
s
.715 .178 .13 r
.299 .72288 m .32214 .73507 L .32363 .75946 L p F P
0 g
s
.692 .252 .13 r
.34828 .76997 m .32363 .75946 L .32214 .73507 L p F P
0 g
s
.32214 .73507 m
.34699 .74583 L
s
.32214 .73507 m
.32275 .70957 L
s
.005 .13 .738 r
.51147 .32765 m .5087 .32881 L .49091 .31497 L p F P
0 g
s
.019 .129 .738 r
.48577 .3177 m .49091 .31497 L .5087 .32881 L p F P
0 g
s
.5087 .32881 m
.52632 .34495 L
s
.50612 .33016 m
.5087 .32881 L
s
.27 .076 .695 r
.61689 .34454 m .61494 .33818 L .64365 .34092 L p F P
0 g
s
.27 .076 .695 r
.64365 .34092 m .6461 .34932 L .61689 .34454 L p F P
0 g
s
.58701 .34222 m
.61689 .34454 L
s
.61689 .34454 m
.61783 .35097 L
s
.11 .07 .738 r
.54262 .32823 m .53976 .32717 L .55337 .31164 L p F P
0 g
s
.11 .07 .738 r
.55337 .31164 m .5591 .31379 L .54262 .32823 L p F P
0 g
s
.52632 .34495 m
.54262 .32823 L
s
.54262 .32823 m
.5453 .32949 L
s
.74 .026 .104 r
.28183 .65701 m .26317 .64191 L .26937 .6152 L p F P
0 g
s
.747 .026 .026 r
.26317 .64191 m .28183 .65701 L .27856 .68347 L p F P
0 g
s
.28183 .65701 m
.30265 .6708 L
s
.28183 .65701 m
.28754 .63019 L
s
.37 .196 .621 r
.35162 .39652 m .35001 .38439 L .37704 .37201 L p F P
0 g
s
.425 .225 .574 r
.35001 .38439 m .35162 .39652 L .32655 .41271 L p F P
0 g
s
.35162 .39652 m
.3551 .4084 L
s
.35162 .39652 m
.37825 .38236 L
s
.326 .131 .661 r
.64721 .3578 m .6461 .34932 L .67438 .35656 L p F P
0 g
s
.326 .131 .661 r
.67438 .35656 m .6756 .36699 L .64721 .3578 L p F P
0 g
s
.61783 .35097 m
.64721 .3578 L
s
.64699 .36627 m
.64721 .3578 L
s
.206 .014 .72 r
.58361 .33381 m .58093 .32982 L .60809 .326 L p F P
0 g
s
.206 .014 .72 r
.60809 .326 m .612 .33197 L .58361 .33381 L p F P
0 g
s
.55496 .33817 m
.58361 .33381 L
s
.58361 .33381 m
.58564 .33796 L
s
.008 .13 .738 r
.51441 .3267 m .51147 .32765 L .49647 .31263 L p F P
0 g
s
.005 .13 .738 r
.49091 .31497 m .49647 .31263 L .51147 .32765 L p F P
0 g
s
.51147 .32765 m
.52632 .34495 L
s
.5087 .32881 m
.51147 .32765 L
s
.447 .572 .181 r
.78214 .58102 m .79615 .56464 L .80578 .59087 L p F P
0 g
s
.447 .572 .181 r
.80578 .59087 m .79118 .60756 L .78214 .58102 L p F P
0 g
s
.77062 .55484 m
.78214 .58102 L
s
.76574 .59631 m
.78214 .58102 L
s
.102 .081 .738 r
.53976 .32717 m .53676 .32631 L .54733 .30991 L p F P
0 g
s
.102 .081 .738 r
.54733 .30991 m .55337 .31164 L .53976 .32717 L p F P
0 g
s
.52632 .34495 m
.53976 .32717 L
s
.53976 .32717 m
.54262 .32823 L
s
.447 .3 .52 r
.72418 .41974 m .72733 .40612 L .75081 .42353 L p F P
0 g
s
.447 .3 .52 r
.75081 .42353 m .74711 .43859 L .72418 .41974 L p F P
0 g
s
.69944 .40272 m
.72418 .41974 L
s
.71895 .43298 m
.72418 .41974 L
s
.022 .128 .738 r
.51749 .32596 m .51441 .3267 L .50237 .31069 L p F P
0 g
s
.008 .13 .738 r
.49647 .31263 m .50237 .31069 L .51441 .3267 L p F P
0 g
s
.51441 .3267 m
.52632 .34495 L
s
.51147 .32765 m
.51441 .3267 L
s
.588 .367 .281 r
.37708 .8014 m .40391 .80869 L .40741 .82899 L p F P
0 g
s
.547 .427 .281 r
.43442 .83454 m .40741 .82899 L .40391 .80869 L p F P
0 g
s
.40173 .78655 m
.40391 .80869 L
s
.40391 .80869 m
.43172 .81449 L
s
.093 .091 .738 r
.53676 .32631 m .53363 .32568 L .54104 .30862 L p F P
0 g
s
.093 .091 .738 r
.54104 .30862 m .54733 .30991 L .53676 .32631 L p F P
0 g
s
.52632 .34495 m
.53676 .32631 L
s
.53676 .32631 m
.53976 .32717 L
s
.035 .125 .738 r
.52066 .32544 m .51749 .32596 L .50854 .30918 L p F P
0 g
s
.022 .128 .738 r
.50237 .31069 m .50854 .30918 L .51749 .32596 L p F P
0 g
s
.51749 .32596 m
.52632 .34495 L
s
.51441 .3267 m
.51749 .32596 L
s
.083 .1 .738 r
.53363 .32568 m .53042 .32527 L .53458 .30779 L p F P
0 g
s
.083 .1 .738 r
.53458 .30779 m .54104 .30862 L .53363 .32568 L p F P
0 g
s
.52632 .34495 m
.53363 .32568 L
s
.53363 .32568 m
.53676 .32631 L
s
.11 .174 .72 r
.47333 .32783 m .47033 .33172 L .44254 .32884 L p F P
0 g
s
.128 .162 .72 r
.43909 .33493 m .44254 .32884 L .47033 .33172 L p F P
0 g
s
.47033 .33172 m
.49834 .33712 L
s
.46796 .33579 m
.47033 .33172 L
s
.048 .121 .738 r
.5239 .32515 m .52066 .32544 L .51493 .30813 L p F P
0 g
s
.035 .125 .738 r
.50854 .30918 m .51493 .30813 L .52066 .32544 L p F P
0 g
s
.52066 .32544 m
.52632 .34495 L
s
.51749 .32596 m
.52066 .32544 L
s
.072 .108 .738 r
.53042 .32527 m .52716 .32509 L .52802 .30743 L p F P
0 g
s
.072 .108 .738 r
.52802 .30743 m .53458 .30779 L .53042 .32527 L p F P
0 g
s
.52632 .34495 m
.53042 .32527 L
s
.53042 .32527 m
.53363 .32568 L
s
.499 .201 .52 r
.30814 .44568 m .3033 .43082 L .32655 .41271 L p F P
0 g
s
.547 .22 .461 r
.3033 .43082 m .30814 .44568 L .28759 .46678 L p F P
0 g
s
.30814 .44568 m
.31523 .46001 L
s
.30814 .44568 m
.33071 .42616 L
s
.06 .115 .738 r
.52716 .32509 m .5239 .32515 L .52145 .30754 L p F P
0 g
s
.048 .121 .738 r
.51493 .30813 m .52145 .30754 L .5239 .32515 L p F P
0 g
s
.5239 .32515 m
.52632 .34495 L
s
.52066 .32544 m
.5239 .32515 L
s
.195 .201 .695 r
.43909 .33493 m .43663 .34122 L .40763 .34494 L p F P
0 g
s
.215 .18 .695 r
.40583 .35339 m .40763 .34494 L .43663 .34122 L p F P
0 g
s
.43663 .34122 m
.46625 .34 L
s
.43517 .34763 m
.43663 .34122 L
s
.06 .115 .738 r
.52145 .30754 m .52802 .30743 L .52716 .32509 L p F P
0 g
s
.5239 .32515 m
.52716 .32509 L
s
.52632 .34495 m
.52716 .32509 L
s
.52716 .32509 m
.53042 .32527 L
s
.676 .246 .206 r
.32363 .75946 m .34828 .76997 L .35144 .79265 L p F P
0 g
s
.647 .315 .206 r
.37708 .8014 m .35144 .79265 L .34828 .76997 L p F P
0 g
s
.34828 .76997 m
.3744 .77901 L
s
.34699 .74583 m
.34828 .76997 L
s
.292 .196 .661 r
.37704 .37201 m .37746 .36157 L .40583 .35339 L p F P
0 g
s
.347 .233 .621 r
.37746 .36157 m .37704 .37201 L .35001 .38439 L p F P
0 g
s
.37704 .37201 m
.37825 .38236 L
s
.37704 .37201 m
.40536 .36188 L
s
.486 .407 .397 r
.76122 .47491 m .76799 .45911 L .7866 .48117 L p F P
0 g
s
.486 .407 .397 r
.7866 .48117 m .77914 .49795 L .76122 .47491 L p F P
0 g
s
.74109 .45319 m
.76122 .47491 L
s
.75207 .49004 m
.76122 .47491 L
s
.724 .05 .181 r
.26937 .6152 m .25355 .59903 L .26291 .57265 L p F P
0 g
s
.739 .052 .104 r
.25355 .59903 m .26937 .6152 L .26317 .64191 L p F P
0 g
s
.26937 .6152 m
.28754 .63019 L
s
.26937 .6152 m
.2781 .58852 L
s
.206 .008 .72 r
.58093 .32982 m .57764 .32604 L .60323 .32031 L p F P
0 g
s
.206 .008 .72 r
.60323 .32031 m .60809 .326 L .58093 .32982 L p F P
0 g
s
.5536 .33618 m
.58093 .32982 L
s
.58093 .32982 m
.58361 .33381 L
s
.27 .225 .661 r
.40763 .34494 m .40583 .35339 L .37746 .36157 L p F P
0 g
s
.40536 .36188 m
.40583 .35339 L
s
.40583 .35339 m
.43517 .34763 L
s
.37 .547 .352 r
.49038 .84126 m .5189 .84239 L .5192 .85988 L p F P
0 g
s
.311 .583 .352 r
.5189 .84239 m .54747 .84203 L .54662 .85954 L p F P
0 g
s
.311 .583 .352 r
.54662 .85954 m .5192 .85988 L .5189 .84239 L p F P
0 g
s
.51868 .82268 m
.5189 .84239 L
s
.248 .612 .352 r
.54747 .84203 m .57588 .84018 L .57388 .85779 L p F P
0 g
s
.248 .612 .352 r
.57388 .85779 m .54662 .85954 L .54747 .84203 L p F P
0 g
s
.54747 .84203 m
.54809 .82231 L
s
.5189 .84239 m
.54747 .84203 L
s
.61 .174 .397 r
.278 .50578 m .26929 .48932 L .28759 .46678 L p F P
0 g
s
.647 .185 .328 r
.26929 .48932 m .278 .50578 L .26283 .53034 L p F P
0 g
s
.278 .50578 m
.28917 .52144 L
s
.278 .50578 m
.29552 .48227 L
s
.024 .693 .281 r
.66176 .80537 m .68805 .79737 L .68339 .81815 L p F P
0 g
s
.024 .693 .281 r
.68339 .81815 m .65788 .8258 L .66176 .80537 L p F P
0 g
s
.66176 .80537 m
.66419 .78311 L
s
.63439 .81189 m
.66176 .80537 L
s
.327 .671 .052 r
.76337 .69077 m .78347 .67639 L .78426 .70234 L p F P
0 g
s
.327 .671 .052 r
.78426 .70234 m .76409 .71653 L .76337 .69077 L p F P
0 g
s
.76025 .66434 m
.76337 .69077 L
s
.7412 .70381 m
.76337 .69077 L
s
.276 .048 .695 r
.61494 .33818 m .612 .33197 L .63988 .33271 L p F P
0 g
s
.276 .048 .695 r
.63988 .33271 m .64365 .34092 L .61494 .33818 L p F P
0 g
s
.58564 .33796 m
.61494 .33818 L
s
.61494 .33818 m
.61689 .34454 L
s
.425 .225 .574 r
.70203 .39071 m .70272 .3785 L .72831 .39226 L p F P
0 g
s
.425 .225 .574 r
.72831 .39226 m .72733 .40612 L .70203 .39071 L p F P
0 g
s
.67516 .3774 m
.70203 .39071 L
s
.69944 .40272 m
.70203 .39071 L
s
.252 .692 .13 r
.74185 .72938 m .76409 .71653 L .76234 .74135 L p F P
0 g
s
.252 .692 .13 r
.76234 .74135 m .74028 .75391 L .74185 .72938 L p F P
0 g
s
.7412 .70381 m
.74185 .72938 L
s
.71779 .74084 m
.74185 .72938 L
s
.091 .185 .72 r
.47693 .32417 m .47333 .32783 L .44695 .323 L p F P
0 g
s
.11 .174 .72 r
.44254 .32884 m .44695 .323 L .47333 .32783 L p F P
0 g
s
.47333 .32783 m
.49986 .33519 L
s
.47033 .33172 m
.47333 .32783 L
s
.425 .506 .352 r
.46215 .83864 m .49038 .84126 L .49183 .85881 L p F P
0 g
s
.37 .547 .352 r
.5192 .85988 m .49183 .85881 L .49038 .84126 L p F P
0 g
s
.48933 .8215 m
.49038 .84126 L
s
.49038 .84126 m
.5189 .84239 L
s
.489 .506 .256 r
.78388 .53895 m .79465 .52215 L .80756 .5473 L p F P
0 g
s
.489 .506 .256 r
.80756 .5473 m .79615 .56464 L .78388 .53895 L p F P
0 g
s
.76913 .51402 m
.78388 .53895 L
s
.77062 .55484 m
.78388 .53895 L
s
.182 .635 .352 r
.57588 .84018 m .6039 .83685 L .60077 .85463 L p F P
0 g
s
.182 .635 .352 r
.60077 .85463 m .57388 .85779 L .57588 .84018 L p F P
0 g
s
.57588 .84018 m
.57733 .82038 L
s
.54747 .84203 m
.57588 .84018 L
s
.204 .03 .72 r
.57764 .32604 m .57377 .3225 L .59749 .31499 L p F P
0 g
s
.204 .03 .72 r
.59749 .31499 m .60323 .32031 L .57764 .32604 L p F P
0 g
s
.55193 .33429 m
.57764 .32604 L
s
.57764 .32604 m
.58093 .32982 L
s
.396 .634 .026 r
.78006 .6499 m .7976 .63422 L .80128 .66076 L p F P
0 g
s
.396 .634 .026 r
.80128 .66076 m .78347 .67639 L .78006 .6499 L p F P
0 g
s
.77411 .62313 m
.78006 .6499 L
s
.76025 .66434 m
.78006 .6499 L
s
.425 .225 .574 r
.32655 .41271 m .32452 .39895 L .35001 .38439 L p F P
0 g
s
.475 .252 .52 r
.32452 .39895 m .32655 .41271 L .3033 .43082 L p F P
0 g
s
.32655 .41271 m
.33071 .42616 L
s
.32655 .41271 m
.35162 .39652 L
s
.388 .156 .621 r
.6756 .36699 m .67438 .35656 L .70146 .36623 L p F P
0 g
s
.388 .156 .621 r
.70146 .36623 m .70272 .3785 L .6756 .36699 L p F P
0 g
s
.64721 .3578 m
.6756 .36699 L
s
.67516 .3774 m
.6756 .36699 L
s
.338 .096 .661 r
.6461 .34932 m .64365 .34092 L .67151 .34621 L p F P
0 g
s
.338 .096 .661 r
.67151 .34621 m .67438 .35656 L .6461 .34932 L p F P
0 g
s
.61689 .34454 m
.6461 .34932 L
s
.6461 .34932 m
.64721 .3578 L
s
.173 .22 .695 r
.44254 .32884 m .43909 .33493 L .41077 .33663 L p F P
0 g
s
.195 .201 .695 r
.40763 .34494 m .41077 .33663 L .43909 .33493 L p F P
0 g
s
.43909 .33493 m
.46796 .33579 L
s
.43663 .34122 m
.43909 .33493 L
s
.174 .698 .206 r
.7164 .76509 m .74028 .75391 L .73644 .77712 L p F P
0 g
s
.174 .698 .206 r
.73644 .77712 m .71302 .78794 L .7164 .76509 L p F P
0 g
s
.7164 .76509 m
.71779 .74084 L
s
.69096 .77485 m
.7164 .76509 L
s
.475 .459 .352 r
.43442 .83454 m .46215 .83864 L .46474 .85633 L p F P
0 g
s
.425 .506 .352 r
.49183 .85881 m .46474 .85633 L .46215 .83864 L p F P
0 g
s
.46027 .81876 m
.46215 .83864 L
s
.46215 .83864 m
.49038 .84126 L
s
.071 .193 .72 r
.48109 .32078 m .47693 .32417 L .45227 .3175 L p F P
0 g
s
.091 .185 .72 r
.44695 .323 m .45227 .3175 L .47693 .32417 L p F P
0 g
s
.47693 .32417 m
.50168 .33337 L
s
.47333 .32783 m
.47693 .32417 L
s
.692 .122 .256 r
.26291 .57265 m .25022 .55575 L .26283 .53034 L p F P
0 g
s
.715 .126 .181 r
.25022 .55575 m .26291 .57265 L .25355 .59903 L p F P
0 g
s
.26291 .57265 m
.2781 .58852 L
s
.26291 .57265 m
.27483 .54672 L
s
.489 .329 .461 r
.74711 .43859 m .75081 .42353 L .77224 .44281 L p F P
0 g
s
.489 .329 .461 r
.77224 .44281 m .76799 .45911 L .74711 .43859 L p F P
0 g
s
.72418 .41974 m
.74711 .43859 L
s
.74109 .45319 m
.74711 .43859 L
s
.624 .304 .281 r
.35144 .79265 m .37708 .8014 L .38136 .822 L p F P
0 g
s
.588 .367 .281 r
.40741 .82899 m .38136 .822 L .37708 .8014 L p F P
0 g
s
.37708 .8014 m
.40391 .80869 L
s
.3744 .77901 m
.37708 .8014 L
s
.2 .051 .72 r
.57377 .3225 m .56935 .31926 L .59093 .3101 L p F P
0 g
s
.2 .051 .72 r
.59093 .3101 m .59749 .31499 L .57377 .3225 L p F P
0 g
s
.54997 .33254 m
.57377 .3225 L
s
.57377 .3225 m
.57764 .32604 L
s
.28 .019 .695 r
.612 .33197 m .60809 .326 L .6348 .32478 L p F P
0 g
s
.28 .019 .695 r
.6348 .32478 m .63988 .33271 L .612 .33197 L p F P
0 g
s
.58361 .33381 m
.612 .33197 L
s
.612 .33197 m
.61494 .33818 L
s
.115 .65 .352 r
.6039 .83685 m .63131 .83205 L .62706 .85008 L p F P
0 g
s
.115 .65 .352 r
.62706 .85008 m .60077 .85463 L .6039 .83685 L p F P
0 g
s
.6039 .83685 m
.60617 .8169 L
s
.57588 .84018 m
.6039 .83685 L
s
.547 .22 .461 r
.28759 .46678 m .28211 .45071 L .3033 .43082 L p F P
0 g
s
.588 .237 .397 r
.28211 .45071 m .28759 .46678 L .26929 .48932 L p F P
0 g
s
.28759 .46678 m
.29552 .48227 L
s
.28759 .46678 m
.30814 .44568 L
s
.347 .233 .621 r
.35001 .38439 m .35032 .37213 L .37746 .36157 L p F P
0 g
s
.399 .268 .574 r
.35032 .37213 m .35001 .38439 L .32452 .39895 L p F P
0 g
s
.35001 .38439 m
.35162 .39652 L
s
.35001 .38439 m
.37704 .37201 L
s
.456 .584 .104 r
.79118 .60756 m .80578 .59087 L .81263 .6174 L p F P
0 g
s
.456 .584 .104 r
.81263 .6174 m .7976 .63422 L .79118 .60756 L p F P
0 g
s
.78214 .58102 m
.79118 .60756 L
s
.77411 .62313 m
.79118 .60756 L
s
.245 .252 .661 r
.41077 .33663 m .40763 .34494 L .37953 .35117 L p F P
0 g
s
.27 .225 .661 r
.37746 .36157 m .37953 .35117 L .40763 .34494 L p F P
0 g
s
.40763 .34494 m
.43663 .34122 L
s
.40583 .35339 m
.40763 .34494 L
s
.051 .2 .72 r
.48577 .3177 m .48109 .32078 L .45845 .3124 L p F P
0 g
s
.071 .193 .72 r
.45227 .3175 m .45845 .3124 L .48109 .32078 L p F P
0 g
s
.48109 .32078 m
.50378 .33169 L
s
.47693 .32417 m
.48109 .32078 L
s
.515 .432 .328 r
.77914 .49795 m .7866 .48117 L .80273 .50457 L p F P
0 g
s
.515 .432 .328 r
.80273 .50457 m .79465 .52215 L .77914 .49795 L p F P
0 g
s
.76122 .47491 m
.77914 .49795 L
s
.76913 .51402 m
.77914 .49795 L
s
.321 .268 .621 r
.37953 .35117 m .37746 .36157 L .35032 .37213 L p F P
0 g
s
.37704 .37201 m
.37746 .36157 L
s
.37746 .36157 m
.40583 .35339 L
s
.739 .104 .052 r
.299 .72288 m .2778 .70932 L .27856 .68347 L p F P
0 g
s
.73 .102 .13 r
.2778 .70932 m .299 .72288 L .30066 .74756 L p F P
0 g
s
.715 .178 .13 r
.32363 .75946 m .30066 .74756 L .299 .72288 L p F P
0 g
s
.299 .72288 m
.32214 .73507 L
s
.299 .72288 m
.29968 .69721 L
s
.193 .071 .72 r
.56935 .31926 m .56445 .31634 L .5836 .3057 L p F P
0 g
s
.193 .071 .72 r
.5836 .3057 m .59093 .3101 L .56935 .31926 L p F P
0 g
s
.54776 .33093 m
.56935 .31926 L
s
.56935 .31926 m
.57377 .3225 L
s
.747 .026 .026 r
.27856 .68347 m .25961 .66843 L .26317 .64191 L p F P
0 g
s
.746 .026 .052 r
.25961 .66843 m .27856 .68347 L .2778 .70932 L p F P
0 g
s
.27856 .68347 m
.29968 .69721 L
s
.27856 .68347 m
.28183 .65701 L
s
.149 .237 .695 r
.44695 .323 m .44254 .32884 L .41523 .32855 L p F P
0 g
s
.173 .22 .695 r
.41077 .33663 m .41523 .32855 L .44254 .32884 L p F P
0 g
s
.44254 .32884 m
.47033 .33172 L
s
.43909 .33493 m
.44254 .32884 L
s
.521 .406 .352 r
.40741 .82899 m .43442 .83454 L .43813 .85244 L p F P
0 g
s
.475 .459 .352 r
.46474 .85633 m .43813 .85244 L .43442 .83454 L p F P
0 g
s
.43172 .81449 m
.43442 .83454 L
s
.43442 .83454 m
.46215 .83864 L
s
.475 .252 .52 r
.72733 .40612 m .72831 .39226 L .75211 .40819 L p F P
0 g
s
.475 .252 .52 r
.75211 .40819 m .75081 .42353 L .72733 .40612 L p F P
0 g
s
.70203 .39071 m
.72733 .40612 L
s
.72418 .41974 m
.72733 .40612 L
s
.03 .204 .72 r
.49091 .31497 m .48577 .3177 L .46542 .30776 L p F P
0 g
s
.051 .2 .72 r
.45845 .3124 m .46542 .30776 L .48577 .3177 L p F P
0 g
s
.48577 .3177 m
.50612 .33016 L
s
.48109 .32078 m
.48577 .3177 L
s
.096 .687 .281 r
.68805 .79737 m .71302 .78794 L .70761 .80912 L p F P
0 g
s
.096 .687 .281 r
.70761 .80912 m .68339 .81815 L .68805 .79737 L p F P
0 g
s
.68805 .79737 m
.69096 .77485 L
s
.66176 .80537 m
.68805 .79737 L
s
.647 .185 .328 r
.26283 .53034 m .25344 .51312 L .26929 .48932 L p F P
0 g
s
.676 .193 .256 r
.25344 .51312 m .26283 .53034 L .25022 .55575 L p F P
0 g
s
.26283 .53034 m
.27483 .54672 L
s
.26283 .53034 m
.278 .50578 L
s
.698 .174 .206 r
.30066 .74756 m .32363 .75946 L .32725 .7825 L p F P
0 g
s
.676 .246 .206 r
.35144 .79265 m .32725 .7825 L .32363 .75946 L p F P
0 g
s
.32363 .75946 m
.34828 .76997 L
s
.32214 .73507 m
.32363 .75946 L
s
.346 .06 .661 r
.64365 .34092 m .63988 .33271 L .66698 .33607 L p F P
0 g
s
.346 .06 .661 r
.66698 .33607 m .67151 .34621 L .64365 .34092 L p F P
0 g
s
.61494 .33818 m
.64365 .34092 L
s
.64365 .34092 m
.6461 .34932 L
s
.185 .091 .72 r
.56445 .31634 m .5591 .31379 L .5756 .30185 L p F P
0 g
s
.185 .091 .72 r
.5756 .30185 m .5836 .3057 L .56445 .31634 L p F P
0 g
s
.5453 .32949 m
.56445 .31634 L
s
.56445 .31634 m
.56935 .31926 L
s
.739 .052 .104 r
.26317 .64191 m .24691 .62562 L .25355 .59903 L p F P
0 g
s
.746 .052 .026 r
.24691 .62562 m .26317 .64191 L .25961 .66843 L p F P
0 g
s
.26317 .64191 m
.28183 .65701 L
s
.26317 .64191 m
.26937 .6152 L
s
.28 .011 .695 r
.60809 .326 m .60323 .32031 L .62846 .31723 L p F P
0 g
s
.28 .011 .695 r
.62846 .31723 m .6348 .32478 L .60809 .326 L p F P
0 g
s
.58093 .32982 m
.60809 .326 L
s
.60809 .326 m
.612 .33197 L
s
.475 .252 .52 r
.3033 .43082 m .30084 .4156 L .32452 .39895 L p F P
0 g
s
.521 .276 .461 r
.30084 .4156 m .3033 .43082 L .28211 .45071 L p F P
0 g
s
.3033 .43082 m
.30814 .44568 L
s
.3033 .43082 m
.32655 .41271 L
s
.446 .18 .574 r
.70272 .3785 m .70146 .36623 L .72706 .37831 L p F P
0 g
s
.446 .18 .574 r
.72706 .37831 m .72831 .39226 L .70272 .3785 L p F P
0 g
s
.6756 .36699 m
.70272 .3785 L
s
.70203 .39071 m
.70272 .3785 L
s
.047 .659 .352 r
.63131 .83205 m .65788 .8258 L .65253 .84417 L p F P
0 g
s
.047 .659 .352 r
.65253 .84417 m .62706 .85008 L .63131 .83205 L p F P
0 g
s
.63131 .83205 m
.63439 .81189 L
s
.6039 .83685 m
.63131 .83205 L
s
.008 .206 .72 r
.49647 .31263 m .49091 .31497 L .47311 .30363 L p F P
0 g
s
.03 .204 .72 r
.46542 .30776 m .47311 .30363 L .49091 .31497 L p F P
0 g
s
.49091 .31497 m
.5087 .32881 L
s
.48577 .3177 m
.49091 .31497 L
s
.504 .522 .181 r
.79615 .56464 m .80756 .5473 L .81771 .57318 L p F P
0 g
s
.504 .522 .181 r
.81771 .57318 m .80578 .59087 L .79615 .56464 L p F P
0 g
s
.78388 .53895 m
.79615 .56464 L
s
.78214 .58102 m
.79615 .56464 L
s
.402 .115 .621 r
.67438 .35656 m .67151 .34621 L .69823 .35404 L p F P
0 g
s
.402 .115 .621 r
.69823 .35404 m .70146 .36623 L .67438 .35656 L p F P
0 g
s
.6461 .34932 m
.67438 .35656 L
s
.67438 .35656 m
.6756 .36699 L
s
.174 .11 .72 r
.5591 .31379 m .55337 .31164 L .56701 .29859 L p F P
0 g
s
.174 .11 .72 r
.56701 .29859 m .5756 .30185 L .5591 .31379 L p F P
0 g
s
.54262 .32823 m
.5591 .31379 L
s
.5591 .31379 m
.56445 .31634 L
s
.526 .354 .397 r
.76799 .45911 m .77224 .44281 L .79136 .46382 L p F P
0 g
s
.526 .354 .397 r
.79136 .46382 m .7866 .48117 L .76799 .45911 L p F P
0 g
s
.74711 .43859 m
.76799 .45911 L
s
.76122 .47491 m
.76799 .45911 L
s
.124 .252 .695 r
.45227 .3175 m .44695 .323 L .42097 .32081 L p F P
0 g
s
.149 .237 .695 r
.41523 .32855 m .42097 .32081 L .44695 .323 L p F P
0 g
s
.44695 .323 m
.47333 .32783 L
s
.44254 .32884 m
.44695 .323 L
s
.014 .206 .72 r
.50237 .31069 m .49647 .31263 L .48143 .30008 L p F P
0 g
s
.008 .206 .72 r
.47311 .30363 m .48143 .30008 L .49647 .31263 L p F P
0 g
s
.49647 .31263 m
.51147 .32765 L
s
.49091 .31497 m
.49647 .31263 L
s
.217 .276 .661 r
.41523 .32855 m .41077 .33663 L .38327 .34091 L p F P
0 g
s
.245 .252 .661 r
.37953 .35117 m .38327 .34091 L .41077 .33663 L p F P
0 g
s
.40763 .34494 m
.41077 .33663 L
s
.41077 .33663 m
.43909 .33493 L
s
.323 .662 .13 r
.76409 .71653 m .78426 .70234 L .78235 .7275 L p F P
0 g
s
.323 .662 .13 r
.78235 .7275 m .76234 .74135 L .76409 .71653 L p F P
0 g
s
.76337 .69077 m
.76409 .71653 L
s
.74185 .72938 m
.76409 .71653 L
s
.162 .128 .72 r
.55337 .31164 m .54733 .30991 L .55793 .29596 L p F P
0 g
s
.162 .128 .72 r
.55793 .29596 m .56701 .29859 L .55337 .31164 L p F P
0 g
s
.53976 .32717 m
.55337 .31164 L
s
.55337 .31164 m
.5591 .31379 L
s
.652 .237 .281 r
.32725 .7825 m .35144 .79265 L .3565 .81363 L p F P
0 g
s
.624 .304 .281 r
.38136 .822 m .3565 .81363 L .35144 .79265 L p F P
0 g
s
.35144 .79265 m
.37708 .8014 L
s
.34828 .76997 m
.35144 .79265 L
s
.399 .268 .574 r
.32452 .39895 m .32469 .38502 L .35032 .37213 L p F P
0 g
s
.447 .3 .52 r
.32469 .38502 m .32452 .39895 L .30084 .4156 L p F P
0 g
s
.32452 .39895 m
.32655 .41271 L
s
.32452 .39895 m
.35001 .38439 L
s
.56 .35 .352 r
.38136 .822 m .40741 .82899 L .41224 .84718 L p F P
0 g
s
.521 .406 .352 r
.43813 .85244 m .41224 .84718 L .40741 .82899 L p F P
0 g
s
.40391 .80869 m
.40741 .82899 L
s
.40741 .82899 m
.43442 .83454 L
s
.715 .126 .181 r
.25355 .59903 m .24031 .5818 L .25022 .55575 L p F P
0 g
s
.73 .129 .104 r
.24031 .5818 m .25355 .59903 L .24691 .62562 L p F P
0 g
s
.25355 .59903 m
.26937 .6152 L
s
.25355 .59903 m
.26291 .57265 L
s
.035 .203 .72 r
.50854 .30918 m .50237 .31069 L .49028 .29714 L p F P
0 g
s
.014 .206 .72 r
.48143 .30008 m .49028 .29714 L .50237 .31069 L p F P
0 g
s
.50237 .31069 m
.51441 .3267 L
s
.49647 .31263 m
.50237 .31069 L
s
.395 .633 .052 r
.78347 .67639 m .80128 .66076 L .80213 .68692 L p F P
0 g
s
.395 .633 .052 r
.80213 .68692 m .78426 .70234 L .78347 .67639 L p F P
0 g
s
.78006 .6499 m
.78347 .67639 L
s
.76337 .69077 m
.78347 .67639 L
s
.588 .237 .397 r
.26929 .48932 m .26321 .47222 L .28211 .45071 L p F P
0 g
s
.624 .252 .328 r
.26321 .47222 m .26929 .48932 L .25344 .51312 L p F P
0 g
s
.26929 .48932 m
.278 .50578 L
s
.26929 .48932 m
.28759 .46678 L
s
.277 .04 .695 r
.60323 .32031 m .59749 .31499 L .62093 .31015 L p F P
0 g
s
.277 .04 .695 r
.62093 .31015 m .62846 .31723 L .60323 .32031 L p F P
0 g
s
.57764 .32604 m
.60323 .32031 L
s
.60323 .32031 m
.60809 .326 L
s
.246 .676 .206 r
.74028 .75391 m .76234 .74135 L .75807 .76498 L p F P
0 g
s
.246 .676 .206 r
.75807 .76498 m .73644 .77712 L .74028 .75391 L p F P
0 g
s
.74028 .75391 m
.74185 .72938 L
s
.7164 .76509 m
.74028 .75391 L
s
.148 .144 .72 r
.54733 .30991 m .54104 .30862 L .54848 .29401 L p F P
0 g
s
.148 .144 .72 r
.54848 .29401 m .55793 .29596 L .54733 .30991 L p F P
0 g
s
.53676 .32631 m
.54733 .30991 L
s
.54733 .30991 m
.55337 .31164 L
s
.291 .3 .621 r
.38327 .34091 m .37953 .35117 L .3526 .35989 L p F P
0 g
s
.321 .268 .621 r
.35032 .37213 m .3526 .35989 L .37953 .35117 L p F P
0 g
s
.37953 .35117 m
.40763 .34494 L
s
.37746 .36157 m
.37953 .35117 L
s
.056 .198 .72 r
.51493 .30813 m .50854 .30918 L .49957 .29486 L p F P
0 g
s
.035 .203 .72 r
.49028 .29714 m .49957 .29486 L .50854 .30918 L p F P
0 g
s
.50854 .30918 m
.51749 .32596 L
s
.50237 .31069 m
.50854 .30918 L
s
.369 .309 .574 r
.3526 .35989 m .35032 .37213 L .32469 .38502 L p F P
0 g
s
.35001 .38439 m
.35032 .37213 L
s
.35032 .37213 m
.37746 .36157 L
s
.132 .159 .72 r
.54104 .30862 m .53458 .30779 L .53876 .29275 L p F P
0 g
s
.132 .159 .72 r
.53876 .29275 m .54848 .29401 L .54104 .30862 L p F P
0 g
s
.53363 .32568 m
.54104 .30862 L
s
.54104 .30862 m
.54733 .30991 L
s
.35 .024 .661 r
.63988 .33271 m .6348 .32478 L .66082 .32625 L p F P
0 g
s
.35 .024 .661 r
.66082 .32625 m .66698 .33607 L .63988 .33271 L p F P
0 g
s
.612 .33197 m
.63988 .33271 L
s
.63988 .33271 m
.64365 .34092 L
s
.076 .192 .72 r
.52145 .30754 m .51493 .30813 L .50917 .29327 L p F P
0 g
s
.056 .198 .72 r
.49957 .29486 m .50917 .29327 L .51493 .30813 L p F P
0 g
s
.51493 .30813 m
.52066 .32544 L
s
.50854 .30918 m
.51493 .30813 L
s
.539 .452 .256 r
.79465 .52215 m .80273 .50457 L .81618 .52913 L p F P
0 g
s
.539 .452 .256 r
.81618 .52913 m .80756 .5473 L .79465 .52215 L p F P
0 g
s
.77914 .49795 m
.79465 .52215 L
s
.78388 .53895 m
.79465 .52215 L
s
.115 .171 .72 r
.53458 .30779 m .52802 .30743 L .52889 .2922 L p F P
0 g
s
.115 .171 .72 r
.52889 .2922 m .53876 .29275 L .53458 .30779 L p F P
0 g
s
.53042 .32527 m
.53458 .30779 L
s
.53458 .30779 m
.54104 .30862 L
s
.521 .276 .461 r
.75081 .42353 m .75211 .40819 L .77385 .42616 L p F P
0 g
s
.521 .276 .461 r
.77385 .42616 m .77224 .44281 L .75081 .42353 L p F P
0 g
s
.72733 .40612 m
.75081 .42353 L
s
.74711 .43859 m
.75081 .42353 L
s
.096 .182 .72 r
.52802 .30743 m .52145 .30754 L .51899 .29238 L p F P
0 g
s
.076 .192 .72 r
.50917 .29327 m .51899 .29238 L .52145 .30754 L p F P
0 g
s
.52145 .30754 m
.5239 .32515 L
s
.51493 .30813 m
.52145 .30754 L
s
.096 .182 .72 r
.51899 .29238 m .52889 .2922 L .52802 .30743 L p F P
0 g
s
.52145 .30754 m
.52802 .30743 L
s
.52716 .32509 m
.52802 .30743 L
s
.52802 .30743 m
.53458 .30779 L
s
.097 .263 .695 r
.45845 .3124 m .45227 .3175 L .42793 .31349 L p F P
0 g
s
.124 .252 .695 r
.42097 .32081 m .42793 .31349 L .45227 .3175 L p F P
0 g
s
.45227 .3175 m
.47693 .32417 L
s
.44695 .323 m
.45227 .3175 L
s
.46 .589 .026 r
.7976 .63422 m .81263 .6174 L .81656 .64398 L p F P
0 g
s
.46 .589 .026 r
.81656 .64398 m .80128 .66076 L .7976 .63422 L p F P
0 g
s
.79118 .60756 m
.7976 .63422 L
s
.78006 .6499 m
.7976 .63422 L
s
.023 .66 .352 r
.65788 .8258 m .68339 .81815 L .67697 .83692 L p F P
0 g
s
.023 .66 .352 r
.67697 .83692 m .65253 .84417 L .65788 .8258 L p F P
0 g
s
.65788 .8258 m
.66176 .80537 L
s
.63131 .83205 m
.65788 .8258 L
s
.347 .514 .419 r
.49183 .85881 m .5192 .85988 L .51958 .87492 L p F P
0 g
s
.292 .547 .419 r
.5192 .85988 m .54662 .85954 L .54553 .8746 L p F P
0 g
s
.292 .547 .419 r
.54553 .8746 m .51958 .87492 L .5192 .85988 L p F P
0 g
s
.5189 .84239 m
.5192 .85988 L
s
.167 .673 .281 r
.71302 .78794 m .73644 .77712 L .7303 .79877 L p F P
0 g
s
.167 .673 .281 r
.7303 .79877 m .70761 .80912 L .71302 .78794 L p F P
0 g
s
.71302 .78794 m
.7164 .76509 L
s
.68805 .79737 m
.71302 .78794 L
s
.233 .575 .419 r
.54662 .85954 m .57388 .85779 L .57133 .87296 L p F P
0 g
s
.233 .575 .419 r
.57133 .87296 m .54553 .8746 L .54662 .85954 L p F P
0 g
s
.54662 .85954 m
.54747 .84203 L
s
.5192 .85988 m
.54662 .85954 L
s
.272 .069 .695 r
.59749 .31499 m .59093 .3101 L .61227 .30363 L p F P
0 g
s
.272 .069 .695 r
.61227 .30363 m .62093 .31015 L .59749 .31499 L p F P
0 g
s
.57377 .3225 m
.59749 .31499 L
s
.59749 .31499 m
.60323 .32031 L
s
.676 .193 .256 r
.25022 .55575 m .24024 .53796 L .25344 .51312 L p F P
0 g
s
.698 .2 .181 r
.24024 .53796 m .25022 .55575 L .24031 .5818 L p F P
0 g
s
.25022 .55575 m
.26291 .57265 L
s
.25022 .55575 m
.26283 .53034 L
s
.187 .297 .661 r
.42097 .32081 m .41523 .32855 L .38865 .33092 L p F P
0 g
s
.217 .276 .661 r
.38327 .34091 m .38865 .33092 L .41523 .32855 L p F P
0 g
s
.41523 .32855 m
.44254 .32884 L
s
.41077 .33663 m
.41523 .32855 L
s
.521 .276 .461 r
.28211 .45071 m .27922 .4342 L .30084 .4156 L p F P
0 g
s
.56 .297 .397 r
.27922 .4342 m .28211 .45071 L .26321 .47222 L p F P
0 g
s
.28211 .45071 m
.28759 .46678 L
s
.28211 .45071 m
.3033 .43082 L
s
.412 .072 .621 r
.67151 .34621 m .66698 .33607 L .69303 .34207 L p F P
0 g
s
.412 .072 .621 r
.69303 .34207 m .69823 .35404 L .67151 .34621 L p F P
0 g
s
.64365 .34092 m
.67151 .34621 L
s
.67151 .34621 m
.67438 .35656 L
s
.499 .201 .52 r
.72831 .39226 m .72706 .37831 L .75091 .3927 L p F P
0 g
s
.499 .201 .52 r
.75091 .3927 m .75211 .40819 L .72831 .39226 L p F P
0 g
s
.70272 .3785 m
.72831 .39226 L
s
.72733 .40612 m
.72831 .39226 L
s
.399 .475 .419 r
.46474 .85633 m .49183 .85881 L .49367 .87392 L p F P
0 g
s
.347 .514 .419 r
.51958 .87492 m .49367 .87392 L .49183 .85881 L p F P
0 g
s
.49038 .84126 m
.49183 .85881 L
s
.49183 .85881 m
.5192 .85988 L
s
.462 .132 .574 r
.70146 .36623 m .69823 .35404 L .72355 .36441 L p F P
0 g
s
.462 .132 .574 r
.72355 .36441 m .72706 .37831 L .70146 .36623 L p F P
0 g
s
.67438 .35656 m
.70146 .36623 L
s
.70146 .36623 m
.70272 .3785 L
s
.746 .026 .052 r
.2778 .70932 m .25879 .69448 L .25961 .66843 L p F P
0 g
s
.736 .026 .13 r
.25879 .69448 m .2778 .70932 L .27964 .73432 L p F P
0 g
s
.73 .102 .13 r
.30066 .74756 m .27964 .73432 L .2778 .70932 L p F P
0 g
s
.2778 .70932 m
.299 .72288 L
s
.2778 .70932 m
.27856 .68347 L
s
.171 .596 .419 r
.57388 .85779 m .60077 .85463 L .59677 .87001 L p F P
0 g
s
.171 .596 .419 r
.59677 .87001 m .57133 .87296 L .57388 .85779 L p F P
0 g
s
.57388 .85779 m
.57588 .84018 L
s
.54662 .85954 m
.57388 .85779 L
s
.069 .272 .695 r
.46542 .30776 m .45845 .3124 L .43606 .30669 L p F P
0 g
s
.097 .263 .695 r
.42793 .31349 m .43606 .30669 L .45845 .3124 L p F P
0 g
s
.45845 .3124 m
.48109 .32078 L
s
.45227 .3175 m
.45845 .3124 L
s
.712 .1 .206 r
.27964 .73432 m .30066 .74756 L .30473 .77098 L p F P
0 g
s
.698 .174 .206 r
.32725 .7825 m .30473 .77098 L .30066 .74756 L p F P
0 g
s
.30066 .74756 m
.32363 .75946 L
s
.299 .72288 m
.30066 .74756 L
s
.594 .289 .352 r
.3565 .81363 m .38136 .822 L .38728 .84057 L p F P
0 g
s
.56 .35 .352 r
.41224 .84718 m .38728 .84057 L .38136 .822 L p F P
0 g
s
.37708 .8014 m
.38136 .822 L
s
.38136 .822 m
.40741 .82899 L
s
.558 .376 .328 r
.7866 .48117 m .79136 .46382 L .80796 .48638 L p F P
0 g
s
.558 .376 .328 r
.80796 .48638 m .80273 .50457 L .7866 .48117 L p F P
0 g
s
.76799 .45911 m
.7866 .48117 L
s
.77914 .49795 m
.7866 .48117 L
s
.515 .533 .104 r
.80578 .59087 m .81771 .57318 L .82492 .59956 L p F P
0 g
s
.515 .533 .104 r
.82492 .59956 m .81263 .6174 L .80578 .59087 L p F P
0 g
s
.79615 .56464 m
.80578 .59087 L
s
.79118 .60756 m
.80578 .59087 L
s
.746 .052 .026 r
.25961 .66843 m .24309 .65218 L .24691 .62562 L p F P
0 g
s
.745 .052 .052 r
.24309 .65218 m .25961 .66843 L .25879 .69448 L p F P
0 g
s
.25961 .66843 m
.27856 .68347 L
s
.25961 .66843 m
.26317 .64191 L
s
.351 .013 .661 r
.6348 .32478 m .62846 .31723 L .65309 .31689 L p F P
0 g
s
.351 .013 .661 r
.65309 .31689 m .66082 .32625 L .6348 .32478 L p F P
0 g
s
.60809 .326 m
.6348 .32478 L
s
.6348 .32478 m
.63988 .33271 L
s
.447 .431 .419 r
.43813 .85244 m .46474 .85633 L .46804 .87159 L p F P
0 g
s
.399 .475 .419 r
.49367 .87392 m .46804 .87159 L .46474 .85633 L p F P
0 g
s
.46215 .83864 m
.46474 .85633 L
s
.46474 .85633 m
.49183 .85881 L
s
.263 .097 .695 r
.59093 .3101 m .5836 .3057 L .60258 .29775 L p F P
0 g
s
.263 .097 .695 r
.60258 .29775 m .61227 .30363 L .59093 .3101 L p F P
0 g
s
.56935 .31926 m
.59093 .3101 L
s
.59093 .3101 m
.59749 .31499 L
s
.447 .3 .52 r
.30084 .4156 m .30083 .40016 L .32469 .38502 L p F P
0 g
s
.489 .329 .461 r
.30083 .40016 m .30084 .4156 L .27922 .4342 L p F P
0 g
s
.30084 .4156 m
.3033 .43082 L
s
.30084 .4156 m
.32452 .39895 L
s
.258 .329 .621 r
.38865 .33092 m .38327 .34091 L .35685 .34779 L p F P
0 g
s
.291 .3 .621 r
.3526 .35989 m .35685 .34779 L .38327 .34091 L p F P
0 g
s
.37953 .35117 m
.38327 .34091 L
s
.38327 .34091 m
.41077 .33663 L
s
.108 .611 .419 r
.60077 .85463 m .62706 .85008 L .62163 .86575 L p F P
0 g
s
.108 .611 .419 r
.62163 .86575 m .59677 .87001 L .60077 .85463 L p F P
0 g
s
.60077 .85463 m
.6039 .83685 L
s
.57388 .85779 m
.60077 .85463 L
s
.624 .252 .328 r
.25344 .51312 m .24682 .4952 L .26321 .47222 L p F P
0 g
s
.652 .263 .256 r
.24682 .4952 m .25344 .51312 L .24024 .53796 L p F P
0 g
s
.25344 .51312 m
.26283 .53034 L
s
.25344 .51312 m
.26929 .48932 L
s
.673 .167 .281 r
.30473 .77098 m .32725 .7825 L .33304 .80391 L p F P
0 g
s
.652 .237 .281 r
.3565 .81363 m .33304 .80391 L .32725 .7825 L p F P
0 g
s
.32725 .7825 m
.35144 .79265 L
s
.32363 .75946 m
.32725 .7825 L
s
.04 .277 .695 r
.47311 .30363 m .46542 .30776 L .44527 .30049 L p F P
0 g
s
.069 .272 .695 r
.43606 .30669 m .44527 .30049 L .46542 .30776 L p F P
0 g
s
.46542 .30776 m
.48577 .3177 L
s
.45845 .3124 m
.46542 .30776 L
s
.369 .309 .574 r
.32469 .38502 m .32711 .37108 L .3526 .35989 L p F P
0 g
s
.413 .345 .52 r
.32711 .37108 m .32469 .38502 L .30083 .40016 L p F P
0 g
s
.32452 .39895 m
.32469 .38502 L
s
.32469 .38502 m
.35032 .37213 L
s
.155 .315 .661 r
.42793 .31349 m .42097 .32081 L .39563 .32133 L p F P
0 g
s
.187 .297 .661 r
.38865 .33092 m .39563 .32133 L .42097 .32081 L p F P
0 g
s
.42097 .32081 m
.44695 .323 L
s
.41523 .32855 m
.42097 .32081 L
s
.73 .129 .104 r
.24691 .62562 m .23327 .60825 L .24031 .5818 L p F P
0 g
s
.736 .13 .026 r
.23327 .60825 m .24691 .62562 L .24309 .65218 L p F P
0 g
s
.24691 .62562 m
.26317 .64191 L
s
.24691 .62562 m
.25355 .59903 L
s
.092 .654 .352 r
.68339 .81815 m .70761 .80912 L .70015 .82838 L p F P
0 g
s
.092 .654 .352 r
.70015 .82838 m .67697 .83692 L .68339 .81815 L p F P
0 g
s
.68339 .81815 m
.68805 .79737 L
s
.65788 .8258 m
.68339 .81815 L
s
.335 .345 .574 r
.35685 .34779 m .3526 .35989 L .32711 .37108 L p F P
0 g
s
.3526 .35989 m
.37953 .35117 L
s
.35032 .37213 m
.3526 .35989 L
s
.56 .297 .397 r
.77224 .44281 m .77385 .42616 L .7933 .44607 L p F P
0 g
s
.56 .297 .397 r
.7933 .44607 m .79136 .46382 L .77224 .44281 L p F P
0 g
s
.75081 .42353 m
.77224 .44281 L
s
.76799 .45911 m
.77224 .44281 L
s
.252 .124 .695 r
.5836 .3057 m .5756 .30185 L .59197 .29259 L p F P
0 g
s
.252 .124 .695 r
.59197 .29259 m .60258 .29775 L .5836 .3057 L p F P
0 g
s
.56445 .31634 m
.5836 .3057 L
s
.5836 .3057 m
.59093 .3101 L
s
.489 .381 .419 r
.41224 .84718 m .43813 .85244 L .44287 .86796 L p F P
0 g
s
.447 .431 .419 r
.46804 .87159 m .44287 .86796 L .43813 .85244 L p F P
0 g
s
.43442 .83454 m
.43813 .85244 L
s
.43813 .85244 m
.46474 .85633 L
s
.556 .466 .181 r
.80756 .5473 m .81618 .52913 L .82675 .55464 L p F P
0 g
s
.556 .466 .181 r
.82675 .55464 m .81771 .57318 L .80756 .5473 L p F P
0 g
s
.79465 .52215 m
.80756 .5473 L
s
.79615 .56464 m
.80756 .5473 L
s
.39 .625 .13 r
.78426 .70234 m .80213 .68692 L .80007 .71244 L p F P
0 g
s
.39 .625 .13 r
.80007 .71244 m .78235 .7275 L .78426 .70234 L p F P
0 g
s
.78347 .67639 m
.78426 .70234 L
s
.76409 .71653 m
.78426 .70234 L
s
.315 .647 .206 r
.76234 .74135 m .78235 .7275 L .77768 .7516 L p F P
0 g
s
.315 .647 .206 r
.77768 .7516 m .75807 .76498 L .76234 .74135 L p F P
0 g
s
.76234 .74135 m
.76409 .71653 L
s
.74028 .75391 m
.76234 .74135 L
s
.417 .028 .621 r
.66698 .33607 m .66082 .32625 L .68589 .33047 L p F P
0 g
s
.417 .028 .621 r
.68589 .33047 m .69303 .34207 L .66698 .33607 L p F P
0 g
s
.63988 .33271 m
.66698 .33607 L
s
.66698 .33607 m
.67151 .34621 L
s
.011 .28 .695 r
.48143 .30008 m .47311 .30363 L .45545 .29498 L p F P
0 g
s
.04 .277 .695 r
.44527 .30049 m .45545 .29498 L .47311 .30363 L p F P
0 g
s
.47311 .30363 m
.49091 .31497 L
s
.46542 .30776 m
.47311 .30363 L
s
.348 .05 .661 r
.62846 .31723 m .62093 .31015 L .64384 .30809 L p F P
0 g
s
.348 .05 .661 r
.64384 .30809 m .65309 .31689 L .62846 .31723 L p F P
0 g
s
.60323 .32031 m
.62846 .31723 L
s
.62846 .31723 m
.6348 .32478 L
s
.044 .619 .419 r
.62706 .85008 m .65253 .84417 L .64571 .86022 L p F P
0 g
s
.044 .619 .419 r
.64571 .86022 m .62163 .86575 L .62706 .85008 L p F P
0 g
s
.62706 .85008 m
.63131 .83205 L
s
.60077 .85463 m
.62706 .85008 L
s
.237 .149 .695 r
.5756 .30185 m .56701 .29859 L .58055 .28822 L p F P
0 g
s
.237 .149 .695 r
.58055 .28822 m .59197 .29259 L .5756 .30185 L p F P
0 g
s
.5591 .31379 m
.5756 .30185 L
s
.5756 .30185 m
.5836 .3057 L
s
.56 .297 .397 r
.26321 .47222 m .2599 .45464 L .27922 .4342 L p F P
0 g
s
.594 .315 .328 r
.2599 .45464 m .26321 .47222 L .24682 .4952 L p F P
0 g
s
.26321 .47222 m
.26929 .48932 L
s
.26321 .47222 m
.28211 .45071 L
s
.547 .22 .461 r
.75211 .40819 m .75091 .3927 L .77274 .40934 L p F P
0 g
s
.547 .22 .461 r
.77274 .40934 m .77385 .42616 L .75211 .40819 L p F P
0 g
s
.72831 .39226 m
.75211 .40819 L
s
.75081 .42353 m
.75211 .40819 L
s
.459 .588 .052 r
.80128 .66076 m .81656 .64398 L .81746 .67037 L p F P
0 g
s
.459 .588 .052 r
.81746 .67037 m .80213 .68692 L .80128 .66076 L p F P
0 g
s
.7976 .63422 m
.80128 .66076 L
s
.78347 .67639 m
.80128 .66076 L
s
.698 .2 .181 r
.24031 .5818 m .22986 .56365 L .24024 .53796 L p F P
0 g
s
.712 .204 .104 r
.22986 .56365 m .24031 .5818 L .23327 .60825 L p F P
0 g
s
.24031 .5818 m
.25355 .59903 L
s
.24031 .5818 m
.25022 .55575 L
s
.237 .652 .281 r
.73644 .77712 m .75807 .76498 L .75125 .78716 L p F P
0 g
s
.237 .652 .281 r
.75125 .78716 m .7303 .79877 L .73644 .77712 L p F P
0 g
s
.73644 .77712 m
.74028 .75391 L
s
.71302 .78794 m
.73644 .77712 L
s
.474 .083 .574 r
.69823 .35404 m .69303 .34207 L .71776 .35074 L p F P
0 g
s
.474 .083 .574 r
.71776 .35074 m .72355 .36441 L .69823 .35404 L p F P
0 g
s
.67151 .34621 m
.69823 .35404 L
s
.69823 .35404 m
.70146 .36623 L
s
.621 .226 .352 r
.33304 .80391 m .3565 .81363 L .36346 .83265 L p F P
0 g
s
.594 .289 .352 r
.38728 .84057 m .36346 .83265 L .3565 .81363 L p F P
0 g
s
.3565 .81363 m
.38136 .822 L
s
.35144 .79265 m
.3565 .81363 L
s
.019 .28 .695 r
.49028 .29714 m .48143 .30008 L .4665 .29022 L p F P
0 g
s
.011 .28 .695 r
.45545 .29498 m .4665 .29022 L .48143 .30008 L p F P
0 g
s
.48143 .30008 m
.49647 .31263 L
s
.47311 .30363 m
.48143 .30008 L
s
.518 .148 .52 r
.72706 .37831 m .72355 .36441 L .74717 .37726 L p F P
0 g
s
.518 .148 .52 r
.74717 .37726 m .75091 .3927 L .72706 .37831 L p F P
0 g
s
.70146 .36623 m
.72706 .37831 L
s
.72706 .37831 m
.72831 .39226 L
s
.121 .33 .661 r
.43606 .30669 m .42793 .31349 L .40416 .31224 L p F P
0 g
s
.155 .315 .661 r
.39563 .32133 m .40416 .31224 L .42793 .31349 L p F P
0 g
s
.42793 .31349 m
.45227 .3175 L
s
.42097 .32081 m
.42793 .31349 L
s
.222 .354 .621 r
.39563 .32133 m .38865 .33092 L .36307 .33599 L p F P
0 g
s
.258 .329 .621 r
.35685 .34779 m .36307 .33599 L .38865 .33092 L p F P
0 g
s
.38327 .34091 m
.38865 .33092 L
s
.38865 .33092 m
.41523 .32855 L
s
.583 .393 .256 r
.80273 .50457 m .80796 .48638 L .82181 .51031 L p F P
0 g
s
.583 .393 .256 r
.82181 .51031 m .81618 .52913 L .80273 .50457 L p F P
0 g
s
.7866 .48117 m
.80273 .50457 L
s
.79465 .52215 m
.80273 .50457 L
s
.22 .173 .695 r
.56701 .29859 m .55793 .29596 L .56848 .28471 L p F P
0 g
s
.22 .173 .695 r
.56848 .28471 m .58055 .28822 L .56701 .29859 L p F P
0 g
s
.55337 .31164 m
.56701 .29859 L
s
.56701 .29859 m
.5756 .30185 L
s
.526 .328 .419 r
.38728 .84057 m .41224 .84718 L .41839 .86304 L p F P
0 g
s
.489 .381 .419 r
.44287 .86796 m .41839 .86304 L .41224 .84718 L p F P
0 g
s
.40741 .82899 m
.41224 .84718 L
s
.41224 .84718 m
.43813 .85244 L
s
.048 .276 .695 r
.49957 .29486 m .49028 .29714 L .47827 .28629 L p F P
0 g
s
.019 .28 .695 r
.4665 .29022 m .47827 .28629 L .49028 .29714 L p F P
0 g
s
.49028 .29714 m
.50237 .31069 L
s
.48143 .30008 m
.49028 .29714 L
s
.519 .538 .026 r
.81263 .6174 m .82492 .59956 L .82907 .62619 L p F P
0 g
s
.519 .538 .026 r
.82907 .62619 m .81656 .64398 L .81263 .6174 L p F P
0 g
s
.80578 .59087 m
.81263 .6174 L
s
.7976 .63422 m
.81263 .6174 L
s
.489 .329 .461 r
.27922 .4342 m .27901 .41744 L .30083 .40016 L p F P
0 g
s
.526 .354 .397 r
.27901 .41744 m .27922 .4342 L .2599 .45464 L p F P
0 g
s
.27922 .4342 m
.28211 .45071 L
s
.27922 .4342 m
.30084 .4156 L
s
.201 .195 .695 r
.55793 .29596 m .54848 .29401 L .55588 .28208 L p F P
0 g
s
.201 .195 .695 r
.55588 .28208 m .56848 .28471 L .55793 .29596 L p F P
0 g
s
.54733 .30991 m
.55793 .29596 L
s
.55793 .29596 m
.56701 .29859 L
s
.341 .086 .661 r
.62093 .31015 m .61227 .30363 L .63317 .29997 L p F P
0 g
s
.341 .086 .661 r
.63317 .29997 m .64384 .30809 L .62093 .31015 L p F P
0 g
s
.59749 .31499 m
.62093 .31015 L
s
.62093 .31015 m
.62846 .31723 L
s
.736 .026 .13 r
.27964 .73432 m .26079 .71983 L .25879 .69448 L p F P
0 g
s
.719 .025 .206 r
.26079 .71983 m .27964 .73432 L .28412 .75819 L p F P
0 g
s
.712 .1 .206 r
.30473 .77098 m .28412 .75819 L .27964 .73432 L p F P
0 g
s
.27964 .73432 m
.30066 .74756 L
s
.2778 .70932 m
.27964 .73432 L
s
.076 .27 .695 r
.50917 .29327 m .49957 .29486 L .49064 .28323 L p F P
0 g
s
.048 .276 .695 r
.47827 .28629 m .49064 .28323 L .49957 .29486 L p F P
0 g
s
.49957 .29486 m
.50854 .30918 L
s
.49028 .29714 m
.49957 .29486 L
s
.652 .263 .256 r
.24024 .53796 m .23315 .51943 L .24682 .4952 L p F P
0 g
s
.673 .272 .181 r
.23315 .51943 m .24024 .53796 L .22986 .56365 L p F P
0 g
s
.24024 .53796 m
.25022 .55575 L
s
.24024 .53796 m
.25344 .51312 L
s
.159 .641 .352 r
.70761 .80912 m .7303 .79877 L .72185 .81859 L p F P
0 g
s
.159 .641 .352 r
.72185 .81859 m .70015 .82838 L .70761 .80912 L p F P
0 g
s
.70761 .80912 m
.71302 .78794 L
s
.68339 .81815 m
.70761 .80912 L
s
.745 .052 .052 r
.25879 .69448 m .24221 .67846 L .24309 .65218 L p F P
0 g
s
.735 .052 .13 r
.24221 .67846 m .25879 .69448 L .26079 .71983 L p F P
0 g
s
.25879 .69448 m
.2778 .70932 L
s
.25879 .69448 m
.25961 .66843 L
s
.18 .215 .695 r
.54848 .29401 m .53876 .29275 L .54292 .28039 L p F P
0 g
s
.18 .215 .695 r
.54292 .28039 m .55588 .28208 L .54848 .29401 L p F P
0 g
s
.54104 .30862 m
.54848 .29401 L
s
.54848 .29401 m
.55793 .29596 L
s
.418 .015 .621 r
.66082 .32625 m .65309 .31689 L .67685 .31937 L p F P
0 g
s
.418 .015 .621 r
.67685 .31937 m .68589 .33047 L .66082 .32625 L p F P
0 g
s
.6348 .32478 m
.66082 .32625 L
s
.66082 .32625 m
.66698 .33607 L
s
.297 .379 .574 r
.36307 .33599 m .35685 .34779 L .3318 .35728 L p F P
0 g
s
.335 .345 .574 r
.32711 .37108 m .3318 .35728 L .35685 .34779 L p F P
0 g
s
.35685 .34779 m
.38327 .34091 L
s
.3526 .35989 m
.35685 .34779 L
s
.021 .62 .419 r
.65253 .84417 m .67697 .83692 L .66878 .85344 L p F P
0 g
s
.021 .62 .419 r
.66878 .85344 m .64571 .86022 L .65253 .84417 L p F P
0 g
s
.65253 .84417 m
.65788 .8258 L
s
.62706 .85008 m
.65253 .84417 L
s
.104 .26 .695 r
.51899 .29238 m .50917 .29327 L .50344 .28109 L p F P
0 g
s
.076 .27 .695 r
.49064 .28323 m .50344 .28109 L .50917 .29327 L p F P
0 g
s
.50917 .29327 m
.51493 .30813 L
s
.49957 .29486 m
.50917 .29327 L
s
.413 .345 .52 r
.30083 .40016 m .30334 .38467 L .32711 .37108 L p F P
0 g
s
.452 .379 .461 r
.30334 .38467 m .30083 .40016 L .27901 .41744 L p F P
0 g
s
.30083 .40016 m
.30084 .4156 L
s
.30083 .40016 m
.32469 .38502 L
s
.156 .233 .695 r
.53876 .29275 m .52889 .2922 L .52975 .27966 L p F P
0 g
s
.156 .233 .695 r
.52975 .27966 m .54292 .28039 L .53876 .29275 L p F P
0 g
s
.53458 .30779 m
.53876 .29275 L
s
.53876 .29275 m
.54848 .29401 L
s
.687 .096 .281 r
.28412 .75819 m .30473 .77098 L .31122 .7929 L p F P
0 g
s
.673 .167 .281 r
.33304 .80391 m .31122 .7929 L .30473 .77098 L p F P
0 g
s
.30473 .77098 m
.32725 .7825 L
s
.30066 .74756 m
.30473 .77098 L
s
.594 .315 .328 r
.79136 .46382 m .7933 .44607 L .81019 .46775 L p F P
0 g
s
.594 .315 .328 r
.81019 .46775 m .80796 .48638 L .79136 .46382 L p F P
0 g
s
.77224 .44281 m
.79136 .46382 L
s
.7866 .48117 m
.79136 .46382 L
s
.086 .341 .661 r
.44527 .30049 m .43606 .30669 L .41416 .30378 L p F P
0 g
s
.121 .33 .661 r
.40416 .31224 m .41416 .30378 L .43606 .30669 L p F P
0 g
s
.43606 .30669 m
.45845 .3124 L
s
.42793 .31349 m
.43606 .30669 L
s
.131 .248 .695 r
.52889 .2922 m .51899 .29238 L .51654 .27989 L p F P
0 g
s
.104 .26 .695 r
.50344 .28109 m .51654 .27989 L .51899 .29238 L p F P
0 g
s
.51899 .29238 m
.52145 .30754 L
s
.50917 .29327 m
.51899 .29238 L
s
.131 .248 .695 r
.51654 .27989 m .52975 .27966 L .52889 .2922 L p F P
0 g
s
.51899 .29238 m
.52889 .2922 L
s
.52802 .30743 m
.52889 .2922 L
s
.52889 .2922 m
.53876 .29275 L
s
.374 .387 .52 r
.3318 .35728 m .32711 .37108 L .30334 .38467 L p F P
0 g
s
.32469 .38502 m
.32711 .37108 L
s
.32711 .37108 m
.3526 .35989 L
s
.736 .13 .026 r
.24309 .65218 m .22922 .63486 L .23327 .60825 L p F P
0 g
s
.735 .13 .052 r
.22922 .63486 m .24309 .65218 L .24221 .67846 L p F P
0 g
s
.24309 .65218 m
.25961 .66843 L
s
.24309 .65218 m
.24691 .62562 L
s
.568 .476 .104 r
.81771 .57318 m .82675 .55464 L .83427 .58085 L p F P
0 g
s
.568 .476 .104 r
.83427 .58085 m .82492 .59956 L .81771 .57318 L p F P
0 g
s
.80756 .5473 m
.81771 .57318 L
s
.80578 .59087 m
.81771 .57318 L
s
.321 .475 .482 r
.49367 .87392 m .51958 .87492 L .52004 .88726 L p F P
0 g
s
.27 .506 .482 r
.51958 .87492 m .54553 .8746 L .54421 .88697 L p F P
0 g
s
.27 .506 .482 r
.54421 .88697 m .52004 .88726 L .51958 .87492 L p F P
0 g
s
.5192 .85988 m
.51958 .87492 L
s
.215 .531 .482 r
.54553 .8746 m .57133 .87296 L .56824 .88545 L p F P
0 g
s
.215 .531 .482 r
.56824 .88545 m .54421 .88697 L .54553 .8746 L p F P
0 g
s
.54553 .8746 m
.54662 .85954 L
s
.51958 .87492 m
.54553 .8746 L
s
.33 .121 .661 r
.61227 .30363 m .60258 .29775 L .62119 .29265 L p F P
0 g
s
.33 .121 .661 r
.62119 .29265 m .63317 .29997 L .61227 .30363 L p F P
0 g
s
.59093 .3101 m
.61227 .30363 L
s
.61227 .30363 m
.62093 .31015 L
s
.184 .376 .621 r
.40416 .31224 m .39563 .32133 L .3712 .32464 L p F P
0 g
s
.222 .354 .621 r
.36307 .33599 m .3712 .32464 L .39563 .32133 L p F P
0 g
s
.39563 .32133 m
.42097 .32081 L
s
.38865 .33092 m
.39563 .32133 L
s
.558 .271 .419 r
.36346 .83265 m .38728 .84057 L .39481 .85686 L p F P
0 g
s
.526 .328 .419 r
.41839 .86304 m .39481 .85686 L .38728 .84057 L p F P
0 g
s
.38136 .822 m
.38728 .84057 L
s
.38728 .84057 m
.41224 .84718 L
s
.369 .439 .482 r
.46804 .87159 m .49367 .87392 L .49592 .88633 L p F P
0 g
s
.321 .475 .482 r
.52004 .88726 m .49592 .88633 L .49367 .87392 L p F P
0 g
s
.49183 .85881 m
.49367 .87392 L
s
.49367 .87392 m
.51958 .87492 L
s
.594 .315 .328 r
.24682 .4952 m .24313 .47675 L .2599 .45464 L p F P
0 g
s
.621 .33 .256 r
.24313 .47675 m .24682 .4952 L .23315 .51943 L p F P
0 g
s
.24682 .4952 m
.25344 .51312 L
s
.24682 .4952 m
.26321 .47222 L
s
.48 .033 .574 r
.69303 .34207 m .68589 .33047 L .70972 .33746 L p F P
0 g
s
.48 .033 .574 r
.70972 .33746 m .71776 .35074 L .69303 .34207 L p F P
0 g
s
.66698 .33607 m
.69303 .34207 L
s
.69303 .34207 m
.69823 .35404 L
s
.588 .237 .397 r
.77385 .42616 m .77274 .40934 L .79229 .42811 L p F P
0 g
s
.588 .237 .397 r
.79229 .42811 m .7933 .44607 L .77385 .42616 L p F P
0 g
s
.75211 .40819 m
.77385 .42616 L
s
.77224 .44281 m
.77385 .42616 L
s
.159 .551 .482 r
.57133 .87296 m .59677 .87001 L .59191 .88272 L p F P
0 g
s
.159 .551 .482 r
.59191 .88272 m .56824 .88545 L .57133 .87296 L p F P
0 g
s
.57133 .87296 m
.57388 .85779 L
s
.54553 .8746 m
.57133 .87296 L
s
.641 .159 .352 r
.31122 .7929 m .33304 .80391 L .34102 .82345 L p F P
0 g
s
.621 .226 .352 r
.36346 .83265 m .34102 .82345 L .33304 .80391 L p F P
0 g
s
.33304 .80391 m
.3565 .81363 L
s
.32725 .7825 m
.33304 .80391 L
s
.05 .348 .661 r
.45545 .29498 m .44527 .30049 L .42552 .29607 L p F P
0 g
s
.086 .341 .661 r
.41416 .30378 m .42552 .29607 L .44527 .30049 L p F P
0 g
s
.44527 .30049 m
.46542 .30776 L
s
.43606 .30669 m
.44527 .30049 L
s
.381 .61 .206 r
.78235 .7275 m .80007 .71244 L .79502 .73705 L p F P
0 g
s
.381 .61 .206 r
.79502 .73705 m .77768 .7516 L .78235 .7275 L p F P
0 g
s
.78235 .7275 m
.78426 .70234 L
s
.76234 .74135 m
.78235 .7275 L
s
.712 .204 .104 r
.23327 .60825 m .22248 .58994 L .22986 .56365 L p F P
0 g
s
.719 .206 .026 r
.22248 .58994 m .23327 .60825 L .22922 .63486 L p F P
0 g
s
.23327 .60825 m
.24691 .62562 L
s
.23327 .60825 m
.24031 .5818 L
s
.413 .398 .482 r
.44287 .86796 m .46804 .87159 L .47205 .88419 L p F P
0 g
s
.369 .439 .482 r
.49592 .88633 m .47205 .88419 L .46804 .87159 L p F P
0 g
s
.46474 .85633 m
.46804 .87159 L
s
.46804 .87159 m
.49367 .87392 L
s
.567 .162 .461 r
.75091 .3927 m .74717 .37726 L .76884 .39254 L p F P
0 g
s
.567 .162 .461 r
.76884 .39254 m .77274 .40934 L .75091 .3927 L p F P
0 g
s
.72706 .37831 m
.75091 .3927 L
s
.75091 .3927 m
.75211 .40819 L
s
.53 .093 .52 r
.72355 .36441 m .71776 .35074 L .74088 .36205 L p F P
0 g
s
.53 .093 .52 r
.74088 .36205 m .74717 .37726 L .72355 .36441 L p F P
0 g
s
.69823 .35404 m
.72355 .36441 L
s
.72355 .36441 m
.72706 .37831 L
s
.304 .624 .281 r
.75807 .76498 m .77768 .7516 L .77021 .77437 L p F P
0 g
s
.304 .624 .281 r
.77021 .77437 m .75125 .78716 L .75807 .76498 L p F P
0 g
s
.75807 .76498 m
.76234 .74135 L
s
.73644 .77712 m
.75807 .76498 L
s
.454 .581 .13 r
.80213 .68692 m .81746 .67037 L .81526 .69628 L p F P
0 g
s
.454 .581 .13 r
.81526 .69628 m .80007 .71244 L .80213 .68692 L p F P
0 g
s
.80128 .66076 m
.80213 .68692 L
s
.78426 .70234 m
.80213 .68692 L
s
.414 .059 .621 r
.65309 .31689 m .64384 .30809 L .66598 .30893 L p F P
0 g
s
.414 .059 .621 r
.66598 .30893 m .67685 .31937 L .65309 .31689 L p F P
0 g
s
.62846 .31723 m
.65309 .31689 L
s
.65309 .31689 m
.66082 .32625 L
s
.602 .406 .181 r
.81618 .52913 m .82181 .51031 L .83271 .53541 L p F P
0 g
s
.602 .406 .181 r
.83271 .53541 m .82675 .55464 L .81618 .52913 L p F P
0 g
s
.80273 .50457 m
.81618 .52913 L
s
.80756 .5473 m
.81618 .52913 L
s
.086 .614 .419 r
.67697 .83692 m .70015 .82838 L .69065 .84546 L p F P
0 g
s
.086 .614 .419 r
.69065 .84546 m .66878 .85344 L .67697 .83692 L p F P
0 g
s
.67697 .83692 m
.68339 .81815 L
s
.65253 .84417 m
.67697 .83692 L
s
.315 .155 .661 r
.60258 .29775 m .59197 .29259 L .60804 .28621 L p F P
0 g
s
.315 .155 .661 r
.60804 .28621 m .62119 .29265 L .60258 .29775 L p F P
0 g
s
.5836 .3057 m
.60258 .29775 L
s
.60258 .29775 m
.61227 .30363 L
s
.1 .564 .482 r
.59677 .87001 m .62163 .86575 L .61504 .8788 L p F P
0 g
s
.1 .564 .482 r
.61504 .8788 m .59191 .88272 L .59677 .87001 L p F P
0 g
s
.59677 .87001 m
.60077 .85463 L
s
.57133 .87296 m
.59677 .87001 L
s
.526 .354 .397 r
.2599 .45464 m .25949 .43676 L .27901 .41744 L p F P
0 g
s
.558 .376 .328 r
.25949 .43676 m .2599 .45464 L .24313 .47675 L p F P
0 g
s
.2599 .45464 m
.26321 .47222 L
s
.2599 .45464 m
.27922 .4342 L
s
.255 .407 .574 r
.3712 .32464 m .36307 .33599 L .33876 .34379 L p F P
0 g
s
.297 .379 .574 r
.3318 .35728 m .33876 .34379 L .36307 .33599 L p F P
0 g
s
.35685 .34779 m
.36307 .33599 L
s
.36307 .33599 m
.38865 .33092 L
s
.518 .537 .052 r
.81656 .64398 m .82907 .62619 L .83002 .65281 L p F P
0 g
s
.518 .537 .052 r
.83002 .65281 m .81746 .67037 L .81656 .64398 L p F P
0 g
s
.81263 .6174 m
.81656 .64398 L
s
.80128 .66076 m
.81656 .64398 L
s
.013 .351 .661 r
.4665 .29022 m .45545 .29498 L .43813 .28919 L p F P
0 g
s
.05 .348 .661 r
.42552 .29607 m .43813 .28919 L .45545 .29498 L p F P
0 g
s
.45545 .29498 m
.47311 .30363 L
s
.44527 .30049 m
.45545 .29498 L
s
.452 .352 .482 r
.41839 .86304 m .44287 .86796 L .44863 .88083 L p F P
0 g
s
.413 .398 .482 r
.47205 .88419 m .44863 .88083 L .44287 .86796 L p F P
0 g
s
.43813 .85244 m
.44287 .86796 L
s
.44287 .86796 m
.46804 .87159 L
s
.226 .621 .352 r
.7303 .79877 m .75125 .78716 L .74186 .80762 L p F P
0 g
s
.226 .621 .352 r
.74186 .80762 m .72185 .81859 L .7303 .79877 L p F P
0 g
s
.7303 .79877 m
.73644 .77712 L
s
.70761 .80912 m
.7303 .79877 L
s
.144 .393 .621 r
.41416 .30378 m .40416 .31224 L .3812 .31386 L p F P
0 g
s
.184 .376 .621 r
.3712 .32464 m .3812 .31386 L .40416 .31224 L p F P
0 g
s
.40416 .31224 m
.42793 .31349 L
s
.39563 .32133 m
.40416 .31224 L
s
.673 .272 .181 r
.22986 .56365 m .2224 .54473 L .23315 .51943 L p F P
0 g
s
.687 .277 .104 r
.2224 .54473 m .22986 .56365 L .22248 .58994 L p F P
0 g
s
.22986 .56365 m
.24031 .5818 L
s
.22986 .56365 m
.24024 .53796 L
s
.452 .379 .461 r
.27901 .41744 m .28156 .40061 L .30334 .38467 L p F P
0 g
s
.486 .407 .397 r
.28156 .40061 m .27901 .41744 L .25949 .43676 L p F P
0 g
s
.27901 .41744 m
.27922 .4342 L
s
.27901 .41744 m
.30083 .40016 L
s
.621 .33 .256 r
.80796 .48638 m .81019 .46775 L .8243 .49102 L p F P
0 g
s
.621 .33 .256 r
.8243 .49102 m .82181 .51031 L .80796 .48638 L p F P
0 g
s
.79136 .46382 m
.80796 .48638 L
s
.80273 .50457 m
.80796 .48638 L
s
.297 .187 .661 r
.59197 .29259 m .58055 .28822 L .59387 .28075 L p F P
0 g
s
.297 .187 .661 r
.59387 .28075 m .60804 .28621 L .59197 .29259 L p F P
0 g
s
.5756 .30185 m
.59197 .29259 L
s
.59197 .29259 m
.60258 .29775 L
s
.332 .424 .52 r
.33876 .34379 m .3318 .35728 L .3084 .36933 L p F P
0 g
s
.374 .387 .52 r
.30334 .38467 m .3084 .36933 L .3318 .35728 L p F P
0 g
s
.3318 .35728 m
.35685 .34779 L
s
.32711 .37108 m
.3318 .35728 L
s
.583 .212 .419 r
.34102 .82345 m .36346 .83265 L .37233 .84945 L p F P
0 g
s
.558 .271 .419 r
.39481 .85686 m .37233 .84945 L .36346 .83265 L p F P
0 g
s
.36346 .83265 m
.38728 .84057 L
s
.3565 .81363 m
.36346 .83265 L
s
.041 .572 .482 r
.62163 .86575 m .64571 .86022 L .63742 .8737 L p F P
0 g
s
.041 .572 .482 r
.63742 .8737 m .61504 .8788 L .62163 .86575 L p F P
0 g
s
.62163 .86575 m
.62706 .85008 L
s
.59677 .87001 m
.62163 .86575 L
s
.41 .424 .461 r
.3084 .36933 m .30334 .38467 L .28156 .40061 L p F P
0 g
s
.30083 .40016 m
.30334 .38467 L
s
.30334 .38467 m
.32711 .37108 L
s
.735 .052 .13 r
.26079 .71983 m .24435 .70418 L .24221 .67846 L p F P
0 g
s
.717 .05 .206 r
.24435 .70418 m .26079 .71983 L .26566 .74419 L p F P
0 g
s
.719 .025 .206 r
.28412 .75819 m .26566 .74419 L .26079 .71983 L p F P
0 g
s
.26079 .71983 m
.27964 .73432 L
s
.25879 .69448 m
.26079 .71983 L
s
.481 .017 .574 r
.68589 .33047 m .67685 .31937 L .69948 .32474 L p F P
0 g
s
.481 .017 .574 r
.69948 .32474 m .70972 .33746 L .68589 .33047 L p F P
0 g
s
.66082 .32625 m
.68589 .33047 L
s
.68589 .33047 m
.69303 .34207 L
s
.024 .35 .661 r
.47827 .28629 m .4665 .29022 L .45183 .28325 L p F P
0 g
s
.013 .351 .661 r
.43813 .28919 m .45183 .28325 L .4665 .29022 L p F P
0 g
s
.4665 .29022 m
.48143 .30008 L
s
.45545 .29498 m
.4665 .29022 L
s
.693 .024 .281 r
.26566 .74419 m .28412 .75819 L .29128 .78067 L p F P
0 g
s
.687 .096 .281 r
.31122 .7929 m .29128 .78067 L .28412 .75819 L p F P
0 g
s
.28412 .75819 m
.30473 .77098 L
s
.27964 .73432 m
.28412 .75819 L
s
.406 .102 .621 r
.64384 .30809 m .63317 .29997 L .6534 .29928 L p F P
0 g
s
.406 .102 .621 r
.6534 .29928 m .66598 .30893 L .64384 .30809 L p F P
0 g
s
.62093 .31015 m
.64384 .30809 L
s
.64384 .30809 m
.65309 .31689 L
s
.573 .481 .026 r
.82492 .59956 m .83427 .58085 L .83859 .60753 L p F P
0 g
s
.573 .481 .026 r
.83859 .60753 m .82907 .62619 L .82492 .59956 L p F P
0 g
s
.81771 .57318 m
.82492 .59956 L
s
.81263 .6174 m
.82492 .59956 L
s
.735 .13 .052 r
.24221 .67846 m .22829 .66137 L .22922 .63486 L p F P
0 g
s
.726 .128 .13 r
.22829 .66137 m .24221 .67846 L .24435 .70418 L p F P
0 g
s
.24221 .67846 m
.25879 .69448 L
s
.24221 .67846 m
.24309 .65218 L
s
.276 .217 .661 r
.58055 .28822 m .56848 .28471 L .57885 .27635 L p F P
0 g
s
.276 .217 .661 r
.57885 .27635 m .59387 .28075 L .58055 .28822 L p F P
0 g
s
.56701 .29859 m
.58055 .28822 L
s
.58055 .28822 m
.59197 .29259 L
s
.621 .33 .256 r
.23315 .51943 m .22913 .50035 L .24313 .47675 L p F P
0 g
s
.641 .341 .181 r
.22913 .50035 m .23315 .51943 L .2224 .54473 L p F P
0 g
s
.23315 .51943 m
.24024 .53796 L
s
.23315 .51943 m
.24682 .4952 L
s
.624 .252 .328 r
.7933 .44607 m .79229 .42811 L .8093 .44887 L p F P
0 g
s
.624 .252 .328 r
.8093 .44887 m .81019 .46775 L .7933 .44607 L p F P
0 g
s
.77385 .42616 m
.7933 .44607 L
s
.79136 .46382 m
.7933 .44607 L
s
.486 .303 .482 r
.39481 .85686 m .41839 .86304 L .42587 .8763 L p F P
0 g
s
.452 .352 .482 r
.44863 .88083 m .42587 .8763 L .41839 .86304 L p F P
0 g
s
.41224 .84718 m
.41839 .86304 L
s
.41839 .86304 m
.44287 .86796 L
s
.654 .092 .352 r
.29128 .78067 m .31122 .7929 L .32017 .81304 L p F P
0 g
s
.641 .159 .352 r
.34102 .82345 m .32017 .81304 L .31122 .7929 L p F P
0 g
s
.31122 .7929 m
.33304 .80391 L
s
.30473 .77098 m
.31122 .7929 L
s
.06 .346 .661 r
.49064 .28323 m .47827 .28629 L .46646 .27833 L p F P
0 g
s
.024 .35 .661 r
.45183 .28325 m .46646 .27833 L .47827 .28629 L p F P
0 g
s
.47827 .28629 m
.49028 .29714 L
s
.4665 .29022 m
.47827 .28629 L
s
.15 .602 .419 r
.70015 .82838 m .72185 .81859 L .7111 .83632 L p F P
0 g
s
.15 .602 .419 r
.7111 .83632 m .69065 .84546 L .70015 .82838 L p F P
0 g
s
.70015 .82838 m
.70761 .80912 L
s
.67697 .83692 m
.70015 .82838 L
s
.102 .406 .621 r
.42552 .29607 m .41416 .30378 L .39297 .30381 L p F P
0 g
s
.144 .393 .621 r
.3812 .31386 m .39297 .30381 L .41416 .30378 L p F P
0 g
s
.41416 .30378 m
.43606 .30669 L
s
.40416 .31224 m
.41416 .30378 L
s
.537 .037 .52 r
.71776 .35074 m .70972 .33746 L .73205 .34724 L p F P
0 g
s
.537 .037 .52 r
.73205 .34724 m .74088 .36205 L .71776 .35074 L p F P
0 g
s
.69303 .34207 m
.71776 .35074 L
s
.71776 .35074 m
.72355 .36441 L
s
.252 .245 .661 r
.56848 .28471 m .55588 .28208 L .56317 .27307 L p F P
0 g
s
.252 .245 .661 r
.56317 .27307 m .57885 .27635 L .56848 .28471 L p F P
0 g
s
.55793 .29596 m
.56848 .28471 L
s
.56848 .28471 m
.58055 .28822 L
s
.211 .432 .574 r
.3812 .31386 m .3712 .32464 L .34796 .33078 L p F P
0 g
s
.255 .407 .574 r
.33876 .34379 m .34796 .33078 L .3712 .32464 L p F P
0 g
s
.36307 .33599 m
.3712 .32464 L
s
.3712 .32464 m
.39563 .32133 L
s
.61 .174 .397 r
.77274 .40934 m .76884 .39254 L .78827 .41015 L p F P
0 g
s
.61 .174 .397 r
.78827 .41015 m .79229 .42811 L .77274 .40934 L p F P
0 g
s
.75091 .3927 m
.77274 .40934 L
s
.77274 .40934 m
.77385 .42616 L
s
.719 .206 .026 r
.22922 .63486 m .21824 .6166 L .22248 .58994 L p F P
0 g
s
.717 .206 .052 r
.21824 .6166 m .22922 .63486 L .22829 .66137 L p F P
0 g
s
.22922 .63486 m
.24309 .65218 L
s
.22922 .63486 m
.23327 .60825 L
s
.614 .414 .104 r
.82675 .55464 m .83271 .53541 L .84047 .56144 L p F P
0 g
s
.614 .414 .104 r
.84047 .56144 m .83427 .58085 L .82675 .55464 L p F P
0 g
s
.81618 .52913 m
.82675 .55464 L
s
.81771 .57318 m
.82675 .55464 L
s
.019 .573 .482 r
.64571 .86022 m .66878 .85344 L .65885 .86746 L p F P
0 g
s
.019 .573 .482 r
.65885 .86746 m .63742 .8737 L .64571 .86022 L p F P
0 g
s
.64571 .86022 m
.65253 .84417 L
s
.62163 .86575 m
.64571 .86022 L
s
.581 .102 .461 r
.74717 .37726 m .74088 .36205 L .76212 .37595 L p F P
0 g
s
.581 .102 .461 r
.76212 .37595 m .76884 .39254 L .74717 .37726 L p F P
0 g
s
.72355 .36441 m
.74717 .37726 L
s
.74717 .37726 m
.75091 .3927 L
s
.096 .338 .661 r
.50344 .28109 m .49064 .28323 L .48185 .27451 L p F P
0 g
s
.06 .346 .661 r
.46646 .27833 m .48185 .27451 L .49064 .28323 L p F P
0 g
s
.49064 .28323 m
.49957 .29486 L
s
.47827 .28629 m
.49064 .28323 L
s
.225 .27 .661 r
.55588 .28208 m .54292 .28039 L .54701 .27096 L p F P
0 g
s
.225 .27 .661 r
.54701 .27096 m .56317 .27307 L .55588 .28208 L p F P
0 g
s
.54848 .29401 m
.55588 .28208 L
s
.55588 .28208 m
.56848 .28471 L
s
.558 .376 .328 r
.24313 .47675 m .24251 .45797 L .25949 .43676 L p F P
0 g
s
.583 .393 .256 r
.24251 .45797 m .24313 .47675 L .22913 .50035 L p F P
0 g
s
.24313 .47675 m
.24682 .4952 L
s
.24313 .47675 m
.2599 .45464 L
s
.393 .144 .621 r
.63317 .29997 m .62119 .29265 L .63924 .29056 L p F P
0 g
s
.393 .144 .621 r
.63924 .29056 m .6534 .29928 L .63317 .29997 L p F P
0 g
s
.61227 .30363 m
.63317 .29997 L
s
.63317 .29997 m
.64384 .30809 L
s
.367 .588 .281 r
.77768 .7516 m .79502 .73705 L .78697 .76047 L p F P
0 g
s
.367 .588 .281 r
.78697 .76047 m .77021 .77437 L .77768 .7516 L p F P
0 g
s
.77768 .7516 m
.78235 .7275 L
s
.75807 .76498 m
.77768 .7516 L
s
.443 .567 .206 r
.80007 .71244 m .81526 .69628 L .80988 .72145 L p F P
0 g
s
.443 .567 .206 r
.80988 .72145 m .79502 .73705 L .80007 .71244 L p F P
0 g
s
.80007 .71244 m
.80213 .68692 L
s
.78235 .7275 m
.80007 .71244 L
s
.131 .326 .661 r
.51654 .27989 m .50344 .28109 L .4978 .27183 L p F P
0 g
s
.096 .338 .661 r
.48185 .27451 m .4978 .27183 L .50344 .28109 L p F P
0 g
s
.50344 .28109 m
.50917 .29327 L
s
.49064 .28323 m
.50344 .28109 L
s
.196 .292 .661 r
.54292 .28039 m .52975 .27966 L .53059 .27004 L p F P
0 g
s
.196 .292 .661 r
.53059 .27004 m .54701 .27096 L .54292 .28039 L p F P
0 g
s
.53876 .29275 m
.54292 .28039 L
s
.54292 .28039 m
.55588 .28208 L
s
.164 .311 .661 r
.52975 .27966 m .51654 .27989 L .51412 .27033 L p F P
0 g
s
.131 .326 .661 r
.4978 .27183 m .51412 .27033 L .51654 .27989 L p F P
0 g
s
.51654 .27989 m
.51899 .29238 L
s
.50344 .28109 m
.51654 .27989 L
s
.164 .311 .661 r
.51412 .27033 m .53059 .27004 L .52975 .27966 L p F P
0 g
s
.51654 .27989 m
.52975 .27966 L
s
.52889 .2922 m
.52975 .27966 L
s
.52975 .27966 m
.54292 .28039 L
s
.602 .15 .419 r
.32017 .81304 m .34102 .82345 L .35118 .84086 L p F P
0 g
s
.583 .212 .419 r
.37233 .84945 m .35118 .84086 L .34102 .82345 L p F P
0 g
s
.34102 .82345 m
.36346 .83265 L
s
.33304 .80391 m
.34102 .82345 L
s
.476 .068 .574 r
.67685 .31937 m .66598 .30893 L .68711 .31275 L p F P
0 g
s
.476 .068 .574 r
.68711 .31275 m .69948 .32474 L .67685 .31937 L p F P
0 g
s
.65309 .31689 m
.67685 .31937 L
s
.67685 .31937 m
.68589 .33047 L
s
.289 .594 .352 r
.75125 .78716 m .77021 .77437 L .75995 .79554 L p F P
0 g
s
.289 .594 .352 r
.75995 .79554 m .74186 .80762 L .75125 .78716 L p F P
0 g
s
.75125 .78716 m
.75807 .76498 L
s
.7303 .79877 m
.75125 .78716 L
s
.515 .251 .482 r
.37233 .84945 m .39481 .85686 L .40396 .8706 L p F P
0 g
s
.486 .303 .482 r
.42587 .8763 m .40396 .8706 L .39481 .85686 L p F P
0 g
s
.38728 .84057 m
.39481 .85686 L
s
.39481 .85686 m
.41839 .86304 L
s
.687 .277 .104 r
.22248 .58994 m .21474 .57085 L .2224 .54473 L p F P
0 g
s
.693 .28 .026 r
.21474 .57085 m .22248 .58994 L .21824 .6166 L p F P
0 g
s
.22248 .58994 m
.23327 .60825 L
s
.22248 .58994 m
.22986 .56365 L
s
.512 .53 .13 r
.81746 .67037 m .83002 .65281 L .8277 .67915 L p F P
0 g
s
.512 .53 .13 r
.8277 .67915 m .81526 .69628 L .81746 .67037 L p F P
0 g
s
.81656 .64398 m
.81746 .67037 L
s
.80213 .68692 m
.81746 .67037 L
s
.286 .456 .52 r
.34796 .33078 m .33876 .34379 L .31602 .3543 L p F P
0 g
s
.332 .424 .52 r
.3084 .36933 m .31602 .3543 L .33876 .34379 L p F P
0 g
s
.3318 .35728 m
.33876 .34379 L
s
.33876 .34379 m
.36307 .33599 L
s
.059 .414 .621 r
.43813 .28919 m .42552 .29607 L .40639 .29463 L p F P
0 g
s
.102 .406 .621 r
.39297 .30381 m .40639 .29463 L .42552 .29607 L p F P
0 g
s
.42552 .29607 m
.44527 .30049 L
s
.41416 .30378 m
.42552 .29607 L
s
.291 .431 .539 r
.49592 .88633 m .52004 .88726 L .52058 .89666 L p F P
0 g
s
.245 .459 .539 r
.52004 .88726 m .54421 .88697 L .54266 .8964 L p F P
0 g
s
.245 .459 .539 r
.54266 .8964 m .52058 .89666 L .52004 .88726 L p F P
0 g
s
.51958 .87492 m
.52004 .88726 L
s
.486 .407 .397 r
.25949 .43676 m .26205 .41878 L .28156 .40061 L p F P
0 g
s
.515 .432 .328 r
.26205 .41878 m .25949 .43676 L .24251 .45797 L p F P
0 g
s
.25949 .43676 m
.2599 .45464 L
s
.25949 .43676 m
.27901 .41744 L
s
.641 .341 .181 r
.82181 .51031 m .8243 .49102 L .83542 .51569 L p F P
0 g
s
.641 .341 .181 r
.83542 .51569 m .83271 .53541 L .82181 .51031 L p F P
0 g
s
.80796 .48638 m
.82181 .51031 L
s
.81618 .52913 m
.82181 .51031 L
s
.195 .482 .539 r
.54421 .88697 m .56824 .88545 L .5646 .89502 L p F P
0 g
s
.195 .482 .539 r
.5646 .89502 m .54266 .8964 L .54421 .88697 L p F P
0 g
s
.54421 .88697 m
.54553 .8746 L
s
.52004 .88726 m
.54421 .88697 L
s
.335 .398 .539 r
.47205 .88419 m .49592 .88633 L .49856 .89582 L p F P
0 g
s
.291 .431 .539 r
.52058 .89666 m .49856 .89582 L .49592 .88633 L p F P
0 g
s
.49367 .87392 m
.49592 .88633 L
s
.49592 .88633 m
.52004 .88726 L
s
.363 .464 .461 r
.31602 .3543 m .3084 .36933 L .28693 .38389 L p F P
0 g
s
.41 .424 .461 r
.28156 .40061 m .28693 .38389 L .3084 .36933 L p F P
0 g
s
.3084 .36933 m
.3318 .35728 L
s
.30334 .38467 m
.3084 .36933 L
s
.441 .456 .397 r
.28693 .38389 m .28156 .40061 L .26205 .41878 L p F P
0 g
s
.27901 .41744 m
.28156 .40061 L
s
.28156 .40061 m
.30334 .38467 L
s
.144 .499 .539 r
.56824 .88545 m .59191 .88272 L .58621 .89255 L p F P
0 g
s
.144 .499 .539 r
.58621 .89255 m .5646 .89502 L .56824 .88545 L p F P
0 g
s
.56824 .88545 m
.57133 .87296 L
s
.54421 .88697 m
.56824 .88545 L
s
.376 .184 .621 r
.62119 .29265 m .60804 .28621 L .62365 .28288 L p F P
0 g
s
.376 .184 .621 r
.62365 .28288 m .63924 .29056 L .62119 .29265 L p F P
0 g
s
.60258 .29775 m
.62119 .29265 L
s
.62119 .29265 m
.63317 .29997 L
s
.079 .568 .482 r
.66878 .85344 m .69065 .84546 L .67914 .86011 L p F P
0 g
s
.079 .568 .482 r
.67914 .86011 m .65885 .86746 L .66878 .85344 L p F P
0 g
s
.66878 .85344 m
.67697 .83692 L
s
.64571 .86022 m
.66878 .85344 L
s
.165 .452 .574 r
.39297 .30381 m .3812 .31386 L .35931 .31842 L p F P
0 g
s
.211 .432 .574 r
.34796 .33078 m .35931 .31842 L .3812 .31386 L p F P
0 g
s
.3812 .31386 m
.40416 .31224 L
s
.3712 .32464 m
.3812 .31386 L
s
.572 .48 .052 r
.82907 .62619 m .83859 .60753 L .83959 .6344 L p F P
0 g
s
.572 .48 .052 r
.83959 .6344 m .83002 .65281 L .82907 .62619 L p F P
0 g
s
.82492 .59956 m
.82907 .62619 L
s
.81656 .64398 m
.82907 .62619 L
s
.374 .361 .539 r
.44863 .88083 m .47205 .88419 L .47676 .89387 L p F P
0 g
s
.335 .398 .539 r
.49856 .89582 m .47676 .89387 L .47205 .88419 L p F P
0 g
s
.46804 .87159 m
.47205 .88419 L
s
.47205 .88419 m
.49592 .88633 L
s
.212 .583 .419 r
.72185 .81859 m .74186 .80762 L .72992 .82609 L p F P
0 g
s
.212 .583 .419 r
.72992 .82609 m .7111 .83632 L .72185 .81859 L p F P
0 g
s
.72185 .81859 m
.7303 .79877 L
s
.70015 .82838 m
.72185 .81859 L
s
.641 .341 .181 r
.2224 .54473 m .2181 .52522 L .22913 .50035 L p F P
0 g
s
.654 .348 .104 r
.2181 .52522 m .2224 .54473 L .21474 .57085 L p F P
0 g
s
.2224 .54473 m
.22986 .56365 L
s
.2224 .54473 m
.23315 .51943 L
s
.652 .263 .256 r
.81019 .46775 m .8093 .44887 L .82352 .47146 L p F P
0 g
s
.652 .263 .256 r
.82352 .47146 m .8243 .49102 L .81019 .46775 L p F P
0 g
s
.7933 .44607 m
.81019 .46775 L
s
.80796 .48638 m
.81019 .46775 L
s
.717 .05 .206 r
.26566 .74419 m .24957 .72908 L .24435 .70418 L p F P
0 g
s
.692 .049 .281 r
.24957 .72908 m .26566 .74419 L .27343 .76729 L p F P
0 g
s
.693 .024 .281 r
.29128 .78067 m .27343 .76729 L .26566 .74419 L p F P
0 g
s
.26566 .74419 m
.28412 .75819 L
s
.26079 .71983 m
.26566 .74419 L
s
.538 .019 .52 r
.70972 .33746 m .69948 .32474 L .72071 .33304 L p F P
0 g
s
.538 .019 .52 r
.72071 .33304 m .73205 .34724 L .70972 .33746 L p F P
0 g
s
.68589 .33047 m
.70972 .33746 L
s
.70972 .33746 m
.71776 .35074 L
s
.091 .512 .539 r
.59191 .88272 m .61504 .8788 L .60731 .88899 L p F P
0 g
s
.091 .512 .539 r
.60731 .88899 m .58621 .89255 L .59191 .88272 L p F P
0 g
s
.59191 .88272 m
.59677 .87001 L
s
.56824 .88545 m
.59191 .88272 L
s
.015 .418 .621 r
.45183 .28325 m .43813 .28919 L .42132 .28644 L p F P
0 g
s
.059 .414 .621 r
.40639 .29463 m .42132 .28644 L .43813 .28919 L p F P
0 g
s
.43813 .28919 m
.45545 .29498 L
s
.42552 .29607 m
.43813 .28919 L
s
.726 .128 .13 r
.24435 .70418 m .23056 .6875 L .22829 .66137 L p F P
0 g
s
.708 .125 .206 r
.23056 .6875 m .24435 .70418 L .24957 .72908 L p F P
0 g
s
.24435 .70418 m
.26079 .71983 L
s
.24221 .67846 m
.24435 .70418 L
s
.66 .023 .352 r
.27343 .76729 m .29128 .78067 L .30113 .80148 L p F P
0 g
s
.654 .092 .352 r
.32017 .81304 m .30113 .80148 L .29128 .78067 L p F P
0 g
s
.29128 .78067 m
.31122 .7929 L
s
.28412 .75819 m
.29128 .78067 L
s
.466 .117 .574 r
.66598 .30893 m .6534 .29928 L .67274 .30166 L p F P
0 g
s
.466 .117 .574 r
.67274 .30166 m .68711 .31275 L .66598 .30893 L p F P
0 g
s
.64384 .30809 m
.66598 .30893 L
s
.66598 .30893 m
.67685 .31937 L
s
.539 .195 .482 r
.35118 .84086 m .37233 .84945 L .3831 .86378 L p F P
0 g
s
.515 .251 .482 r
.40396 .8706 m .3831 .86378 L .37233 .84945 L p F P
0 g
s
.36346 .83265 m
.37233 .84945 L
s
.37233 .84945 m
.39481 .85686 L
s
.41 .319 .539 r
.42587 .8763 m .44863 .88083 L .4554 .89084 L p F P
0 g
s
.374 .361 .539 r
.47676 .89387 m .4554 .89084 L .44863 .88083 L p F P
0 g
s
.44287 .86796 m
.44863 .88083 L
s
.44863 .88083 m
.47205 .88419 L
s
.647 .185 .328 r
.79229 .42811 m .78827 .41015 L .8052 .42997 L p F P
0 g
s
.647 .185 .328 r
.8052 .42997 m .8093 .44887 L .79229 .42811 L p F P
0 g
s
.77274 .40934 m
.79229 .42811 L
s
.79229 .42811 m
.7933 .44607 L
s
.354 .222 .621 r
.60804 .28621 m .59387 .28075 L .60682 .27637 L p F P
0 g
s
.354 .222 .621 r
.60682 .27637 m .62365 .28288 L .60804 .28621 L p F P
0 g
s
.59197 .29259 m
.60804 .28621 L
s
.60804 .28621 m
.62119 .29265 L
s
.62 .418 .026 r
.83427 .58085 m .84047 .56144 L .84493 .58816 L p F P
0 g
s
.62 .418 .026 r
.84493 .58816 m .83859 .60753 L .83427 .58085 L p F P
0 g
s
.82675 .55464 m
.83427 .58085 L
s
.82492 .59956 m
.83427 .58085 L
s
.588 .041 .461 r
.74088 .36205 m .73205 .34724 L .75258 .35979 L p F P
0 g
s
.588 .041 .461 r
.75258 .35979 m .76212 .37595 L .74088 .36205 L p F P
0 g
s
.71776 .35074 m
.74088 .36205 L
s
.74088 .36205 m
.74717 .37726 L
s
.717 .206 .052 r
.22829 .66137 m .21726 .64335 L .21824 .6166 L p F P
0 g
s
.708 .203 .13 r
.21726 .64335 m .22829 .66137 L .23056 .6875 L p F P
0 g
s
.22829 .66137 m
.24221 .67846 L
s
.22829 .66137 m
.22922 .63486 L
s
.625 .11 .397 r
.76884 .39254 m .76212 .37595 L .78119 .39239 L p F P
0 g
s
.625 .11 .397 r
.78119 .39239 m .78827 .41015 L .76884 .39254 L p F P
0 g
s
.74717 .37726 m
.76884 .39254 L
s
.76884 .39254 m
.77274 .40934 L
s
.583 .393 .256 r
.22913 .50035 m .22832 .48089 L .24251 .45797 L p F P
0 g
s
.602 .406 .181 r
.22832 .48089 m .22913 .50035 L .2181 .52522 L p F P
0 g
s
.22913 .50035 m
.23315 .51943 L
s
.22913 .50035 m
.24313 .47675 L
s
.037 .518 .539 r
.61504 .8788 m .63742 .8737 L .6277 .88437 L p F P
0 g
s
.037 .518 .539 r
.6277 .88437 m .60731 .88899 L .61504 .8788 L p F P
0 g
s
.61504 .8788 m
.62163 .86575 L
s
.59191 .88272 m
.61504 .8788 L
s
.614 .086 .419 r
.30113 .80148 m .32017 .81304 L .33155 .83115 L p F P
0 g
s
.602 .15 .419 r
.35118 .84086 m .33155 .83115 L .32017 .81304 L p F P
0 g
s
.32017 .81304 m
.34102 .82345 L
s
.31122 .7929 m
.32017 .81304 L
s
.028 .417 .621 r
.46646 .27833 m .45183 .28325 L .43758 .27935 L p F P
0 g
s
.015 .418 .621 r
.42132 .28644 m .43758 .27935 L .45183 .28325 L p F P
0 g
s
.45183 .28325 m
.4665 .29022 L
s
.43813 .28919 m
.45183 .28325 L
s
.236 .483 .52 r
.35931 .31842 m .34796 .33078 L .32616 .33978 L p F P
0 g
s
.286 .456 .52 r
.31602 .3543 m .32616 .33978 L .34796 .33078 L p F P
0 g
s
.33876 .34379 m
.34796 .33078 L
s
.34796 .33078 m
.3712 .32464 L
s
.117 .466 .574 r
.40639 .29463 m .39297 .30381 L .37274 .30687 L p F P
0 g
s
.165 .452 .574 r
.35931 .31842 m .37274 .30687 L .39297 .30381 L p F P
0 g
s
.39297 .30381 m
.41416 .30378 L
s
.3812 .31386 m
.39297 .30381 L
s
.138 .556 .482 r
.69065 .84546 m .7111 .83632 L .69807 .85171 L p F P
0 g
s
.138 .556 .482 r
.69807 .85171 m .67914 .86011 L .69065 .84546 L p F P
0 g
s
.69065 .84546 m
.70015 .82838 L
s
.66878 .85344 m
.69065 .84546 L
s
.427 .547 .281 r
.79502 .73705 m .80988 .72145 L .8013 .74558 L p F P
0 g
s
.427 .547 .281 r
.8013 .74558 m .78697 .76047 L .79502 .73705 L p F P
0 g
s
.79502 .73705 m
.80007 .71244 L
s
.77768 .7516 m
.79502 .73705 L
s
.329 .258 .621 r
.59387 .28075 m .57885 .27635 L .58895 .27111 L p F P
0 g
s
.329 .258 .621 r
.58895 .27111 m .60682 .27637 L .59387 .28075 L p F P
0 g
s
.58055 .28822 m
.59387 .28075 L
s
.59387 .28075 m
.60804 .28621 L
s
.693 .28 .026 r
.21824 .6166 m .21034 .59755 L .21474 .57085 L p F P
0 g
s
.692 .28 .052 r
.21034 .59755 m .21824 .6166 L .21726 .64335 L p F P
0 g
s
.21824 .6166 m
.22922 .63486 L
s
.21824 .6166 m
.22248 .58994 L
s
.441 .275 .539 r
.40396 .8706 m .42587 .8763 L .43464 .88673 L p F P
0 g
s
.41 .319 .539 r
.4554 .89084 m .43464 .88673 L .42587 .8763 L p F P
0 g
s
.41839 .86304 m
.42587 .8763 L
s
.42587 .8763 m
.44863 .88083 L
s
.35 .56 .352 r
.77021 .77437 m .78697 .76047 L .7759 .78242 L p F P
0 g
s
.35 .56 .352 r
.7759 .78242 m .75995 .79554 L .77021 .77437 L p F P
0 g
s
.77021 .77437 m
.77768 .7516 L
s
.75125 .78716 m
.77021 .77437 L
s
.654 .348 .104 r
.83271 .53541 m .83542 .51569 L .84334 .54152 L p F P
0 g
s
.654 .348 .104 r
.84334 .54152 m .84047 .56144 L .83271 .53541 L p F P
0 g
s
.82181 .51031 m
.83271 .53541 L
s
.82675 .55464 m
.83271 .53541 L
s
.515 .432 .328 r
.24251 .45797 m .24506 .43905 L .26205 .41878 L p F P
0 g
s
.539 .452 .256 r
.24506 .43905 m .24251 .45797 L .22832 .48089 L p F P
0 g
s
.24251 .45797 m
.24313 .47675 L
s
.24251 .45797 m
.25949 .43676 L
s
.499 .518 .206 r
.81526 .69628 m .8277 .67915 L .82203 .70491 L p F P
0 g
s
.499 .518 .206 r
.82203 .70491 m .80988 .72145 L .81526 .69628 L p F P
0 g
s
.81526 .69628 m
.81746 .67037 L
s
.80007 .71244 m
.81526 .69628 L
s
.072 .412 .621 r
.48185 .27451 m .46646 .27833 L .45497 .27348 L p F P
0 g
s
.028 .417 .621 r
.43758 .27935 m .45497 .27348 L .46646 .27833 L p F P
0 g
s
.46646 .27833 m
.47827 .28629 L
s
.45183 .28325 m
.46646 .27833 L
s
.313 .5 .461 r
.32616 .33978 m .31602 .3543 L .29511 .3675 L p F P
0 g
s
.363 .464 .461 r
.28693 .38389 m .29511 .3675 L .31602 .3543 L p F P
0 g
s
.3084 .36933 m
.31602 .3543 L
s
.31602 .3543 m
.33876 .34379 L
s
.452 .165 .574 r
.6534 .29928 m .63924 .29056 L .65651 .29161 L p F P
0 g
s
.452 .165 .574 r
.65651 .29161 m .67274 .30166 L .6534 .29928 L p F P
0 g
s
.63317 .29997 m
.6534 .29928 L
s
.6534 .29928 m
.66598 .30893 L
s
.533 .076 .52 r
.69948 .32474 m .68711 .31275 L .70697 .31963 L p F P
0 g
s
.533 .076 .52 r
.70697 .31963 m .72071 .33304 L .69948 .32474 L p F P
0 g
s
.67685 .31937 m
.69948 .32474 L
s
.69948 .32474 m
.70972 .33746 L
s
.3 .291 .621 r
.57885 .27635 m .56317 .27307 L .57026 .26719 L p F P
0 g
s
.3 .291 .621 r
.57026 .26719 m .58895 .27111 L .57885 .27635 L p F P
0 g
s
.56848 .28471 m
.57885 .27635 L
s
.57885 .27635 m
.59387 .28075 L
s
.441 .456 .397 r
.26205 .41878 m .26765 .40089 L .28693 .38389 L p F P
0 g
s
.467 .483 .328 r
.26765 .40089 m .26205 .41878 L .24506 .43905 L p F P
0 g
s
.25949 .43676 m
.26205 .41878 L
s
.26205 .41878 m
.28156 .40061 L
s
.017 .519 .539 r
.63742 .8737 m .65885 .86746 L .64721 .87872 L p F P
0 g
s
.017 .519 .539 r
.64721 .87872 m .6277 .88437 L .63742 .8737 L p F P
0 g
s
.63742 .8737 m
.64571 .86022 L
s
.61504 .8788 m
.63742 .8737 L
s
.271 .558 .419 r
.74186 .80762 m .75995 .79554 L .7469 .81483 L p F P
0 g
s
.271 .558 .419 r
.7469 .81483 m .72992 .82609 L .74186 .80762 L p F P
0 g
s
.74186 .80762 m
.75125 .78716 L
s
.72185 .81859 m
.74186 .80762 L
s
.391 .5 .397 r
.29511 .3675 m .28693 .38389 L .26765 .40089 L p F P
0 g
s
.28693 .38389 m
.3084 .36933 L
s
.28156 .40061 m
.28693 .38389 L
s
.564 .474 .13 r
.83002 .65281 m .83959 .6344 L .83716 .66118 L p F P
0 g
s
.564 .474 .13 r
.83716 .66118 m .8277 .67915 L .83002 .65281 L p F P
0 g
s
.82907 .62619 m
.83002 .65281 L
s
.81746 .67037 m
.83002 .65281 L
s
.556 .138 .482 r
.33155 .83115 m .35118 .84086 L .36349 .85588 L p F P
0 g
s
.539 .195 .482 r
.3831 .86378 m .36349 .85588 L .35118 .84086 L p F P
0 g
s
.35118 .84086 m
.37233 .84945 L
s
.34102 .82345 m
.35118 .84086 L
s
.115 .402 .621 r
.4978 .27183 m .48185 .27451 L .4733 .26891 L p F P
0 g
s
.072 .412 .621 r
.45497 .27348 m .4733 .26891 L .48185 .27451 L p F P
0 g
s
.48185 .27451 m
.49064 .28323 L
s
.46646 .27833 m
.48185 .27451 L
s
.654 .348 .104 r
.21474 .57085 m .21025 .55115 L .2181 .52522 L p F P
0 g
s
.66 .351 .026 r
.21025 .55115 m .21474 .57085 L .21034 .59755 L p F P
0 g
s
.21474 .57085 m
.22248 .58994 L
s
.21474 .57085 m
.2224 .54473 L
s
.673 .272 .181 r
.8243 .49102 m .82352 .47146 L .83474 .49567 L p F P
0 g
s
.673 .272 .181 r
.83474 .49567 m .83542 .51569 L .8243 .49102 L p F P
0 g
s
.81019 .46775 m
.8243 .49102 L
s
.82181 .51031 m
.8243 .49102 L
s
.268 .321 .621 r
.56317 .27307 m .54701 .27096 L .551 .26466 L p F P
0 g
s
.268 .321 .621 r
.551 .26466 m .57026 .26719 L .56317 .27307 L p F P
0 g
s
.55588 .28208 m
.56317 .27307 L
s
.56317 .27307 m
.57885 .27635 L
s
.068 .476 .574 r
.42132 .28644 m .40639 .29463 L .38809 .29631 L p F P
0 g
s
.117 .466 .574 r
.37274 .30687 m .38809 .29631 L .40639 .29463 L p F P
0 g
s
.40639 .29463 m
.42552 .29607 L
s
.39297 .30381 m
.40639 .29463 L
s
.467 .227 .539 r
.3831 .86378 m .40396 .8706 L .41468 .88157 L p F P
0 g
s
.441 .275 .539 r
.43464 .88673 m .41468 .88157 L .40396 .8706 L p F P
0 g
s
.39481 .85686 m
.40396 .8706 L
s
.40396 .8706 m
.42587 .8763 L
s
.156 .388 .621 r
.51412 .27033 m .4978 .27183 L .49231 .2657 L p F P
0 g
s
.115 .402 .621 r
.4733 .26891 m .49231 .2657 L .4978 .27183 L p F P
0 g
s
.4978 .27183 m
.50344 .28109 L
s
.48185 .27451 m
.4978 .27183 L
s
.233 .347 .621 r
.54701 .27096 m .53059 .27004 L .53142 .26356 L p F P
0 g
s
.233 .347 .621 r
.53142 .26356 m .551 .26466 L .54701 .27096 L p F P
0 g
s
.54292 .28039 m
.54701 .27096 L
s
.54701 .27096 m
.56317 .27307 L
s
.692 .049 .281 r
.27343 .76729 m .25791 .75286 L .24957 .72908 L p F P
0 g
s
.659 .047 .352 r
.25791 .75286 m .27343 .76729 L .28412 .78885 L p F P
0 g
s
.66 .023 .352 r
.30113 .80148 m .28412 .78885 L .27343 .76729 L p F P
0 g
s
.27343 .76729 m
.29128 .78067 L
s
.26566 .74419 m
.27343 .76729 L
s
.185 .506 .52 r
.37274 .30687 m .35931 .31842 L .33876 .32596 L p F P
0 g
s
.236 .483 .52 r
.32616 .33978 m .33876 .32596 L .35931 .31842 L p F P
0 g
s
.34796 .33078 m
.35931 .31842 L
s
.35931 .31842 m
.3812 .31386 L
s
.708 .125 .206 r
.24957 .72908 m .23609 .71297 L .23056 .6875 L p F P
0 g
s
.683 .121 .281 r
.23609 .71297 m .24957 .72908 L .25791 .75286 L p F P
0 g
s
.24957 .72908 m
.26566 .74419 L
s
.24435 .70418 m
.24957 .72908 L
s
.589 .021 .461 r
.73205 .34724 m .72071 .33304 L .74028 .34426 L p F P
0 g
s
.589 .021 .461 r
.74028 .34426 m .75258 .35979 L .73205 .34724 L p F P
0 g
s
.70972 .33746 m
.73205 .34724 L
s
.73205 .34724 m
.74088 .36205 L
s
.196 .37 .621 r
.53059 .27004 m .51412 .27033 L .51177 .26391 L p F P
0 g
s
.156 .388 .621 r
.49231 .2657 m .51177 .26391 L .51412 .27033 L p F P
0 g
s
.51412 .27033 m
.51654 .27989 L
s
.4978 .27183 m
.51412 .27033 L
s
.196 .37 .621 r
.51177 .26391 m .53142 .26356 L .53059 .27004 L p F P
0 g
s
.51412 .27033 m
.53059 .27004 L
s
.52975 .27966 m
.53059 .27004 L
s
.53059 .27004 m
.54701 .27096 L
s
.676 .193 .256 r
.8093 .44887 m .8052 .42997 L .81937 .45184 L p F P
0 g
s
.676 .193 .256 r
.81937 .45184 m .82352 .47146 L .8093 .44887 L p F P
0 g
s
.79229 .42811 m
.8093 .44887 L
s
.8093 .44887 m
.81019 .46775 L
s
.619 .417 .052 r
.83859 .60753 m .84493 .58816 L .84596 .61528 L p F P
0 g
s
.619 .417 .052 r
.84596 .61528 m .83959 .6344 L .83859 .60753 L p F P
0 g
s
.83427 .58085 m
.83859 .60753 L
s
.82907 .62619 m
.83859 .60753 L
s
.432 .211 .574 r
.63924 .29056 m .62365 .28288 L .6386 .28277 L p F P
0 g
s
.432 .211 .574 r
.6386 .28277 m .65651 .29161 L .63924 .29056 L p F P
0 g
s
.62119 .29265 m
.63924 .29056 L
s
.63924 .29056 m
.6534 .29928 L
s
.195 .539 .482 r
.7111 .83632 m .72992 .82609 L .71547 .8423 L p F P
0 g
s
.195 .539 .482 r
.71547 .8423 m .69807 .85171 L .7111 .83632 L p F P
0 g
s
.7111 .83632 m
.72185 .81859 L
s
.69065 .84546 m
.7111 .83632 L
s
.602 .406 .181 r
.2181 .52522 m .21714 .50532 L .22832 .48089 L p F P
0 g
s
.614 .414 .104 r
.21714 .50532 m .2181 .52522 L .21025 .55115 L p F P
0 g
s
.2181 .52522 m
.2224 .54473 L
s
.2181 .52522 m
.22913 .50035 L
s
.708 .203 .13 r
.23056 .6875 m .21964 .66992 L .21726 .64335 L p F P
0 g
s
.691 .198 .206 r
.21964 .66992 m .23056 .6875 L .23609 .71297 L p F P
0 g
s
.23056 .6875 m
.24435 .70418 L
s
.22829 .66137 m
.23056 .6875 L
s
.258 .381 .59 r
.49856 .89582 m .52058 .89666 L .52121 .9029 L p F P
0 g
s
.217 .406 .59 r
.52058 .89666 m .54266 .8964 L .54088 .90266 L p F P
0 g
s
.217 .406 .59 r
.54088 .90266 m .52121 .9029 L .52058 .89666 L p F P
0 g
s
.52004 .88726 m
.52058 .89666 L
s
.62 .021 .419 r
.28412 .78885 m .30113 .80148 L .31365 .82037 L p F P
0 g
s
.614 .086 .419 r
.33155 .83115 m .31365 .82037 L .30113 .80148 L p F P
0 g
s
.30113 .80148 m
.32017 .81304 L
s
.29128 .78067 m
.30113 .80148 L
s
.173 .427 .59 r
.54266 .8964 m .5646 .89502 L .56044 .90145 L p F P
0 g
s
.173 .427 .59 r
.56044 .90145 m .54088 .90266 L .54266 .8964 L p F P
0 g
s
.54266 .8964 m
.54421 .88697 L
s
.52058 .89666 m
.54266 .8964 L
s
.072 .515 .539 r
.65885 .86746 m .67914 .86011 L .66565 .87208 L p F P
0 g
s
.072 .515 .539 r
.66565 .87208 m .64721 .87872 L .65885 .86746 L p F P
0 g
s
.65885 .86746 m
.66878 .85344 L
s
.63742 .8737 m
.65885 .86746 L
s
.633 .044 .397 r
.76212 .37595 m .75258 .35979 L .77106 .37506 L p F P
0 g
s
.633 .044 .397 r
.77106 .37506 m .78119 .39239 L .76212 .37595 L p F P
0 g
s
.74088 .36205 m
.76212 .37595 L
s
.76212 .37595 m
.76884 .39254 L
s
.662 .116 .328 r
.78827 .41015 m .78119 .39239 L .79783 .41125 L p F P
0 g
s
.662 .116 .328 r
.79783 .41125 m .8052 .42997 L .78827 .41015 L p F P
0 g
s
.76884 .39254 m
.78827 .41015 L
s
.78827 .41015 m
.79229 .42811 L
s
.297 .352 .59 r
.47676 .89387 m .49856 .89582 L .50157 .90215 L p F P
0 g
s
.258 .381 .59 r
.52121 .9029 m .50157 .90215 L .49856 .89582 L p F P
0 g
s
.49592 .88633 m
.49856 .89582 L
s
.49856 .89582 m
.52058 .89666 L
s
.128 .443 .59 r
.5646 .89502 m .58621 .89255 L .57969 .89925 L p F P
0 g
s
.128 .443 .59 r
.57969 .89925 m .56044 .90145 L .5646 .89502 L p F P
0 g
s
.5646 .89502 m
.56824 .88545 L
s
.54266 .8964 m
.5646 .89502 L
s
.522 .131 .52 r
.68711 .31275 m .67274 .30166 L .69094 .3072 L p F P
0 g
s
.522 .131 .52 r
.69094 .3072 m .70697 .31963 L .68711 .31275 L p F P
0 g
s
.66598 .30893 m
.68711 .31275 L
s
.68711 .31275 m
.69948 .32474 L
s
.017 .481 .574 r
.43758 .27935 m .42132 .28644 L .40522 .28686 L p F P
0 g
s
.068 .476 .574 r
.38809 .29631 m .40522 .28686 L .42132 .28644 L p F P
0 g
s
.42132 .28644 m
.43813 .28919 L
s
.40639 .29463 m
.42132 .28644 L
s
.332 .319 .59 r
.4554 .89084 m .47676 .89387 L .48216 .90043 L p F P
0 g
s
.297 .352 .59 r
.50157 .90215 m .48216 .90043 L .47676 .89387 L p F P
0 g
s
.47205 .88419 m
.47676 .89387 L
s
.47676 .89387 m
.49856 .89582 L
s
.692 .28 .052 r
.21726 .64335 m .20932 .62455 L .21034 .59755 L p F P
0 g
s
.683 .276 .13 r
.20932 .62455 m .21726 .64335 L .21964 .66992 L p F P
0 g
s
.21726 .64335 m
.22829 .66137 L
s
.21726 .64335 m
.21824 .6166 L
s
.66 .351 .026 r
.84047 .56144 m .84334 .54152 L .8479 .56827 L p F P
0 g
s
.66 .351 .026 r
.8479 .56827 m .84493 .58816 L .84047 .56144 L p F P
0 g
s
.83271 .53541 m
.84047 .56144 L
s
.83427 .58085 m
.84047 .56144 L
s
.259 .53 .461 r
.33876 .32596 m .32616 .33978 L .30609 .35164 L p F P
0 g
s
.313 .5 .461 r
.29511 .3675 m .30609 .35164 L .32616 .33978 L p F P
0 g
s
.31602 .3543 m
.32616 .33978 L
s
.32616 .33978 m
.34796 .33078 L
s
.539 .452 .256 r
.22832 .48089 m .23084 .46127 L .24506 .43905 L p F P
0 g
s
.556 .466 .181 r
.23084 .46127 m .22832 .48089 L .21714 .50532 L p F P
0 g
s
.22832 .48089 m
.22913 .50035 L
s
.22832 .48089 m
.24251 .45797 L
s
.489 .177 .539 r
.36349 .85588 m .3831 .86378 L .3957 .8754 L p F P
0 g
s
.467 .227 .539 r
.41468 .88157 m .3957 .8754 L .3831 .86378 L p F P
0 g
s
.37233 .84945 m
.3831 .86378 L
s
.3831 .86378 m
.40396 .8706 L
s
.081 .454 .59 r
.58621 .89255 m .60731 .88899 L .59846 .8961 L p F P
0 g
s
.081 .454 .59 r
.59846 .8961 m .57969 .89925 L .58621 .89255 L p F P
0 g
s
.58621 .89255 m
.59191 .88272 L
s
.5646 .89502 m
.58621 .89255 L
s
.406 .521 .352 r
.78697 .76047 m .8013 .74558 L .78951 .76838 L p F P
0 g
s
.406 .521 .352 r
.78951 .76838 m .7759 .78242 L .78697 .76047 L p F P
0 g
s
.78697 .76047 m
.79502 .73705 L
s
.77021 .77437 m
.78697 .76047 L
s
.568 .079 .482 r
.31365 .82037 m .33155 .83115 L .34532 .84695 L p F P
0 g
s
.556 .138 .482 r
.36349 .85588 m .34532 .84695 L .33155 .83115 L p F P
0 g
s
.33155 .83115 m
.35118 .84086 L
s
.32017 .81304 m
.33155 .83115 L
s
.407 .255 .574 r
.62365 .28288 m .60682 .27637 L .61923 .27525 L p F P
0 g
s
.407 .255 .574 r
.61923 .27525 m .6386 .28277 L .62365 .28288 L p F P
0 g
s
.60804 .28621 m
.62365 .28288 L
s
.62365 .28288 m
.63924 .29056 L
s
.482 .499 .281 r
.80988 .72145 m .82203 .70491 L .81298 .7298 L p F P
0 g
s
.482 .499 .281 r
.81298 .7298 m .8013 .74558 L .80988 .72145 L p F P
0 g
s
.80988 .72145 m
.81526 .69628 L
s
.79502 .73705 m
.80988 .72145 L
s
.328 .526 .419 r
.75995 .79554 m .7759 .78242 L .76185 .80261 L p F P
0 g
s
.328 .526 .419 r
.76185 .80261 m .7469 .81483 L .75995 .79554 L p F P
0 g
s
.75995 .79554 m
.77021 .77437 L
s
.74186 .80762 m
.75995 .79554 L
s
.363 .283 .59 r
.43464 .88673 m .4554 .89084 L .46313 .89773 L p F P
0 g
s
.332 .319 .59 r
.48216 .90043 m .46313 .89773 L .4554 .89084 L p F P
0 g
s
.44863 .88083 m
.4554 .89084 L
s
.4554 .89084 m
.47676 .89387 L
s
.467 .483 .328 r
.24506 .43905 m .25085 .42021 L .26765 .40089 L p F P
0 g
s
.489 .506 .256 r
.25085 .42021 m .24506 .43905 L .23084 .46127 L p F P
0 g
s
.24251 .45797 m
.24506 .43905 L
s
.24506 .43905 m
.26205 .41878 L
s
.131 .522 .52 r
.38809 .29631 m .37274 .30687 L .35371 .31304 L p F P
0 g
s
.185 .506 .52 r
.33876 .32596 m .35371 .31304 L .37274 .30687 L p F P
0 g
s
.37274 .30687 m
.39297 .30381 L
s
.35931 .31842 m
.37274 .30687 L
s
.337 .538 .397 r
.30609 .35164 m .29511 .3675 L .27632 .38333 L p F P
0 g
s
.391 .5 .397 r
.26765 .40089 m .27632 .38333 L .29511 .3675 L p F P
0 g
s
.29511 .3675 m
.31602 .3543 L
s
.28693 .38389 m
.29511 .3675 L
s
.66 .351 .026 r
.21034 .59755 m .20573 .57789 L .21025 .55115 L p F P
0 g
s
.659 .35 .052 r
.20573 .57789 m .21034 .59755 L .20932 .62455 L p F P
0 g
s
.21034 .59755 m
.21824 .6166 L
s
.21034 .59755 m
.21474 .57085 L
s
.551 .462 .206 r
.8277 .67915 m .83716 .66118 L .83125 .68757 L p F P
0 g
s
.551 .462 .206 r
.83125 .68757 m .82203 .70491 L .8277 .67915 L p F P
0 g
s
.8277 .67915 m
.83002 .65281 L
s
.81526 .69628 m
.8277 .67915 L
s
.687 .277 .104 r
.83542 .51569 m .83474 .49567 L .84274 .52129 L p F P
0 g
s
.687 .277 .104 r
.84274 .52129 m .84334 .54152 L .83542 .51569 L p F P
0 g
s
.8243 .49102 m
.83542 .51569 L
s
.83271 .53541 m
.83542 .51569 L
s
.414 .53 .328 r
.27632 .38333 m .26765 .40089 L .25085 .42021 L p F P
0 g
s
.26205 .41878 m
.26765 .40089 L
s
.26765 .40089 m
.28693 .38389 L
s
.033 .48 .574 r
.45497 .27348 m .43758 .27935 L .42391 .27869 L p F P
0 g
s
.017 .481 .574 r
.40522 .28686 m .42391 .27869 L .43758 .27935 L p F P
0 g
s
.43758 .27935 m
.45183 .28325 L
s
.42132 .28644 m
.43758 .27935 L
s
.125 .504 .539 r
.67914 .86011 m .69807 .85171 L .68283 .86449 L p F P
0 g
s
.125 .504 .539 r
.68283 .86449 m .66565 .87208 L .67914 .86011 L p F P
0 g
s
.67914 .86011 m
.69065 .84546 L
s
.65885 .86746 m
.67914 .86011 L
s
.033 .459 .59 r
.60731 .88899 m .6277 .88437 L .6166 .89201 L p F P
0 g
s
.033 .459 .59 r
.6166 .89201 m .59846 .8961 L .60731 .88899 L p F P
0 g
s
.60731 .88899 m
.61504 .8788 L
s
.58621 .89255 m
.60731 .88899 L
s
.584 .083 .461 r
.72071 .33304 m .70697 .31963 L .72529 .32957 L p F P
0 g
s
.584 .083 .461 r
.72529 .32957 m .74028 .34426 L .72071 .33304 L p F P
0 g
s
.69948 .32474 m
.72071 .33304 L
s
.72071 .33304 m
.73205 .34724 L
s
.379 .297 .574 r
.60682 .27637 m .58895 .27111 L .59863 .26917 L p F P
0 g
s
.379 .297 .574 r
.59863 .26917 m .61923 .27525 L .60682 .27637 L p F P
0 g
s
.59387 .28075 m
.60682 .27637 L
s
.60682 .27637 m
.62365 .28288 L
s
.251 .515 .482 r
.72992 .82609 m .7469 .81483 L .73113 .83196 L p F P
0 g
s
.251 .515 .482 r
.73113 .83196 m .71547 .8423 L .72992 .82609 L p F P
0 g
s
.72992 .82609 m
.74186 .80762 L
s
.7111 .83632 m
.72992 .82609 L
s
.506 .185 .52 r
.67274 .30166 m .65651 .29161 L .67279 .29593 L p F P
0 g
s
.506 .185 .52 r
.67279 .29593 m .69094 .3072 L .67274 .30166 L p F P
0 g
s
.6534 .29928 m
.67274 .30166 L
s
.67274 .30166 m
.68711 .31275 L
s
.391 .243 .59 r
.41468 .88157 m .43464 .88673 L .44466 .89409 L p F P
0 g
s
.363 .283 .59 r
.46313 .89773 m .44466 .89409 L .43464 .88673 L p F P
0 g
s
.42587 .8763 m
.43464 .88673 L
s
.43464 .88673 m
.4554 .89084 L
s
.611 .412 .13 r
.83959 .6344 m .84596 .61528 L .84346 .64253 L p F P
0 g
s
.611 .412 .13 r
.84346 .64253 m .83716 .66118 L .83959 .6344 L p F P
0 g
s
.83859 .60753 m
.83959 .6344 L
s
.83002 .65281 m
.83959 .6344 L
s
.698 .2 .181 r
.82352 .47146 m .81937 .45184 L .83056 .47558 L p F P
0 g
s
.698 .2 .181 r
.83056 .47558 m .83474 .49567 L .82352 .47146 L p F P
0 g
s
.8093 .44887 m
.82352 .47146 L
s
.82352 .47146 m
.8243 .49102 L
s
.683 .121 .281 r
.25791 .75286 m .24493 .73749 L .23609 .71297 L p F P
0 g
s
.65 .115 .352 r
.24493 .73749 m .25791 .75286 L .26936 .77524 L p F P
0 g
s
.659 .047 .352 r
.28412 .78885 m .26936 .77524 L .25791 .75286 L p F P
0 g
s
.25791 .75286 m
.27343 .76729 L
s
.24957 .72908 m
.25791 .75286 L
s
.614 .414 .104 r
.21025 .55115 m .20916 .53105 L .21714 .50532 L p F P
0 g
s
.62 .418 .026 r
.20916 .53105 m .21025 .55115 L .20573 .57789 L p F P
0 g
s
.21025 .55115 m
.21474 .57085 L
s
.21025 .55115 m
.2181 .52522 L
s
.083 .474 .574 r
.4733 .26891 m .45497 .27348 L .44395 .27191 L p F P
0 g
s
.033 .48 .574 r
.42391 .27869 m .44395 .27191 L .45497 .27348 L p F P
0 g
s
.45497 .27348 m
.46646 .27833 L
s
.43758 .27935 m
.45497 .27348 L
s
.504 .125 .539 r
.34532 .84695 m .36349 .85588 L .3779 .86825 L p F P
0 g
s
.489 .177 .539 r
.3957 .8754 m .3779 .86825 L .36349 .85588 L p F P
0 g
s
.36349 .85588 m
.3831 .86378 L
s
.35118 .84086 m
.36349 .85588 L
s
.619 .044 .419 r
.26936 .77524 m .28412 .78885 L .29771 .8086 L p F P
0 g
s
.62 .021 .419 r
.31365 .82037 m .29771 .8086 L .28412 .78885 L p F P
0 g
s
.28412 .78885 m
.30113 .80148 L
s
.27343 .76729 m
.28412 .78885 L
s
.634 .023 .397 r
.75258 .35979 m .74028 .34426 L .7579 .35839 L p F P
0 g
s
.634 .023 .397 r
.7579 .35839 m .77106 .37506 L .75258 .35979 L p F P
0 g
s
.73205 .34724 m
.75258 .35979 L
s
.75258 .35979 m
.76212 .37595 L
s
.015 .46 .59 r
.6277 .88437 m .64721 .87872 L .63392 .88701 L p F P
0 g
s
.015 .46 .59 r
.63392 .88701 m .6166 .89201 L .6277 .88437 L p F P
0 g
s
.6277 .88437 m
.63742 .8737 L
s
.60731 .88899 m
.6277 .88437 L
s
.691 .198 .206 r
.23609 .71297 m .22544 .696 L .21964 .66992 L p F P
0 g
s
.667 .192 .281 r
.22544 .696 m .23609 .71297 L .24493 .73749 L p F P
0 g
s
.23609 .71297 m
.24957 .72908 L
s
.23056 .6875 m
.23609 .71297 L
s
.692 .122 .256 r
.8052 .42997 m .79783 .41125 L .81178 .4324 L p F P
0 g
s
.692 .122 .256 r
.81178 .4324 m .81937 .45184 L .8052 .42997 L p F P
0 g
s
.78827 .41015 m
.8052 .42997 L
s
.8052 .42997 m
.8093 .44887 L
s
.345 .335 .574 r
.58895 .27111 m .57026 .26719 L .57707 .26464 L p F P
0 g
s
.345 .335 .574 r
.57707 .26464 m .59863 .26917 L .58895 .27111 L p F P
0 g
s
.57885 .27635 m
.58895 .27111 L
s
.58895 .27111 m
.60682 .27637 L
s
.202 .554 .461 r
.35371 .31304 m .33876 .32596 L .3198 .33652 L p F P
0 g
s
.259 .53 .461 r
.30609 .35164 m .3198 .33652 L .33876 .32596 L p F P
0 g
s
.32616 .33978 m
.33876 .32596 L
s
.33876 .32596 m
.35931 .31842 L
s
.671 .047 .328 r
.78119 .39239 m .77106 .37506 L .78719 .39297 L p F P
0 g
s
.671 .047 .328 r
.78719 .39297 m .79783 .41125 L .78119 .39239 L p F P
0 g
s
.76212 .37595 m
.78119 .39239 L
s
.78119 .39239 m
.78827 .41015 L
s
.076 .533 .52 r
.40522 .28686 m .38809 .29631 L .37086 .30119 L p F P
0 g
s
.131 .522 .52 r
.35371 .31304 m .37086 .30119 L .38809 .29631 L p F P
0 g
s
.38809 .29631 m
.40639 .29463 L
s
.37274 .30687 m
.38809 .29631 L
s
.132 .462 .574 r
.49231 .2657 m .4733 .26891 L .46508 .26662 L p F P
0 g
s
.083 .474 .574 r
.44395 .27191 m .46508 .26662 L .4733 .26891 L p F P
0 g
s
.4733 .26891 m
.48185 .27451 L
s
.45497 .27348 m
.4733 .26891 L
s
.659 .35 .052 r
.84493 .58816 m .8479 .56827 L .84895 .59566 L p F P
0 g
s
.659 .35 .052 r
.84895 .59566 m .84596 .61528 L .84493 .58816 L p F P
0 g
s
.84047 .56144 m
.84493 .58816 L
s
.83859 .60753 m
.84493 .58816 L
s
.573 .019 .482 r
.29771 .8086 m .31365 .82037 L .3288 .83705 L p F P
0 g
s
.568 .079 .482 r
.34532 .84695 m .3288 .83705 L .31365 .82037 L p F P
0 g
s
.31365 .82037 m
.33155 .83115 L
s
.30113 .80148 m
.31365 .82037 L
s
.414 .201 .59 r
.3957 .8754 m .41468 .88157 L .42693 .88952 L p F P
0 g
s
.391 .243 .59 r
.44466 .89409 m .42693 .88952 L .41468 .88157 L p F P
0 g
s
.40396 .8706 m
.41468 .88157 L
s
.41468 .88157 m
.43464 .88673 L
s
.683 .276 .13 r
.21964 .66992 m .21179 .65157 L .20932 .62455 L p F P
0 g
s
.667 .27 .206 r
.21179 .65157 m .21964 .66992 L .22544 .696 L p F P
0 g
s
.21964 .66992 m
.23056 .6875 L
s
.21726 .64335 m
.21964 .66992 L
s
.556 .466 .181 r
.21714 .50532 m .21962 .48524 L .23084 .46127 L p F P
0 g
s
.568 .476 .104 r
.21962 .48524 m .21714 .50532 L .20916 .53105 L p F P
0 g
s
.21714 .50532 m
.2181 .52522 L
s
.21714 .50532 m
.22832 .48089 L
s
.177 .489 .539 r
.69807 .85171 m .71547 .8423 L .69858 .856 L p F P
0 g
s
.177 .489 .539 r
.69858 .856 m .68283 .86449 L .69807 .85171 L p F P
0 g
s
.69807 .85171 m
.7111 .83632 L
s
.67914 .86011 m
.69807 .85171 L
s
.309 .369 .574 r
.57026 .26719 m .551 .26466 L .55484 .26171 L p F P
0 g
s
.309 .369 .574 r
.55484 .26171 m .57707 .26464 L .57026 .26719 L p F P
0 g
s
.56317 .27307 m
.57026 .26719 L
s
.57026 .26719 m
.58895 .27111 L
s
.18 .446 .574 r
.51177 .26391 m .49231 .2657 L .48703 .26291 L p F P
0 g
s
.132 .462 .574 r
.46508 .26662 m .48703 .26291 L .49231 .2657 L p F P
0 g
s
.49231 .2657 m
.4978 .27183 L
s
.4733 .26891 m
.49231 .2657 L
s
.483 .236 .52 r
.65651 .29161 m .6386 .28277 L .65271 .28599 L p F P
0 g
s
.483 .236 .52 r
.65271 .28599 m .67279 .29593 L .65651 .29161 L p F P
0 g
s
.63924 .29056 m
.65651 .29161 L
s
.65651 .29161 m
.67274 .30166 L
s
.268 .399 .574 r
.551 .26466 m .53142 .26356 L .53221 .26044 L p F P
0 g
s
.268 .399 .574 r
.53221 .26044 m .55484 .26171 L .551 .26466 L p F P
0 g
s
.54701 .27096 m
.551 .26466 L
s
.551 .26466 m
.57026 .26719 L
s
.572 .143 .461 r
.70697 .31963 m .69094 .3072 L .70775 .31595 L p F P
0 g
s
.572 .143 .461 r
.70775 .31595 m .72529 .32957 L .70697 .31963 L p F P
0 g
s
.68711 .31275 m
.70697 .31963 L
s
.70697 .31963 m
.72071 .33304 L
s
.459 .475 .352 r
.8013 .74558 m .81298 .7298 L .80057 .75351 L p F P
0 g
s
.459 .475 .352 r
.80057 .75351 m .78951 .76838 L .8013 .74558 L p F P
0 g
s
.8013 .74558 m
.80988 .72145 L
s
.78697 .76047 m
.8013 .74558 L
s
.279 .57 .397 r
.3198 .33652 m .30609 .35164 L .28803 .36631 L p F P
0 g
s
.337 .538 .397 r
.27632 .38333 m .28803 .36631 L .30609 .35164 L p F P
0 g
s
.29511 .3675 m
.30609 .35164 L
s
.30609 .35164 m
.32616 .33978 L
s
.063 .456 .59 r
.64721 .87872 m .66565 .87208 L .65027 .88113 L p F P
0 g
s
.063 .456 .59 r
.65027 .88113 m .63392 .88701 L .64721 .87872 L p F P
0 g
s
.64721 .87872 m
.65885 .86746 L
s
.6277 .88437 m
.64721 .87872 L
s
.381 .489 .419 r
.7759 .78242 m .78951 .76838 L .77455 .78955 L p F P
0 g
s
.381 .489 .419 r
.77455 .78955 m .76185 .80261 L .7759 .78242 L p F P
0 g
s
.7759 .78242 m
.78697 .76047 L
s
.75995 .79554 m
.7759 .78242 L
s
.225 .425 .574 r
.53142 .26356 m .51177 .26391 L .50951 .26084 L p F P
0 g
s
.18 .446 .574 r
.48703 .26291 m .50951 .26084 L .51177 .26391 L p F P
0 g
s
.51177 .26391 m
.51412 .27033 L
s
.49231 .2657 m
.51177 .26391 L
s
.225 .425 .574 r
.50951 .26084 m .53221 .26044 L .53142 .26356 L p F P
0 g
s
.51177 .26391 m
.53142 .26356 L
s
.53059 .27004 m
.53142 .26356 L
s
.53142 .26356 m
.551 .26466 L
s
.489 .506 .256 r
.23084 .46127 m .23677 .44171 L .25085 .42021 L p F P
0 g
s
.504 .522 .181 r
.23677 .44171 m .23084 .46127 L .21962 .48524 L p F P
0 g
s
.22832 .48089 m
.23084 .46127 L
s
.23084 .46127 m
.24506 .43905 L
s
.659 .35 .052 r
.20932 .62455 m .20469 .60515 L .20573 .57789 L p F P
0 g
s
.65 .346 .13 r
.20469 .60515 m .20932 .62455 L .21179 .65157 L p F P
0 g
s
.20932 .62455 m
.21726 .64335 L
s
.20932 .62455 m
.21034 .59755 L
s
.693 .28 .026 r
.84334 .54152 m .84274 .52129 L .84734 .54807 L p F P
0 g
s
.693 .28 .026 r
.84734 .54807 m .8479 .56827 L .84334 .54152 L p F P
0 g
s
.83542 .51569 m
.84334 .54152 L
s
.84047 .56144 m
.84334 .54152 L
s
.531 .446 .281 r
.82203 .70491 m .83125 .68757 L .82182 .71327 L p F P
0 g
s
.531 .446 .281 r
.82182 .71327 m .81298 .7298 L .82203 .70491 L p F P
0 g
s
.82203 .70491 m
.8277 .67915 L
s
.80988 .72145 m
.82203 .70491 L
s
.222 .328 .635 r
.50157 .90215 m .52121 .9029 L .5219 .90577 L p F P
0 g
s
.187 .35 .635 r
.52121 .9029 m .54088 .90266 L .53889 .90556 L p F P
0 g
s
.187 .35 .635 r
.53889 .90556 m .5219 .90577 L .52121 .9029 L p F P
0 g
s
.52058 .89666 m
.52121 .9029 L
s
.149 .367 .635 r
.54088 .90266 m .56044 .90145 L .55577 .90451 L p F P
0 g
s
.149 .367 .635 r
.55577 .90451 m .53889 .90556 L .54088 .90266 L p F P
0 g
s
.54088 .90266 m
.54266 .8964 L
s
.52121 .9029 m
.54088 .90266 L
s
.357 .57 .328 r
.28803 .36631 m .27632 .38333 L .25991 .40169 L p F P
0 g
s
.414 .53 .328 r
.25085 .42021 m .25991 .40169 L .27632 .38333 L p F P
0 g
s
.27632 .38333 m
.29511 .3675 L
s
.26765 .40089 m
.27632 .38333 L
s
.019 .538 .52 r
.42391 .27869 m .40522 .28686 L .39004 .29059 L p F P
0 g
s
.076 .533 .52 r
.37086 .30119 m .39004 .29059 L .40522 .28686 L p F P
0 g
s
.40522 .28686 m
.42132 .28644 L
s
.38809 .29631 m
.40522 .28686 L
s
.303 .486 .482 r
.7469 .81483 m .76185 .80261 L .74487 .82077 L p F P
0 g
s
.303 .486 .482 r
.74487 .82077 m .73113 .83196 L .7469 .81483 L p F P
0 g
s
.7469 .81483 m
.75995 .79554 L
s
.72992 .82609 m
.7469 .81483 L
s
.433 .554 .256 r
.25991 .40169 m .25085 .42021 L .23677 .44171 L p F P
0 g
s
.24506 .43905 m
.25085 .42021 L
s
.25085 .42021 m
.26765 .40089 L
s
.515 .072 .539 r
.3288 .83705 m .34532 .84695 L .36144 .86019 L p F P
0 g
s
.504 .125 .539 r
.3779 .86825 m .36144 .86019 L .34532 .84695 L p F P
0 g
s
.34532 .84695 m
.36349 .85588 L
s
.33155 .83115 m
.34532 .84695 L
s
.255 .303 .635 r
.48216 .90043 m .50157 .90215 L .50496 .90512 L p F P
0 g
s
.222 .328 .635 r
.5219 .90577 m .50496 .90512 L .50157 .90215 L p F P
0 g
s
.49856 .89582 m
.50157 .90215 L
s
.50157 .90215 m
.52121 .9029 L
s
.433 .157 .59 r
.3779 .86825 m .3957 .8754 L .41009 .88407 L p F P
0 g
s
.414 .201 .59 r
.42693 .88952 m .41009 .88407 L .3957 .8754 L p F P
0 g
s
.3831 .86378 m
.3957 .8754 L
s
.3957 .8754 m
.41468 .88157 L
s
.11 .381 .635 r
.56044 .90145 m .57969 .89925 L .57238 .90262 L p F P
0 g
s
.11 .381 .635 r
.57238 .90262 m .55577 .90451 L .56044 .90145 L p F P
0 g
s
.56044 .90145 m
.5646 .89502 L
s
.54088 .90266 m
.56044 .90145 L
s
.286 .275 .635 r
.46313 .89773 m .48216 .90043 L .4882 .90364 L p F P
0 g
s
.255 .303 .635 r
.50496 .90512 m .4882 .90364 L .48216 .90043 L p F P
0 g
s
.47676 .89387 m
.48216 .90043 L
s
.48216 .90043 m
.50157 .90215 L
s
.143 .572 .461 r
.37086 .30119 m .35371 .31304 L .33613 .32236 L p F P
0 g
s
.202 .554 .461 r
.3198 .33652 m .33613 .32236 L .35371 .31304 L p F P
0 g
s
.33876 .32596 m
.35371 .31304 L
s
.35371 .31304 m
.37274 .30687 L
s
.596 .402 .206 r
.83716 .66118 m .84346 .64253 L .83735 .66959 L p F P
0 g
s
.596 .402 .206 r
.83735 .66959 m .83125 .68757 L .83716 .66118 L p F P
0 g
s
.83716 .66118 m
.83959 .6344 L
s
.8277 .67915 m
.83716 .66118 L
s
.712 .204 .104 r
.83474 .49567 m .83056 .47558 L .83854 .50098 L p F P
0 g
s
.712 .204 .104 r
.83854 .50098 m .84274 .52129 L .83474 .49567 L p F P
0 g
s
.82352 .47146 m
.83474 .49567 L
s
.83474 .49567 m
.83542 .51569 L
s
.456 .286 .52 r
.6386 .28277 m .61923 .27525 L .63096 .27754 L p F P
0 g
s
.456 .286 .52 r
.63096 .27754 m .65271 .28599 L .6386 .28277 L p F P
0 g
s
.62365 .28288 m
.6386 .28277 L
s
.6386 .28277 m
.65651 .29161 L
s
.628 .089 .397 r
.74028 .34426 m .72529 .32957 L .74182 .3426 L p F P
0 g
s
.628 .089 .397 r
.74182 .3426 m .7579 .35839 L .74028 .34426 L p F P
0 g
s
.72071 .33304 m
.74028 .34426 L
s
.74028 .34426 m
.75258 .35979 L
s
.62 .418 .026 r
.20573 .57789 m .20457 .55781 L .20916 .53105 L p F P
0 g
s
.619 .417 .052 r
.20457 .55781 m .20573 .57789 L .20469 .60515 L p F P
0 g
s
.20573 .57789 m
.21034 .59755 L
s
.20573 .57789 m
.21025 .55115 L
s
.07 .39 .635 r
.57969 .89925 m .59846 .8961 L .58856 .89991 L p F P
0 g
s
.07 .39 .635 r
.58856 .89991 m .57238 .90262 L .57969 .89925 L p F P
0 g
s
.57969 .89925 m
.58621 .89255 L
s
.56044 .90145 m
.57969 .89925 L
s
.111 .447 .59 r
.66565 .87208 m .68283 .86449 L .66547 .87443 L p F P
0 g
s
.111 .447 .59 r
.66547 .87443 m .65027 .88113 L .66565 .87208 L p F P
0 g
s
.66565 .87208 m
.67914 .86011 L
s
.64721 .87872 m
.66565 .87208 L
s
.65 .115 .352 r
.26936 .77524 m .25705 .76075 L .24493 .73749 L p F P
0 g
s
.611 .108 .419 r
.25705 .76075 m .26936 .77524 L .2839 .79593 L p F P
0 g
s
.619 .044 .419 r
.29771 .8086 m .2839 .79593 L .26936 .77524 L p F P
0 g
s
.26936 .77524 m
.28412 .78885 L
s
.25791 .75286 m
.26936 .77524 L
s
.227 .467 .539 r
.71547 .8423 m .73113 .83196 L .71272 .84668 L p F P
0 g
s
.227 .467 .539 r
.71272 .84668 m .69858 .856 L .71547 .8423 L p F P
0 g
s
.71547 .8423 m
.72992 .82609 L
s
.69807 .85171 m
.71547 .8423 L
s
.313 .243 .635 r
.44466 .89409 m .46313 .89773 L .47179 .90132 L p F P
0 g
s
.286 .275 .635 r
.4882 .90364 m .47179 .90132 L .46313 .89773 L p F P
0 g
s
.4554 .89084 m
.46313 .89773 L
s
.46313 .89773 m
.48216 .90043 L
s
.667 .192 .281 r
.24493 .73749 m .23469 .7213 L .22544 .696 L p F P
0 g
s
.635 .182 .352 r
.23469 .7213 m .24493 .73749 L .25705 .76075 L p F P
0 g
s
.24493 .73749 m
.25791 .75286 L
s
.23609 .71297 m
.24493 .73749 L
s
.715 .126 .181 r
.81937 .45184 m .81178 .4324 L .8228 .45566 L p F P
0 g
s
.715 .126 .181 r
.8228 .45566 m .83056 .47558 L .81937 .45184 L p F P
0 g
s
.8052 .42997 m
.81937 .45184 L
s
.81937 .45184 m
.82352 .47146 L
s
.037 .537 .52 r
.44395 .27191 m .42391 .27869 L .41102 .28141 L p F P
0 g
s
.019 .538 .52 r
.39004 .29059 m .41102 .28141 L .42391 .27869 L p F P
0 g
s
.42391 .27869 m
.43758 .27935 L
s
.40522 .28686 m
.42391 .27869 L
s
.572 .041 .482 r
.2839 .79593 m .29771 .8086 L .31412 .82625 L p F P
0 g
s
.573 .019 .482 r
.3288 .83705 m .31412 .82625 L .29771 .8086 L p F P
0 g
s
.29771 .8086 m
.31365 .82037 L
s
.28412 .78885 m
.29771 .8086 L
s
.672 .024 .328 r
.77106 .37506 m .7579 .35839 L .77332 .37535 L p F P
0 g
s
.672 .024 .328 r
.77332 .37535 m .78719 .39297 L .77106 .37506 L p F P
0 g
s
.75258 .35979 m
.77106 .37506 L
s
.77106 .37506 m
.78119 .39239 L
s
.554 .202 .461 r
.69094 .3072 m .67279 .29593 L .68784 .30358 L p F P
0 g
s
.554 .202 .461 r
.68784 .30358 m .70775 .31595 L .69094 .3072 L p F P
0 g
s
.67274 .30166 m
.69094 .3072 L
s
.69094 .3072 m
.70697 .31963 L
s
.028 .395 .635 r
.59846 .8961 m .6166 .89201 L .60418 .89639 L p F P
0 g
s
.028 .395 .635 r
.60418 .89639 m .58856 .89991 L .59846 .8961 L p F P
0 g
s
.59846 .8961 m
.60731 .88899 L
s
.57969 .89925 m
.59846 .8961 L
s
.65 .346 .13 r
.84596 .61528 m .84895 .59566 L .84639 .62338 L p F P
0 g
s
.65 .346 .13 r
.84639 .62338 m .84346 .64253 L .84596 .61528 L p F P
0 g
s
.84493 .58816 m
.84596 .61528 L
s
.83959 .6344 m
.84596 .61528 L
s
.701 .049 .256 r
.79783 .41125 m .78719 .39297 L .80074 .41339 L p F P
0 g
s
.701 .049 .256 r
.80074 .41339 m .81178 .4324 L .79783 .41125 L p F P
0 g
s
.79783 .41125 m
.8052 .42997 L
s
.78119 .39239 m
.79783 .41125 L
s
.667 .27 .206 r
.22544 .696 m .21781 .67831 L .21179 .65157 L p F P
0 g
s
.643 .26 .281 r
.21781 .67831 m .22544 .696 L .23469 .7213 L p F P
0 g
s
.22544 .696 m
.23609 .71297 L
s
.21964 .66992 m
.22544 .696 L
s
.568 .476 .104 r
.20916 .53105 m .21162 .51074 L .21962 .48524 L p F P
0 g
s
.573 .481 .026 r
.21162 .51074 m .20916 .53105 L .20457 .55781 L p F P
0 g
s
.20916 .53105 m
.21025 .55115 L
s
.20916 .53105 m
.21714 .50532 L
s
.424 .332 .52 r
.61923 .27525 m .59863 .26917 L .60779 .2707 L p F P
0 g
s
.424 .332 .52 r
.60779 .2707 m .63096 .27754 L .61923 .27525 L p F P
0 g
s
.60682 .27637 m
.61923 .27525 L
s
.61923 .27525 m
.6386 .28277 L
s
.447 .111 .59 r
.36144 .86019 m .3779 .86825 L .39432 .87775 L p F P
0 g
s
.433 .157 .59 r
.41009 .88407 m .39432 .87775 L .3779 .86825 L p F P
0 g
s
.36349 .85588 m
.3779 .86825 L
s
.3779 .86825 m
.3957 .8754 L
s
.217 .596 .397 r
.33613 .32236 m .3198 .33652 L .30272 .35007 L p F P
0 g
s
.279 .57 .397 r
.28803 .36631 m .30272 .35007 L .3198 .33652 L p F P
0 g
s
.30609 .35164 m
.3198 .33652 L
s
.3198 .33652 m
.33876 .32596 L
s
.337 .209 .635 r
.42693 .88952 m .44466 .89409 L .45588 .89818 L p F P
0 g
s
.313 .243 .635 r
.47179 .90132 m .45588 .89818 L .44466 .89409 L p F P
0 g
s
.43464 .88673 m
.44466 .89409 L
s
.44466 .89409 m
.46313 .89773 L
s
.519 .017 .539 r
.31412 .82625 m .3288 .83705 L .3465 .85126 L p F P
0 g
s
.515 .072 .539 r
.36144 .86019 m .3465 .85126 L .3288 .83705 L p F P
0 g
s
.31365 .82037 m
.3288 .83705 L
s
.3288 .83705 m
.34532 .84695 L
s
.093 .53 .52 r
.46508 .26662 m .44395 .27191 L .43354 .27378 L p F P
0 g
s
.037 .537 .52 r
.41102 .28141 m .43354 .27378 L .44395 .27191 L p F P
0 g
s
.44395 .27191 m
.45497 .27348 L
s
.42391 .27869 m
.44395 .27191 L
s
.083 .584 .461 r
.39004 .29059 m .37086 .30119 L .35493 .30936 L p F P
0 g
s
.143 .572 .461 r
.33613 .32236 m .35493 .30936 L .37086 .30119 L p F P
0 g
s
.37086 .30119 m
.38809 .29631 L
s
.35371 .31304 m
.37086 .30119 L
s
.013 .396 .635 r
.6166 .89201 m .63392 .88701 L .61907 .8921 L p F P
0 g
s
.013 .396 .635 r
.61907 .8921 m .60418 .89639 L .6166 .89201 L p F P
0 g
s
.6166 .89201 m
.6277 .88437 L
s
.59846 .8961 m
.6166 .89201 L
s
.431 .447 .419 r
.78951 .76838 m .80057 .75351 L .78484 .77573 L p F P
0 g
s
.431 .447 .419 r
.78484 .77573 m .77455 .78955 L .78951 .76838 L p F P
0 g
s
.78951 .76838 m
.8013 .74558 L
s
.7759 .78242 m
.78951 .76838 L
s
.65 .346 .13 r
.21179 .65157 m .20722 .63264 L .20469 .60515 L p F P
0 g
s
.635 .338 .206 r
.20722 .63264 m .21179 .65157 L .21781 .67831 L p F P
0 g
s
.21179 .65157 m
.21964 .66992 L
s
.20932 .62455 m
.21179 .65157 L
s
.504 .522 .181 r
.21962 .48524 m .22565 .4652 L .23677 .44171 L p F P
0 g
s
.515 .533 .104 r
.22565 .4652 m .21962 .48524 L .21162 .51074 L p F P
0 g
s
.21714 .50532 m
.21962 .48524 L
s
.21962 .48524 m
.23084 .46127 L
s
.692 .28 .052 r
.8479 .56827 m .84734 .54807 L .8484 .57572 L p F P
0 g
s
.692 .28 .052 r
.8484 .57572 m .84895 .59566 L .8479 .56827 L p F P
0 g
s
.84334 .54152 m
.8479 .56827 L
s
.84493 .58816 m
.8479 .56827 L
s
.352 .452 .482 r
.76185 .80261 m .77455 .78955 L .75651 .8088 L p F P
0 g
s
.352 .452 .482 r
.75651 .8088 m .74487 .82077 L .76185 .80261 L p F P
0 g
s
.7469 .81483 m
.76185 .80261 L
s
.76185 .80261 m
.7759 .78242 L
s
.157 .433 .59 r
.68283 .86449 m .69858 .856 L .67937 .86694 L p F P
0 g
s
.157 .433 .59 r
.67937 .86694 m .66547 .87443 L .68283 .86449 L p F P
0 g
s
.68283 .86449 m
.69807 .85171 L
s
.66565 .87208 m
.68283 .86449 L
s
.506 .425 .352 r
.81298 .7298 m .82182 .71327 L .80889 .73795 L p F P
0 g
s
.506 .425 .352 r
.80889 .73795 m .80057 .75351 L .81298 .7298 L p F P
0 g
s
.81298 .7298 m
.82203 .70491 L
s
.8013 .74558 m
.81298 .7298 L
s
.387 .374 .52 r
.59863 .26917 m .57707 .26464 L .58352 .26559 L p F P
0 g
s
.387 .374 .52 r
.58352 .26559 m .60779 .2707 L .59863 .26917 L p F P
0 g
s
.58895 .27111 m
.59863 .26917 L
s
.59863 .26917 m
.61923 .27525 L
s
.295 .604 .328 r
.30272 .35007 m .28803 .36631 L .27224 .38372 L p F P
0 g
s
.357 .57 .328 r
.25991 .40169 m .27224 .38372 L .28803 .36631 L p F P
0 g
s
.27632 .38333 m
.28803 .36631 L
s
.28803 .36631 m
.30609 .35164 L
s
.433 .554 .256 r
.23677 .44171 m .24615 .42246 L .25991 .40169 L p F P
0 g
s
.447 .572 .181 r
.24615 .42246 m .23677 .44171 L .22565 .4652 L p F P
0 g
s
.23084 .46127 m
.23651 .44257 L
s
.23734 .44085 m
.25085 .42021 L
s
.357 .173 .635 r
.41009 .88407 m .42693 .88952 L .44063 .89426 L p F P
0 g
s
.337 .209 .635 r
.45588 .89818 m .44063 .89426 L .42693 .88952 L p F P
0 g
s
.41468 .88157 m
.42693 .88952 L
s
.42693 .88952 m
.44466 .89409 L
s
.616 .154 .397 r
.72529 .32957 m .70775 .31595 L .72294 .32793 L p F P
0 g
s
.616 .154 .397 r
.72294 .32793 m .74182 .3426 L .72529 .32957 L p F P
0 g
s
.70697 .31963 m
.7245 .32915 L
s
.7262 .33047 m
.74028 .34426 L
s
.373 .596 .256 r
.27224 .38372 m .25991 .40169 L .24615 .42246 L p F P
0 g
s
.26083 .40066 m
.27632 .38333 L
s
.25085 .42021 m
.25931 .40292 L
s
.148 .518 .52 r
.48703 .26291 m .46508 .26662 L .45732 .26783 L p F P
0 g
s
.093 .53 .52 r
.43354 .27378 m .45732 .26783 L .46508 .26662 L p F P
0 g
s
.46508 .26662 m
.4733 .26891 L
s
.44395 .27191 m
.46508 .26662 L
s
.53 .259 .461 r
.67279 .29593 m .65271 .28599 L .66578 .29266 L p F P
0 g
s
.53 .259 .461 r
.66578 .29266 m .68784 .30358 L .67279 .29593 L p F P
0 g
s
.65651 .29161 m
.67193 .2957 L
s
.67434 .2969 m
.69094 .3072 L
s
.575 .388 .281 r
.83125 .68757 m .83735 .66959 L .82763 .69613 L p F P
0 g
s
.82203 .70491 m
.82969 .69051 L
s
.83202 .68415 m
.83716 .66118 L
s
.575 .388 .281 r
.82763 .69613 m .82182 .71327 L .83125 .68757 L p F P
0 g
s
.275 .441 .539 r
.73113 .83196 m .74487 .82077 L .72509 .8366 L p F P
0 g
s
.73181 .83122 m
.7469 .81483 L
s
.71547 .8423 m
.72974 .83288 L
s
.275 .441 .539 r
.72509 .8366 m .71272 .84668 L .73113 .83196 L p F P
0 g
s
.619 .417 .052 r
.20469 .60515 m .20351 .58533 L .20457 .55781 L p F P
0 g
s
.611 .412 .13 r
.20351 .58533 m .20469 .60515 L .20722 .63264 L p F P
0 g
s
.20525 .60752 m
.20932 .62455 L
s
.20481 .60188 m
.20573 .57789 L
s
.719 .206 .026 r
.84274 .52129 m .83854 .50098 L .84314 .52777 L p F P
0 g
s
.84289 .52633 m
.84334 .54152 L
s
.83474 .49567 m
.84115 .51622 L
s
.719 .206 .026 r
.84314 .52777 m .84734 .54807 L .84274 .52129 L p F P
0 g
s
.345 .413 .52 r
.57707 .26464 m .55484 .26171 L .55846 .26229 L p F P
0 g
s
.345 .413 .52 r
.55846 .26229 m .58352 .26559 L .57707 .26464 L p F P
0 g
s
.57026 .26719 m
.57686 .26472 L
s
.57843 .26492 m
.59863 .26917 L
s
.054 .393 .635 r
.63392 .88701 m .65027 .88113 L .63309 .88706 L p F P
0 g
s
.63478 .88647 m
.64721 .87872 L
s
.054 .393 .635 r
.63309 .88706 m .61907 .8921 L .63392 .88701 L p F P
0 g
s
.6166 .89201 m
.63038 .88803 L
s
.447 .111 .59 r
.39432 .87775 m .37978 .87064 L .36144 .86019 L p F P
0 g
s
.456 .063 .59 r
.3465 .85126 m .36144 .86019 L .37978 .87064 L p F P
0 g
s
.36395 .86142 m
.3779 .86825 L
s
.34532 .84695 m
.36047 .8594 L
s
.148 .518 .52 r
.45732 .26783 m .48204 .26365 L .48703 .26291 L p F P
0 g
s
.201 .499 .52 r
.50951 .26084 m .48703 .26291 L .48204 .26365 L p F P
0 g
s
.46508 .26662 m
.48364 .26349 L
s
.48739 .2631 m
.49231 .2657 L
s
.3 .447 .52 r
.55484 .26171 m .53221 .26044 L .53296 .26086 L p F P
0 g
s
.3 .447 .52 r
.53296 .26086 m .55846 .26229 L .55484 .26171 L p F P
0 g
s
.551 .26466 m
.55437 .26206 L
s
.55484 .26171 m
.57707 .26464 L
s
.635 .182 .352 r
.25705 .76075 m .24739 .74551 L .23469 .7213 L p F P
0 g
s
.611 .108 .419 r
.2839 .79593 m .27243 .78246 L .25705 .76075 L p F P
0 g
s
.596 .171 .419 r
.24739 .74551 m .25705 .76075 L .27243 .78246 L p F P
0 g
s
.24493 .73749 m
.25483 .75649 L
s
.26034 .76462 m
.26936 .77524 L
s
.572 .041 .482 r
.31412 .82625 m .30144 .81465 L .2839 .79593 L p F P
0 g
s
.564 .1 .482 r
.27243 .78246 m .2839 .79593 L .30144 .81465 L p F P
0 g
s
.28779 .7995 m
.29771 .8086 L
s
.26936 .77524 m
.28153 .79256 L
s
.083 .584 .461 r
.35493 .30936 m .37599 .29772 L .39004 .29059 L p F P
0 g
s
.021 .589 .461 r
.41102 .28141 m .39004 .29059 L .37599 .29772 L p F P
0 g
s
.37086 .30119 m
.38337 .29428 L
s
.39268 .28995 m
.40522 .28686 L
s
.252 .475 .52 r
.53221 .26044 m .50951 .26084 L .50737 .26131 L p F P
0 g
s
.5098 .26123 m
.51177 .26391 L
s
.201 .499 .52 r
.48204 .26365 m .50737 .26131 L .50951 .26084 L p F P
0 g
s
.48703 .26291 m
.50951 .26084 L
s
.666 .094 .328 r
.7579 .35839 m .74182 .3426 L .75629 .35866 L p F P
0 g
s
.74028 .34426 m
.75121 .35302 L
s
.666 .094 .328 r
.75629 .35866 m .77332 .37535 L .7579 .35839 L p F P
0 g
s
.76435 .36656 m
.77106 .37506 L
s
.252 .475 .52 r
.50737 .26131 m .53296 .26086 L .53221 .26044 L p F P
0 g
s
.50951 .26084 m
.53221 .26044 L
s
.53142 .26356 m
.5321 .26087 L
s
.53221 .26044 m
.55484 .26171 L
s
.73 .129 .104 r
.83056 .47558 m .8228 .45566 L .83067 .48082 L p F P
0 g
s
.81937 .45184 m
.82602 .46594 L
s
.73 .129 .104 r
.83067 .48082 m .83854 .50098 L .83056 .47558 L p F P
0 g
s
.83276 .48619 m
.83474 .49567 L
s
.635 .338 .206 r
.84346 .64253 m .84639 .62338 L .84016 .65113 L p F P
0 g
s
.8444 .63225 m
.84596 .61528 L
s
.635 .338 .206 r
.84016 .65113 m .83735 .66959 L .84346 .64253 L p F P
0 g
s
.83716 .66118 m
.83984 .65326 L
s
.217 .596 .397 r
.30272 .35007 m .32027 .33483 L .33613 .32236 L p F P
0 g
s
.154 .616 .397 r
.35493 .30936 m .33613 .32236 L .32027 .33483 L p F P
0 g
s
.34012 .32024 m
.35371 .31304 L
s
.3198 .33652 m
.32995 .32772 L
s
.357 .173 .635 r
.44063 .89426 m .42617 .88957 L .41009 .88407 L p F P
0 g
s
.373 .135 .635 r
.39432 .87775 m .41009 .88407 L .42617 .88957 L p F P
0 g
s
.41989 .88724 m
.42693 .88952 L
s
.3957 .8754 m
.40811 .88287 L
s
.573 .481 .026 r
.20457 .55781 m .20701 .53753 L .21162 .51074 L p F P
0 g
s
.572 .48 .052 r
.20701 .53753 m .20457 .55781 L .20351 .58533 L p F P
0 g
s
.20499 .56511 m
.20573 .57789 L
s
.20624 .5481 m
.20916 .53105 L
s
.643 .26 .281 r
.23469 .7213 m .22741 .70444 L .21781 .67831 L p F P
0 g
s
.612 .248 .352 r
.22741 .70444 m .23469 .7213 L .24739 .74551 L p F P
0 g
s
.23868 .72761 m
.24493 .73749 L
s
.22544 .696 m
.23191 .7137 L
s
.184 .271 .673 r
.50496 .90512 m .5219 .90577 L .52267 .90508 L p F P
0 g
s
.52121 .9029 m
.52174 .90508 L
s
.155 .289 .673 r
.5219 .90577 m .53889 .90556 L .5367 .90491 L p F P
0 g
s
.155 .289 .673 r
.5367 .90491 m .52267 .90508 L .5219 .90577 L p F P
0 g
s
.124 .304 .673 r
.53889 .90556 m .55577 .90451 L .55063 .90404 L p F P
0 g
s
.124 .304 .673 r
.55063 .90404 m .5367 .90491 L .53889 .90556 L p F P
0 g
s
.53946 .90473 m
.54088 .90266 L
s
.5219 .90577 m
.53889 .90556 L
s
.519 .017 .539 r
.3465 .85126 m .33326 .84154 L .31412 .82625 L p F P
0 g
s
.518 .037 .539 r
.30144 .81465 m .31412 .82625 L .33326 .84154 L p F P
0 g
s
.3222 .83219 m
.3288 .83705 L
s
.29771 .8086 m
.31024 .82208 L
s
.724 .05 .181 r
.81178 .4324 m .80074 .41339 L .81144 .43616 L p F P
0 g
s
.79783 .41125 m
.80445 .42129 L
s
.724 .05 .181 r
.81144 .43616 m .8228 .45566 L .81178 .4324 L p F P
0 g
s
.81692 .44556 m
.81937 .45184 L
s
.201 .414 .59 r
.69858 .856 m .71272 .84668 L .69181 .85873 L p F P
0 g
s
.70356 .85196 m
.71547 .8423 L
s
.201 .414 .59 r
.69181 .85873 m .67937 .86694 L .69858 .856 L p F P
0 g
s
.68283 .86449 m
.68422 .86374 L
s
.703 .025 .256 r
.78719 .39297 m .77332 .37535 L .78627 .39505 L p F P
0 g
s
.77106 .37506 m
.7787 .38354 L
s
.703 .025 .256 r
.78627 .39505 m .80074 .41339 L .78719 .39297 L p F P
0 g
s
.79441 .40537 m
.79783 .41125 L
s
.211 .251 .673 r
.4882 .90364 m .50496 .90512 L .50868 .90454 L p F P
0 g
s
.50157 .90215 m
.50406 .90434 L
s
.184 .271 .673 r
.52267 .90508 m .50868 .90454 L .50496 .90512 L p F P
0 g
s
.50496 .90512 m
.5219 .90577 L
s
.091 .315 .673 r
.55577 .90451 m .57238 .90262 L .56433 .90248 L p F P
0 g
s
.091 .315 .673 r
.56433 .90248 m .55063 .90404 L .55577 .90451 L p F P
0 g
s
.55772 .90323 m
.56044 .90145 L
s
.53889 .90556 m
.55577 .90451 L
s
.5 .313 .461 r
.65271 .28599 m .63096 .27754 L .64182 .28336 L p F P
0 g
s
.5 .313 .461 r
.64182 .28336 m .66578 .29266 L .65271 .28599 L p F P
0 g
s
.6386 .28277 m
.64275 .28371 L
s
.65271 .28599 m
.67279 .29593 L
s
.095 .385 .635 r
.65027 .88113 m .66547 .87443 L .64611 .88131 L p F P
0 g
s
.65586 .87784 m
.66565 .87208 L
s
.095 .385 .635 r
.64611 .88131 m .63309 .88706 L .65027 .88113 L p F P
0 g
s
.63392 .88701 m
.65027 .88113 L
s
.236 .227 .673 r
.47179 .90132 m .4882 .90364 L .49485 .90332 L p F P
0 g
s
.48216 .90043 m
.48618 .90256 L
s
.211 .251 .673 r
.50868 .90454 m .49485 .90332 L .4882 .90364 L p F P
0 g
s
.4882 .90364 m
.50496 .90512 L
s
.635 .338 .206 r
.21781 .67831 m .2134 .66005 L .20722 .63264 L p F P
0 g
s
.612 .326 .281 r
.2134 .66005 m .21781 .67831 L .22741 .70444 L p F P
0 g
s
.22285 .68998 m
.22544 .696 L
s
.21179 .65157 m
.21446 .6634 L
s
.683 .276 .13 r
.84895 .59566 m .8484 .57572 L .84582 .60394 L p F P
0 g
s
.8479 .56827 m
.84825 .57741 L
s
.683 .276 .13 r
.84582 .60394 m .84639 .62338 L .84895 .59566 L p F P
0 g
s
.84596 .61528 m
.84612 .61422 L
s
.058 .323 .673 r
.57238 .90262 m .58856 .89991 L .57767 .90024 L p F P
0 g
s
.058 .323 .673 r
.57767 .90024 m .56433 .90248 L .57238 .90262 L p F P
0 g
s
.57747 .90028 m
.57969 .89925 L
s
.55577 .90451 m
.57238 .90262 L
s
.596 .217 .397 r
.70775 .31595 m .68784 .30358 L .70145 .3146 L p F P
0 g
s
.69094 .3072 m
.69477 .30919 L
s
.596 .217 .397 r
.70145 .3146 m .72294 .32793 L .70775 .31595 L p F P
0 g
s
.70775 .31595 m
.72529 .32957 L
s
.515 .533 .104 r
.21162 .51074 m .21772 .49048 L .22565 .4652 L p F P
0 g
s
.519 .538 .026 r
.21772 .49048 m .21162 .51074 L .20701 .53753 L p F P
0 g
s
.20916 .53105 m
.20993 .52471 L
s
.21703 .4935 m
.21962 .48524 L
s
.398 .413 .482 r
.77455 .78955 m .78484 .77573 L .76589 .79617 L p F P
0 g
s
.78263 .77812 m
.78951 .76838 L
s
.398 .413 .482 r
.76589 .79617 m .75651 .8088 L .77455 .78955 L p F P
0 g
s
.295 .604 .328 r
.27224 .38372 m .28777 .36656 L .30272 .35007 L p F P
0 g
s
.23 .632 .328 r
.32027 .33483 m .30272 .35007 L .28777 .36656 L p F P
0 g
s
.3131 .34184 m
.3198 .33652 L
s
.28803 .36631 m
.28811 .36622 L
s
.041 .588 .461 r
.43354 .27378 m .41102 .28141 L .39907 .28762 L p F P
0 g
s
.41842 .27985 m
.42391 .27869 L
s
.021 .589 .461 r
.37599 .29772 m .39907 .28762 L .41102 .28141 L p F P
0 g
s
.39004 .29059 m
.41102 .28141 L
s
.475 .399 .419 r
.80057 .75351 m .80889 .73795 L .79252 .76129 L p F P
0 g
s
.8082 .73894 m
.81298 .7298 L
s
.475 .399 .419 r
.79252 .76129 m .78484 .77573 L .80057 .75351 L p F P
0 g
s
.259 .201 .673 r
.45588 .89818 m .47179 .90132 L .48132 .9014 L p F P
0 g
s
.46313 .89773 m
.46789 .8997 L
s
.236 .227 .673 r
.49485 .90332 m .48132 .9014 L .47179 .90132 L p F P
0 g
s
.47179 .90132 m
.4882 .90364 L
s
.46 .015 .59 r
.33326 .84154 m .3465 .85126 L .36662 .86277 L p F P
0 g
s
.3288 .83705 m
.33874 .84503 L
s
.456 .063 .59 r
.37978 .87064 m .36662 .86277 L .3465 .85126 L p F P
0 g
s
.3465 .85126 m
.36144 .86019 L
s
.385 .095 .635 r
.37978 .87064 m .39432 .87775 L .41265 .88416 L p F P
0 g
s
.3779 .86825 m
.38753 .87382 L
s
.373 .135 .635 r
.42617 .88957 m .41265 .88416 L .39432 .87775 L p F P
0 g
s
.39432 .87775 m
.41009 .88407 L
s
.319 .41 .539 r
.74487 .82077 m .75651 .8088 L .73552 .82585 L p F P
0 g
s
.75463 .81033 m
.75826 .80645 L
s
.319 .41 .539 r
.73552 .82585 m .72509 .8366 L .74487 .82077 L p F P
0 g
s
.73113 .83196 m
.74487 .82077 L
s
.024 .327 .673 r
.58856 .89991 m .60418 .89639 L .59052 .89734 L p F P
0 g
s
.59627 .89694 m
.59846 .8961 L
s
.024 .327 .673 r
.59052 .89734 m .57767 .90024 L .58856 .89991 L p F P
0 g
s
.57238 .90262 m
.58856 .89991 L
s
.447 .572 .181 r
.22565 .4652 m .23528 .44547 L .24615 .42246 L p F P
0 g
s
.456 .584 .104 r
.23528 .44547 m .22565 .4652 L .21772 .49048 L p F P
0 g
s
.22565 .4652 m
.23677 .44171 L
s
.547 .37 .352 r
.82182 .71327 m .82763 .69613 L .8143 .72183 L p F P
0 g
s
.547 .37 .352 r
.8143 .72183 m .80889 .73795 L .82182 .71327 L p F P
0 g
s
.82182 .71327 m
.83125 .68757 L
s
.611 .412 .13 r
.20722 .63264 m .20609 .61331 L .20351 .58533 L p F P
0 g
s
.596 .402 .206 r
.20609 .61331 m .20722 .63264 L .2134 .66005 L p F P
0 g
s
.20469 .60515 m
.20722 .63264 L
s
.308 .632 .256 r
.28777 .36656 m .27224 .38372 L .25898 .40377 L p F P
0 g
s
.28754 .36685 m
.28803 .36631 L
s
.373 .596 .256 r
.24615 .42246 m .25898 .40377 L .27224 .38372 L p F P
0 g
s
.25991 .40169 m
.27224 .38372 L
s
.464 .363 .461 r
.63096 .27754 m .60779 .2707 L .61629 .27583 L p F P
0 g
s
.464 .363 .461 r
.61629 .27583 m .64182 .28336 L .63096 .27754 L p F P
0 g
s
.63096 .27754 m
.65271 .28599 L
s
.717 .206 .052 r
.84734 .54807 m .84314 .52777 L .8442 .55569 L p F P
0 g
s
.717 .206 .052 r
.8442 .55569 m .8484 .57572 L .84734 .54807 L p F P
0 g
s
.84274 .52129 m
.84734 .54807 L
s
.279 .173 .673 r
.44063 .89426 m .45588 .89818 L .46822 .89882 L p F P
0 g
s
.44466 .89409 m
.44884 .89562 L
s
.259 .201 .673 r
.48132 .9014 m .46822 .89882 L .45588 .89818 L p F P
0 g
s
.45588 .89818 m
.47179 .90132 L
s
.385 .616 .181 r
.25898 .40377 m .24615 .42246 L .23528 .44547 L p F P
0 g
s
.23677 .44171 m
.24615 .42246 L
s
.24615 .42246 m
.25991 .40169 L
s
.089 .628 .397 r
.37599 .29772 m .35493 .30936 L .34053 .32083 L p F P
0 g
s
.36991 .30168 m
.37086 .30119 L
s
.154 .616 .397 r
.32027 .33483 m .34053 .32083 L .35493 .30936 L p F P
0 g
s
.33613 .32236 m
.35493 .30936 L
s
.135 .373 .635 r
.66547 .87443 m .67937 .86694 L .65797 .8749 L p F P
0 g
s
.67702 .86781 m
.68283 .86449 L
s
.135 .373 .635 r
.65797 .8749 m .64611 .88131 L .66547 .87443 L p F P
0 g
s
.65027 .88113 m
.66547 .87443 L
s
.243 .391 .59 r
.71272 .84668 m .72509 .8366 L .70264 .84987 L p F P
0 g
s
.243 .391 .59 r
.70264 .84987 m .69181 .85873 L .71272 .84668 L p F P
0 g
s
.69858 .856 m
.71272 .84668 L
s
.71272 .84668 m
.73113 .83196 L
s
.011 .328 .673 r
.60418 .89639 m .61907 .8921 L .60276 .8938 L p F P
0 g
s
.6152 .8925 m
.6166 .89201 L
s
.011 .328 .673 r
.60276 .8938 m .59052 .89734 L .60418 .89639 L p F P
0 g
s
.58856 .89991 m
.60418 .89639 L
s
.652 .163 .328 r
.74182 .3426 m .72294 .32793 L .73625 .34313 L p F P
0 g
s
.652 .163 .328 r
.73625 .34313 m .75629 .35866 L .74182 .3426 L p F P
0 g
s
.72529 .32957 m
.74182 .3426 L
s
.74182 .3426 m
.7579 .35839 L
s
.102 .581 .461 r
.45732 .26783 m .43354 .27378 L .42388 .27922 L p F P
0 g
s
.041 .588 .461 r
.39907 .28762 m .42388 .27922 L .43354 .27378 L p F P
0 g
s
.41102 .28141 m
.43354 .27378 L
s
.612 .326 .281 r
.83735 .66959 m .84016 .65113 L .83024 .67856 L p F P
0 g
s
.612 .326 .281 r
.83024 .67856 m .82763 .69613 L .83735 .66959 L p F P
0 g
s
.83735 .66959 m
.84346 .64253 L
s
.83125 .68757 m
.83735 .66959 L
s
.596 .171 .419 r
.27243 .78246 m .26347 .76831 L .24739 .74551 L p F P
0 g
s
.551 .159 .482 r
.26347 .76831 m .27243 .78246 L .29096 .80232 L p F P
0 g
s
.564 .1 .482 r
.30144 .81465 m .29096 .80232 L .27243 .78246 L p F P
0 g
s
.25705 .76075 m
.27243 .78246 L
s
.27243 .78246 m
.2839 .79593 L
s
.736 .13 .026 r
.83854 .50098 m .83067 .48082 L .8352 .50763 L p F P
0 g
s
.736 .13 .026 r
.8352 .50763 m .84314 .52777 L .83854 .50098 L p F P
0 g
s
.83056 .47558 m
.83854 .50098 L
s
.83854 .50098 m
.84274 .52129 L
s
.512 .091 .539 r
.29096 .80232 m .30144 .81465 L .32188 .8311 L p F P
0 g
s
.518 .037 .539 r
.33326 .84154 m .32188 .8311 L .30144 .81465 L p F P
0 g
s
.2839 .79593 m
.30144 .81465 L
s
.30144 .81465 m
.31412 .82625 L
s
.572 .48 .052 r
.20351 .58533 m .20595 .56532 L .20701 .53753 L p F P
0 g
s
.564 .474 .13 r
.20595 .56532 m .20351 .58533 L .20609 .61331 L p F P
0 g
s
.20351 .58533 m
.20469 .60515 L
s
.20351 .58533 m
.20457 .55781 L
s
.295 .143 .673 r
.42617 .88957 m .44063 .89426 L .45567 .89558 L p F P
0 g
s
.42693 .88952 m
.42835 .89002 L
s
.279 .173 .673 r
.46822 .89882 m .45567 .89558 L .44063 .89426 L p F P
0 g
s
.44063 .89426 m
.45588 .89818 L
s
.612 .248 .352 r
.24739 .74551 m .24056 .72964 L .22741 .70444 L p F P
0 g
s
.575 .233 .419 r
.24056 .72964 m .24739 .74551 L .26347 .76831 L p F P
0 g
s
.24739 .74551 m
.25705 .76075 L
s
.23469 .7213 m
.24739 .74551 L
s
.424 .41 .461 r
.60779 .2707 m .58352 .26559 L .5895 .2702 L p F P
0 g
s
.424 .41 .461 r
.5895 .2702 m .61629 .27583 L .60779 .2707 L p F P
0 g
s
.60779 .2707 m
.63096 .27754 L
s
.57 .279 .397 r
.68784 .30358 m .66578 .29266 L .6776 .30282 L p F P
0 g
s
.57 .279 .397 r
.6776 .30282 m .70145 .3146 L .68784 .30358 L p F P
0 g
s
.67279 .29593 m
.68784 .30358 L
s
.68784 .30358 m
.70775 .31595 L
s
.393 .054 .635 r
.36662 .86277 m .37978 .87064 L .40022 .87806 L p F P
0 g
s
.385 .095 .635 r
.41265 .88416 m .40022 .87806 L .37978 .87064 L p F P
0 g
s
.36144 .86019 m
.37978 .87064 L
s
.37978 .87064 m
.39432 .87775 L
s
.696 .098 .256 r
.77332 .37535 m .75629 .35866 L .76846 .37766 L p F P
0 g
s
.696 .098 .256 r
.76846 .37766 m .78627 .39505 L .77332 .37535 L p F P
0 g
s
.7579 .35839 m
.77332 .37535 L
s
.77332 .37535 m
.78719 .39297 L
s
.739 .052 .104 r
.8228 .45566 m .81144 .43616 L .8191 .46107 L p F P
0 g
s
.739 .052 .104 r
.8191 .46107 m .83067 .48082 L .8228 .45566 L p F P
0 g
s
.81178 .4324 m
.8228 .45566 L
s
.8228 .45566 m
.83056 .47558 L
s
.045 .325 .673 r
.61907 .8921 m .63309 .88706 L .61426 .88966 L p F P
0 g
s
.045 .325 .673 r
.61426 .88966 m .60276 .8938 L .61907 .8921 L p F P
0 g
s
.61907 .8921 m
.63392 .88701 L
s
.60418 .89639 m
.61907 .8921 L
s
.162 .567 .461 r
.48204 .26365 m .45732 .26783 L .45011 .27266 L p F P
0 g
s
.102 .581 .461 r
.42388 .27922 m .45011 .27266 L .45732 .26783 L p F P
0 g
s
.43354 .27378 m
.45732 .26783 L
s
.459 .033 .59 r
.32188 .8311 m .33326 .84154 L .35499 .85421 L p F P
0 g
s
.46 .015 .59 r
.36662 .86277 m .35499 .85421 L .33326 .84154 L p F P
0 g
s
.31412 .82625 m
.33326 .84154 L
s
.33326 .84154 m
.3465 .85126 L
s
.725 .026 .181 r
.80074 .41339 m .78627 .39505 L .79652 .41734 L p F P
0 g
s
.725 .026 .181 r
.79652 .41734 m .81144 .43616 L .80074 .41339 L p F P
0 g
s
.78719 .39297 m
.80074 .41339 L
s
.80074 .41339 m
.81178 .4324 L
s
.612 .326 .281 r
.22741 .70444 m .22324 .68705 L .2134 .66005 L p F P
0 g
s
.583 .311 .352 r
.22324 .68705 m .22741 .70444 L .24056 .72964 L p F P
0 g
s
.22741 .70444 m
.23469 .7213 L
s
.21781 .67831 m
.22741 .70444 L
s
.667 .27 .206 r
.84639 .62338 m .84582 .60394 L .83953 .63239 L p F P
0 g
s
.667 .27 .206 r
.83953 .63239 m .84016 .65113 L .84639 .62338 L p F P
0 g
s
.84639 .62338 m
.84895 .59566 L
s
.84346 .64253 m
.84639 .62338 L
s
.163 .652 .328 r
.34053 .32083 m .32027 .33483 L .30638 .35044 L p F P
0 g
s
.23 .632 .328 r
.28777 .36656 m .30638 .35044 L .32027 .33483 L p F P
0 g
s
.32027 .33483 m
.33613 .32236 L
s
.30272 .35007 m
.32027 .33483 L
s
.379 .452 .461 r
.58352 .26559 m .55846 .26229 L .56183 .26656 L p F P
0 g
s
.379 .452 .461 r
.56183 .26656 m .5895 .2702 L .58352 .26559 L p F P
0 g
s
.57707 .26464 m
.58352 .26559 L
s
.58352 .26559 m
.60779 .2707 L
s
.519 .538 .026 r
.20701 .53753 m .21315 .51728 L .21772 .49048 L p F P
0 g
s
.518 .537 .052 r
.21315 .51728 m .20701 .53753 L .20595 .56532 L p F P
0 g
s
.20457 .55781 m
.20701 .53753 L
s
.20701 .53753 m
.21162 .51074 L
s
.173 .357 .635 r
.67937 .86694 m .69181 .85873 L .66855 .86789 L p F P
0 g
s
.173 .357 .635 r
.66855 .86789 m .65797 .8749 L .67937 .86694 L p F P
0 g
s
.66547 .87443 m
.67937 .86694 L
s
.67937 .86694 m
.69858 .856 L
s
.023 .634 .397 r
.39907 .28762 m .37599 .29772 L .36328 .30828 L p F P
0 g
s
.089 .628 .397 r
.34053 .32083 m .36328 .30828 L .37599 .29772 L p F P
0 g
s
.37599 .29772 m
.39004 .29059 L
s
.35493 .30936 m
.37599 .29772 L
s
.308 .111 .673 r
.41265 .88416 m .42617 .88957 L .4438 .89172 L p F P
0 g
s
.295 .143 .673 r
.45567 .89558 m .4438 .89172 L .42617 .88957 L p F P
0 g
s
.42617 .88957 m
.44063 .89426 L
s
.41009 .88407 m
.42617 .88957 L
s
.22 .547 .461 r
.50737 .26131 m .48204 .26365 L .47741 .26806 L p F P
0 g
s
.162 .567 .461 r
.45011 .27266 m .47741 .26806 L .48204 .26365 L p F P
0 g
s
.48204 .26365 m
.48703 .26291 L
s
.45732 .26783 m
.48204 .26365 L
s
.439 .369 .482 r
.78484 .77573 m .79252 .76129 L .77283 .78298 L p F P
0 g
s
.439 .369 .482 r
.77283 .78298 m .76589 .79617 L .78484 .77573 L p F P
0 g
s
.78484 .77573 m
.80057 .75351 L
s
.77455 .78955 m
.78484 .77573 L
s
.361 .374 .539 r
.75651 .8088 m .76589 .79617 L .74386 .81452 L p F P
0 g
s
.361 .374 .539 r
.74386 .81452 m .73552 .82585 L .75651 .8088 L p F P
0 g
s
.74487 .82077 m
.75651 .8088 L
s
.75651 .8088 m
.77455 .78955 L
s
.329 .489 .461 r
.55846 .26229 m .53296 .26086 L .53366 .26498 L p F P
0 g
s
.329 .489 .461 r
.53366 .26498 m .56183 .26656 L .55846 .26229 L p F P
0 g
s
.55484 .26171 m
.55846 .26229 L
s
.55846 .26229 m
.58352 .26559 L
s
.276 .521 .461 r
.53296 .26086 m .50737 .26131 L .50539 .26548 L p F P
0 g
s
.22 .547 .461 r
.47741 .26806 m .50539 .26548 L .50737 .26131 L p F P
0 g
s
.50737 .26131 m
.50951 .26084 L
s
.48204 .26365 m
.50737 .26131 L
s
.596 .402 .206 r
.2134 .66005 m .21236 .64143 L .20609 .61331 L p F P
0 g
s
.575 .388 .281 r
.21236 .64143 m .2134 .66005 L .22324 .68705 L p F P
0 g
s
.2134 .66005 m
.21781 .67831 L
s
.20722 .63264 m
.2134 .66005 L
s
.514 .347 .419 r
.80889 .73795 m .8143 .72183 L .79745 .74636 L p F P
0 g
s
.514 .347 .419 r
.79745 .74636 m .79252 .76129 L .80889 .73795 L p F P
0 g
s
.80889 .73795 m
.82182 .71327 L
s
.80057 .75351 m
.80889 .73795 L
s
.276 .521 .461 r
.50539 .26548 m .53366 .26498 L .53296 .26086 L p F P
0 g
s
.50737 .26131 m
.53296 .26086 L
s
.53221 .26044 m
.53296 .26086 L
s
.53296 .26086 m
.55846 .26229 L
s
.079 .318 .673 r
.63309 .88706 m .64611 .88131 L .62491 .88493 L p F P
0 g
s
.079 .318 .673 r
.62491 .88493 m .61426 .88966 L .63309 .88706 L p F P
0 g
s
.63309 .88706 m
.65027 .88113 L
s
.61907 .8921 m
.63309 .88706 L
s
.283 .363 .59 r
.72509 .8366 m .73552 .82585 L .71173 .84043 L p F P
0 g
s
.283 .363 .59 r
.71173 .84043 m .70264 .84987 L .72509 .8366 L p F P
0 g
s
.71272 .84668 m
.72509 .8366 L
s
.72509 .8366 m
.74487 .82077 L
s
.456 .584 .104 r
.21772 .49048 m .22751 .4705 L .23528 .44547 L p F P
0 g
s
.46 .589 .026 r
.22751 .4705 m .21772 .49048 L .21315 .51728 L p F P
0 g
s
.21162 .51074 m
.21772 .49048 L
s
.21772 .49048 m
.22565 .4652 L
s
.708 .203 .13 r
.8484 .57572 m .8442 .55569 L .84162 .5844 L p F P
0 g
s
.708 .203 .13 r
.84162 .5844 m .84582 .60394 L .8484 .57572 L p F P
0 g
s
.84734 .54807 m
.8484 .57572 L
s
.8484 .57572 m
.84895 .59566 L
s
.538 .337 .397 r
.66578 .29266 m .64182 .28336 L .65167 .29278 L p F P
0 g
s
.538 .337 .397 r
.65167 .29278 m .6776 .30282 L .66578 .29266 L p F P
0 g
s
.65271 .28599 m
.66578 .29266 L
s
.66578 .29266 m
.68784 .30358 L
s
.241 .661 .256 r
.30638 .35044 m .28777 .36656 L .2752 .38589 L p F P
0 g
s
.308 .632 .256 r
.25898 .40377 m .2752 .38589 L .28777 .36656 L p F P
0 g
s
.27224 .38372 m
.28777 .36656 L
s
.28777 .36656 m
.30272 .35007 L
s
.396 .013 .635 r
.35499 .85421 m .36662 .86277 L .389 .87133 L p F P
0 g
s
.393 .054 .635 r
.40022 .87806 m .389 .87133 L .36662 .86277 L p F P
0 g
s
.3465 .85126 m
.36662 .86277 L
s
.36662 .86277 m
.37978 .87064 L
s
.632 .23 .328 r
.72294 .32793 m .70145 .3146 L .7134 .329 L p F P
0 g
s
.632 .23 .328 r
.7134 .329 m .73625 .34313 L .72294 .32793 L p F P
0 g
s
.70775 .31595 m
.72294 .32793 L
s
.72294 .32793 m
.74182 .3426 L
s
.144 .212 .704 r
.50868 .90454 m .52267 .90508 L .52351 .90067 L p F P
0 g
s
.121 .226 .704 r
.52267 .90508 m .5367 .90491 L .53432 .90054 L p F P
0 g
s
.121 .226 .704 r
.53432 .90054 m .52351 .90067 L .52267 .90508 L p F P
0 g
s
.5219 .90577 m
.52267 .90508 L
s
.097 .237 .704 r
.5367 .90491 m .55063 .90404 L .54506 .89987 L p F P
0 g
s
.097 .237 .704 r
.54506 .89987 m .53432 .90054 L .5367 .90491 L p F P
0 g
s
.5367 .90491 m
.53889 .90556 L
s
.52267 .90508 m
.5367 .90491 L
s
.165 .195 .704 r
.49485 .90332 m .50868 .90454 L .51272 .90026 L p F P
0 g
s
.144 .212 .704 r
.52351 .90067 m .51272 .90026 L .50868 .90454 L p F P
0 g
s
.50496 .90512 m
.50868 .90454 L
s
.50868 .90454 m
.52267 .90508 L
s
.071 .246 .704 r
.55063 .90404 m .56433 .90248 L .55561 .89867 L p F P
0 g
s
.071 .246 .704 r
.55561 .89867 m .54506 .89987 L .55063 .90404 L p F P
0 g
s
.55063 .90404 m
.55577 .90451 L
s
.5367 .90491 m
.55063 .90404 L
s
.385 .616 .181 r
.23528 .44547 m .24849 .42629 L .25898 .40377 L p F P
0 g
s
.393 .628 .104 r
.24849 .42629 m .23528 .44547 L .22751 .4705 L p F P
0 g
s
.22565 .4652 m
.23528 .44547 L
s
.23528 .44547 m
.24615 .42246 L
s
.318 .652 .181 r
.2752 .38589 m .25898 .40377 L .24849 .42629 L p F P
0 g
s
.25898 .40377 m
.27224 .38372 L
s
.24615 .42246 m
.25898 .40377 L
s
.318 .079 .673 r
.40022 .87806 m .41265 .88416 L .43273 .88727 L p F P
0 g
s
.308 .111 .673 r
.4438 .89172 m .43273 .88727 L .41265 .88416 L p F P
0 g
s
.41265 .88416 m
.42617 .88957 L
s
.39432 .87775 m
.41265 .88416 L
s
.583 .311 .352 r
.82763 .69613 m .83024 .67856 L .81665 .70532 L p F P
0 g
s
.583 .311 .352 r
.81665 .70532 m .8143 .72183 L .82763 .69613 L p F P
0 g
s
.82763 .69613 m
.83735 .66959 L
s
.82182 .71327 m
.82763 .69613 L
s
.185 .177 .704 r
.48132 .9014 m .49485 .90332 L .50206 .89931 L p F P
0 g
s
.165 .195 .704 r
.51272 .90026 m .50206 .89931 L .49485 .90332 L p F P
0 g
s
.4882 .90364 m
.49485 .90332 L
s
.49485 .90332 m
.50868 .90454 L
s
.045 .252 .704 r
.56433 .90248 m .57767 .90024 L .56588 .89694 L p F P
0 g
s
.045 .252 .704 r
.56588 .89694 m .55561 .89867 L .56433 .90248 L p F P
0 g
s
.56433 .90248 m
.57238 .90262 L
s
.55063 .90404 m
.56433 .90248 L
s
.551 .159 .482 r
.29096 .80232 m .28283 .78939 L .26347 .76831 L p F P
0 g
s
.499 .144 .539 r
.28283 .78939 m .29096 .80232 L .31252 .82004 L p F P
0 g
s
.512 .091 .539 r
.32188 .8311 m .31252 .82004 L .29096 .80232 L p F P
0 g
s
.29096 .80232 m
.30144 .81465 L
s
.27243 .78246 m
.29096 .80232 L
s
.044 .633 .397 r
.42388 .27922 m .39907 .28762 L .38825 .29738 L p F P
0 g
s
.023 .634 .397 r
.36328 .30828 m .38825 .29738 L .39907 .28762 L p F P
0 g
s
.39907 .28762 m
.41102 .28141 L
s
.37599 .29772 m
.39907 .28762 L
s
.564 .474 .13 r
.20609 .61331 m .20853 .5938 L .20595 .56532 L p F P
0 g
s
.551 .462 .206 r
.20853 .5938 m .20609 .61331 L .21236 .64143 L p F P
0 g
s
.20609 .61331 m
.20722 .63264 L
s
.20351 .58533 m
.20609 .61331 L
s
.735 .13 .052 r
.84314 .52777 m .8352 .50763 L .83625 .5358 L p F P
0 g
s
.735 .13 .052 r
.83625 .5358 m .8442 .55569 L .84314 .52777 L p F P
0 g
s
.83854 .50098 m
.84314 .52777 L
s
.84314 .52777 m
.84734 .54807 L
s
.575 .233 .419 r
.26347 .76831 m .2572 .75359 L .24056 .72964 L p F P
0 g
s
.531 .215 .482 r
.2572 .75359 m .26347 .76831 L .28283 .78939 L p F P
0 g
s
.26347 .76831 m
.27243 .78246 L
s
.24739 .74551 m
.26347 .76831 L
s
.209 .337 .635 r
.69181 .85873 m .70264 .84987 L .67773 .86033 L p F P
0 g
s
.209 .337 .635 r
.67773 .86033 m .66855 .86789 L .69181 .85873 L p F P
0 g
s
.67937 .86694 m
.69181 .85873 L
s
.69181 .85873 m
.71272 .84668 L
s
.202 .157 .704 r
.46822 .89882 m .48132 .9014 L .49165 .89783 L p F P
0 g
s
.185 .177 .704 r
.50206 .89931 m .49165 .89783 L .48132 .9014 L p F P
0 g
s
.47179 .90132 m
.48132 .9014 L
s
.48132 .9014 m
.49485 .90332 L
s
.454 .081 .59 r
.31252 .82004 m .32188 .8311 L .34504 .84504 L p F P
0 g
s
.459 .033 .59 r
.35499 .85421 m .34504 .84504 L .32188 .8311 L p F P
0 g
s
.30144 .81465 m
.32188 .8311 L
s
.32188 .8311 m
.33326 .84154 L
s
.111 .308 .673 r
.64611 .88131 m .65797 .8749 L .63458 .87968 L p F P
0 g
s
.111 .308 .673 r
.63458 .87968 m .62491 .88493 L .64611 .88131 L p F P
0 g
s
.64611 .88131 m
.66547 .87443 L
s
.63309 .88706 m
.64611 .88131 L
s
.094 .666 .328 r
.36328 .30828 m .34053 .32083 L .3279 .33561 L p F P
0 g
s
.163 .652 .328 r
.30638 .35044 m .3279 .33561 L .34053 .32083 L p F P
0 g
s
.32027 .33483 m
.34053 .32083 L
s
.34053 .32083 m
.35493 .30936 L
s
.019 .255 .704 r
.57767 .90024 m .59052 .89734 L .57576 .8947 L p F P
0 g
s
.019 .255 .704 r
.57576 .8947 m .56588 .89694 L .57767 .90024 L p F P
0 g
s
.57767 .90024 m
.58856 .89991 L
s
.56433 .90248 m
.57767 .90024 L
s
.682 .17 .256 r
.75629 .35866 m .73625 .34313 L .74746 .36146 L p F P
0 g
s
.682 .17 .256 r
.74746 .36146 m .76846 .37766 L .75629 .35866 L p F P
0 g
s
.74182 .3426 m
.75629 .35866 L
s
.75629 .35866 m
.77332 .37535 L
s
.5 .391 .397 r
.64182 .28336 m .61629 .27583 L .62399 .28465 L p F P
0 g
s
.5 .391 .397 r
.62399 .28465 m .65167 .29278 L .64182 .28336 L p F P
0 g
s
.63096 .27754 m
.64182 .28336 L
s
.64182 .28336 m
.66578 .29266 L
s
.583 .311 .352 r
.24056 .72964 m .23672 .7133 L .22324 .68705 L p F P
0 g
s
.547 .292 .419 r
.23672 .7133 m .24056 .72964 L .2572 .75359 L p F P
0 g
s
.24056 .72964 m
.24739 .74551 L
s
.22741 .70444 m
.24056 .72964 L
s
.643 .26 .281 r
.84016 .65113 m .83953 .63239 L .82951 .66073 L p F P
0 g
s
.643 .26 .281 r
.82951 .66073 m .83024 .67856 L .84016 .65113 L p F P
0 g
s
.84016 .65113 m
.84639 .62338 L
s
.83735 .66959 m
.84016 .65113 L
s
.217 .135 .704 r
.45567 .89558 m .46822 .89882 L .48157 .89584 L p F P
0 g
s
.202 .157 .704 r
.49165 .89783 m .48157 .89584 L .46822 .89882 L p F P
0 g
s
.45588 .89818 m
.46822 .89882 L
s
.46822 .89882 m
.48132 .9014 L
s
.746 .052 .026 r
.83067 .48082 m .8191 .46107 L .82351 .48789 L p F P
0 g
s
.746 .052 .026 r
.82351 .48789 m .8352 .50763 L .83067 .48082 L p F P
0 g
s
.8228 .45566 m
.83067 .48082 L
s
.83067 .48082 m
.83854 .50098 L
s
.518 .537 .052 r
.20595 .56532 m .21209 .54533 L .21315 .51728 L p F P
0 g
s
.512 .53 .13 r
.21209 .54533 m .20595 .56532 L .20853 .5938 L p F P
0 g
s
.20351 .58533 m
.20595 .56532 L
s
.20595 .56532 m
.20701 .53753 L
s
.325 .045 .673 r
.389 .87133 m .40022 .87806 L .42257 .88227 L p F P
0 g
s
.318 .079 .673 r
.43273 .88727 m .42257 .88227 L .40022 .87806 L p F P
0 g
s
.37978 .87064 m
.40022 .87806 L
s
.40022 .87806 m
.41265 .88416 L
s
.719 .101 .181 r
.78627 .39505 m .76846 .37766 L .7781 .39947 L p F P
0 g
s
.719 .101 .181 r
.7781 .39947 m .79652 .41734 L .78627 .39505 L p F P
0 g
s
.77332 .37535 m
.78627 .39505 L
s
.78627 .39505 m
.80074 .41339 L
s
.008 .256 .704 r
.59052 .89734 m .60276 .8938 L .58515 .89197 L p F P
0 g
s
.008 .256 .704 r
.58515 .89197 m .57576 .8947 L .59052 .89734 L p F P
0 g
s
.59052 .89734 m
.60418 .89639 L
s
.57767 .90024 m
.59052 .89734 L
s
.395 .028 .635 r
.34504 .84504 m .35499 .85421 L .37913 .86403 L p F P
0 g
s
.396 .013 .635 r
.389 .87133 m .37913 .86403 L .35499 .85421 L p F P
0 g
s
.33326 .84154 m
.35499 .85421 L
s
.35499 .85421 m
.36662 .86277 L
s
.74 .026 .104 r
.81144 .43616 m .79652 .41734 L .80384 .44201 L p F P
0 g
s
.74 .026 .104 r
.80384 .44201 m .8191 .46107 L .81144 .43616 L p F P
0 g
s
.80074 .41339 m
.81144 .43616 L
s
.81144 .43616 m
.8228 .45566 L
s
.398 .335 .539 r
.76589 .79617 m .77283 .78298 L .74998 .8027 L p F P
0 g
s
.398 .335 .539 r
.74998 .8027 m .74386 .81452 L .76589 .79617 L p F P
0 g
s
.76589 .79617 m
.78484 .77573 L
s
.75651 .8088 m
.76589 .79617 L
s
.11 .625 .397 r
.45011 .27266 m .42388 .27922 L .41513 .28831 L p F P
0 g
s
.044 .633 .397 r
.38825 .29738 m .41513 .28831 L .42388 .27922 L p F P
0 g
s
.42388 .27922 m
.43354 .27378 L
s
.39907 .28762 m
.42388 .27922 L
s
.604 .295 .328 r
.70145 .3146 m .6776 .30282 L .68799 .31651 L p F P
0 g
s
.604 .295 .328 r
.68799 .31651 m .7134 .329 L .70145 .3146 L p F P
0 g
s
.68784 .30358 m
.70145 .3146 L
s
.70145 .3146 m
.72294 .32793 L
s
.319 .332 .59 r
.73552 .82585 m .74386 .81452 L .71895 .8305 L p F P
0 g
s
.319 .332 .59 r
.71895 .8305 m .71173 .84043 L .73552 .82585 L p F P
0 g
s
.72509 .8366 m
.73552 .82585 L
s
.73552 .82585 m
.75651 .8088 L
s
.23 .111 .704 r
.4438 .89172 m .45567 .89558 L .47193 .89334 L p F P
0 g
s
.217 .135 .704 r
.48157 .89584 m .47193 .89334 L .45567 .89558 L p F P
0 g
s
.44063 .89426 m
.45567 .89558 L
s
.45567 .89558 m
.46822 .89882 L
s
.575 .388 .281 r
.22324 .68705 m .22235 .66933 L .21236 .64143 L p F P
0 g
s
.547 .37 .352 r
.22235 .66933 m .22324 .68705 L .23672 .7133 L p F P
0 g
s
.22324 .68705 m
.22741 .70444 L
s
.2134 .66005 m
.22324 .68705 L
s
.475 .321 .482 r
.79252 .76129 m .79745 .74636 L .77721 .76936 L p F P
0 g
s
.475 .321 .482 r
.77721 .76936 m .77283 .78298 L .79252 .76129 L p F P
0 g
s
.79252 .76129 m
.80889 .73795 L
s
.78484 .77573 m
.79252 .76129 L
s
.691 .198 .206 r
.84582 .60394 m .84162 .5844 L .83533 .61358 L p F P
0 g
s
.691 .198 .206 r
.83533 .61358 m .83953 .63239 L .84582 .60394 L p F P
0 g
s
.84582 .60394 m
.8484 .57572 L
s
.84582 .60394 m
.84639 .62338 L
s
.143 .295 .673 r
.65797 .8749 m .66855 .86789 L .64318 .87394 L p F P
0 g
s
.143 .295 .673 r
.64318 .87394 m .63458 .87968 L .65797 .8749 L p F P
0 g
s
.65797 .8749 m
.67937 .86694 L
s
.64611 .88131 m
.65797 .8749 L
s
.17 .682 .256 r
.3279 .33561 m .30638 .35044 L .29468 .36909 L p F P
0 g
s
.241 .661 .256 r
.2752 .38589 m .29468 .36909 L .30638 .35044 L p F P
0 g
s
.28777 .36656 m
.30638 .35044 L
s
.30638 .35044 m
.32027 .33483 L
s
.456 .441 .397 r
.61629 .27583 m .5895 .2702 L .59492 .27857 L p F P
0 g
s
.456 .441 .397 r
.59492 .27857 m .62399 .28465 L .61629 .27583 L p F P
0 g
s
.60779 .2707 m
.61629 .27583 L
s
.61629 .27583 m
.64182 .28336 L
s
.035 .254 .704 r
.60276 .8938 m .61426 .88966 L .59395 .88877 L p F P
0 g
s
.035 .254 .704 r
.59395 .88877 m .58515 .89197 L .60276 .8938 L p F P
0 g
s
.60276 .8938 m
.61907 .8921 L
s
.59052 .89734 m
.60276 .8938 L
s
.46 .589 .026 r
.21315 .51728 m .22303 .49732 L .22751 .4705 L p F P
0 g
s
.459 .588 .052 r
.22303 .49732 m .21315 .51728 L .21209 .54533 L p F P
0 g
s
.20701 .53753 m
.21315 .51728 L
s
.21315 .51728 m
.21772 .49048 L
s
.243 .313 .635 r
.70264 .84987 m .71173 .84043 L .68539 .85229 L p F P
0 g
s
.243 .313 .635 r
.68539 .85229 m .67773 .86033 L .70264 .84987 L p F P
0 g
s
.69181 .85873 m
.70264 .84987 L
s
.70264 .84987 m
.72509 .8366 L
s
.547 .292 .419 r
.8143 .72183 m .81665 .70532 L .79949 .73107 L p F P
0 g
s
.547 .292 .419 r
.79949 .73107 m .79745 .74636 L .8143 .72183 L p F P
0 g
s
.8143 .72183 m
.82763 .69613 L
s
.80889 .73795 m
.8143 .72183 L
s
.174 .61 .397 r
.47741 .26806 m .45011 .27266 L .44358 .28123 L p F P
0 g
s
.11 .625 .397 r
.41513 .28831 m .44358 .28123 L .45011 .27266 L p F P
0 g
s
.45011 .27266 m
.45732 .26783 L
s
.42388 .27922 m
.45011 .27266 L
s
.241 .087 .704 r
.43273 .88727 m .4438 .89172 L .46284 .89037 L p F P
0 g
s
.23 .111 .704 r
.47193 .89334 m .46284 .89037 L .4438 .89172 L p F P
0 g
s
.42617 .88957 m
.4438 .89172 L
s
.4438 .89172 m
.45567 .89558 L
s
.024 .672 .328 r
.38825 .29738 m .36328 .30828 L .35212 .3223 L p F P
0 g
s
.094 .666 .328 r
.3279 .33561 m .35212 .3223 L .36328 .30828 L p F P
0 g
s
.36328 .30828 m
.37599 .29772 L
s
.34053 .32083 m
.36328 .30828 L
s
.551 .462 .206 r
.21236 .64143 m .21483 .62262 L .20853 .5938 L p F P
0 g
s
.531 .446 .281 r
.21483 .62262 m .21236 .64143 L .22235 .66933 L p F P
0 g
s
.21236 .64143 m
.2134 .66005 L
s
.20609 .61331 m
.21236 .64143 L
s
.328 .011 .673 r
.37913 .86403 m .389 .87133 L .41344 .87676 L p F P
0 g
s
.325 .045 .673 r
.42257 .88227 m .41344 .87676 L .389 .87133 L p F P
0 g
s
.36662 .86277 m
.389 .87133 L
s
.389 .87133 m
.40022 .87806 L
s
.393 .628 .104 r
.22751 .4705 m .241 .45108 L .24849 .42629 L p F P
0 g
s
.396 .634 .026 r
.241 .45108 m .22751 .4705 L .22303 .49732 L p F P
0 g
s
.21772 .49048 m
.22751 .4705 L
s
.22751 .4705 m
.23528 .44547 L
s
.249 .682 .181 r
.29468 .36909 m .2752 .38589 L .26525 .40793 L p F P
0 g
s
.318 .652 .181 r
.24849 .42629 m .26525 .40793 L .2752 .38589 L p F P
0 g
s
.2752 .38589 m
.28777 .36656 L
s
.25898 .40377 m
.2752 .38589 L
s
.499 .144 .539 r
.31252 .82004 m .30531 .80844 L .28283 .78939 L p F P
0 g
s
.443 .128 .59 r
.30531 .80844 m .31252 .82004 L .33691 .83533 L p F P
0 g
s
.454 .081 .59 r
.34504 .84504 m .33691 .83533 L .31252 .82004 L p F P
0 g
s
.31252 .82004 m
.32188 .8311 L
s
.29096 .80232 m
.31252 .82004 L
s
.531 .215 .482 r
.28283 .78939 m .2772 .77596 L .2572 .75359 L p F P
0 g
s
.482 .195 .539 r
.2772 .77596 m .28283 .78939 L .30531 .80844 L p F P
0 g
s
.28283 .78939 m
.29096 .80232 L
s
.26347 .76831 m
.28283 .78939 L
s
.407 .486 .397 r
.5895 .2702 m .56183 .26656 L .56488 .27463 L p F P
0 g
s
.407 .486 .397 r
.56488 .27463 m .59492 .27857 L .5895 .2702 L p F P
0 g
s
.58352 .26559 m
.5895 .2702 L
s
.5895 .2702 m
.61629 .27583 L
s
.726 .128 .13 r
.8442 .55569 m .83625 .5358 L .8337 .56502 L p F P
0 g
s
.726 .128 .13 r
.8337 .56502 m .84162 .5844 L .8442 .55569 L p F P
0 g
s
.84314 .52777 m
.8442 .55569 L
s
.8442 .55569 m
.8484 .57572 L
s
.325 .666 .104 r
.26525 .40793 m .24849 .42629 L .241 .45108 L p F P
0 g
s
.23528 .44547 m
.24849 .42629 L
s
.24849 .42629 m
.25898 .40377 L
s
.061 .249 .704 r
.61426 .88966 m .62491 .88493 L .60207 .88514 L p F P
0 g
s
.061 .249 .704 r
.60207 .88514 m .59395 .88877 L .61426 .88966 L p F P
0 g
s
.61426 .88966 m
.63309 .88706 L
s
.60276 .8938 m
.61426 .88966 L
s
.661 .241 .256 r
.73625 .34313 m .7134 .329 L .72347 .34672 L p F P
0 g
s
.661 .241 .256 r
.72347 .34672 m .74746 .36146 L .73625 .34313 L p F P
0 g
s
.72294 .32793 m
.73625 .34313 L
s
.73625 .34313 m
.75629 .35866 L
s
.237 .588 .397 r
.50539 .26548 m .47741 .26806 L .4732 .27625 L p F P
0 g
s
.174 .61 .397 r
.44358 .28123 m .4732 .27625 L .47741 .26806 L p F P
0 g
s
.47741 .26806 m
.48204 .26365 L
s
.45011 .27266 m
.47741 .26806 L
s
.547 .292 .419 r
.2572 .75359 m .25375 .73846 L .23672 .7133 L p F P
0 g
s
.506 .27 .482 r
.25375 .73846 m .2572 .75359 L .2772 .77596 L p F P
0 g
s
.2572 .75359 m
.26347 .76831 L
s
.24056 .72964 m
.2572 .75359 L
s
.39 .07 .635 r
.33691 .83533 m .34504 .84504 L .37073 .85621 L p F P
0 g
s
.395 .028 .635 r
.37913 .86403 m .37073 .85621 L .34504 .84504 L p F P
0 g
s
.32188 .8311 m
.34504 .84504 L
s
.34504 .84504 m
.35499 .85421 L
s
.612 .248 .352 r
.83024 .67856 m .82951 .66073 L .81581 .68859 L p F P
0 g
s
.612 .248 .352 r
.81581 .68859 m .81665 .70532 L .83024 .67856 L p F P
0 g
s
.83024 .67856 m
.84016 .65113 L
s
.82763 .69613 m
.83024 .67856 L
s
.354 .526 .397 r
.56183 .26656 m .53366 .26498 L .53429 .27292 L p F P
0 g
s
.354 .526 .397 r
.53429 .27292 m .56488 .27463 L .56183 .26656 L p F P
0 g
s
.55846 .26229 m
.56183 .26656 L
s
.56183 .26656 m
.5895 .2702 L
s
.57 .357 .328 r
.6776 .30282 m .65167 .29278 L .66032 .30585 L p F P
0 g
s
.57 .357 .328 r
.66032 .30585 m .68799 .31651 L .6776 .30282 L p F P
0 g
s
.66578 .29266 m
.6776 .30282 L
s
.6776 .30282 m
.70145 .3146 L
s
.173 .279 .673 r
.66855 .86789 m .67773 .86033 L .6506 .86776 L p F P
0 g
s
.173 .279 .673 r
.6506 .86776 m .64318 .87394 L .66855 .86789 L p F P
0 g
s
.65797 .8749 m
.66855 .86789 L
s
.66855 .86789 m
.69181 .85873 L
s
.249 .061 .704 r
.42257 .88227 m .43273 .88727 L .45437 .88694 L p F P
0 g
s
.241 .087 .704 r
.46284 .89037 m .45437 .88694 L .43273 .88727 L p F P
0 g
s
.41265 .88416 m
.43273 .88727 L
s
.43273 .88727 m
.4438 .89172 L
s
.297 .56 .397 r
.53366 .26498 m .50539 .26548 L .50358 .27347 L p F P
0 g
s
.237 .588 .397 r
.4732 .27625 m .50358 .27347 L .50539 .26548 L p F P
0 g
s
.50539 .26548 m
.50737 .26131 L
s
.47741 .26806 m
.50539 .26548 L
s
.297 .56 .397 r
.50358 .27347 m .53429 .27292 L .53366 .26498 L p F P
0 g
s
.50539 .26548 m
.53366 .26498 L
s
.53296 .26086 m
.53366 .26498 L
s
.53366 .26498 m
.56183 .26656 L
s
.512 .53 .13 r
.20853 .5938 m .21466 .57431 L .21209 .54533 L p F P
0 g
s
.499 .518 .206 r
.21466 .57431 m .20853 .5938 L .21483 .62262 L p F P
0 g
s
.20609 .61331 m
.20853 .5938 L
s
.20595 .56532 m
.20853 .5938 L
s
.745 .052 .052 r
.8352 .50763 m .82351 .48789 L .82453 .51632 L p F P
0 g
s
.745 .052 .052 r
.82453 .51632 m .83625 .5358 L .8352 .50763 L p F P
0 g
s
.83067 .48082 m
.8352 .50763 L
s
.8352 .50763 m
.84314 .52777 L
s
.352 .297 .59 r
.74386 .81452 m .74998 .8027 L .72419 .82016 L p F P
0 g
s
.352 .297 .59 r
.72419 .82016 m .71895 .8305 L .74386 .81452 L p F P
0 g
s
.74386 .81452 m
.76589 .79617 L
s
.73552 .82585 m
.74386 .81452 L
s
.102 .15 .727 r
.51272 .90026 m .52351 .90067 L .5244 .89244 L p F P
0 g
s
.086 .159 .727 r
.52351 .90067 m .53432 .90054 L .53178 .89235 L p F P
0 g
s
.086 .159 .727 r
.53178 .89235 m .5244 .89244 L .52351 .90067 L p F P
0 g
s
.52267 .90508 m
.52351 .90067 L
s
.069 .167 .727 r
.53432 .90054 m .54506 .89987 L .53911 .89189 L p F P
0 g
s
.069 .167 .727 r
.53911 .89189 m .53178 .89235 L .53432 .90054 L p F P
0 g
s
.53432 .90054 m
.5367 .90491 L
s
.52351 .90067 m
.53432 .90054 L
s
.087 .241 .704 r
.62491 .88493 m .63458 .87968 L .60944 .88111 L p F P
0 g
s
.087 .241 .704 r
.60944 .88111 m .60207 .88514 L .62491 .88493 L p F P
0 g
s
.62491 .88493 m
.64611 .88131 L
s
.61426 .88966 m
.62491 .88493 L
s
.547 .37 .352 r
.23672 .7133 m .23601 .69666 L .22235 .66933 L p F P
0 g
s
.514 .347 .419 r
.23601 .69666 m .23672 .7133 L .25375 .73846 L p F P
0 g
s
.23672 .7133 m
.24056 .72964 L
s
.22324 .68705 m
.23672 .7133 L
s
.704 .176 .181 r
.76846 .37766 m .74746 .36146 L .75634 .38282 L p F P
0 g
s
.704 .176 .181 r
.75634 .38282 m .7781 .39947 L .76846 .37766 L p F P
0 g
s
.75629 .35866 m
.76846 .37766 L
s
.76846 .37766 m
.78627 .39505 L
s
.117 .138 .727 r
.50206 .89931 m .51272 .90026 L .51704 .89216 L p F P
0 g
s
.102 .15 .727 r
.5244 .89244 m .51704 .89216 L .51272 .90026 L p F P
0 g
s
.50868 .90454 m
.51272 .90026 L
s
.51272 .90026 m
.52351 .90067 L
s
.431 .291 .539 r
.77283 .78298 m .77721 .76936 L .75376 .79052 L p F P
0 g
s
.431 .291 .539 r
.75376 .79052 m .74998 .8027 L .77283 .78298 L p F P
0 g
s
.77283 .78298 m
.79252 .76129 L
s
.76589 .79617 m
.77283 .78298 L
s
.051 .174 .727 r
.54506 .89987 m .55561 .89867 L .54631 .89107 L p F P
0 g
s
.051 .174 .727 r
.54631 .89107 m .53911 .89189 L .54506 .89987 L p F P
0 g
s
.54506 .89987 m
.55063 .90404 L
s
.53432 .90054 m
.54506 .89987 L
s
.047 .671 .328 r
.41513 .28831 m .38825 .29738 L .37874 .31073 L p F P
0 g
s
.024 .672 .328 r
.35212 .3223 m .37874 .31073 L .38825 .29738 L p F P
0 g
s
.38825 .29738 m
.39907 .28762 L
s
.36328 .30828 m
.38825 .29738 L
s
.275 .286 .635 r
.71173 .84043 m .71895 .8305 L .69142 .84385 L p F P
0 g
s
.275 .286 .635 r
.69142 .84385 m .68539 .85229 L .71173 .84043 L p F P
0 g
s
.70264 .84987 m
.71173 .84043 L
s
.71173 .84043 m
.73552 .82585 L
s
.327 .024 .673 r
.37073 .85621 m .37913 .86403 L .40545 .87078 L p F P
0 g
s
.328 .011 .673 r
.41344 .87676 m .40545 .87078 L .37913 .86403 L p F P
0 g
s
.35499 .85421 m
.37913 .86403 L
s
.37913 .86403 m
.389 .87133 L
s
.131 .125 .727 r
.49165 .89783 m .50206 .89931 L .50977 .89151 L p F P
0 g
s
.117 .138 .727 r
.51704 .89216 m .50977 .89151 L .50206 .89931 L p F P
0 g
s
.49485 .90332 m
.50206 .89931 L
s
.50206 .89931 m
.51272 .90026 L
s
.747 .026 .026 r
.8191 .46107 m .80384 .44201 L .80807 .46883 L p F P
0 g
s
.747 .026 .026 r
.80807 .46883 m .82351 .48789 L .8191 .46107 L p F P
0 g
s
.81144 .43616 m
.8191 .46107 L
s
.8191 .46107 m
.83067 .48082 L
s
.098 .696 .256 r
.35212 .3223 m .3279 .33561 L .31727 .35362 L p F P
0 g
s
.17 .682 .256 r
.29468 .36909 m .31727 .35362 L .3279 .33561 L p F P
0 g
s
.30638 .35044 m
.3279 .33561 L
s
.3279 .33561 m
.34053 .32083 L
s
.667 .192 .281 r
.83953 .63239 m .83533 .61358 L .82534 .64285 L p F P
0 g
s
.667 .192 .281 r
.82534 .64285 m .82951 .66073 L .83953 .63239 L p F P
0 g
s
.83953 .63239 m
.84582 .60394 L
s
.83953 .63239 m
.84016 .65113 L
s
.032 .178 .727 r
.55561 .89867 m .56588 .89694 L .5533 .88988 L p F P
0 g
s
.032 .178 .727 r
.5533 .88988 m .54631 .89107 L .55561 .89867 L p F P
0 g
s
.55561 .89867 m
.56433 .90248 L
s
.54506 .89987 m
.55561 .89867 L
s
.734 .103 .104 r
.79652 .41734 m .7781 .39947 L .785 .4239 L p F P
0 g
s
.734 .103 .104 r
.785 .4239 m .80384 .44201 L .79652 .41734 L p F P
0 g
s
.78627 .39505 m
.79652 .41734 L
s
.79652 .41734 m
.81144 .43616 L
s
.254 .035 .704 r
.41344 .87676 m .42257 .88227 L .44664 .8831 L p F P
0 g
s
.249 .061 .704 r
.45437 .88694 m .44664 .8831 L .42257 .88227 L p F P
0 g
s
.40022 .87806 m
.42257 .88227 L
s
.42257 .88227 m
.43273 .88727 L
s
.143 .111 .727 r
.48157 .89584 m .49165 .89783 L .50267 .8905 L p F P
0 g
s
.131 .125 .727 r
.50977 .89151 m .50267 .8905 L .49165 .89783 L p F P
0 g
s
.48132 .9014 m
.49165 .89783 L
s
.49165 .89783 m
.50206 .89931 L
s
.506 .27 .482 r
.79745 .74636 m .79949 .73107 L .77891 .75545 L p F P
0 g
s
.506 .27 .482 r
.77891 .75545 m .77721 .76936 L .79745 .74636 L p F P
0 g
s
.79745 .74636 m
.8143 .72183 L
s
.79252 .76129 m
.79745 .74636 L
s
.459 .588 .052 r
.21209 .54533 m .222 .52562 L .22303 .49732 L p F P
0 g
s
.454 .581 .13 r
.222 .52562 m .21209 .54533 L .21466 .57431 L p F P
0 g
s
.20595 .56532 m
.21209 .54533 L
s
.21209 .54533 m
.21315 .51728 L
s
.014 .181 .727 r
.56588 .89694 m .57576 .8947 L .56002 .88835 L p F P
0 g
s
.014 .181 .727 r
.56002 .88835 m .5533 .88988 L .56588 .89694 L p F P
0 g
s
.56588 .89694 m
.57767 .90024 L
s
.55561 .89867 m
.56588 .89694 L
s
.53 .414 .328 r
.65167 .29278 m .62399 .28465 L .63076 .29721 L p F P
0 g
s
.53 .414 .328 r
.63076 .29721 m .66032 .30585 L .65167 .29278 L p F P
0 g
s
.64182 .28336 m
.65167 .29278 L
s
.65167 .29278 m
.6776 .30282 L
s
.154 .095 .727 r
.47193 .89334 m .48157 .89584 L .49581 .88913 L p F P
0 g
s
.143 .111 .727 r
.50267 .8905 m .49581 .88913 L .48157 .89584 L p F P
0 g
s
.46822 .89882 m
.48157 .89584 L
s
.48157 .89584 m
.49165 .89783 L
s
.531 .446 .281 r
.22235 .66933 m .22485 .65144 L .21483 .62262 L p F P
0 g
s
.506 .425 .352 r
.22485 .65144 m .22235 .66933 L .23601 .69666 L p F P
0 g
s
.22235 .66933 m
.22324 .68705 L
s
.21236 .64143 m
.22235 .66933 L
s
.201 .259 .673 r
.67773 .86033 m .68539 .85229 L .65675 .8612 L p F P
0 g
s
.201 .259 .673 r
.65675 .8612 m .6506 .86776 L .67773 .86033 L p F P
0 g
s
.66855 .86789 m
.67773 .86033 L
s
.67773 .86033 m
.70264 .84987 L
s
.111 .23 .704 r
.63458 .87968 m .64318 .87394 L .61595 .87671 L p F P
0 g
s
.111 .23 .704 r
.61595 .87671 m .60944 .88111 L .63458 .87968 L p F P
0 g
s
.63458 .87968 m
.65797 .8749 L
s
.62491 .88493 m
.63458 .87968 L
s
.482 .195 .539 r
.30531 .80844 m .30039 .79642 L .2772 .77596 L p F P
0 g
s
.427 .173 .59 r
.30039 .79642 m .30531 .80844 L .33071 .82518 L p F P
0 g
s
.443 .128 .59 r
.33691 .83533 m .33071 .82518 L .30531 .80844 L p F P
0 g
s
.30531 .80844 m
.31252 .82004 L
s
.28283 .78939 m
.30531 .80844 L
s
.005 .181 .727 r
.57576 .8947 m .58515 .89197 L .56639 .88648 L p F P
0 g
s
.005 .181 .727 r
.56639 .88648 m .56002 .88835 L .57576 .8947 L p F P
0 g
s
.57576 .8947 m
.59052 .89734 L
s
.56588 .89694 m
.57576 .8947 L
s
.632 .308 .256 r
.7134 .329 m .68799 .31651 L .69675 .33367 L p F P
0 g
s
.632 .308 .256 r
.69675 .33367 m .72347 .34672 L .7134 .329 L p F P
0 g
s
.70145 .3146 m
.7134 .329 L
s
.7134 .329 m
.73625 .34313 L
s
.381 .11 .635 r
.33071 .82518 m .33691 .83533 L .36391 .84795 L p F P
0 g
s
.39 .07 .635 r
.37073 .85621 m .36391 .84795 L .33691 .83533 L p F P
0 g
s
.31252 .82004 m
.33691 .83533 L
s
.33691 .83533 m
.34504 .84504 L
s
.176 .704 .181 r
.31727 .35362 m .29468 .36909 L .28542 .39066 L p F P
0 g
s
.249 .682 .181 r
.26525 .40793 m .28542 .39066 L .29468 .36909 L p F P
0 g
s
.2752 .38589 m
.29468 .36909 L
s
.29468 .36909 m
.30638 .35044 L
s
.708 .125 .206 r
.84162 .5844 m .8337 .56502 L .82751 .59492 L p F P
0 g
s
.708 .125 .206 r
.82751 .59492 m .83533 .61358 L .84162 .5844 L p F P
0 g
s
.84162 .5844 m
.8442 .55569 L
s
.84162 .5844 m
.84582 .60394 L
s
.396 .634 .026 r
.22303 .49732 m .23667 .4779 L .241 .45108 L p F P
0 g
s
.395 .633 .052 r
.23667 .4779 m .22303 .49732 L .222 .52562 L p F P
0 g
s
.21315 .51728 m
.22303 .49732 L
s
.22303 .49732 m
.22751 .4705 L
s
.506 .27 .482 r
.2772 .77596 m .2742 .76217 L .25375 .73846 L p F P
0 g
s
.459 .245 .539 r
.2742 .76217 m .2772 .77596 L .30039 .79642 L p F P
0 g
s
.2772 .77596 m
.28283 .78939 L
s
.2572 .75359 m
.2772 .77596 L
s
.575 .233 .419 r
.81665 .70532 m .81581 .68859 L .79853 .7156 L p F P
0 g
s
.575 .233 .419 r
.79853 .7156 m .79949 .73107 L .81665 .70532 L p F P
0 g
s
.81665 .70532 m
.83024 .67856 L
s
.8143 .72183 m
.81665 .70532 L
s
.163 .079 .727 r
.46284 .89037 m .47193 .89334 L .48926 .88742 L p F P
0 g
s
.154 .095 .727 r
.49581 .88913 m .48926 .88742 L .47193 .89334 L p F P
0 g
s
.45567 .89558 m
.47193 .89334 L
s
.47193 .89334 m
.48157 .89584 L
s
.116 .662 .328 r
.44358 .28123 m .41513 .28831 L .40744 .3011 L p F P
0 g
s
.047 .671 .328 r
.37874 .31073 m .40744 .3011 L .41513 .28831 L p F P
0 g
s
.41513 .28831 m
.42388 .27922 L
s
.38825 .29738 m
.41513 .28831 L
s
.256 .008 .704 r
.40545 .87078 m .41344 .87676 L .43971 .87887 L p F P
0 g
s
.254 .035 .704 r
.44664 .8831 m .43971 .87887 L .41344 .87676 L p F P
0 g
s
.389 .87133 m
.41344 .87676 L
s
.41344 .87676 m
.42257 .88227 L
s
.024 .179 .727 r
.58515 .89197 m .59395 .88877 L .57235 .8843 L p F P
0 g
s
.024 .179 .727 r
.57235 .8843 m .56639 .88648 L .58515 .89197 L p F P
0 g
s
.58515 .89197 m
.60276 .8938 L
s
.57576 .8947 m
.58515 .89197 L
s
.323 .058 .673 r
.36391 .84795 m .37073 .85621 L .39868 .8644 L p F P
0 g
s
.327 .024 .673 r
.40545 .87078 m .39868 .8644 L .37073 .85621 L p F P
0 g
s
.34504 .84504 m
.37073 .85621 L
s
.37073 .85621 m
.37913 .86403 L
s
.254 .696 .104 r
.28542 .39066 m .26525 .40793 L .25813 .43247 L p F P
0 g
s
.325 .666 .104 r
.241 .45108 m .25813 .43247 L .26525 .40793 L p F P
0 g
s
.26525 .40793 m
.2752 .38589 L
s
.24849 .42629 m
.26525 .40793 L
s
.328 .672 .026 r
.25813 .43247 m .241 .45108 L .23667 .4779 L p F P
0 g
s
.22751 .4705 m
.241 .45108 L
s
.241 .45108 m
.24849 .42629 L
s
.499 .518 .206 r
.21483 .62262 m .2209 .60386 L .21466 .57431 L p F P
0 g
s
.482 .499 .281 r
.2209 .60386 m .21483 .62262 L .22485 .65144 L p F P
0 g
s
.21236 .64143 m
.21483 .62262 L
s
.20853 .5938 m
.21483 .62262 L
s
.483 .467 .328 r
.62399 .28465 m .59492 .27857 L .5997 .29075 L p F P
0 g
s
.483 .467 .328 r
.5997 .29075 m .63076 .29721 L .62399 .28465 L p F P
0 g
s
.61629 .27583 m
.62399 .28465 L
s
.62399 .28465 m
.65167 .29278 L
s
.17 .061 .727 r
.45437 .88694 m .46284 .89037 L .48309 .88538 L p F P
0 g
s
.163 .079 .727 r
.48926 .88742 m .48309 .88538 L .46284 .89037 L p F P
0 g
s
.4438 .89172 m
.46284 .89037 L
s
.46284 .89037 m
.47193 .89334 L
s
.514 .347 .419 r
.25375 .73846 m .25326 .72306 L .23601 .69666 L p F P
0 g
s
.475 .321 .482 r
.25326 .72306 m .25375 .73846 L .2742 .76217 L p F P
0 g
s
.25375 .73846 m
.2572 .75359 L
s
.23672 .7133 m
.25375 .73846 L
s
.303 .255 .635 r
.71895 .8305 m .72419 .82016 L .69572 .83508 L p F P
0 g
s
.303 .255 .635 r
.69572 .83508 m .69142 .84385 L .71895 .8305 L p F P
0 g
s
.71895 .8305 m
.74386 .81452 L
s
.71173 .84043 m
.71895 .8305 L
s
.025 .703 .256 r
.37874 .31073 m .35212 .3223 L .34271 .33972 L p F P
0 g
s
.098 .696 .256 r
.31727 .35362 m .34271 .33972 L .35212 .3223 L p F P
0 g
s
.35212 .3223 m
.36328 .30828 L
s
.3279 .33561 m
.35212 .3223 L
s
.735 .052 .13 r
.83625 .5358 m .82453 .51632 L .82205 .54602 L p F P
0 g
s
.735 .052 .13 r
.82205 .54602 m .8337 .56502 L .83625 .5358 L p F P
0 g
s
.8352 .50763 m
.83625 .5358 L
s
.83625 .5358 m
.8442 .55569 L
s
.135 .217 .704 r
.64318 .87394 m .6506 .86776 L .62154 .87199 L p F P
0 g
s
.135 .217 .704 r
.62154 .87199 m .61595 .87671 L .64318 .87394 L p F P
0 g
s
.64318 .87394 m
.66855 .86789 L
s
.63458 .87968 m
.64318 .87394 L
s
.381 .258 .59 r
.74998 .8027 m .75376 .79052 L .72733 .80953 L p F P
0 g
s
.381 .258 .59 r
.72733 .80953 m .72419 .82016 L .74998 .8027 L p F P
0 g
s
.74998 .8027 m
.77283 .78298 L
s
.74386 .81452 m
.74998 .8027 L
s
.043 .176 .727 r
.59395 .88877 m .60207 .88514 L .57784 .88182 L p F P
0 g
s
.043 .176 .727 r
.57784 .88182 m .57235 .8843 L .59395 .88877 L p F P
0 g
s
.59395 .88877 m
.61426 .88966 L
s
.58515 .89197 m
.59395 .88877 L
s
.682 .249 .181 r
.74746 .36146 m .72347 .34672 L .73145 .36766 L p F P
0 g
s
.682 .249 .181 r
.73145 .36766 m .75634 .38282 L .74746 .36146 L p F P
0 g
s
.73625 .34313 m
.74746 .36146 L
s
.74746 .36146 m
.76846 .37766 L
s
.635 .182 .352 r
.82951 .66073 m .82534 .64285 L .81168 .67183 L p F P
0 g
s
.635 .182 .352 r
.81168 .67183 m .81581 .68859 L .82951 .66073 L p F P
0 g
s
.82951 .66073 m
.83953 .63239 L
s
.82951 .66073 m
.83024 .67856 L
s
.185 .647 .328 r
.4732 .27625 m .44358 .28123 L .43783 .29358 L p F P
0 g
s
.116 .662 .328 r
.40744 .3011 m .43783 .29358 L .44358 .28123 L p F P
0 g
s
.44358 .28123 m
.45011 .27266 L
s
.41513 .28831 m
.44358 .28123 L
s
.227 .236 .673 r
.68539 .85229 m .69142 .84385 L .66154 .85433 L p F P
0 g
s
.227 .236 .673 r
.66154 .85433 m .65675 .8612 L .68539 .85229 L p F P
0 g
s
.67773 .86033 m
.68539 .85229 L
s
.68539 .85229 m
.71173 .84043 L
s
.459 .245 .539 r
.77721 .76936 m .77891 .75545 L .75509 .7781 L p F P
0 g
s
.459 .245 .539 r
.75509 .7781 m .75376 .79052 L .77721 .76936 L p F P
0 g
s
.77721 .76936 m
.79745 .74636 L
s
.77283 .78298 m
.77721 .76936 L
s
.176 .043 .727 r
.44664 .8831 m .45437 .88694 L .47737 .88305 L p F P
0 g
s
.17 .061 .727 r
.48309 .88538 m .47737 .88305 L .45437 .88694 L p F P
0 g
s
.43273 .88727 m
.45437 .88694 L
s
.45437 .88694 m
.46284 .89037 L
s
.432 .515 .328 r
.59492 .27857 m .56488 .27463 L .56757 .28656 L p F P
0 g
s
.432 .515 .328 r
.56757 .28656 m .5997 .29075 L .59492 .27857 L p F P
0 g
s
.5895 .2702 m
.59492 .27857 L
s
.59492 .27857 m
.62399 .28465 L
s
.255 .019 .704 r
.39868 .8644 m .40545 .87078 L .43366 .8743 L p F P
0 g
s
.256 .008 .704 r
.43971 .87887 m .43366 .8743 L .40545 .87078 L p F P
0 g
s
.37913 .86403 m
.40545 .87078 L
s
.40545 .87078 m
.41344 .87676 L
s
.746 .026 .052 r
.82351 .48789 m .80807 .46883 L .80905 .4975 L p F P
0 g
s
.746 .026 .052 r
.80905 .4975 m .82453 .51632 L .82351 .48789 L p F P
0 g
s
.8191 .46107 m
.82351 .48789 L
s
.82351 .48789 m
.8352 .50763 L
s
.454 .581 .13 r
.21466 .57431 m .22451 .55509 L .222 .52562 L p F P
0 g
s
.443 .567 .206 r
.22451 .55509 m .21466 .57431 L .2209 .60386 L p F P
0 g
s
.20853 .5938 m
.21466 .57431 L
s
.21209 .54533 m
.21466 .57431 L
s
.506 .425 .352 r
.23601 .69666 m .23855 .67988 L .22485 .65144 L p F P
0 g
s
.475 .399 .419 r
.23855 .67988 m .23601 .69666 L .25326 .72306 L p F P
0 g
s
.23601 .69666 m
.23672 .7133 L
s
.22235 .66933 m
.23601 .69666 L
s
.596 .373 .256 r
.68799 .31651 m .66032 .30585 L .66762 .32253 L p F P
0 g
s
.596 .373 .256 r
.66762 .32253 m .69675 .33367 L .68799 .31651 L p F P
0 g
s
.6776 .30282 m
.68799 .31651 L
s
.68799 .31651 m
.7134 .329 L
s
.719 .179 .104 r
.7781 .39947 m .75634 .38282 L .7627 .40702 L p F P
0 g
s
.719 .179 .104 r
.7627 .40702 m .785 .4239 L .7781 .39947 L p F P
0 g
s
.76846 .37766 m
.7781 .39947 L
s
.7781 .39947 m
.79652 .41734 L
s
.061 .17 .727 r
.60207 .88514 m .60944 .88111 L .58279 .87907 L p F P
0 g
s
.061 .17 .727 r
.58279 .87907 m .57784 .88182 L .60207 .88514 L p F P
0 g
s
.60207 .88514 m
.62491 .88493 L
s
.59395 .88877 m
.60207 .88514 L
s
.252 .624 .328 r
.50358 .27347 m .4732 .27625 L .4695 .28828 L p F P
0 g
s
.185 .647 .328 r
.43783 .29358 m .4695 .28828 L .4732 .27625 L p F P
0 g
s
.4732 .27625 m
.47741 .26806 L
s
.44358 .28123 m
.4732 .27625 L
s
.74 .104 .026 r
.80384 .44201 m .785 .4239 L .78898 .45071 L p F P
0 g
s
.74 .104 .026 r
.78898 .45071 m .80807 .46883 L .80384 .44201 L p F P
0 g
s
.79652 .41734 m
.80384 .44201 L
s
.80384 .44201 m
.8191 .46107 L
s
.427 .173 .59 r
.33071 .82518 m .32655 .81467 L .30039 .79642 L p F P
0 g
s
.367 .149 .635 r
.32655 .81467 m .33071 .82518 L .35876 .83933 L p F P
0 g
s
.381 .11 .635 r
.36391 .84795 m .35876 .83933 L .33071 .82518 L p F P
0 g
s
.33071 .82518 m
.33691 .83533 L
s
.30531 .80844 m
.33071 .82518 L
s
.376 .558 .328 r
.56488 .27463 m .53429 .27292 L .53485 .28475 L p F P
0 g
s
.376 .558 .328 r
.53485 .28475 m .56757 .28656 L .56488 .27463 L p F P
0 g
s
.56183 .26656 m
.56488 .27463 L
s
.56488 .27463 m
.59492 .27857 L
s
.459 .245 .539 r
.30039 .79642 m .29787 .7841 L .2742 .76217 L p F P
0 g
s
.406 .217 .59 r
.29787 .7841 m .30039 .79642 L .32655 .81467 L p F P
0 g
s
.30039 .79642 m
.30531 .80844 L
s
.2772 .77596 m
.30039 .79642 L
s
.315 .091 .673 r
.35876 .83933 m .36391 .84795 L .39322 .85767 L p F P
0 g
s
.323 .058 .673 r
.39868 .8644 m .39322 .85767 L .36391 .84795 L p F P
0 g
s
.33691 .83533 m
.36391 .84795 L
s
.36391 .84795 m
.37073 .85621 L
s
.531 .215 .482 r
.79949 .73107 m .79853 .7156 L .77782 .74138 L p F P
0 g
s
.531 .215 .482 r
.77782 .74138 m .77891 .75545 L .79949 .73107 L p F P
0 g
s
.79949 .73107 m
.81665 .70532 L
s
.79745 .74636 m
.79949 .73107 L
s
.157 .202 .704 r
.6506 .86776 m .65675 .8612 L .62614 .86698 L p F P
0 g
s
.157 .202 .704 r
.62614 .86698 m .62154 .87199 L .6506 .86776 L p F P
0 g
s
.64318 .87394 m
.6506 .86776 L
s
.6506 .86776 m
.67773 .86033 L
s
.683 .121 .281 r
.83533 .61358 m .82751 .59492 L .81766 .62512 L p F P
0 g
s
.683 .121 .281 r
.81766 .62512 m .82534 .64285 L .83533 .61358 L p F P
0 g
s
.83533 .61358 m
.84162 .5844 L
s
.83533 .61358 m
.83953 .63239 L
s
.179 .024 .727 r
.43971 .87887 m .44664 .8831 L .47215 .88042 L p F P
0 g
s
.176 .043 .727 r
.47737 .88305 m .47215 .88042 L .44664 .8831 L p F P
0 g
s
.42257 .88227 m
.44664 .8831 L
s
.44664 .8831 m
.45437 .88694 L
s
.315 .594 .328 r
.53429 .27292 m .50358 .27347 L .502 .28532 L p F P
0 g
s
.252 .624 .328 r
.4695 .28828 m .502 .28532 L .50358 .27347 L p F P
0 g
s
.50358 .27347 m
.50539 .26548 L
s
.4732 .27625 m
.50358 .27347 L
s
.101 .719 .181 r
.34271 .33972 m .31727 .35362 L .30883 .37475 L p F P
0 g
s
.176 .704 .181 r
.28542 .39066 m .30883 .37475 L .31727 .35362 L p F P
0 g
s
.29468 .36909 m
.31727 .35362 L
s
.31727 .35362 m
.3279 .33561 L
s
.315 .594 .328 r
.502 .28532 m .53485 .28475 L .53429 .27292 L p F P
0 g
s
.50358 .27347 m
.53429 .27292 L
s
.53366 .26498 m
.53429 .27292 L
s
.53429 .27292 m
.56488 .27463 L
s
.049 .701 .256 r
.40744 .3011 m .37874 .31073 L .37072 .32764 L p F P
0 g
s
.025 .703 .256 r
.34271 .33972 m .37072 .32764 L .37874 .31073 L p F P
0 g
s
.37874 .31073 m
.38825 .29738 L
s
.35212 .3223 m
.37874 .31073 L
s
.395 .633 .052 r
.222 .52562 m .23567 .50645 L .23667 .4779 L p F P
0 g
s
.39 .625 .13 r
.23567 .50645 m .222 .52562 L .22451 .55509 L p F P
0 g
s
.21209 .54533 m
.222 .52562 L
s
.222 .52562 m
.22303 .49732 L
s
.079 .163 .727 r
.60944 .88111 m .61595 .87671 L .58716 .87608 L p F P
0 g
s
.079 .163 .727 r
.58716 .87608 m .58279 .87907 L .60944 .88111 L p F P
0 g
s
.60944 .88111 m
.63458 .87968 L
s
.60207 .88514 m
.60944 .88111 L
s
.059 .086 .742 r
.51704 .89216 m .5244 .89244 L .52534 .88033 L p F P
0 g
s
.05 .092 .742 r
.5244 .89244 m .53178 .89235 L .5291 .88028 L p F P
0 g
s
.05 .092 .742 r
.5291 .88028 m .52534 .88033 L .5244 .89244 L p F P
0 g
s
.52351 .90067 m
.5244 .89244 L
s
.04 .096 .742 r
.53178 .89235 m .53911 .89189 L .53284 .88005 L p F P
0 g
s
.04 .096 .742 r
.53284 .88005 m .5291 .88028 L .53178 .89235 L p F P
0 g
s
.53178 .89235 m
.53432 .90054 L
s
.5244 .89244 m
.53178 .89235 L
s
.475 .321 .482 r
.2742 .76217 m .27394 .74816 L .25326 .72306 L p F P
0 g
s
.431 .291 .539 r
.27394 .74816 m .2742 .76217 L .29787 .7841 L p F P
0 g
s
.2742 .76217 m
.2772 .77596 L
s
.25375 .73846 m
.2742 .76217 L
s
.068 .079 .742 r
.50977 .89151 m .51704 .89216 L .52158 .88019 L p F P
0 g
s
.059 .086 .742 r
.52534 .88033 m .52158 .88019 L .51704 .89216 L p F P
0 g
s
.51272 .90026 m
.51704 .89216 L
s
.51704 .89216 m
.5244 .89244 L
s
.482 .499 .281 r
.22485 .65144 m .23084 .63361 L .2209 .60386 L p F P
0 g
s
.459 .475 .352 r
.23084 .63361 m .22485 .65144 L .23855 .67988 L p F P
0 g
s
.22235 .66933 m
.22485 .65144 L
s
.21483 .62262 m
.22485 .65144 L
s
.03 .1 .742 r
.53911 .89189 m .54631 .89107 L .5365 .87962 L p F P
0 g
s
.03 .1 .742 r
.5365 .87962 m .53284 .88005 L .53911 .89189 L p F P
0 g
s
.53911 .89189 m
.54506 .89987 L
s
.53178 .89235 m
.53911 .89189 L
s
.252 .045 .704 r
.39322 .85767 m .39868 .8644 L .42858 .86942 L p F P
0 g
s
.255 .019 .704 r
.43366 .8743 m .42858 .86942 L .39868 .8644 L p F P
0 g
s
.37073 .85621 m
.39868 .8644 L
s
.39868 .8644 m
.40545 .87078 L
s
.076 .072 .742 r
.50267 .8905 m .50977 .89151 L .51788 .87985 L p F P
0 g
s
.068 .079 .742 r
.52158 .88019 m .51788 .87985 L .50977 .89151 L p F P
0 g
s
.50206 .89931 m
.50977 .89151 L
s
.50977 .89151 m
.51704 .89216 L
s
.328 .222 .635 r
.72419 .82016 m .72733 .80953 L .69823 .82608 L p F P
0 g
s
.328 .222 .635 r
.69823 .82608 m .69572 .83508 L .72419 .82016 L p F P
0 g
s
.72419 .82016 m
.74998 .8027 L
s
.71895 .8305 m
.72419 .82016 L
s
.019 .102 .742 r
.54631 .89107 m .5533 .88988 L .54006 .87901 L p F P
0 g
s
.019 .102 .742 r
.54006 .87901 m .5365 .87962 L .54631 .89107 L p F P
0 g
s
.54631 .89107 m
.55561 .89867 L
s
.53911 .89189 m
.54631 .89107 L
s
.251 .211 .673 r
.69142 .84385 m .69572 .83508 L .66492 .84721 L p F P
0 g
s
.251 .211 .673 r
.66492 .84721 m .66154 .85433 L .69142 .84385 L p F P
0 g
s
.68539 .85229 m
.69142 .84385 L
s
.69142 .84385 m
.71895 .8305 L
s
.083 .063 .742 r
.49581 .88913 m .50267 .8905 L .51427 .87933 L p F P
0 g
s
.076 .072 .742 r
.51788 .87985 m .51427 .87933 L .50267 .8905 L p F P
0 g
s
.49165 .89783 m
.50267 .8905 L
s
.50267 .8905 m
.50977 .89151 L
s
.179 .719 .104 r
.30883 .37475 m .28542 .39066 L .27879 .41497 L p F P
0 g
s
.254 .696 .104 r
.25813 .43247 m .27879 .41497 L .28542 .39066 L p F P
0 g
s
.26525 .40793 m
.28542 .39066 L
s
.28542 .39066 m
.29468 .36909 L
s
.181 .005 .727 r
.43366 .8743 m .43971 .87887 L .4675 .87755 L p F P
0 g
s
.179 .024 .727 r
.47215 .88042 m .4675 .87755 L .43971 .87887 L p F P
0 g
s
.41344 .87676 m
.43971 .87887 L
s
.43971 .87887 m
.44664 .8831 L
s
.596 .171 .419 r
.81581 .68859 m .81168 .67183 L .79447 .70012 L p F P
0 g
s
.596 .171 .419 r
.79447 .70012 m .79853 .7156 L .81581 .68859 L p F P
0 g
s
.81581 .68859 m
.82951 .66073 L
s
.81581 .68859 m
.81665 .70532 L
s
.328 .672 .026 r
.23667 .4779 m .25402 .45929 L .25813 .43247 L p F P
0 g
s
.327 .671 .052 r
.25402 .45929 m .23667 .4779 L .23567 .50645 L p F P
0 g
s
.22303 .49732 m
.23667 .4779 L
s
.23667 .4779 m
.241 .45108 L
s
.008 .104 .742 r
.5533 .88988 m .56002 .88835 L .54347 .87823 L p F P
0 g
s
.008 .104 .742 r
.54347 .87823 m .54006 .87901 L .5533 .88988 L p F P
0 g
s
.5533 .88988 m
.56588 .89694 L
s
.54631 .89107 m
.5533 .88988 L
s
.717 .05 .206 r
.8337 .56502 m .82205 .54602 L .81602 .57664 L p F P
0 g
s
.717 .05 .206 r
.81602 .57664 m .82751 .59492 L .8337 .56502 L p F P
0 g
s
.8337 .56502 m
.83625 .5358 L
s
.8337 .56502 m
.84162 .5844 L
s
.554 .433 .256 r
.66032 .30585 m .63076 .29721 L .63648 .3135 L p F P
0 g
s
.554 .433 .256 r
.63648 .3135 m .66762 .32253 L .66032 .30585 L p F P
0 g
s
.65167 .29278 m
.66032 .30585 L
s
.66032 .30585 m
.68799 .31651 L
s
.406 .217 .59 r
.75376 .79052 m .75509 .7781 L .72831 .7987 L p F P
0 g
s
.406 .217 .59 r
.72831 .7987 m .72733 .80953 L .75376 .79052 L p F P
0 g
s
.75376 .79052 m
.77721 .76936 L
s
.74998 .8027 m
.75376 .79052 L
s
.652 .318 .181 r
.72347 .34672 m .69675 .33367 L .7037 .35422 L p F P
0 g
s
.652 .318 .181 r
.7037 .35422 m .73145 .36766 L .72347 .34672 L p F P
0 g
s
.7134 .329 m
.72347 .34672 L
s
.72347 .34672 m
.74746 .36146 L
s
.089 .054 .742 r
.48926 .88742 m .49581 .88913 L .51078 .87863 L p F P
0 g
s
.083 .063 .742 r
.51427 .87933 m .51078 .87863 L .49581 .88913 L p F P
0 g
s
.48157 .89584 m
.49581 .88913 L
s
.49581 .88913 m
.50267 .8905 L
s
.256 .703 .026 r
.27879 .41497 m .25813 .43247 L .25402 .45929 L p F P
0 g
s
.25813 .43247 m
.26525 .40793 L
s
.241 .45108 m
.25813 .43247 L
s
.177 .185 .704 r
.65675 .8612 m .66154 .85433 L .62969 .86175 L p F P
0 g
s
.177 .185 .704 r
.62969 .86175 m .62614 .86698 L .65675 .8612 L p F P
0 g
s
.6506 .86776 m
.65675 .8612 L
s
.65675 .8612 m
.68539 .85229 L
s
.003 .104 .742 r
.56002 .88835 m .56639 .88648 L .5467 .87727 L p F P
0 g
s
.003 .104 .742 r
.5467 .87727 m .54347 .87823 L .56002 .88835 L p F P
0 g
s
.56002 .88835 m
.57576 .8947 L
s
.5533 .88988 m
.56002 .88835 L
s
.095 .154 .727 r
.61595 .87671 m .62154 .87199 L .59088 .87288 L p F P
0 g
s
.095 .154 .727 r
.59088 .87288 m .58716 .87608 L .61595 .87671 L p F P
0 g
s
.61595 .87671 m
.64318 .87394 L
s
.60944 .88111 m
.61595 .87671 L
s
.475 .399 .419 r
.25326 .72306 m .25582 .70756 L .23855 .67988 L p F P
0 g
s
.439 .369 .482 r
.25582 .70756 m .25326 .72306 L .27394 .74816 L p F P
0 g
s
.25326 .72306 m
.25375 .73846 L
s
.23601 .69666 m
.25326 .72306 L
s
.094 .045 .742 r
.48309 .88538 m .48926 .88742 L .50746 .87775 L p F P
0 g
s
.089 .054 .742 r
.51078 .87863 m .50746 .87775 L .48926 .88742 L p F P
0 g
s
.47193 .89334 m
.48926 .88742 L
s
.48926 .88742 m
.49581 .88913 L
s
.367 .149 .635 r
.35876 .83933 m .35538 .83043 L .32655 .81467 L p F P
0 g
s
.304 .124 .673 r
.35538 .83043 m .35876 .83933 L .38916 .85066 L p F P
0 g
s
.315 .091 .673 r
.39322 .85767 m .38916 .85066 L .35876 .83933 L p F P
0 g
s
.35876 .83933 m
.36391 .84795 L
s
.33071 .82518 m
.35876 .83933 L
s
.443 .567 .206 r
.2209 .60386 m .23063 .58537 L .22451 .55509 L p F P
0 g
s
.427 .547 .281 r
.23063 .58537 m .2209 .60386 L .23084 .63361 L p F P
0 g
s
.21483 .62262 m
.2209 .60386 L
s
.21466 .57431 m
.2209 .60386 L
s
.014 .103 .742 r
.56639 .88648 m .57235 .8843 L .54972 .87615 L p F P
0 g
s
.014 .103 .742 r
.54972 .87615 m .5467 .87727 L .56639 .88648 L p F P
0 g
s
.56639 .88648 m
.58515 .89197 L
s
.56002 .88835 m
.56639 .88648 L
s
.122 .692 .256 r
.43783 .29358 m .40744 .3011 L .40095 .31757 L p F P
0 g
s
.049 .701 .256 r
.37072 .32764 m .40095 .31757 L .40744 .3011 L p F P
0 g
s
.40744 .3011 m
.41513 .28831 L
s
.37874 .31073 m
.40744 .3011 L
s
.406 .217 .59 r
.32655 .81467 m .32452 .80392 L .29787 .7841 L p F P
0 g
s
.35 .187 .635 r
.32452 .80392 m .32655 .81467 L .35538 .83043 L p F P
0 g
s
.32655 .81467 m
.33071 .82518 L
s
.30039 .79642 m
.32655 .81467 L
s
.482 .195 .539 r
.77891 .75545 m .77782 .74138 L .7539 .76557 L p F P
0 g
s
.482 .195 .539 r
.7539 .76557 m .75509 .7781 L .77891 .75545 L p F P
0 g
s
.77891 .75545 m
.79949 .73107 L
s
.77721 .76936 m
.77891 .75545 L
s
.181 .014 .727 r
.42858 .86942 m .43366 .8743 L .46346 .87444 L p F P
0 g
s
.181 .005 .727 r
.4675 .87755 m .46346 .87444 L .43366 .8743 L p F P
0 g
s
.40545 .87078 m
.43366 .8743 L
s
.43366 .8743 m
.43971 .87887 L
s
.736 .026 .13 r
.82453 .51632 m .80905 .4975 L .80667 .52768 L p F P
0 g
s
.736 .026 .13 r
.80667 .52768 m .82205 .54602 L .82453 .51632 L p F P
0 g
s
.82351 .48789 m
.82453 .51632 L
s
.82453 .51632 m
.83625 .5358 L
s
.098 .035 .742 r
.47737 .88305 m .48309 .88538 L .50433 .87671 L p F P
0 g
s
.094 .045 .742 r
.50746 .87775 m .50433 .87671 L .48309 .88538 L p F P
0 g
s
.46284 .89037 m
.48309 .88538 L
s
.48309 .88538 m
.48926 .88742 L
s
.246 .071 .704 r
.38916 .85066 m .39322 .85767 L .42452 .8643 L p F P
0 g
s
.252 .045 .704 r
.42858 .86942 m .42452 .8643 L .39322 .85767 L p F P
0 g
s
.36391 .84795 m
.39322 .85767 L
s
.39322 .85767 m
.39868 .8644 L
s
.696 .254 .104 r
.75634 .38282 m .73145 .36766 L .73717 .39163 L p F P
0 g
s
.696 .254 .104 r
.73717 .39163 m .7627 .40702 L .75634 .38282 L p F P
0 g
s
.74746 .36146 m
.75634 .38282 L
s
.75634 .38282 m
.7781 .39947 L
s
.65 .115 .352 r
.82534 .64285 m .81766 .62512 L .80421 .65522 L p F P
0 g
s
.65 .115 .352 r
.80421 .65522 m .81168 .67183 L .82534 .64285 L p F P
0 g
s
.82534 .64285 m
.83533 .61358 L
s
.82534 .64285 m
.82951 .66073 L
s
.026 .725 .181 r
.37072 .32764 m .34271 .33972 L .33525 .36045 L p F P
0 g
s
.101 .719 .181 r
.30883 .37475 m .33525 .36045 L .34271 .33972 L p F P
0 g
s
.31727 .35362 m
.34271 .33972 L
s
.34271 .33972 m
.35212 .3223 L
s
.024 .101 .742 r
.57235 .8843 m .57784 .88182 L .55249 .87489 L p F P
0 g
s
.024 .101 .742 r
.55249 .87489 m .54972 .87615 L .57235 .8843 L p F P
0 g
s
.57235 .8843 m
.59395 .88877 L
s
.56639 .88648 m
.57235 .8843 L
s
.431 .291 .539 r
.29787 .7841 m .29784 .7716 L .27394 .74816 L p F P
0 g
s
.381 .258 .59 r
.29784 .7716 m .29787 .7841 L .32452 .80392 L p F P
0 g
s
.29787 .7841 m
.30039 .79642 L
s
.2742 .76217 m
.29787 .7841 L
s
.506 .489 .256 r
.63076 .29721 m .5997 .29075 L .60373 .30674 L p F P
0 g
s
.506 .489 .256 r
.60373 .30674 m .63648 .3135 L .63076 .29721 L p F P
0 g
s
.62399 .28465 m
.63076 .29721 L
s
.63076 .29721 m
.66032 .30585 L
s
.111 .143 .727 r
.62154 .87199 m .62614 .86698 L .59392 .86949 L p F P
0 g
s
.111 .143 .727 r
.59392 .86949 m .59088 .87288 L .62154 .87199 L p F P
0 g
s
.62154 .87199 m
.6506 .86776 L
s
.61595 .87671 m
.62154 .87199 L
s
.739 .104 .052 r
.80807 .46883 m .78898 .45071 L .7899 .47961 L p F P
0 g
s
.739 .104 .052 r
.7899 .47961 m .80905 .4975 L .80807 .46883 L p F P
0 g
s
.80384 .44201 m
.80807 .46883 L
s
.80807 .46883 m
.82351 .48789 L
s
.101 .024 .742 r
.47215 .88042 m .47737 .88305 L .50144 .87551 L p F P
0 g
s
.098 .035 .742 r
.50433 .87671 m .50144 .87551 L .47737 .88305 L p F P
0 g
s
.45437 .88694 m
.47737 .88305 L
s
.47737 .88305 m
.48309 .88538 L
s
.725 .181 .026 r
.785 .4239 m .7627 .40702 L .76637 .43382 L p F P
0 g
s
.725 .181 .026 r
.76637 .43382 m .78898 .45071 L .785 .4239 L p F P
0 g
s
.7781 .39947 m
.785 .4239 L
s
.785 .4239 m
.80384 .44201 L
s
.271 .184 .673 r
.69572 .83508 m .69823 .82608 L .66681 .83992 L p F P
0 g
s
.271 .184 .673 r
.66681 .83992 m .66492 .84721 L .69572 .83508 L p F P
0 g
s
.69572 .83508 m
.72419 .82016 L
s
.69142 .84385 m
.69572 .83508 L
s
.459 .475 .352 r
.23855 .67988 m .24441 .66317 L .23084 .63361 L p F P
0 g
s
.431 .447 .419 r
.24441 .66317 m .23855 .67988 L .25582 .70756 L p F P
0 g
s
.23601 .69666 m
.23855 .67988 L
s
.22485 .65144 m
.23855 .67988 L
s
.035 .098 .742 r
.57784 .88182 m .58279 .87907 L .55497 .87348 L p F P
0 g
s
.035 .098 .742 r
.55497 .87348 m .55249 .87489 L .57784 .88182 L p F P
0 g
s
.57784 .88182 m
.60207 .88514 L
s
.57235 .8843 m
.57784 .88182 L
s
.195 .165 .704 r
.66154 .85433 m .66492 .84721 L .63214 .85635 L p F P
0 g
s
.195 .165 .704 r
.63214 .85635 m .62969 .86175 L .66154 .85433 L p F P
0 g
s
.65675 .8612 m
.66154 .85433 L
s
.66154 .85433 m
.69142 .84385 L
s
.39 .625 .13 r
.22451 .55509 m .2381 .53641 L .23567 .50645 L p F P
0 g
s
.381 .61 .206 r
.2381 .53641 m .22451 .55509 L .23063 .58537 L p F P
0 g
s
.21466 .57431 m
.22451 .55509 L
s
.222 .52562 m
.22451 .55509 L
s
.35 .187 .635 r
.72733 .80953 m .72831 .7987 L .69888 .81694 L p F P
0 g
s
.35 .187 .635 r
.69888 .81694 m .69823 .82608 L .72733 .80953 L p F P
0 g
s
.72733 .80953 m
.75376 .79052 L
s
.72419 .82016 m
.72733 .80953 L
s
.551 .159 .482 r
.79853 .7156 m .79447 .70012 L .77388 .72733 L p F P
0 g
s
.551 .159 .482 r
.77388 .72733 m .77782 .74138 L .79853 .7156 L p F P
0 g
s
.79853 .7156 m
.81581 .68859 L
s
.79853 .7156 m
.79949 .73107 L
s
.193 .676 .256 r
.4695 .28828 m .43783 .29358 L .43298 .3097 L p F P
0 g
s
.122 .692 .256 r
.40095 .31757 m .43298 .3097 L .43783 .29358 L p F P
0 g
s
.43783 .29358 m
.44358 .28123 L
s
.40744 .3011 m
.43783 .29358 L
s
.178 .032 .727 r
.42452 .8643 m .42858 .86942 L .46009 .87114 L p F P
0 g
s
.181 .014 .727 r
.46346 .87444 m .46009 .87114 L .42858 .86942 L p F P
0 g
s
.42858 .86942 m
.43366 .8743 L
s
.39868 .8644 m
.42858 .86942 L
s
.103 .014 .742 r
.4675 .87755 m .47215 .88042 L .49882 .87417 L p F P
0 g
s
.101 .024 .742 r
.50144 .87551 m .49882 .87417 L .47215 .88042 L p F P
0 g
s
.44664 .8831 m
.47215 .88042 L
s
.47215 .88042 m
.47737 .88305 L
s
.616 .385 .181 r
.69675 .33367 m .66762 .32253 L .67342 .34275 L p F P
0 g
s
.616 .385 .181 r
.67342 .34275 m .7037 .35422 L .69675 .33367 L p F P
0 g
s
.68799 .31651 m
.69675 .33367 L
s
.69675 .33367 m
.72347 .34672 L
s
.439 .369 .482 r
.27394 .74816 m .2765 .73408 L .25582 .70756 L p F P
0 g
s
.398 .335 .539 r
.2765 .73408 m .27394 .74816 L .29784 .7716 L p F P
0 g
s
.27394 .74816 m
.2742 .76217 L
s
.25326 .72306 m
.27394 .74816 L
s
.692 .049 .281 r
.82751 .59492 m .81602 .57664 L .80645 .60777 L p F P
0 g
s
.692 .049 .281 r
.80645 .60777 m .81766 .62512 L .82751 .59492 L p F P
0 g
s
.82751 .59492 m
.8337 .56502 L
s
.82751 .59492 m
.83533 .61358 L
s
.045 .094 .742 r
.58279 .87907 m .58716 .87608 L .55715 .87196 L p F P
0 g
s
.045 .094 .742 r
.55715 .87196 m .55497 .87348 L .58279 .87907 L p F P
0 g
s
.58279 .87907 m
.60944 .88111 L
s
.57784 .88182 m
.58279 .87907 L
s
.452 .539 .256 r
.5997 .29075 m .56757 .28656 L .56984 .30236 L p F P
0 g
s
.452 .539 .256 r
.56984 .30236 m .60373 .30674 L .5997 .29075 L p F P
0 g
s
.59492 .27857 m
.5997 .29075 L
s
.5997 .29075 m
.63076 .29721 L
s
.103 .734 .104 r
.33525 .36045 m .30883 .37475 L .30279 .39883 L p F P
0 g
s
.179 .719 .104 r
.27879 .41497 m .30279 .39883 L .30883 .37475 L p F P
0 g
s
.28542 .39066 m
.30883 .37475 L
s
.30883 .37475 m
.31727 .35362 L
s
.125 .131 .727 r
.62614 .86698 m .62969 .86175 L .59624 .86596 L p F P
0 g
s
.125 .131 .727 r
.59624 .86596 m .59392 .86949 L .62614 .86698 L p F P
0 g
s
.62154 .87199 m
.62614 .86698 L
s
.62614 .86698 m
.65675 .8612 L
s
.304 .124 .673 r
.38916 .85066 m .38655 .84345 L .35538 .83043 L p F P
0 g
s
.237 .097 .704 r
.38655 .84345 m .38916 .85066 L .42153 .85897 L p F P
0 g
s
.246 .071 .704 r
.42452 .8643 m .42153 .85897 L .38916 .85066 L p F P
0 g
s
.38916 .85066 m
.39322 .85767 L
s
.35876 .83933 m
.38916 .85066 L
s
.35 .187 .635 r
.35538 .83043 m .35383 .82135 L .32452 .80392 L p F P
0 g
s
.289 .155 .673 r
.35383 .82135 m .35538 .83043 L .38655 .84345 L p F P
0 g
s
.35538 .83043 m
.35876 .83933 L
s
.32655 .81467 m
.35538 .83043 L
s
.427 .173 .59 r
.75509 .7781 m .7539 .76557 L .72706 .7878 L p F P
0 g
s
.427 .173 .59 r
.72706 .7878 m .72831 .7987 L .75509 .7781 L p F P
0 g
s
.75509 .7781 m
.77891 .75545 L
s
.75376 .79052 m
.75509 .7781 L
s
.327 .671 .052 r
.23567 .50645 m .25307 .48808 L .25402 .45929 L p F P
0 g
s
.323 .662 .13 r
.25307 .48808 m .23567 .50645 L .2381 .53641 L p F P
0 g
s
.222 .52562 m
.23567 .50645 L
s
.23567 .50645 m
.23667 .4779 L
s
.104 .003 .742 r
.46346 .87444 m .4675 .87755 L .49649 .87271 L p F P
0 g
s
.103 .014 .742 r
.49882 .87417 m .49649 .87271 L .4675 .87755 L p F P
0 g
s
.43971 .87887 m
.4675 .87755 L
s
.4675 .87755 m
.47215 .88042 L
s
.263 .652 .256 r
.502 .28532 m .4695 .28828 L .46638 .30416 L p F P
0 g
s
.193 .676 .256 r
.43298 .3097 m .46638 .30416 L .4695 .28828 L p F P
0 g
s
.4695 .28828 m
.4732 .27625 L
s
.43783 .29358 m
.4695 .28828 L
s
.427 .547 .281 r
.23084 .63361 m .24035 .61605 L .23063 .58537 L p F P
0 g
s
.406 .521 .352 r
.24035 .61605 m .23084 .63361 L .24441 .66317 L p F P
0 g
s
.22485 .65144 m
.23084 .63361 L
s
.2209 .60386 m
.23084 .63361 L
s
.393 .583 .256 r
.56757 .28656 m .53485 .28475 L .53532 .30046 L p F P
0 g
s
.393 .583 .256 r
.53532 .30046 m .56984 .30236 L .56757 .28656 L p F P
0 g
s
.56488 .27463 m
.56757 .28656 L
s
.56757 .28656 m
.5997 .29075 L
s
.054 .089 .742 r
.58716 .87608 m .59088 .87288 L .559 .87034 L p F P
0 g
s
.054 .089 .742 r
.559 .87034 m .55715 .87196 L .58716 .87608 L p F P
0 g
s
.58716 .87608 m
.61595 .87671 L
s
.58279 .87907 m
.58716 .87608 L
s
.181 .725 .026 r
.30279 .39883 m .27879 .41497 L .27496 .44178 L p F P
0 g
s
.256 .703 .026 r
.25402 .45929 m .27496 .44178 L .27879 .41497 L p F P
0 g
s
.27879 .41497 m
.28542 .39066 L
s
.25813 .43247 m
.27879 .41497 L
s
.381 .258 .59 r
.32452 .80392 m .32469 .79305 L .29784 .7716 L p F P
0 g
s
.328 .222 .635 r
.32469 .79305 m .32452 .80392 L .35383 .82135 L p F P
0 g
s
.32452 .80392 m
.32655 .81467 L
s
.29787 .7841 m
.32452 .80392 L
s
.174 .051 .727 r
.42153 .85897 m .42452 .8643 L .45742 .86767 L p F P
0 g
s
.178 .032 .727 r
.46009 .87114 m .45742 .86767 L .42452 .8643 L p F P
0 g
s
.39322 .85767 m
.42452 .8643 L
s
.42452 .8643 m
.42858 .86942 L
s
.255 .701 .052 r
.27496 .44178 m .25402 .45929 L .25307 .48808 L p F P
0 g
s
.23667 .4779 m
.25402 .45929 L
s
.25402 .45929 m
.25813 .43247 L
s
.05 .724 .181 r
.40095 .31757 m .37072 .32764 L .36436 .34801 L p F P
0 g
s
.026 .725 .181 r
.33525 .36045 m .36436 .34801 L .37072 .32764 L p F P
0 g
s
.37072 .32764 m
.37874 .31073 L
s
.34271 .33972 m
.37072 .32764 L
s
.611 .108 .419 r
.81168 .67183 m .80421 .65522 L .78729 .6848 L p F P
0 g
s
.611 .108 .419 r
.78729 .6848 m .79447 .70012 L .81168 .67183 L p F P
0 g
s
.81168 .67183 m
.82534 .64285 L
s
.81168 .67183 m
.81581 .68859 L
s
.33 .621 .256 r
.53485 .28475 m .502 .28532 L .50066 .30106 L p F P
0 g
s
.263 .652 .256 r
.46638 .30416 m .50066 .30106 L .502 .28532 L p F P
0 g
s
.502 .28532 m
.50358 .27347 L
s
.4695 .28828 m
.502 .28532 L
s
.33 .621 .256 r
.50066 .30106 m .53532 .30046 L .53485 .28475 L p F P
0 g
s
.502 .28532 m
.53485 .28475 L
s
.53429 .27292 m
.53485 .28475 L
s
.53485 .28475 m
.56757 .28656 L
s
.212 .144 .704 r
.66492 .84721 m .66681 .83992 L .63345 .85082 L p F P
0 g
s
.212 .144 .704 r
.63345 .85082 m .63214 .85635 L .66492 .84721 L p F P
0 g
s
.66492 .84721 m
.69572 .83508 L
s
.66154 .85433 m
.66492 .84721 L
s
.104 .008 .742 r
.46009 .87114 m .46346 .87444 L .49448 .87113 L p F P
0 g
s
.104 .003 .742 r
.49649 .87271 m .49448 .87113 L .46346 .87444 L p F P
0 g
s
.43366 .8743 m
.46346 .87444 L
s
.46346 .87444 m
.4675 .87755 L
s
.719 .025 .206 r
.82205 .54602 m .80667 .52768 L .8009 .559 L p F P
0 g
s
.719 .025 .206 r
.8009 .559 m .81602 .57664 L .82205 .54602 L p F P
0 g
s
.82205 .54602 m
.82453 .51632 L
s
.82205 .54602 m
.8337 .56502 L
s
.431 .447 .419 r
.25582 .70756 m .26149 .69214 L .24441 .66317 L p F P
0 g
s
.398 .413 .482 r
.26149 .69214 m .25582 .70756 L .2765 .73408 L p F P
0 g
s
.25326 .72306 m
.25582 .70756 L
s
.23855 .67988 m
.25582 .70756 L
s
.289 .155 .673 r
.69823 .82608 m .69888 .81694 L .66717 .83253 L p F P
0 g
s
.289 .155 .673 r
.66717 .83253 m .66681 .83992 L .69823 .82608 L p F P
0 g
s
.69823 .82608 m
.72733 .80953 L
s
.69572 .83508 m
.69823 .82608 L
s
.666 .325 .104 r
.73145 .36766 m .7037 .35422 L .70868 .378 L p F P
0 g
s
.666 .325 .104 r
.70868 .378 m .73717 .39163 L .73145 .36766 L p F P
0 g
s
.72347 .34672 m
.73145 .36766 L
s
.73145 .36766 m
.75634 .38282 L
s
.015 .021 .749 r
.52632 .86433 m .52158 .88019 L .52534 .88033 L closepath p F P
0 g
s
.013 .023 .749 r
.52632 .86433 m .52534 .88033 L .5291 .88028 L closepath p F P
0 g
s
.5244 .89244 m
.52534 .88033 L
s
.138 .117 .727 r
.62969 .86175 m .63214 .85635 L .59781 .86232 L p F P
0 g
s
.138 .117 .727 r
.59781 .86232 m .59624 .86596 L .62969 .86175 L p F P
0 g
s
.62614 .86698 m
.62969 .86175 L
s
.62969 .86175 m
.66154 .85433 L
s
.011 .024 .749 r
.52632 .86433 m .5291 .88028 L .53284 .88005 L closepath p F P
0 g
s
.5291 .88028 m
.53178 .89235 L
s
.52534 .88033 m
.5291 .88028 L
s
.499 .144 .539 r
.77782 .74138 m .77388 .72733 L .75015 .75306 L p F P
0 g
s
.499 .144 .539 r
.75015 .75306 m .7539 .76557 L .77782 .74138 L p F P
0 g
s
.77782 .74138 m
.79853 .7156 L
s
.77782 .74138 m
.77891 .75545 L
s
.017 .019 .749 r
.52632 .86433 m .51788 .87985 L .52158 .88019 L closepath p F P
0 g
s
.52158 .88019 m
.52534 .88033 L
s
.51704 .89216 m
.52158 .88019 L
s
.008 .025 .749 r
.52632 .86433 m .53284 .88005 L .5365 .87962 L closepath p F P
0 g
s
.53284 .88005 m
.53911 .89189 L
s
.5291 .88028 m
.53284 .88005 L
s
.063 .083 .742 r
.59088 .87288 m .59392 .86949 L .5605 .86862 L p F P
0 g
s
.063 .083 .742 r
.5605 .86862 m .559 .87034 L .59088 .87288 L p F P
0 g
s
.59088 .87288 m
.62154 .87199 L
s
.58716 .87608 m
.59088 .87288 L
s
.019 .017 .749 r
.52632 .86433 m .51427 .87933 L .51788 .87985 L closepath p F P
0 g
s
.50977 .89151 m
.51788 .87985 L
s
.51788 .87985 m
.52158 .88019 L
s
.005 .026 .749 r
.52632 .86433 m .5365 .87962 L .54006 .87901 L closepath p F P
0 g
s
.5365 .87962 m
.54631 .89107 L
s
.53284 .88005 m
.5365 .87962 L
s
.021 .015 .749 r
.52632 .86433 m .51078 .87863 L .51427 .87933 L closepath p F P
0 g
s
.50267 .8905 m
.51427 .87933 L
s
.51427 .87933 m
.51788 .87985 L
s
.572 .447 .181 r
.66762 .32253 m .63648 .3135 L .64102 .33345 L p F P
0 g
s
.572 .447 .181 r
.64102 .33345 m .67342 .34275 L .66762 .32253 L p F P
0 g
s
.66032 .30585 m
.66762 .32253 L
s
.66762 .32253 m
.69675 .33367 L
s
.003 .026 .749 r
.52632 .86433 m .54006 .87901 L .54347 .87823 L closepath p F P
0 g
s
.54006 .87901 m
.5533 .88988 L
s
.5365 .87962 m
.54006 .87901 L
s
.398 .335 .539 r
.29784 .7716 m .30035 .75906 L .2765 .73408 L p F P
0 g
s
.352 .297 .59 r
.30035 .75906 m .29784 .7716 L .32469 .79305 L p F P
0 g
s
.29784 .7716 m
.29787 .7841 L
s
.27394 .74816 m
.29784 .7716 L
s
.023 .013 .749 r
.52632 .86433 m .50746 .87775 L .51078 .87863 L closepath p F P
0 g
s
.49581 .88913 m
.51078 .87863 L
s
.51078 .87863 m
.51427 .87933 L
s
.381 .61 .206 r
.23063 .58537 m .24401 .56739 L .2381 .53641 L p F P
0 g
s
.367 .588 .281 r
.24401 .56739 m .23063 .58537 L .24035 .61605 L p F P
0 g
s
.2209 .60386 m
.23063 .58537 L
s
.22451 .55509 m
.23063 .58537 L
s
0 .026 .749 r
.52632 .86433 m .54347 .87823 L .5467 .87727 L closepath p F P
0 g
s
.54347 .87823 m
.56002 .88835 L
s
.54006 .87901 m
.54347 .87823 L
s
.102 .019 .742 r
.45742 .86767 m .46009 .87114 L .49281 .86946 L p F P
0 g
s
.104 .008 .742 r
.49448 .87113 m .49281 .86946 L .46009 .87114 L p F P
0 g
s
.42858 .86942 m
.46009 .87114 L
s
.46009 .87114 m
.46346 .87444 L
s
.289 .155 .673 r
.38655 .84345 m .38544 .83609 L .35383 .82135 L p F P
0 g
s
.226 .121 .704 r
.38544 .83609 m .38655 .84345 L .41967 .85349 L p F P
0 g
s
.237 .097 .704 r
.42153 .85897 m .41967 .85349 L .38655 .84345 L p F P
0 g
s
.38655 .84345 m
.38916 .85066 L
s
.35538 .83043 m
.38655 .84345 L
s
.367 .149 .635 r
.72831 .7987 m .72706 .7878 L .69763 .80775 L p F P
0 g
s
.367 .149 .635 r
.69763 .80775 m .69888 .81694 L .72831 .7987 L p F P
0 g
s
.72831 .7987 m
.75509 .7781 L
s
.72733 .80953 m
.72831 .7987 L
s
.73 .102 .13 r
.80905 .4975 m .7899 .47961 L .78766 .51025 L p F P
0 g
s
.73 .102 .13 r
.78766 .51025 m .80667 .52768 L .80905 .4975 L p F P
0 g
s
.80807 .46883 m
.80905 .4975 L
s
.80905 .4975 m
.82453 .51632 L
s
.024 .011 .749 r
.52632 .86433 m .50433 .87671 L .50746 .87775 L closepath p F P
0 g
s
.48926 .88742 m
.50746 .87775 L
s
.50746 .87775 m
.51078 .87863 L
s
.167 .069 .727 r
.41967 .85349 m .42153 .85897 L .45548 .86408 L p F P
0 g
s
.174 .051 .727 r
.45742 .86767 m .45548 .86408 L .42153 .85897 L p F P
0 g
s
.38916 .85066 m
.42153 .85897 L
s
.42153 .85897 m
.42452 .8643 L
s
.003 .026 .749 r
.52632 .86433 m .5467 .87727 L .54972 .87615 L closepath p F P
0 g
s
.5467 .87727 m
.56639 .88648 L
s
.54347 .87823 m
.5467 .87727 L
s
.703 .256 .026 r
.7627 .40702 m .73717 .39163 L .74047 .41842 L p F P
0 g
s
.703 .256 .026 r
.74047 .41842 m .76637 .43382 L .7627 .40702 L p F P
0 g
s
.75634 .38282 m
.7627 .40702 L
s
.7627 .40702 m
.785 .4239 L
s
.025 .008 .749 r
.52632 .86433 m .50144 .87551 L .50433 .87671 L closepath p F P
0 g
s
.48309 .88538 m
.50433 .87671 L
s
.50433 .87671 m
.50746 .87775 L
s
.659 .047 .352 r
.81766 .62512 m .80645 .60777 L .79339 .63899 L p F P
0 g
s
.659 .047 .352 r
.79339 .63899 m .80421 .65522 L .81766 .62512 L p F P
0 g
s
.81766 .62512 m
.82751 .59492 L
s
.81766 .62512 m
.82534 .64285 L
s
.072 .076 .742 r
.59392 .86949 m .59624 .86596 L .56163 .86684 L p F P
0 g
s
.072 .076 .742 r
.56163 .86684 m .5605 .86862 L .59392 .86949 L p F P
0 g
s
.59392 .86949 m
.62614 .86698 L
s
.59088 .87288 m
.59392 .86949 L
s
.328 .222 .635 r
.35383 .82135 m .35416 .81217 L .32469 .79305 L p F P
0 g
s
.271 .184 .673 r
.35416 .81217 m .35383 .82135 L .38544 .83609 L p F P
0 g
s
.35383 .82135 m
.35538 .83043 L
s
.32452 .80392 m
.35383 .82135 L
s
.724 .181 .052 r
.78898 .45071 m .76637 .43382 L .76722 .46293 L p F P
0 g
s
.724 .181 .052 r
.76722 .46293 m .7899 .47961 L .78898 .45071 L p F P
0 g
s
.785 .4239 m
.78898 .45071 L
s
.78898 .45071 m
.80807 .46883 L
s
.005 .026 .749 r
.52632 .86433 m .54972 .87615 L .55249 .87489 L closepath p F P
0 g
s
.54972 .87615 m
.57235 .8843 L
s
.5467 .87727 m
.54972 .87615 L
s
.126 .715 .181 r
.43298 .3097 m .40095 .31757 L .39579 .33764 L p F P
0 g
s
.05 .724 .181 r
.36436 .34801 m .39579 .33764 L .40095 .31757 L p F P
0 g
s
.40095 .31757 m
.40744 .3011 L
s
.37072 .32764 m
.40095 .31757 L
s
.026 .005 .749 r
.52632 .86433 m .49882 .87417 L .50144 .87551 L closepath p F P
0 g
s
.47737 .88305 m
.50144 .87551 L
s
.50144 .87551 m
.50433 .87671 L
s
.026 .74 .104 r
.36436 .34801 m .33525 .36045 L .3299 .38432 L p F P
0 g
s
.103 .734 .104 r
.30279 .39883 m .3299 .38432 L .33525 .36045 L p F P
0 g
s
.30883 .37475 m
.33525 .36045 L
s
.33525 .36045 m
.34271 .33972 L
s
.15 .102 .727 r
.63214 .85635 m .63345 .85082 L .5986 .85861 L p F P
0 g
s
.15 .102 .727 r
.5986 .85861 m .59781 .86232 L .63214 .85635 L p F P
0 g
s
.63214 .85635 m
.66492 .84721 L
s
.62969 .86175 m
.63214 .85635 L
s
.406 .521 .352 r
.24441 .66317 m .25362 .64673 L .24035 .61605 L p F P
0 g
s
.381 .489 .419 r
.25362 .64673 m .24441 .66317 L .26149 .69214 L p F P
0 g
s
.23855 .67988 m
.24441 .66317 L
s
.23084 .63361 m
.24441 .66317 L
s
.008 .025 .749 r
.52632 .86433 m .55249 .87489 L .55497 .87348 L closepath p F P
0 g
s
.55249 .87489 m
.57784 .88182 L
s
.54972 .87615 m
.55249 .87489 L
s
.1 .03 .742 r
.45548 .86408 m .45742 .86767 L .4915 .8677 L p F P
0 g
s
.102 .019 .742 r
.49281 .86946 m .4915 .8677 L .45742 .86767 L p F P
0 g
s
.45742 .86767 m
.46009 .87114 L
s
.42452 .8643 m
.45742 .86767 L
s
.226 .121 .704 r
.66681 .83992 m .66717 .83253 L .63359 .84524 L p F P
0 g
s
.226 .121 .704 r
.63359 .84524 m .63345 .85082 L .66681 .83992 L p F P
0 g
s
.66681 .83992 m
.69823 .82608 L
s
.66492 .84721 m
.66681 .83992 L
s
.564 .1 .482 r
.79447 .70012 m .78729 .6848 L .76707 .71345 L p F P
0 g
s
.564 .1 .482 r
.76707 .71345 m .77388 .72733 L .79447 .70012 L p F P
0 g
s
.79447 .70012 m
.81168 .67183 L
s
.79447 .70012 m
.79853 .7156 L
s
.026 .003 .749 r
.52632 .86433 m .49649 .87271 L .49882 .87417 L closepath p F P
0 g
s
.47215 .88042 m
.49882 .87417 L
s
.49882 .87417 m
.50144 .87551 L
s
.323 .662 .13 r
.2381 .53641 m .25538 .51851 L .25307 .48808 L p F P
0 g
s
.315 .647 .206 r
.25538 .51851 m .2381 .53641 L .24401 .56739 L p F P
0 g
s
.22451 .55509 m
.2381 .53641 L
s
.23567 .50645 m
.2381 .53641 L
s
.398 .413 .482 r
.2765 .73408 m .28193 .72009 L .26149 .69214 L p F P
0 g
s
.361 .374 .539 r
.28193 .72009 m .2765 .73408 L .30035 .75906 L p F P
0 g
s
.27394 .74816 m
.2765 .73408 L
s
.25582 .70756 m
.2765 .73408 L
s
.011 .024 .749 r
.52632 .86433 m .55497 .87348 L .55715 .87196 L closepath p F P
0 g
s
.55497 .87348 m
.58279 .87907 L
s
.55249 .87489 m
.55497 .87348 L
s
.443 .128 .59 r
.7539 .76557 m .75015 .75306 L .72355 .77695 L p F P
0 g
s
.443 .128 .59 r
.72355 .77695 m .72706 .7878 L .7539 .76557 L p F P
0 g
s
.7539 .76557 m
.77782 .74138 L
s
.7539 .76557 m
.75509 .7781 L
s
.079 .068 .742 r
.59624 .86596 m .59781 .86232 L .56237 .865 L p F P
0 g
s
.079 .068 .742 r
.56237 .865 m .56163 .86684 L .59624 .86596 L p F P
0 g
s
.59392 .86949 m
.59624 .86596 L
s
.59624 .86596 m
.62969 .86175 L
s
.026 0 .749 r
.52632 .86433 m .49448 .87113 L .49649 .87271 L closepath p F P
0 g
s
.4675 .87755 m
.49649 .87271 L
s
.49649 .87271 m
.49882 .87417 L
s
.522 .504 .181 r
.63648 .3135 m .60373 .30674 L .60693 .32647 L p F P
0 g
s
.522 .504 .181 r
.60693 .32647 m .64102 .33345 L .63648 .3135 L p F P
0 g
s
.63076 .29721 m
.63648 .3135 L
s
.63648 .3135 m
.66762 .32253 L
s
.352 .297 .59 r
.32469 .79305 m .32711 .78215 L .30035 .75906 L p F P
0 g
s
.303 .255 .635 r
.32711 .78215 m .32469 .79305 L .35416 .81217 L p F P
0 g
s
.32452 .80392 m
.32469 .79305 L
s
.29784 .7716 m
.32469 .79305 L
s
.226 .121 .704 r
.41967 .85349 m .41896 .84793 L .38544 .83609 L p F P
0 g
s
.159 .086 .727 r
.41896 .84793 m .41967 .85349 L .45432 .8604 L p F P
0 g
s
.167 .069 .727 r
.45548 .86408 m .45432 .8604 L .41967 .85349 L p F P
0 g
s
.41967 .85349 m
.42153 .85897 L
s
.38655 .84345 m
.41967 .85349 L
s
.304 .124 .673 r
.69888 .81694 m .69763 .80775 L .66598 .82513 L p F P
0 g
s
.304 .124 .673 r
.66598 .82513 m .66717 .83253 L .69888 .81694 L p F P
0 g
s
.69888 .81694 m
.72831 .7987 L
s
.69823 .82608 m
.69888 .81694 L
s
.013 .023 .749 r
.52632 .86433 m .55715 .87196 L .559 .87034 L closepath p F P
0 g
s
.55715 .87196 m
.58716 .87608 L
s
.55497 .87348 m
.55715 .87196 L
s
.026 .003 .749 r
.52632 .86433 m .49281 .86946 L .49448 .87113 L closepath p F P
0 g
s
.46346 .87444 m
.49448 .87113 L
s
.49448 .87113 m
.49649 .87271 L
s
.096 .04 .742 r
.45432 .8604 m .45548 .86408 L .49057 .86589 L p F P
0 g
s
.1 .03 .742 r
.4915 .8677 m .49057 .86589 L .45548 .86408 L p F P
0 g
s
.42153 .85897 m
.45548 .86408 L
s
.45548 .86408 m
.45742 .86767 L
s
.693 .024 .281 r
.81602 .57664 m .8009 .559 L .79173 .59104 L p F P
0 g
s
.693 .024 .281 r
.79173 .59104 m .80645 .60777 L .81602 .57664 L p F P
0 g
s
.81602 .57664 m
.82205 .54602 L
s
.81602 .57664 m
.82751 .59492 L
s
.104 .74 .026 r
.3299 .38432 m .30279 .39883 L .29931 .42562 L p F P
0 g
s
.181 .725 .026 r
.27496 .44178 m .29931 .42562 L .30279 .39883 L p F P
0 g
s
.27879 .41497 m
.30279 .39883 L
s
.30279 .39883 m
.30883 .37475 L
s
.271 .184 .673 r
.38544 .83609 m .38588 .82868 L .35416 .81217 L p F P
0 g
s
.212 .144 .704 r
.38588 .82868 m .38544 .83609 L .41896 .84793 L p F P
0 g
s
.38544 .83609 m
.38655 .84345 L
s
.35383 .82135 m
.38544 .83609 L
s
.628 .393 .104 r
.7037 .35422 m .67342 .34275 L .67758 .36635 L p F P
0 g
s
.628 .393 .104 r
.67758 .36635 m .70868 .378 L .7037 .35422 L p F P
0 g
s
.69675 .33367 m
.7037 .35422 L
s
.7037 .35422 m
.73145 .36766 L
s
.255 .701 .052 r
.25307 .48808 m .27408 .47079 L .27496 .44178 L p F P
0 g
s
.252 .692 .13 r
.27408 .47079 m .25307 .48808 L .25538 .51851 L p F P
0 g
s
.23567 .50645 m
.25307 .48808 L
s
.25307 .48808 m
.25402 .45929 L
s
.015 .021 .749 r
.52632 .86433 m .559 .87034 L .5605 .86862 L closepath p F P
0 g
s
.559 .87034 m
.59088 .87288 L
s
.55715 .87196 m
.559 .87034 L
s
.2 .698 .181 r
.46638 .30416 m .43298 .3097 L .42913 .32953 L p F P
0 g
s
.126 .715 .181 r
.39579 .33764 m .42913 .32953 L .43298 .3097 L p F P
0 g
s
.43298 .3097 m
.43783 .29358 L
s
.40095 .31757 m
.43298 .3097 L
s
.159 .086 .727 r
.63345 .85082 m .63359 .84524 L .5986 .85487 L p F P
0 g
s
.159 .086 .727 r
.5986 .85487 m .5986 .85861 L .63345 .85082 L p F P
0 g
s
.63345 .85082 m
.66681 .83992 L
s
.63214 .85635 m
.63345 .85082 L
s
.026 .005 .749 r
.52632 .86433 m .4915 .8677 L .49281 .86946 L closepath p F P
0 g
s
.46009 .87114 m
.49281 .86946 L
s
.49281 .86946 m
.49448 .87113 L
s
.181 .724 .052 r
.29931 .42562 m .27496 .44178 L .27408 .47079 L p F P
0 g
s
.27496 .44178 m
.27879 .41497 L
s
.25402 .45929 m
.27496 .44178 L
s
.086 .059 .742 r
.59781 .86232 m .5986 .85861 L .56272 .86314 L p F P
0 g
s
.086 .059 .742 r
.56272 .86314 m .56237 .865 L .59781 .86232 L p F P
0 g
s
.59624 .86596 m
.59781 .86232 L
s
.59781 .86232 m
.63214 .85635 L
s
.367 .588 .281 r
.24035 .61605 m .25339 .59899 L .24401 .56739 L p F P
0 g
s
.35 .56 .352 r
.25339 .59899 m .24035 .61605 L .25362 .64673 L p F P
0 g
s
.23084 .63361 m
.24035 .61605 L
s
.23063 .58537 m
.24035 .61605 L
s
.017 .019 .749 r
.52632 .86433 m .5605 .86862 L .56163 .86684 L closepath p F P
0 g
s
.5605 .86862 m
.59392 .86949 L
s
.559 .87034 m
.5605 .86862 L
s
.619 .044 .419 r
.80421 .65522 m .79339 .63899 L .77697 .66985 L p F P
0 g
s
.619 .044 .419 r
.77697 .66985 m .78729 .6848 L .80421 .65522 L p F P
0 g
s
.80421 .65522 m
.81766 .62512 L
s
.80421 .65522 m
.81168 .67183 L
s
.466 .556 .181 r
.60373 .30674 m .56984 .30236 L .57165 .32196 L p F P
0 g
s
.466 .556 .181 r
.57165 .32196 m .60693 .32647 L .60373 .30674 L p F P
0 g
s
.5997 .29075 m
.60373 .30674 L
s
.60373 .30674 m
.63648 .3135 L
s
.025 .008 .749 r
.52632 .86433 m .49057 .86589 L .4915 .8677 L closepath p F P
0 g
s
.45742 .86767 m
.4915 .8677 L
s
.4915 .8677 m
.49281 .86946 L
s
.381 .11 .635 r
.72706 .7878 m .72355 .77695 L .69445 .79863 L p F P
0 g
s
.381 .11 .635 r
.69445 .79863 m .69763 .80775 L .72706 .7878 L p F P
0 g
s
.72706 .7878 m
.7539 .76557 L
s
.72706 .7878 m
.72831 .7987 L
s
.303 .255 .635 r
.35416 .81217 m .35641 .803 L .32711 .78215 L p F P
0 g
s
.251 .211 .673 r
.35641 .803 m .35416 .81217 L .38588 .82868 L p F P
0 g
s
.35383 .82135 m
.35416 .81217 L
s
.32469 .79305 m
.35416 .81217 L
s
.159 .086 .727 r
.45432 .8604 m .45393 .85667 L .41896 .84793 L p F P
0 g
s
.092 .05 .742 r
.45393 .85667 m .45432 .8604 L .49003 .86404 L p F P
0 g
s
.096 .04 .742 r
.49057 .86589 m .49003 .86404 L .45432 .8604 L p F P
0 g
s
.45432 .8604 m
.45548 .86408 L
s
.41967 .85349 m
.45432 .8604 L
s
.512 .091 .539 r
.77388 .72733 m .76707 .71345 L .74379 .74074 L p F P
0 g
s
.512 .091 .539 r
.74379 .74074 m .75015 .75306 L .77388 .72733 L p F P
0 g
s
.77388 .72733 m
.79447 .70012 L
s
.77388 .72733 m
.77782 .74138 L
s
.237 .097 .704 r
.66717 .83253 m .66598 .82513 L .63256 .83966 L p F P
0 g
s
.237 .097 .704 r
.63256 .83966 m .63359 .84524 L .66717 .83253 L p F P
0 g
s
.66717 .83253 m
.69888 .81694 L
s
.66681 .83992 m
.66717 .83253 L
s
.361 .374 .539 r
.30035 .75906 m .30546 .74664 L .28193 .72009 L p F P
0 g
s
.319 .332 .59 r
.30546 .74664 m .30035 .75906 L .32711 .78215 L p F P
0 g
s
.29784 .7716 m
.30035 .75906 L
s
.2765 .73408 m
.30035 .75906 L
s
.381 .489 .419 r
.26149 .69214 m .27031 .67699 L .25362 .64673 L p F P
0 g
s
.352 .452 .482 r
.27031 .67699 m .26149 .69214 L .28193 .72009 L p F P
0 g
s
.25582 .70756 m
.26149 .69214 L
s
.24441 .66317 m
.26149 .69214 L
s
.019 .017 .749 r
.52632 .86433 m .56163 .86684 L .56237 .865 L closepath p F P
0 g
s
.56163 .86684 m
.59624 .86596 L
s
.5605 .86862 m
.56163 .86684 L
s
.212 .144 .704 r
.41896 .84793 m .41943 .84234 L .38588 .82868 L p F P
0 g
s
.15 .102 .727 r
.41943 .84234 m .41896 .84793 L .45393 .85667 L p F P
0 g
s
.41896 .84793 m
.41967 .85349 L
s
.38544 .83609 m
.41896 .84793 L
s
.712 .1 .206 r
.80667 .52768 m .78766 .51025 L .78223 .54224 L p F P
0 g
s
.712 .1 .206 r
.78223 .54224 m .8009 .559 L .80667 .52768 L p F P
0 g
s
.80667 .52768 m
.80905 .4975 L
s
.80667 .52768 m
.82205 .54602 L
s
.052 .739 .104 r
.39579 .33764 m .36436 .34801 L .35979 .37169 L p F P
0 g
s
.026 .74 .104 r
.3299 .38432 m .35979 .37169 L .36436 .34801 L p F P
0 g
s
.36436 .34801 m
.37072 .32764 L
s
.33525 .36045 m
.36436 .34801 L
s
.272 .673 .181 r
.50066 .30106 m .46638 .30416 L .4639 .32382 L p F P
0 g
s
.2 .698 .181 r
.42913 .32953 m .4639 .32382 L .46638 .30416 L p F P
0 g
s
.46638 .30416 m
.4695 .28828 L
s
.43298 .3097 m
.46638 .30416 L
s
.024 .011 .749 r
.52632 .86433 m .49003 .86404 L .49057 .86589 L closepath p F P
0 g
s
.49057 .86589 m
.4915 .8677 L
s
.45548 .86408 m
.49057 .86589 L
s
.092 .05 .742 r
.5986 .85861 m .5986 .85487 L .56268 .86126 L p F P
0 g
s
.092 .05 .742 r
.56268 .86126 m .56272 .86314 L .5986 .85861 L p F P
0 g
s
.5986 .85861 m
.63345 .85082 L
s
.59781 .86232 m
.5986 .85861 L
s
.672 .328 .026 r
.73717 .39163 m .70868 .378 L .71156 .40477 L p F P
0 g
s
.672 .328 .026 r
.71156 .40477 m .74047 .41842 L .73717 .39163 L p F P
0 g
s
.73145 .36766 m
.73717 .39163 L
s
.73717 .39163 m
.7627 .40702 L
s
.021 .015 .749 r
.52632 .86433 m .56237 .865 L .56272 .86314 L closepath p F P
0 g
s
.56237 .865 m
.59781 .86232 L
s
.56163 .86684 m
.56237 .865 L
s
.406 .602 .181 r
.56984 .30236 m .53532 .30046 L .53569 .32 L p F P
0 g
s
.406 .602 .181 r
.53569 .32 m .57165 .32196 L .56984 .30236 L p F P
0 g
s
.56757 .28656 m
.56984 .30236 L
s
.56984 .30236 m
.60373 .30674 L
s
.092 .05 .742 r
.49003 .86404 m .48988 .86216 L .45393 .85667 L p F P
0 g
s
.023 .013 .749 r
.52632 .86433 m .48988 .86216 L .49003 .86404 L closepath p F P
0 g
s
.49003 .86404 m
.49057 .86589 L
s
.45432 .8604 m
.49003 .86404 L
s
.167 .069 .727 r
.63359 .84524 m .63256 .83966 L .59781 .85113 L p F P
0 g
s
.167 .069 .727 r
.59781 .85113 m .5986 .85487 L .63359 .84524 L p F P
0 g
s
.63359 .84524 m
.66717 .83253 L
s
.63345 .85082 m
.63359 .84524 L
s
.715 .178 .13 r
.7899 .47961 m .76722 .46293 L .76516 .494 L p F P
0 g
s
.715 .178 .13 r
.76516 .494 m .78766 .51025 L .7899 .47961 L p F P
0 g
s
.78898 .45071 m
.7899 .47961 L
s
.7899 .47961 m
.80905 .4975 L
s
.341 .641 .181 r
.53532 .30046 m .50066 .30106 L .49959 .32062 L p F P
0 g
s
.272 .673 .181 r
.4639 .32382 m .49959 .32062 L .50066 .30106 L p F P
0 g
s
.50066 .30106 m
.502 .28532 L
s
.46638 .30416 m
.50066 .30106 L
s
.15 .102 .727 r
.45393 .85667 m .45434 .85292 L .41943 .84234 L p F P
0 g
s
.086 .059 .742 r
.45434 .85292 m .45393 .85667 L .48988 .86216 L p F P
0 g
s
.45393 .85667 m
.45432 .8604 L
s
.41896 .84793 m
.45393 .85667 L
s
.251 .211 .673 r
.38588 .82868 m .38788 .8213 L .35641 .803 L p F P
0 g
s
.195 .165 .704 r
.38788 .8213 m .38588 .82868 L .41943 .84234 L p F P
0 g
s
.38544 .83609 m
.38588 .82868 L
s
.35416 .81217 m
.38588 .82868 L
s
.315 .647 .206 r
.24401 .56739 m .26099 .55018 L .25538 .51851 L p F P
0 g
s
.304 .624 .281 r
.26099 .55018 m .24401 .56739 L .25339 .59899 L p F P
0 g
s
.23063 .58537 m
.24401 .56739 L
s
.2381 .53641 m
.24401 .56739 L
s
.341 .641 .181 r
.49959 .32062 m .53569 .32 L .53532 .30046 L p F P
0 g
s
.50066 .30106 m
.53532 .30046 L
s
.53485 .28475 m
.53532 .30046 L
s
.53532 .30046 m
.56984 .30236 L
s
.701 .255 .052 r
.76637 .43382 m .74047 .41842 L .74123 .44773 L p F P
0 g
s
.701 .255 .052 r
.74123 .44773 m .76722 .46293 L .76637 .43382 L p F P
0 g
s
.7627 .40702 m
.76637 .43382 L
s
.76637 .43382 m
.78898 .45071 L
s
.315 .091 .673 r
.69763 .80775 m .69445 .79863 L .66323 .81778 L p F P
0 g
s
.315 .091 .673 r
.66323 .81778 m .66598 .82513 L .69763 .80775 L p F P
0 g
s
.69763 .80775 m
.72706 .7878 L
s
.69763 .80775 m
.69888 .81694 L
s
.023 .013 .749 r
.52632 .86433 m .56272 .86314 L .56268 .86126 L closepath p F P
0 g
s
.56272 .86314 m
.5986 .85861 L
s
.56237 .865 m
.56272 .86314 L
s
.584 .456 .104 r
.67342 .34275 m .64102 .33345 L .64428 .3569 L p F P
0 g
s
.584 .456 .104 r
.64428 .3569 m .67758 .36635 L .67342 .34275 L p F P
0 g
s
.66762 .32253 m
.67342 .34275 L
s
.67342 .34275 m
.7037 .35422 L
s
.319 .332 .59 r
.32711 .78215 m .3318 .77138 L .30546 .74664 L p F P
0 g
s
.275 .286 .635 r
.3318 .77138 m .32711 .78215 L .35641 .803 L p F P
0 g
s
.30035 .75906 m
.32711 .78215 L
s
.32469 .79305 m
.32711 .78215 L
s
.086 .059 .742 r
.48988 .86216 m .49014 .86029 L .45434 .85292 L p F P
0 g
s
.021 .015 .749 r
.52632 .86433 m .49014 .86029 L .48988 .86216 L closepath p F P
0 g
s
.45393 .85667 m
.48988 .86216 L
s
.48988 .86216 m
.49003 .86404 L
s
.026 0 .749 r
.52632 .86433 m .55855 .85406 L .55658 .85244 L closepath p F P
0 g
s
.026 .003 .749 r
.52632 .86433 m .55658 .85244 L .55428 .85093 L closepath p F P
0 g
s
.026 .005 .749 r
.52632 .86433 m .55428 .85093 L .55166 .84954 L closepath p F P
0 g
s
.025 .008 .749 r
.52632 .86433 m .55166 .84954 L .54875 .8483 L closepath p F P
0 g
s
.024 .011 .749 r
.52632 .86433 m .54875 .8483 L .5456 .84721 L closepath p F P
0 g
s
.023 .013 .749 r
.52632 .86433 m .5456 .84721 L .54222 .84629 L closepath p F P
0 g
s
.021 .015 .749 r
.52632 .86433 m .54222 .84629 L .53866 .84556 L closepath p F P
0 g
s
.019 .017 .749 r
.52632 .86433 m .53866 .84556 L .53496 .84501 L closepath p F P
0 g
s
.017 .019 .749 r
.52632 .86433 m .53496 .84501 L .53117 .84466 L closepath p F P
0 g
s
.015 .021 .749 r
.52632 .86433 m .53117 .84466 L .52732 .8445 L closepath p F P
0 g
s
.013 .023 .749 r
.52632 .86433 m .52732 .8445 L .52346 .84455 L closepath p F P
0 g
s
.011 .024 .749 r
.52632 .86433 m .52346 .84455 L .51963 .8448 L closepath p F P
0 g
s
.008 .025 .749 r
.52632 .86433 m .51963 .8448 L .51587 .84525 L closepath p F P
0 g
s
.005 .026 .749 r
.52632 .86433 m .51587 .84525 L .51224 .84589 L closepath p F P
0 g
s
.003 .026 .749 r
.52632 .86433 m .51224 .84589 L .50876 .84671 L closepath p F P
0 g
s
0 .026 .749 r
.52632 .86433 m .50876 .84671 L .50549 .84771 L closepath p F P
0 g
s
.003 .026 .749 r
.52632 .86433 m .50549 .84771 L .50245 .84888 L closepath p F P
0 g
s
.005 .026 .749 r
.52632 .86433 m .50245 .84888 L .49968 .85019 L closepath p F P
0 g
s
.008 .025 .749 r
.52632 .86433 m .49968 .85019 L .4972 .85164 L closepath p F P
0 g
s
.011 .024 .749 r
.52632 .86433 m .4972 .85164 L .49506 .85321 L closepath p F P
0 g
s
.013 .023 .749 r
.52632 .86433 m .49506 .85321 L .49326 .85488 L closepath p F P
0 g
s
.015 .021 .749 r
.52632 .86433 m .49326 .85488 L .49184 .85662 L closepath p F P
0 g
s
.017 .019 .749 r
.52632 .86433 m .49184 .85662 L .49079 .85844 L closepath p F P
0 g
s
.019 .017 .749 r
.52632 .86433 m .49079 .85844 L .49014 .86029 L closepath p F P
0 g
s
.024 .011 .749 r
.52632 .86433 m .56268 .86126 L .56223 .85939 L closepath p F P
0 g
s
.025 .008 .749 r
.52632 .86433 m .56223 .85939 L .56139 .85756 L closepath p F P
0 g
s
.026 .005 .749 r
.52632 .86433 m .56139 .85756 L .56016 .85577 L closepath p F P
0 g
s
.026 .003 .749 r
.52632 .86433 m .56016 .85577 L .55855 .85406 L closepath p F P
0 g
s
.48988 .86216 m
.52632 .86433 L
s
.49003 .86404 m
.52632 .86433 L
s
.49057 .86589 m
.52632 .86433 L
s
.4915 .8677 m
.52632 .86433 L
s
.49281 .86946 m
.52632 .86433 L
s
.49448 .87113 m
.52632 .86433 L
s
.49649 .87271 m
.52632 .86433 L
s
.49882 .87417 m
.52632 .86433 L
s
.50144 .87551 m
.52632 .86433 L
s
.50433 .87671 m
.52632 .86433 L
s
.50746 .87775 m
.52632 .86433 L
s
.51078 .87863 m
.52632 .86433 L
s
.51427 .87933 m
.52632 .86433 L
s
.51788 .87985 m
.52632 .86433 L
s
.52158 .88019 m
.52632 .86433 L
s
.52534 .88033 m
.52632 .86433 L
s
.52632 .86433 m
.5291 .88028 L
s
.52632 .86433 m
.53284 .88005 L
s
.52632 .86433 m
.5365 .87962 L
s
.52632 .86433 m
.54006 .87901 L
s
.52632 .86433 m
.54347 .87823 L
s
.52632 .86433 m
.5467 .87727 L
s
.52632 .86433 m
.54972 .87615 L
s
.52632 .86433 m
.55249 .87489 L
s
.52632 .86433 m
.55497 .87348 L
s
.52632 .86433 m
.55715 .87196 L
s
.52632 .86433 m
.559 .87034 L
s
.52632 .86433 m
.5605 .86862 L
s
.52632 .86433 m
.56163 .86684 L
s
.52632 .86433 m
.56237 .865 L
s
.52632 .86433 m
.56272 .86314 L
s
.52632 .86433 m
.52632 .86433 L
s
.096 .04 .742 r
.5986 .85487 m .59781 .85113 L .56223 .85939 L p F P
0 g
s
.096 .04 .742 r
.56223 .85939 m .56268 .86126 L .5986 .85487 L p F P
0 g
s
.5986 .85487 m
.63359 .84524 L
s
.5986 .85861 m
.5986 .85487 L
s
.56268 .86126 m
.5986 .85487 L
s
.52632 .86433 m
.56268 .86126 L
s
.56268 .86126 m
.56272 .86314 L
s
.66 .023 .352 r
.80645 .60777 m .79173 .59104 L .77924 .62334 L p F P
0 g
s
.66 .023 .352 r
.77924 .62334 m .79339 .63899 L .80645 .60777 L p F P
0 g
s
.80645 .60777 m
.81602 .57664 L
s
.80645 .60777 m
.81766 .62512 L
s
.454 .081 .59 r
.75015 .75306 m .74379 .74074 L .71777 .76627 L p F P
0 g
s
.454 .081 .59 r
.71777 .76627 m .72355 .77695 L .75015 .75306 L p F P
0 g
s
.75015 .75306 m
.77388 .72733 L
s
.75015 .75306 m
.7539 .76557 L
s
.195 .165 .704 r
.41943 .84234 m .42108 .83678 L .38788 .8213 L p F P
0 g
s
.138 .117 .727 r
.42108 .83678 m .41943 .84234 L .45434 .85292 L p F P
0 g
s
.38588 .82868 m
.41943 .84234 L
s
.41896 .84793 m
.41943 .84234 L
s
.352 .452 .482 r
.28193 .72009 m .29024 .70637 L .27031 .67699 L p F P
0 g
s
.319 .41 .539 r
.29024 .70637 m .28193 .72009 L .30546 .74664 L p F P
0 g
s
.26149 .69214 m
.28193 .72009 L
s
.2765 .73408 m
.28193 .72009 L
s
.572 .041 .482 r
.78729 .6848 m .77697 .66985 L .75737 .69992 L p F P
0 g
s
.572 .041 .482 r
.75737 .69992 m .76707 .71345 L .78729 .6848 L p F P
0 g
s
.78729 .6848 m
.80421 .65522 L
s
.78729 .6848 m
.79447 .70012 L
s
.35 .56 .352 r
.25362 .64673 m .26618 .63078 L .25339 .59899 L p F P
0 g
s
.328 .526 .419 r
.26618 .63078 m .25362 .64673 L .27031 .67699 L p F P
0 g
s
.24441 .66317 m
.25362 .64673 L
s
.24035 .61605 m
.25362 .64673 L
s
.079 .068 .742 r
.45555 .84921 m .45434 .85292 L .49014 .86029 L p F P
0 g
s
.079 .068 .742 r
.49014 .86029 m .49079 .85844 L .45555 .84921 L p F P
0 g
s
.48988 .86216 m
.49014 .86029 L
s
.49014 .86029 m
.52632 .86433 L
s
.246 .071 .704 r
.66598 .82513 m .66323 .81778 L .63033 .83414 L p F P
0 g
s
.246 .071 .704 r
.63033 .83414 m .63256 .83966 L .66598 .82513 L p F P
0 g
s
.66598 .82513 m
.69763 .80775 L
s
.66598 .82513 m
.66717 .83253 L
s
.026 .747 .026 r
.35979 .37169 m .3299 .38432 L .32681 .4111 L p F P
0 g
s
.104 .74 .026 r
.29931 .42562 m .32681 .4111 L .3299 .38432 L p F P
0 g
s
.30279 .39883 m
.3299 .38432 L
s
.3299 .38432 m
.33525 .36045 L
s
.138 .117 .727 r
.45434 .85292 m .45555 .84921 L .42108 .83678 L p F P
0 g
s
.45434 .85292 m
.49014 .86029 L
s
.41943 .84234 m
.45434 .85292 L
s
.45393 .85667 m
.45434 .85292 L
s
.1 .03 .742 r
.56139 .85756 m .56223 .85939 L .59781 .85113 L p F P
0 g
s
.56223 .85939 m
.56268 .86126 L
s
.52632 .86433 m
.56223 .85939 L
s
.252 .692 .13 r
.25538 .51851 m .27623 .50166 L .27408 .47079 L p F P
0 g
s
.246 .676 .206 r
.27623 .50166 m .25538 .51851 L .26099 .55018 L p F P
0 g
s
.2381 .53641 m
.25538 .51851 L
s
.25307 .48808 m
.25538 .51851 L
s
.129 .73 .104 r
.42913 .32953 m .39579 .33764 L .39209 .36116 L p F P
0 g
s
.052 .739 .104 r
.35979 .37169 m .39209 .36116 L .39579 .33764 L p F P
0 g
s
.39579 .33764 m
.40095 .31757 L
s
.36436 .34801 m
.39579 .33764 L
s
.275 .286 .635 r
.35641 .803 m .36059 .79395 L .3318 .77138 L p F P
0 g
s
.227 .236 .673 r
.36059 .79395 m .35641 .803 L .38788 .8213 L p F P
0 g
s
.32711 .78215 m
.35641 .803 L
s
.35416 .81217 m
.35641 .803 L
s
.174 .051 .727 r
.63256 .83966 m .63033 .83414 L .59622 .84745 L p F P
0 g
s
.174 .051 .727 r
.59622 .84745 m .59781 .85113 L .63256 .83966 L p F P
0 g
s
.63256 .83966 m
.66598 .82513 L
s
.63256 .83966 m
.63359 .84524 L
s
.072 .076 .742 r
.45754 .84558 m .45555 .84921 L .49079 .85844 L p F P
0 g
s
.072 .076 .742 r
.49079 .85844 m .49184 .85662 L .45754 .84558 L p F P
0 g
s
.49014 .86029 m
.49079 .85844 L
s
.49079 .85844 m
.52632 .86433 L
s
.1 .03 .742 r
.59781 .85113 m .59622 .84745 L .56139 .85756 L p F P
0 g
s
.56223 .85939 m
.59781 .85113 L
s
.59781 .85113 m
.5986 .85487 L
s
.59781 .85113 m
.63256 .83966 L
s
.102 .019 .742 r
.56016 .85577 m .56139 .85756 L .59622 .84745 L p F P
0 g
s
.56139 .85756 m
.56223 .85939 L
s
.52632 .86433 m
.56139 .85756 L
s
.39 .07 .635 r
.72355 .77695 m .71777 .76627 L .68934 .78967 L p F P
0 g
s
.39 .07 .635 r
.68934 .78967 m .69445 .79863 L .72355 .77695 L p F P
0 g
s
.72355 .77695 m
.75015 .75306 L
s
.72355 .77695 m
.72706 .7878 L
s
.104 .739 .052 r
.32681 .4111 m .29931 .42562 L .2985 .45484 L p F P
0 g
s
.181 .724 .052 r
.27408 .47079 m .2985 .45484 L .29931 .42562 L p F P
0 g
s
.29931 .42562 m
.30279 .39883 L
s
.27496 .44178 m
.29931 .42562 L
s
.178 .715 .13 r
.2985 .45484 m .27408 .47079 L .27623 .50166 L p F P
0 g
s
.25307 .48808 m
.27408 .47079 L
s
.27408 .47079 m
.27496 .44178 L
s
.063 .083 .742 r
.4603 .84206 m .45754 .84558 L .49184 .85662 L p F P
0 g
s
.063 .083 .742 r
.49184 .85662 m .49326 .85488 L .4603 .84206 L p F P
0 g
s
.49079 .85844 m
.49184 .85662 L
s
.49184 .85662 m
.52632 .86433 L
s
.687 .096 .281 r
.8009 .559 m .78223 .54224 L .7736 .57515 L p F P
0 g
s
.687 .096 .281 r
.7736 .57515 m .79173 .59104 L .8009 .559 L p F P
0 g
s
.8009 .559 m
.80667 .52768 L
s
.8009 .559 m
.81602 .57664 L
s
.227 .236 .673 r
.38788 .8213 m .39145 .81403 L .36059 .79395 L p F P
0 g
s
.177 .185 .704 r
.39145 .81403 m .38788 .8213 L .42108 .83678 L p F P
0 g
s
.35641 .803 m
.38788 .8213 L
s
.38588 .82868 m
.38788 .8213 L
s
.125 .131 .727 r
.42392 .83132 m .42108 .83678 L .45555 .84921 L p F P
0 g
s
.125 .131 .727 r
.45555 .84921 m .45754 .84558 L .42392 .83132 L p F P
0 g
s
.45434 .85292 m
.45555 .84921 L
s
.45555 .84921 m
.49079 .85844 L
s
.319 .41 .539 r
.30546 .74664 m .31316 .73446 L .29024 .70637 L p F P
0 g
s
.283 .363 .59 r
.31316 .73446 m .30546 .74664 L .3318 .77138 L p F P
0 g
s
.28193 .72009 m
.30546 .74664 L
s
.30035 .75906 m
.30546 .74664 L
s
.102 .019 .742 r
.59622 .84745 m .59386 .84387 L .56016 .85577 L p F P
0 g
s
.104 .008 .742 r
.55855 .85406 m .56016 .85577 L .59386 .84387 L p F P
0 g
s
.56016 .85577 m
.56139 .85756 L
s
.52632 .86433 m
.56016 .85577 L
s
.177 .185 .704 r
.42108 .83678 m .42392 .83132 L .39145 .81403 L p F P
0 g
s
.42108 .83678 m
.45555 .84921 L
s
.38788 .8213 m
.42108 .83678 L
s
.41943 .84234 m
.42108 .83678 L
s
.533 .515 .104 r
.64102 .33345 m .60693 .32647 L .60923 .34982 L p F P
0 g
s
.533 .515 .104 r
.60923 .34982 m .64428 .3569 L .64102 .33345 L p F P
0 g
s
.63648 .3135 m
.64102 .33345 L
s
.64102 .33345 m
.67342 .34275 L
s
.634 .396 .026 r
.70868 .378 m .67758 .36635 L .67998 .39311 L p F P
0 g
s
.634 .396 .026 r
.67998 .39311 m .71156 .40477 L .70868 .378 L p F P
0 g
s
.7037 .35422 m
.70868 .378 L
s
.70868 .378 m
.73717 .39163 L
s
.054 .089 .742 r
.46382 .83869 m .4603 .84206 L .49326 .85488 L p F P
0 g
s
.054 .089 .742 r
.49326 .85488 m .49506 .85321 L .46382 .83869 L p F P
0 g
s
.49184 .85662 m
.49326 .85488 L
s
.49326 .85488 m
.52632 .86433 L
s
.518 .037 .539 r
.76707 .71345 m .75737 .69992 L .73486 .72874 L p F P
0 g
s
.518 .037 .539 r
.73486 .72874 m .74379 .74074 L .76707 .71345 L p F P
0 g
s
.76707 .71345 m
.78729 .6848 L
s
.76707 .71345 m
.77388 .72733 L
s
.178 .032 .727 r
.59386 .84387 m .59622 .84745 L .63033 .83414 L p F P
0 g
s
.56139 .85756 m
.59622 .84745 L
s
.59622 .84745 m
.59781 .85113 L
s
.323 .058 .673 r
.69445 .79863 m .68934 .78967 L .65892 .8106 L p F P
0 g
s
.323 .058 .673 r
.65892 .8106 m .66323 .81778 L .69445 .79863 L p F P
0 g
s
.69445 .79863 m
.72355 .77695 L
s
.69445 .79863 m
.69763 .80775 L
s
.304 .624 .281 r
.25339 .59899 m .26989 .58267 L .26099 .55018 L p F P
0 g
s
.289 .594 .352 r
.26989 .58267 m .25339 .59899 L .26618 .63078 L p F P
0 g
s
.24035 .61605 m
.25339 .59899 L
s
.24401 .56739 m
.25339 .59899 L
s
.104 .003 .742 r
.55658 .85244 m .55855 .85406 L .59073 .84042 L p F P
0 g
s
.104 .008 .742 r
.59386 .84387 m .59073 .84042 L .55855 .85406 L p F P
0 g
s
.55855 .85406 m
.56016 .85577 L
s
.52632 .86433 m
.55855 .85406 L
s
.62 .021 .419 r
.79339 .63899 m .77924 .62334 L .76355 .65546 L p F P
0 g
s
.62 .021 .419 r
.76355 .65546 m .77697 .66985 L .79339 .63899 L p F P
0 g
s
.79339 .63899 m
.80645 .60777 L
s
.79339 .63899 m
.80421 .65522 L
s
.328 .526 .419 r
.27031 .67699 m .28225 .6623 L .26618 .63078 L p F P
0 g
s
.303 .486 .482 r
.28225 .6623 m .27031 .67699 L .29024 .70637 L p F P
0 g
s
.25362 .64673 m
.27031 .67699 L
s
.26149 .69214 m
.27031 .67699 L
s
.045 .094 .742 r
.46804 .83552 m .46382 .83869 L .49506 .85321 L p F P
0 g
s
.045 .094 .742 r
.49506 .85321 m .4972 .85164 L .46804 .83552 L p F P
0 g
s
.49326 .85488 m
.49506 .85321 L
s
.49506 .85321 m
.52632 .86433 L
s
.252 .045 .704 r
.62694 .82874 m .63033 .83414 L .66323 .81778 L p F P
0 g
s
.178 .032 .727 r
.63033 .83414 m .62694 .82874 L .59386 .84387 L p F P
0 g
s
.59622 .84745 m
.63033 .83414 L
s
.63033 .83414 m
.63256 .83966 L
s
.252 .045 .704 r
.66323 .81778 m .65892 .8106 L .62694 .82874 L p F P
0 g
s
.63033 .83414 m
.66323 .81778 L
s
.66323 .81778 m
.69445 .79863 L
s
.66323 .81778 m
.66598 .82513 L
s
.204 .712 .104 r
.4639 .32382 m .42913 .32953 L .42636 .35292 L p F P
0 g
s
.129 .73 .104 r
.39209 .36116 m .42636 .35292 L .42913 .32953 L p F P
0 g
s
.42913 .32953 m
.43298 .3097 L
s
.39579 .33764 m
.42913 .32953 L
s
.111 .143 .727 r
.42791 .82602 m .42392 .83132 L .45754 .84558 L p F P
0 g
s
.111 .143 .727 r
.45754 .84558 m .4603 .84206 L .42791 .82602 L p F P
0 g
s
.45555 .84921 m
.45754 .84558 L
s
.45754 .84558 m
.49184 .85662 L
s
.698 .174 .206 r
.78766 .51025 m .76516 .494 L .76015 .52663 L p F P
0 g
s
.698 .174 .206 r
.76015 .52663 m .78223 .54224 L .78766 .51025 L p F P
0 g
s
.78766 .51025 m
.7899 .47961 L
s
.78766 .51025 m
.80667 .52768 L
s
.104 .003 .742 r
.59073 .84042 m .58687 .83714 L .55658 .85244 L p F P
0 g
s
.103 .014 .742 r
.55428 .85093 m .55658 .85244 L .58687 .83714 L p F P
0 g
s
.52632 .86433 m
.55658 .85244 L
s
.55658 .85244 m
.55855 .85406 L
s
.283 .363 .59 r
.3318 .77138 m .33876 .76084 L .31316 .73446 L p F P
0 g
s
.243 .313 .635 r
.33876 .76084 m .3318 .77138 L .36059 .79395 L p F P
0 g
s
.30546 .74664 m
.3318 .77138 L
s
.32711 .78215 m
.3318 .77138 L
s
.035 .098 .742 r
.47293 .83258 m .46804 .83552 L .4972 .85164 L p F P
0 g
s
.035 .098 .742 r
.4972 .85164 m .49968 .85019 L .47293 .83258 L p F P
0 g
s
.49506 .85321 m
.4972 .85164 L
s
.4972 .85164 m
.52632 .86433 L
s
.671 .327 .052 r
.74047 .41842 m .71156 .40477 L .71222 .43425 L p F P
0 g
s
.671 .327 .052 r
.71222 .43425 m .74123 .44773 L .74047 .41842 L p F P
0 g
s
.73717 .39163 m
.74047 .41842 L
s
.74047 .41842 m
.76637 .43382 L
s
.181 .014 .727 r
.59073 .84042 m .59386 .84387 L .62694 .82874 L p F P
0 g
s
.56016 .85577 m
.59386 .84387 L
s
.59386 .84387 m
.59622 .84745 L
s
.103 .014 .742 r
.58687 .83714 m .58232 .83408 L .55428 .85093 L p F P
0 g
s
.101 .024 .742 r
.55166 .84954 m .55428 .85093 L .58232 .83408 L p F P
0 g
s
.55428 .85093 m
.55658 .85244 L
s
.52632 .86433 m
.55428 .85093 L
s
.692 .252 .13 r
.76722 .46293 m .74123 .44773 L .73938 .47919 L p F P
0 g
s
.692 .252 .13 r
.73938 .47919 m .76516 .494 L .76722 .46293 L p F P
0 g
s
.76637 .43382 m
.76722 .46293 L
s
.76722 .46293 m
.7899 .47961 L
s
.052 .746 .026 r
.39209 .36116 m .35979 .37169 L .35716 .39846 L p F P
0 g
s
.026 .747 .026 r
.32681 .4111 m .35716 .39846 L .35979 .37169 L p F P
0 g
s
.3299 .38432 m
.35979 .37169 L
s
.35979 .37169 m
.36436 .34801 L
s
.476 .568 .104 r
.60693 .32647 m .57165 .32196 L .57295 .34523 L p F P
0 g
s
.476 .568 .104 r
.57295 .34523 m .60923 .34982 L .60693 .32647 L p F P
0 g
s
.60373 .30674 m
.60693 .32647 L
s
.60693 .32647 m
.64102 .33345 L
s
.459 .033 .59 r
.74379 .74074 m .73486 .72874 L .70973 .7559 L p F P
0 g
s
.459 .033 .59 r
.70973 .7559 m .71777 .76627 L .74379 .74074 L p F P
0 g
s
.74379 .74074 m
.76707 .71345 L
s
.74379 .74074 m
.75015 .75306 L
s
.157 .202 .704 r
.39655 .80695 m .39145 .81403 L .42392 .83132 L p F P
0 g
s
.157 .202 .704 r
.42392 .83132 m .42791 .82602 L .39655 .80695 L p F P
0 g
s
.42108 .83678 m
.42392 .83132 L
s
.42392 .83132 m
.45754 .84558 L
s
.024 .101 .742 r
.47844 .82992 m .47293 .83258 L .49968 .85019 L p F P
0 g
s
.024 .101 .742 r
.49968 .85019 m .50245 .84888 L .47844 .82992 L p F P
0 g
s
.4972 .85164 m
.49968 .85019 L
s
.49968 .85019 m
.52632 .86433 L
s
.243 .313 .635 r
.36059 .79395 m .36669 .78512 L .33876 .76084 L p F P
0 g
s
.201 .259 .673 r
.36669 .78512 m .36059 .79395 L .39145 .81403 L p F P
0 g
s
.3318 .77138 m
.36059 .79395 L
s
.35641 .803 m
.36059 .79395 L
s
.101 .024 .742 r
.58232 .83408 m .57712 .83126 L .55166 .84954 L p F P
0 g
s
.098 .035 .742 r
.54875 .8483 m .55166 .84954 L .57712 .83126 L p F P
0 g
s
.55166 .84954 m
.55428 .85093 L
s
.52632 .86433 m
.55166 .84954 L
s
.201 .259 .673 r
.39145 .81403 m .39655 .80695 L .36669 .78512 L p F P
0 g
s
.38788 .8213 m
.39145 .81403 L
s
.39145 .81403 m
.42392 .83132 L
s
.36059 .79395 m
.39145 .81403 L
s
.246 .676 .206 r
.26099 .55018 m .28145 .53398 L .27623 .50166 L p F P
0 g
s
.237 .652 .281 r
.28145 .53398 m .26099 .55018 L .26989 .58267 L p F P
0 g
s
.24401 .56739 m
.26099 .55018 L
s
.25538 .51851 m
.26099 .55018 L
s
.095 .154 .727 r
.43304 .82094 m .42791 .82602 L .4603 .84206 L p F P
0 g
s
.095 .154 .727 r
.4603 .84206 m .46382 .83869 L .43304 .82094 L p F P
0 g
s
.45754 .84558 m
.4603 .84206 L
s
.4603 .84206 m
.49326 .85488 L
s
.014 .103 .742 r
.4845 .82755 m .47844 .82992 L .50245 .84888 L p F P
0 g
s
.014 .103 .742 r
.50245 .84888 m .50549 .84771 L .4845 .82755 L p F P
0 g
s
.49968 .85019 m
.50245 .84888 L
s
.50245 .84888 m
.52632 .86433 L
s
.277 .687 .104 r
.49959 .32062 m .4639 .32382 L .46211 .34712 L p F P
0 g
s
.204 .712 .104 r
.42636 .35292 m .46211 .34712 L .4639 .32382 L p F P
0 g
s
.4639 .32382 m
.46638 .30416 L
s
.42913 .32953 m
.4639 .32382 L
s
.303 .486 .482 r
.29024 .70637 m .30141 .69309 L .28225 .6623 L p F P
0 g
s
.275 .441 .539 r
.30141 .69309 m .29024 .70637 L .31316 .73446 L p F P
0 g
s
.27031 .67699 m
.29024 .70637 L
s
.28193 .72009 m
.29024 .70637 L
s
.098 .035 .742 r
.57712 .83126 m .57134 .82874 L .54875 .8483 L p F P
0 g
s
.094 .045 .742 r
.5456 .84721 m .54875 .8483 L .57134 .82874 L p F P
0 g
s
.54875 .8483 m
.55166 .84954 L
s
.52632 .86433 m
.54875 .8483 L
s
.654 .092 .352 r
.79173 .59104 m .7736 .57515 L .76185 .60851 L p F P
0 g
s
.654 .092 .352 r
.76185 .60851 m .77924 .62334 L .79173 .59104 L p F P
0 g
s
.79173 .59104 m
.8009 .559 L
s
.79173 .59104 m
.80645 .60777 L
s
.255 .019 .704 r
.62239 .82354 m .62694 .82874 L .65892 .8106 L p F P
0 g
s
.181 .014 .727 r
.62694 .82874 m .62239 .82354 L .59073 .84042 L p F P
0 g
s
.59386 .84387 m
.62694 .82874 L
s
.62694 .82874 m
.63033 .83414 L
s
.003 .104 .742 r
.49106 .82551 m .4845 .82755 L .50549 .84771 L p F P
0 g
s
.003 .104 .742 r
.50549 .84771 m .50876 .84671 L .49106 .82551 L p F P
0 g
s
.50245 .84888 m
.50549 .84771 L
s
.50549 .84771 m
.52632 .86433 L
s
.181 .005 .727 r
.58687 .83714 m .59073 .84042 L .62239 .82354 L p F P
0 g
s
.59073 .84042 m
.59386 .84387 L
s
.55855 .85406 m
.59073 .84042 L
s
.573 .019 .482 r
.77697 .66985 m .76355 .65546 L .74485 .68691 L p F P
0 g
s
.573 .019 .482 r
.74485 .68691 m .75737 .69992 L .77697 .66985 L p F P
0 g
s
.77697 .66985 m
.79339 .63899 L
s
.77697 .66985 m
.78729 .6848 L
s
.395 .028 .635 r
.71777 .76627 m .70973 .7559 L .68233 .78099 L p F P
0 g
s
.395 .028 .635 r
.68233 .78099 m .68934 .78967 L .71777 .76627 L p F P
0 g
s
.71777 .76627 m
.74379 .74074 L
s
.71777 .76627 m
.72355 .77695 L
s
.414 .614 .104 r
.57165 .32196 m .53569 .32 L .53596 .34324 L p F P
0 g
s
.414 .614 .104 r
.53596 .34324 m .57295 .34523 L .57165 .32196 L p F P
0 g
s
.56984 .30236 m
.57165 .32196 L
s
.57165 .32196 m
.60693 .32647 L
s
.094 .045 .742 r
.57134 .82874 m .56503 .82652 L .5456 .84721 L p F P
0 g
s
.089 .054 .742 r
.54222 .84629 m .5456 .84721 L .56503 .82652 L p F P
0 g
s
.5456 .84721 m
.54875 .8483 L
s
.52632 .86433 m
.5456 .84721 L
s
.289 .594 .352 r
.26618 .63078 m .28202 .61553 L .26989 .58267 L p F P
0 g
s
.271 .558 .419 r
.28202 .61553 m .26618 .63078 L .28225 .6623 L p F P
0 g
s
.25362 .64673 m
.26618 .63078 L
s
.25339 .59899 m
.26618 .63078 L
s
.589 .46 .026 r
.67758 .36635 m .64428 .3569 L .64616 .38364 L p F P
0 g
s
.589 .46 .026 r
.64616 .38364 m .67998 .39311 L .67758 .36635 L p F P
0 g
s
.67342 .34275 m
.67758 .36635 L
s
.67758 .36635 m
.70868 .378 L
s
.008 .104 .742 r
.49802 .82383 m .49106 .82551 L .50876 .84671 L p F P
0 g
s
.008 .104 .742 r
.50876 .84671 m .51224 .84589 L .49802 .82383 L p F P
0 g
s
.50549 .84771 m
.50876 .84671 L
s
.50876 .84671 m
.52632 .86433 L
s
.348 .654 .104 r
.53569 .32 m .49959 .32062 L .49883 .34387 L p F P
0 g
s
.277 .687 .104 r
.46211 .34712 m .49883 .34387 L .49959 .32062 L p F P
0 g
s
.49959 .32062 m
.50066 .30106 L
s
.4639 .32382 m
.49959 .32062 L
s
.089 .054 .742 r
.56503 .82652 m .55827 .82465 L .54222 .84629 L p F P
0 g
s
.083 .063 .742 r
.53866 .84556 m .54222 .84629 L .55827 .82465 L p F P
0 g
s
.54222 .84629 m
.5456 .84721 L
s
.52632 .86433 m
.54222 .84629 L
s
.327 .024 .673 r
.65308 .80364 m .65892 .8106 L .68934 .78967 L p F P
0 g
s
.255 .019 .704 r
.65892 .8106 m .65308 .80364 L .62239 .82354 L p F P
0 g
s
.65892 .8106 m
.66323 .81778 L
s
.62694 .82874 m
.65892 .8106 L
s
.026 .746 .052 r
.35716 .39846 m .32681 .4111 L .3261 .4405 L p F P
0 g
s
.104 .739 .052 r
.2985 .45484 m .3261 .4405 L .32681 .4111 L p F P
0 g
s
.29931 .42562 m
.32681 .4111 L
s
.32681 .4111 m
.3299 .38432 L
s
.019 .102 .742 r
.50532 .82252 m .49802 .82383 L .51224 .84589 L p F P
0 g
s
.019 .102 .742 r
.51224 .84589 m .51587 .84525 L .50532 .82252 L p F P
0 g
s
.50876 .84671 m
.51224 .84589 L
s
.51224 .84589 m
.52632 .86433 L
s
.348 .654 .104 r
.49883 .34387 m .53596 .34324 L .53569 .32 L p F P
0 g
s
.49959 .32062 m
.53569 .32 L
s
.53532 .30046 m
.53569 .32 L
s
.53569 .32 m
.57165 .32196 L
s
.327 .024 .673 r
.68934 .78967 m .68233 .78099 L .65308 .80364 L p F P
0 g
s
.65892 .8106 m
.68934 .78967 L
s
.68934 .78967 m
.71777 .76627 L
s
.68934 .78967 m
.69445 .79863 L
s
.079 .163 .727 r
.43924 .81614 m .43304 .82094 L .46382 .83869 L p F P
0 g
s
.079 .163 .727 r
.46382 .83869 m .46804 .83552 L .43924 .81614 L p F P
0 g
s
.4603 .84206 m
.46382 .83869 L
s
.46382 .83869 m
.49506 .85321 L
s
.178 .715 .13 r
.27623 .50166 m .30046 .48612 L .2985 .45484 L p F P
0 g
s
.174 .698 .206 r
.30046 .48612 m .27623 .50166 L .28145 .53398 L p F P
0 g
s
.25538 .51851 m
.27623 .50166 L
s
.27408 .47079 m
.27623 .50166 L
s
.083 .063 .742 r
.55827 .82465 m .55114 .82315 L .53866 .84556 L p F P
0 g
s
.076 .072 .742 r
.53496 .84501 m .53866 .84556 L .55114 .82315 L p F P
0 g
s
.53866 .84556 m
.54222 .84629 L
s
.52632 .86433 m
.53866 .84556 L
s
.03 .1 .742 r
.51286 .8216 m .50532 .82252 L .51587 .84525 L p F P
0 g
s
.03 .1 .742 r
.51587 .84525 m .51963 .8448 L .51286 .8216 L p F P
0 g
s
.51224 .84589 m
.51587 .84525 L
s
.51587 .84525 m
.52632 .86433 L
s
.135 .217 .704 r
.40317 .80015 m .39655 .80695 L .42791 .82602 L p F P
0 g
s
.135 .217 .704 r
.42791 .82602 m .43304 .82094 L .40317 .80015 L p F P
0 g
s
.42392 .83132 m
.42791 .82602 L
s
.42791 .82602 m
.4603 .84206 L
s
.076 .072 .742 r
.55114 .82315 m .54371 .82203 L .53496 .84501 L p F P
0 g
s
.068 .079 .742 r
.53117 .84466 m .53496 .84501 L .54371 .82203 L p F P
0 g
s
.53496 .84501 m
.53866 .84556 L
s
.52632 .86433 m
.53496 .84501 L
s
.04 .096 .742 r
.52056 .82109 m .51286 .8216 L .51963 .8448 L p F P
0 g
s
.04 .096 .742 r
.51963 .8448 m .52346 .84455 L .52056 .82109 L p F P
0 g
s
.51587 .84525 m
.51963 .8448 L
s
.51963 .8448 m
.52632 .86433 L
s
.068 .079 .742 r
.54371 .82203 m .53608 .82131 L .53117 .84466 L p F P
0 g
s
.059 .086 .742 r
.52732 .8445 m .53117 .84466 L .53608 .82131 L p F P
0 g
s
.53117 .84466 m
.53496 .84501 L
s
.52632 .86433 m
.53117 .84466 L
s
.05 .092 .742 r
.52833 .821 m .52056 .82109 L .52346 .84455 L p F P
0 g
s
.05 .092 .742 r
.52346 .84455 m .52732 .8445 L .52833 .821 L p F P
0 g
s
.51963 .8448 m
.52346 .84455 L
s
.52346 .84455 m
.52632 .86433 L
s
.275 .441 .539 r
.31316 .73446 m .32341 .7227 L .30141 .69309 L p F P
0 g
s
.243 .391 .59 r
.32341 .7227 m .31316 .73446 L .33876 .76084 L p F P
0 g
s
.29024 .70637 m
.31316 .73446 L
s
.30546 .74664 m
.31316 .73446 L
s
.059 .086 .742 r
.53608 .82131 m .52833 .821 L .52732 .8445 L p F P
0 g
s
.52346 .84455 m
.52732 .8445 L
s
.52632 .86433 m
.52732 .8445 L
s
.52732 .8445 m
.53117 .84466 L
s
.102 .73 .13 r
.3261 .4405 m .2985 .45484 L .30046 .48612 L p F P
0 g
s
.2985 .45484 m
.29931 .42562 L
s
.27408 .47079 m
.2985 .45484 L
s
.181 .005 .727 r
.62239 .82354 m .61674 .81859 L .58687 .83714 L p F P
0 g
s
.179 .024 .727 r
.58232 .83408 m .58687 .83714 L .61674 .81859 L p F P
0 g
s
.58687 .83714 m
.59073 .84042 L
s
.55658 .85244 m
.58687 .83714 L
s
.13 .736 .026 r
.42636 .35292 m .39209 .36116 L .38995 .38791 L p F P
0 g
s
.052 .746 .026 r
.35716 .39846 m .38995 .38791 L .39209 .36116 L p F P
0 g
s
.39209 .36116 m
.39579 .33764 L
s
.35979 .37169 m
.39209 .36116 L
s
.673 .167 .281 r
.78223 .54224 m .76015 .52663 L .75219 .56036 L p F P
0 g
s
.673 .167 .281 r
.75219 .56036 m .7736 .57515 L .78223 .54224 L p F P
0 g
s
.78223 .54224 m
.78766 .51025 L
s
.78223 .54224 m
.8009 .559 L
s
.061 .17 .727 r
.44647 .81169 m .43924 .81614 L .46804 .83552 L p F P
0 g
s
.061 .17 .727 r
.46804 .83552 m .47293 .83258 L .44647 .81169 L p F P
0 g
s
.46382 .83869 m
.46804 .83552 L
s
.46804 .83552 m
.4972 .85164 L
s
.256 .008 .704 r
.61674 .81859 m .62239 .82354 L .65308 .80364 L p F P
0 g
s
.59073 .84042 m
.62239 .82354 L
s
.62239 .82354 m
.62694 .82874 L
s
.519 .017 .539 r
.75737 .69992 m .74485 .68691 L .72339 .71724 L p F P
0 g
s
.519 .017 .539 r
.72339 .71724 m .73486 .72874 L .75737 .69992 L p F P
0 g
s
.75737 .69992 m
.77697 .66985 L
s
.75737 .69992 m
.76707 .71345 L
s
.173 .279 .673 r
.37467 .77663 m .36669 .78512 L .39655 .80695 L p F P
0 g
s
.173 .279 .673 r
.39655 .80695 m .40317 .80015 L .37467 .77663 L p F P
0 g
s
.39145 .81403 m
.39655 .80695 L
s
.39655 .80695 m
.42791 .82602 L
s
.243 .391 .59 r
.33876 .76084 m .34795 .75068 L .32341 .7227 L p F P
0 g
s
.209 .337 .635 r
.34795 .75068 m .33876 .76084 L .36669 .78512 L p F P
0 g
s
.31316 .73446 m
.33876 .76084 L
s
.3318 .77138 m
.33876 .76084 L
s
.209 .337 .635 r
.36669 .78512 m .37467 .77663 L .34795 .75068 L p F P
0 g
s
.36059 .79395 m
.36669 .78512 L
s
.36669 .78512 m
.39655 .80695 L
s
.33876 .76084 m
.36669 .78512 L
s
.179 .024 .727 r
.61674 .81859 m .61003 .81395 L .58232 .83408 L p F P
0 g
s
.176 .043 .727 r
.57712 .83126 m .58232 .83408 L .61003 .81395 L p F P
0 g
s
.58232 .83408 m
.58687 .83714 L
s
.55428 .85093 m
.58232 .83408 L
s
.633 .395 .052 r
.71156 .40477 m .67998 .39311 L .68054 .42273 L p F P
0 g
s
.633 .395 .052 r
.68054 .42273 m .71222 .43425 L .71156 .40477 L p F P
0 g
s
.70868 .378 m
.71156 .40477 L
s
.71156 .40477 m
.74047 .41842 L
s
.271 .558 .419 r
.28225 .6623 m .29725 .64828 L .28202 .61553 L p F P
0 g
s
.251 .515 .482 r
.29725 .64828 m .28225 .6623 L .30141 .69309 L p F P
0 g
s
.26618 .63078 m
.28225 .6623 L
s
.27031 .67699 m
.28225 .6623 L
s
.237 .652 .281 r
.26989 .58267 m .28974 .56732 L .28145 .53398 L p F P
0 g
s
.226 .621 .352 r
.28974 .56732 m .26989 .58267 L .28202 .61553 L p F P
0 g
s
.25339 .59899 m
.26989 .58267 L
s
.26099 .55018 m
.26989 .58267 L
s
.614 .086 .419 r
.77924 .62334 m .76185 .60851 L .74711 .64183 L p F P
0 g
s
.614 .086 .419 r
.74711 .64183 m .76355 .65546 L .77924 .62334 L p F P
0 g
s
.77924 .62334 m
.79173 .59104 L
s
.77924 .62334 m
.79339 .63899 L
s
.111 .23 .704 r
.41124 .79372 m .40317 .80015 L .43304 .82094 L p F P
0 g
s
.111 .23 .704 r
.43304 .82094 m .43924 .81614 L .41124 .79372 L p F P
0 g
s
.42791 .82602 m
.43304 .82094 L
s
.43304 .82094 m
.46382 .83869 L
s
.043 .176 .727 r
.45464 .80763 m .44647 .81169 L .47293 .83258 L p F P
0 g
s
.043 .176 .727 r
.47293 .83258 m .47844 .82992 L .45464 .80763 L p F P
0 g
s
.46804 .83552 m
.47293 .83258 L
s
.47293 .83258 m
.49968 .85019 L
s
.538 .519 .026 r
.64428 .3569 m .60923 .34982 L .61056 .37655 L p F P
0 g
s
.538 .519 .026 r
.61056 .37655 m .64616 .38364 L .64428 .3569 L p F P
0 g
s
.64102 .33345 m
.64428 .3569 L
s
.64428 .3569 m
.67758 .36635 L
s
.676 .246 .206 r
.76516 .494 m .73938 .47919 L .73487 .5124 L p F P
0 g
s
.676 .246 .206 r
.73487 .5124 m .76015 .52663 L .76516 .494 L p F P
0 g
s
.76516 .494 m
.76722 .46293 L
s
.76516 .494 m
.78766 .51025 L
s
.328 .011 .673 r
.64575 .79701 m .65308 .80364 L .68233 .78099 L p F P
0 g
s
.256 .008 .704 r
.65308 .80364 m .64575 .79701 L .61674 .81859 L p F P
0 g
s
.62239 .82354 m
.65308 .80364 L
s
.65308 .80364 m
.65892 .8106 L
s
.46 .015 .59 r
.73486 .72874 m .72339 .71724 L .69948 .74597 L p F P
0 g
s
.46 .015 .59 r
.69948 .74597 m .70973 .7559 L .73486 .72874 L p F P
0 g
s
.73486 .72874 m
.75737 .69992 L
s
.73486 .72874 m
.74379 .74074 L
s
.662 .323 .13 r
.74123 .44773 m .71222 .43425 L .71061 .46606 L p F P
0 g
s
.662 .323 .13 r
.71061 .46606 m .73938 .47919 L .74123 .44773 L p F P
0 g
s
.74047 .41842 m
.74123 .44773 L
s
.74123 .44773 m
.76722 .46293 L
s
.176 .043 .727 r
.61003 .81395 m .60234 .80968 L .57712 .83126 L p F P
0 g
s
.17 .061 .727 r
.57134 .82874 m .57712 .83126 L .60234 .80968 L p F P
0 g
s
.57712 .83126 m
.58232 .83408 L
s
.55166 .84954 m
.57712 .83126 L
s
.254 .035 .704 r
.61003 .81395 m .61674 .81859 L .64575 .79701 L p F P
0 g
s
.58687 .83714 m
.61674 .81859 L
s
.61674 .81859 m
.62239 .82354 L
s
.396 .013 .635 r
.67347 .77269 m .68233 .78099 L .70973 .7559 L p F P
0 g
s
.328 .011 .673 r
.68233 .78099 m .67347 .77269 L .64575 .79701 L p F P
0 g
s
.68233 .78099 m
.68934 .78967 L
s
.65308 .80364 m
.68233 .78099 L
s
.396 .013 .635 r
.70973 .7559 m .69948 .74597 L .67347 .77269 L p F P
0 g
s
.68233 .78099 m
.70973 .7559 L
s
.70973 .7559 m
.73486 .72874 L
s
.70973 .7559 m
.71777 .76627 L
s
.024 .179 .727 r
.46367 .80403 m .45464 .80763 L .47844 .82992 L p F P
0 g
s
.024 .179 .727 r
.47844 .82992 m .4845 .82755 L .46367 .80403 L p F P
0 g
s
.47293 .83258 m
.47844 .82992 L
s
.47844 .82992 m
.50245 .84888 L
s
.206 .719 .026 r
.46211 .34712 m .42636 .35292 L .42476 .37966 L p F P
0 g
s
.13 .736 .026 r
.38995 .38791 m .42476 .37966 L .42636 .35292 L p F P
0 g
s
.42636 .35292 m
.42913 .32953 L
s
.39209 .36116 m
.42636 .35292 L
s
.251 .515 .482 r
.30141 .69309 m .31538 .68043 L .29725 .64828 L p F P
0 g
s
.227 .467 .539 r
.31538 .68043 m .30141 .69309 L .32341 .7227 L p F P
0 g
s
.28225 .6623 m
.30141 .69309 L
s
.29024 .70637 m
.30141 .69309 L
s
.052 .745 .052 r
.38995 .38791 m .35716 .39846 L .35655 .42801 L p F P
0 g
s
.026 .746 .052 r
.3261 .4405 m .35655 .42801 L .35716 .39846 L p F P
0 g
s
.32681 .4111 m
.35716 .39846 L
s
.35716 .39846 m
.35979 .37169 L
s
.17 .061 .727 r
.60234 .80968 m .59375 .80584 L .57134 .82874 L p F P
0 g
s
.163 .079 .727 r
.56503 .82652 m .57134 .82874 L .59375 .80584 L p F P
0 g
s
.57134 .82874 m
.57712 .83126 L
s
.54875 .8483 m
.57134 .82874 L
s
.174 .698 .206 r
.28145 .53398 m .30522 .51905 L .30046 .48612 L p F P
0 g
s
.167 .673 .281 r
.30522 .51905 m .28145 .53398 L .28974 .56732 L p F P
0 g
s
.26099 .55018 m
.28145 .53398 L
s
.27623 .50166 m
.28145 .53398 L
s
.143 .295 .673 r
.38446 .76857 m .37467 .77663 L .40317 .80015 L p F P
0 g
s
.143 .295 .673 r
.40317 .80015 m .41124 .79372 L .38446 .76857 L p F P
0 g
s
.39655 .80695 m
.40317 .80015 L
s
.40317 .80015 m
.43304 .82094 L
s
.087 .241 .704 r
.42069 .78774 m .41124 .79372 L .43924 .81614 L p F P
0 g
s
.087 .241 .704 r
.43924 .81614 m .44647 .81169 L .42069 .78774 L p F P
0 g
s
.43304 .82094 m
.43924 .81614 L
s
.43924 .81614 m
.46804 .83552 L
s
.005 .181 .727 r
.47345 .80092 m .46367 .80403 L .4845 .82755 L p F P
0 g
s
.005 .181 .727 r
.4845 .82755 m .49106 .82551 L .47345 .80092 L p F P
0 g
s
.47844 .82992 m
.4845 .82755 L
s
.4845 .82755 m
.50549 .84771 L
s
.568 .079 .482 r
.76355 .65546 m .74711 .64183 L .72957 .67461 L p F P
0 g
s
.568 .079 .482 r
.72957 .67461 m .74485 .68691 L .76355 .65546 L p F P
0 g
s
.76355 .65546 m
.77924 .62334 L
s
.76355 .65546 m
.77697 .66985 L
s
.481 .573 .026 r
.60923 .34982 m .57295 .34523 L .57369 .37196 L p F P
0 g
s
.481 .573 .026 r
.57369 .37196 m .61056 .37655 L .60923 .34982 L p F P
0 g
s
.60693 .32647 m
.60923 .34982 L
s
.60923 .34982 m
.64428 .3569 L
s
.641 .159 .352 r
.7736 .57515 m .75219 .56036 L .74137 .5947 L p F P
0 g
s
.641 .159 .352 r
.74137 .5947 m .76185 .60851 L .7736 .57515 L p F P
0 g
s
.7736 .57515 m
.78223 .54224 L
s
.7736 .57515 m
.79173 .59104 L
s
.163 .079 .727 r
.59375 .80584 m .58435 .80247 L .56503 .82652 L p F P
0 g
s
.154 .095 .727 r
.55827 .82465 m .56503 .82652 L .58435 .80247 L p F P
0 g
s
.56503 .82652 m
.57134 .82874 L
s
.5456 .84721 m
.56503 .82652 L
s
.226 .621 .352 r
.28202 .61553 m .30103 .6012 L .28974 .56732 L p F P
0 g
s
.212 .583 .419 r
.30103 .6012 m .28202 .61553 L .29725 .64828 L p F P
0 g
s
.26989 .58267 m
.28202 .61553 L
s
.26618 .63078 m
.28202 .61553 L
s
.227 .467 .539 r
.32341 .7227 m .33616 .7115 L .31538 .68043 L p F P
0 g
s
.201 .414 .59 r
.33616 .7115 m .32341 .7227 L .34795 .75068 L p F P
0 g
s
.30141 .69309 m
.32341 .7227 L
s
.31316 .73446 m
.32341 .7227 L
s
.173 .357 .635 r
.35931 .74103 m .34795 .75068 L .37467 .77663 L p F P
0 g
s
.173 .357 .635 r
.37467 .77663 m .38446 .76857 L .35931 .74103 L p F P
0 g
s
.36669 .78512 m
.37467 .77663 L
s
.37467 .77663 m
.40317 .80015 L
s
.026 .736 .13 r
.35655 .42801 m .3261 .4405 L .32783 .47215 L p F P
0 g
s
.102 .73 .13 r
.30046 .48612 m .32783 .47215 L .3261 .4405 L p F P
0 g
s
.3261 .4405 m
.32681 .4111 L
s
.2985 .45484 m
.3261 .4405 L
s
.1 .712 .206 r
.32783 .47215 m .30046 .48612 L .30522 .51905 L p F P
0 g
s
.27623 .50166 m
.30046 .48612 L
s
.2985 .45484 m
.30046 .48612 L
s
.254 .035 .704 r
.64575 .79701 m .63701 .79078 L .61003 .81395 L p F P
0 g
s
.249 .061 .704 r
.60234 .80968 m .61003 .81395 L .63701 .79078 L p F P
0 g
s
.61003 .81395 m
.61674 .81859 L
s
.58232 .83408 m
.61003 .81395 L
s
.325 .045 .673 r
.63701 .79078 m .64575 .79701 L .67347 .77269 L p F P
0 g
s
.61674 .81859 m
.64575 .79701 L
s
.64575 .79701 m
.65308 .80364 L
s
.014 .181 .727 r
.48386 .79835 m .47345 .80092 L .49106 .82551 L p F P
0 g
s
.014 .181 .727 r
.49106 .82551 m .49802 .82383 L .48386 .79835 L p F P
0 g
s
.4845 .82755 m
.49106 .82551 L
s
.49106 .82551 m
.50876 .84671 L
s
.201 .414 .59 r
.34795 .75068 m .35931 .74103 L .33616 .7115 L p F P
0 g
s
.34795 .75068 m
.37467 .77663 L
s
.32341 .7227 m
.34795 .75068 L
s
.33876 .76084 m
.34795 .75068 L
s
.28 .693 .026 r
.49883 .34387 m .46211 .34712 L .46108 .37385 L p F P
0 g
s
.206 .719 .026 r
.42476 .37966 m .46108 .37385 L .46211 .34712 L p F P
0 g
s
.46211 .34712 m
.4639 .32382 L
s
.42636 .35292 m
.46211 .34712 L
s
.588 .459 .052 r
.67998 .39311 m .64616 .38364 L .64659 .41338 L p F P
0 g
s
.588 .459 .052 r
.64659 .41338 m .68054 .42273 L .67998 .39311 L p F P
0 g
s
.67758 .36635 m
.67998 .39311 L
s
.67998 .39311 m
.71156 .40477 L
s
.154 .095 .727 r
.58435 .80247 m .57425 .79961 L .55827 .82465 L p F P
0 g
s
.143 .111 .727 r
.55114 .82315 m .55827 .82465 L .57425 .79961 L p F P
0 g
s
.55827 .82465 m
.56503 .82652 L
s
.54222 .84629 m
.55827 .82465 L
s
.032 .178 .727 r
.4948 .79635 m .48386 .79835 L .49802 .82383 L p F P
0 g
s
.032 .178 .727 r
.49802 .82383 m .50532 .82252 L .4948 .79635 L p F P
0 g
s
.49106 .82551 m
.49802 .82383 L
s
.49802 .82383 m
.51224 .84589 L
s
.418 .62 .026 r
.57295 .34523 m .53596 .34324 L .53612 .36996 L p F P
0 g
s
.418 .62 .026 r
.53612 .36996 m .57369 .37196 L .57295 .34523 L p F P
0 g
s
.57165 .32196 m
.57295 .34523 L
s
.57295 .34523 m
.60923 .34982 L
s
.061 .249 .704 r
.43141 .78228 m .42069 .78774 L .44647 .81169 L p F P
0 g
s
.061 .249 .704 r
.44647 .81169 m .45464 .80763 L .43141 .78228 L p F P
0 g
s
.43924 .81614 m
.44647 .81169 L
s
.44647 .81169 m
.47293 .83258 L
s
.515 .072 .539 r
.74485 .68691 m .72957 .67461 L .70947 .70637 L p F P
0 g
s
.515 .072 .539 r
.70947 .70637 m .72339 .71724 L .74485 .68691 L p F P
0 g
s
.74485 .68691 m
.76355 .65546 L
s
.74485 .68691 m
.75737 .69992 L
s
.143 .111 .727 r
.57425 .79961 m .56357 .79732 L .55114 .82315 L p F P
0 g
s
.131 .125 .727 r
.54371 .82203 m .55114 .82315 L .56357 .79732 L p F P
0 g
s
.55114 .82315 m
.55827 .82465 L
s
.53866 .84556 m
.55114 .82315 L
s
.351 .66 .026 r
.53596 .34324 m .49883 .34387 L .49839 .37059 L p F P
0 g
s
.28 .693 .026 r
.46108 .37385 m .49839 .37059 L .49883 .34387 L p F P
0 g
s
.49883 .34387 m
.49959 .32062 L
s
.46211 .34712 m
.49883 .34387 L
s
.652 .237 .281 r
.76015 .52663 m .73487 .5124 L .72772 .54688 L p F P
0 g
s
.652 .237 .281 r
.72772 .54688 m .75219 .56036 L .76015 .52663 L p F P
0 g
s
.76015 .52663 m
.76516 .494 L
s
.76015 .52663 m
.78223 .54224 L
s
.051 .174 .727 r
.50611 .79496 m .4948 .79635 L .50532 .82252 L p F P
0 g
s
.051 .174 .727 r
.50532 .82252 m .51286 .8216 L .50611 .79496 L p F P
0 g
s
.49802 .82383 m
.50532 .82252 L
s
.50532 .82252 m
.51587 .84525 L
s
.111 .308 .673 r
.39598 .76106 m .38446 .76857 L .41124 .79372 L p F P
0 g
s
.111 .308 .673 r
.41124 .79372 m .42069 .78774 L .39598 .76106 L p F P
0 g
s
.40317 .80015 m
.41124 .79372 L
s
.41124 .79372 m
.43924 .81614 L
s
.393 .054 .635 r
.66284 .76488 m .67347 .77269 L .69948 .74597 L p F P
0 g
s
.325 .045 .673 r
.67347 .77269 m .66284 .76488 L .63701 .79078 L p F P
0 g
s
.64575 .79701 m
.67347 .77269 L
s
.67347 .77269 m
.68233 .78099 L
s
.351 .66 .026 r
.49839 .37059 m .53612 .36996 L .53596 .34324 L p F P
0 g
s
.49883 .34387 m
.53596 .34324 L
s
.53569 .32 m
.53596 .34324 L
s
.53596 .34324 m
.57295 .34523 L
s
.131 .125 .727 r
.56357 .79732 m .55243 .79561 L .54371 .82203 L p F P
0 g
s
.117 .138 .727 r
.53608 .82131 m .54371 .82203 L .55243 .79561 L p F P
0 g
s
.54371 .82203 m
.55114 .82315 L
s
.53496 .84501 m
.54371 .82203 L
s
.249 .061 .704 r
.63701 .79078 m .62694 .78504 L .60234 .80968 L p F P
0 g
s
.241 .087 .704 r
.59375 .80584 m .60234 .80968 L .62694 .78504 L p F P
0 g
s
.60234 .80968 m
.61003 .81395 L
s
.57712 .83126 m
.60234 .80968 L
s
.069 .167 .727 r
.51768 .79418 m .50611 .79496 L .51286 .8216 L p F P
0 g
s
.069 .167 .727 r
.51286 .8216 m .52056 .82109 L .51768 .79418 L p F P
0 g
s
.50532 .82252 m
.51286 .8216 L
s
.51286 .8216 m
.51963 .8448 L
s
.117 .138 .727 r
.55243 .79561 m .54098 .7945 L .53608 .82131 L p F P
0 g
s
.102 .15 .727 r
.52833 .821 m .53608 .82131 L .54098 .7945 L p F P
0 g
s
.53608 .82131 m
.54371 .82203 L
s
.53117 .84466 m
.53608 .82131 L
s
.456 .063 .59 r
.72339 .71724 m .70947 .70637 L .68712 .73661 L p F P
0 g
s
.456 .063 .59 r
.68712 .73661 m .69948 .74597 L .72339 .71724 L p F P
0 g
s
.72339 .71724 m
.74485 .68691 L
s
.72339 .71724 m
.73486 .72874 L
s
.212 .583 .419 r
.29725 .64828 m .31519 .63512 L .30103 .6012 L p F P
0 g
s
.195 .539 .482 r
.31519 .63512 m .29725 .64828 L .31538 .68043 L p F P
0 g
s
.28202 .61553 m
.29725 .64828 L
s
.28225 .6623 m
.29725 .64828 L
s
.086 .159 .727 r
.52935 .79402 m .51768 .79418 L .52056 .82109 L p F P
0 g
s
.086 .159 .727 r
.52056 .82109 m .52833 .821 L .52935 .79402 L p F P
0 g
s
.51286 .8216 m
.52056 .82109 L
s
.52056 .82109 m
.52346 .84455 L
s
.625 .39 .13 r
.71222 .43425 m .68054 .42273 L .67919 .45485 L p F P
0 g
s
.625 .39 .13 r
.67919 .45485 m .71061 .46606 L .71222 .43425 L p F P
0 g
s
.71156 .40477 m
.71222 .43425 L
s
.71222 .43425 m
.74123 .44773 L
s
.13 .735 .052 r
.42476 .37966 m .38995 .38791 L .38946 .4176 L p F P
0 g
s
.052 .745 .052 r
.35655 .42801 m .38946 .4176 L .38995 .38791 L p F P
0 g
s
.38995 .38791 m
.39209 .36116 L
s
.35716 .39846 m
.38995 .38791 L
s
.102 .15 .727 r
.54098 .7945 m .52935 .79402 L .52833 .821 L p F P
0 g
s
.52056 .82109 m
.52833 .821 L
s
.52732 .8445 m
.52833 .821 L
s
.52833 .821 m
.53608 .82131 L
s
.393 .054 .635 r
.69948 .74597 m .68712 .73661 L .66284 .76488 L p F P
0 g
s
.69948 .74597 m
.70973 .7559 L
s
.67347 .77269 m
.69948 .74597 L
s
.69948 .74597 m
.72339 .71724 L
s
.167 .673 .281 r
.28974 .56732 m .31277 .55319 L .30522 .51905 L p F P
0 g
s
.159 .641 .352 r
.31277 .55319 m .28974 .56732 L .30103 .6012 L p F P
0 g
s
.26989 .58267 m
.28974 .56732 L
s
.28145 .53398 m
.28974 .56732 L
s
.647 .315 .206 r
.73938 .47919 m .71061 .46606 L .70668 .49979 L p F P
0 g
s
.647 .315 .206 r
.70668 .49979 m .73487 .5124 L .73938 .47919 L p F P
0 g
s
.73938 .47919 m
.74123 .44773 L
s
.73938 .47919 m
.76516 .494 L
s
.602 .15 .419 r
.76185 .60851 m .74137 .5947 L .72781 .62916 L p F P
0 g
s
.602 .15 .419 r
.72781 .62916 m .74711 .64183 L .76185 .60851 L p F P
0 g
s
.76185 .60851 m
.7736 .57515 L
s
.76185 .60851 m
.77924 .62334 L
s
.035 .254 .704 r
.4433 .77742 m .43141 .78228 L .45464 .80763 L p F P
0 g
s
.035 .254 .704 r
.45464 .80763 m .46367 .80403 L .4433 .77742 L p F P
0 g
s
.44647 .81169 m
.45464 .80763 L
s
.45464 .80763 m
.47844 .82992 L
s
.318 .079 .673 r
.62694 .78504 m .63701 .79078 L .66284 .76488 L p F P
0 g
s
.61003 .81395 m
.63701 .79078 L
s
.63701 .79078 m
.64575 .79701 L
s
.135 .373 .635 r
.37273 .73201 m .35931 .74103 L .38446 .76857 L p F P
0 g
s
.135 .373 .635 r
.38446 .76857 m .39598 .76106 L .37273 .73201 L p F P
0 g
s
.37467 .77663 m
.38446 .76857 L
s
.38446 .76857 m
.41124 .79372 L
s
.241 .087 .704 r
.62694 .78504 m .61564 .77986 L .59375 .80584 L p F P
0 g
s
.23 .111 .704 r
.58435 .80247 m .59375 .80584 L .61564 .77986 L p F P
0 g
s
.59375 .80584 m
.60234 .80968 L
s
.57134 .82874 m
.59375 .80584 L
s
.537 .518 .052 r
.64616 .38364 m .61056 .37655 L .61087 .40637 L p F P
0 g
s
.537 .518 .052 r
.61087 .40637 m .64659 .41338 L .64616 .38364 L p F P
0 g
s
.64428 .3569 m
.64616 .38364 L
s
.64616 .38364 m
.67998 .39311 L
s
.195 .539 .482 r
.31538 .68043 m .33203 .66857 L .31519 .63512 L p F P
0 g
s
.177 .489 .539 r
.33203 .66857 m .31538 .68043 L .33616 .7115 L p F P
0 g
s
.29725 .64828 m
.31538 .68043 L
s
.30141 .69309 m
.31538 .68043 L
s
.079 .318 .673 r
.40911 .7542 m .39598 .76106 L .42069 .78774 L p F P
0 g
s
.079 .318 .673 r
.42069 .78774 m .43141 .78228 L .40911 .7542 L p F P
0 g
s
.41124 .79372 m
.42069 .78774 L
s
.42069 .78774 m
.44647 .81169 L
s
.1 .712 .206 r
.30522 .51905 m .33205 .50564 L .32783 .47215 L p F P
0 g
s
.096 .687 .281 r
.33205 .50564 m .30522 .51905 L .31277 .55319 L p F P
0 g
s
.28145 .53398 m
.30522 .51905 L
s
.30046 .48612 m
.30522 .51905 L
s
.052 .735 .13 r
.38946 .4176 m .35655 .42801 L .35803 .45999 L p F P
0 g
s
.026 .736 .13 r
.32783 .47215 m .35803 .45999 L .35655 .42801 L p F P
0 g
s
.3261 .4405 m
.35655 .42801 L
s
.35655 .42801 m
.35716 .39846 L
s
.157 .433 .59 r
.3513 .70103 m .33616 .7115 L .35931 .74103 L p F P
0 g
s
.157 .433 .59 r
.35931 .74103 m .37273 .73201 L .3513 .70103 L p F P
0 g
s
.34795 .75068 m
.35931 .74103 L
s
.35931 .74103 m
.38446 .76857 L
s
.008 .256 .704 r
.45621 .77323 m .4433 .77742 L .46367 .80403 L p F P
0 g
s
.008 .256 .704 r
.46367 .80403 m .47345 .80092 L .45621 .77323 L p F P
0 g
s
.45464 .80763 m
.46367 .80403 L
s
.46367 .80403 m
.4845 .82755 L
s
.177 .489 .539 r
.33616 .7115 m .3513 .70103 L .33203 .66857 L p F P
0 g
s
.33616 .7115 m
.35931 .74103 L
s
.31538 .68043 m
.33616 .7115 L
s
.32341 .7227 m
.33616 .7115 L
s
.556 .138 .482 r
.74711 .64183 m .72781 .62916 L .71169 .6632 L p F P
0 g
s
.556 .138 .482 r
.71169 .6632 m .72957 .67461 L .74711 .64183 L p F P
0 g
s
.74711 .64183 m
.76185 .60851 L
s
.74711 .64183 m
.76355 .65546 L
s
.385 .095 .635 r
.65053 .75767 m .66284 .76488 L .68712 .73661 L p F P
0 g
s
.318 .079 .673 r
.66284 .76488 m .65053 .75767 L .62694 .78504 L p F P
0 g
s
.63701 .79078 m
.66284 .76488 L
s
.66284 .76488 m
.67347 .77269 L
s
.025 .719 .206 r
.35803 .45999 m .32783 .47215 L .33205 .50564 L p F P
0 g
s
.3261 .4405 m
.32783 .47215 L
s
.30046 .48612 m
.32783 .47215 L
s
.206 .717 .052 r
.46108 .37385 m .42476 .37966 L .42439 .40944 L p F P
0 g
s
.13 .735 .052 r
.38946 .4176 m .42439 .40944 L .42476 .37966 L p F P
0 g
s
.42476 .37966 m
.42636 .35292 L
s
.38995 .38791 m
.42476 .37966 L
s
.621 .226 .352 r
.75219 .56036 m .72772 .54688 L .718 .58214 L p F P
0 g
s
.621 .226 .352 r
.718 .58214 m .74137 .5947 L .75219 .56036 L p F P
0 g
s
.75219 .56036 m
.76015 .52663 L
s
.75219 .56036 m
.7736 .57515 L
s
.23 .111 .704 r
.61564 .77986 m .60324 .77532 L .58435 .80247 L p F P
0 g
s
.217 .135 .704 r
.57425 .79961 m .58435 .80247 L .60324 .77532 L p F P
0 g
s
.58435 .80247 m
.59375 .80584 L
s
.56503 .82652 m
.58435 .80247 L
s
.159 .641 .352 r
.30103 .6012 m .32304 .58802 L .31277 .55319 L p F P
0 g
s
.15 .602 .419 r
.32304 .58802 m .30103 .6012 L .31519 .63512 L p F P
0 g
s
.28974 .56732 m
.30103 .6012 L
s
.28202 .61553 m
.30103 .6012 L
s
.308 .111 .673 r
.61564 .77986 m .62694 .78504 L .65053 .75767 L p F P
0 g
s
.60234 .80968 m
.62694 .78504 L
s
.62694 .78504 m
.63701 .79078 L
s
.019 .255 .704 r
.46999 .76975 m .45621 .77323 L .47345 .80092 L p F P
0 g
s
.019 .255 .704 r
.47345 .80092 m .48386 .79835 L .46999 .76975 L p F P
0 g
s
.46367 .80403 m
.47345 .80092 L
s
.47345 .80092 m
.49106 .82551 L
s
.48 .572 .052 r
.61056 .37655 m .57369 .37196 L .57387 .40184 L p F P
0 g
s
.48 .572 .052 r
.57387 .40184 m .61087 .40637 L .61056 .37655 L p F P
0 g
s
.60923 .34982 m
.61056 .37655 L
s
.61056 .37655 m
.64616 .38364 L
s
.504 .125 .539 r
.72957 .67461 m .71169 .6632 L .69324 .69629 L p F P
0 g
s
.504 .125 .539 r
.69324 .69629 m .70947 .70637 L .72957 .67461 L p F P
0 g
s
.72957 .67461 m
.74711 .64183 L
s
.72957 .67461 m
.74485 .68691 L
s
.581 .454 .13 r
.68054 .42273 m .64659 .41338 L .64554 .44574 L p F P
0 g
s
.581 .454 .13 r
.64554 .44574 m .67919 .45485 L .68054 .42273 L p F P
0 g
s
.67998 .39311 m
.68054 .42273 L
s
.68054 .42273 m
.71222 .43425 L
s
.447 .111 .59 r
.67274 .72794 m .68712 .73661 L .70947 .70637 L p F P
0 g
s
.385 .095 .635 r
.68712 .73661 m .67274 .72794 L .65053 .75767 L p F P
0 g
s
.68712 .73661 m
.69948 .74597 L
s
.66284 .76488 m
.68712 .73661 L
s
.217 .135 .704 r
.60324 .77532 m .5899 .77146 L .57425 .79961 L p F P
0 g
s
.202 .157 .704 r
.56357 .79732 m .57425 .79961 L .5899 .77146 L p F P
0 g
s
.57425 .79961 m
.58435 .80247 L
s
.55827 .82465 m
.57425 .79961 L
s
.447 .111 .59 r
.70947 .70637 m .69324 .69629 L .67274 .72794 L p F P
0 g
s
.68712 .73661 m
.70947 .70637 L
s
.70947 .70637 m
.72957 .67461 L
s
.70947 .70637 m
.72339 .71724 L
s
.045 .325 .673 r
.42371 .74807 m .40911 .7542 L .43141 .78228 L p F P
0 g
s
.045 .325 .673 r
.43141 .78228 m .4433 .77742 L .42371 .74807 L p F P
0 g
s
.42069 .78774 m
.43141 .78228 L
s
.43141 .78228 m
.45464 .80763 L
s
.095 .385 .635 r
.38809 .72376 m .37273 .73201 L .39598 .76106 L p F P
0 g
s
.095 .385 .635 r
.39598 .76106 m .40911 .7542 L .38809 .72376 L p F P
0 g
s
.38446 .76857 m
.39598 .76106 L
s
.39598 .76106 m
.42069 .78774 L
s
.624 .304 .281 r
.73487 .5124 m .70668 .49979 L .70045 .53495 L p F P
0 g
s
.624 .304 .281 r
.70045 .53495 m .72772 .54688 L .73487 .5124 L p F P
0 g
s
.73487 .5124 m
.73938 .47919 L
s
.73487 .5124 m
.76015 .52663 L
s
.045 .252 .704 r
.48447 .76705 m .46999 .76975 L .48386 .79835 L p F P
0 g
s
.045 .252 .704 r
.48386 .79835 m .4948 .79635 L .48447 .76705 L p F P
0 g
s
.47345 .80092 m
.48386 .79835 L
s
.48386 .79835 m
.49802 .82383 L
s
.28 .692 .052 r
.49839 .37059 m .46108 .37385 L .46084 .40371 L p F P
0 g
s
.206 .717 .052 r
.42439 .40944 m .46084 .40371 L .46108 .37385 L p F P
0 g
s
.46108 .37385 m
.46211 .34712 L
s
.42476 .37966 m
.46108 .37385 L
s
.61 .381 .206 r
.71061 .46606 m .67919 .45485 L .67591 .48902 L p F P
0 g
s
.61 .381 .206 r
.67591 .48902 m .70668 .49979 L .71061 .46606 L p F P
0 g
s
.71061 .46606 m
.71222 .43425 L
s
.71061 .46606 m
.73938 .47919 L
s
.202 .157 .704 r
.5899 .77146 m .57575 .76835 L .56357 .79732 L p F P
0 g
s
.185 .177 .704 r
.55243 .79561 m .56357 .79732 L .57575 .76835 L p F P
0 g
s
.56357 .79732 m
.57425 .79961 L
s
.55114 .82315 m
.56357 .79732 L
s
.15 .602 .419 r
.31519 .63512 m .33591 .62303 L .32304 .58802 L p F P
0 g
s
.138 .556 .482 r
.33591 .62303 m .31519 .63512 L .33203 .66857 L p F P
0 g
s
.30103 .6012 m
.31519 .63512 L
s
.29725 .64828 m
.31519 .63512 L
s
.417 .619 .052 r
.57369 .37196 m .53612 .36996 L .53615 .39987 L p F P
0 g
s
.417 .619 .052 r
.53615 .39987 m .57387 .40184 L .57369 .37196 L p F P
0 g
s
.57295 .34523 m
.57369 .37196 L
s
.57369 .37196 m
.61056 .37655 L
s
.308 .111 .673 r
.65053 .75767 m .63667 .75115 L .61564 .77986 L p F P
0 g
s
.295 .143 .673 r
.60324 .77532 m .61564 .77986 L .63667 .75115 L p F P
0 g
s
.61564 .77986 m
.62694 .78504 L
s
.59375 .80584 m
.61564 .77986 L
s
.071 .246 .704 r
.49949 .76516 m .48447 .76705 L .4948 .79635 L p F P
0 g
s
.071 .246 .704 r
.4948 .79635 m .50611 .79496 L .49949 .76516 L p F P
0 g
s
.48386 .79835 m
.4948 .79635 L
s
.4948 .79635 m
.50532 .82252 L
s
.096 .687 .281 r
.31277 .55319 m .33873 .54049 L .33205 .50564 L p F P
0 g
s
.092 .654 .352 r
.33873 .54049 m .31277 .55319 L .32304 .58802 L p F P
0 g
s
.28974 .56732 m
.31277 .55319 L
s
.30522 .51905 m
.31277 .55319 L
s
.583 .212 .419 r
.74137 .5947 m .718 .58214 L .70582 .61764 L p F P
0 g
s
.583 .212 .419 r
.70582 .61764 m .72781 .62916 L .74137 .5947 L p F P
0 g
s
.74137 .5947 m
.75219 .56036 L
s
.74137 .5947 m
.76185 .60851 L
s
.128 .726 .13 r
.42439 .40944 m .38946 .4176 L .39066 .44985 L p F P
0 g
s
.052 .735 .13 r
.35803 .45999 m .39066 .44985 L .38946 .4176 L p F P
0 g
s
.35655 .42801 m
.38946 .4176 L
s
.38946 .4176 m
.38995 .38791 L
s
.373 .135 .635 r
.63667 .75115 m .65053 .75767 L .67274 .72794 L p F P
0 g
s
.62694 .78504 m
.65053 .75767 L
s
.65053 .75767 m
.66284 .76488 L
s
.35 .659 .052 r
.53612 .36996 m .49839 .37059 L .49829 .40049 L p F P
0 g
s
.28 .692 .052 r
.46084 .40371 m .49829 .40049 L .49839 .37059 L p F P
0 g
s
.49839 .37059 m
.49883 .34387 L
s
.46108 .37385 m
.49839 .37059 L
s
.185 .177 .704 r
.57575 .76835 m .56099 .76604 L .55243 .79561 L p F P
0 g
s
.165 .195 .704 r
.54098 .7945 m .55243 .79561 L .56099 .76604 L p F P
0 g
s
.55243 .79561 m
.56357 .79732 L
s
.54371 .82203 m
.55243 .79561 L
s
.111 .447 .59 r
.36868 .69142 m .3513 .70103 L .37273 .73201 L p F P
0 g
s
.111 .447 .59 r
.37273 .73201 m .38809 .72376 L .36868 .69142 L p F P
0 g
s
.35931 .74103 m
.37273 .73201 L
s
.37273 .73201 m
.39598 .76106 L
s
.35 .659 .052 r
.49829 .40049 m .53615 .39987 L .53612 .36996 L p F P
0 g
s
.49839 .37059 m
.53612 .36996 L
s
.53596 .34324 m
.53612 .36996 L
s
.53612 .36996 m
.57369 .37196 L
s
.097 .237 .704 r
.51484 .7641 m .49949 .76516 L .50611 .79496 L p F P
0 g
s
.097 .237 .704 r
.50611 .79496 m .51768 .79418 L .51484 .7641 L p F P
0 g
s
.4948 .79635 m
.50611 .79496 L
s
.50611 .79496 m
.51286 .8216 L
s
.138 .556 .482 r
.33203 .66857 m .3512 .65767 L .33591 .62303 L p F P
0 g
s
.125 .504 .539 r
.3512 .65767 m .33203 .66857 L .3513 .70103 L p F P
0 g
s
.31519 .63512 m
.33203 .66857 L
s
.31538 .68043 m
.33203 .66857 L
s
.165 .195 .704 r
.56099 .76604 m .54579 .76454 L .54098 .7945 L p F P
0 g
s
.144 .212 .704 r
.52935 .79402 m .54098 .7945 L .54579 .76454 L p F P
0 g
s
.54098 .7945 m
.55243 .79561 L
s
.53608 .82131 m
.54098 .7945 L
s
.011 .328 .673 r
.4396 .74278 m .42371 .74807 L .4433 .77742 L p F P
0 g
s
.011 .328 .673 r
.4433 .77742 m .45621 .77323 L .4396 .74278 L p F P
0 g
s
.43141 .78228 m
.4433 .77742 L
s
.4433 .77742 m
.46367 .80403 L
s
.121 .226 .704 r
.53034 .76389 m .51484 .7641 L .51768 .79418 L p F P
0 g
s
.121 .226 .704 r
.51768 .79418 m .52935 .79402 L .53034 .76389 L p F P
0 g
s
.50611 .79496 m
.51768 .79418 L
s
.51768 .79418 m
.52056 .82109 L
s
.125 .504 .539 r
.3513 .70103 m .36868 .69142 L .3512 .65767 L p F P
0 g
s
.33616 .7115 m
.3513 .70103 L
s
.3513 .70103 m
.37273 .73201 L
s
.33203 .66857 m
.3513 .70103 L
s
.144 .212 .704 r
.54579 .76454 m .53034 .76389 L .52935 .79402 L p F P
0 g
s
.51768 .79418 m
.52935 .79402 L
s
.52833 .821 m
.52935 .79402 L
s
.52935 .79402 m
.54098 .7945 L
s
.025 .719 .206 r
.33205 .50564 m .36163 .49396 L .35803 .45999 L p F P
0 g
s
.024 .693 .281 r
.36163 .49396 m .33205 .50564 L .33873 .54049 L p F P
0 g
s
.30522 .51905 m
.33205 .50564 L
s
.32783 .47215 m
.33205 .50564 L
s
.05 .717 .206 r
.39066 .44985 m .35803 .45999 L .36163 .49396 L p F P
0 g
s
.35655 .42801 m
.35803 .45999 L
s
.32783 .47215 m
.35803 .45999 L
s
.53 .512 .13 r
.64659 .41338 m .61087 .40637 L .61012 .43892 L p F P
0 g
s
.53 .512 .13 r
.61012 .43892 m .64554 .44574 L .64659 .41338 L p F P
0 g
s
.64616 .38364 m
.64659 .41338 L
s
.64659 .41338 m
.68054 .42273 L
s
.054 .393 .635 r
.40522 .71639 m .38809 .72376 L .40911 .7542 L p F P
0 g
s
.054 .393 .635 r
.40911 .7542 m .42371 .74807 L .40522 .71639 L p F P
0 g
s
.39598 .76106 m
.40911 .7542 L
s
.40911 .7542 m
.43141 .78228 L
s
.295 .143 .673 r
.63667 .75115 m .62143 .74542 L .60324 .77532 L p F P
0 g
s
.279 .173 .673 r
.5899 .77146 m .60324 .77532 L .62143 .74542 L p F P
0 g
s
.60324 .77532 m
.61564 .77986 L
s
.58435 .80247 m
.60324 .77532 L
s
.539 .195 .482 r
.72781 .62916 m .70582 .61764 L .69137 .65283 L p F P
0 g
s
.539 .195 .482 r
.69137 .65283 m .71169 .6632 L .72781 .62916 L p F P
0 g
s
.72781 .62916 m
.74137 .5947 L
s
.72781 .62916 m
.74711 .64183 L
s
.433 .157 .59 r
.65651 .7201 m .67274 .72794 L .69324 .69629 L p F P
0 g
s
.373 .135 .635 r
.67274 .72794 m .65651 .7201 L .63667 .75115 L p F P
0 g
s
.65053 .75767 m
.67274 .72794 L
s
.67274 .72794 m
.68712 .73661 L
s
.594 .289 .352 r
.72772 .54688 m .70045 .53495 L .69199 .57103 L p F P
0 g
s
.594 .289 .352 r
.69199 .57103 m .718 .58214 L .72772 .54688 L p F P
0 g
s
.72772 .54688 m
.73487 .5124 L
s
.72772 .54688 m
.75219 .56036 L
s
.092 .654 .352 r
.32304 .58802 m .34782 .57618 L .33873 .54049 L p F P
0 g
s
.086 .614 .419 r
.34782 .57618 m .32304 .58802 L .33591 .62303 L p F P
0 g
s
.31277 .55319 m
.32304 .58802 L
s
.30103 .6012 m
.32304 .58802 L
s
.024 .327 .673 r
.45661 .73839 m .4396 .74278 L .45621 .77323 L p F P
0 g
s
.024 .327 .673 r
.45621 .77323 m .46999 .76975 L .45661 .73839 L p F P
0 g
s
.4433 .77742 m
.45621 .77323 L
s
.45621 .77323 m
.47345 .80092 L
s
.489 .177 .539 r
.71169 .6632 m .69137 .65283 L .67484 .68716 L p F P
0 g
s
.489 .177 .539 r
.67484 .68716 m .69324 .69629 L .71169 .6632 L p F P
0 g
s
.71169 .6632 m
.72781 .62916 L
s
.71169 .6632 m
.72957 .67461 L
s
.433 .157 .59 r
.69324 .69629 m .67484 .68716 L .65651 .7201 L p F P
0 g
s
.69324 .69629 m
.70947 .70637 L
s
.67274 .72794 m
.69324 .69629 L
s
.69324 .69629 m
.71169 .6632 L
s
.203 .708 .13 r
.46084 .40371 m .42439 .40944 L .42529 .44191 L p F P
0 g
s
.128 .726 .13 r
.39066 .44985 m .42529 .44191 L .42439 .40944 L p F P
0 g
s
.42439 .40944 m
.42476 .37966 L
s
.38946 .4176 m
.42439 .40944 L
s
.357 .173 .635 r
.62143 .74542 m .63667 .75115 L .65651 .7201 L p F P
0 g
s
.63667 .75115 m
.65053 .75767 L
s
.61564 .77986 m
.63667 .75115 L
s
.567 .443 .206 r
.67919 .45485 m .64554 .44574 L .64297 .48029 L p F P
0 g
s
.567 .443 .206 r
.64297 .48029 m .67591 .48902 L .67919 .45485 L p F P
0 g
s
.67919 .45485 m
.68054 .42273 L
s
.67919 .45485 m
.71061 .46606 L
s
.279 .173 .673 r
.62143 .74542 m .60497 .74055 L .5899 .77146 L p F P
0 g
s
.259 .201 .673 r
.57575 .76835 m .5899 .77146 L .60497 .74055 L p F P
0 g
s
.5899 .77146 m
.60324 .77532 L
s
.57425 .79961 m
.5899 .77146 L
s
.588 .367 .281 r
.70668 .49979 m .67591 .48902 L .67071 .52477 L p F P
0 g
s
.588 .367 .281 r
.67071 .52477 m .70045 .53495 L .70668 .49979 L p F P
0 g
s
.70668 .49979 m
.71061 .46606 L
s
.70668 .49979 m
.73487 .5124 L
s
.063 .456 .59 r
.38812 .68283 m .36868 .69142 L .38809 .72376 L p F P
0 g
s
.063 .456 .59 r
.38809 .72376 m .40522 .71639 L .38812 .68283 L p F P
0 g
s
.37273 .73201 m
.38809 .72376 L
s
.38809 .72376 m
.40911 .7542 L
s
.474 .564 .13 r
.61087 .40637 m .57387 .40184 L .57345 .43451 L p F P
0 g
s
.474 .564 .13 r
.57345 .43451 m .61012 .43892 L .61087 .40637 L p F P
0 g
s
.61056 .37655 m
.61087 .40637 L
s
.61087 .40637 m
.64659 .41338 L
s
.058 .323 .673 r
.47452 .73498 m .45661 .73839 L .46999 .76975 L p F P
0 g
s
.058 .323 .673 r
.46999 .76975 m .48447 .76705 L .47452 .73498 L p F P
0 g
s
.45621 .77323 m
.46999 .76975 L
s
.46999 .76975 m
.48386 .79835 L
s
.086 .614 .419 r
.33591 .62303 m .3592 .61218 L .34782 .57618 L p F P
0 g
s
.079 .568 .482 r
.3592 .61218 m .33591 .62303 L .3512 .65767 L p F P
0 g
s
.32304 .58802 m
.33591 .62303 L
s
.31519 .63512 m
.33591 .62303 L
s
.013 .396 .635 r
.42391 .71001 m .40522 .71639 L .42371 .74807 L p F P
0 g
s
.013 .396 .635 r
.42371 .74807 m .4396 .74278 L .42391 .71001 L p F P
0 g
s
.40911 .7542 m
.42371 .74807 L
s
.42371 .74807 m
.4433 .77742 L
s
.024 .693 .281 r
.33873 .54049 m .36733 .52944 L .36163 .49396 L p F P
0 g
s
.023 .66 .352 r
.36733 .52944 m .33873 .54049 L .34782 .57618 L p F P
0 g
s
.31277 .55319 m
.33873 .54049 L
s
.33205 .50564 m
.33873 .54049 L
s
.259 .201 .673 r
.60497 .74055 m .58751 .73662 L .57575 .76835 L p F P
0 g
s
.236 .227 .673 r
.56099 .76604 m .57575 .76835 L .58751 .73662 L p F P
0 g
s
.57575 .76835 m
.5899 .77146 L
s
.56357 .79732 m
.57575 .76835 L
s
.558 .271 .419 r
.718 .58214 m .69199 .57103 L .6814 .60746 L p F P
0 g
s
.558 .271 .419 r
.6814 .60746 m .70582 .61764 L .718 .58214 L p F P
0 g
s
.718 .58214 m
.72772 .54688 L
s
.718 .58214 m
.74137 .5947 L
s
.072 .515 .539 r
.3727 .64791 m .3512 .65767 L .36868 .69142 L p F P
0 g
s
.072 .515 .539 r
.36868 .69142 m .38812 .68283 L .3727 .64791 L p F P
0 g
s
.3513 .70103 m
.36868 .69142 L
s
.36868 .69142 m
.38809 .72376 L
s
.276 .683 .13 r
.49829 .40049 m .46084 .40371 L .46142 .43632 L p F P
0 g
s
.203 .708 .13 r
.42529 .44191 m .46142 .43632 L .46084 .40371 L p F P
0 g
s
.46084 .40371 m
.46108 .37385 L
s
.42439 .40944 m
.46084 .40371 L
s
.079 .568 .482 r
.3512 .65767 m .3727 .64791 L .3592 .61218 L p F P
0 g
s
.3512 .65767 m
.36868 .69142 L
s
.33591 .62303 m
.3512 .65767 L
s
.33203 .66857 m
.3512 .65767 L
s
.125 .708 .206 r
.42529 .44191 m .39066 .44985 L .39358 .48422 L p F P
0 g
s
.05 .717 .206 r
.36163 .49396 m .39358 .48422 L .39066 .44985 L p F P
0 g
s
.38946 .4176 m
.39066 .44985 L
s
.35803 .45999 m
.39066 .44985 L
s
.414 .201 .59 r
.63861 .71319 m .65651 .7201 L .67484 .68716 L p F P
0 g
s
.357 .173 .635 r
.65651 .7201 m .63861 .71319 L .62143 .74542 L p F P
0 g
s
.63667 .75115 m
.65651 .7201 L
s
.65651 .7201 m
.67274 .72794 L
s
.091 .315 .673 r
.49309 .73258 m .47452 .73498 L .48447 .76705 L p F P
0 g
s
.091 .315 .673 r
.48447 .76705 m .49949 .76516 L .49309 .73258 L p F P
0 g
s
.46999 .76975 m
.48447 .76705 L
s
.48447 .76705 m
.4948 .79635 L
s
.337 .209 .635 r
.60497 .74055 m .62143 .74542 L .63861 .71319 L p F P
0 g
s
.62143 .74542 m
.63667 .75115 L
s
.60324 .77532 m
.62143 .74542 L
s
.412 .611 .13 r
.57387 .40184 m .53615 .39987 L .53606 .43259 L p F P
0 g
s
.412 .611 .13 r
.53606 .43259 m .57345 .43451 L .57387 .40184 L p F P
0 g
s
.57369 .37196 m
.57387 .40184 L
s
.57387 .40184 m
.61087 .40637 L
s
.049 .692 .281 r
.39358 .48422 m .36163 .49396 L .36733 .52944 L p F P
0 g
s
.33205 .50564 m
.36163 .49396 L
s
.35803 .45999 m
.36163 .49396 L
s
.236 .227 .673 r
.58751 .73662 m .56925 .73369 L .56099 .76604 L p F P
0 g
s
.211 .251 .673 r
.54579 .76454 m .56099 .76604 L .56925 .73369 L p F P
0 g
s
.56099 .76604 m
.57575 .76835 L
s
.55243 .79561 m
.56099 .76604 L
s
.346 .65 .13 r
.53615 .39987 m .49829 .40049 L .49853 .43319 L p F P
0 g
s
.276 .683 .13 r
.46142 .43632 m .49853 .43319 L .49829 .40049 L p F P
0 g
s
.49829 .40049 m
.49839 .37059 L
s
.46084 .40371 m
.49829 .40049 L
s
.124 .304 .673 r
.5121 .73124 m .49309 .73258 L .49949 .76516 L p F P
0 g
s
.124 .304 .673 r
.49949 .76516 m .51484 .7641 L .5121 .73124 L p F P
0 g
s
.48447 .76705 m
.49949 .76516 L
s
.49949 .76516 m
.50611 .79496 L
s
.346 .65 .13 r
.49853 .43319 m .53606 .43259 L .53615 .39987 L p F P
0 g
s
.49829 .40049 m
.53615 .39987 L
s
.53612 .36996 m
.53615 .39987 L
s
.53615 .39987 m
.57387 .40184 L
s
.515 .251 .482 r
.70582 .61764 m .6814 .60746 L .66884 .64367 L p F P
0 g
s
.515 .251 .482 r
.66884 .64367 m .69137 .65283 L .70582 .61764 L p F P
0 g
s
.70582 .61764 m
.718 .58214 L
s
.70582 .61764 m
.72781 .62916 L
s
.211 .251 .673 r
.56925 .73369 m .55043 .7318 L .54579 .76454 L p F P
0 g
s
.184 .271 .673 r
.53034 .76389 m .54579 .76454 L .55043 .7318 L p F P
0 g
s
.54579 .76454 m
.56099 .76604 L
s
.54098 .7945 m
.54579 .76454 L
s
.518 .499 .206 r
.64554 .44574 m .61012 .43892 L .60831 .47374 L p F P
0 g
s
.518 .499 .206 r
.60831 .47374 m .64297 .48029 L .64554 .44574 L p F P
0 g
s
.64554 .44574 m
.64659 .41338 L
s
.64554 .44574 m
.67919 .45485 L
s
.028 .395 .635 r
.44395 .70471 m .42391 .71001 L .4396 .74278 L p F P
0 g
s
.028 .395 .635 r
.4396 .74278 m .45661 .73839 L .44395 .70471 L p F P
0 g
s
.42371 .74807 m
.4396 .74278 L
s
.4396 .74278 m
.45621 .77323 L
s
.155 .289 .673 r
.5313 .73098 m .5121 .73124 L .51484 .7641 L p F P
0 g
s
.155 .289 .673 r
.51484 .7641 m .53034 .76389 L .5313 .73098 L p F P
0 g
s
.49949 .76516 m
.51484 .7641 L
s
.51484 .7641 m
.51768 .79418 L
s
.467 .227 .539 r
.6545 .6791 m .67484 .68716 L .69137 .65283 L p F P
0 g
s
.414 .201 .59 r
.67484 .68716 m .6545 .6791 L .63861 .71319 L p F P
0 g
s
.67484 .68716 m
.69324 .69629 L
s
.65651 .7201 m
.67484 .68716 L
s
.184 .271 .673 r
.55043 .7318 m .5313 .73098 L .53034 .76389 L p F P
0 g
s
.51484 .7641 m
.53034 .76389 L
s
.52935 .79402 m
.53034 .76389 L
s
.53034 .76389 m
.54579 .76454 L
s
.56 .35 .352 r
.70045 .53495 m .67071 .52477 L .66366 .56155 L p F P
0 g
s
.56 .35 .352 r
.66366 .56155 m .69199 .57103 L .70045 .53495 L p F P
0 g
s
.70045 .53495 m
.70668 .49979 L
s
.70045 .53495 m
.72772 .54688 L
s
.015 .46 .59 r
.40939 .67538 m .38812 .68283 L .40522 .71639 L p F P
0 g
s
.015 .46 .59 r
.40522 .71639 m .42391 .71001 L .40939 .67538 L p F P
0 g
s
.38809 .72376 m
.40522 .71639 L
s
.40522 .71639 m
.42371 .74807 L
s
.467 .227 .539 r
.69137 .65283 m .66884 .64367 L .6545 .6791 L p F P
0 g
s
.67484 .68716 m
.69137 .65283 L
s
.69137 .65283 m
.70582 .61764 L
s
.69137 .65283 m
.71169 .6632 L
s
.023 .66 .352 r
.34782 .57618 m .37508 .56589 L .36733 .52944 L p F P
0 g
s
.021 .62 .419 r
.37508 .56589 m .34782 .57618 L .3592 .61218 L p F P
0 g
s
.33873 .54049 m
.34782 .57618 L
s
.32304 .58802 m
.34782 .57618 L
s
.547 .427 .281 r
.67591 .48902 m .64297 .48029 L .6389 .51651 L p F P
0 g
s
.547 .427 .281 r
.6389 .51651 m .67071 .52477 L .67591 .48902 L p F P
0 g
s
.67591 .48902 m
.67919 .45485 L
s
.67591 .48902 m
.70668 .49979 L
s
.337 .209 .635 r
.63861 .71319 m .61923 .70732 L .60497 .74055 L p F P
0 g
s
.313 .243 .635 r
.58751 .73662 m .60497 .74055 L .61923 .70732 L p F P
0 g
s
.60497 .74055 m
.62143 .74542 L
s
.5899 .77146 m
.60497 .74055 L
s
.198 .691 .206 r
.46142 .43632 m .42529 .44191 L .42747 .47661 L p F P
0 g
s
.125 .708 .206 r
.39358 .48422 m .42747 .47661 L .42529 .44191 L p F P
0 g
s
.42439 .40944 m
.42529 .44191 L
s
.39066 .44985 m
.42529 .44191 L
s
.391 .243 .59 r
.61923 .70732 m .63861 .71319 L .6545 .6791 L p F P
0 g
s
.63861 .71319 m
.65651 .7201 L
s
.62143 .74542 m
.63861 .71319 L
s
.017 .519 .539 r
.39627 .63945 m .3727 .64791 L .38812 .68283 L p F P
0 g
s
.017 .519 .539 r
.38812 .68283 m .40939 .67538 L .39627 .63945 L p F P
0 g
s
.36868 .69142 m
.38812 .68283 L
s
.38812 .68283 m
.40522 .71639 L
s
.07 .39 .635 r
.46508 .70058 m .44395 .70471 L .45661 .73839 L p F P
0 g
s
.07 .39 .635 r
.45661 .73839 m .47452 .73498 L .46508 .70058 L p F P
0 g
s
.4396 .74278 m
.45661 .73839 L
s
.45661 .73839 m
.46999 .76975 L
s
.021 .62 .419 r
.3592 .61218 m .38477 .60276 L .37508 .56589 L p F P
0 g
s
.019 .573 .482 r
.38477 .60276 m .3592 .61218 L .3727 .64791 L p F P
0 g
s
.34782 .57618 m
.3592 .61218 L
s
.33591 .62303 m
.3592 .61218 L
s
.049 .692 .281 r
.36733 .52944 m .3982 .52023 L .39358 .48422 L p F P
0 g
s
.047 .659 .352 r
.3982 .52023 m .36733 .52944 L .37508 .56589 L p F P
0 g
s
.33873 .54049 m
.36733 .52944 L
s
.36163 .49396 m
.36733 .52944 L
s
.019 .573 .482 r
.3727 .64791 m .39627 .63945 L .38477 .60276 L p F P
0 g
s
.3512 .65767 m
.3727 .64791 L
s
.3727 .64791 m
.38812 .68283 L
s
.3592 .61218 m
.3727 .64791 L
s
.462 .551 .206 r
.61012 .43892 m .57345 .43451 L .57242 .4695 L p F P
0 g
s
.462 .551 .206 r
.57242 .4695 m .60831 .47374 L .61012 .43892 L p F P
0 g
s
.61012 .43892 m
.61087 .40637 L
s
.61012 .43892 m
.64554 .44574 L
s
.526 .328 .419 r
.69199 .57103 m .66366 .56155 L .65483 .59878 L p F P
0 g
s
.526 .328 .419 r
.65483 .59878 m .6814 .60746 L .69199 .57103 L p F P
0 g
s
.69199 .57103 m
.70045 .53495 L
s
.69199 .57103 m
.718 .58214 L
s
.121 .683 .281 r
.42747 .47661 m .39358 .48422 L .3982 .52023 L p F P
0 g
s
.39066 .44985 m
.39358 .48422 L
s
.36163 .49396 m
.39358 .48422 L
s
.313 .243 .635 r
.61923 .70732 m .59864 .70257 L .58751 .73662 L p F P
0 g
s
.286 .275 .635 r
.56925 .73369 m .58751 .73662 L .59864 .70257 L p F P
0 g
s
.58751 .73662 m
.60497 .74055 L
s
.57575 .76835 m
.58751 .73662 L
s
.033 .459 .59 r
.43222 .6692 m .40939 .67538 L .42391 .71001 L p F P
0 g
s
.033 .459 .59 r
.42391 .71001 m .44395 .70471 L .43222 .6692 L p F P
0 g
s
.40522 .71639 m
.42391 .71001 L
s
.42391 .71001 m
.4396 .74278 L
s
.11 .381 .635 r
.48703 .69768 m .46508 .70058 L .47452 .73498 L p F P
0 g
s
.11 .381 .635 r
.47452 .73498 m .49309 .73258 L .48703 .69768 L p F P
0 g
s
.45661 .73839 m
.47452 .73498 L
s
.47452 .73498 m
.48447 .76705 L
s
.27 .667 .206 r
.49853 .43319 m .46142 .43632 L .46283 .47125 L p F P
0 g
s
.198 .691 .206 r
.42747 .47661 m .46283 .47125 L .46142 .43632 L p F P
0 g
s
.46084 .40371 m
.46142 .43632 L
s
.42529 .44191 m
.46142 .43632 L
s
.441 .275 .539 r
.63244 .67224 m .6545 .6791 L .66884 .64367 L p F P
0 g
s
.391 .243 .59 r
.6545 .6791 m .63244 .67224 L .61923 .70732 L p F P
0 g
s
.63861 .71319 m
.6545 .6791 L
s
.6545 .6791 m
.67484 .68716 L
s
.486 .303 .482 r
.6814 .60746 m .65483 .59878 L .64437 .63587 L p F P
0 g
s
.486 .303 .482 r
.64437 .63587 m .66884 .64367 L .6814 .60746 L p F P
0 g
s
.6814 .60746 m
.69199 .57103 L
s
.6814 .60746 m
.70582 .61764 L
s
.286 .275 .635 r
.59864 .70257 m .57708 .69903 L .56925 .73369 L p F P
0 g
s
.255 .303 .635 r
.55043 .7318 m .56925 .73369 L .57708 .69903 L p F P
0 g
s
.56925 .73369 m
.58751 .73662 L
s
.56099 .76604 m
.56925 .73369 L
s
.402 .596 .206 r
.57345 .43451 m .53606 .43259 L .53585 .46766 L p F P
0 g
s
.402 .596 .206 r
.53585 .46766 m .57242 .4695 L .57345 .43451 L p F P
0 g
s
.57345 .43451 m
.57387 .40184 L
s
.57345 .43451 m
.61012 .43892 L
s
.521 .406 .352 r
.67071 .52477 m .6389 .51651 L .63337 .55386 L p F P
0 g
s
.521 .406 .352 r
.63337 .55386 m .66366 .56155 L .67071 .52477 L p F P
0 g
s
.67071 .52477 m
.67591 .48902 L
s
.67071 .52477 m
.70045 .53495 L
s
.499 .482 .281 r
.64297 .48029 m .60831 .47374 L .60543 .51032 L p F P
0 g
s
.499 .482 .281 r
.60543 .51032 m .6389 .51651 L .64297 .48029 L p F P
0 g
s
.64297 .48029 m
.64554 .44574 L
s
.64297 .48029 m
.67591 .48902 L
s
.363 .283 .59 r
.59864 .70257 m .61923 .70732 L .63244 .67224 L p F P
0 g
s
.60497 .74055 m
.61923 .70732 L
s
.61923 .70732 m
.63861 .71319 L
s
.441 .275 .539 r
.66884 .64367 m .64437 .63587 L .63244 .67224 L p F P
0 g
s
.66884 .64367 m
.69137 .65283 L
s
.6545 .6791 m
.66884 .64367 L
s
.66884 .64367 m
.6814 .60746 L
s
.149 .367 .635 r
.50951 .69606 m .48703 .69768 L .49309 .73258 L p F P
0 g
s
.149 .367 .635 r
.49309 .73258 m .5121 .73124 L .50951 .69606 L p F P
0 g
s
.47452 .73498 m
.49309 .73258 L
s
.49309 .73258 m
.49949 .76516 L
s
.338 .635 .206 r
.53606 .43259 m .49853 .43319 L .49914 .46825 L p F P
0 g
s
.27 .667 .206 r
.46283 .47125 m .49914 .46825 L .49853 .43319 L p F P
0 g
s
.49829 .40049 m
.49853 .43319 L
s
.46142 .43632 m
.49853 .43319 L
s
.047 .659 .352 r
.37508 .56589 m .40447 .55732 L .3982 .52023 L p F P
0 g
s
.044 .619 .419 r
.40447 .55732 m .37508 .56589 L .38477 .60276 L p F P
0 g
s
.36733 .52944 m
.37508 .56589 L
s
.34782 .57618 m
.37508 .56589 L
s
.338 .635 .206 r
.49914 .46825 m .53585 .46766 L .53606 .43259 L p F P
0 g
s
.49853 .43319 m
.53606 .43259 L
s
.53606 .43259 m
.53615 .39987 L
s
.53606 .43259 m
.57345 .43451 L
s
.255 .303 .635 r
.57708 .69903 m .55484 .69674 L .55043 .7318 L p F P
0 g
s
.222 .328 .635 r
.5313 .73098 m .55043 .7318 L .55484 .69674 L p F P
0 g
s
.55043 .7318 m
.56925 .73369 L
s
.54579 .76454 m
.55043 .7318 L
s
.037 .518 .539 r
.42162 .6324 m .39627 .63945 L .40939 .67538 L p F P
0 g
s
.037 .518 .539 r
.40939 .67538 m .43222 .6692 L .42162 .6324 L p F P
0 g
s
.38812 .68283 m
.40939 .67538 L
s
.40939 .67538 m
.42391 .71001 L
s
.187 .35 .635 r
.53221 .69575 m .50951 .69606 L .5121 .73124 L p F P
0 g
s
.187 .35 .635 r
.5121 .73124 m .5313 .73098 L .53221 .69575 L p F P
0 g
s
.49309 .73258 m
.5121 .73124 L
s
.5121 .73124 m
.51484 .7641 L
s
.222 .328 .635 r
.55484 .69674 m .53221 .69575 L .5313 .73098 L p F P
0 g
s
.5121 .73124 m
.5313 .73098 L
s
.53034 .76389 m
.5313 .73098 L
s
.5313 .73098 m
.55043 .7318 L
s
.081 .454 .59 r
.45634 .66437 m .43222 .6692 L .44395 .70471 L p F P
0 g
s
.081 .454 .59 r
.44395 .70471 m .46508 .70058 L .45634 .66437 L p F P
0 g
s
.42391 .71001 m
.44395 .70471 L
s
.44395 .70471 m
.45661 .73839 L
s
.192 .667 .281 r
.46283 .47125 m .42747 .47661 L .43093 .51303 L p F P
0 g
s
.121 .683 .281 r
.3982 .52023 m .43093 .51303 L .42747 .47661 L p F P
0 g
s
.42529 .44191 m
.42747 .47661 L
s
.39358 .48422 m
.42747 .47661 L
s
.044 .619 .419 r
.38477 .60276 m .41232 .59491 L .40447 .55732 L p F P
0 g
s
.041 .572 .482 r
.41232 .59491 m .38477 .60276 L .39627 .63945 L p F P
0 g
s
.37508 .56589 m
.38477 .60276 L
s
.3592 .61218 m
.38477 .60276 L
s
.115 .65 .352 r
.43093 .51303 m .3982 .52023 L .40447 .55732 L p F P
0 g
s
.36733 .52944 m
.3982 .52023 L
s
.39358 .48422 m
.3982 .52023 L
s
.041 .572 .482 r
.39627 .63945 m .42162 .6324 L .41232 .59491 L p F P
0 g
s
.3727 .64791 m
.39627 .63945 L
s
.39627 .63945 m
.40939 .67538 L
s
.38477 .60276 m
.39627 .63945 L
s
.363 .283 .59 r
.63244 .67224 m .60895 .6667 L .59864 .70257 L p F P
0 g
s
.332 .319 .59 r
.57708 .69903 m .59864 .70257 L .60895 .6667 L p F P
0 g
s
.59864 .70257 m
.61923 .70732 L
s
.58751 .73662 m
.59864 .70257 L
s
.489 .381 .419 r
.66366 .56155 m .63337 .55386 L .62646 .59174 L p F P
0 g
s
.489 .381 .419 r
.62646 .59174 m .65483 .59878 L .66366 .56155 L p F P
0 g
s
.66366 .56155 m
.67071 .52477 L
s
.66366 .56155 m
.69199 .57103 L
s
.41 .319 .539 r
.60895 .6667 m .63244 .67224 L .64437 .63587 L p F P
0 g
s
.63244 .67224 m
.6545 .6791 L
s
.61923 .70732 m
.63244 .67224 L
s
.446 .531 .281 r
.60831 .47374 m .57242 .4695 L .57081 .50632 L p F P
0 g
s
.446 .531 .281 r
.57081 .50632 m .60543 .51032 L .60831 .47374 L p F P
0 g
s
.60831 .47374 m
.61012 .43892 L
s
.60831 .47374 m
.64297 .48029 L
s
.128 .443 .59 r
.48141 .66098 m .45634 .66437 L .46508 .70058 L p F P
0 g
s
.128 .443 .59 r
.46508 .70058 m .48703 .69768 L .48141 .66098 L p F P
0 g
s
.44395 .70471 m
.46508 .70058 L
s
.46508 .70058 m
.47452 .73498 L
s
.475 .459 .352 r
.6389 .51651 m .60543 .51032 L .60154 .5481 L p F P
0 g
s
.475 .459 .352 r
.60154 .5481 m .63337 .55386 L .6389 .51651 L p F P
0 g
s
.6389 .51651 m
.64297 .48029 L
s
.6389 .51651 m
.67071 .52477 L
s
.452 .352 .482 r
.65483 .59878 m .62646 .59174 L .61828 .62956 L p F P
0 g
s
.452 .352 .482 r
.61828 .62956 m .64437 .63587 L .65483 .59878 L p F P
0 g
s
.65483 .59878 m
.66366 .56155 L
s
.65483 .59878 m
.6814 .60746 L
s
.41 .319 .539 r
.64437 .63587 m .61828 .62956 L .60895 .6667 L p F P
0 g
s
.63244 .67224 m
.64437 .63587 L
s
.64437 .63587 m
.66884 .64367 L
s
.64437 .63587 m
.65483 .59878 L
s
.26 .643 .281 r
.49914 .46825 m .46283 .47125 L .46506 .50797 L p F P
0 g
s
.192 .667 .281 r
.43093 .51303 m .46506 .50797 L .46283 .47125 L p F P
0 g
s
.46142 .43632 m
.46283 .47125 L
s
.42747 .47661 m
.46283 .47125 L
s
.091 .512 .539 r
.44843 .62691 m .42162 .6324 L .43222 .6692 L p F P
0 g
s
.091 .512 .539 r
.43222 .6692 m .45634 .66437 L .44843 .62691 L p F P
0 g
s
.40939 .67538 m
.43222 .6692 L
s
.43222 .6692 m
.44395 .70471 L
s
.332 .319 .59 r
.60895 .6667 m .58433 .66256 L .57708 .69903 L p F P
0 g
s
.297 .352 .59 r
.55484 .69674 m .57708 .69903 L .58433 .66256 L p F P
0 g
s
.57708 .69903 m
.59864 .70257 L
s
.56925 .73369 m
.57708 .69903 L
s
.115 .65 .352 r
.40447 .55732 m .43562 .55062 L .43093 .51303 L p F P
0 g
s
.108 .611 .419 r
.43562 .55062 m .40447 .55732 L .41232 .59491 L p F P
0 g
s
.3982 .52023 m
.40447 .55732 L
s
.37508 .56589 m
.40447 .55732 L
s
.388 .575 .281 r
.57242 .4695 m .53585 .46766 L .53552 .50458 L p F P
0 g
s
.388 .575 .281 r
.53552 .50458 m .57081 .50632 L .57242 .4695 L p F P
0 g
s
.57242 .4695 m
.57345 .43451 L
s
.57242 .4695 m
.60831 .47374 L
s
.173 .427 .59 r
.5071 .65909 m .48141 .66098 L .48703 .69768 L p F P
0 g
s
.173 .427 .59 r
.48703 .69768 m .50951 .69606 L .5071 .65909 L p F P
0 g
s
.46508 .70058 m
.48703 .69768 L
s
.48703 .69768 m
.49309 .73258 L
s
.182 .635 .352 r
.46506 .50797 m .43093 .51303 L .43562 .55062 L p F P
0 g
s
.42747 .47661 m
.43093 .51303 L
s
.3982 .52023 m
.43093 .51303 L
s
.326 .612 .281 r
.53585 .46766 m .49914 .46825 L .50009 .50513 L p F P
0 g
s
.26 .643 .281 r
.46506 .50797 m .50009 .50513 L .49914 .46825 L p F P
0 g
s
.49853 .43319 m
.49914 .46825 L
s
.46283 .47125 m
.49914 .46825 L
s
.374 .361 .539 r
.58433 .66256 m .60895 .6667 L .61828 .62956 L p F P
0 g
s
.59864 .70257 m
.60895 .6667 L
s
.60895 .6667 m
.63244 .67224 L
s
.297 .352 .59 r
.58433 .66256 m .55892 .65988 L .55484 .69674 L p F P
0 g
s
.258 .381 .59 r
.53221 .69575 m .55484 .69674 L .55892 .65988 L p F P
0 g
s
.55484 .69674 m
.57708 .69903 L
s
.55043 .7318 m
.55484 .69674 L
s
.326 .612 .281 r
.50009 .50513 m .53552 .50458 L .53585 .46766 L p F P
0 g
s
.49914 .46825 m
.53585 .46766 L
s
.53585 .46766 m
.53606 .43259 L
s
.53585 .46766 m
.57242 .4695 L
s
.1 .564 .482 r
.44148 .58878 m .41232 .59491 L .42162 .6324 L p F P
0 g
s
.1 .564 .482 r
.42162 .6324 m .44843 .62691 L .44148 .58878 L p F P
0 g
s
.39627 .63945 m
.42162 .6324 L
s
.42162 .6324 m
.43222 .6692 L
s
.108 .611 .419 r
.41232 .59491 m .44148 .58878 L .43562 .55062 L p F P
0 g
s
.41232 .59491 m
.42162 .6324 L
s
.40447 .55732 m
.41232 .59491 L
s
.38477 .60276 m
.41232 .59491 L
s
.217 .406 .59 r
.53306 .65872 m .5071 .65909 L .50951 .69606 L p F P
0 g
s
.217 .406 .59 r
.50951 .69606 m .53221 .69575 L .53306 .65872 L p F P
0 g
s
.48703 .69768 m
.50951 .69606 L
s
.50951 .69606 m
.5121 .73124 L
s
.258 .381 .59 r
.55892 .65988 m .53306 .65872 L .53221 .69575 L p F P
0 g
s
.50951 .69606 m
.53221 .69575 L
s
.5313 .73098 m
.53221 .69575 L
s
.53221 .69575 m
.55484 .69674 L
s
.447 .431 .419 r
.63337 .55386 m .60154 .5481 L .59667 .58648 L p F P
0 g
s
.447 .431 .419 r
.59667 .58648 m .62646 .59174 L .63337 .55386 L p F P
0 g
s
.63337 .55386 m
.6389 .51651 L
s
.63337 .55386 m
.66366 .56155 L
s
.425 .506 .352 r
.60543 .51032 m .57081 .50632 L .56861 .54438 L p F P
0 g
s
.425 .506 .352 r
.56861 .54438 m .60154 .5481 L .60543 .51032 L p F P
0 g
s
.60543 .51032 m
.60831 .47374 L
s
.60543 .51032 m
.6389 .51651 L
s
.144 .499 .539 r
.47632 .62304 m .44843 .62691 L .45634 .66437 L p F P
0 g
s
.144 .499 .539 r
.45634 .66437 m .48141 .66098 L .47632 .62304 L p F P
0 g
s
.43222 .6692 m
.45634 .66437 L
s
.45634 .66437 m
.46508 .70058 L
s
.413 .398 .482 r
.5909 .62484 m .61828 .62956 L .62646 .59174 L p F P
0 g
s
.374 .361 .539 r
.61828 .62956 m .5909 .62484 L .58433 .66256 L p F P
0 g
s
.60895 .6667 m
.61828 .62956 L
s
.61828 .62956 m
.64437 .63587 L
s
.413 .398 .482 r
.62646 .59174 m .59667 .58648 L .5909 .62484 L p F P
0 g
s
.61828 .62956 m
.62646 .59174 L
s
.62646 .59174 m
.63337 .55386 L
s
.62646 .59174 m
.65483 .59878 L
s
.335 .398 .539 r
.55892 .65988 m .58433 .66256 L .5909 .62484 L p F P
0 g
s
.57708 .69903 m
.58433 .66256 L
s
.58433 .66256 m
.60895 .6667 L
s
.248 .612 .352 r
.50009 .50513 m .46506 .50797 L .46808 .54591 L p F P
0 g
s
.182 .635 .352 r
.43562 .55062 m .46808 .54591 L .46506 .50797 L p F P
0 g
s
.46283 .47125 m
.46506 .50797 L
s
.43093 .51303 m
.46506 .50797 L
s
.171 .596 .419 r
.46808 .54591 m .43562 .55062 L .44148 .58878 L p F P
0 g
s
.40447 .55732 m
.43562 .55062 L
s
.43093 .51303 m
.43562 .55062 L
s
.195 .482 .539 r
.50492 .62088 m .47632 .62304 L .48141 .66098 L p F P
0 g
s
.195 .482 .539 r
.48141 .66098 m .5071 .65909 L .50492 .62088 L p F P
0 g
s
.45634 .66437 m
.48141 .66098 L
s
.48141 .66098 m
.48703 .69768 L
s
.159 .551 .482 r
.47185 .58448 m .44148 .58878 L .44843 .62691 L p F P
0 g
s
.159 .551 .482 r
.44843 .62691 m .47632 .62304 L .47185 .58448 L p F P
0 g
s
.42162 .6324 m
.44843 .62691 L
s
.44843 .62691 m
.45634 .66437 L
s
.37 .547 .352 r
.57081 .50632 m .53552 .50458 L .53506 .54276 L p F P
0 g
s
.37 .547 .352 r
.53506 .54276 m .56861 .54438 L .57081 .50632 L p F P
0 g
s
.57081 .50632 m
.57242 .4695 L
s
.57081 .50632 m
.60543 .51032 L
s
.171 .596 .419 r
.44148 .58878 m .47185 .58448 L .46808 .54591 L p F P
0 g
s
.44148 .58878 m
.44843 .62691 L
s
.43562 .55062 m
.44148 .58878 L
s
.41232 .59491 m
.44148 .58878 L
s
.335 .398 .539 r
.5909 .62484 m .56262 .62179 L .55892 .65988 L p F P
0 g
s
.291 .431 .539 r
.53306 .65872 m .55892 .65988 L .56262 .62179 L p F P
0 g
s
.55892 .65988 m
.58433 .66256 L
s
.55484 .69674 m
.55892 .65988 L
s
.399 .475 .419 r
.60154 .5481 m .56861 .54438 L .56587 .58308 L p F P
0 g
s
.399 .475 .419 r
.56587 .58308 m .59667 .58648 L .60154 .5481 L p F P
0 g
s
.60154 .5481 m
.60543 .51032 L
s
.60154 .5481 m
.63337 .55386 L
s
.311 .583 .352 r
.53552 .50458 m .50009 .50513 L .50139 .54327 L p F P
0 g
s
.248 .612 .352 r
.46808 .54591 m .50139 .54327 L .50009 .50513 L p F P
0 g
s
.49914 .46825 m
.50009 .50513 L
s
.46506 .50797 m
.50009 .50513 L
s
.311 .583 .352 r
.50139 .54327 m .53506 .54276 L .53552 .50458 L p F P
0 g
s
.50009 .50513 m
.53552 .50458 L
s
.53552 .50458 m
.53585 .46766 L
s
.53552 .50458 m
.57081 .50632 L
s
.245 .459 .539 r
.53382 .62046 m .50492 .62088 L .5071 .65909 L p F P
0 g
s
.245 .459 .539 r
.5071 .65909 m .53306 .65872 L .53382 .62046 L p F P
0 g
s
.48141 .66098 m
.5071 .65909 L
s
.5071 .65909 m
.50951 .69606 L
s
.369 .439 .482 r
.56262 .62179 m .5909 .62484 L .59667 .58648 L p F P
0 g
s
.58433 .66256 m
.5909 .62484 L
s
.5909 .62484 m
.61828 .62956 L
s
.291 .431 .539 r
.56262 .62179 m .53382 .62046 L .53306 .65872 L p F P
0 g
s
.5071 .65909 m
.53306 .65872 L
s
.53221 .69575 m
.53306 .65872 L
s
.53306 .65872 m
.55892 .65988 L
s
.369 .439 .482 r
.59667 .58648 m .56587 .58308 L .56262 .62179 L p F P
0 g
s
.59667 .58648 m
.60154 .5481 L
s
.59667 .58648 m
.62646 .59174 L
s
.5909 .62484 m
.59667 .58648 L
s
.233 .575 .419 r
.50139 .54327 m .46808 .54591 L .47185 .58448 L p F P
0 g
s
.46506 .50797 m
.46808 .54591 L
s
.43562 .55062 m
.46808 .54591 L
s
.215 .531 .482 r
.503 .58207 m .47185 .58448 L .47632 .62304 L p F P
0 g
s
.215 .531 .482 r
.47632 .62304 m .50492 .62088 L .503 .58207 L p F P
0 g
s
.44843 .62691 m
.47632 .62304 L
s
.47632 .62304 m
.48141 .66098 L
s
.347 .514 .419 r
.56861 .54438 m .53506 .54276 L .53449 .5816 L p F P
0 g
s
.347 .514 .419 r
.53449 .5816 m .56587 .58308 L .56861 .54438 L p F P
0 g
s
.56861 .54438 m
.57081 .50632 L
s
.56861 .54438 m
.60154 .5481 L
s
.233 .575 .419 r
.47185 .58448 m .503 .58207 L .50139 .54327 L p F P
0 g
s
.47185 .58448 m
.47632 .62304 L
s
.46808 .54591 m
.47185 .58448 L
s
.44148 .58878 m
.47185 .58448 L
s
.321 .475 .482 r
.53382 .62046 m .56262 .62179 L .56587 .58308 L p F P
0 g
s
.55892 .65988 m
.56262 .62179 L
s
.56262 .62179 m
.5909 .62484 L
s
.292 .547 .419 r
.53506 .54276 m .50139 .54327 L .503 .58207 L p F P
0 g
s
.46808 .54591 m
.50139 .54327 L
s
.50009 .50513 m
.50139 .54327 L
s
.27 .506 .482 r
.53449 .5816 m .503 .58207 L .50492 .62088 L p F P
0 g
s
.27 .506 .482 r
.50492 .62088 m .53382 .62046 L .53449 .5816 L p F P
0 g
s
.47632 .62304 m
.50492 .62088 L
s
.50492 .62088 m
.5071 .65909 L
s
.292 .547 .419 r
.503 .58207 m .53449 .5816 L .53506 .54276 L p F P
0 g
s
.503 .58207 m
.50492 .62088 L
s
.50139 .54327 m
.503 .58207 L
s
.47185 .58448 m
.503 .58207 L
s
.53506 .54276 m
.53552 .50458 L
s
.53506 .54276 m
.56861 .54438 L
s
.50139 .54327 m
.53506 .54276 L
s
.321 .475 .482 r
.56587 .58308 m .53449 .5816 L .53382 .62046 L p F P
0 g
s
.53449 .5816 m
.56587 .58308 L
s
.53449 .5816 m
.53506 .54276 L
s
.50492 .62088 m
.53382 .62046 L
s
.53306 .65872 m
.53382 .62046 L
s
.53382 .62046 m
.56262 .62179 L
s
.56587 .58308 m
.56861 .54438 L
s
.56587 .58308 m
.59667 .58648 L
s
.56262 .62179 m
.56587 .58308 L
s
.53382 .62046 m
.53449 .5816 L
s
.503 .58207 m
.53449 .5816 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{265.312, 287.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 264.312}, {286.938, 0}} -> {0.0486402, -4.72903, \
0.00324458, 0.00324458}}],

Cell[OutputFormData["\<\
Graphics3D[{{{RGBColor[0.02598896135221991, 0.0027315499082742945, \
0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[Pi/30]*Sin[Pi/30], Sin[Pi/30]^2, \
Cos[Pi/30]}, {Sin[Pi/30], 0, Cos[Pi/30]}}]}, 
   {RGBColor[0.02556106638841174, 0.005433172384139969, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[Pi/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[Pi/15], Cos[Pi/30]}, {Cos[Pi/30]*Sin[Pi/30], Sin[Pi/30]^2, 
       Cos[Pi/30]}}]}, {RGBColor[0.024853119032255105, 0.008075267886400592, \
0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[Pi/15]*Sin[Pi/30], Sin[Pi/30]*Sin[Pi/15], Cos[Pi/30]}}]}, \
{RGBColor[0.02387287570313157, 0.010628889063839363, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(2*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(2*Pi)/15], Cos[Pi/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.02263107615208411, 0.013066057908456682, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, \
Cos[Pi/30]}, {Cos[(2*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(2*Pi)/15], 
       Cos[Pi/30]}}]}, {RGBColor[0.021141325794857276, 0.01536007228838055, \
0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {((1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}}]}, \
{RGBColor[0.019419946648115135, 0.017485798502011148, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(7*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(7*Pi)/30], Cos[Pi/30]}, 
      {((1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.017485798502011148, 0.01941994664811513, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(4*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(4*Pi)/15], Cos[Pi/30]}, 
      {Cos[(7*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/30], Cos[Pi/30]}}]}, 
   {RGBColor[0.01536007228838055, 0.021141325794857276, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, ((1 \
+ Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(4*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(4*Pi)/15], Cos[Pi/30]}}]}, 
   {RGBColor[0.013066057908456682, 0.02263107615208411, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
       ((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}}]}, \
{RGBColor[0.010628889063839369, 0.02387287570313157, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(11*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(11*Pi)/30], Cos[Pi/30]}, 
      {Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}}]}, \
{RGBColor[0.008075267886400592, 0.024853119032255105, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(11*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/30], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.005433172384139967, 0.02556106638841174, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(13*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(13*Pi)/30], Cos[Pi/30]}, 
      {((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.0027315499082742945, 0.02598896135221991, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(7*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(7*Pi)/15], Cos[Pi/30]}, 
      {Cos[(13*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/30], \
Cos[Pi/30]}}]}, {RGBColor[0, 0.026132115816913364, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {0, Sin[Pi/30], Cos[Pi/30]}, \
{Cos[(7*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/15], Cos[Pi/30]}}]}, 
   {RGBColor[0.002731549908274291, 0.025988961352219914, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(8*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(8*Pi)/15], Cos[Pi/30]}, {0, Sin[Pi/30], Cos[Pi/30]}}]}, 
   {RGBColor[0.005433172384139964, 0.02556106638841174, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(17*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(17*Pi)/30], Cos[Pi/30]}, 
      {Cos[(8*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(8*Pi)/15], Cos[Pi/30]}}]}, 
   {RGBColor[0.008075267886400592, 0.024853119032255105, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {-((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(17*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/30], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.01062888906383936, 0.023872875703131572, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(19*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(19*Pi)/30], Cos[Pi/30]}, 
      {-((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.013066057908456682, 0.02263107615208411, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {Cos[(19*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/30], 
       Cos[Pi/30]}}]}, {RGBColor[0.01536007228838055, 0.021141325794857276, \
0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, \
((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {-Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}}]}, \
{RGBColor[0.01748579850201114, 0.019419946648115142, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(11*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(11*Pi)/15], Cos[Pi/30]}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.01941994664811514, 0.017485798502011145, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(23*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(23*Pi)/30], Cos[Pi/30]}, 
      {Cos[(11*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/15], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.021141325794857276, 0.01536007228838055, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-((1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(23*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/30], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.02263107615208411, 0.013066057908456682, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, \
Cos[Pi/30]}, {-((1 + Sqrt[5])*Sin[Pi/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}}]}, \
{RGBColor[0.023872875703131572, 0.01062888906383936, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(13*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(13*Pi)/15], Cos[Pi/30]}, 
      {-(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}}]}, \
{RGBColor[0.024853119032255105, 0.008075267886400592, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(13*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/15], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.02556106638841174, 0.005433172384139969, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(14*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(14*Pi)/15], Cos[Pi/30]}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.02598896135221991, 0.002731549908274302, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(29*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(29*Pi)/30], Cos[Pi/30]}, 
      {Cos[(14*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(14*Pi)/15], \
Cos[Pi/30]}}]}, {RGBColor[0.026132115816913364, 0, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-Sin[Pi/30], 0, Cos[Pi/30]}, \
{Cos[(29*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/30], Cos[Pi/30]}}]}, 
   {RGBColor[0.02598896135221991, 0.0027315499082742954, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(31*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(31*Pi)/30], Cos[Pi/30]}, {-Sin[Pi/30], 0, Cos[Pi/30]}}]}, 
   {RGBColor[0.02556106638841174, 0.005433172384139963, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(16*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(16*Pi)/15], Cos[Pi/30]}, 
      {Cos[(31*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(31*Pi)/30], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.024853119032255105, 0.008075267886400592, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
-((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(16*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(16*Pi)/15], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.023872875703131572, 0.010628889063839355, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(17*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(17*Pi)/15], Cos[Pi/30]}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.02263107615208411, 0.013066057908456682, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, \
Cos[Pi/30]}, {Cos[(17*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/15], 
       Cos[Pi/30]}}]}, {RGBColor[0.021141325794857276, 0.01536007228838055, \
0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-((1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 \
- Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {-(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}}]}, \
{RGBColor[0.019419946648115135, 0.017485798502011148, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(37*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(37*Pi)/30], Cos[Pi/30]}, 
      {-((1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.017485798502011155, 0.01941994664811513, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(19*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(19*Pi)/15], Cos[Pi/30]}, 
      {Cos[(37*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(37*Pi)/30], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.01536007228838055, 0.021141325794857276, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, \
-((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(19*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/15], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.013066057908456682, 0.02263107615208411, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
       -((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}}]}, \
{RGBColor[0.010628889063839362, 0.023872875703131572, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(41*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(41*Pi)/30], Cos[Pi/30]}, 
      {-Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}}]}, \
{RGBColor[0.008075267886400592, 0.024853119032255105, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {-((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 \
+ Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(41*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(41*Pi)/30], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.005433172384139982, 0.02556106638841174, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(43*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(43*Pi)/30], Cos[Pi/30]}, 
      {-((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.002731549908274315, 0.02598896135221991, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(22*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(22*Pi)/15], Cos[Pi/30]}, 
      {Cos[(43*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(43*Pi)/30], \
Cos[Pi/30]}}]}, {RGBColor[0, 0.026132115816913364, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {0, -Sin[Pi/30], Cos[Pi/30]}, \
{Cos[(22*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(22*Pi)/15], Cos[Pi/30]}}]}, 
   {RGBColor[0.0027315499082743054, 0.02598896135221991, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(23*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(23*Pi)/15], Cos[Pi/30]}, {0, -Sin[Pi/30], Cos[Pi/30]}}]}, 
   {RGBColor[0.0054331723841399724, 0.02556106638841174, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(47*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(47*Pi)/30], Cos[Pi/30]}, 
      {Cos[(23*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/15], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.008075267886400592, 0.024853119032255105, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 \
+ Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(47*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(47*Pi)/30], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.010628889063839353, 0.023872875703131572, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(49*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(49*Pi)/30], Cos[Pi/30]}, 
      {((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.013066057908456682, 0.02263107615208411, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {Cos[(49*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(49*Pi)/30], 
       Cos[Pi/30]}}]}, {RGBColor[0.01536007228838055, 0.021141325794857276, \
0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, \
-((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}}]}, \
{RGBColor[0.017485798502011155, 0.01941994664811513, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(26*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(26*Pi)/15], Cos[Pi/30]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.01941994664811512, 0.017485798502011166, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(53*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(53*Pi)/30], Cos[Pi/30]}, 
      {Cos[(26*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(26*Pi)/15], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.021141325794857276, 0.01536007228838055, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {((1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(53*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(53*Pi)/30], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.02263107615208411, 0.013066057908456682, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, \
Cos[Pi/30]}, {((1 + Sqrt[5])*Sin[Pi/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}}]}, \
{RGBColor[0.023872875703131572, 0.010628889063839363, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(28*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(28*Pi)/15], Cos[Pi/30]}, 
      {(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}}]}, \
{RGBColor[0.024853119032255105, 0.008075267886400592, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
-((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(28*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(28*Pi)/15], \
Cos[Pi/30]}}]}, 
   {RGBColor[0.02556106638841174, 0.005433172384139984, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(29*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(29*Pi)/15], Cos[Pi/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}}]}, 
   {RGBColor[0.02598896135221991, 0.0027315499082743167, 0.7486304738420684], \

    Polygon[{{0, 0, 1}, {0, 0, 1}, {Cos[(59*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(59*Pi)/30], Cos[Pi/30]}, 
      {Cos[(29*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/15], \
Cos[Pi/30]}}]}, {RGBColor[0.026132115816913364, 0, 0.7486304738420684], 
    Polygon[{{0, 0, 1}, {0, 0, 1}, {Sin[Pi/30], 0, Cos[Pi/30]}, \
{Cos[(59*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(59*Pi)/30], Cos[Pi/30]}}]}, 
   {RGBColor[0.10381425937445837, 0.008164722292414264, 0.7417978478675881], 
    Polygon[{{Sin[Pi/30], 0, Cos[Pi/30]}, {Cos[Pi/30]*Sin[Pi/30], \
Sin[Pi/30]^2, Cos[Pi/30]}, {Cos[Pi/30]*Sin[Pi/15], Sin[Pi/30]*Sin[Pi/15], 
       Cos[Pi/15]}, {Sin[Pi/15], 0, Cos[Pi/15]}}]}, \
{RGBColor[0.10239210812510668, 0.01897154008708915, 0.7417978478675881], 
    Polygon[{{Cos[Pi/30]*Sin[Pi/30], Sin[Pi/30]^2, Cos[Pi/30]}, \
{Cos[Pi/15]*Sin[Pi/30], Sin[Pi/30]*Sin[Pi/15], Cos[Pi/30]}, 
      {Cos[Pi/15]*Sin[Pi/15], Sin[Pi/15]^2, Cos[Pi/15]}, \
{Cos[Pi/30]*Sin[Pi/15], Sin[Pi/30]*Sin[Pi/15], Cos[Pi/15]}}]}, 
   {RGBColor[0.09984812751221016, 0.0295705017185199, 0.7417978478675881], \
Polygon[{{Cos[Pi/15]*Sin[Pi/30], Sin[Pi/30]*Sin[Pi/15], Cos[Pi/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
       ((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {Cos[Pi/15]*Sin[Pi/15], \
Sin[Pi/15]^2, Cos[Pi/15]}}]}, 
   {RGBColor[0.0962101899197259, 0.03984548274509723, 0.7417978478675881], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(2*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(2*Pi)/15], Cos[Pi/30]}, \
{Cos[(2*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(2*Pi)/15], Cos[Pi/15]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, ((-1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.09151815335320451, 0.049683908324515955, 0.7417978478675881], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(2*Pi)/15], \
Cos[Pi/30]}, {(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}, 
      {(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, \
{Cos[(2*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(2*Pi)/15], Cos[Pi/15]}}]}, 
   {RGBColor[0.08582342474714064, 0.058977986607305063, 0.7417978478675881], 
    Polygon[{{(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}, {((1 + \
Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}}]}, 
   {RGBColor[0.07918839673984084, 0.06762588972688738, 0.7417978478675881], 
    Polygon[{{((1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(7*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/30], Cos[Pi/30]}, \
{Cos[(7*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/30], Cos[Pi/15]}, 
      {((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.07168576408662197, 0.0755328694469947, 0.7417978478675881], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/30], \
Cos[Pi/30]}, {Cos[(4*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(4*Pi)/15], 
       Cos[Pi/30]}, {Cos[(4*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(4*Pi)/15], \
Cos[Pi/15]}, {Cos[(7*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/30], 
       Cos[Pi/15]}}]}, {RGBColor[0.06339772720085952, 0.08261229524317165, \
0.7417978478675881], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(4*Pi)/15], \
Cos[Pi/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
       ((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(4*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(4*Pi)/15], Cos[Pi/15]}}]}, 
   {RGBColor[0.054415091549057146, 0.08878660344493022, 0.7417978478675881], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, \
Cos[Pi/30]}, 
      {Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}}]}, 
   {RGBColor[0.04483627276715334, 0.0939881470395549, 0.7417978478675881], 
    Polygon[{{Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, \
{Cos[(11*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/30], Cos[Pi/30]}, 
      {Cos[(11*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/30], Cos[Pi/15]}, \
{Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}}]}, 
   {RGBColor[0.0347662183982193, 0.09815993682692999, 0.7417978478675881], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/30], \
Cos[Pi/30]}, {((-1 + Sqrt[5])*Sin[Pi/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {((-1 + \
Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(11*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/30], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.02431525806521544, 0.10125626580514188, 0.7417978478675881], 
    Polygon[{{((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(13*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/30], Cos[Pi/30]}, \
{Cos[(13*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/30], Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.013597894676554232, 0.10324320994595676, 0.7417978478675881], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/30], \
Cos[Pi/30]}, {Cos[(7*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/15], 
       Cos[Pi/30]}, {Cos[(7*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/15], \
Cos[Pi/15]}, {Cos[(13*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/30], 
       Cos[Pi/15]}}]}, {RGBColor[0.0027315499082742945, 0.1040989998735731, \
0.7417978478675881], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/15], \
Cos[Pi/30]}, {0, Sin[Pi/30], Cos[Pi/30]}, {0, Sin[Pi/15], Cos[Pi/15]}, 
      {Cos[(7*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/15], Cos[Pi/15]}}]}, 
   {RGBColor[0.008164722292414254, 0.10381425937445839, 0.7417978478675881], 
    Polygon[{{0, Sin[Pi/30], Cos[Pi/30]}, {Cos[(8*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(8*Pi)/15], Cos[Pi/30]}, 
      {Cos[(8*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(8*Pi)/15], Cos[Pi/15]}, {0, \
Sin[Pi/15], Cos[Pi/15]}}]}, 
   {RGBColor[0.01897154008708913, 0.10239210812510668, 0.7417978478675881], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(8*Pi)/15], \
Cos[Pi/30]}, {Cos[(17*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/30], 
       Cos[Pi/30]}, {Cos[(17*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/30], \
Cos[Pi/15]}, {Cos[(8*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(8*Pi)/15], 
       Cos[Pi/15]}}]}, {RGBColor[0.029570501718519892, 0.09984812751221016, \
0.7417978478675881], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/30], \
Cos[Pi/30]}, {-((-1 + Sqrt[5])*Sin[Pi/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {-((-1 + \
Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(17*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/30], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.03984548274509722, 0.09621018991972591, 0.7417978478675881], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(19*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/30], Cos[Pi/30]}, \
{Cos[(19*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/30], Cos[Pi/15]}, 
      {-((-1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.049683908324515955, 0.09151815335320451, 0.7417978478675881], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/30], \
Cos[Pi/30]}, {-Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {-Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, \
{Cos[(19*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/30], Cos[Pi/15]}}]}, 
   {RGBColor[0.058977986607305063, 0.08582342474714064, 0.7417978478675881], 
    Polygon[{{-Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, {-(Sqrt[(5 \
- Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + Sqrt[5])*Sin[Pi/30])/4, 
       Cos[Pi/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {-Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}}]}, \
{RGBColor[0.06762588972688735, 0.07918839673984085, 0.7417978478675881], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(11*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/15], Cos[Pi/30]}, \
{Cos[(11*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/15], Cos[Pi/15]}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.07553286944699471, 0.07168576408662197, 0.7417978478675881], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/15], \
Cos[Pi/30]}, {Cos[(23*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/30], 
       Cos[Pi/30]}, {Cos[(23*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/30], \
Cos[Pi/15]}, {Cos[(11*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/15], 
       Cos[Pi/15]}}]}, {RGBColor[0.08261229524317167, 0.06339772720085952, \
0.7417978478675881], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/30], \
Cos[Pi/30]}, {-((1 + Sqrt[5])*Sin[Pi/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {-((1 + \
Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(23*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/30], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.08878660344493022, 0.054415091549057146, 0.7417978478675881], 
    Polygon[{{-((1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {-(Sqrt[3]*Sin[Pi/30])/2, \
Sin[Pi/30]/2, 
       Cos[Pi/30]}, {-(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, \
{-((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, 
       Cos[Pi/15]}}]}, {RGBColor[0.09398814703955491, 0.04483627276715331, \
0.7417978478675881], 
    Polygon[{{-(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}, \
{Cos[(13*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/15], Cos[Pi/30]}, 
      {Cos[(13*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/15], Cos[Pi/15]}, \
{-(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}}]}, 
   {RGBColor[0.09815993682692999, 0.03476621839821929, 0.7417978478675881], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/15], \
Cos[Pi/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
       ((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, ((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(13*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.10125626580514188, 0.02431525806521545, 0.7417978478675881], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(14*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(14*Pi)/15], Cos[Pi/30]}, \
{Cos[(14*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(14*Pi)/15], Cos[Pi/15]}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, ((-1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.10324320994595676, 0.013597894676554255, 0.7417978478675881], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(14*Pi)/15], \
Cos[Pi/30]}, {Cos[(29*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/30], 
       Cos[Pi/30]}, {Cos[(29*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/30], \
Cos[Pi/15]}, {Cos[(14*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(14*Pi)/15], 
       Cos[Pi/15]}}]}, {RGBColor[0.1040989998735731, 0.002731549908274302, \
0.7417978478675881], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/30], \
Cos[Pi/30]}, {-Sin[Pi/30], 0, Cos[Pi/30]}, {-Sin[Pi/15], 0, Cos[Pi/15]}, 
      {Cos[(29*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/30], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.10381425937445837, 0.008164722292414267, 0.7417978478675881], 
    Polygon[{{-Sin[Pi/30], 0, Cos[Pi/30]}, {Cos[(31*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(31*Pi)/30], Cos[Pi/30]}, 
      {Cos[(31*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(31*Pi)/30], Cos[Pi/15]}, \
{-Sin[Pi/15], 0, Cos[Pi/15]}}]}, 
   {RGBColor[0.10239210812510668, 0.01897154008708913, 0.7417978478675881], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(31*Pi)/30], \
Cos[Pi/30]}, {Cos[(16*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(16*Pi)/15], 
       Cos[Pi/30]}, {Cos[(16*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(16*Pi)/15], \
Cos[Pi/15]}, {Cos[(31*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(31*Pi)/30], 
       Cos[Pi/15]}}]}, {RGBColor[0.09984812751221016, 0.029570501718519892, \
0.7417978478675881], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(16*Pi)/15], \
Cos[Pi/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
       -((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(16*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(16*Pi)/15], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.09621018991972591, 0.03984548274509721, 0.7417978478675881], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(17*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/15], Cos[Pi/30]}, \
{Cos[(17*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/15], Cos[Pi/15]}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.09151815335320451, 0.04968390832451595, 0.7417978478675881], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/15], \
Cos[Pi/30]}, {-(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}, 
      {-(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, \
{Cos[(17*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/15], Cos[Pi/15]}}]}, 
   {RGBColor[0.08582342474714064, 0.058977986607305063, 0.7417978478675881], 
    Polygon[{{-(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}, {-((1 + \
Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
       Cos[Pi/30]}, {-((1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {-(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}}]}, \
{RGBColor[0.07918839673984084, 0.06762588972688738, 0.7417978478675881], 
    Polygon[{{-((1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(37*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(37*Pi)/30], Cos[Pi/30]}, \
{Cos[(37*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(37*Pi)/30], Cos[Pi/15]}, 
      {-((1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.07168576408662199, 0.0755328694469947, 0.7417978478675881], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(37*Pi)/30], \
Cos[Pi/30]}, {Cos[(19*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/15], 
       Cos[Pi/30]}, {Cos[(19*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/15], \
Cos[Pi/15]}, {Cos[(37*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(37*Pi)/30], 
       Cos[Pi/15]}}]}, {RGBColor[0.06339772720085954, 0.08261229524317165, \
0.7417978478675881], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/15], \
Cos[Pi/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
       -((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(19*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/15], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.054415091549057146, 0.08878660344493022, 0.7417978478675881], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {-Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, \

       Cos[Pi/30]}, {-Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + Sqrt[5])*Sin[Pi/15])/4, 
       Cos[Pi/15]}}]}, {RGBColor[0.04483627276715331, 0.09398814703955491, \
0.7417978478675881], 
    Polygon[{{-Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, \
{Cos[(41*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(41*Pi)/30], Cos[Pi/30]}, 
      {Cos[(41*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(41*Pi)/30], Cos[Pi/15]}, \
{-Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}}]}, 
   {RGBColor[0.03476621839821929, 0.09815993682692999, 0.7417978478675881], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(41*Pi)/30], \
Cos[Pi/30]}, {-((-1 + Sqrt[5])*Sin[Pi/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {-((-1 + \
Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(41*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(41*Pi)/30], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.024315258065215485, 0.10125626580514187, 0.7417978478675881], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(43*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(43*Pi)/30], Cos[Pi/30]}, \
{Cos[(43*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(43*Pi)/30], Cos[Pi/15]}, 
      {-((-1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.013597894676554307, 0.10324320994595676, 0.7417978478675881], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(43*Pi)/30], \
Cos[Pi/30]}, {Cos[(22*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(22*Pi)/15], 
       Cos[Pi/30]}, {Cos[(22*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(22*Pi)/15], \
Cos[Pi/15]}, {Cos[(43*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(43*Pi)/30], 
       Cos[Pi/15]}}]}, {RGBColor[0.002731549908274315, 0.1040989998735731, \
0.7417978478675881], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(22*Pi)/15], \
Cos[Pi/30]}, {0, -Sin[Pi/30], Cos[Pi/30]}, {0, -Sin[Pi/15], Cos[Pi/15]}, 
      {Cos[(22*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(22*Pi)/15], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.008164722292414297, 0.10381425937445837, 0.7417978478675881], 
    Polygon[{{0, -Sin[Pi/30], Cos[Pi/30]}, {Cos[(23*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(23*Pi)/15], Cos[Pi/30]}, 
      {Cos[(23*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/15], Cos[Pi/15]}, \
{0, -Sin[Pi/15], Cos[Pi/15]}}]}, 
   {RGBColor[0.01897154008708917, 0.10239210812510667, 0.7417978478675881], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/15], \
Cos[Pi/30]}, {Cos[(47*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(47*Pi)/30], 
       Cos[Pi/30]}, {Cos[(47*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(47*Pi)/30], \
Cos[Pi/15]}, {Cos[(23*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/15], 
       Cos[Pi/15]}}]}, {RGBColor[0.029570501718519902, 0.09984812751221016, \
0.7417978478675881], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(47*Pi)/30], \
Cos[Pi/30]}, {((-1 + Sqrt[5])*Sin[Pi/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {((-1 + \
Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(47*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(47*Pi)/30], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.039845482745097194, 0.09621018991972591, 0.7417978478675881], 
    Polygon[{{((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Cos[(49*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(49*Pi)/30], Cos[Pi/30]}, \
{Cos[(49*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(49*Pi)/30], Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.049683908324515955, 0.09151815335320451, 0.7417978478675881], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(49*Pi)/30], \
Cos[Pi/30]}, {Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, 
      {Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, \
{Cos[(49*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(49*Pi)/30], Cos[Pi/15]}}]}, 
   {RGBColor[0.058977986607305063, 0.08582342474714064, 0.7417978478675881], 
    Polygon[{{Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + Sqrt[5])*Sin[Pi/30])/4, 
       Cos[Pi/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}}]}, \
{RGBColor[0.0676258897268874, 0.07918839673984082, 0.7417978478675881], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(26*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(26*Pi)/15], Cos[Pi/30]}, \
{Cos[(26*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(26*Pi)/15], Cos[Pi/15]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.07553286944699467, 0.07168576408662201, 0.7417978478675881], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(26*Pi)/15], \
Cos[Pi/30]}, {Cos[(53*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(53*Pi)/30], 
       Cos[Pi/30]}, {Cos[(53*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(53*Pi)/30], \
Cos[Pi/15]}, {Cos[(26*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(26*Pi)/15], 
       Cos[Pi/15]}}]}, {RGBColor[0.08261229524317165, 0.06339772720085954, \
0.7417978478675881], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(53*Pi)/30], \
Cos[Pi/30]}, {((1 + Sqrt[5])*Sin[Pi/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {((1 + \
Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(53*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(53*Pi)/30], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.08878660344493022, 0.054415091549057146, 0.7417978478675881], 
    Polygon[{{((1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {(Sqrt[3]*Sin[Pi/30])/2, \
-Sin[Pi/30]/2, 
       Cos[Pi/30]}, {(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, {((1 \
+ Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, 
       Cos[Pi/15]}}]}, {RGBColor[0.09398814703955491, 0.044836272767153316, \
0.7417978478675881], 
    Polygon[{{(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}, \
{Cos[(28*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(28*Pi)/15], Cos[Pi/30]}, 
      {Cos[(28*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(28*Pi)/15], Cos[Pi/15]}, \
{(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}}]}, 
   {RGBColor[0.09815993682692999, 0.03476621839821929, 0.7417978478675881], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(28*Pi)/15], \
Cos[Pi/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
       -((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(28*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(28*Pi)/15], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.10125626580514187, 0.024315258065215492, 0.7417978478675881], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
      {Cos[(29*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/15], Cos[Pi/30]}, \
{Cos[(29*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/15], Cos[Pi/15]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}}]}, 
   {RGBColor[0.10324320994595676, 0.013597894676554314, 0.7417978478675881], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/15], \
Cos[Pi/30]}, {Cos[(59*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(59*Pi)/30], 
       Cos[Pi/30]}, {Cos[(59*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(59*Pi)/30], \
Cos[Pi/15]}, {Cos[(29*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/15], 
       Cos[Pi/15]}}]}, {RGBColor[0.1040989998735731, 0.0027315499082743167, \
0.7417978478675881], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(59*Pi)/30], \
Cos[Pi/30]}, {Sin[Pi/30], 0, Cos[Pi/30]}, {Sin[Pi/15], 0, Cos[Pi/15]}, 
      {Cos[(59*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(59*Pi)/30], \
Cos[Pi/15]}}]}, 
   {RGBColor[0.18050214664645986, 0.013508440270540562, 0.7268379294406913], 
    Polygon[{{Sin[Pi/15], 0, Cos[Pi/15]}, {Cos[Pi/30]*Sin[Pi/15], \
Sin[Pi/30]*Sin[Pi/15], Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 \
+ Sqrt[5])/2]/2}, {(-1 + Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.1781013204982568, 0.03230205162679419, 0.7268379294406913], \
Polygon[{{Cos[Pi/30]*Sin[Pi/15], Sin[Pi/30]*Sin[Pi/15], Cos[Pi/15]}, 
      {Cos[Pi/15]*Sin[Pi/15], Sin[Pi/15]^2, Cos[Pi/15]}, {((-1 + \
Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 \
+ Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17374917901257747, 0.0507417549457858, 0.7268379294406913], 
    Polygon[{{Cos[Pi/15]*Sin[Pi/15], Sin[Pi/15]^2, Cos[Pi/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, ((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, Sqrt[(5 \
+ Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[Pi/15])/4, 
       ((-1 + Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.16749340516228312, 0.0686255209791965, 0.7268379294406913], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, ((-1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(2*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(2*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
(-1 + Sqrt[5])^2/16, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.15940253851478242, 0.08575741144394561, 0.7268379294406913], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(2*Pi)/15], \
Cos[Pi/15]}, {(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, 
      {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.14956522429818808, 0.1019497257630228, 0.7268379294406913], 
    Polygon[{{(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, {((1 + \
Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.1380892421856475, 0.11702505755228865, 0.7268379294406913], 
    Polygon[{{((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(7*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 \
- Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.12510032543868924, 0.1308182383219439, 0.7268379294406913], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/30], \
Cos[Pi/15]}, {Cos[(4*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(4*Pi)/15], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.11074078334729859, 0.14317814709706767, 0.7268379294406913], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(4*Pi)/15], \
Cos[Pi/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, 
       ((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 \
+ Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.09516794205955617, 0.15396936613064244, 0.7268379294406913], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, \
Cos[Pi/15]}, 
      {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.0785524208834371, 0.16307366456872865, 0.7268379294406913], 
    Polygon[{{Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, \
{Cos[(11*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/30], Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.0610762629459682, 0.17039129381244167, 0.7268379294406913], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/30], \
Cos[Pi/15]}, {((-1 + Sqrt[5])*Sin[Pi/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.04293094069063355, 0.17584208038447502, 0.7268379294406913], 
    Polygon[{{((-1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(13*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.024315258065215443, \
0.17936630432649506, 0.7268379294406913], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/30], \
Cos[Pi/15]}, {Cos[(7*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/15], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.005433172384139969, 0.18092535350350178, 0.7268379294406913], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/15], \
Cos[Pi/15]}, {0, Sin[Pi/15], Cos[Pi/15]}, 
      {0, (-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.013508440270540545, \
0.18050214664645992, 0.7268379294406913], 
    Polygon[{{0, Sin[Pi/15], Cos[Pi/15]}, {Cos[(8*Pi)/15]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(8*Pi)/15], Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {0, (-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.03230205162679416, 0.17810132049825683, 0.7268379294406913], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(8*Pi)/15], \
Cos[Pi/15]}, {Cos[(17*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/30], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.05074175494578579, 0.17374917901257747, 0.7268379294406913], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/30], \
Cos[Pi/15]}, {-((-1 + Sqrt[5])*Sin[Pi/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {-(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.06862552097919648, 0.16749340516228314, 0.7268379294406913], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(19*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {-(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.08575741144394561, \
0.15940253851478242, 0.7268379294406913], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/30], \
Cos[Pi/15]}, {-Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.1019497257630228, 0.14956522429818808, 0.7268379294406913], 
    Polygon[{{-Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, {-(Sqrt[(5 \
- Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, 
       Cos[Pi/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.11702505755228859, 0.1380892421856475, 0.7268379294406913], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(11*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.13081823832194392, 0.1251003254386892, 0.7268379294406913], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/15], \
Cos[Pi/15]}, {Cos[(23*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/30], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.1431781470970677, 0.11074078334729856, 0.7268379294406913], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/30], \
Cos[Pi/15]}, {-((1 + Sqrt[5])*Sin[Pi/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.15396936613064244, 0.09516794205955617, 0.7268379294406913], 
    Polygon[{{-((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {-(Sqrt[3]*Sin[Pi/15])/2, \
Sin[Pi/15]/2, 
       Cos[Pi/15]}, {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \

   {RGBColor[0.16307366456872865, 0.07855242088343706, 0.7268379294406913], 
    Polygon[{{-(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, \
{Cos[(13*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/15], Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17039129381244167, 0.06107626294596818, 0.7268379294406913], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[Pi/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
       ((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {-((-1 + Sqrt[5])*Sqrt[(5 \
+ Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17584208038447502, 0.04293094069063356, 0.7268379294406913], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, ((-1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(14*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(14*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.17936630432649506, \
0.024315258065215485, 0.7268379294406913], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(14*Pi)/15], \
Cos[Pi/15]}, {Cos[(29*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/30], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.18092535350350178, 0.005433172384139984, 0.7268379294406913], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/30], \
Cos[Pi/15]}, {-Sin[Pi/15], 0, Cos[Pi/15]}, 
      {(1 - Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.18050214664645986, \
0.013508440270540567, 0.7268379294406913], 
    Polygon[{{-Sin[Pi/15], 0, Cos[Pi/15]}, {Cos[(31*Pi)/30]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(31*Pi)/30], Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(1 - Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.1781013204982568, 0.03230205162679416, 0.7268379294406913], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(31*Pi)/30], \
Cos[Pi/15]}, {Cos[(16*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(16*Pi)/15], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17374917901257747, 0.05074175494578578, 0.7268379294406913], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(16*Pi)/15], \
Cos[Pi/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
       -((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {-((-1 + Sqrt[5])*Sqrt[(5 \
+ Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.16749340516228317, 0.06862552097919646, 0.7268379294406913], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(17*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.15940253851478242, \
0.0857574114439456, 0.7268379294406913], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/15], \
Cos[Pi/15]}, {-(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.14956522429818808, 0.1019497257630228, 0.7268379294406913], 
    Polygon[{{-(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, {-((1 + \
Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, 
       Cos[Pi/15]}, {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.1380892421856475, 0.11702505755228865, 0.7268379294406913], 
    Polygon[{{-((1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(37*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(37*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, 
       -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.12510032543868926, 0.1308182383219439, 0.7268379294406913], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(37*Pi)/30], \
Cos[Pi/15]}, {Cos[(19*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/15], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.11074078334729859, 0.14317814709706767, 0.7268379294406913], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/15], \
Cos[Pi/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, 
       -((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.09516794205955617, 0.15396936613064244, 0.7268379294406913], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {-Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, \

       Cos[Pi/15]}, {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.07855242088343706, 0.16307366456872865, 0.7268379294406913], 
    Polygon[{{-Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, \
{Cos[(41*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(41*Pi)/30], Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.061076262945968185, 0.17039129381244167, 0.7268379294406913], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(41*Pi)/30], \
Cos[Pi/15]}, {-((-1 + Sqrt[5])*Sin[Pi/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {-(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.04293094069063362, 0.17584208038447502, 0.7268379294406913], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(43*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(43*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {-(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.024315258065215575, \
0.17936630432649506, 0.7268379294406913], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(43*Pi)/30], \
Cos[Pi/15]}, {Cos[(22*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(22*Pi)/15], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(22*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.00543317238414001, 0.18092535350350178, 0.7268379294406913], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(22*Pi)/15], \
Cos[Pi/15]}, {0, -Sin[Pi/15], Cos[Pi/15]}, 
      {0, (1 - Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.013508440270540616, \
0.18050214664645986, 0.7268379294406913], 
    Polygon[{{0, -Sin[Pi/15], Cos[Pi/15]}, {Cos[(23*Pi)/15]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(23*Pi)/15], Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {0, (1 - Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.032302051626794226, 0.1781013204982568, 0.7268379294406913], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/15], \
Cos[Pi/15]}, {Cos[(47*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(47*Pi)/30], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.050741754945785804, 0.17374917901257747, 0.7268379294406913], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(47*Pi)/30], \
Cos[Pi/15]}, {((-1 + Sqrt[5])*Sin[Pi/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.06862552097919644, 0.16749340516228317, 0.7268379294406913], 
    Polygon[{{((-1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {Cos[(49*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(49*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.0857574114439456, \
0.15940253851478242, 0.7268379294406913], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(49*Pi)/30], \
Cos[Pi/15]}, {Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
      {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.1019497257630228, 0.14956522429818808, 0.7268379294406913], 
    Polygon[{{Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + Sqrt[5])*Sin[Pi/15])/4, 
       Cos[Pi/15]}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.11702505755228866, 0.13808924218564744, 0.7268379294406913], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(26*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(26*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.13081823832194386, 0.1251003254386893, 0.7268379294406913], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(26*Pi)/15], \
Cos[Pi/15]}, {Cos[(53*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(53*Pi)/30], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.14317814709706767, 0.11074078334729862, 0.7268379294406913], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(53*Pi)/30], \
Cos[Pi/15]}, {((1 + Sqrt[5])*Sin[Pi/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.15396936613064244, 0.09516794205955617, 0.7268379294406913], 
    Polygon[{{((1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {(Sqrt[3]*Sin[Pi/15])/2, \
-Sin[Pi/15]/2, 
       Cos[Pi/15]}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.16307366456872865, 0.07855242088343709, 0.7268379294406913], 
    Polygon[{{(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, \
{Cos[(28*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(28*Pi)/15], Cos[Pi/15]}, 
      {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17039129381244167, 0.061076262945968185, 0.7268379294406913], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(28*Pi)/15], \
Cos[Pi/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
       -((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {((-1 + Sqrt[5])*Sqrt[(5 \
+ Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17584208038447502, 0.04293094069063363, 0.7268379294406913], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
      {Cos[(29*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.17936630432649506, \
0.024315258065215582, 0.7268379294406913], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/15], \
Cos[Pi/15]}, {Cos[(59*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(59*Pi)/30], 
       Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(59*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.18092535350350178, 0.005433172384140013, 0.7268379294406913], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(59*Pi)/30], \
Cos[Pi/15]}, {Sin[Pi/15], 0, Cos[Pi/15]}, 
      {(-1 + Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
       Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.2552124146273002, \
0.018704156950239956, 0.703914622558227], 
    Polygon[{{(-1 + Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[Pi/30]*Sin[(2*Pi)/15], \
Sin[Pi/30]*Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, {Sin[(2*Pi)/15], 0, \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.2518592175339307, 0.045278655129237205, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 \
+ Sqrt[5])/2]/2}, 
      {Cos[Pi/15]*Sin[(2*Pi)/15], Sin[Pi/15]*Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, \
{Cos[Pi/30]*Sin[(2*Pi)/15], Sin[Pi/30]*Sin[(2*Pi)/15], 
       Cos[(2*Pi)/15]}}]}, {RGBColor[0.24574659814832978, 0.0713570708874708, \
0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, Sqrt[(5 \
+ Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, \
{Cos[Pi/15]*Sin[(2*Pi)/15], Sin[Pi/15]*Sin[(2*Pi)/15], Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.23694152760763398, 0.09665368364463417, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(2*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]^2, Cos[(2*Pi)/15]}, \
{(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.22554047610726669, 0.12089133841770333, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, \
Cos[(2*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]^2, Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.21166835595328928, 0.14380448238892918, 0.703914622558227], 
    Polygon[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.1954771529970365, 0.16514207435807934, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(7*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(2*Pi)/15]}, {((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.17714426144632409, 0.1846703352023616, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(4*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(7*Pi)/30], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.1568705402973859, 0.2021753092094147, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
      {Cos[(4*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.1348781126816785, 0.21746520822086612, 0.703914622558227], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.11140793223837107, 0.23037251290352923, 0.703914622558227], 
    Polygon[{{(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(11*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], 
       Cos[(2*Pi)/15]}, {Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.08671714317585136, 0.24075580812627367, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 \
+ Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], 
       Cos[(2*Pi)/15]}}]}, {RGBColor[0.06107626294596817, 0.2485013323337949, \
0.703914622558227], 
    Polygon[{{(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(13*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.034766218398219285, 0.25352422394202, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(7*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(13*Pi)/30], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.008075267886400592, 0.2557694510993819, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {0, (-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {0, Sin[(2*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(7*Pi)/15], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.01870415695023993, 0.25521241462730027, 0.703914622558227], 
    Polygon[{{0, (-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(8*Pi)/15]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(8*Pi)/15], Cos[(2*Pi)/15]}, 
      {0, Sin[(2*Pi)/15], Cos[(2*Pi)/15]}}]}, {RGBColor[0.04527865512923715, \
0.2518592175339307, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(17*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(8*Pi)/15], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.07135707088747079, 0.24574659814832978, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{Cos[(17*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], 
       Cos[(2*Pi)/15]}}]}, {RGBColor[0.09665368364463416, 0.236941527607634, \
0.703914622558227], 
    Polygon[{{-(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(19*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(2*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.12089133841770333, 0.22554047610726669, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.14380448238892918, 0.21166835595328928, 0.703914622558227], 
    Polygon[{{(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \

       Cos[(2*Pi)/15]}, {-Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.1651420743580793, 0.19547715299703652, 0.703914622558227], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(11*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.1846703352023616, 0.17714426144632406, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(23*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(11*Pi)/15], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.20217530920941473, 0.15687054029738587, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {Cos[(23*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.21746520822086612, 0.1348781126816785, 0.703914622558227], 
    Polygon[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 \
+ Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, \
Cos[(2*Pi)/15]}, 
      {-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.23037251290352925, 0.111407932238371, 0.703914622558227], 
    Polygon[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(13*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], 
       Cos[(2*Pi)/15]}, {-(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.24075580812627367, 0.08671714317585134, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.2485013323337949, 0.061076262945968185, 0.703914622558227], 
    Polygon[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(14*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.25352422394202, 0.03476621839821934, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(29*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(14*Pi)/15], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.2557694510993819, 0.008075267886400613, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(1 - Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {-Sin[(2*Pi)/15], 0, \
Cos[(2*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(29*Pi)/30], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.2552124146273002, 0.018704156950239963, 0.703914622558227], 
    Polygon[{{(1 - Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(31*Pi)/30])/4, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(31*Pi)/30]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(31*Pi)/30], Cos[(2*Pi)/15]}, 
      {-Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}}]}, {RGBColor[0.2518592175339307, \
0.04527865512923716, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(16*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(31*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(31*Pi)/30], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.24574659814832978, 0.07135707088747079, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, \
{Cos[(16*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.23694152760763404, 0.09665368364463411, 0.703914622558227], 
    Polygon[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])^2/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(17*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.22554047610726669, 0.1208913384177033, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, \
Cos[(2*Pi)/15]}, 
      {Cos[(17*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.21166835595328928, 0.14380448238892918, 0.703914622558227], 
    Polygon[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{-(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.1954771529970365, 0.16514207435807934, 0.703914622558227], 
    Polygon[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 \
+ Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(37*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(2*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.17714426144632414, 0.18467033520236154, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(19*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(37*Pi)/30], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.1568705402973859, 0.20217530920941468, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
      {Cos[(19*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.1348781126816785, 0.21746520822086612, 0.703914622558227], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 \
+ Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.11140793223837102, 0.23037251290352925, 0.703914622558227], 
    Polygon[{{(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(41*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(41*Pi)/30], 
       Cos[(2*Pi)/15]}, {-Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.08671714317585134, 0.24075580812627367, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{Cos[(41*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(41*Pi)/30], 
       Cos[(2*Pi)/15]}}]}, {RGBColor[0.06107626294596827, \
0.24850133233379487, 0.703914622558227], 
    Polygon[{{-(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(43*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(2*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.034766218398219466, 0.25352422394202, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(22*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(22*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(43*Pi)/30], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.008075267886400653, 0.2557694510993819, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(22*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {0, (1 - Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {0, -Sin[(2*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(22*Pi)/15], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.018704156950240032, 0.2552124146273002, 0.703914622558227], 
    Polygon[{{0, (1 - Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/15])/4, 
       Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(23*Pi)/15]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(23*Pi)/15], Cos[(2*Pi)/15]}, 
      {0, -Sin[(2*Pi)/15], Cos[(2*Pi)/15]}}]}, {RGBColor[0.04527865512923725, \
0.2518592175339307, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(47*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(23*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(23*Pi)/15], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.07135707088747081, 0.24574659814832978, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{Cos[(47*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(47*Pi)/30], 
       Cos[(2*Pi)/15]}}]}, {RGBColor[0.0966536836446341, 0.23694152760763404, \
0.703914622558227], 
    Polygon[{{(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(49*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.1208913384177033, 0.2255404761072667, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.14380448238892918, 0.21166835595328928, 0.703914622558227], 
    Polygon[{{(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \

       Cos[(2*Pi)/15]}, {Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.16514207435807937, 0.19547715299703644, 0.703914622558227], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(26*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(2*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.18467033520236154, 0.17714426144632417, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(53*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(26*Pi)/15], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.20217530920941468, 0.15687054029738592, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {Cos[(53*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.21746520822086612, 0.1348781126816785, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 \
+ Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, 
      {((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.23037251290352925, 0.11140793223837103, 0.703914622558227], 
    Polygon[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(28*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(28*Pi)/15], 
       Cos[(2*Pi)/15]}, {(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.24075580812627367, 0.08671714317585136, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(2*Pi)/15]}}]}, 
   {RGBColor[0.24850133233379487, 0.06107626294596828, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(29*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(2*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.25352422394202, 0.03476621839821949, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(59*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(59*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(29*Pi)/15], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.2557694510993819, 0.008075267886400658, 0.703914622558227], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(59*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {Sin[(2*Pi)/15], 0, \
Cos[(2*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(59*Pi)/30], Cos[(2*Pi)/15]}}]}, \
{RGBColor[0.3271265219868526, 0.023694946972296044, 0.6732790797674101], 
    Polygon[{{Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}, {Cos[Pi/30]*Sin[(2*Pi)/15], \
Sin[Pi/30]*Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, 
      {Cos[Pi/30]/2, Sin[Pi/30]/2, Sqrt[3]/2}, {1/2, 0, Sqrt[3]/2}}]}, \
{RGBColor[0.32285769227737315, 0.05775917621091655, 0.6732790797674101], 
    Polygon[{{Cos[Pi/30]*Sin[(2*Pi)/15], Sin[Pi/30]*Sin[(2*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[Pi/15]*Sin[(2*Pi)/15], Sin[Pi/15]*Sin[(2*Pi)/15], 
       Cos[(2*Pi)/15]}, {Cos[Pi/15]/2, Sin[Pi/15]/2, Sqrt[3]/2}, \
{Cos[Pi/30]/2, Sin[Pi/30]/2, Sqrt[3]/2}}]}, 
   {RGBColor[0.3150515661289872, 0.09119058382808559, 0.6732790797674101], 
    Polygon[{{Cos[Pi/15]*Sin[(2*Pi)/15], Sin[Pi/15]*Sin[(2*Pi)/15], \
Cos[(2*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, 
      {Cos[Pi/15]/2, Sin[Pi/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.3037936690933133, 0.12362288832597762, 0.6732790797674101], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]^2, Cos[(2*Pi)/15]}, \
{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, Sqrt[3]/2}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}}]}, \
{RGBColor[0.2892073450461408, 0.15470075458961774, 0.6732790797674101], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]^2, \
Cos[(2*Pi)/15]}, {(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, \
Cos[(2*Pi)/15]}, 
      {Sqrt[3]/4, 1/4, Sqrt[3]/2}, {Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, \
Sqrt[3]/2}}]}, 
   {RGBColor[0.27145240480611504, 0.18408368701275984, 0.6732790797674101], 
    Polygon[{{(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(1 + \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {Sqrt[3]/4, 1/4, Sqrt[3]/2}}]}, {RGBColor[0.25072337521396587, \
0.21144976003900215, 0.6732790797674101], 
    Polygon[{{((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {Cos[(7*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, Sqrt[3]/2}, 
      {(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}}]}, \
{RGBColor[0.2272473678557331, 0.2364991452455501, 0.6732790797674101], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(4*Pi)/15], Cos[(2*Pi)/15]}, {Cos[(4*Pi)/15]/2, \
Sin[(4*Pi)/15]/2, Sqrt[3]/2}, 
      {Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.20128159078070398, 0.25895739632616, 0.6732790797674101], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(2*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, 
      {Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.17311053047620073, 0.27857845598230146, 0.6732790797674101], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
      {Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {1/4, \
Sqrt[3]/4, Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, 
       Sqrt[3]/2}}]}, {RGBColor[0.14304283497409281, 0.2951473517784111, \
0.6732790797674101], 
    Polygon[{{Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], 
       Cos[(2*Pi)/15]}, {Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, Sqrt[3]/2}, \
{1/4, Sqrt[3]/4, Sqrt[3]/2}}]}, 
   {RGBColor[0.11140793223837105, 0.3084825514248824, 0.6732790797674101], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(-1 + \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.07855242088343706, 0.3184379516838187, 0.6732790797674101], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {Cos[(13*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, Sqrt[3]/2}, 
      {(-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}}]}, \
{RGBColor[0.04483627276715331, 0.32490447910668163, 0.6732790797674101], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(7*Pi)/15], Cos[(2*Pi)/15]}, {Cos[(7*Pi)/15]/2, \
Sin[(7*Pi)/15]/2, Sqrt[3]/2}, 
      {Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.010628889063839363, 0.32781128506581847, 0.6732790797674101], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(2*Pi)/15]}, {0, Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, 
      {0, 1/2, Sqrt[3]/2}, {Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, \
Sqrt[3]/2}}]}, 
   {RGBColor[0.023694946972296016, 0.32712652198685266, 0.6732790797674101], 
    Polygon[{{0, Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(2*Pi)/15]}, 
      {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, Sqrt[3]/2}, {0, 1/2, \
Sqrt[3]/2}}]}, 
   {RGBColor[0.05775917621091649, 0.3228576922773732, 0.6732790797674101], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(17*Pi)/30], Cos[(2*Pi)/15]}, {Cos[(17*Pi)/30]/2, \
Sin[(17*Pi)/30]/2, Sqrt[3]/2}, 
      {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.09119058382808556, 0.3150515661289872, 0.6732790797674101], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(2*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(1 - \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.12362288832597759, 0.30379366909331335, 0.6732790797674101], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, Sqrt[3]/2}, 
      {(1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}}]}, \
{RGBColor[0.1547007545896177, 0.2892073450461409, 0.6732790797674101], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(2*Pi)/15]}, {-Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 
       Cos[(2*Pi)/15]}, {-1/4, Sqrt[3]/4, Sqrt[3]/2}, {Cos[(19*Pi)/30]/2, \
Sin[(19*Pi)/30]/2, Sqrt[3]/2}}]}, 
   {RGBColor[0.18408368701275984, 0.27145240480611504, 0.6732790797674101], 
    Polygon[{{-Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, {-1/4, Sqrt[3]/4, Sqrt[3]/2}}]}, 
   {RGBColor[0.21144976003900207, 0.2507233752139659, 0.6732790797674101], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
      {Cos[(11*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, Sqrt[3]/2}, 
      {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}}]}, \
{RGBColor[0.23649914524555013, 0.22724736785573307, 0.6732790797674101], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(23*Pi)/30], Cos[(2*Pi)/15]}, {Cos[(23*Pi)/30]/2, \
Sin[(23*Pi)/30]/2, Sqrt[3]/2}, 
      {Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.25895739632616, 0.20128159078070396, 0.6732790797674101], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(2*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(-1 - \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.27857845598230146, 0.17311053047620073, 0.6732790797674101], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{-Sqrt[3]/4, 1/4, Sqrt[3]/2}, 
      {(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}}]}, \
{RGBColor[0.2951473517784111, 0.14304283497409273, 0.6732790797674101], 
    Polygon[{{-(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], 
       Cos[(2*Pi)/15]}, {Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, Sqrt[3]/2}, \
{-Sqrt[3]/4, 1/4, Sqrt[3]/2}}]}, 
   {RGBColor[0.30848255142488246, 0.111407932238371, 0.6732790797674101], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, 
      {Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.3184379516838187, 0.07855242088343709, 0.6732790797674101], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
      {Cos[(14*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, Sqrt[3]/2}, 
      {-Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}}]}, \
{RGBColor[0.32490447910668163, 0.04483627276715338, 0.6732790797674101], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(29*Pi)/30], Cos[(2*Pi)/15]}, {Cos[(29*Pi)/30]/2, \
Sin[(29*Pi)/30]/2, Sqrt[3]/2}, 
      {Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.32781128506581847, 0.010628889063839391, 0.6732790797674101], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(2*Pi)/15]}, {-Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}, 
      {-1/2, 0, Sqrt[3]/2}, {Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, \
Sqrt[3]/2}}]}, 
   {RGBColor[0.3271265219868526, 0.023694946972296054, 0.6732790797674101], 
    Polygon[{{-Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(2*Pi)/15]}, 
      {Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, Sqrt[3]/2}, {-1/2, 0, \
Sqrt[3]/2}}]}, 
   {RGBColor[0.32285769227737315, 0.057759176210916495, 0.6732790797674101], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(16*Pi)/15], Cos[(2*Pi)/15]}, {Cos[(16*Pi)/15]/2, \
Sin[(16*Pi)/15]/2, Sqrt[3]/2}, 
      {Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.3150515661289872, 0.09119058382808556, 0.6732790797674101], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, 
      {Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.3037936690933134, 0.12362288832597755, 0.6732790797674101], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
      {Cos[(17*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, Sqrt[3]/2}, 
      {-Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}}]}, \
{RGBColor[0.2892073450461409, 0.15470075458961768, 0.6732790797674101], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, 
       Cos[(2*Pi)/15]}, {-Sqrt[3]/4, -1/4, Sqrt[3]/2}, {Cos[(17*Pi)/15]/2, \
Sin[(17*Pi)/15]/2, Sqrt[3]/2}}]}, 
   {RGBColor[0.27145240480611504, 0.18408368701275984, 0.6732790797674101], 
    Polygon[{{-(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, \
Cos[(2*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(-1 - \
Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {-Sqrt[3]/4, -1/4, Sqrt[3]/2}}]}, {RGBColor[0.25072337521396587, \
0.21144976003900215, 0.6732790797674101], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {Cos[(37*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, Sqrt[3]/2}, 
      {(-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}}]}, \
{RGBColor[0.22724736785573318, 0.23649914524555005, 0.6732790797674101], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(19*Pi)/15], Cos[(2*Pi)/15]}, {Cos[(19*Pi)/15]/2, \
Sin[(19*Pi)/15]/2, Sqrt[3]/2}, 
      {Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.201281590780704, 0.25895739632616, 0.6732790797674101], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-Sqrt[(5 - \
Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, 
      {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.17311053047620073, 0.27857845598230146, 0.6732790797674101], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
      {-Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{-1/4, -Sqrt[3]/4, Sqrt[3]/2}, 
      {-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}}]}, \
{RGBColor[0.14304283497409276, 0.2951473517784111, 0.6732790797674101], 
    Polygon[{{-Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(41*Pi)/30], 
       Cos[(2*Pi)/15]}, {Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, Sqrt[3]/2}, \
{-1/4, -Sqrt[3]/4, Sqrt[3]/2}}]}, 
   {RGBColor[0.11140793223837102, 0.30848255142488246, 0.6732790797674101], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(2*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(1 - \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.07855242088343718, 0.3184379516838187, 0.6732790797674101], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {Cos[(43*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, Sqrt[3]/2}, 
      {(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}}]}, \
{RGBColor[0.04483627276715354, 0.32490447910668163, 0.6732790797674101], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(22*Pi)/15], Cos[(2*Pi)/15]}, {Cos[(22*Pi)/15]/2, \
Sin[(22*Pi)/15]/2, Sqrt[3]/2}, 
      {Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.010628889063839441, 0.32781128506581847, 0.6732790797674101], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(2*Pi)/15]}, {0, -Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, 
      {0, -1/2, Sqrt[3]/2}, {Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, \
Sqrt[3]/2}}]}, 
   {RGBColor[0.02369494697229614, 0.3271265219868526, 0.6732790797674101], 
    Polygon[{{0, -Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(2*Pi)/15]}, 
      {Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, Sqrt[3]/2}, {0, -1/2, \
Sqrt[3]/2}}]}, 
   {RGBColor[0.05775917621091661, 0.32285769227737315, 0.6732790797674101], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(47*Pi)/30], Cos[(2*Pi)/15]}, {Cos[(47*Pi)/30]/2, \
Sin[(47*Pi)/30]/2, Sqrt[3]/2}, 
      {Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.09119058382808559, 0.3150515661289872, 0.6732790797674101], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(-1 + \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.12362288832597754, 0.3037936690933134, 0.6732790797674101], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, Sqrt[3]/2}, 
      {(-1 + Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}}]}, \
{RGBColor[0.15470075458961768, 0.2892073450461409, 0.6732790797674101], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(2*Pi)/15]}, {Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, 
       Cos[(2*Pi)/15]}, {1/4, -Sqrt[3]/4, Sqrt[3]/2}, {Cos[(49*Pi)/30]/2, \
Sin[(49*Pi)/30]/2, Sqrt[3]/2}}]}, 
   {RGBColor[0.18408368701275984, 0.27145240480611504, 0.6732790797674101], 
    Polygon[{{Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {Sqrt[(5 - \
Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, 
      {1/4, -Sqrt[3]/4, Sqrt[3]/2}}]}, {RGBColor[0.21144976003900218, \
0.2507233752139658, 0.6732790797674101], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
      {Cos[(26*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, Sqrt[3]/2}, 
      {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}}]}, \
{RGBColor[0.23649914524555, 0.2272473678557332, 0.6732790797674101], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(53*Pi)/30], Cos[(2*Pi)/15]}, {Cos[(53*Pi)/30]/2, \
Sin[(53*Pi)/30]/2, Sqrt[3]/2}, 
      {Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.25895739632615994, 0.20128159078070404, 0.6732790797674101], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(2*Pi)/15]}, {((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(1 + \
Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.27857845598230146, 0.17311053047620073, 0.6732790797674101], 
    Polygon[{{((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
      {(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{Sqrt[3]/4, -1/4, Sqrt[3]/2}, 
      {(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}}]}, \
{RGBColor[0.2951473517784111, 0.14304283497409276, 0.6732790797674101], 
    Polygon[{{(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(28*Pi)/15], 
       Cos[(2*Pi)/15]}, {Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, Sqrt[3]/2}, \
{Sqrt[3]/4, -1/4, Sqrt[3]/2}}]}, 
   {RGBColor[0.30848255142488246, 0.11140793223837103, 0.6732790797674101], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(2*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, 
      {Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.3184379516838187, 0.0785524208834372, 0.6732790797674101], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
      {Cos[(29*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, Sqrt[3]/2}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}}]}, \
{RGBColor[0.32490447910668163, 0.044836272767153566, 0.6732790797674101], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(2*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(59*Pi)/30], Cos[(2*Pi)/15]}, {Cos[(59*Pi)/30]/2, \
Sin[(59*Pi)/30]/2, Sqrt[3]/2}, 
      {Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, Sqrt[3]/2}}]}, \
{RGBColor[0.32781128506581847, 0.010628889063839448, 0.6732790797674101], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(2*Pi)/15]}, {Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}, 
      {1/2, 0, Sqrt[3]/2}, {Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, \
Sqrt[3]/2}}]}, 
   {RGBColor[0.39545656271589147, 0.02842613019683723, 0.6352669504859562], 
    Polygon[{{1/2, 0, Sqrt[3]/2}, {Cos[Pi/30]/2, Sin[Pi/30]/2, Sqrt[3]/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, (1 + Sqrt[5])/4}, {Sqrt[(5 - \
Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.39031887058190917, 0.06960687567114443, 0.6352669504859562], 
    Polygon[{{Cos[Pi/30]/2, Sin[Pi/30]/2, Sqrt[3]/2}, {Cos[Pi/15]/2, \
Sin[Pi/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
       (1 + Sqrt[5])/4}}]}, {RGBColor[0.3809047632223568, 0.1100249936494234, \
0.6352669504859562], 
    Polygon[{{Cos[Pi/15]/2, Sin[Pi/15]/2, Sqrt[3]/2}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, 
      {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.36731738356749405, 0.14923765477306916, 0.6352669504859562], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, \
{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3497055977921617, 0.18681523692103416, 0.6352669504859562], 
    Polygon[{{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, Sqrt[3]/2}, {Sqrt[3]/4, \
1/4, Sqrt[3]/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, 
       (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.32826236430681743, 0.2223460322396907, 0.6352669504859562], 
    Polygon[{{Sqrt[3]/4, 1/4, Sqrt[3]/2}, {(1 + Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/4, Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       (5 - Sqrt[5])/8, (1 + Sqrt[5])/4}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.30322261966481173, 0.2554407579002307, 0.6352669504859562], 
    Polygon[{{(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, \
{Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.2748607045483458, 0.2857368211628005, 0.6352669504859562], 
    Polygon[{{Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.243487358034548, 0.3129022920184369, 0.6352669504859562], \
Polygon[{{Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, Sqrt[3]/2}, 
      {Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, {(5 - \
Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.20944631307311828, 0.33663953988370504, 0.6352669504859562], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, {1/4, \
Sqrt[3]/4, Sqrt[3]/2}, 
      {Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       (1 + Sqrt[5])/4}}]}, {RGBColor[0.17311053047620079, \
0.3566884945036547, 0.6352669504859562], 
    Polygon[{{1/4, Sqrt[3]/4, Sqrt[3]/2}, {Cos[(11*Pi)/30]/2, \
Sin[(11*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (1 + Sqrt[5])/4}, {Sqrt[(5 \
- Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.13487811268167854, 0.37282949533595616, 0.6352669504859562], 
    Polygon[{{Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, Sqrt[3]/2}, {(-1 + \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.09516794205955614, 0.38488569819776924, 0.6352669504859562], 
    Polygon[{{(-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, \
{Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.05441509154905714, 0.3927250128076172, 0.6352669504859562], 
    Polygon[{{Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.013066057908456682, 0.3962615499941524, 0.6352669504859562], 
    Polygon[{{Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, Sqrt[3]/2}, {0, 1/2, \
Sqrt[3]/2}, {0, Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.0284261301968372, 0.39545656271589147, 0.6352669504859562], 
    Polygon[{{0, 1/2, Sqrt[3]/2}, {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, \
Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (1 + Sqrt[5])/4}, {0, \
Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.06960687567114436, 0.3903188705819092, 0.6352669504859562], 
    Polygon[{{Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.11002499364942339, 0.3809047632223568, 0.6352669504859562], 
    Polygon[{{Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, Sqrt[3]/2}, {(1 - \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.1492376547730691, 0.36731738356749405, 0.6352669504859562], 
    Polygon[{{(1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, \
{Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.18681523692103413, 0.3497055977921617, 0.6352669504859562], 
    Polygon[{{Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, Sqrt[3]/2}, {-1/4, \
Sqrt[3]/4, Sqrt[3]/2}, 
      {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, \
{RGBColor[0.2223460322396907, 0.32826236430681743, 0.6352669504859562], 
    Polygon[{{-1/4, Sqrt[3]/4, Sqrt[3]/2}, {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/8, Sqrt[3]/2}, 
      {(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       (1 + Sqrt[5])/4}}]}, {RGBColor[0.2554407579002306, 0.3032226196648118, \
0.6352669504859562], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, \
{Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.2857368211628006, 0.27486070454834577, 0.6352669504859562], 
    Polygon[{{Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.31290229201843694, 0.24348735803454796, 0.6352669504859562], 
    Polygon[{{Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, Sqrt[3]/2}, {(-1 - \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, \
{RGBColor[0.33663953988370504, 0.20944631307311828, 0.6352669504859562], 
    Polygon[{{(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, \
{-Sqrt[3]/4, 1/4, Sqrt[3]/2}, 
      {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, 
       (1 + Sqrt[5])/4}}]}, {RGBColor[0.3566884945036547, \
0.17311053047620067, 0.6352669504859562], 
    Polygon[{{-Sqrt[3]/4, 1/4, Sqrt[3]/2}, {Cos[(13*Pi)/15]/2, \
Sin[(13*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3728294953359562, 0.13487811268167849, 0.6352669504859562], 
    Polygon[{{Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, Sqrt[3]/2}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, 
      {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.38488569819776924, 0.09516794205955617, 0.6352669504859562], 
    Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, \
{Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3927250128076172, 0.05441509154905722, 0.6352669504859562], 
    Polygon[{{Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3962615499941524, 0.013066057908456717, 0.6352669504859562], 
    Polygon[{{Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, Sqrt[3]/2}, {-1/2, 0, \
Sqrt[3]/2}, {-Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.39545656271589147, 0.028426130196837242, 0.6352669504859562], 
    Polygon[{{-1/2, 0, Sqrt[3]/2}, {Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, \
Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (1 + Sqrt[5])/4}, {-Sqrt[(5 \
- Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.39031887058190917, 0.06960687567114437, 0.6352669504859562], 
    Polygon[{{Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3809047632223568, 0.11002499364942338, 0.6352669504859562], 
    Polygon[{{Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, Sqrt[3]/2}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, 
      {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3673173835674941, 0.14923765477306905, 0.6352669504859562], \
Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, 
      {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/15])/2, 
       (1 + Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.34970559779216176, 0.18681523692103413, 0.6352669504859562], 
    Polygon[{{Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, Sqrt[3]/2}, {-Sqrt[3]/4, \
-1/4, Sqrt[3]/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       -Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/15])/2, 
       (1 + Sqrt[5])/4}}]}, {RGBColor[0.32826236430681743, \
0.2223460322396907, 0.6352669504859562], 
    Polygon[{{-Sqrt[3]/4, -1/4, Sqrt[3]/2}, {(-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, 
       (1 + Sqrt[5])/4}}]}, {RGBColor[0.30322261966481173, \
0.2554407579002307, 0.6352669504859562], 
    Polygon[{{(-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, \
{Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.2748607045483459, 0.2857368211628005, 0.6352669504859562], \
Polygon[{{Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, Sqrt[3]/2}, 
      {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/15])/2, 
       (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.24348735803454802, 0.3129022920184369, 0.6352669504859562], 
    Polygon[{{Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, Sqrt[3]/2}, {-Sqrt[(5 - \
Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, 
      {(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, \
{RGBColor[0.20944631307311828, 0.33663953988370504, 0.6352669504859562], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, {-1/4, \
-Sqrt[3]/4, Sqrt[3]/2}, 
      {-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       (1 + Sqrt[5])/4}}]}, {RGBColor[0.1731105304762007, 0.3566884945036547, \
0.6352669504859562], 
    Polygon[{{-1/4, -Sqrt[3]/4, Sqrt[3]/2}, {Cos[(41*Pi)/30]/2, \
Sin[(41*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (1 + Sqrt[5])/4}, {-Sqrt[(5 \
- Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.1348781126816785, 0.3728294953359562, 0.6352669504859562], \
Polygon[{{Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, Sqrt[3]/2}, 
      {(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.09516794205955631, 0.3848856981977692, 0.6352669504859562], \
Polygon[{{(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(43*Pi)/30])/2, 
       (1 + Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.054415091549057416, 0.3927250128076171, 0.6352669504859562], 
    Polygon[{{Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.01306605790845678, 0.3962615499941524, 0.6352669504859562], 
    Polygon[{{Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, Sqrt[3]/2}, {0, -1/2, \
Sqrt[3]/2}, {0, -Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.028426130196837346, 0.39545656271589147, 0.6352669504859562], 
    Polygon[{{0, -1/2, Sqrt[3]/2}, {Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, \
Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (1 + Sqrt[5])/4}, {0, \
-Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.06960687567114451, 0.39031887058190917, 0.6352669504859562], 
    Polygon[{{Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.11002499364942342, 0.3809047632223568, 0.6352669504859562], 
    Polygon[{{Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, Sqrt[3]/2}, {(-1 + \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.14923765477306905, 0.3673173835674941, 0.6352669504859562], \
Polygon[{{(-1 + Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(49*Pi)/30])/2, 
       (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.1868152369210341, 0.34970559779216176, 0.6352669504859562], 
    Polygon[{{Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, Sqrt[3]/2}, {1/4, \
-Sqrt[3]/4, Sqrt[3]/2}, 
      {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, \
{RGBColor[0.2223460322396907, 0.32826236430681743, 0.6352669504859562], 
    Polygon[{{1/4, -Sqrt[3]/4, Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - \
Sqrt[5])/8, Sqrt[3]/2}, 
      {(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       (1 + Sqrt[5])/4}}]}, {RGBColor[0.25544075790023074, \
0.3032226196648117, 0.6352669504859562], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, \
{Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.28573682116280047, 0.27486070454834594, 0.6352669504859562], 
    Polygon[{{Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.31290229201843683, 0.24348735803454807, 0.6352669504859562], 
    Polygon[{{Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, Sqrt[3]/2}, {(1 + \
Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, \
{RGBColor[0.33663953988370504, 0.20944631307311828, 0.6352669504859562], 
    Polygon[{{(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, \
{Sqrt[3]/4, -1/4, Sqrt[3]/2}, 
      {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, 
       (1 + Sqrt[5])/4}}]}, {RGBColor[0.3566884945036547, \
0.17311053047620073, 0.6352669504859562], 
    Polygon[{{Sqrt[3]/4, -1/4, Sqrt[3]/2}, {Cos[(28*Pi)/15]/2, \
Sin[(28*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3728294953359562, 0.1348781126816785, 0.6352669504859562], \
Polygon[{{Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, Sqrt[3]/2}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3848856981977692, 0.09516794205955632, 0.6352669504859562], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, \
{Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3927250128076171, 0.054415091549057444, 0.6352669504859562], 
    Polygon[{{Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3962615499941524, 0.013066057908456788, 0.6352669504859562], 
    Polygon[{{Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, Sqrt[3]/2}, {1/2, 0, \
Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.459453898589209, 0.032845870790391696, 0.5902947035568222], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
       (1 + Sqrt[5])/4}, {Cos[Pi/30]*Sin[(7*Pi)/30], \
Sin[Pi/30]*Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, {Sin[(7*Pi)/30], 0, \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.45350363366087504, 0.08069194763534407, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, (1 + Sqrt[5])/4}, 
      {Cos[Pi/15]*Sin[(7*Pi)/30], Sin[Pi/15]*Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[Pi/30]*Sin[(7*Pi)/30], Sin[Pi/30]*Sin[(7*Pi)/30], 
       Cos[(7*Pi)/30]}}]}, {RGBColor[0.44258468802041606, 0.127653946616128, \
0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, (1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Cos[Pi/15]*Sin[(7*Pi)/30], Sin[Pi/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.4268166919212052, 0.17321734224447993, 0.5902947035568222], 
    Polygon[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 \
+ Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Cos[(2*Pi)/15]*Sin[(7*Pi)/30], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.4063724028281706, 0.2168829324231421, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, 
      {Cos[(2*Pi)/15]*Sin[(7*Pi)/30], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.3814758126508584, 0.258172307808505, 0.5902947035568222], 
    Polygon[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, 
       (1 + Sqrt[5])/4}, {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.3523996936411974, 0.29663309336348914, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (1 + Sqrt[5])/4}, \
{Cos[(7*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]^2, Cos[(7*Pi)/30]}, 
      {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.3194626098436266, 0.3318439046731174, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Cos[(4*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]^2, 
       Cos[(7*Pi)/30]}}]}, {RGBColor[0.28302542684076004, 0.3634189647203456, \
0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, \
{Cos[(4*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.243487358034548, 0.3910123305397901, 0.5902947035568222], 
    Polygon[{{(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       (1 + Sqrt[5])/4}, {Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.20128159078070407, 0.4143216834412501, 0.5902947035568222], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], 
       Cos[(7*Pi)/30]}, {Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.15687054029738592, 0.43309164127654143, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {Cos[(11*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.11074078334729856, 0.4471165564597546, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 \
+ Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Cos[(13*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(7*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.06339772720085952, 0.45624276908524003, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Cos[(7*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(13*Pi)/30], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.01536007228838055, 0.4603702904576901, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {0, Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, {0, Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.03284587079039166, 0.45945389858920904, 0.5902947035568222], 
    Polygon[{{0, Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       (1 + Sqrt[5])/4}, {Cos[(8*Pi)/15]*Sin[(7*Pi)/30], \
Sin[(7*Pi)/30]*Sin[(8*Pi)/15], Cos[(7*Pi)/30]}, {0, Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.08069194763534399, 0.45350363366087504, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Cos[(17*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(8*Pi)/15], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.12765394661612797, 0.442584688020416, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {Cos[(17*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.17321734224447988, 0.4268166919212052, 0.5902947035568222], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Cos[(19*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.2168829324231421, 0.40637240282817066, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {-Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \

      {Cos[(19*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.258172307808505, 0.3814758126508584, 0.5902947035568222], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       (1 + Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {-Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.29663309336348903, 0.3523996936411975, 0.5902947035568222], 
    Polygon[{{(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], 
       Cos[(7*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.3318439046731174, 0.31946260984362657, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Cos[(23*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(11*Pi)/15], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.3634189647203456, 0.28302542684076004, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{Cos[(23*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], 
       Cos[(7*Pi)/30]}}]}, {RGBColor[0.3910123305397901, 0.243487358034548, \
0.5902947035568222], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, 
       (1 + Sqrt[5])/4}, {-(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.4143216834412501, 0.20128159078070396, 0.5902947035568222], 
    Polygon[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], 
       Cos[(7*Pi)/30]}, {-(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.43309164127654143, 0.15687054029738587, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Cos[(13*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.4471165564597546, 0.11074078334729859, 0.5902947035568222], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Cos[(14*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.45624276908524003, 0.06339772720085962, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Cos[(29*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(14*Pi)/15], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.4603702904576901, 0.015360072288380591, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {-Sin[(7*Pi)/30], 0, \
Cos[(7*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(29*Pi)/30], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.459453898589209, 0.03284587079039171, 0.5902947035568222], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (1 + Sqrt[5])/4}, \
{Cos[(31*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(31*Pi)/30], 
       Cos[(7*Pi)/30]}, {-Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.45350363366087504, 0.080691947635344, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Cos[(16*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(31*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(31*Pi)/30], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.44258468802041606, 0.12765394661612797, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Cos[(16*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.4268166919212052, 0.17321734224447982, 0.5902947035568222], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Cos[(17*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.40637240282817066, 0.21688293242314208, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}, 
      {Cos[(17*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.3814758126508584, 0.258172307808505, 0.5902947035568222], 
    Polygon[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       (-5 + Sqrt[5])/8, (1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.3523996936411974, 0.29663309336348914, 0.5902947035568222], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 \
+ Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (1 + Sqrt[5])/4}, \
{Cos[(37*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(37*Pi)/30], 
       Cos[(7*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.3194626098436267, 0.33184390467311736, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Cos[(19*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(37*Pi)/30], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.2830254268407601, 0.3634189647203456, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, \
{Cos[(19*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.243487358034548, 0.3910123305397901, 0.5902947035568222], 
    Polygon[{{(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 \
+ Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])/2]/4, 
       -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}, {-Sin[(7*Pi)/30]/2, \
-(Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.20128159078070398, 0.4143216834412501, 0.5902947035568222], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (1 + Sqrt[5])/4}, \
{Cos[(41*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(41*Pi)/30], 
       Cos[(7*Pi)/30]}, {-Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.15687054029738587, 0.43309164127654143, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {Cos[(41*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.11074078334729873, 0.44711655645975457, 0.5902947035568222], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Cos[(43*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.06339772720085984, 0.45624276908524, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Cos[(22*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(43*Pi)/30], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.015360072288380664, 0.4603702904576901, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {0, -Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, {0, -Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(22*Pi)/15], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.03284587079039183, 0.459453898589209, 0.5902947035568222], 
    Polygon[{{0, -Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(23*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/15], 
       Cos[(7*Pi)/30]}, {0, -Sin[(7*Pi)/30], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.08069194763534415, 0.453503633660875, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Cos[(47*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(23*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(23*Pi)/15], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.12765394661612803, 0.44258468802041595, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {Cos[(47*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.17321734224447982, 0.4268166919212052, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Cos[(49*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.21688293242314205, 0.40637240282817066, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \

      {Cos[(49*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.258172307808505, 0.3814758126508584, 0.5902947035568222], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.2966330933634892, 0.35239969364119733, 0.5902947035568222], 
    Polygon[{{(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(26*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(26*Pi)/15], 
       Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.3318439046731173, 0.31946260984362673, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Cos[(53*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(26*Pi)/15], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.3634189647203455, 0.28302542684076015, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{Cos[(53*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(53*Pi)/30], 
       Cos[(7*Pi)/30]}}]}, {RGBColor[0.3910123305397901, 0.243487358034548, \
0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, 
       (1 + Sqrt[5])/4}, {(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}, {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.4143216834412501, 0.20128159078070398, 0.5902947035568222], 
    Polygon[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(28*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(28*Pi)/15], 
       Cos[(7*Pi)/30]}, {(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.43309164127654143, 0.1568705402973859, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Cos[(28*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(7*Pi)/30]}}]}, 
   {RGBColor[0.44711655645975457, 0.11074078334729875, 0.5902947035568222], 
    Polygon[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {Cos[(29*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.45624276908524, 0.06339772720085987, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Cos[(59*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(29*Pi)/15], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.4603702904576901, 0.015360072288380674, 0.5902947035568222], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {Sin[(7*Pi)/30], 0, \
Cos[(7*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(59*Pi)/30], Cos[(7*Pi)/30]}}]}, \
{RGBColor[0.5184173614026737, 0.036905745150126276, 0.5388550643284117], 
    Polygon[{{Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}, {Cos[Pi/30]*Sin[(7*Pi)/30], \
Sin[Pi/30]*Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, 
      {Cos[Pi/30]*Sin[(4*Pi)/15], Sin[Pi/30]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, \
{Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.5117197160277158, 0.09089294173537525, 0.5388550643284117], 
    Polygon[{{Cos[Pi/30]*Sin[(7*Pi)/30], Sin[Pi/30]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[Pi/15]*Sin[(7*Pi)/30], Sin[Pi/15]*Sin[(7*Pi)/30], 
       Cos[(7*Pi)/30]}, {Cos[Pi/15]*Sin[(4*Pi)/15], \
Sin[Pi/15]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, 
      {Cos[Pi/30]*Sin[(4*Pi)/15], Sin[Pi/30]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.4994155623597233, 0.1438842962304006, 0.5388550643284117], 
    Polygon[{{Cos[Pi/15]*Sin[(7*Pi)/30], Sin[Pi/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}, {Cos[Pi/15]*Sin[(4*Pi)/15], \
Sin[Pi/15]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.4816397072810926, 0.19529922426620094, 0.5388550643284117], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Cos[(2*Pi)/15]*Sin[(7*Pi)/30], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.45858690677990177, \
0.24457441313195072, 0.5388550643284117], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(7*Pi)/30], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, 
       Cos[(7*Pi)/30]}, {(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, \
Cos[(4*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}}]}, \
{RGBColor[0.4305097321625505, 0.2911699935469405, 0.5388550643284117], 
    Polygon[{{(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}, {(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.3977158028296732, 0.3345754545813917, 0.5388550643284117], 
    Polygon[{{((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {Cos[(7*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]^2, Cos[(7*Pi)/30]}, \
{Cos[(7*Pi)/30]*Sin[(4*Pi)/15], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], 
       Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.36056441593361166, 0.3743152369210341, 0.5388550643284117], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]^2, \
Cos[(7*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(7*Pi)/30], \
Sin[(7*Pi)/30]*Sin[(4*Pi)/15], 
       Cos[(7*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]^2, \
Cos[(4*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(7*Pi)/30]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}}]}, \
{RGBColor[0.31946260984362657, 0.40995394319447065, 0.5388550643284117], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]^2, \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.27486070454834577, 0.4411011082778906, 0.5388550643284117], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.22724736785573318, 0.46741547731267685, 0.5388550643284117], 
    Polygon[{{Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], 
       Cos[(7*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(11*Pi)/30], Cos[(4*Pi)/15]}, 
      {Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}]}, \
{RGBColor[0.1771442614463241, 0.48860874456504844, 0.5388550643284117], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(7*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(11*Pi)/30], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.1251003254386892, 0.5044487121640122, 0.5388550643284117], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {Cos[(13*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(13*Pi)/30], Cos[(4*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.07168576408662194, 0.5147618341098276, \
0.5388550643284117], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/30]}, \
{Cos[(7*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(4*Pi)/15]}, 
      {Cos[(13*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.017485798502011148, 0.5194351176802965, 0.5388550643284117], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/30]}, {0, Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, 
      {0, Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(7*Pi)/15], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.036905745150126235, 0.5184173614026737, 0.5388550643284117], 
    Polygon[{{0, Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/30]}, 
      {Cos[(8*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(4*Pi)/15]}, {0, Sin[(4*Pi)/15], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.09089294173537515, 0.5117197160277158, 0.5388550643284117], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(17*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(4*Pi)/15]}, 
      {Cos[(8*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.14388429623040058, 0.49941556235972334, 0.5388550643284117], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(17*Pi)/30], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.1952992242662009, 0.4816397072810926, 0.5388550643284117], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {Cos[(19*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(19*Pi)/30], Cos[(4*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.24457441313195066, \
0.45858690677990177, 0.5388550643284117], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/30]}, {-Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 
       Cos[(7*Pi)/30]}, {-Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, \
Cos[(4*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(19*Pi)/30], Cos[(4*Pi)/15]}}]}, \
{RGBColor[0.2911699935469405, 0.4305097321625505, 0.5388550643284117], 
    Polygon[{{-Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}, {-Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.3345754545813916, 0.39771580282967334, 0.5388550643284117], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Cos[(11*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(11*Pi)/15], Cos[(4*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.3743152369210342, 0.3605644159336116, \
0.5388550643284117], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(23*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(23*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(23*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(4*Pi)/15]}, 
      {Cos[(11*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.40995394319447065, 0.3194626098436265, 0.5388550643284117], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(7*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(23*Pi)/30], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.4411011082778906, 0.27486070454834577, 0.5388550643284117], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{-(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, 
      {-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.46741547731267685, 0.22724736785573307, 0.5388550643284117], 
    Polygon[{{-(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], 
       Cos[(7*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(13*Pi)/15], Cos[(4*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}}]}, \
{RGBColor[0.48860874456504844, 0.17714426144632406, 0.5388550643284117], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(13*Pi)/15], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.5044487121640122, 0.1251003254386892, 0.5388550643284117], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Cos[(14*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(14*Pi)/15], Cos[(4*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.5147618341098276, 0.07168576408662207, \
0.5388550643284117], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(29*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(29*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(4*Pi)/15]}, 
      {Cos[(14*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.5194351176802965, 0.017485798502011197, 0.5388550643284117], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(7*Pi)/30]}, {-Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}, 
      {-Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(29*Pi)/30], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.5184173614026737, 0.0369057451501263, 0.5388550643284117], 
    Polygon[{{-Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/30]}, 
      {Cos[(31*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(4*Pi)/15]}, {-Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.5117197160277158, 0.09089294173537518, 0.5388550643284117], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(16*Pi)/15], Cos[(7*Pi)/30]}, \
{Cos[(16*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(4*Pi)/15]}, 
      {Cos[(31*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.4994155623597233, 0.14388429623040058, 0.5388550643284117], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(16*Pi)/15], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.4816397072810926, 0.19529922426620083, 0.5388550643284117], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Cos[(17*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(17*Pi)/15], Cos[(4*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.45858690677990177, \
0.24457441313195064, 0.5388550643284117], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, 
       Cos[(7*Pi)/30]}, {-(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, \
Cos[(4*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(17*Pi)/15], Cos[(4*Pi)/15]}}]}, \
{RGBColor[0.4305097321625505, 0.2911699935469405, 0.5388550643284117], 
    Polygon[{{-(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}, {-(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.3977158028296732, 0.3345754545813917, 0.5388550643284117], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {Cos[(37*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(37*Pi)/30], Cos[(4*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.3605644159336117, 0.3743152369210341, \
0.5388550643284117], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(19*Pi)/15], Cos[(7*Pi)/30]}, \
{Cos[(19*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(4*Pi)/15]}, 
      {Cos[(37*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.3194626098436266, 0.4099539431944706, 0.5388550643284117], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(19*Pi)/15], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.27486070454834577, 0.4411011082778906, 0.5388550643284117], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {-Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{-Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.22724736785573307, 0.46741547731267685, 0.5388550643284117], 
    Polygon[{{-Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(7*Pi)/30], \
Sin[(7*Pi)/30]*Sin[(41*Pi)/30], 
       Cos[(7*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(41*Pi)/30], Cos[(4*Pi)/15]}, 
      {-Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.17714426144632409, 0.48860874456504844, 0.5388550643284117], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(7*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(41*Pi)/30], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.1251003254386894, 0.5044487121640122, 0.5388550643284117], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {Cos[(43*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(43*Pi)/30], Cos[(4*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.07168576408662232, 0.5147618341098276, \
0.5388550643284117], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(22*Pi)/15], Cos[(7*Pi)/30]}, \
{Cos[(22*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(4*Pi)/15]}, 
      {Cos[(43*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.01748579850201128, 0.5194351176802965, 0.5388550643284117], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(7*Pi)/30]}, {0, -Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, 
      {0, -Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(22*Pi)/15], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.03690574515012643, 0.5184173614026737, 0.5388550643284117], 
    Polygon[{{0, -Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/30]}, 
      {Cos[(23*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(4*Pi)/15]}, {0, -Sin[(4*Pi)/15], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.09089294173537535, 0.5117197160277158, 0.5388550643284117], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(47*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(47*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(4*Pi)/15]}, 
      {Cos[(23*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.1438842962304006, 0.49941556235972334, 0.5388550643284117], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(7*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(47*Pi)/30], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.19529922426620083, 0.4816397072810926, 0.5388550643284117], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {Cos[(49*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(49*Pi)/30], Cos[(4*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.24457441313195066, \
0.45858690677990177, 0.5388550643284117], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/30]}, {Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, 
       Cos[(7*Pi)/30]}, {Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, \
Cos[(4*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(49*Pi)/30], Cos[(4*Pi)/15]}}]}, \
{RGBColor[0.2911699935469405, 0.4305097321625505, 0.5388550643284117], 
    Polygon[{{Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}, {Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.3345754545813918, 0.3977158028296731, 0.5388550643284117], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Cos[(26*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(26*Pi)/15], Cos[(4*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.37431523692103397, 0.3605644159336118, \
0.5388550643284117], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(53*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(53*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(4*Pi)/15]}, 
      {Cos[(26*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.40995394319447054, 0.3194626098436267, 0.5388550643284117], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(7*Pi)/30]}, {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(53*Pi)/30], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.4411011082778906, 0.27486070454834577, 0.5388550643284117], 
    Polygon[{{((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
      {(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, 
      {((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.46741547731267685, 0.2272473678557331, 0.5388550643284117], 
    Polygon[{{(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(28*Pi)/15], 
       Cos[(7*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(28*Pi)/15], Cos[(4*Pi)/15]}, 
      {(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}}]}, \
{RGBColor[0.48860874456504844, 0.17714426144632409, 0.5388550643284117], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(28*Pi)/15], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.5044487121640122, 0.1251003254386894, 0.5388550643284117], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
      {Cos[(29*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(29*Pi)/15], Cos[(4*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       Cos[(4*Pi)/15]}}]}, {RGBColor[0.5147618341098276, 0.07168576408662236, \
0.5388550643284117], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(7*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(59*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(59*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(4*Pi)/15]}, 
      {Cos[(29*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.5194351176802965, 0.01748579850201129, 0.5388550643284117], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(7*Pi)/30]}, {Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}, 
      {Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(59*Pi)/30], Cos[(4*Pi)/15]}}]}, 
   {RGBColor[0.5717009351188034, 0.040561272442972404, 0.4815116162525474], 
    Polygon[{{Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, {Cos[Pi/30]*Sin[(4*Pi)/15], \
Sin[Pi/30]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, 
      {((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 - \
Sqrt[5])/2]/2}, {(1 + Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.564329290101522, 0.1000980937451828, 0.4815116162525474], 
    Polygon[{{Cos[Pi/30]*Sin[(4*Pi)/15], Sin[Pi/30]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[Pi/15]*Sin[(4*Pi)/15], Sin[Pi/15]*Sin[(4*Pi)/15], 
       Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 - \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5507747352883924, 0.15853821938544824, 0.4815116162525474], 
    Polygon[{{Cos[Pi/15]*Sin[(4*Pi)/15], Sin[Pi/15]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.53118577721842, 0.21524136711787137, 0.4815116162525474], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(4*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.5057770366154725, \
0.26958628538999935, 0.4815116162525474], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(4*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, 
       Cos[(4*Pi)/15]}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.4748268969587166, 0.32097755990483745, 0.4815116162525474], 
    Polygon[{{(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, \
{((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {(1 + \
Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, \
Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.43867445445496484, 0.3688521371044856, 0.4815116162525474], 
    Polygon[{{((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {Cos[(7*Pi)/30]*Sin[(4*Pi)/15], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {(1 + \
Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.3977158028296732, \
0.4126854931027448, 0.4815116162525474], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(4*Pi)/15], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]^2, 
       Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.3523996936411974, 0.45199738047857907, 0.4815116162525474], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]^2, \
Cos[(4*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.3032226196648117, 0.4863570899673574, 0.4815116162525474], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
      {Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {(1 + \
Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2507233752139659, 0.5153881694016891, 0.4815116162525474], \
Polygon[{{Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {Cos[(11*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {(1 + \
Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.19547715299703652, 0.5387725482001476, 0.4815116162525474], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(4*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.13808924218564744, 0.5562540222151214, 0.4815116162525474], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {Cos[(13*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.07918839673984082, \
0.5676410607590687, 0.4815116162525474], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(7*Pi)/15], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.01941994664811513, 0.5728089050548111, 0.4815116162525474], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(4*Pi)/15]}, {0, Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, 
      {0, (1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.04056127244297236, \
0.5717009351188034, 0.4815116162525474], 
    Polygon[{{0, Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(4*Pi)/15]}, 
      {((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {0, (1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.1000980937451827, 0.564329290101522, 0.4815116162525474], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(17*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.1585382193854482, 0.5507747352883924, 0.4815116162525474], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(4*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.21524136711787134, 0.5311857772184201, 0.4815116162525474], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.26958628538999935, \
0.5057770366154726, 0.4815116162525474], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(4*Pi)/15]}, {-Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}, {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.32097755990483745, 0.4748268969587166, 0.4815116162525474], 
    Polygon[{{-Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.3688521371044854, 0.4386744544549649, 0.4815116162525474], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
      {Cos[(11*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.41268549310274494, \
0.39771580282967317, 0.4815116162525474], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(23*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.4519973804785792, 0.35239969364119733, 0.4815116162525474], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(4*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {-(1 + \
Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.4863570899673574, 0.3032226196648117, 0.4815116162525474], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5153881694016891, 0.2507233752139658, 0.4815116162525474], 
    Polygon[{{-(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], 
       Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5387725482001476, 0.19547715299703647, 0.4815116162525474], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(4*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5562540222151214, 0.13808924218564747, 0.4815116162525474], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
      {Cos[(14*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.5676410607590687, \
0.07918839673984093, 0.4815116162525474], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(29*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5728089050548111, 0.019419946648115183, 0.4815116162525474], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(4*Pi)/15]}, {-Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, 
      {(-1 - Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.5717009351188034, \
0.040561272442972425, 0.4815116162525474], 
    Polygon[{{-Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(4*Pi)/15]}, 
      {((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.564329290101522, 0.10009809374518272, 0.4815116162525474], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(16*Pi)/15], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5507747352883924, 0.15853821938544818, 0.4815116162525474], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(4*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5311857772184201, 0.21524136711787126, 0.4815116162525474], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
      {Cos[(17*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.5057770366154726, \
0.2695862853899993, 0.4815116162525474], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(4*Pi)/15]}, {-(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, 
       Cos[(4*Pi)/15]}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, \
Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.4748268969587166, 0.32097755990483745, 0.4815116162525474], 
    Polygon[{{-(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, \
Cos[(4*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {-(1 + \
Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.43867445445496484, 0.3688521371044856, 0.4815116162525474], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {Cos[(37*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-(1 + \
Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.3977158028296733, \
0.4126854931027448, 0.4815116162525474], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(19*Pi)/15], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.3523996936411974, 0.45199738047857907, 0.4815116162525474], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(4*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.3032226196648117, 0.4863570899673574, 0.4815116162525474], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
      {-Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {(-1 \
- Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, Sqrt[(5 \
- Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2507233752139658, 0.5153881694016891, 0.4815116162525474], 
    Polygon[{{-Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, \
Cos[(4*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(41*Pi)/30], 
       Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.19547715299703647, 0.5387725482001476, 0.4815116162525474], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(4*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.13808924218564766, 0.5562540222151214, 0.4815116162525474], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {Cos[(43*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.07918839673984121, \
0.5676410607590687, 0.4815116162525474], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(22*Pi)/15], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.019419946648115277, 0.5728089050548111, 0.4815116162525474], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(4*Pi)/15]}, {0, -Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, 
      {0, (-1 - Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.04056127244297257, \
0.5717009351188034, 0.4815116162525474], 
    Polygon[{{0, -Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(4*Pi)/15]}, 
      {((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {0, (-1 - Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.10009809374518291, 0.564329290101522, 0.4815116162525474], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(47*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.15853821938544826, 0.5507747352883924, 0.4815116162525474], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(4*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.21524136711787123, 0.5311857772184201, 0.4815116162525474], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.2695862853899993, \
0.5057770366154726, 0.4815116162525474], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(4*Pi)/15]}, {Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, 
       Cos[(4*Pi)/15]}, {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.32097755990483745, 0.4748268969587166, 0.4815116162525474], 
    Polygon[{{Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + \
Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.3688521371044856, 0.4386744544549648, 0.4815116162525474], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
      {Cos[(26*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[(5 \
- Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.4126854931027447, \
0.3977158028296734, 0.4815116162525474], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(53*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.451997380478579, 0.35239969364119744, 0.4815116162525474], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {(1 + \
Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.4863570899673574, 0.3032226196648117, 0.4815116162525474], 
    Polygon[{{((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
      {(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5153881694016891, 0.2507233752139658, 0.4815116162525474], 
    Polygon[{{(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(28*Pi)/15], 
       Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5387725482001476, 0.1954771529970365, 0.4815116162525474], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(4*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5562540222151214, 0.1380892421856477, 0.4815116162525474], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
      {Cos[(29*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.5676410607590687, \
0.07918839673984127, 0.4815116162525474], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(4*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(59*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5728089050548111, 0.01941994664811529, 0.4815116162525474], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(4*Pi)/15]}, {Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, 
      {(1 + Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.6187208337536595, \
0.04377240194694139, 0.41889262614623657], 
    Polygon[{{(1 + Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 - \
Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, 1/2}, {Sqrt[3]/2, 0, \
1/2}}]}, 
   {RGBColor[0.61075595437948, 0.10820655009304536, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, 
       1/2}, {(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, 1/2}}]}, \
{RGBColor[0.5960995049602188, 0.17145516463265364, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, 1/2}}]}, 
   {RGBColor[0.5749120646227723, 0.23282528050924664, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 1/2}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}}]}, 
   {RGBColor[0.5474257673972349, 0.2916445138907582, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{3/4, Sqrt[3]/4, 1/2}, 
      {(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 1/2}}]}, \
{RGBColor[0.5139417589078867, 0.3472684289475444, 0.41889262614623657], 
    Polygon[{{(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \

       Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, 1/2}, {3/4, Sqrt[3]/4, 1/2}}]}, 
   {RGBColor[0.47482689695871666, 0.3990875984261907, 0.41889262614623657], 
    Polygon[{{(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}}]}, 
   {RGBColor[0.4305097321625506, 0.4465342806620306, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.3814758126508584, 0.48908863987563167, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - \
Sqrt[5])/2]/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, {(Sqrt[3]*Cos[(4*Pi)/15])/2, \
(Sqrt[3]*Sin[(4*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.32826236430681743, 0.5262844416023776, 0.41889262614623657], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{Sqrt[3]/4, 3/4, 1/2}, 
      {Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}}]}, \
{RGBColor[0.27145240480611516, 0.5577141608548282, 0.41889262614623657], 
    Polygon[{{(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, 1/2}, 
      {Sqrt[3]/4, 3/4, 1/2}}]}, {RGBColor[0.21166835595328934, \
0.5830334470517621, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.14956522429818808, 0.6019648967952043, 0.41889262614623657], 
    Polygon[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}}]}, 
   {RGBColor[0.08582342474714062, 0.614301093160105, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.021141325794857276, 0.6199068781975756, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {0, (1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {0, Sqrt[3]/2, 1/2}, \
{(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.04377240194694133, 0.6187208337536596, 0.41889262614623657], 
    Polygon[{{0, (1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[(8*Pi)/15])/2, \
(Sqrt[3]*Sin[(8*Pi)/15])/2, 1/2}, {0, Sqrt[3]/2, 1/2}}]}, 
   {RGBColor[0.10820655009304525, 0.61075595437948, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.1714551646326536, 0.5960995049602188, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.2328252805092466, 0.5749120646227723, 0.41889262614623657], 
    Polygon[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 1/2}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}}]}, 
   {RGBColor[0.29164451389075813, 0.5474257673972349, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{-Sqrt[3]/4, 3/4, 1/2}, 
      {(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 1/2}}]}, \
{RGBColor[0.3472684289475444, 0.5139417589078867, 0.41889262614623657], 
    Polygon[{{(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       (1 + Sqrt[5])^2/16, Sqrt[(5 - Sqrt[5])/2]/2}, {-Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, {-Sqrt[3]/4, 3/4, 1/2}}]}, 
   {RGBColor[0.39908759842619057, 0.4748268969587167, 0.41889262614623657], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}}]}, 
   {RGBColor[0.4465342806620306, 0.4305097321625505, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.4890886398756318, 0.38147581265085834, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.5262844416023776, 0.32826236430681743, 0.41889262614623657], 
    Polygon[{{-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{-3/4, Sqrt[3]/4, 1/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}}]}, \
{RGBColor[0.5577141608548282, 0.27145240480611504, 0.41889262614623657], 
    Polygon[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 1/2}, 
      {-3/4, Sqrt[3]/4, 1/2}}]}, {RGBColor[0.5830334470517621, \
0.21166835595328926, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.6019648967952043, 0.14956522429818808, 0.41889262614623657], 
    Polygon[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}}]}, 
   {RGBColor[0.614301093160105, 0.08582342474714075, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.6199068781975756, 0.021141325794857332, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {-Sqrt[3]/2, 0, 1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.6187208337536595, 0.0437724019469414, 0.41889262614623657], 
    Polygon[{{(-1 - Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[(31*Pi)/30])/2, \
(Sqrt[3]*Sin[(31*Pi)/30])/2, 1/2}, {-Sqrt[3]/2, 0, 1/2}}]}, 
   {RGBColor[0.61075595437948, 0.10820655009304528, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.5960995049602188, 0.1714551646326536, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.5749120646227724, 0.2328252805092465, 0.41889262614623657], 
    Polygon[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}}]}, 
   {RGBColor[0.5474257673972349, 0.2916445138907581, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {-3/4, -Sqrt[3]/4, 1/2}, 
      {(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, 1/2}}]}, \
{RGBColor[0.5139417589078867, 0.3472684289475444, 0.41889262614623657], 
    Polygon[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, 
      {-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, {-3/4, \
-Sqrt[3]/4, 1/2}}]}, 
   {RGBColor[0.47482689695871666, 0.3990875984261907, 0.41889262614623657], 
    Polygon[{{-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, 1/2}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}}]}, 
   {RGBColor[0.4305097321625507, 0.4465342806620305, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.3814758126508584, 0.48908863987563167, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, Sqrt[(5 \
- Sqrt[5])/2]/2}, 
      {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.32826236430681743, 0.5262844416023776, 0.41889262614623657], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {-Sqrt[3]/4, -3/4, 1/2}, 
      {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}}]}, \
{RGBColor[0.27145240480611504, 0.5577141608548282, 0.41889262614623657], 
    Polygon[{{(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, 1/2}, 
      {-Sqrt[3]/4, -3/4, 1/2}}]}, {RGBColor[0.21166835595328928, \
0.5830334470517621, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.1495652242981883, 0.6019648967952043, 0.41889262614623657], 
    Polygon[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, 1/2}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}}]}, 
   {RGBColor[0.08582342474714105, 0.614301093160105, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.021141325794857432, 0.6199068781975756, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(22*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {0, (-1 - Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {0, -Sqrt[3]/2, 1/2}, \
{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.043772401946941555, 0.6187208337536595, 0.41889262614623657], 
    Polygon[{{0, (-1 - Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, 
       Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[(23*Pi)/15])/2, \
(Sqrt[3]*Sin[(23*Pi)/15])/2, 1/2}, {0, -Sqrt[3]/2, 1/2}}]}, 
   {RGBColor[0.1082065500930455, 0.6107559543794799, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.17145516463265364, 0.5960995049602187, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.2328252805092465, 0.5749120646227724, 0.41889262614623657], 
    Polygon[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}}]}, 
   {RGBColor[0.2916445138907581, 0.5474257673972349, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{Sqrt[3]/4, -3/4, 1/2}, 
      {(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, 1/2}}]}, \
{RGBColor[0.3472684289475444, 0.5139417589078867, 0.41889262614623657], 
    Polygon[{{(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       -(1 + Sqrt[5])^2/16, Sqrt[(5 - Sqrt[5])/2]/2}, {Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, {Sqrt[3]/4, -3/4, 1/2}}]}, 
   {RGBColor[0.3990875984261908, 0.4748268969587166, 0.41889262614623657], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, 1/2}, \
{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}}]}, 
   {RGBColor[0.44653428066203044, 0.43050973216255084, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.4890886398756316, 0.3814758126508585, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.5262844416023776, 0.32826236430681743, 0.41889262614623657], 
    Polygon[{{(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{3/4, -Sqrt[3]/4, 1/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}}]}, \
{RGBColor[0.5577141608548282, 0.27145240480611504, 0.41889262614623657], 
    Polygon[{{(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, 1/2}, 
      {3/4, -Sqrt[3]/4, 1/2}}]}, {RGBColor[0.5830334470517621, \
0.21166835595328928, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.6019648967952043, 0.14956522429818833, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, 1/2}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}}]}, 
   {RGBColor[0.614301093160105, 0.08582342474714111, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, 1/2}}]}, 
   {RGBColor[0.6199068781975756, 0.021141325794857446, 0.41889262614623657], 
    Polygon[{{((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(59*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {Sqrt[3]/2, 0, 1/2}, \
{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, 1/2}}]}, 
   {RGBColor[0.6589618974582522, 0.04650395185521568, 0.3516841607689501], 
    Polygon[{{Sqrt[3]/2, 0, 1/2}, {(Sqrt[3]*Cos[Pi/30])/2, \
(Sqrt[3]*Sin[Pi/30])/2, 1/2}, {Cos[Pi/30]*Sin[(11*Pi)/30], \
Sin[Pi/30]*Sin[(11*Pi)/30], 
       Cos[(11*Pi)/30]}, {Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.6504910486123562, 0.11512947283441216, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, 1/2}, \
{(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, 1/2}, 
      {Cos[Pi/15]*Sin[(11*Pi)/30], Sin[Pi/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[Pi/30]*Sin[(11*Pi)/30], Sin[Pi/30]*Sin[(11*Pi)/30], 
       Cos[(11*Pi)/30]}}]}, {RGBColor[0.6348932837138599, \
0.18249361121684382, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, 1/2}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[Pi/15]*Sin[(11*Pi)/30], Sin[Pi/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.6123394951390335, 0.24785831140554038, 0.3516841607689501], 
    Polygon[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 1/2}, 
      {Cos[(2*Pi)/15]*Sin[(11*Pi)/30], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.5830767869151866, 0.31050742406679166, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 1/2}, \
{3/4, Sqrt[3]/4, 1/2}, 
      {(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{Cos[(2*Pi)/15]*Sin[(11*Pi)/30], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], 
       Cos[(11*Pi)/30]}}]}, {RGBColor[0.5474257673972349, \
0.36975455241211136, 0.3516841607689501], 
    Polygon[{{3/4, Sqrt[3]/4, 1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, 1/2}, 
      {((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.5057770366154726, 0.4249505725050895, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 1/2}, 
      {Cos[(7*Pi)/30]*Sin[(11*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.45858690677990177, 0.4754907451990774, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 1/2}, 
      {Cos[(4*Pi)/15]*Sin[(11*Pi)/30], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(11*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(11*Pi)/30], Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.40637240282817066, 0.520821341785829, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 1/2}, \
{Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(4*Pi)/15]*Sin[(11*Pi)/30], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.3497055977921617, 0.5604457107631025, 0.3516841607689501], \
Polygon[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
      {Sqrt[3]/4, 3/4, 1/2}, {Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, \
Cos[(11*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.2892073450461409, 0.5939297192524505, 0.3516841607689501], 
    Polygon[{{Sqrt[3]/4, 3/4, 1/2}, {(Sqrt[3]*Cos[(11*Pi)/30])/2, \
(Sqrt[3]*Sin[(11*Pi)/30])/2, 1/2}, 
      {Cos[(11*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]^2, Cos[(11*Pi)/30]}, \
{Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.22554047610726674, 0.6209065094498847, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
      {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(11*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]^2, \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.1594025385147824, 0.6410805179967456, 0.3516841607689501], \
Polygon[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
      {(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 1/2}, \
{Cos[(13*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], 
       Cos[(11*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.0915181533532045, 0.654230714233711, 0.3516841607689501], \
Polygon[{{(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 1/2}, 
      {(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 1/2}, \
{Cos[(7*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], 
       Cos[(11*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(13*Pi)/30], Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.02263107615208411, 0.6602130218589535, 0.3516841607689501], \
Polygon[{{(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 1/2}, 
      {0, Sqrt[3]/2, 1/2}, {0, Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, \
{Cos[(7*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], 
       Cos[(11*Pi)/30]}}]}, {RGBColor[0.04650395185521562, \
0.6589618974582522, 0.3516841607689501], 
    Polygon[{{0, Sqrt[3]/2, 1/2}, {(Sqrt[3]*Cos[(8*Pi)/15])/2, \
(Sqrt[3]*Sin[(8*Pi)/15])/2, 1/2}, 
      {Cos[(8*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(11*Pi)/30]}, {0, Sin[(11*Pi)/30], Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.11512947283441206, 0.6504910486123562, 0.3516841607689501], \
Polygon[{{(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, 1/2}, 
      {(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 1/2}, \
{Cos[(17*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/30], 
       Cos[(11*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(8*Pi)/15], Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.18249361121684377, 0.6348932837138599, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 1/2}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
      {-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(17*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.24785831140554032, 0.6123394951390335, 0.3516841607689501], 
    Polygon[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 1/2}, 
      {Cos[(19*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(11*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.3105074240667916, 0.5830767869151866, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 1/2}, \
{-Sqrt[3]/4, 3/4, 1/2}, 
      {-Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Cos[(19*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], 
       Cos[(11*Pi)/30]}}]}, {RGBColor[0.36975455241211136, \
0.5474257673972349, 0.3516841607689501], 
    Polygon[{{-Sqrt[3]/4, 3/4, 1/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {-Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.4249505725050893, 0.5057770366154726, 0.3516841607689501], \
Polygon[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
      {(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 1/2}, \
{Cos[(11*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], 
       Cos[(11*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.4754907451990774, 0.45858690677990177, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, 1/2}, 
      {Cos[(23*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.5208213417858291, 0.40637240282817055, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, 1/2}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, 
      {-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(23*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.5604457107631025, 0.3497055977921617, 0.3516841607689501], \
Polygon[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, 
      {-3/4, Sqrt[3]/4, 1/2}, {-(Sqrt[3]*Sin[(11*Pi)/30])/2, \
Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.5939297192524506, 0.28920734504614076, 0.3516841607689501], 
    Polygon[{{-3/4, Sqrt[3]/4, 1/2}, {(Sqrt[3]*Cos[(13*Pi)/15])/2, \
(Sqrt[3]*Sin[(13*Pi)/15])/2, 1/2}, 
      {Cos[(13*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(11*Pi)/30]}, {-(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, 
       Cos[(11*Pi)/30]}}]}, {RGBColor[0.6209065094498847, \
0.22554047610726669, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(13*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.6410805179967456, 0.15940253851478242, 0.3516841607689501], 
    Polygon[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 1/2}, 
      {Cos[(14*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.654230714233711, 0.09151815335320465, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, 1/2}, 
      {Cos[(29*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(14*Pi)/15], Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.6602130218589534, 0.02263107615208417, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, 1/2}, \
{-Sqrt[3]/2, 0, 1/2}, {-Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, 
      {Cos[(29*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.6589618974582522, 0.0465039518552157, 0.3516841607689501], 
    Polygon[{{-Sqrt[3]/2, 0, 1/2}, {(Sqrt[3]*Cos[(31*Pi)/30])/2, \
(Sqrt[3]*Sin[(31*Pi)/30])/2, 1/2}, 
      {Cos[(31*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(11*Pi)/30]}, {-Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.6504910486123562, 0.11512947283441206, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, 1/2}, 
      {Cos[(16*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(31*Pi)/30]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(31*Pi)/30], Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.6348932837138599, 0.18249361121684377, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(16*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.6123394951390336, 0.2478583114055402, 0.3516841607689501], 
    Polygon[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, \
1/2}, {(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, 1/2}, 
      {Cos[(17*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.5830767869151867, 0.3105074240667916, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, 1/2}, \
{-3/4, -Sqrt[3]/4, 1/2}, 
      {-(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{Cos[(17*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/15], 
       Cos[(11*Pi)/30]}}]}, {RGBColor[0.5474257673972349, \
0.36975455241211136, 0.3516841607689501], 
    Polygon[{{-3/4, -Sqrt[3]/4, 1/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, \
-Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, 
      {-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}}]}, \

   {RGBColor[0.5057770366154726, 0.4249505725050895, 0.3516841607689501], 
    Polygon[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, 1/2}, 
      {Cos[(37*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(11*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.4585869067799019, 0.47549074519907736, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, 1/2}, 
      {Cos[(19*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(37*Pi)/30], Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.40637240282817066, 0.520821341785829, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(19*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.3497055977921617, 0.5604457107631025, 0.3516841607689501], 
    Polygon[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, \
{-Sqrt[3]/4, -3/4, 1/2}, 
      {-Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.28920734504614076, 0.5939297192524506, 0.3516841607689501], 
    Polygon[{{-Sqrt[3]/4, -3/4, 1/2}, {(Sqrt[3]*Cos[(41*Pi)/30])/2, \
(Sqrt[3]*Sin[(41*Pi)/30])/2, 1/2}, 
      {Cos[(41*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(11*Pi)/30]}, {-Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, 
       Cos[(11*Pi)/30]}}]}, {RGBColor[0.22554047610726669, \
0.6209065094498847, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, 1/2}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
      {-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(41*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.15940253851478264, 0.6410805179967456, 0.3516841607689501], 
    Polygon[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, \
1/2}, {(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, 1/2}, 
      {Cos[(43*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.09151815335320497, 0.6542307142337109, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, 1/2}, 
      {Cos[(22*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(43*Pi)/30], Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.02263107615208428, 0.6602130218589535, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, 1/2}, \
{0, -Sqrt[3]/2, 1/2}, {0, -Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
      {Cos[(22*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.04650395185521586, 0.6589618974582522, 0.3516841607689501], 
    Polygon[{{0, -Sqrt[3]/2, 1/2}, {(Sqrt[3]*Cos[(23*Pi)/15])/2, \
(Sqrt[3]*Sin[(23*Pi)/15])/2, 1/2}, 
      {Cos[(23*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(11*Pi)/30]}, {0, -Sin[(11*Pi)/30], Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.1151294728344123, 0.6504910486123561, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, 1/2}, 
      {Cos[(47*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(23*Pi)/15]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(23*Pi)/15], Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.18249361121684382, 0.6348932837138599, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
      {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(47*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.24785831140554018, 0.6123394951390336, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, 1/2}, 
      {Cos[(49*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.31050742406679155, 0.5830767869151866, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, 1/2}, \
{Sqrt[3]/4, -3/4, 1/2}, 
      {Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Cos[(49*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(49*Pi)/30], 
       Cos[(11*Pi)/30]}}]}, {RGBColor[0.36975455241211136, \
0.5474257673972349, 0.3516841607689501], 
    Polygon[{{Sqrt[3]/4, -3/4, 1/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
-(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.4249505725050895, 0.5057770366154724, 0.3516841607689501], \
Polygon[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
      {(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, 1/2}, \
{Cos[(26*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(26*Pi)/15], 
       Cos[(11*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.4754907451990773, 0.458586906779902, 0.3516841607689501], \
Polygon[{{(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, 1/2}, 
      {(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, 1/2}, \
{Cos[(53*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(53*Pi)/30], 
       Cos[(11*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(26*Pi)/15], Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.520821341785829, 0.4063724028281708, 0.3516841607689501], \
Polygon[{{(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, 1/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, {((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Cos[(53*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(53*Pi)/30], 
       Cos[(11*Pi)/30]}}]}, {RGBColor[0.5604457107631025, 0.3497055977921617, \
0.3516841607689501], 
    Polygon[{{(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, \
{3/4, -Sqrt[3]/4, 1/2}, 
      {(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.5939297192524506, 0.2892073450461408, 0.3516841607689501], 
    Polygon[{{3/4, -Sqrt[3]/4, 1/2}, {(Sqrt[3]*Cos[(28*Pi)/15])/2, \
(Sqrt[3]*Sin[(28*Pi)/15])/2, 1/2}, 
      {Cos[(28*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, 
       Cos[(11*Pi)/30]}}]}, {RGBColor[0.6209065094498847, \
0.22554047610726669, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, 1/2}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(28*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.6410805179967456, 0.15940253851478267, 0.3516841607689501], 
    Polygon[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, 1/2}, 
      {Cos[(29*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.6542307142337109, 0.09151815335320501, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, 1/2}, 
      {Cos[(59*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(29*Pi)/15], Cos[(11*Pi)/30]}}]}, \
{RGBColor[0.6602130218589534, 0.022631076152084293, 0.3516841607689501], 
    Polygon[{{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, 1/2}, \
{Sqrt[3]/2, 0, 1/2}, {Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, 
      {Cos[(59*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/30]}}]}, 
   {RGBColor[0.69198323671765, 0.04872599473538668, 0.28062257013163705], 
    Polygon[{{Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, \
{Cos[Pi/30]*Sin[(11*Pi)/30], Sin[Pi/30]*Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, (-1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.6830992267926321, 0.1207910129790141, 0.28062257013163705], 
    Polygon[{{Cos[Pi/30]*Sin[(11*Pi)/30], Sin[Pi/30]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[Pi/15]*Sin[(11*Pi)/30], Sin[Pi/15]*Sin[(11*Pi)/30], 
       Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.666731038791171, 0.19153261960729895, 0.28062257013163705], 
    Polygon[{{Cos[Pi/15]*Sin[(11*Pi)/30], Sin[Pi/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {(5 + \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6430580060062742, 0.2601757547743888, 0.28062257013163705], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(2*Pi)/15]*Sin[(11*Pi)/30], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(5 + \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.6123394951390335, \
0.32596834992689355, 0.28062257013163705], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(11*Pi)/30], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, 
       Cos[(11*Pi)/30]}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5749120646227723, 0.3881895676243367, 0.28062257013163705], 
    Polygon[{{(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, \
Cos[(11*Pi)/30]}, {((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       (-1 + Sqrt[5])/4}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.5311857772184201, 0.44615769918499815, 0.28062257013163705], 
    Polygon[{{((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(7*Pi)/30]*Sin[(11*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (-1 + Sqrt[5])/4}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.4816397072810926, \
0.49923763362888784, 0.28062257013163705], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(11*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(11*Pi)/30], 
       Sin[(4*Pi)/15]*Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.4268166919212052, 0.5468478160865483, 0.28062257013163705], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(11*Pi)/30], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.36731738356749405, 0.5884666194359021, 0.28062257013163705], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3037936690933134, 0.623638059358159, 0.28062257013163705], 
    Polygon[{{Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, \
Cos[(11*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]^2, 
       Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.23694152760763404, 0.6519767901974342, 0.28062257013163705], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]^2, \
Cos[(11*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.1674934051622831, 0.6731723268883916, 0.28062257013163705], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(13*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (-1 + Sqrt[5])/4}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.09621018991972587, \
0.6869924466955939, 0.28062257013163705], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(13*Pi)/30], Cos[(11*Pi)/30]}, 
      {Cos[(7*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(Sqrt[(5 \
+ Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.02387287570313157, 0.6932857334943876, 0.28062257013163705], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(11*Pi)/30]}, {0, Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
      {0, Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.048725994735386614, \
0.69198323671765, 0.28062257013163705], 
    Polygon[{{0, Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(11*Pi)/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {0, Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.12079101297901397, 0.6830992267926321, 0.28062257013163705], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(17*Pi)/30], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.1915326196072989, 0.666731038791171, 0.28062257013163705], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(17*Pi)/30], Cos[(11*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
       (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.26017575477438876, 0.6430580060062742, 0.28062257013163705], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(19*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (-1 + Sqrt[5])/4}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.32596834992689355, \
0.6123394951390335, 0.28062257013163705], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(19*Pi)/30], Cos[(11*Pi)/30]}, 
      {-Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
       (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3881895676243367, 0.5749120646227723, 0.28062257013163705], 
    Polygon[{{-Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, \
Cos[(11*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       (-1 + Sqrt[5])/4}, {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.44615769918499804, 0.5311857772184201, 0.28062257013163705], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(11*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.49923763362888784, 0.4816397072810926, 0.28062257013163705], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/30]}, 
      {Cos[(23*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5468478160865483, 0.4268166919212051, 0.28062257013163705], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(23*Pi)/30], Cos[(11*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(23*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5884666194359021, 0.36731738356749405, 0.28062257013163705], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, 
       (-1 + Sqrt[5])/4}, {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6236380593581591, 0.3037936690933133, 0.28062257013163705], 
    Polygon[{{-(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, \
Cos[(11*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(13*Pi)/15], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       (-1 + Sqrt[5])/4}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6519767901974342, 0.23694152760763398, 0.28062257013163705], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(13*Pi)/15], Cos[(11*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {(-5 - \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6731723268883916, 0.16749340516228312, 0.28062257013163705], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(14*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(-5 - \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.6869924466955939, \
0.09621018991972602, 0.28062257013163705], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(14*Pi)/15], Cos[(11*Pi)/30]}, 
      {Cos[(29*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.6932857334943876, 0.02387287570313163, 0.28062257013163705], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(29*Pi)/30], Cos[(11*Pi)/30]}, {-Sin[(11*Pi)/30], 0, \
Cos[(11*Pi)/30]}, 
      {-Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.69198323671765, 0.04872599473538669, \
0.28062257013163705], 
    Polygon[{{-Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(11*Pi)/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {-Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.6830992267926321, 0.12079101297901398, 0.28062257013163705], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(31*Pi)/30], Cos[(11*Pi)/30]}, 
      {Cos[(16*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.666731038791171, 0.1915326196072989, 0.28062257013163705], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(16*Pi)/15], Cos[(11*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {(-5 - \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6430580060062742, 0.26017575477438865, 0.28062257013163705], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(17*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(-5 - \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.6123394951390336, \
0.3259683499268935, 0.28062257013163705], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(17*Pi)/15], Cos[(11*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, 
       (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.5749120646227723, 0.3881895676243367, 0.28062257013163705], 
    Polygon[{{-(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, \
Cos[(11*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, {-Sqrt[(3*(5 \
+ Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.5311857772184201, 0.44615769918499815, 0.28062257013163705], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(37*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (-1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.48163970728109273, 0.4992376336288878, 0.28062257013163705], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(37*Pi)/30], Cos[(11*Pi)/30]}, 
      {Cos[(19*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.4268166919212052, 0.5468478160865482, 0.28062257013163705], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(19*Pi)/15], Cos[(11*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.36731738356749405, 0.5884666194359021, 0.28062257013163705], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {-Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
       (-1 + Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3037936690933133, 0.6236380593581591, 0.28062257013163705], 
    Polygon[{{-Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, \
Cos[(11*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(41*Pi)/30], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(41*Pi)/30])/2, 
       (-1 + Sqrt[5])/4}, {-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.23694152760763398, 0.6519767901974342, 0.28062257013163705], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(41*Pi)/30], Cos[(11*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
       (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.16749340516228334, 0.6731723268883916, 0.28062257013163705], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(43*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (-1 + Sqrt[5])/4}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.09621018991972637, \
0.6869924466955939, 0.28062257013163705], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(43*Pi)/30], Cos[(11*Pi)/30]}, 
      {Cos[(22*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.023872875703131746, 0.6932857334943876, 0.28062257013163705], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(22*Pi)/15], Cos[(11*Pi)/30]}, {0, -Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, 
      {0, -Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.048725994735386864, \
0.69198323671765, 0.28062257013163705], 
    Polygon[{{0, -Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(11*Pi)/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {0, -Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.12079101297901425, 0.6830992267926321, 0.28062257013163705], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(23*Pi)/15], Cos[(11*Pi)/30]}, 
      {Cos[(47*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.19153261960729898, 0.666731038791171, 0.28062257013163705], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(47*Pi)/30], Cos[(11*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
       (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.2601757547743886, 0.6430580060062742, 0.28062257013163705], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {Cos[(49*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (-1 + Sqrt[5])/4}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.3259683499268935, \
0.6123394951390336, 0.28062257013163705], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(49*Pi)/30], Cos[(11*Pi)/30]}, 
      {Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
       (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3881895676243367, 0.5749120646227723, 0.28062257013163705], 
    Polygon[{{Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, \
Cos[(11*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       (-1 + Sqrt[5])/4}, {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.44615769918499826, 0.5311857772184199, 0.28062257013163705], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(26*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (-1 + Sqrt[5])/4}, {Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, 
       -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.4992376336288876, 0.48163970728109284, 0.28062257013163705], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(26*Pi)/15], Cos[(11*Pi)/30]}, 
      {Cos[(53*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5468478160865482, 0.4268166919212053, 0.28062257013163705], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(53*Pi)/30], Cos[(11*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(53*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5884666194359021, 0.36731738356749405, 0.28062257013163705], 
    Polygon[{{((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
      {(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, 
       (-1 + Sqrt[5])/4}, {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6236380593581591, 0.3037936690933133, 0.28062257013163705], 
    Polygon[{{(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, \
Cos[(11*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(11*Pi)/30], 
       Sin[(11*Pi)/30]*Sin[(28*Pi)/15], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(28*Pi)/15])/2, 
       (-1 + Sqrt[5])/4}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6519767901974342, 0.23694152760763398, 0.28062257013163705], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(28*Pi)/15], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {(5 + \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6731723268883916, 0.1674934051622834, 0.28062257013163705], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
      {Cos[(29*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(5 + \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.6869924466955939, \
0.09621018991972641, 0.28062257013163705], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(29*Pi)/15], Cos[(11*Pi)/30]}, 
      {Cos[(59*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(59*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.6932857334943876, 0.023872875703131763, 0.28062257013163705], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(59*Pi)/30], Cos[(11*Pi)/30]}, {Sin[(11*Pi)/30], 0, \
Cos[(11*Pi)/30]}, 
      {Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
       (-1 + Sqrt[5])/4}}]}, {RGBColor[0.7174230628287676, \
0.05041418542066685, 0.20648641989191352], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
       (-1 + Sqrt[5])/4}, {Cos[Pi/30]*Sin[(13*Pi)/30], \
Sin[Pi/30]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, {Sin[(13*Pi)/30], 0, \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.708223226896465, 0.12512914150827345, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, (-1 + Sqrt[5])/4}, 
      {Cos[Pi/15]*Sin[(13*Pi)/30], Sin[Pi/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[Pi/30]*Sin[(13*Pi)/30], Sin[Pi/30]*Sin[(13*Pi)/30], 
       Cos[(13*Pi)/30]}}]}, {RGBColor[0.6912639490850464, \
0.19847315653655914, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, (-1 + Sqrt[5])/4}, 
      {(5 + Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, \
{Cos[Pi/15]*Sin[(13*Pi)/30], Sin[Pi/15]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}}]}, \

   {RGBColor[0.666731038791171, 0.2696426581286521, 0.20648641989191352], 
    Polygon[{{(5 + Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 \
+ Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(2*Pi)/15]*Sin[(13*Pi)/30], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], 
       Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.6348932837138599, 0.33785789833193386, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}, 
      {Cos[(2*Pi)/15]*Sin[(13*Pi)/30], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.5960995049602188, 0.4023714966997804, 0.20648641989191352], 
    Polygon[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, {((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       Cos[(13*Pi)/30]}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.5507747352883924, 0.4624766287481351, 0.20648641989191352], 
    Polygon[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 \
+ Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(7*Pi)/30]*Sin[(13*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.4994155623597234, 0.5175147700724689, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(4*Pi)/15]*Sin[(13*Pi)/30], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(13*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.442584688020416, 0.5668829112789608, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
      {Cos[(4*Pi)/15]*Sin[(13*Pi)/30], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.3809047632223568, 0.6100401646816048, 0.20648641989191352], 
    Polygon[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.3150515661289873, 0.6465136903808856, 0.20648641989191352], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/30]*Sin[(13*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], 
       Cos[(13*Pi)/30]}, {Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.24574659814832983, 0.6759038767966659, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(13*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], 
       Cos[(13*Pi)/30]}}]}, {RGBColor[0.17374917901257741, \
0.6978887188962826, 0.20648641989191352], 
    Polygon[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 \
+ Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]^2, Cos[(13*Pi)/30]}, 
      {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.09984812751221013, 0.7122273461490682, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(7*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]^2, 
       Cos[(13*Pi)/30]}}]}, {RGBColor[0.024853119032255105, \
0.7187626615542906, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {0, Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {0, Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(7*Pi)/15], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.050414185420666786, 0.7174230628287677, 0.20648641989191352], 
    Polygon[{{0, Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       (-1 + Sqrt[5])/4}, {Cos[(8*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(8*Pi)/15], Cos[(13*Pi)/30]}, 
      {0, Sin[(13*Pi)/30], Cos[(13*Pi)/30]}}]}, {RGBColor[0.1251291415082733, \
0.708223226896465, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(17*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(8*Pi)/15], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.1984731565365591, 0.6912639490850464, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], 
       Cos[(13*Pi)/30]}}]}, {RGBColor[0.26964265812865207, 0.666731038791171, \
0.20648641989191352], 
    Polygon[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 \
+ Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(19*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], 
       Cos[(13*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.3378578983319338, 0.6348932837138599, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {-Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 
       Cos[(13*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(19*Pi)/30], Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.4023714966997804, 0.5960995049602188, 0.20648641989191352], 
    Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, {-(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
       Cos[(13*Pi)/30]}, {-Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.462476628748135, 0.5507747352883926, 0.20648641989191352], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(11*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(13*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.5175147700724689, 0.49941556235972334, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(23*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(11*Pi)/15], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.5668829112789608, 0.442584688020416, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
      {-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
      {Cos[(23*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.6100401646816048, 0.3809047632223568, 0.20648641989191352], 
    Polygon[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 \
+ Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
      {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, 
       Cos[(13*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.6465136903808856, 0.3150515661289871, 0.20648641989191352], 
    Polygon[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], 
       Cos[(13*Pi)/30]}, {-(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.6759038767966659, 0.24574659814832975, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], 
       Cos[(13*Pi)/30]}}]}, {RGBColor[0.6978887188962826, \
0.17374917901257747, 0.20648641989191352], 
    Polygon[{{(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 \
+ Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(14*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], 
       Cos[(13*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.7122273461490682, 0.0998481275122103, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(29*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(14*Pi)/15], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.7187626615542906, 0.02485311903225517, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {-Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {-Sin[(13*Pi)/30], 0, \
Cos[(13*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(29*Pi)/30], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.7174230628287676, 0.05041418542066686, 0.20648641989191352], 
    Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(31*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(31*Pi)/30], 
       Cos[(13*Pi)/30]}, {-Sin[(13*Pi)/30], 0, Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.708223226896465, 0.1251291415082733, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(16*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(31*Pi)/30]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(31*Pi)/30], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.6912639490850464, 0.1984731565365591, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {(-5 - Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, \
{Cos[(16*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(16*Pi)/15], 
       Cos[(13*Pi)/30]}}]}, {RGBColor[0.6667310387911711, \
0.26964265812865196, 0.20648641989191352], 
    Polygon[{{(-5 - Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(17*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/15], 
       Cos[(13*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.6348932837138599, 0.3378578983319338, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, 
       Cos[(13*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(17*Pi)/15], Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.5960995049602188, 0.4023714966997804, 0.20648641989191352], 
    Polygon[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       Cos[(13*Pi)/30]}, {-(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.5507747352883924, 0.4624766287481351, 0.20648641989191352], 
    Polygon[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(37*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.49941556235972345, 0.5175147700724688, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(19*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(37*Pi)/30], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.4425846880204161, 0.5668829112789608, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
      {Cos[(19*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.3809047632223568, 0.6100401646816048, 0.20648641989191352], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
      {-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {-Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, 
       Cos[(13*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.31505156612898716, 0.6465136903808856, 0.20648641989191352], 
    Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(41*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(41*Pi)/30], 
       Cos[(13*Pi)/30]}, {-Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.24574659814832975, 0.6759038767966659, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(41*Pi)/30], 
       Cos[(13*Pi)/30]}}]}, {RGBColor[0.1737491790125777, 0.6978887188962826, \
0.20648641989191352], 
    Polygon[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, \
(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(43*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(43*Pi)/30], 
       Cos[(13*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.09984812751221064, 0.7122273461490681, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(22*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(43*Pi)/30], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.02485311903225529, 0.7187626615542906, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {0, -Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {0, -Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(22*Pi)/15], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.05041418542066704, 0.7174230628287676, 0.20648641989191352], 
    Polygon[{{0, -Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(23*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/15], 
       Cos[(13*Pi)/30]}, {0, -Sin[(13*Pi)/30], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.1251291415082736, 0.7082232268964649, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(47*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(23*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(23*Pi)/15], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.19847315653655917, 0.6912639490850464, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Cos[(47*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(47*Pi)/30], 
       Cos[(13*Pi)/30]}}]}, {RGBColor[0.26964265812865196, \
0.6667310387911711, 0.20648641989191352], 
    Polygon[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, (-1 \
+ Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(49*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(49*Pi)/30], 
       Cos[(13*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.33785789833193375, 0.6348932837138599, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, 
       Cos[(13*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(49*Pi)/30], Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.4023714966997804, 0.5960995049602188, 0.20648641989191352], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, \
{Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.4624766287481353, 0.5507747352883924, 0.20648641989191352], 
    Polygon[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(26*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.5175147700724687, 0.4994155623597236, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(53*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(26*Pi)/15], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.5668829112789607, 0.4425846880204162, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
      {((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
      {Cos[(53*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.6100401646816048, 0.3809047632223568, 0.20648641989191352], 
    Polygon[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 \
+ Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
      {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, 
       Cos[(13*Pi)/30]}, {((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.6465136903808856, 0.3150515661289872, 0.20648641989191352], 
    Polygon[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(28*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(28*Pi)/15], 
       Cos[(13*Pi)/30]}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.6759038767966659, 0.24574659814832978, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(28*Pi)/15], 
       Cos[(13*Pi)/30]}}]}, {RGBColor[0.6978887188962826, \
0.17374917901257775, 0.20648641989191352], 
    Polygon[{{(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 \
+ Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(29*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/15], 
       Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}]}, 
   {RGBColor[0.7122273461490681, 0.0998481275122107, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Cos[(59*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(29*Pi)/15], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.7187626615542906, 0.024853119032255306, 0.20648641989191352], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {Sin[(13*Pi)/30], 0, \
Cos[(13*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(59*Pi)/30], Cos[(13*Pi)/30]}}]}, \
{RGBColor[0.7350026517331055, 0.05155002774063165, 0.13008796122579297], 
    Polygon[{{Sin[(13*Pi)/30], 0, Cos[(13*Pi)/30]}, \
{Cos[Pi/30]*Sin[(13*Pi)/30], Sin[Pi/30]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, 
      {Cos[Pi/30]*Sin[(7*Pi)/15], Sin[Pi/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, \
{Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.7255877851211819, 0.12809632897821185, 0.13008796122579297], 
    Polygon[{{Cos[Pi/30]*Sin[(13*Pi)/30], Sin[Pi/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[Pi/15]*Sin[(13*Pi)/30], Sin[Pi/15]*Sin[(13*Pi)/30], 
       Cos[(13*Pi)/30]}, {Cos[Pi/15]*Sin[(7*Pi)/15], \
Sin[Pi/15]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
      {Cos[Pi/30]*Sin[(7*Pi)/15], Sin[Pi/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.708223226896465, 0.20323918002962665, 0.13008796122579297], 
    Polygon[{{Cos[Pi/15]*Sin[(13*Pi)/30], Sin[Pi/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}, {Cos[Pi/15]*Sin[(7*Pi)/15], \
Sin[Pi/15]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.6830992267926321, 0.27615530009410416, 0.13008796122579297], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
      {Cos[(2*Pi)/15]*Sin[(13*Pi)/30], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.6504910486123561, 0.3460458049015389, \
0.13008796122579297], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(13*Pi)/30], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, 
       Cos[(13*Pi)/30]}, {(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, \
Cos[(7*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(2*Pi)/15]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}}]}, \
{RGBColor[0.61075595437948, 0.4121449594557323, 0.13008796122579297], 
    Polygon[{{(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}, {((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}, {(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.5643292901015221, 0.4737285675872512, 0.13008796122579297], 
    Polygon[{{((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
      {Cos[(7*Pi)/30]*Sin[(13*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.5117197160277158, 0.5301219063982081, \
0.13008796122579297], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(13*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(4*Pi)/15]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(4*Pi)/15]*Sin[(7*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, 
      {Cos[(7*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.45350363366087504, 0.5807071186675254, 0.13008796122579297], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(13*Pi)/30], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.39031887058190917, 0.6249299822239445, 0.13008796122579297], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
      {Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.32285769227737326, 0.6623059821201116, 0.13008796122579297], 
    Polygon[{{Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(13*Pi)/30], 
       Cos[(13*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
      {Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}}]}, \
{RGBColor[0.2518592175339307, 0.692425619079734, 0.13008796122579297], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.17810132049825678, 0.7149588960573425, 0.13008796122579297], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
      {Cos[(13*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]^2, Cos[(13*Pi)/30]}, \
{Cos[(13*Pi)/30]*Sin[(7*Pi)/15], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], 
       Cos[(7*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.10239210812510666, 0.7296589337549793, 0.13008796122579297], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]^2, \
Cos[(13*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(7*Pi)/15], Cos[(13*Pi)/30]}, \
{Cos[(7*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]^2, Cos[(7*Pi)/15]}, 
      {Cos[(13*Pi)/30]*Sin[(7*Pi)/15], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.02556106638841174, 0.7363646754834481, 0.13008796122579297], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(13*Pi)/30]}, {0, Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, 
      {0, Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]^2, Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.051550027740631596, 0.7350026517331055, 0.13008796122579297], 
    Polygon[{{0, Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(13*Pi)/30]}, 
      {Cos[(8*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/15]}, {0, Sin[(7*Pi)/15], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.12809632897821174, 0.7255877851211819, 0.13008796122579297], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(17*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/15]}, 
      {Cos[(8*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.20323918002962663, 0.708223226896465, 0.13008796122579297], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(17*Pi)/30], Cos[(13*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(17*Pi)/30], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.2761553000941041, 0.6830992267926322, 0.13008796122579297], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
      {Cos[(19*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(19*Pi)/30], Cos[(7*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.3460458049015389, 0.6504910486123562, \
0.13008796122579297], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(19*Pi)/30], Cos[(13*Pi)/30]}, 
      {-Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{-Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.4121449594557323, 0.61075595437948, 0.13008796122579297], 
    Polygon[{{-Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}, {-Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.473728567587251, 0.5643292901015222, 0.13008796122579297], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
      {Cos[(11*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(11*Pi)/15], Cos[(7*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.5301219063982081, 0.5117197160277158, \
0.13008796122579297], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(11*Pi)/15], Cos[(13*Pi)/30]}, 
      {Cos[(23*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(23*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(23*Pi)/30], Cos[(7*Pi)/15]}, \
{Cos[(11*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.5807071186675254, 0.453503633660875, 0.13008796122579297], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(23*Pi)/30], Cos[(13*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(23*Pi)/30], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.6249299822239445, 0.39031887058190917, 0.13008796122579297], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}, \
{-(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, 
      {-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.6623059821201117, 0.3228576922773731, 0.13008796122579297], 
    Polygon[{{-(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(7*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}}]}, \
{RGBColor[0.692425619079734, 0.25185921753393065, 0.13008796122579297], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(13*Pi)/15], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.7149588960573425, 0.1781013204982568, 0.13008796122579297], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
      {Cos[(14*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(14*Pi)/15], Cos[(7*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.7296589337549793, 0.10239210812510682, \
0.13008796122579297], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(14*Pi)/15], Cos[(13*Pi)/30]}, 
      {Cos[(29*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(29*Pi)/30], Cos[(7*Pi)/15]}, \
{Cos[(14*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.7363646754834481, 0.02556106638841181, 0.13008796122579297], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(29*Pi)/30], Cos[(13*Pi)/30]}, {-Sin[(13*Pi)/30], 0, \
Cos[(13*Pi)/30]}, 
      {-Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(29*Pi)/30], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.7350026517331055, 0.05155002774063167, 0.13008796122579297], 
    Polygon[{{-Sin[(13*Pi)/30], 0, Cos[(13*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(13*Pi)/30]}, 
      {Cos[(31*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/15]}, {-Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.7255877851211819, 0.12809632897821177, 0.13008796122579297], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(31*Pi)/30], Cos[(13*Pi)/30]}, 
      {Cos[(16*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(16*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.708223226896465, 0.2032391800296266, 0.13008796122579297], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(16*Pi)/15], Cos[(13*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(16*Pi)/15], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.6830992267926324, 0.276155300094104, 0.13008796122579297], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
      {Cos[(17*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(17*Pi)/15], Cos[(7*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.6504910486123563, 0.34604580490153886, \
0.13008796122579297], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(17*Pi)/15], Cos[(13*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}, \
{-(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, 
      {Cos[(17*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.61075595437948, 0.4121449594557323, 0.13008796122579297], 
    Polygon[{{-(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{-(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.5643292901015221, 0.4737285675872512, 0.13008796122579297], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
      {Cos[(37*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(37*Pi)/30], Cos[(7*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.511719716027716, 0.5301219063982081, \
0.13008796122579297], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(37*Pi)/30], Cos[(13*Pi)/30]}, 
      {Cos[(19*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(19*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[(37*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.4535036336608751, 0.5807071186675254, 0.13008796122579297], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(19*Pi)/15], Cos[(13*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(19*Pi)/15], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.39031887058190917, 0.6249299822239445, 0.13008796122579297], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
      {-Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{-Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.32285769227737315, 0.6623059821201117, 0.13008796122579297], 
    Polygon[{{-Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(41*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(7*Pi)/15]}, 
      {-Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}}]}, \
{RGBColor[0.2518592175339307, 0.692425619079734, 0.13008796122579297], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(41*Pi)/30], Cos[(13*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{Cos[(41*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(41*Pi)/30], 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.17810132049825705, 0.7149588960573425, \
0.13008796122579297], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
      {Cos[(43*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(43*Pi)/30], Cos[(7*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.10239210812510717, 0.7296589337549791, \
0.13008796122579297], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(43*Pi)/30], Cos[(13*Pi)/30]}, 
      {Cos[(22*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(22*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[(43*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.02556106638841193, 0.7363646754834481, 0.13008796122579297], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(22*Pi)/15], Cos[(13*Pi)/30]}, {0, -Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, 
      {0, -Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(22*Pi)/15], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.05155002774063186, 0.7350026517331055, 0.13008796122579297], 
    Polygon[{{0, -Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(13*Pi)/30]}, 
      {Cos[(23*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/15]}, {0, -Sin[(7*Pi)/15], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.12809632897821202, 0.7255877851211818, 0.13008796122579297], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(23*Pi)/15], Cos[(13*Pi)/30]}, 
      {Cos[(47*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(47*Pi)/30], Cos[(7*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.20323918002962668, 0.708223226896465, 0.13008796122579297], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(47*Pi)/30], Cos[(13*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{Cos[(47*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(47*Pi)/30], 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.27615530009410394, 0.6830992267926324, \
0.13008796122579297], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
      {Cos[(49*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(49*Pi)/30], Cos[(7*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.3460458049015388, 0.6504910486123563, \
0.13008796122579297], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(49*Pi)/30], Cos[(13*Pi)/30]}, 
      {Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.4121449594557323, 0.61075595437948, 0.13008796122579297], 
    Polygon[{{Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}, {Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.4737285675872513, 0.564329290101522, 0.13008796122579297], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
      {Cos[(26*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(26*Pi)/15], Cos[(7*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.5301219063982079, 0.511719716027716, \
0.13008796122579297], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(26*Pi)/15], Cos[(13*Pi)/30]}, 
      {Cos[(53*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(53*Pi)/30], Cos[(7*Pi)/15]}, \
{Cos[(26*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.5807071186675254, 0.4535036336608752, 0.13008796122579297], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(53*Pi)/30], Cos[(13*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(53*Pi)/30], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.6249299822239445, 0.39031887058190917, 0.13008796122579297], 
    Polygon[{{((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
      {(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}, \
{(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, 
      {((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.6623059821201117, 0.32285769227737315, 0.13008796122579297], 
    Polygon[{{(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(13*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(28*Pi)/15], Cos[(13*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(7*Pi)/15]}, 
      {(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}}]}, \
{RGBColor[0.692425619079734, 0.2518592175339307, 0.13008796122579297], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(28*Pi)/15], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(28*Pi)/15], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.7149588960573425, 0.17810132049825708, 0.13008796122579297], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
      {Cos[(29*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(29*Pi)/15], Cos[(7*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       Cos[(7*Pi)/15]}}]}, {RGBColor[0.7296589337549791, 0.10239210812510723, \
0.13008796122579297], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(29*Pi)/15], Cos[(13*Pi)/30]}, 
      {Cos[(59*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(59*Pi)/30], Cos[(7*Pi)/15]}, \
{Cos[(29*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.7363646754834481, 0.02556106638841195, 0.13008796122579297], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(59*Pi)/30], Cos[(13*Pi)/30]}, {Sin[(13*Pi)/30], 0, \
Cos[(13*Pi)/30]}, 
      {Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(59*Pi)/30], Cos[(7*Pi)/15]}}]}, 
   {RGBColor[0.7445293977758624, 0.05212107716913328, 0.05226423163382673], 
    Polygon[{{Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, {Cos[Pi/30]*Sin[(7*Pi)/15], \
Sin[Pi/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
      {Cos[Pi/30], Sin[Pi/30], 0}, {1, 0, 0}}]}, \
{RGBColor[0.7350026517331055, 0.12966006626198484, 0.05226423163382673], 
    Polygon[{{Cos[Pi/30]*Sin[(7*Pi)/15], Sin[Pi/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[Pi/15]*Sin[(7*Pi)/15], Sin[Pi/15]*Sin[(7*Pi)/15], 
       Cos[(7*Pi)/15]}, {Cos[Pi/15], Sin[Pi/15], 0}, {Cos[Pi/30], Sin[Pi/30], \
0}}]}, 
   {RGBColor[0.7174230628287676, 0.2057784725357569, 0.05226423163382673], 
    Polygon[{{Cos[Pi/15]*Sin[(7*Pi)/15], Sin[Pi/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, {Cos[Pi/15], Sin[Pi/15], 0}}]}, 
   {RGBColor[0.69198323671765, 0.2796423268025134, 0.05226423163382673], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(7*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(2*Pi)/15], Sin[(2*Pi)/15], 0}, 
      {Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}}]}, \
{RGBColor[0.6589618974582522, 0.35044236121790256, 0.05226423163382673], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(7*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, 
       Cos[(7*Pi)/15]}, {Sqrt[3]/2, 1/2, 0}, {Cos[(2*Pi)/15], Sin[(2*Pi)/15], \
0}}]}, 
   {RGBColor[0.6187208337536595, 0.4174028757890097, 0.05226423163382673], 
    Polygon[{{(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {(1 + \
Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, {Sqrt[3]/2, 1/2, 0}}]}, 
   {RGBColor[0.5717009351188034, 0.47979023710580526, 0.05226423163382673], 
    Polygon[{{((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {Cos[(7*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(7*Pi)/30], Sin[(7*Pi)/30], 0}, 
      {(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}}]}, \
{RGBColor[0.5184173614026737, 0.5369209161823076, 0.05226423163382673], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(4*Pi)/15], \
Sin[(4*Pi)/15], 0}, {Cos[(7*Pi)/30], Sin[(7*Pi)/30], 0}}]}, 
   {RGBColor[0.459453898589209, 0.5881689773431916, 0.05226423163382673], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(7*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {Sqrt[(5 - \
Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}, {Cos[(4*Pi)/15], Sin[(4*Pi)/15], 0}}]}, 
   {RGBColor[0.39545656271589147, 0.6329729361060323, 0.05226423163382673], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
      {Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {1/2, \
Sqrt[3]/2, 0}, {Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}}]}, 
   {RGBColor[0.3271265219868527, 0.6708419109227928, 0.05226423163382673], 
    Polygon[{{Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(7*Pi)/15], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], 
       Cos[(7*Pi)/15]}, {Cos[(11*Pi)/30], Sin[(11*Pi)/30], 0}, {1/2, \
Sqrt[3]/2, 0}}]}, 
   {RGBColor[0.25521241462730027, 0.7013610013807882, 0.05226423163382673], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(7*Pi)/15], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {(-1 + \
Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
      {Cos[(11*Pi)/30], Sin[(11*Pi)/30], 0}}]}, \
{RGBColor[0.18050214664645986, 0.7241958339384306, 0.05226423163382673], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {Cos[(13*Pi)/30]*Sin[(7*Pi)/15], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(13*Pi)/30], Sin[(13*Pi)/30], 0}, 
      {(-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}}]}, \
{RGBColor[0.10381425937445836, 0.7390962253917224, 0.05226423163382673], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(7*Pi)/15], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]^2, 
       Cos[(7*Pi)/15]}, {Cos[(7*Pi)/15], Sin[(7*Pi)/15], 0}, \
{Cos[(13*Pi)/30], Sin[(13*Pi)/30], 0}}]}, 
   {RGBColor[0.02598896135221991, 0.745898923933794, 0.05226423163382673], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]^2, \
Cos[(7*Pi)/15]}, {0, Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {0, 1, 0}, 
      {Cos[(7*Pi)/15], Sin[(7*Pi)/15], 0}}]}, {RGBColor[0.05212107716913321, \
0.7445293977758624, 0.05226423163382673], 
    Polygon[{{0, Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/15]}, 
      {Cos[(8*Pi)/15], Sin[(8*Pi)/15], 0}, {0, 1, 0}}]}, \
{RGBColor[0.12966006626198473, 0.7350026517331055, 0.05226423163382673], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(17*Pi)/30], Cos[(7*Pi)/15]}, {Cos[(17*Pi)/30], \
Sin[(17*Pi)/30], 0}, {Cos[(8*Pi)/15], Sin[(8*Pi)/15], 0}}]}, 
   {RGBColor[0.20577847253575687, 0.7174230628287676, 0.05226423163382673], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {-(-1 + \
Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
      {Cos[(17*Pi)/30], Sin[(17*Pi)/30], 0}}]}, \
{RGBColor[0.27964232680251333, 0.69198323671765, 0.05226423163382673], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(19*Pi)/30], Sin[(19*Pi)/30], 0}, 
      {-(-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}}]}, \
{RGBColor[0.3504423612179025, 0.6589618974582522, 0.05226423163382673], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/15]}, {-Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}, {-1/2, Sqrt[3]/2, 0}, {Cos[(19*Pi)/30], \
Sin[(19*Pi)/30], 0}}]}, 
   {RGBColor[0.4174028757890097, 0.6187208337536595, 0.05226423163382673], 
    Polygon[{{-Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {-Sqrt[(5 - \
Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}, {-1/2, Sqrt[3]/2, 0}}]}, 
   {RGBColor[0.47979023710580504, 0.5717009351188035, 0.05226423163382673], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
      {Cos[(11*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(11*Pi)/15], Sin[(11*Pi)/15], 0}, 
      {-Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}}]}, \
{RGBColor[0.5369209161823076, 0.5184173614026737, 0.05226423163382673], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(23*Pi)/30], Cos[(7*Pi)/15]}, {Cos[(23*Pi)/30], \
Sin[(23*Pi)/30], 0}, {Cos[(11*Pi)/15], Sin[(11*Pi)/15], 0}}]}, 
   {RGBColor[0.5881689773431917, 0.45945389858920893, 0.05226423163382673], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(7*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {-(1 + \
Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, 
      {Cos[(23*Pi)/30], Sin[(23*Pi)/30], 0}}]}, {RGBColor[0.6329729361060323, \
0.39545656271589147, 0.05226423163382673], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{-Sqrt[3]/2, 1/2, 0}, {-(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}}]}, 
   {RGBColor[0.6708419109227928, 0.32712652198685255, 0.05226423163382673], 
    Polygon[{{-(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], 
       Cos[(7*Pi)/15]}, {Cos[(13*Pi)/15], Sin[(13*Pi)/15], 0}, {-Sqrt[3]/2, \
1/2, 0}}]}, 
   {RGBColor[0.7013610013807882, 0.25521241462730015, 0.05226423163382673], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(7*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, 
      {Cos[(13*Pi)/15], Sin[(13*Pi)/15], 0}}]}, {RGBColor[0.7241958339384306, \
0.18050214664645986, 0.05226423163382673], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
      {Cos[(14*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(14*Pi)/15], Sin[(14*Pi)/15], 0}, 
      {-Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}}]}, \
{RGBColor[0.7390962253917224, 0.10381425937445851, 0.05226423163382673], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(29*Pi)/30], Cos[(7*Pi)/15]}, {Cos[(29*Pi)/30], \
Sin[(29*Pi)/30], 0}, {Cos[(14*Pi)/15], Sin[(14*Pi)/15], 0}}]}, 
   {RGBColor[0.745898923933794, 0.02598896135221998, 0.05226423163382673], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(7*Pi)/15]}, {-Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, {-1, 0, 0}, 
      {Cos[(29*Pi)/30], Sin[(29*Pi)/30], 0}}]}, {RGBColor[0.7445293977758624, \
0.05212107716913329, 0.05226423163382673], 
    Polygon[{{-Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/15]}, 
      {Cos[(31*Pi)/30], Sin[(31*Pi)/30], 0}, {-1, 0, 0}}]}, \
{RGBColor[0.7350026517331055, 0.12966006626198473, 0.05226423163382673], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(16*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(16*Pi)/15], \
Sin[(16*Pi)/15], 0}, {Cos[(31*Pi)/30], Sin[(31*Pi)/30], 0}}]}, 
   {RGBColor[0.7174230628287676, 0.20577847253575685, 0.05226423163382673], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(7*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, 
      {Cos[(16*Pi)/15], Sin[(16*Pi)/15], 0}}]}, {RGBColor[0.6919832367176502, \
0.2796423268025132, 0.05226423163382673], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
      {Cos[(17*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(17*Pi)/15], Sin[(17*Pi)/15], 0}, 
      {-Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}}]}, \
{RGBColor[0.6589618974582523, 0.3504423612179025, 0.05226423163382673], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/15]}, {-(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, 
       Cos[(7*Pi)/15]}, {-Sqrt[3]/2, -1/2, 0}, {Cos[(17*Pi)/15], \
Sin[(17*Pi)/15], 0}}]}, 
   {RGBColor[0.6187208337536595, 0.4174028757890097, 0.05226423163382673], 
    Polygon[{{-(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, \
Cos[(7*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {-(1 + \
Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}, {-Sqrt[3]/2, -1/2, 0}}]}, 
   {RGBColor[0.5717009351188034, 0.47979023710580526, 0.05226423163382673], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {Cos[(37*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(37*Pi)/30], Sin[(37*Pi)/30], 0}, 
      {-(1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}}]}, \
{RGBColor[0.5184173614026738, 0.5369209161823076, 0.05226423163382673], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(19*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(19*Pi)/15], \
Sin[(19*Pi)/15], 0}, {Cos[(37*Pi)/30], Sin[(37*Pi)/30], 0}}]}, 
   {RGBColor[0.45945389858920904, 0.5881689773431916, 0.05226423163382673], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {-Sqrt[(5 - \
Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, 
      {Cos[(19*Pi)/15], Sin[(19*Pi)/15], 0}}]}, \
{RGBColor[0.39545656271589147, 0.6329729361060323, 0.05226423163382673], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
      {-Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{-1/2, -Sqrt[3]/2, 0}, {-Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}}]}, 
   {RGBColor[0.32712652198685255, 0.6708419109227928, 0.05226423163382673], 
    Polygon[{{-Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, \
Cos[(7*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(41*Pi)/30], 
       Cos[(7*Pi)/15]}, {Cos[(41*Pi)/30], Sin[(41*Pi)/30], 0}, {-1/2, \
-Sqrt[3]/2, 0}}]}, 
   {RGBColor[0.2552124146273002, 0.7013610013807882, 0.05226423163382673], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(7*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {-(-1 + \
Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
      {Cos[(41*Pi)/30], Sin[(41*Pi)/30], 0}}]}, \
{RGBColor[0.18050214664646008, 0.7241958339384305, 0.05226423163382673], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {Cos[(43*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(43*Pi)/30], Sin[(43*Pi)/30], 0}, 
      {-(-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}}]}, \
{RGBColor[0.10381425937445889, 0.7390962253917224, 0.05226423163382673], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(22*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(22*Pi)/15], \
Sin[(22*Pi)/15], 0}, {Cos[(43*Pi)/30], Sin[(43*Pi)/30], 0}}]}, 
   {RGBColor[0.025988961352220105, 0.745898923933794, 0.05226423163382673], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(7*Pi)/15]}, {0, -Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {0, -1, 0}, 
      {Cos[(22*Pi)/15], Sin[(22*Pi)/15], 0}}]}, \
{RGBColor[0.05212107716913349, 0.7445293977758624, 0.05226423163382673], 
    Polygon[{{0, -Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/15]}, 
      {Cos[(23*Pi)/15], Sin[(23*Pi)/15], 0}, {0, -1, 0}}]}, \
{RGBColor[0.129660066261985, 0.7350026517331054, 0.05226423163382673], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(47*Pi)/30], Cos[(7*Pi)/15]}, {Cos[(47*Pi)/30], \
Sin[(47*Pi)/30], 0}, {Cos[(23*Pi)/15], Sin[(23*Pi)/15], 0}}]}, 
   {RGBColor[0.20577847253575693, 0.7174230628287674, 0.05226423163382673], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(7*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {(-1 + \
Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
      {Cos[(47*Pi)/30], Sin[(47*Pi)/30], 0}}]}, {RGBColor[0.2796423268025132, \
0.6919832367176502, 0.05226423163382673], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(49*Pi)/30], Sin[(49*Pi)/30], 0}, 
      {(-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}}]}, \
{RGBColor[0.35044236121790245, 0.6589618974582523, 0.05226423163382673], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/15]}, {Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, 
       Cos[(7*Pi)/15]}, {1/2, -Sqrt[3]/2, 0}, {Cos[(49*Pi)/30], \
Sin[(49*Pi)/30], 0}}]}, 
   {RGBColor[0.4174028757890097, 0.6187208337536595, 0.05226423163382673], 
    Polygon[{{Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {Sqrt[(5 - \
Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, {1/2, -Sqrt[3]/2, 0}}]}, 
   {RGBColor[0.4797902371058054, 0.5717009351188033, 0.05226423163382673], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
      {Cos[(26*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(26*Pi)/15], Sin[(26*Pi)/15], 0}, 
      {Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}}]}, \
{RGBColor[0.5369209161823075, 0.5184173614026739, 0.05226423163382673], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(53*Pi)/30], Cos[(7*Pi)/15]}, {Cos[(53*Pi)/30], \
Sin[(53*Pi)/30], 0}, {Cos[(26*Pi)/15], Sin[(26*Pi)/15], 0}}]}, 
   {RGBColor[0.5881689773431915, 0.45945389858920915, 0.05226423163382673], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(7*Pi)/15]}, {((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {(1 + \
Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}, 
      {Cos[(53*Pi)/30], Sin[(53*Pi)/30], 0}}]}, {RGBColor[0.6329729361060323, \
0.39545656271589147, 0.05226423163382673], 
    Polygon[{{((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
      {(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{Sqrt[3]/2, -1/2, 0}, {(1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}}]}, 
   {RGBColor[0.6708419109227928, 0.3271265219868526, 0.05226423163382673], 
    Polygon[{{(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(28*Pi)/15], 
       Cos[(7*Pi)/15]}, {Cos[(28*Pi)/15], Sin[(28*Pi)/15], 0}, {Sqrt[3]/2, \
-1/2, 0}}]}, 
   {RGBColor[0.7013610013807882, 0.2552124146273002, 0.05226423163382673], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(7*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, 
      {Cos[(28*Pi)/15], Sin[(28*Pi)/15], 0}}]}, {RGBColor[0.7241958339384305, \
0.18050214664646014, 0.05226423163382673], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
      {Cos[(29*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(29*Pi)/15], Sin[(29*Pi)/15], 0}, 
      {Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}}]}, \
{RGBColor[0.7390962253917224, 0.10381425937445893, 0.05226423163382673], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(7*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(59*Pi)/30], Cos[(7*Pi)/15]}, {Cos[(59*Pi)/30], \
Sin[(59*Pi)/30], 0}, {Cos[(29*Pi)/15], Sin[(29*Pi)/15], 0}}]}, 
   {RGBColor[0.745898923933794, 0.025988961352220123, 0.05226423163382673], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(7*Pi)/15]}, {Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, {1, 0, 0}, 
      {Cos[(59*Pi)/30], Sin[(59*Pi)/30], 0}}]}, {RGBColor[0.7458989239337941, \
0.05212107716913328, 0.026132115816913333], 
    Polygon[{{1, 0, 0}, {Cos[Pi/30], Sin[Pi/30], 0}, \
{Cos[Pi/30]*Sin[(8*Pi)/15], Sin[Pi/30]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
      {Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}}]}, {RGBColor[0.7363646754834481, \
0.1298032207266783, 0.026132115816913333], 
    Polygon[{{Cos[Pi/30], Sin[Pi/30], 0}, {Cos[Pi/15], Sin[Pi/15], 0}, \
{Cos[Pi/15]*Sin[(8*Pi)/15], Sin[Pi/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
      {Cos[Pi/30]*Sin[(8*Pi)/15], Sin[Pi/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.7187626615542907, 0.20606321303487163, 0.026132115816913333], 
    Polygon[{{Cos[Pi/15], Sin[Pi/15], 0}, {Sqrt[(5 + Sqrt[5])/2]/2, (-1 + \
Sqrt[5])/4, 0}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, \
{Cos[Pi/15]*Sin[(8*Pi)/15], Sin[Pi/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.6932857334943876, 0.28006553365955533, 0.026132115816913333], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, {Cos[(2*Pi)/15], \
Sin[(2*Pi)/15], 0}, 
      {Cos[(2*Pi)/15]*Sin[(8*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.6602130218589535, 0.3509993976899842, 0.026132115816913333], 
    Polygon[{{Cos[(2*Pi)/15], Sin[(2*Pi)/15], 0}, {Sqrt[3]/2, 1/2, 0}, \
{(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(8*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.6199068781975756, 0.41808763886797556, 0.026132115816913333], 
    Polygon[{{Sqrt[3]/2, 1/2, 0}, {(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, \
0}, {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.5728089050548111, 0.4805952243840663, 0.026132115816913333], 
    Polygon[{{(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, {Cos[(7*Pi)/30], \
Sin[(7*Pi)/30], 0}, 
      {Cos[(7*Pi)/30]*Sin[(8*Pi)/15], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.5194351176802966, 0.5378373080507888, 0.026132115816913333], 
    Polygon[{{Cos[(7*Pi)/30], Sin[(7*Pi)/30], 0}, {Cos[(4*Pi)/15], \
Sin[(4*Pi)/15], 0}, {Cos[(4*Pi)/15]*Sin[(8*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(7*Pi)/30]*Sin[(8*Pi)/15], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.4603702904576901, 0.5891867336208145, 0.026132115816913333], 
    Polygon[{{Cos[(4*Pi)/15], Sin[(4*Pi)/15], 0}, {Sqrt[(5 - Sqrt[5])/2]/2, \
(1 + Sqrt[5])/4, 0}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, \
{Cos[(4*Pi)/15]*Sin[(8*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.3962615499941525, 0.63408090604204, 0.026132115816913333], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}, {1/2, Sqrt[3]/2, \
0}, {Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.3278112850658186, 0.6720279553667089, 0.026132115816913333], 
    Polygon[{{1/2, Sqrt[3]/2, 0}, {Cos[(11*Pi)/30], Sin[(11*Pi)/30], 0}, \
{Cos[(11*Pi)/30]*Sin[(8*Pi)/15], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], 
       Cos[(8*Pi)/15]}, {Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.25576945109938193, 0.7026121257814895, 0.026132115816913333], 
    Polygon[{{Cos[(11*Pi)/30], Sin[(11*Pi)/30], 0}, {(-1 + Sqrt[5])/4, \
Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
      {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(11*Pi)/30]*Sin[(8*Pi)/15], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.18092535350350175, 0.7254983307151682, 0.026132115816913333], 
    Polygon[{{(-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}, \
{Cos[(13*Pi)/30], Sin[(13*Pi)/30], 0}, 
      {Cos[(13*Pi)/30]*Sin[(8*Pi)/15], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.10409899987357309, 0.7404358241172455, 0.026132115816913333], 
    Polygon[{{Cos[(13*Pi)/30], Sin[(13*Pi)/30], 0}, {Cos[(7*Pi)/15], \
Sin[(7*Pi)/15], 0}, {Cos[(7*Pi)/15]*Sin[(8*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(13*Pi)/30]*Sin[(8*Pi)/15], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.026132115816913364, 0.7472609476841366, 0.026132115816913333], \

    Polygon[{{Cos[(7*Pi)/15], Sin[(7*Pi)/15], 0}, {0, 1, 0}, {0, \
Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
      {Cos[(7*Pi)/15]*Sin[(8*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.052121077169133216, 0.7458989239337941, 0.026132115816913333], \

    Polygon[{{0, 1, 0}, {Cos[(8*Pi)/15], Sin[(8*Pi)/15], 0}, \
{Cos[(8*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]^2, Cos[(8*Pi)/15]}, 
      {0, Sin[(8*Pi)/15], Cos[(8*Pi)/15]}}]}, {RGBColor[0.1298032207266782, \
0.7363646754834482, 0.026132115816913333], 
    Polygon[{{Cos[(8*Pi)/15], Sin[(8*Pi)/15], 0}, {Cos[(17*Pi)/30], \
Sin[(17*Pi)/30], 0}, {Cos[(17*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(17*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]^2, Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.20606321303487163, 0.7187626615542906, 0.026132115816913333], 
    Polygon[{{Cos[(17*Pi)/30], Sin[(17*Pi)/30], 0}, {-(-1 + Sqrt[5])/4, \
Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
      {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(17*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.2800655336595553, 0.6932857334943876, 0.026132115816913333], 
    Polygon[{{-(-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}, \
{Cos[(19*Pi)/30], Sin[(19*Pi)/30], 0}, 
      {Cos[(19*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(8*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.35099939768998417, 0.6602130218589535, 0.026132115816913333], 
    Polygon[{{Cos[(19*Pi)/30], Sin[(19*Pi)/30], 0}, {-1/2, Sqrt[3]/2, 0}, \
{-Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.41808763886797556, 0.6199068781975756, 0.026132115816913333], 
    Polygon[{{-1/2, Sqrt[3]/2, 0}, {-Sqrt[(5 - Sqrt[5])/2]/2, (1 + \
Sqrt[5])/4, 0}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-Sin[(8*Pi)/15]/2, \
(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.48059522438406616, 0.5728089050548113, 0.026132115816913333], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}, \
{Cos[(11*Pi)/15], Sin[(11*Pi)/15], 0}, 
      {Cos[(11*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.5378373080507888, 0.5194351176802965, 0.026132115816913333], 
    Polygon[{{Cos[(11*Pi)/15], Sin[(11*Pi)/15], 0}, {Cos[(23*Pi)/30], \
Sin[(23*Pi)/30], 0}, {Cos[(23*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(23*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(11*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.5891867336208146, 0.46037029045769007, 0.026132115816913333], 
    Polygon[{{Cos[(23*Pi)/30], Sin[(23*Pi)/30], 0}, {-(1 + Sqrt[5])/4, \
Sqrt[(5 - Sqrt[5])/2]/2, 0}, 
      {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(23*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.63408090604204, 0.3962615499941525, 0.026132115816913333], 
    Polygon[{{-(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, {-Sqrt[3]/2, \
1/2, 0}, {-(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, 
       Cos[(8*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.672027955366709, 0.3278112850658184, 0.026132115816913333], \
Polygon[{{-Sqrt[3]/2, 1/2, 0}, {Cos[(13*Pi)/15], Sin[(13*Pi)/15], 0}, 
      {Cos[(13*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, 
       Cos[(8*Pi)/15]}}]}, {RGBColor[0.7026121257814895, 0.2557694510993819, \
0.026132115816913333], 
    Polygon[{{Cos[(13*Pi)/15], Sin[(13*Pi)/15], 0}, {-Sqrt[(5 + \
Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Cos[(13*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.7254983307151682, 0.1809253535035018, 0.026132115816913333], 
    Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, \
{Cos[(14*Pi)/15], Sin[(14*Pi)/15], 0}, 
      {Cos[(14*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.7404358241172455, 0.10409899987357324, 0.026132115816913333], 
    Polygon[{{Cos[(14*Pi)/15], Sin[(14*Pi)/15], 0}, {Cos[(29*Pi)/30], \
Sin[(29*Pi)/30], 0}, {Cos[(29*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(29*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(14*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.7472609476841366, 0.026132115816913434, 0.026132115816913333], \

    Polygon[{{Cos[(29*Pi)/30], Sin[(29*Pi)/30], 0}, {-1, 0, 0}, \
{-Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, 
      {Cos[(29*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.7458989239337941, 0.0521210771691333, 0.026132115816913333], 
    Polygon[{{-1, 0, 0}, {Cos[(31*Pi)/30], Sin[(31*Pi)/30], 0}, \
{Cos[(31*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(8*Pi)/15]}, 
      {-Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}}]}, {RGBColor[0.7363646754834481, \
0.1298032207266782, 0.026132115816913333], 
    Polygon[{{Cos[(31*Pi)/30], Sin[(31*Pi)/30], 0}, {Cos[(16*Pi)/15], \
Sin[(16*Pi)/15], 0}, {Cos[(16*Pi)/15]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(16*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.7187626615542907, 0.2060632130348716, 0.026132115816913333], 
    Polygon[{{Cos[(16*Pi)/15], Sin[(16*Pi)/15], 0}, {-Sqrt[(5 + \
Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Cos[(16*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.6932857334943877, 0.28006553365955517, 0.026132115816913333], 
    Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, \
{Cos[(17*Pi)/15], Sin[(17*Pi)/15], 0}, 
      {Cos[(17*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.6602130218589535, 0.3509993976899841, 0.026132115816913333], 
    Polygon[{{Cos[(17*Pi)/15], Sin[(17*Pi)/15], 0}, {-Sqrt[3]/2, -1/2, 0}, \
{-(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, 
      {Cos[(17*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.6199068781975756, 0.41808763886797556, 0.026132115816913333], 
    Polygon[{{-Sqrt[3]/2, -1/2, 0}, {-(1 + Sqrt[5])/4, -Sqrt[(5 - \
Sqrt[5])/2]/2, 0}, {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{-(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.5728089050548111, 0.4805952243840663, 0.026132115816913333], 
    Polygon[{{-(1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}, \
{Cos[(37*Pi)/30], Sin[(37*Pi)/30], 0}, 
      {Cos[(37*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(8*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.5194351176802967, 0.5378373080507888, 0.026132115816913333], 
    Polygon[{{Cos[(37*Pi)/30], Sin[(37*Pi)/30], 0}, {Cos[(19*Pi)/15], \
Sin[(19*Pi)/15], 0}, {Cos[(19*Pi)/15]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(19*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(37*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.4603702904576902, 0.5891867336208145, 0.026132115816913333], 
    Polygon[{{Cos[(19*Pi)/15], Sin[(19*Pi)/15], 0}, {-Sqrt[(5 - \
Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Cos[(19*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.3962615499941525, 0.63408090604204, 0.026132115816913333], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, {-1/2, \
-Sqrt[3]/2, 0}, {-Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, 
       Cos[(8*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.32781128506581847, 0.672027955366709, 0.026132115816913333], 
    Polygon[{{-1/2, -Sqrt[3]/2, 0}, {Cos[(41*Pi)/30], Sin[(41*Pi)/30], 0}, \
{Cos[(41*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(41*Pi)/30], 
       Cos[(8*Pi)/15]}, {-Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.2557694510993819, 0.7026121257814895, 0.026132115816913333], 
    Polygon[{{Cos[(41*Pi)/30], Sin[(41*Pi)/30], 0}, {-(-1 + Sqrt[5])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
      {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(41*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.18092535350350206, 0.7254983307151681, 0.026132115816913333], 
    Polygon[{{-(-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, \
{Cos[(43*Pi)/30], Sin[(43*Pi)/30], 0}, 
      {Cos[(43*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(8*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.10409899987357361, 0.7404358241172454, 0.026132115816913333], 
    Polygon[{{Cos[(43*Pi)/30], Sin[(43*Pi)/30], 0}, {Cos[(22*Pi)/15], \
Sin[(22*Pi)/15], 0}, {Cos[(22*Pi)/15]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(22*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(43*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.02613211581691356, 0.7472609476841368, 0.026132115816913333], 
    Polygon[{{Cos[(22*Pi)/15], Sin[(22*Pi)/15], 0}, {0, -1, 0}, {0, \
-Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
      {Cos[(22*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.05212107716913349, 0.7458989239337941, 0.026132115816913333], 
    Polygon[{{0, -1, 0}, {Cos[(23*Pi)/15], Sin[(23*Pi)/15], 0}, \
{Cos[(23*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(8*Pi)/15]}, 
      {0, -Sin[(8*Pi)/15], Cos[(8*Pi)/15]}}]}, {RGBColor[0.12980322072667846, \
0.7363646754834481, 0.026132115816913333], 
    Polygon[{{Cos[(23*Pi)/15], Sin[(23*Pi)/15], 0}, {Cos[(47*Pi)/30], \
Sin[(47*Pi)/30], 0}, {Cos[(47*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(47*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.20606321303487168, 0.7187626615542906, 0.026132115816913333], 
    Polygon[{{Cos[(47*Pi)/30], Sin[(47*Pi)/30], 0}, {(-1 + Sqrt[5])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
      {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(47*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.2800655336595551, 0.6932857334943877, 0.026132115816913333], 
    Polygon[{{(-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, \
{Cos[(49*Pi)/30], Sin[(49*Pi)/30], 0}, 
      {Cos[(49*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(8*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.3509993976899841, 0.6602130218589535, 0.026132115816913333], 
    Polygon[{{Cos[(49*Pi)/30], Sin[(49*Pi)/30], 0}, {1/2, -Sqrt[3]/2, 0}, \
{Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.41808763886797556, 0.6199068781975756, 0.026132115816913333], 
    Polygon[{{1/2, -Sqrt[3]/2, 0}, {Sqrt[(5 - Sqrt[5])/2]/2, -(1 + \
Sqrt[5])/4, 0}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {Sin[(8*Pi)/15]/2, \
-(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.48059522438406643, 0.5728089050548111, 0.026132115816913333], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, \
{Cos[(26*Pi)/15], Sin[(26*Pi)/15], 0}, 
      {Cos[(26*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.5378373080507887, 0.5194351176802967, 0.026132115816913333], 
    Polygon[{{Cos[(26*Pi)/15], Sin[(26*Pi)/15], 0}, {Cos[(53*Pi)/30], \
Sin[(53*Pi)/30], 0}, {Cos[(53*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(53*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(26*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.5891867336208144, 0.4603702904576903, 0.026132115816913333], 
    Polygon[{{Cos[(53*Pi)/30], Sin[(53*Pi)/30], 0}, {(1 + Sqrt[5])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2, 0}, 
      {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(53*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.63408090604204, 0.3962615499941525, 0.026132115816913333], 
    Polygon[{{(1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}, {Sqrt[3]/2, \
-1/2, 0}, {(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, 
       Cos[(8*Pi)/15]}, {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.672027955366709, 0.32781128506581847, 0.026132115816913333], 
    Polygon[{{Sqrt[3]/2, -1/2, 0}, {Cos[(28*Pi)/15], Sin[(28*Pi)/15], 0}, \
{Cos[(28*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(28*Pi)/15], 
       Cos[(8*Pi)/15]}, {(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.7026121257814895, 0.2557694510993819, 0.026132115816913333], 
    Polygon[{{Cos[(28*Pi)/15], Sin[(28*Pi)/15], 0}, {Sqrt[(5 + Sqrt[5])/2]/2, \
-(-1 + Sqrt[5])/4, 0}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Cos[(28*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.7254983307151681, 0.18092535350350208, 0.026132115816913333], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, \
{Cos[(29*Pi)/15], Sin[(29*Pi)/15], 0}, 
      {Cos[(29*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}]}, \
{RGBColor[0.7404358241172454, 0.10409899987357366, 0.026132115816913333], 
    Polygon[{{Cos[(29*Pi)/15], Sin[(29*Pi)/15], 0}, {Cos[(59*Pi)/30], \
Sin[(59*Pi)/30], 0}, {Cos[(59*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(59*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(29*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.7472609476841366, 0.026132115816913576, 0.026132115816913333], \

    Polygon[{{Cos[(59*Pi)/30], Sin[(59*Pi)/30], 0}, {1, 0, 0}, \
{Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, 
      {Cos[(59*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(8*Pi)/15]}}]}, 
   {RGBColor[0.7390962253917225, 0.05155002774063165, 0.10424215433826645], 
    Polygon[{{Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, {Cos[Pi/30]*Sin[(8*Pi)/15], \
Sin[Pi/30]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
      {Cos[Pi/30]*Sin[(17*Pi)/30], Sin[Pi/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.7296589337549793, 0.12852422394202004, 0.10424215433826645], 
    Polygon[{{Cos[Pi/30]*Sin[(8*Pi)/15], Sin[Pi/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[Pi/15]*Sin[(8*Pi)/15], Sin[Pi/15]*Sin[(8*Pi)/15], 
       Cos[(8*Pi)/15]}, {Cos[Pi/15]*Sin[(17*Pi)/30], \
Sin[Pi/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
      {Cos[Pi/30]*Sin[(17*Pi)/30], Sin[Pi/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.7122273461490682, 0.20409028185047676, 0.10424215433826645], 
    Polygon[{{Cos[Pi/15]*Sin[(8*Pi)/15], Sin[Pi/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}, {Cos[Pi/15]*Sin[(17*Pi)/30], \
Sin[Pi/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.686992446695594, 0.2774202839223424, 0.10424215433826645], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(8*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(2*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.654230714233711, 0.34771081130962833, \
0.10424215433826645], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(8*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, 
       Cos[(8*Pi)/15]}, {(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(2*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}}]}, \
{RGBColor[0.6143010931601051, 0.4141917462850408, 0.10424215433826645], 
    Polygon[{{(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, \
{((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}, {(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.5676410607590688, 0.47613470981295913, 0.10424215433826645], 
    Polygon[{{((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(7*Pi)/30]*Sin[(8*Pi)/15], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(17*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.5147618341098276, 0.5328610418225731, \
0.10424215433826645], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(8*Pi)/15], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(8*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(4*Pi)/15]*Sin[(17*Pi)/30], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, 
      {Cos[(7*Pi)/30]*Sin[(17*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.45624276908524003, 0.5837492367496372, 0.10424215433826645], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(8*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(4*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.3927250128076172, 0.6282417528814912, 0.10424215433826645], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.32490447910668174, 0.6658511209007367, 0.10424215433826645], 
    Polygon[{{Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(8*Pi)/15], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], 
       Cos[(8*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
      {Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.2535242239420201, 0.6961652847010888, 0.10424215433826645], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(8*Pi)/15], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.17936630432649503, 0.7188521159603044, 0.10424215433826645], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(13*Pi)/30]*Sin[(8*Pi)/15], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(17*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.10324320994595675, \
0.7336630530075825, 0.10424215433826645], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(8*Pi)/15], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(8*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(7*Pi)/15]*Sin[(17*Pi)/30], Sin[(7*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, 
      {Cos[(13*Pi)/30]*Sin[(17*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.025988961352219914, 0.7404358241172455, 0.10424215433826645], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(8*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {0, Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
      {0, Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(7*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.051550027740631596, 0.7390962253917225, 0.10424215433826645], 
    Polygon[{{0, Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]^2, Cos[(8*Pi)/15]}, 
      {Cos[(8*Pi)/15]*Sin[(17*Pi)/30], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {0, Sin[(17*Pi)/30], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.1285242239420199, 0.7296589337549793, 0.10424215433826645], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]^2, \
Cos[(8*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(8*Pi)/15], \
Sin[(8*Pi)/15]*Sin[(17*Pi)/30], 
       Cos[(8*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]^2, \
Cos[(17*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(8*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}}]}, \
{RGBColor[0.2040902818504767, 0.7122273461490682, 0.10424215433826645], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(8*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]^2, \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.27742028392234236, 0.686992446695594, 0.10424215433826645], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(19*Pi)/30], Cos[(17*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.3477108113096283, 0.6542307142337112, \
0.10424215433826645], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(8*Pi)/15]}, {-Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, 
       Cos[(8*Pi)/15]}, {-Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(19*Pi)/30], Cos[(17*Pi)/30]}}]}, \
{RGBColor[0.4141917462850408, 0.6143010931601051, 0.10424215433826645], 
    Polygon[{{-Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}, {-Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.476134709812959, 0.567641060759069, 0.10424215433826645], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Cos[(11*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(11*Pi)/15], Cos[(17*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.5328610418225732, 0.5147618341098275, \
0.10424215433826645], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(23*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(23*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(17*Pi)/30]}, 
      {Cos[(11*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.5837492367496373, 0.45624276908524, 0.10424215433826645], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(8*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}, {Cos[(23*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(23*Pi)/30], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.6282417528814912, 0.3927250128076172, 0.10424215433826645], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, \
{-(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, 
      {-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.6658511209007367, 0.3249044791066816, 0.10424215433826645], 
    Polygon[{{-(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], 
       Cos[(8*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(13*Pi)/15], Cos[(17*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}}]}, \
{RGBColor[0.6961652847010888, 0.25352422394202, 0.10424215433826645], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(13*Pi)/15], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.7188521159603044, 0.17936630432649509, 0.10424215433826645], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Cos[(14*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(14*Pi)/15], Cos[(17*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.7336630530075825, 0.1032432099459569, \
0.10424215433826645], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(29*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(29*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(17*Pi)/30]}, 
      {Cos[(14*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.7404358241172455, 0.025988961352219984, 0.10424215433826645], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(8*Pi)/15]}, {-Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, 
      {-Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}, \
{Cos[(29*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.7390962253917225, 0.05155002774063168, 0.10424215433826645], 
    Polygon[{{-Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(8*Pi)/15]}, 
      {Cos[(31*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(17*Pi)/30]}, {-Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.7296589337549793, 0.12852422394201993, 0.10424215433826645], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(16*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(16*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(17*Pi)/30]}, 
      {Cos[(31*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.7122273461490682, 0.20409028185047667, 0.10424215433826645], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(16*Pi)/15], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.6869924466955941, 0.27742028392234225, 0.10424215433826645], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Cos[(17*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(17*Pi)/15], Cos[(17*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.6542307142337112, 0.3477108113096282, \
0.10424215433826645], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, 
       Cos[(8*Pi)/15]}, {-(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(17*Pi)/15], Cos[(17*Pi)/30]}}]}, \
{RGBColor[0.6143010931601051, 0.4141917462850408, 0.10424215433826645], 
    Polygon[{{-(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, \
Cos[(8*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{-(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.5676410607590688, 0.47613470981295913, 0.10424215433826645], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(37*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(37*Pi)/30], Cos[(17*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.5147618341098277, 0.5328610418225731, \
0.10424215433826645], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(19*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(19*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(17*Pi)/30]}, 
      {Cos[(37*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.45624276908524014, 0.5837492367496372, 0.10424215433826645], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(19*Pi)/15], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.3927250128076172, 0.6282417528814912, 0.10424215433826645], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {-Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{-Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.32490447910668163, 0.6658511209007367, 0.10424215433826645], 
    Polygon[{{-Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, \
Cos[(8*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(8*Pi)/15], \
Sin[(8*Pi)/15]*Sin[(41*Pi)/30], 
       Cos[(8*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(41*Pi)/30], Cos[(17*Pi)/30]}, 
      {-Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}]}, \

   {RGBColor[0.25352422394202, 0.6961652847010888, 0.10424215433826645], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(8*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(41*Pi)/30], 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.1793663043264953, 0.7188521159603043, \
0.10424215433826645], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(43*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(43*Pi)/30], Cos[(17*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.10324320994595727, \
0.7336630530075825, 0.10424215433826645], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(22*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(22*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(17*Pi)/30]}, 
      {Cos[(43*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.02598896135222011, 0.7404358241172455, 0.10424215433826645], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(8*Pi)/15]}, {0, -Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
      {0, -Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(22*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.05155002774063186, 0.7390962253917225, 0.10424215433826645], 
    Polygon[{{0, -Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(8*Pi)/15]}, 
      {Cos[(23*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(17*Pi)/30]}, {0, -Sin[(17*Pi)/30], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.1285242239420202, 0.7296589337549793, 0.10424215433826645], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(47*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(47*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(17*Pi)/30]}, 
      {Cos[(23*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.20409028185047678, 0.7122273461490682, 0.10424215433826645], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(8*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{Cos[(47*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(47*Pi)/30], 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.27742028392234225, \
0.6869924466955941, 0.10424215433826645], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(49*Pi)/30], Cos[(17*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.3477108113096282, 0.6542307142337112, \
0.10424215433826645], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(8*Pi)/15]}, {Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, 
       Cos[(8*Pi)/15]}, {Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(49*Pi)/30], Cos[(17*Pi)/30]}}]}, \
{RGBColor[0.4141917462850408, 0.6143010931601051, 0.10424215433826645], 
    Polygon[{{Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}, {Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.4761347098129593, 0.5676410607590687, 0.10424215433826645], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Cos[(26*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(26*Pi)/15], Cos[(17*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.532861041822573, 0.5147618341098278, \
0.10424215433826645], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(53*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(53*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(17*Pi)/30]}, 
      {Cos[(26*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.5837492367496371, 0.4562427690852402, 0.10424215433826645], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(8*Pi)/15]}, {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       Cos[(17*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(53*Pi)/30], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.6282417528814912, 0.3927250128076172, 0.10424215433826645], 
    Polygon[{{((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
      {(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, \
{(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, 
      {((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.6658511209007367, 0.32490447910668163, 0.10424215433826645], 
    Polygon[{{(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(28*Pi)/15], 
       Cos[(8*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(28*Pi)/15], Cos[(17*Pi)/30]}, 
      {(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.6961652847010888, 0.25352422394202007, 0.10424215433826645], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(28*Pi)/15], Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.7188521159603043, 0.17936630432649536, 0.10424215433826645], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
      {Cos[(29*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(29*Pi)/15], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       Cos[(17*Pi)/30]}}]}, {RGBColor[0.7336630530075825, \
0.10324320994595733, 0.10424215433826645], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(8*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(59*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(59*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(17*Pi)/30]}, 
      {Cos[(29*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.7404358241172455, 0.025988961352220126, 0.10424215433826645], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(8*Pi)/15]}, {Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, 
      {Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}, \
{Cos[(59*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(17*Pi)/30]}}]}, 
   {RGBColor[0.7241958339384306, 0.05041418542066685, 0.18121009400261642], 
    Polygon[{{Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}, \
{Cos[Pi/30]*Sin[(17*Pi)/30], Sin[Pi/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, -(-1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.7149588960573425, 0.12583708886443007, 0.18121009400261642], 
    Polygon[{{Cos[Pi/30]*Sin[(17*Pi)/30], Sin[Pi/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[Pi/15]*Sin[(17*Pi)/30], Sin[Pi/15]*Sin[(17*Pi)/30], 
       Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6978887188962826, 0.19988129482949085, 0.18121009400261642], 
    Polygon[{{Cos[Pi/15]*Sin[(17*Pi)/30], Sin[Pi/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {(5 + \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6731723268883916, 0.2717355595005497, 0.18121009400261642], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
      {Cos[(2*Pi)/15]*Sin[(17*Pi)/30], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(-1 + Sqrt[5])/4}, {(5 + \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.6410805179967456, \
0.340612632517399, 0.18121009400261642], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(17*Pi)/30], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, 
       Cos[(17*Pi)/30]}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + \
Sqrt[5])/2]/4, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6019648967952043, 0.4057578822546119, 0.18121009400261642], 
    Polygon[{{(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}, {((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       -(-1 + Sqrt[5])/4}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + \
Sqrt[5])/2]/4, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.5562540222151214, 0.46645756372354763, 0.18121009400261642], 
    Polygon[{{((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
      {Cos[(7*Pi)/30]*Sin[(17*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5044487121640122, 0.5220466385118074, 0.18121009400261642], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(17*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(4*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.4471165564597546, 0.5719160610832497, 0.18121009400261642], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(17*Pi)/30], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.38488569819776924, 0.6155194516083339, 0.18121009400261642], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
      {Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
       -(-1 + Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.31843795168381883, 0.652379082215871, 0.18121009400261642], 
    Polygon[{{Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(17*Pi)/30], 
       Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.24850133233379496, 0.6820911110795516, 0.18121009400261642], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.17584208038447496, 0.7043300069935032, 0.18121009400261642], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
      {Cos[(13*Pi)/30]*Sin[(17*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.10125626580514185, \
0.7188521159603043, 0.18121009400261642], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
      {Cos[(7*Pi)/15]*Sin[(17*Pi)/30], Sin[(7*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.02556106638841174, 0.7254983307151682, 0.18121009400261642], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(17*Pi)/30], Sin[(7*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {0, Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
      {0, Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.050414185420666786, \
0.7241958339384307, 0.18121009400261642], 
    Polygon[{{0, Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(17*Pi)/30], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {0, Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.12583708886442996, 0.7149588960573425, 0.18121009400261642], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(17*Pi)/30], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]^2, Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.1998812948294908, 0.6978887188962826, 0.18121009400261642], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]^2, \
Cos[(17*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.2717355595005496, 0.6731723268883917, 0.18121009400261642], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
      {Cos[(19*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {-((-1 \
+ Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.34061263251739893, \
0.6410805179967456, 0.18121009400261642], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(19*Pi)/30], Cos[(17*Pi)/30]}, 
      {-Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.4057578822546119, 0.6019648967952043, 0.18121009400261642], 
    Polygon[{{-Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -(-1 + Sqrt[5])/4}, {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.4664575637235474, 0.5562540222151217, 0.18121009400261642], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
      {Cos[(11*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5220466385118074, 0.5044487121640122, 0.18121009400261642], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(11*Pi)/15], Cos[(17*Pi)/30]}, 
      {Cos[(23*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5719160610832498, 0.44711655645975457, 0.18121009400261642], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(23*Pi)/30], Cos[(17*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(23*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.6155194516083339, 0.38488569819776924, 0.18121009400261642], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, 
       -(-1 + Sqrt[5])/4}, {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6523790822158712, 0.31843795168381867, 0.18121009400261642], 
    Polygon[{{-(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(13*Pi)/15], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       -(-1 + Sqrt[5])/4}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + \
Sqrt[5])/2]/4, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6820911110795516, 0.24850133233379484, 0.18121009400261642], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(13*Pi)/15], Cos[(17*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {(-5 - \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.7043300069935032, 0.17584208038447502, 0.18121009400261642], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
      {Cos[(14*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(-1 + Sqrt[5])/4}, {(-5 - \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.7188521159603043, \
0.101256265805142, 0.18121009400261642], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(14*Pi)/15], Cos[(17*Pi)/30]}, 
      {Cos[(29*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.7254983307151682, 0.02556106638841181, 0.18121009400261642], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(29*Pi)/30], Cos[(17*Pi)/30]}, {-Sin[(17*Pi)/30], 0, \
Cos[(17*Pi)/30]}, 
      {-Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.7241958339384306, \
0.05041418542066686, 0.18121009400261642], 
    Polygon[{{-Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(17*Pi)/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {-Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.7149588960573425, 0.12583708886442996, 0.18121009400261642], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(31*Pi)/30], Cos[(17*Pi)/30]}, 
      {Cos[(16*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.6978887188962826, 0.1998812948294908, 0.18121009400261642], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(16*Pi)/15], Cos[(17*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {(-5 - \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6731723268883917, 0.2717355595005495, 0.18121009400261642], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
      {Cos[(17*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(-1 + Sqrt[5])/4}, {(-5 - \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.6410805179967456, \
0.3406126325173989, 0.18121009400261642], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(17*Pi)/15], Cos[(17*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6019648967952043, 0.4057578822546119, 0.18121009400261642], 
    Polygon[{{-(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, {-Sqrt[(3*(5 \
+ Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.5562540222151214, 0.46645756372354763, 0.18121009400261642], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
      {Cos[(37*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5044487121640124, 0.5220466385118074, 0.18121009400261642], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(37*Pi)/30], Cos[(17*Pi)/30]}, 
      {Cos[(19*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.4471165564597547, 0.5719160610832497, 0.18121009400261642], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(19*Pi)/15], Cos[(17*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.38488569819776924, 0.6155194516083339, 0.18121009400261642], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
      {-Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
       -(-1 + Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3184379516838187, 0.6523790822158712, 0.18121009400261642], 
    Polygon[{{-Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(41*Pi)/30], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(41*Pi)/30])/2, 
       -(-1 + Sqrt[5])/4}, {-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.24850133233379487, 0.6820911110795516, 0.18121009400261642], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(41*Pi)/30], Cos[(17*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.17584208038447524, 0.7043300069935031, 0.18121009400261642], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
      {Cos[(43*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {-((-1 \
+ Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.10125626580514235, \
0.7188521159603043, 0.18121009400261642], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(43*Pi)/30], Cos[(17*Pi)/30]}, 
      {Cos[(22*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.02556106638841193, 0.7254983307151682, 0.18121009400261642], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(22*Pi)/15], Cos[(17*Pi)/30]}, {0, -Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, 
      {0, -Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.05041418542066704, \
0.7241958339384306, 0.18121009400261642], 
    Polygon[{{0, -Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(17*Pi)/30]}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {0, -Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.12583708886443024, 0.7149588960573425, 0.18121009400261642], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(23*Pi)/15], Cos[(17*Pi)/30]}, 
      {Cos[(47*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.19988129482949088, 0.6978887188962826, 0.18121009400261642], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(47*Pi)/30], Cos[(17*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.2717355595005495, 0.6731723268883917, 0.18121009400261642], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
      {Cos[(49*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.3406126325173989, \
0.6410805179967456, 0.18121009400261642], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(49*Pi)/30], Cos[(17*Pi)/30]}, 
      {Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
       -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.4057578822546119, 0.6019648967952043, 0.18121009400261642], 
    Polygon[{{Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -(-1 + Sqrt[5])/4}, {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.4664575637235477, 0.5562540222151214, 0.18121009400261642], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
      {Cos[(26*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5220466385118073, 0.5044487121640124, 0.18121009400261642], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(26*Pi)/15], Cos[(17*Pi)/30]}, 
      {Cos[(53*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.5719160610832497, 0.4471165564597548, 0.18121009400261642], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(53*Pi)/30], Cos[(17*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(53*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.6155194516083339, 0.38488569819776924, 0.18121009400261642], 
    Polygon[{{((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
      {(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, 
       -(-1 + Sqrt[5])/4}, {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6523790822158712, 0.3184379516838187, 0.18121009400261642], 
    Polygon[{{(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(17*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(28*Pi)/15], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(28*Pi)/15])/2, 
       -(-1 + Sqrt[5])/4}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + \
Sqrt[5])/2]/4, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.6820911110795516, 0.2485013323337949, 0.18121009400261642], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(28*Pi)/15], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {(5 + \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.7043300069935031, 0.1758420803844753, 0.18121009400261642], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
      {Cos[(29*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(-1 + Sqrt[5])/4}, {(5 + \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.7188521159603043, \
0.10125626580514241, 0.18121009400261642], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(29*Pi)/15], Cos[(17*Pi)/30]}, 
      {Cos[(59*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(59*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(-1 + Sqrt[5])/4}}]}, \
{RGBColor[0.7254983307151682, 0.02556106638841195, 0.18121009400261642], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(59*Pi)/30], Cos[(17*Pi)/30]}, {Sin[(17*Pi)/30], 0, \
Cos[(17*Pi)/30]}, 
      {Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
       -(-1 + Sqrt[5])/4}}]}, {RGBColor[0.7013610013807882, \
0.04872599473538668, 0.25619265795642376], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
       -(-1 + Sqrt[5])/4}, {Cos[Pi/30]*Sin[(19*Pi)/30], \
Sin[Pi/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {Sin[(19*Pi)/30], 0, \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.692425619079734, 0.12177125630813765, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[Pi/15]*Sin[(19*Pi)/30], Sin[Pi/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[Pi/30]*Sin[(19*Pi)/30], Sin[Pi/30]*Sin[(19*Pi)/30], 
       Cos[(19*Pi)/30]}}]}, {RGBColor[0.6759038767966659, \
0.19348236651450307, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -(-1 + Sqrt[5])/4}, 
      {(5 + Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, \
{Cos[Pi/15]*Sin[(19*Pi)/30], Sin[Pi/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}]}, \

   {RGBColor[0.6519767901974342, 0.26307364342454737, 0.25619265795642376], 
    Polygon[{{(5 + Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 \
+ Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(2*Pi)/15]*Sin[(19*Pi)/30], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], 
       Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.6209065094498847, 0.32978263044553324, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, 
       Cos[(19*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(2*Pi)/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.5830334470517621, 0.3928784499559058, 0.25619265795642376], 
    Polygon[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, {((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       Cos[(19*Pi)/30]}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.5387725482001476, 0.45166981095346026, 0.25619265795642376], 
    Polygon[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 \
+ Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(7*Pi)/30]*Sin[(19*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.48860874456504855, 0.5055125829842242, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(4*Pi)/15]*Sin[(19*Pi)/30], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(19*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.43309164127654143, 0.5538168533705041, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
      {Cos[(4*Pi)/15]*Sin[(19*Pi)/30], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.3728294953359562, 0.5960533904176297, 0.25619265795642376], 
    Polygon[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 
       Cos[(19*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.3084825514248825, 0.6317594417871487, 0.25619265795642376], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/30]*Sin[(19*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], 
       Cos[(19*Pi)/30]}, {Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.24075580812627373, 0.6605438045082853, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(19*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], 
       Cos[(19*Pi)/30]}}]}, {RGBColor[0.1703912938124416, 0.6820911110795516, \
0.25619265795642376], 
    Polygon[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, -(-1 \
+ Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/30]*Sin[(19*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], 
       Cos[(19*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.09815993682692996, 0.6961652847010888, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(7*Pi)/15]*Sin[(19*Pi)/30], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(19*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.024853119032255105, 0.7026121257814895, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {0, Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {0, Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(7*Pi)/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.048725994735386614, 0.7013610013807883, 0.25619265795642376], 
    Polygon[{{0, Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       -(-1 + Sqrt[5])/4}, {Cos[(8*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(8*Pi)/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, 
      {0, Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.12177125630813751, 0.692425619079734, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(17*Pi)/30]*Sin[(19*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(8*Pi)/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.193482366514503, 0.6759038767966659, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(19*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/30], 
       Cos[(19*Pi)/30]}}]}, {RGBColor[0.2630736434245473, 0.6519767901974342, \
0.25619265795642376], 
    Polygon[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, \
-(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(19*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]^2, Cos[(19*Pi)/30]}, 
      {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.32978263044553324, 0.6209065094498848, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {-Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 
       Cos[(19*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]^2, \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.3928784499559058, 0.5830334470517621, 0.25619265795642376], 
    Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, \
{-Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.45166981095346015, 0.5387725482001477, 0.25619265795642376], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(11*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(19*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.5055125829842242, 0.48860874456504844, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(23*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(11*Pi)/15], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.5538168533705042, 0.43309164127654143, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
      {-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
      {Cos[(23*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.5960533904176297, 0.3728294953359562, 0.25619265795642376], 
    Polygon[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 \
+ Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
      {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, 
       Cos[(19*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.6317594417871487, 0.30848255142488235, 0.25619265795642376], 
    Polygon[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], 
       Cos[(19*Pi)/30]}, {-(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.6605438045082853, 0.24075580812627365, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], 
       Cos[(19*Pi)/30]}}]}, {RGBColor[0.6820911110795516, \
0.17039129381244167, 0.25619265795642376], 
    Polygon[{{(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(14*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], 
       Cos[(19*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.6961652847010888, 0.09815993682693012, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(29*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(14*Pi)/15], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.7026121257814895, 0.02485311903225517, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {-Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {-Sin[(19*Pi)/30], 0, \
Cos[(19*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(29*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.7013610013807882, 0.04872599473538669, 0.25619265795642376], 
    Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(31*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(31*Pi)/30], 
       Cos[(19*Pi)/30]}, {-Sin[(19*Pi)/30], 0, Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.692425619079734, 0.12177125630813754, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(16*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(31*Pi)/30]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(31*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.6759038767966659, 0.19348236651450298, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {(-5 - Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, \
{Cos[(16*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(16*Pi)/15], 
       Cos[(19*Pi)/30]}}]}, {RGBColor[0.6519767901974343, 0.2630736434245472, \
0.25619265795642376], 
    Polygon[{{(-5 - Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(17*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(17*Pi)/15], 
       Cos[(19*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.6209065094498847, 0.32978263044553313, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, 
       Cos[(19*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(17*Pi)/15], Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.5830334470517621, 0.3928784499559058, 0.25619265795642376], 
    Polygon[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       Cos[(19*Pi)/30]}, {-(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.5387725482001476, 0.45166981095346026, 0.25619265795642376], 
    Polygon[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(37*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(19*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.48860874456504855, 0.5055125829842241, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(19*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(37*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.43309164127654154, 0.5538168533705041, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
      {Cos[(19*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.3728294953359562, 0.5960533904176297, 0.25619265795642376], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
      {-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {-Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, 
       Cos[(19*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.3084825514248824, 0.6317594417871487, 0.25619265795642376], 
    Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(41*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(41*Pi)/30], 
       Cos[(19*Pi)/30]}, {-Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.24075580812627367, 0.6605438045082853, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(41*Pi)/30], 
       Cos[(19*Pi)/30]}}]}, {RGBColor[0.1703912938124419, 0.6820911110795516, \
0.25619265795642376], 
    Polygon[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, \
-(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(43*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(43*Pi)/30], 
       Cos[(19*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.09815993682693046, 0.6961652847010888, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(22*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(43*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.02485311903225529, 0.7026121257814895, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {0, -Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {0, -Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(22*Pi)/15], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.04872599473538687, 0.7013610013807882, 0.25619265795642376], 
    Polygon[{{0, -Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(23*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/15], 
       Cos[(19*Pi)/30]}, {0, -Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.12177125630813779, 0.692425619079734, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(47*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(23*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(23*Pi)/15], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.19348236651450307, 0.6759038767966659, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Cos[(47*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(47*Pi)/30], 
       Cos[(19*Pi)/30]}}]}, {RGBColor[0.2630736434245472, 0.6519767901974343, \
0.25619265795642376], 
    Polygon[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, \
-(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(49*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(49*Pi)/30], 
       Cos[(19*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.32978263044553313, 0.6209065094498848, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, 
       Cos[(19*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(49*Pi)/30], Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.3928784499559058, 0.5830334470517621, 0.25619265795642376], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, \
{Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.45166981095346037, 0.5387725482001476, 0.25619265795642376], 
    Polygon[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(26*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.505512582984224, 0.48860874456504877, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(53*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(26*Pi)/15], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.553816853370504, 0.4330916412765416, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
      {((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
      {Cos[(53*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.5960533904176297, 0.3728294953359562, 0.25619265795642376], 
    Polygon[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 \
+ Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
      {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, 
       Cos[(19*Pi)/30]}, {((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.6317594417871487, 0.30848255142488246, 0.25619265795642376], 
    Polygon[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(28*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(28*Pi)/15], 
       Cos[(19*Pi)/30]}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.6605438045082853, 0.24075580812627367, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(28*Pi)/15], 
       Cos[(19*Pi)/30]}}]}, {RGBColor[0.6820911110795516, \
0.17039129381244195, 0.25619265795642376], 
    Polygon[{{(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(29*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/15], 
       Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}]}, 
   {RGBColor[0.6961652847010888, 0.09815993682693051, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Cos[(59*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(29*Pi)/15], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.7026121257814895, 0.024853119032255306, 0.25619265795642376], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {Sin[(19*Pi)/30], 0, \
Cos[(19*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(59*Pi)/30], Cos[(19*Pi)/30]}}]}, \
{RGBColor[0.6708419109227928, 0.04650395185521568, 0.3283683215379], 
    Polygon[{{Sin[(19*Pi)/30], 0, Cos[(19*Pi)/30]}, \
{Cos[Pi/30]*Sin[(19*Pi)/30], Sin[Pi/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, 
      {(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, -1/2}, {Sqrt[3]/2, 0, \
-1/2}}]}, 
   {RGBColor[0.6623059821201117, 0.11637127238545963, 0.3283683215379], 
    Polygon[{{Cos[Pi/30]*Sin[(19*Pi)/30], Sin[Pi/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[Pi/15]*Sin[(19*Pi)/30], Sin[Pi/15]*Sin[(19*Pi)/30], 
       Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, \
-1/2}, {(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, -1/2}}]}, 
   {RGBColor[0.6465136903808856, 0.1849636049031942, 0.3283683215379], 
    Polygon[{{Cos[Pi/15]*Sin[(19*Pi)/30], Sin[Pi/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
      {(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, -1/2}}]}, \
{RGBColor[0.6236380593581591, 0.25152943745948664, 0.3283683215379], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
      {Cos[(2*Pi)/15]*Sin[(19*Pi)/30], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 
       -1/2}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, \
-1/2}}]}, 
   {RGBColor[0.5939297192524506, 0.3153394608630542, 0.3283683215379], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(19*Pi)/30], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, 
       Cos[(19*Pi)/30]}, {3/4, Sqrt[3]/4, -1/2}, {(Sqrt[3]*Cos[(2*Pi)/15])/2, \
(Sqrt[3]*Sin[(2*Pi)/15])/2, -1/2}}]}, 
   {RGBColor[0.5577141608548282, 0.37569455914438166, 0.3283683215379], 
    Polygon[{{(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}, {((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
      {3/4, Sqrt[3]/4, -1/2}}]}, {RGBColor[0.5153881694016891, \
0.4319334692165824, 0.3283683215379], 
    Polygon[{{((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
      {Cos[(7*Pi)/30]*Sin[(19*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 
       -1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
-1/2}}]}, 
   {RGBColor[0.46741547731267696, 0.4834400258121569, 0.3283683215379], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(19*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(4*Pi)/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, -1/2}, 
      {(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, -1/2}}]}, \
{RGBColor[0.4143216834412501, 0.5296499123186041, 0.3283683215379], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(19*Pi)/30], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
      {(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, -1/2}}]}, \
{RGBColor[0.3566884945036547, 0.5700568435493191, 0.3283683215379], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
      {Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Sqrt[3]/4, 3/4, -1/2}, 
      {Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}}]}, \
{RGBColor[0.2951473517784112, 0.6042181127100439, 0.3283683215379], 
    Polygon[{{Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, \
Cos[(19*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(19*Pi)/30], 
       Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(11*Pi)/30])/2, \
(Sqrt[3]*Sin[(11*Pi)/30])/2, -1/2}, {Sqrt[3]/4, 3/4, -1/2}}]}, 
   {RGBColor[0.23037251290352928, 0.6317594417871487, 0.3283683215379], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
      {(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, -1/2}}]}, \
{RGBColor[0.16307366456872863, 0.6523790822158712, 0.3283683215379], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
      {Cos[(13*Pi)/30]*Sin[(19*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(13*Pi)/30])/2, 
       (Sqrt[3]*Sin[(13*Pi)/30])/2, -1/2}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, \
Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}}]}, 
   {RGBColor[0.09398814703955488, 0.6658511209007367, 0.3283683215379], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, 
      {Cos[(7*Pi)/15]*Sin[(19*Pi)/30], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 
       -1/2}, {(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
-1/2}}]}, 
   {RGBColor[0.023872875703131572, 0.6720279553667089, 0.3283683215379], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(19*Pi)/30], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {0, Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, 
      {0, Sqrt[3]/2, -1/2}, {(Sqrt[3]*Cos[(7*Pi)/15])/2, \
(Sqrt[3]*Sin[(7*Pi)/15])/2, -1/2}}]}, 
   {RGBColor[0.04650395185521562, 0.6708419109227928, 0.3283683215379], 
    Polygon[{{0, Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(19*Pi)/30], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, 
      {(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, -1/2}, {0, \
Sqrt[3]/2, -1/2}}]}, 
   {RGBColor[0.11637127238545951, 0.6623059821201117, 0.3283683215379], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(19*Pi)/30], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(19*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, -1/2}, 
      {(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, -1/2}}]}, \
{RGBColor[0.18496360490319413, 0.6465136903808856, 0.3283683215379], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
      {(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, -1/2}}]}, \
{RGBColor[0.2515294374594865, 0.6236380593581591, 0.3283683215379], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
      {Cos[(19*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]^2, Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, -1/2}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}}]}, \
{RGBColor[0.3153394608630542, 0.5939297192524506, 0.3283683215379], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]^2, \
Cos[(19*Pi)/30]}, {-Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 
       Cos[(19*Pi)/30]}, {-Sqrt[3]/4, 3/4, -1/2}, \
{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, -1/2}}]}, 
   {RGBColor[0.37569455914438166, 0.5577141608548282, 0.3283683215379], 
    Polygon[{{-Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, \
Cos[(19*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {-Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
      {-Sqrt[3]/4, 3/4, -1/2}}]}, {RGBColor[0.43193346921658227, \
0.5153881694016892, 0.3283683215379], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
      {Cos[(11*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(11*Pi)/15])/2, 
       (Sqrt[3]*Sin[(11*Pi)/15])/2, -1/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}}]}, 
   {RGBColor[0.48344002581215684, 0.46741547731267685, 0.3283683215379], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(11*Pi)/15], Cos[(19*Pi)/30]}, 
      {Cos[(23*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(23*Pi)/30])/2, 
       (Sqrt[3]*Sin[(23*Pi)/30])/2, -1/2}, {(Sqrt[3]*Cos[(11*Pi)/15])/2, \
(Sqrt[3]*Sin[(11*Pi)/15])/2, -1/2}}]}, 
   {RGBColor[0.5296499123186041, 0.41432168344125, 0.3283683215379], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(23*Pi)/30], Cos[(19*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
      {(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, -1/2}}]}, \
{RGBColor[0.5700568435493191, 0.3566884945036547, 0.3283683215379], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}, \
{-3/4, Sqrt[3]/4, -1/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}}]}, \
{RGBColor[0.6042181127100439, 0.29514735177841106, 0.3283683215379], 
    Polygon[{{-(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(13*Pi)/15], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, -1/2}, 
      {-3/4, Sqrt[3]/4, -1/2}}]}, {RGBColor[0.6317594417871487, \
0.23037251290352923, 0.3283683215379], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(13*Pi)/15], Cos[(19*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {-Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
      {(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, -1/2}}]}, \
{RGBColor[0.6523790822158712, 0.16307366456872865, 0.3283683215379], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
      {Cos[(14*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(14*Pi)/15])/2, 
       (Sqrt[3]*Sin[(14*Pi)/15])/2, -1/2}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, \
(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}}]}, 
   {RGBColor[0.6658511209007367, 0.09398814703955503, 0.3283683215379], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(14*Pi)/15], Cos[(19*Pi)/30]}, 
      {Cos[(29*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(29*Pi)/30])/2, 
       (Sqrt[3]*Sin[(29*Pi)/30])/2, -1/2}, {(Sqrt[3]*Cos[(14*Pi)/15])/2, \
(Sqrt[3]*Sin[(14*Pi)/15])/2, -1/2}}]}, 
   {RGBColor[0.6720279553667089, 0.023872875703131635, 0.3283683215379], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(29*Pi)/30], Cos[(19*Pi)/30]}, {-Sin[(19*Pi)/30], 0, \
Cos[(19*Pi)/30]}, 
      {-Sqrt[3]/2, 0, -1/2}, {(Sqrt[3]*Cos[(29*Pi)/30])/2, \
(Sqrt[3]*Sin[(29*Pi)/30])/2, -1/2}}]}, 
   {RGBColor[0.6708419109227928, 0.0465039518552157, 0.3283683215379], 
    Polygon[{{-Sin[(19*Pi)/30], 0, Cos[(19*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(19*Pi)/30]}, 
      {(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, -1/2}, \
{-Sqrt[3]/2, 0, -1/2}}]}, 
   {RGBColor[0.6623059821201117, 0.11637127238545952, 0.3283683215379], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(31*Pi)/30], Cos[(19*Pi)/30]}, 
      {Cos[(16*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(16*Pi)/15])/2, 
       (Sqrt[3]*Sin[(16*Pi)/15])/2, -1/2}, {(Sqrt[3]*Cos[(31*Pi)/30])/2, \
(Sqrt[3]*Sin[(31*Pi)/30])/2, -1/2}}]}, 
   {RGBColor[0.6465136903808856, 0.18496360490319413, 0.3283683215379], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(16*Pi)/15], Cos[(19*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {-Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
      {(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, -1/2}}]}, \
{RGBColor[0.6236380593581592, 0.25152943745948647, 0.3283683215379], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
      {Cos[(17*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(17*Pi)/15])/2, 
       (Sqrt[3]*Sin[(17*Pi)/15])/2, -1/2}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, \
-(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}}]}, 
   {RGBColor[0.5939297192524506, 0.31533946086305414, 0.3283683215379], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(17*Pi)/15], Cos[(19*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}, \
{-3/4, -Sqrt[3]/4, -1/2}, 
      {(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, -1/2}}]}, \
{RGBColor[0.5577141608548282, 0.37569455914438166, 0.3283683215379], 
    Polygon[{{-(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
      {-3/4, -Sqrt[3]/4, -1/2}}]}, {RGBColor[0.5153881694016891, \
0.4319334692165824, 0.3283683215379], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
      {Cos[(37*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(37*Pi)/30])/2, 
       (Sqrt[3]*Sin[(37*Pi)/30])/2, -1/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, \
-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}}]}, 
   {RGBColor[0.46741547731267696, 0.48344002581215684, 0.3283683215379], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(37*Pi)/30], Cos[(19*Pi)/30]}, 
      {Cos[(19*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(19*Pi)/15])/2, 
       (Sqrt[3]*Sin[(19*Pi)/15])/2, -1/2}, {(Sqrt[3]*Cos[(37*Pi)/30])/2, \
(Sqrt[3]*Sin[(37*Pi)/30])/2, -1/2}}]}, 
   {RGBColor[0.4143216834412501, 0.5296499123186041, 0.3283683215379], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(19*Pi)/15], Cos[(19*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {-Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
      {(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, -1/2}}]}, \
{RGBColor[0.3566884945036547, 0.5700568435493191, 0.3283683215379], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
      {-Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{-Sqrt[3]/4, -3/4, -1/2}, 
      {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}}]}, \
{RGBColor[0.2951473517784111, 0.6042181127100439, 0.3283683215379], 
    Polygon[{{-Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, \
Cos[(19*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(41*Pi)/30], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, -1/2}, 
      {-Sqrt[3]/4, -3/4, -1/2}}]}, {RGBColor[0.23037251290352923, \
0.6317594417871487, 0.3283683215379], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(41*Pi)/30], Cos[(19*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
      {(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, -1/2}}]}, \
{RGBColor[0.16307366456872888, 0.652379082215871, 0.3283683215379], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
      {Cos[(43*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(43*Pi)/30])/2, 
       (Sqrt[3]*Sin[(43*Pi)/30])/2, -1/2}, {-(Sqrt[3]*(-1 + Sqrt[5]))/8, \
-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}}]}, 
   {RGBColor[0.09398814703955535, 0.6658511209007367, 0.3283683215379], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(43*Pi)/30], Cos[(19*Pi)/30]}, 
      {Cos[(22*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(22*Pi)/15])/2, 
       (Sqrt[3]*Sin[(22*Pi)/15])/2, -1/2}, {(Sqrt[3]*Cos[(43*Pi)/30])/2, \
(Sqrt[3]*Sin[(43*Pi)/30])/2, -1/2}}]}, 
   {RGBColor[0.02387287570313175, 0.6720279553667089, 0.3283683215379], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(22*Pi)/15], Cos[(19*Pi)/30]}, {0, -Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, 
      {0, -Sqrt[3]/2, -1/2}, {(Sqrt[3]*Cos[(22*Pi)/15])/2, \
(Sqrt[3]*Sin[(22*Pi)/15])/2, -1/2}}]}, 
   {RGBColor[0.046503951855215865, 0.6708419109227928, 0.3283683215379], 
    Polygon[{{0, -Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(19*Pi)/30]}, 
      {(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, -1/2}, {0, \
-Sqrt[3]/2, -1/2}}]}, 
   {RGBColor[0.11637127238545977, 0.6623059821201116, 0.3283683215379], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(23*Pi)/15], Cos[(19*Pi)/30]}, 
      {Cos[(47*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(47*Pi)/30])/2, 
       (Sqrt[3]*Sin[(47*Pi)/30])/2, -1/2}, {(Sqrt[3]*Cos[(23*Pi)/15])/2, \
(Sqrt[3]*Sin[(23*Pi)/15])/2, -1/2}}]}, 
   {RGBColor[0.18496360490319422, 0.6465136903808856, 0.3283683215379], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(47*Pi)/30], Cos[(19*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
      {(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, -1/2}}]}, \
{RGBColor[0.2515294374594864, 0.6236380593581592, 0.3283683215379], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
      {Cos[(49*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(49*Pi)/30])/2, 
       (Sqrt[3]*Sin[(49*Pi)/30])/2, -1/2}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, \
-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}}]}, 
   {RGBColor[0.31533946086305414, 0.5939297192524506, 0.3283683215379], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(49*Pi)/30], Cos[(19*Pi)/30]}, 
      {Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Sqrt[3]/4, -3/4, -1/2}, 
      {(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, -1/2}}]}, \
{RGBColor[0.37569455914438166, 0.5577141608548282, 0.3283683215379], 
    Polygon[{{Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, \
Cos[(19*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
      {Sqrt[3]/4, -3/4, -1/2}}]}, {RGBColor[0.4319334692165825, \
0.5153881694016891, 0.3283683215379], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
      {Cos[(26*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(26*Pi)/15])/2, 
       (Sqrt[3]*Sin[(26*Pi)/15])/2, -1/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
-(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}}]}, 
   {RGBColor[0.4834400258121567, 0.46741547731267713, 0.3283683215379], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(26*Pi)/15], Cos[(19*Pi)/30]}, 
      {Cos[(53*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(53*Pi)/30])/2, 
       (Sqrt[3]*Sin[(53*Pi)/30])/2, -1/2}, {(Sqrt[3]*Cos[(26*Pi)/15])/2, \
(Sqrt[3]*Sin[(26*Pi)/15])/2, -1/2}}]}, 
   {RGBColor[0.529649912318604, 0.4143216834412502, 0.3283683215379], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(53*Pi)/30], Cos[(19*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
      {(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, -1/2}}]}, \
{RGBColor[0.5700568435493191, 0.3566884945036547, 0.3283683215379], 
    Polygon[{{((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
      {(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}, \
{3/4, -Sqrt[3]/4, -1/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}}]}, \
{RGBColor[0.6042181127100439, 0.2951473517784111, 0.3283683215379], 
    Polygon[{{(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(19*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(28*Pi)/15], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, -1/2}, 
      {3/4, -Sqrt[3]/4, -1/2}}]}, {RGBColor[0.6317594417871487, \
0.23037251290352925, 0.3283683215379], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(28*Pi)/15], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
      {(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, -1/2}}]}, \
{RGBColor[0.652379082215871, 0.1630736645687289, 0.3283683215379], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
      {Cos[(29*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(29*Pi)/15])/2, 
       (Sqrt[3]*Sin[(29*Pi)/15])/2, -1/2}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, \
-(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}}]}, 
   {RGBColor[0.6658511209007367, 0.09398814703955541, 0.3283683215379], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(29*Pi)/15], Cos[(19*Pi)/30]}, 
      {Cos[(59*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(59*Pi)/30])/2, 
       (Sqrt[3]*Sin[(59*Pi)/30])/2, -1/2}, {(Sqrt[3]*Cos[(29*Pi)/15])/2, \
(Sqrt[3]*Sin[(29*Pi)/15])/2, -1/2}}]}, 
   {RGBColor[0.6720279553667089, 0.023872875703131763, 0.3283683215379], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(59*Pi)/30], Cos[(19*Pi)/30]}, {Sin[(19*Pi)/30], 0, \
Cos[(19*Pi)/30]}, 
      {Sqrt[3]/2, 0, -1/2}, {(Sqrt[3]*Cos[(59*Pi)/30])/2, \
(Sqrt[3]*Sin[(59*Pi)/30])/2, -1/2}}]}, 
   {RGBColor[0.6329729361060323, 0.04377240194694139, 0.3969463130731183], 
    Polygon[{{Sqrt[3]/2, 0, -1/2}, {(Sqrt[3]*Cos[Pi/30])/2, \
(Sqrt[3]*Sin[Pi/30])/2, -1/2}, {((1 + Sqrt[5])*Cos[Pi/30])/4, 
       ((1 + Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {(1 + \
Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.6249299822239445, 0.10969630045027219, 0.3969463130731183], \
Polygon[{{(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, -1/2}, 
      {(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, -1/2}, {((1 + \
Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + \
Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.6100401646816048, 0.17441834333044323, 0.3969463130731183], \
Polygon[{{(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, -1/2}, 
      {Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.5884666194359021, \
0.237229422341701, 0.3969463130731183], 
    Polygon[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5604457107631025, 0.297441366158335, 0.3969463130731183], \
Polygon[{{(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, -1/2}, 
      {3/4, Sqrt[3]/4, -1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5262844416023776, 0.3543944801237308, 0.3969463130731183], 
    Polygon[{{3/4, Sqrt[3]/4, -1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -1/2}, 
      {(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.4863570899673574, \
0.40746477400307834, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, \
{(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.4411011082778906, 0.4560707985509622, 0.3969463130731183], \
Polygon[{{(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, -1/2}, 
      {(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, -1/2}, {((1 + \
Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.3910123305397901, 0.4996800159909718, 0.3969463130731183], \
Polygon[{{(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, -1/2}, 
      {Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, 
       -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.33663953988370504, 0.5378146346110184, 0.3969463130731183], 
    Polygon[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, \
{Sqrt[3]/4, 3/4, -1/2}, 
      {(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.2785784559823016, \
0.570056843549319, 0.3969463130731183], 
    Polygon[{{Sqrt[3]/4, 3/4, -1/2}, {(Sqrt[3]*Cos[(11*Pi)/30])/2, \
(Sqrt[3]*Sin[(11*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.21746520822086615, 0.5960533904176297, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, \
-1/2}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.15396936613064244, 0.6155194516083339, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, \
{(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.08878660344493021, 0.6282417528814912, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
-1/2}, {(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.02263107615208411, 0.63408090604204, 0.3969463130731183], \
Polygon[{{(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, -1/2}, 
      {0, Sqrt[3]/2, -1/2}, {0, (1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.04377240194694133, \
0.6329729361060323, 0.3969463130731183], 
    Polygon[{{0, Sqrt[3]/2, -1/2}, {(Sqrt[3]*Cos[(8*Pi)/15])/2, \
(Sqrt[3]*Sin[(8*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {0, (1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.1096963004502721, 0.6249299822239445, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, -1/2}, \
{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17441834333044318, 0.6100401646816048, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, \
-1/2}, {-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
      {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.23722942234170097, 0.5884666194359021, 0.3969463130731183], 
    Polygon[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, \
-1/2}, {(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.29744136615833494, 0.5604457107631025, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, \
-1/2}, {-Sqrt[3]/4, 3/4, -1/2}, 
      {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.3543944801237308, 0.5262844416023776, 0.3969463130731183], 
    Polygon[{{-Sqrt[3]/4, 3/4, -1/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.4074647740030781, \
0.4863570899673575, 0.3969463130731183], 
    Polygon[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, -Sqrt[(5 \
- Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.45607079855096233, 0.4411011082778906, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, \
-1/2}, {(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.4996800159909718, 0.39101233053979007, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, \
-1/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
      {-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.5378146346110184, 0.33663953988370504, 0.3969463130731183], 
    Polygon[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, \
{-3/4, Sqrt[3]/4, -1/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.5700568435493191, \
0.2785784559823014, 0.3969463130731183], 
    Polygon[{{-3/4, Sqrt[3]/4, -1/2}, {(Sqrt[3]*Cos[(13*Pi)/15])/2, \
(Sqrt[3]*Sin[(13*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5960533904176297, 0.21746520822086607, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, \
-1/2}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
      {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.6155194516083339, 0.15396936613064244, 0.3969463130731183], 
    Polygon[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, \
-1/2}, {(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.6282417528814912, 0.08878660344493035, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, \
-1/2}, {(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.63408090604204, 0.02263107615208417, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, \
-1/2}, {-Sqrt[3]/2, 0, -1/2}, 
      {(-1 - Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.6329729361060323, \
0.0437724019469414, 0.3969463130731183], 
    Polygon[{{-Sqrt[3]/2, 0, -1/2}, {(Sqrt[3]*Cos[(31*Pi)/30])/2, \
(Sqrt[3]*Sin[(31*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.6249299822239445, 0.1096963004502721, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, \
-1/2}, {(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.6100401646816048, 0.17441834333044318, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, \
-1/2}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
      {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5884666194359021, 0.23722942234170086, 0.3969463130731183], 
    Polygon[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, \
-1/2}, {(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5604457107631026, 0.29744136615833494, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, \
-1/2}, {-3/4, -Sqrt[3]/4, -1/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.5262844416023776, 0.3543944801237308, 0.3969463130731183], 
    Polygon[{{-3/4, -Sqrt[3]/4, -1/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, \
-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
      {-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.4863570899673574, \
0.40746477400307834, 0.3969463130731183], 
    Polygon[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
-1/2}, {(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.44110110827789073, 0.4560707985509622, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, \
-1/2}, {(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.3910123305397901, 0.4996800159909717, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, \
-1/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, \
-Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.33663953988370504, 0.5378146346110184, 0.3969463130731183], 
    Polygon[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, \
-1/2}, {-Sqrt[3]/4, -3/4, -1/2}, 
      {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])^2/16, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.27857845598230146, \
0.5700568435493191, 0.3969463130731183], 
    Polygon[{{-Sqrt[3]/4, -3/4, -1/2}, {(Sqrt[3]*Cos[(41*Pi)/30])/2, \
(Sqrt[3]*Sin[(41*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2174652082208661, 0.5960533904176297, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, \
-1/2}, {-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
      {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.15396936613064266, 0.6155194516083338, 0.3969463130731183], 
    Polygon[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, \
-1/2}, {(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.08878660344493065, 0.6282417528814911, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, \
-1/2}, {(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.02263107615208428, 0.63408090604204, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, \
-1/2}, {0, -Sqrt[3]/2, -1/2}, 
      {0, (-1 - Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.043772401946941555, \
0.6329729361060323, 0.3969463130731183], 
    Polygon[{{0, -Sqrt[3]/2, -1/2}, {(Sqrt[3]*Cos[(23*Pi)/15])/2, \
(Sqrt[3]*Sin[(23*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {0, (-1 - Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.10969630045027233, 0.6249299822239444, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, \
-1/2}, {(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17441834333044326, 0.6100401646816048, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, \
-1/2}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.23722942234170086, 0.5884666194359021, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, \
-1/2}, {(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2974413661583349, 0.5604457107631026, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, \
-1/2}, {Sqrt[3]/4, -3/4, -1/2}, 
      {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.3543944801237308, 0.5262844416023776, 0.3969463130731183], 
    Polygon[{{Sqrt[3]/4, -3/4, -1/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
-(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.40746477400307834, \
0.48635708996735727, 0.3969463130731183], 
    Polygon[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, -Sqrt[(5 \
- Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.45607079855096216, 0.44110110827789084, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, \
-1/2}, {(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.49968001599097167, 0.39101233053979023, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, \
-1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
      {(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, \
{RGBColor[0.5378146346110184, 0.33663953988370504, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, \
{3/4, -Sqrt[3]/4, -1/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.5700568435493191, \
0.27857845598230146, 0.3969463130731183], 
    Polygon[{{3/4, -Sqrt[3]/4, -1/2}, {(Sqrt[3]*Cos[(28*Pi)/15])/2, \
(Sqrt[3]*Sin[(28*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.5960533904176297, 0.21746520822086612, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, \
-1/2}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
      {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.6155194516083338, 0.1539693661306427, 0.3969463130731183], 
    Polygon[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, \
-1/2}, {(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.6282417528814911, 0.0887866034449307, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, \
-1/2}, {(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, -1/2}, 
      {((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.63408090604204, 0.022631076152084293, 0.3969463130731183], 
    Polygon[{{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, \
-1/2}, {Sqrt[3]/2, 0, -1/2}, 
      {(1 + Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}}]}, {RGBColor[0.5881689773431917, \
0.04056127244297242, 0.461175277735951], 
    Polygon[{{(1 + Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}, {Cos[Pi/30]*Sin[(11*Pi)/15], \
Sin[Pi/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, 
      {Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}}]}, {RGBColor[0.5807071186675256, \
0.10181947289192497, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {Cos[Pi/15]*Sin[(11*Pi)/15], 
       Sin[Pi/15]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[Pi/30]*Sin[(11*Pi)/15], Sin[Pi/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}]}, \

   {RGBColor[0.5668829112789608, 0.1619621178887791, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Cos[Pi/15]*Sin[(11*Pi)/15], Sin[Pi/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.5468478160865484, 0.2203302720292916, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(2*Pi)/15]*Sin[(11*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.5208213417858291, 0.27628444160237764, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(11*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.4890886398756318, 0.3292115810170317, 0.461175277735951], 
    Polygon[{{(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \

       -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.45199738047857924, 0.3785318094581108, 0.461175277735951], 
    Polygon[{{(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(7*Pi)/30]*Sin[(11*Pi)/15], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.40995394319447065, 0.4237047641818932, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(4*Pi)/15]*Sin[(11*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(11*Pi)/15], 
       Sin[(7*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.3634189647203457, 0.4642355208433766, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, \
{Cos[(4*Pi)/15]*Sin[(11*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.31290229201843694, 0.4996800159909718, 0.461175277735951], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.2589573963261601, 0.5296499123186043, 0.461175277735951], 
    Polygon[{{(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(11*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], 
       Cos[(11*Pi)/15]}, {Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.2021753092094148, 0.5538168533705042, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {Cos[(11*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.14317814709706767, 0.5719160610832498, 0.461175277735951], 
    Polygon[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(13*Pi)/30]*Sin[(11*Pi)/15], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.08261229524317165, 0.5837492367496373, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(7*Pi)/15]*Sin[(11*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(11*Pi)/15], 
       Sin[(13*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.021141325794857276, 0.5891867336208145, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {0, (1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {0, Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(11*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.04056127244297236, 0.5881689773431917, 0.461175277735951], 
    Polygon[{{0, (1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}, {Cos[(8*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(8*Pi)/15]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, 
      {0, Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.10181947289192486, 0.5807071186675256, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(17*Pi)/30]*Sin[(11*Pi)/15], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(11*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.16196211788877907, 0.5668829112789608, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {Cos[(17*Pi)/30]*Sin[(11*Pi)/15], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.22033027202929156, 0.5468478160865484, 0.461175277735951], 
    Polygon[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(19*Pi)/30]*Sin[(11*Pi)/15], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.27628444160237764, 0.5208213417858291, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(11*Pi)/15], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.3292115810170317, 0.4890886398756318, 0.461175277735951], 
    Polygon[{{(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       (1 + Sqrt[5])^2/16, -Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       Cos[(11*Pi)/15]}, {-Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.37853180945811066, 0.45199738047857935, 0.461175277735951], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(11*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]^2, Cos[(11*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.4237047641818932, 0.40995394319447065, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(23*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]^2, 
       Cos[(11*Pi)/15]}}]}, {RGBColor[0.4642355208433767, 0.3634189647203456, \
0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{Cos[(23*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], 
       Cos[(11*Pi)/15]}}]}, {RGBColor[0.4996800159909718, \
0.31290229201843694, 0.461175277735951], 
    Polygon[{{-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, \
Cos[(11*Pi)/15]}, 
      {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.5296499123186043, 0.25895739632616, 0.461175277735951], 
    Polygon[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(13*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], 
       Cos[(11*Pi)/15]}, {-(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.5538168533705042, 0.20217530920941473, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Cos[(13*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.5719160610832498, 0.1431781470970677, 0.461175277735951], 
    Polygon[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(14*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.5837492367496373, 0.08261229524317178, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(29*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(14*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.5891867336208145, 0.021141325794857332, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {-Sin[(11*Pi)/15], 0, \
Cos[(11*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(29*Pi)/30], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.5881689773431917, 0.04056127244297243, 0.461175277735951], 
    Polygon[{{(-1 - Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}, {Cos[(31*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(31*Pi)/30], Cos[(11*Pi)/15]}, 
      {-Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.5807071186675256, 0.10181947289192488, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(16*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(31*Pi)/30]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(31*Pi)/30], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.5668829112789608, 0.16196211788877904, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Cos[(16*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.5468478160865484, 0.22033027202929148, 0.461175277735951], 
    Polygon[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(17*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.5208213417858291, 0.2762844416023776, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(17*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, 
       Cos[(11*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(17*Pi)/15], Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.4890886398756318, 0.3292115810170317, 0.461175277735951], 
    Polygon[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, 
      {-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{-(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.45199738047857924, 0.3785318094581108, 0.461175277735951], 
    Polygon[{{-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(37*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(11*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.40995394319447076, 0.4237047641818932, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(19*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(37*Pi)/30], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.3634189647203457, 0.4642355208433766, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, \
-Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, \
{Cos[(19*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(19*Pi)/15], 
       Cos[(11*Pi)/15]}}]}, {RGBColor[0.31290229201843694, \
0.4996800159909718, 0.461175277735951], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, 
       Cos[(11*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.25895739632616, 0.5296499123186043, 0.461175277735951], 
    Polygon[{{(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
       ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(41*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(41*Pi)/30], 
       Cos[(11*Pi)/15]}, {-Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.20217530920941473, 0.5538168533705042, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {Cos[(41*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.1431781470970679, 0.5719160610832497, 0.461175277735951], 
    Polygon[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(43*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.08261229524317207, 0.5837492367496373, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(22*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(43*Pi)/30], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.021141325794857432, 0.5891867336208145, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(22*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {0, (-1 - Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {0, -Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(22*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.04056127244297258, 0.5881689773431917, 0.461175277735951], 
    Polygon[{{0, (-1 - Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, 
       -Sqrt[(5 - Sqrt[5])/2]/2}, {Cos[(23*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(23*Pi)/15], Cos[(11*Pi)/15]}, 
      {0, -Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.1018194728919251, 0.5807071186675254, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(47*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(23*Pi)/15]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(23*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.16196211788877912, 0.5668829112789608, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {Cos[(47*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.22033027202929145, 0.5468478160865484, 0.461175277735951], 
    Polygon[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(49*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.2762844416023776, 0.5208213417858291, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.3292115810170317, 0.4890886398756318, 0.461175277735951], 
    Polygon[{{(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       -(1 + Sqrt[5])^2/16, -Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       Cos[(11*Pi)/15]}, {Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.3785318094581109, 0.4519973804785792, 0.461175277735951], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(26*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.42370476418189307, 0.40995394319447087, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(53*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(26*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.46423552084337655, 0.36341896472034574, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{Cos[(53*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(53*Pi)/30], 
       Cos[(11*Pi)/15]}}]}, {RGBColor[0.4996800159909718, \
0.31290229201843694, 0.461175277735951], 
    Polygon[{{(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, \
Cos[(11*Pi)/15]}, 
      {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.5296499123186043, 0.25895739632616, 0.461175277735951], 
    Polygon[{{(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, 
       ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(28*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(28*Pi)/15], 
       Cos[(11*Pi)/15]}, {(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.5538168533705042, 0.20217530920941473, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Cos[(28*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(11*Pi)/15]}}]}, 
   {RGBColor[0.5719160610832497, 0.14317814709706791, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(29*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.5837492367496373, 0.08261229524317212, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
      {Cos[(59*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(29*Pi)/15], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.5891867336208145, 0.021141325794857446, 0.461175277735951], 
    Polygon[{{((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(59*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
      {(1 + Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {Sin[(11*Pi)/15], 0, \
Cos[(11*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(59*Pi)/30], Cos[(11*Pi)/15]}}]}, \
{RGBColor[0.5369209161823078, 0.03690574515012629, 0.5203515095487775], 
    Polygon[{{Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}, \
{Cos[Pi/30]*Sin[(11*Pi)/15], Sin[Pi/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, 
      {Cos[Pi/30]*Sin[(23*Pi)/30], Sin[Pi/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.5301219063982081, 0.09282708988147925, 0.5203515095487775], 
    Polygon[{{Cos[Pi/30]*Sin[(11*Pi)/15], Sin[Pi/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[Pi/15]*Sin[(11*Pi)/15], Sin[Pi/15]*Sin[(11*Pi)/15], 
       Cos[(11*Pi)/15]}, {Cos[Pi/15]*Sin[(23*Pi)/30], \
Sin[Pi/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
      {Cos[Pi/30]*Sin[(23*Pi)/30], Sin[Pi/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.517514770072469, 0.14773140159077336, 0.5203515095487775], 
    Polygon[{{Cos[Pi/15]*Sin[(11*Pi)/15], Sin[Pi/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}, {Cos[Pi/15]*Sin[(23*Pi)/30], \
Sin[Pi/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.49923763362888796, 0.20101713714945568, 0.5203515095487775], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(11*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(2*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.4754907451990775, \
0.25210048688798825, 0.5203515095487775], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(11*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, 
       Cos[(11*Pi)/15]}, {(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, \
Cos[(23*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(2*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}}]}, \
{RGBColor[0.4465342806620306, 0.3004217709367576, 0.5203515095487775], 
    Polygon[{{(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       Cos[(23*Pi)/30]}, {(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.412685493102745, 0.3454515711958466, 0.5203515095487775], 
    Polygon[{{((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {Cos[(7*Pi)/30]*Sin[(11*Pi)/15], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.3743152369210342, \
0.38669653175052504, 0.5203515095487775], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(11*Pi)/15], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(11*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(4*Pi)/15]*Sin[(23*Pi)/30], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, 
      {Cos[(7*Pi)/30]*Sin[(23*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.33184390467311753, 0.4237047641818932, 0.5203515095487775], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(11*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(4*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.28573682116280064, 0.45607079855096233, 0.5203515095487775], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.2364991452455502, 0.48344002581215695, 0.5203515095487775], 
    Polygon[{{Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(11*Pi)/15], 
       Cos[(11*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
      {Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.18467033520236165, 0.5055125829842242, 0.5203515095487775], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(23*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.1308182383219439, 0.5220466385118077, \
0.5203515095487775], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {Cos[(13*Pi)/30]*Sin[(11*Pi)/15], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.0755328694469947, 0.5328610418225732, \
0.5203515095487775], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(13*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, 
      {Cos[(7*Pi)/15]*Sin[(11*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(7*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(13*Pi)/30]*Sin[(23*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.019419946648115142, 0.5378373080507889, 0.5203515095487775], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(11*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {0, Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, 
      {0, Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(7*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.03690574515012624, 0.5369209161823078, 0.5203515095487775], 
    Polygon[{{0, Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(11*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, 
      {Cos[(8*Pi)/15]*Sin[(23*Pi)/30], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {0, Sin[(23*Pi)/30], Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.09282708988147916, 0.5301219063982081, 0.5203515095487775], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(11*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(11*Pi)/15], 
       Sin[(17*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(17*Pi)/30]*Sin[(23*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, 
      {Cos[(8*Pi)/15]*Sin[(23*Pi)/30], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.14773140159077333, 0.517514770072469, 0.5203515095487775], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(17*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(23*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.20101713714945563, \
0.49923763362888796, 0.5203515095487775], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(11*Pi)/15], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.25210048688798825, \
0.4754907451990775, 0.5203515095487775], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(19*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, 
      {-Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{-Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {Cos[(19*Pi)/30]*Sin[(23*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.3004217709367576, 0.4465342806620306, 0.5203515095487775], 
    Polygon[{{-Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}, {-Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.34545157119584646, 0.4126854931027451, 0.5203515095487775], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Cos[(11*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]^2, Cos[(11*Pi)/15]}, \
{Cos[(11*Pi)/15]*Sin[(23*Pi)/30], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], 
       Cos[(23*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.38669653175052504, 0.3743152369210342, 0.5203515095487775], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]^2, \
Cos[(11*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(23*Pi)/30], Cos[(11*Pi)/15]}, \
{Cos[(23*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]^2, Cos[(23*Pi)/30]}, 
      {Cos[(11*Pi)/15]*Sin[(23*Pi)/30], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.4237047641818932, 0.3318439046731175, 0.5203515095487775], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(23*Pi)/30], Cos[(11*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(23*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]^2, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.45607079855096233, 0.28573682116280064, 0.5203515095487775], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, \
{-(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, 
      {-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.48344002581215695, 0.2364991452455501, 0.5203515095487775], 
    Polygon[{{-(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, \
Cos[(11*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(13*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(23*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.5055125829842242, 0.1846703352023616, 0.5203515095487775], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(13*Pi)/15], Cos[(11*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(13*Pi)/15], Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.5220466385118077, 0.13081823832194395, 0.5203515095487775], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Cos[(14*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(14*Pi)/15], Cos[(23*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.5328610418225732, \
0.07553286944699482, 0.5203515095487775], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(14*Pi)/15], Cos[(11*Pi)/15]}, 
      {Cos[(29*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(29*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(14*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.5378373080507889, 0.019419946648115194, 0.5203515095487775], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(29*Pi)/30], Cos[(11*Pi)/15]}, {-Sin[(11*Pi)/15], 0, \
Cos[(11*Pi)/15]}, 
      {-Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, \
{Cos[(29*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.5369209161823078, 0.036905745150126304, 0.5203515095487775], 
    Polygon[{{-Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(11*Pi)/15]}, 
      {Cos[(31*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(23*Pi)/30]}, {-Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.5301219063982081, 0.09282708988147917, 0.5203515095487775], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(31*Pi)/30], Cos[(11*Pi)/15]}, 
      {Cos[(16*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(16*Pi)/15], Cos[(23*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.517514770072469, 0.1477314015907733, 0.5203515095487775], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(16*Pi)/15], Cos[(11*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(16*Pi)/15], Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.499237633628888, 0.20101713714945557, 0.5203515095487775], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Cos[(17*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(17*Pi)/15], Cos[(23*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.4754907451990775, 0.2521004868879882, \
0.5203515095487775], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(17*Pi)/15], Cos[(11*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, \
{-(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, 
      {Cos[(17*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.4465342806620306, 0.3004217709367576, 0.5203515095487775], 
    Polygon[{{-(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, \
Cos[(11*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.412685493102745, 0.3454515711958466, 0.5203515095487775], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {Cos[(37*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(37*Pi)/30], Cos[(23*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.3743152369210343, 0.386696531750525, \
0.5203515095487775], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(37*Pi)/30], Cos[(11*Pi)/15]}, 
      {Cos[(19*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(19*Pi)/15], Cos[(23*Pi)/30]}, \
{Cos[(37*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.33184390467311753, 0.4237047641818932, 0.5203515095487775], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(19*Pi)/15], Cos[(11*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(19*Pi)/15], Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.28573682116280064, 0.45607079855096233, 0.5203515095487775], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {-Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{-Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.23649914524555013, 0.48344002581215695, 0.5203515095487775], 
    Polygon[{{-Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(41*Pi)/30], Cos[(11*Pi)/15]}, \
{Cos[(41*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(23*Pi)/30]}, 
      {-Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}}]}, \

   {RGBColor[0.18467033520236162, 0.5055125829842242, 0.5203515095487775], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(41*Pi)/30], Cos[(11*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(41*Pi)/30], 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.1308182383219441, 0.5220466385118075, \
0.5203515095487775], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {Cos[(43*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(43*Pi)/30], Cos[(23*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.07553286944699508, \
0.5328610418225732, 0.5203515095487775], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(43*Pi)/30], Cos[(11*Pi)/15]}, 
      {Cos[(22*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(22*Pi)/15], Cos[(23*Pi)/30]}, \
{Cos[(43*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.019419946648115288, 0.5378373080507889, 0.5203515095487775], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(22*Pi)/15], Cos[(11*Pi)/15]}, {0, -Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, 
      {0, -Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(22*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.03690574515012643, 0.5369209161823078, 0.5203515095487775], 
    Polygon[{{0, -Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(11*Pi)/15]}, 
      {Cos[(23*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(23*Pi)/30]}, {0, -Sin[(23*Pi)/30], Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.09282708988147938, 0.5301219063982081, 0.5203515095487775], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(23*Pi)/15], Cos[(11*Pi)/15]}, 
      {Cos[(47*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(47*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.1477314015907734, 0.5175147700724689, 0.5203515095487775], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(47*Pi)/30], Cos[(11*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(47*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(47*Pi)/30], 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.20101713714945552, 0.499237633628888, \
0.5203515095487775], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(49*Pi)/30], Cos[(23*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.25210048688798814, \
0.4754907451990775, 0.5203515095487775], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(49*Pi)/30], Cos[(11*Pi)/15]}, 
      {Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {Cos[(49*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.3004217709367576, 0.4465342806620306, 0.5203515095487775], 
    Polygon[{{Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}, {Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.34545157119584663, 0.41268549310274494, 0.5203515095487775], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Cos[(26*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(26*Pi)/15], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.38669653175052493, \
0.3743152369210344, 0.5203515095487775], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(26*Pi)/15], Cos[(11*Pi)/15]}, 
      {Cos[(53*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(53*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(26*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.42370476418189307, 0.3318439046731176, 0.5203515095487775], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(53*Pi)/30], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(53*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(53*Pi)/30], 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.45607079855096233, \
0.28573682116280064, 0.5203515095487775], 
    Polygon[{{((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
      {(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, \
{(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, 
      {((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.48344002581215695, 0.23649914524555016, 0.5203515095487775], 
    Polygon[{{(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, \
Cos[(11*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(11*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(28*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(23*Pi)/30]}, 
      {(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.5055125829842242, 0.18467033520236162, 0.5203515095487775], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(28*Pi)/15], Cos[(11*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(28*Pi)/15], Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.5220466385118075, 0.13081823832194414, 0.5203515095487775], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
      {Cos[(29*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(29*Pi)/15], Cos[(23*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       Cos[(23*Pi)/30]}}]}, {RGBColor[0.5328610418225732, \
0.07553286944699512, 0.5203515095487775], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(29*Pi)/15], Cos[(11*Pi)/15]}, 
      {Cos[(59*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(59*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(29*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.5378373080507889, 0.019419946648115298, 0.5203515095487775], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(59*Pi)/30], Cos[(11*Pi)/15]}, {Sin[(11*Pi)/15], 0, \
Cos[(11*Pi)/15]}, 
      {Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, \
{Cos[(59*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(23*Pi)/30]}}]}, 
   {RGBColor[0.47979023710580515, 0.032845870790391696, 0.5738266613324341], 
    Polygon[{{Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, \
{Cos[Pi/30]*Sin[(23*Pi)/30], Sin[Pi/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, -(1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.47372856758725107, 0.08281767384897465, 0.5738266613324341], 
    Polygon[{{Cos[Pi/30]*Sin[(23*Pi)/30], Sin[Pi/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[Pi/15]*Sin[(23*Pi)/30], Sin[Pi/15]*Sin[(23*Pi)/30], 
       Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.46247662874813505, 0.13188210914215584, 0.5738266613324341], 
    Polygon[{{Cos[Pi/15]*Sin[(23*Pi)/30], Sin[Pi/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.44615769918499804, 0.17950161644946994, 0.5738266613324341], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
      {Cos[(2*Pi)/15]*Sin[(23*Pi)/30], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(1 + Sqrt[5])/4}, {Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, 
       (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.4249505725050894, 0.22515446648383552, 0.5738266613324341], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(23*Pi)/30], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, 
       Cos[(23*Pi)/30]}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.39908759842619057, 0.26834047706680303, 0.5738266613324341], 
    Polygon[{{(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, \
Cos[(23*Pi)/30]}, {((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, {(Sqrt[(5 \
- Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + Sqrt[5])/4}, 
      {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.3688521371044855, 0.30858649322917175, 0.5738266613324341], 
    Polygon[{{((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {Cos[(7*Pi)/30]*Sin[(23*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, 
       -(1 + Sqrt[5])/4}}]}, {RGBColor[0.33457545458139165, \
0.3454515711958464, 0.5738266613324341], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(23*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(4*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.2966330933634891, 0.37853180945811066, 0.5738266613324341], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(23*Pi)/30], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {(5 - Sqrt[5])/8, \
(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.25544075790023063, 0.40746477400307823, 0.5738266613324341], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
      {Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + Sqrt[5])/4}, 
      {(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.21144976003900218, 0.43193346921658227, 0.5738266613324341], 
    Polygon[{{Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, \
Cos[(23*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(23*Pi)/30], 
       Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.16514207435807932, 0.45166981095346015, 0.5738266613324341], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, {(Sqrt[(5 \
- Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.11702505755228859, 0.4664575637235475, 0.5738266613324341], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {Cos[(13*Pi)/30]*Sin[(23*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.06762588972688735, 0.476134709812959, 0.5738266613324341], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
      {Cos[(7*Pi)/15]*Sin[(23*Pi)/30], Sin[(7*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.017485798502011145, 0.48059522438406616, 0.5738266613324341], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(23*Pi)/30], Sin[(7*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {0, Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
      {0, Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
       -(1 + Sqrt[5])/4}}]}, {RGBColor[0.032845870790391654, \
0.47979023710580515, 0.5738266613324341], 
    Polygon[{{0, Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(23*Pi)/30], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {0, Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.08281767384897457, 0.47372856758725107, 0.5738266613324341], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(23*Pi)/30], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.1318821091421558, 0.46247662874813505, 0.5738266613324341], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(17*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.17950161644946988, 0.44615769918499804, 0.5738266613324341], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {Cos[(19*Pi)/30]*Sin[(23*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.22515446648383552, 0.4249505725050894, 0.5738266613324341], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
      {-Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.26834047706680303, 0.39908759842619057, 0.5738266613324341], 
    Polygon[{{-Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, \
Cos[(23*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {(-5 + \
Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.30858649322917164, 0.3688521371044856, 0.5738266613324341], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
      {Cos[(11*Pi)/15]*Sin[(23*Pi)/30], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(1 + Sqrt[5])/4}, {(-5 + \
Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       -(1 + Sqrt[5])/4}}]}, {RGBColor[0.3454515711958464, \
0.33457545458139165, 0.5738266613324341], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(11*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
      {Cos[(23*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]^2, Cos[(23*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.37853180945811066, 0.2966330933634891, 0.5738266613324341], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]^2, \
Cos[(23*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + \
Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.40746477400307823, 0.25544075790023063, 0.5738266613324341], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, 
       -(1 + Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - \
Sqrt[5])/8, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.43193346921658227, 0.21144976003900207, 0.5738266613324341], 
    Polygon[{{-(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, \
Cos[(23*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(13*Pi)/15], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       -(1 + Sqrt[5])/4}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.45166981095346015, 0.16514207435807926, 0.5738266613324341], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(13*Pi)/15], Cos[(23*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.4664575637235475, 0.11702505755228862, 0.5738266613324341], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
      {Cos[(14*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.476134709812959, 0.06762588972688746, 0.5738266613324341], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(14*Pi)/15], Cos[(23*Pi)/30]}, 
      {Cos[(29*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.48059522438406616, 0.01748579850201119, 0.5738266613324341], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(29*Pi)/30], Cos[(23*Pi)/30]}, {-Sin[(23*Pi)/30], 0, \
Cos[(23*Pi)/30]}, 
      {-Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       -(1 + Sqrt[5])/4}}]}, {RGBColor[0.47979023710580515, \
0.03284587079039171, 0.5738266613324341], 
    Polygon[{{-Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(23*Pi)/30]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.47372856758725107, 0.08281767384897458, 0.5738266613324341], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(31*Pi)/30], Cos[(23*Pi)/30]}, 
      {Cos[(16*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.46247662874813505, 0.13188210914215578, 0.5738266613324341], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(16*Pi)/15], Cos[(23*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.4461576991849981, 0.17950161644946983, 0.5738266613324341], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
      {Cos[(17*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
       -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.4249505725050894, 0.22515446648383547, 0.5738266613324341], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(17*Pi)/15], Cos[(23*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.39908759842619057, 0.26834047706680303, 0.5738266613324341], 
    Polygon[{{-(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, \
Cos[(23*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, 
       -(1 + Sqrt[5])/4}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.3688521371044855, 0.30858649322917175, 0.5738266613324341], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {Cos[(37*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, 
       -(1 + Sqrt[5])/4}}]}, {RGBColor[0.33457545458139176, \
0.34545157119584635, 0.5738266613324341], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(37*Pi)/30], Cos[(23*Pi)/30]}, 
      {Cos[(19*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.29663309336348914, 0.3785318094581106, 0.5738266613324341], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(19*Pi)/15], Cos[(23*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {(-5 + \
Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.25544075790023063, 0.40746477400307823, 0.5738266613324341], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
      {-Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       -(1 + Sqrt[5])/4}, {(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.21144976003900207, 0.43193346921658227, 0.5738266613324341], 
    Polygon[{{-Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, \
Cos[(23*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(41*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(41*Pi)/30])/2, 
       -(1 + Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.1651420743580793, 0.45166981095346015, 0.5738266613324341], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(41*Pi)/30], Cos[(23*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.11702505755228876, 0.46645756372354746, 0.5738266613324341], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {Cos[(43*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.06762588972688768, 0.476134709812959, 0.5738266613324341], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(43*Pi)/30], Cos[(23*Pi)/30]}, 
      {Cos[(22*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.017485798502011273, 0.48059522438406616, 0.5738266613324341], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(22*Pi)/15], Cos[(23*Pi)/30]}, {0, -Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, 
      {0, -Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
       -(1 + Sqrt[5])/4}}]}, {RGBColor[0.03284587079039182, \
0.47979023710580515, 0.5738266613324341], 
    Polygon[{{0, -Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(23*Pi)/30]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {0, -Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.08281767384897476, 0.47372856758725107, 0.5738266613324341], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(23*Pi)/15], Cos[(23*Pi)/30]}, 
      {Cos[(47*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.13188210914215587, 0.46247662874813505, 0.5738266613324341], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(47*Pi)/30], Cos[(23*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(47*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.17950161644946983, 0.4461576991849981, 0.5738266613324341], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {Cos[(49*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.22515446648383547, 0.4249505725050894, 0.5738266613324341], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(49*Pi)/30], Cos[(23*Pi)/30]}, 
      {Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.26834047706680303, 0.39908759842619057, 0.5738266613324341], 
    Polygon[{{Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {(5 - \
Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}}]}, 
   {RGBColor[0.30858649322917187, 0.36885213710448544, 0.5738266613324341], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
      {Cos[(26*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(1 + Sqrt[5])/4}, {(5 - \
Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       -(1 + Sqrt[5])/4}}]}, {RGBColor[0.3454515711958463, \
0.3345754545813918, 0.5738266613324341], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(26*Pi)/15], Cos[(23*Pi)/30]}, 
      {Cos[(53*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.37853180945811055, 0.2966330933634892, 0.5738266613324341], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(53*Pi)/30], Cos[(23*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.40746477400307823, 0.25544075790023063, 0.5738266613324341], 
    Polygon[{{((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
      {(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + \
Sqrt[5])/8, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.43193346921658227, 0.21144976003900207, 0.5738266613324341], 
    Polygon[{{(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, \
Cos[(23*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(23*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(28*Pi)/15], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(28*Pi)/15])/2, 
       -(1 + Sqrt[5])/4}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.45166981095346015, 0.16514207435807932, 0.5738266613324341], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(28*Pi)/15], Cos[(23*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, 
   {RGBColor[0.46645756372354746, 0.11702505755228879, 0.5738266613324341], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
      {Cos[(29*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(1 + Sqrt[5])/4}, {Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, 
       -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.476134709812959, 0.06762588972688773, 0.5738266613324341], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(29*Pi)/15], Cos[(23*Pi)/30]}, 
      {Cos[(59*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(1 + Sqrt[5])/4}}]}, \
{RGBColor[0.48059522438406616, 0.017485798502011287, 0.5738266613324341], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(59*Pi)/30], Cos[(23*Pi)/30]}, {Sin[(23*Pi)/30], 0, \
Cos[(23*Pi)/30]}, 
      {Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
       -(1 + Sqrt[5])/4}}]}, {RGBColor[0.4174028757890097, \
0.02842613019683723, 0.6210148481335833], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
       -(1 + Sqrt[5])/4}, {Cos[Pi/30]/2, Sin[Pi/30]/2, -Sqrt[3]/2}, {1/2, 0, \
-Sqrt[3]/2}}]}, 
   {RGBColor[0.4121449594557323, 0.0719008900510683, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -(1 + Sqrt[5])/4}, {Cos[Pi/15]/2, Sin[Pi/15]/2, \
-Sqrt[3]/2}, 
      {Cos[Pi/30]/2, Sin[Pi/30]/2, -Sqrt[3]/2}}]}, \
{RGBColor[0.4023714966997804, 0.11458788870767132, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -(1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, {Cos[Pi/15]/2, \
Sin[Pi/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.3881895676243367, 0.15601943847653577, 0.6210148481335833], 
    Polygon[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 \
+ Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, -Sqrt[3]/2}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}}]}, 
   {RGBColor[0.36975455241211136, 0.19574160662828483, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {Sqrt[3]/4, 1/4, -Sqrt[3]/2}, 
      {Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, -Sqrt[3]/2}}]}, \
{RGBColor[0.3472684289475444, 0.23331918877624985, 0.6210148481335833], 
    Polygon[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, 
       -(1 + Sqrt[5])/4}, {(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, \
-Sqrt[3]/2}, {Sqrt[3]/4, 1/4, -Sqrt[3]/2}}]}, 
   {RGBColor[0.3209775599048375, 0.2683404770668031, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, -Sqrt[3]/2}, 
      {(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}}]}, \
{RGBColor[0.29116999354694056, 0.30042177093675754, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(7*Pi)/30]/2, \
Sin[(7*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.258172307808505, 0.32921158101703163, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, 
      {Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, -Sqrt[3]/2}}]}, \
{RGBColor[0.2223460322396907, 0.3543944801237308, 0.6210148481335833], 
    Polygon[{{(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       -(1 + Sqrt[5])/4}, {1/4, Sqrt[3]/4, -Sqrt[3]/2}, {Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}}]}, 
   {RGBColor[0.18408368701275993, 0.37569455914438166, 0.6210148481335833], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, -Sqrt[3]/2}, 
      {1/4, Sqrt[3]/4, -Sqrt[3]/2}}]}, {RGBColor[0.14380448238892923, \
0.3928784499559058, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
      {(-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.10194972576302277, 0.4057578822546119, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 \
+ Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, -Sqrt[3]/2}, {(-1 + Sqrt[5])/8, \
Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}}]}, 
   {RGBColor[0.05897798660730506, 0.41419174628504074, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(13*Pi)/30]/2, \
Sin[(13*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.01536007228838055, 0.41808763886797556, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {0, Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {0, 1/2, -Sqrt[3]/2}, \
{Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.0284261301968372, 0.41740287578900975, 0.6210148481335833], 
    Polygon[{{0, Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
       -(1 + Sqrt[5])/4}, {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, -Sqrt[3]/2}, \
{0, 1/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.07190089005106823, 0.4121449594557323, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(8*Pi)/15]/2, \
Sin[(8*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.1145878887076713, 0.4023714966997804, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
      {(1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.15601943847653577, 0.38818956762433676, 0.6210148481335833], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, -Sqrt[3]/2}, {(1 - Sqrt[5])/8, \
Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}}]}, 
   {RGBColor[0.19574160662828483, 0.36975455241211136, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {-1/4, Sqrt[3]/4, -Sqrt[3]/2}, 
      {Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, -Sqrt[3]/2}}]}, \
{RGBColor[0.23331918877624985, 0.3472684289475444, 0.6210148481335833], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, 
      {(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, 
      {-1/4, Sqrt[3]/4, -Sqrt[3]/2}}]}, {RGBColor[0.268340477066803, \
0.32097755990483756, 0.6210148481335833], 
    Polygon[{{(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 \
+ Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, -Sqrt[3]/2}, 
      {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}}]}, \
{RGBColor[0.30042177093675754, 0.29116999354694056, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(11*Pi)/15]/2, \
Sin[(11*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.3292115810170317, 0.2581723078085049, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + \
Sqrt[5])/4}, {(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, -Sqrt[3]/2}}]}, \
{RGBColor[0.3543944801237308, 0.2223460322396907, 0.6210148481335833], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 \
+ Sqrt[5])/4}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       Sqrt[(5 - Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}, {-Sqrt[3]/4, 1/4, \
-Sqrt[3]/2}, {(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}}]}, 
   {RGBColor[0.37569455914438166, 0.18408368701275984, 0.6210148481335833], 
    Polygon[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, -Sqrt[3]/2}, 
      {-Sqrt[3]/4, 1/4, -Sqrt[3]/2}}]}, {RGBColor[0.3928784499559058, \
0.14380448238892918, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {-Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.4057578822546119, 0.1019497257630228, 0.6210148481335833], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}}]}, 
   {RGBColor[0.41419174628504074, 0.05897798660730514, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(14*Pi)/15]/2, \
Sin[(14*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.41808763886797556, 0.015360072288380591, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {-1/2, 0, -Sqrt[3]/2}, \
{Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.4174028757890097, 0.028426130196837242, 0.6210148481335833], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, -Sqrt[3]/2}, {-1/2, 0, -Sqrt[3]/2}}]}, \

   {RGBColor[0.4121449594557323, 0.07190089005106823, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(31*Pi)/30]/2, \
Sin[(31*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.4023714966997804, 0.11458788870767128, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {-Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.38818956762433676, 0.15601943847653568, 0.6210148481335833], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}}]}, 
   {RGBColor[0.3697545524121114, 0.1957416066282848, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {-Sqrt[3]/4, -1/4, -Sqrt[3]/2}, 
      {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, -Sqrt[3]/2}}]}, \
{RGBColor[0.3472684289475444, 0.23331918877624985, 0.6210148481335833], 
    Polygon[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
       (-5 + Sqrt[5])/8, -(1 + Sqrt[5])/4}, {(-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/4, -Sqrt[3]/2}, {-Sqrt[3]/4, -1/4, -Sqrt[3]/2}}]}, 
   {RGBColor[0.3209775599048375, 0.2683404770668031, 0.6210148481335833], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, -(1 \
+ Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, -Sqrt[3]/2}, 
      {(-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}}]}, \
{RGBColor[0.2911699935469406, 0.3004217709367575, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(37*Pi)/30]/2, \
Sin[(37*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.258172307808505, 0.32921158101703163, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, 
      {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, -Sqrt[3]/2}}]}, \
{RGBColor[0.2223460322396907, 0.3543944801237308, 0.6210148481335833], 
    Polygon[{{(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 \
+ Sqrt[5])/4}, 
      {-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {-1/4, -Sqrt[3]/4, -Sqrt[3]/2}, 
      {-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}}]}, \
{RGBColor[0.18408368701275984, 0.37569455914438166, 0.6210148481335833], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, -Sqrt[3]/2}, 
      {-1/4, -Sqrt[3]/4, -Sqrt[3]/2}}]}, {RGBColor[0.14380448238892918, \
0.3928784499559058, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
      {(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.10194972576302294, 0.40575788225461185, 0.6210148481335833], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, -Sqrt[3]/2}, {(1 - Sqrt[5])/8, \
-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}}]}, 
   {RGBColor[0.05897798660730534, 0.41419174628504074, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(43*Pi)/30]/2, \
Sin[(43*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.015360072288380664, 0.41808763886797556, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {0, -Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {0, -1/2, -Sqrt[3]/2}, \
{Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.028426130196837346, 0.4174028757890097, 0.6210148481335833], 
    Polygon[{{0, -Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, -Sqrt[3]/2}, {0, -1/2, -Sqrt[3]/2}}]}, \

   {RGBColor[0.0719008900510684, 0.41214495945573226, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(23*Pi)/15]/2, \
Sin[(23*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.11458788870767134, 0.40237149669978034, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
      {(-1 + Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.15601943847653565, 0.38818956762433676, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, -Sqrt[3]/2}, {(-1 + Sqrt[5])/8, \
-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}}]}, 
   {RGBColor[0.19574160662828477, 0.3697545524121114, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {1/4, -Sqrt[3]/4, -Sqrt[3]/2}, 
      {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, -Sqrt[3]/2}}]}, \
{RGBColor[0.23331918877624985, 0.3472684289475444, 0.6210148481335833], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, 
      {(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, 
      {1/4, -Sqrt[3]/4, -Sqrt[3]/2}}]}, {RGBColor[0.2683404770668032, \
0.32097755990483745, 0.6210148481335833], 
    Polygon[{{(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 \
+ Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, -Sqrt[3]/2}, 
      {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}}]}, \
{RGBColor[0.3004217709367574, 0.2911699935469407, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(26*Pi)/15]/2, \
Sin[(26*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.3292115810170316, 0.25817230780850503, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, -(1 + \
Sqrt[5])/4}, {(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, -Sqrt[3]/2}}]}, \
{RGBColor[0.3543944801237308, 0.2223460322396907, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, -(1 \
+ Sqrt[5])/4}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
       -Sqrt[(5 - Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}, {Sqrt[3]/4, -1/4, \
-Sqrt[3]/2}, {(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}}]}, 
   {RGBColor[0.37569455914438166, 0.18408368701275984, 0.6210148481335833], 
    Polygon[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, -Sqrt[3]/2}, 
      {Sqrt[3]/4, -1/4, -Sqrt[3]/2}}]}, {RGBColor[0.3928784499559058, \
0.14380448238892918, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.40575788225461185, 0.10194972576302296, 0.6210148481335833], 
    Polygon[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, -Sqrt[3]/2}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}}]}, 
   {RGBColor[0.41419174628504074, 0.058977986607305376, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(29*Pi)/15]/2, \
Sin[(29*Pi)/15]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.41808763886797556, 0.015360072288380674, 0.6210148481335833], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
      {Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {1/2, 0, -Sqrt[3]/2}, \
{Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, -Sqrt[3]/2}}]}, 
   {RGBColor[0.3504423612179025, 0.023694946972296044, 0.6613990663028695], 
    Polygon[{{1/2, 0, -Sqrt[3]/2}, {Cos[Pi/30]/2, Sin[Pi/30]/2, -Sqrt[3]/2}, \
{Cos[Pi/30]*Sin[(13*Pi)/15], Sin[Pi/30]*Sin[(13*Pi)/15], 
       Cos[(13*Pi)/15]}, {Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.3460458049015389, 0.06019634505553386, 0.6613990663028695], 
    Polygon[{{Cos[Pi/30]/2, Sin[Pi/30]/2, -Sqrt[3]/2}, {Cos[Pi/15]/2, \
Sin[Pi/15]/2, -Sqrt[3]/2}, 
      {Cos[Pi/15]*Sin[(13*Pi)/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[Pi/30]*Sin[(13*Pi)/15], Sin[Pi/30]*Sin[(13*Pi)/15], 
       Cos[(13*Pi)/15]}}]}, {RGBColor[0.3378578983319338, \
0.09603821938544822, 0.6613990663028695], 
    Polygon[{{Cos[Pi/15]/2, Sin[Pi/15]/2, -Sqrt[3]/2}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[Pi/15]*Sin[(13*Pi)/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.32596834992689355, 0.13082787888648614, 0.6613990663028695], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, -Sqrt[3]/2}, 
      {Cos[(2*Pi)/15]*Sin[(13*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.31050742406679166, 0.16418416076895004, 0.6613990663028695], 
    Polygon[{{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, -Sqrt[3]/2}, {Sqrt[3]/4, \
1/4, -Sqrt[3]/2}, {(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, 
       Cos[(13*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.29164451389075813, 0.19574160662828483, 0.6613990663028695], 
    Polygon[{{Sqrt[3]/4, 1/4, -Sqrt[3]/2}, {(1 + Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.26958628538999935, 0.22515446648383558, 0.6613990663028695], 
    Polygon[{{(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(7*Pi)/30]*Sin[(13*Pi)/15], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.24457441313195072, 0.2521004868879882, 0.6613990663028695], 
    Polygon[{{Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, -Sqrt[3]/2}, 
      {Cos[(4*Pi)/15]*Sin[(13*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(13*Pi)/15], 
       Sin[(7*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.2168829324231421, 0.2762844416023776, 0.6613990663028695], 
    Polygon[{{Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, -Sqrt[3]/2}, {Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(4*Pi)/15]*Sin[(13*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.18681523692103413, 0.29744136615833494, 0.6613990663028695], 
    Polygon[{{Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, {1/4, \
Sqrt[3]/4, -Sqrt[3]/2}, 
      {Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.15470075458961777, 0.3153394608630542, 0.6613990663028695], 
    Polygon[{{1/4, Sqrt[3]/4, -Sqrt[3]/2}, {Cos[(11*Pi)/30]/2, \
Sin[(11*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(11*Pi)/30]*Sin[(13*Pi)/15], 
       Sin[(11*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {Sin[(13*Pi)/15]/2, \
(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.12089133841770336, 0.32978263044553324, 0.6613990663028695], 
    Polygon[{{Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, -Sqrt[3]/2}, {(-1 + \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(11*Pi)/30]*Sin[(13*Pi)/15], Sin[(11*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.08575741144394558, 0.34061263251739893, 0.6613990663028695], 
    Polygon[{{(-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(13*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.04968390832451595, 0.3477108113096282, 0.6613990663028695], 
    Polygon[{{Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, -Sqrt[3]/2}, 
      {Cos[(7*Pi)/15]*Sin[(13*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.013066057908456682, 0.35099939768998417, 0.6613990663028695], 
    Polygon[{{Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, -Sqrt[3]/2}, {0, 1/2, \
-Sqrt[3]/2}, {0, Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
      {Cos[(7*Pi)/15]*Sin[(13*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.023694946972296016, 0.35044236121790256, 0.6613990663028695], 
    Polygon[{{0, 1/2, -Sqrt[3]/2}, {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, \
-Sqrt[3]/2}, {Cos[(8*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {0, Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.060196345055533805, 0.3460458049015389, 0.6613990663028695], 
    Polygon[{{Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(17*Pi)/30]*Sin[(13*Pi)/15], Sin[(17*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.09603821938544821, 0.3378578983319338, 0.6613990663028695], 
    Polygon[{{Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, -Sqrt[3]/2}, {(1 - \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(17*Pi)/30]*Sin[(13*Pi)/15], Sin[(17*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.13082787888648612, 0.32596834992689355, 0.6613990663028695], 
    Polygon[{{(1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(19*Pi)/30]*Sin[(13*Pi)/15], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.16418416076895, 0.31050742406679166, 0.6613990663028695], 
    Polygon[{{Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, -Sqrt[3]/2}, {-1/4, \
Sqrt[3]/4, -Sqrt[3]/2}, {-Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 
       Cos[(13*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(19*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.19574160662828483, 0.29164451389075813, 0.6613990663028695], 
    Polygon[{{-1/4, Sqrt[3]/4, -Sqrt[3]/2}, {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/8, -Sqrt[3]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {-Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.22515446648383552, 0.2695862853899994, 0.6613990663028695], \
Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, 
      {Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(11*Pi)/15]*Sin[(13*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.2521004868879882, 0.24457441313195066, 0.6613990663028695], 
    Polygon[{{Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(23*Pi)/30]*Sin[(13*Pi)/15], Sin[(23*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.27628444160237764, 0.21688293242314208, 0.6613990663028695], 
    Polygon[{{Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, -Sqrt[3]/2}, {(-1 - \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(23*Pi)/30]*Sin[(13*Pi)/15], Sin[(23*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.29744136615833494, 0.18681523692103413, 0.6613990663028695], 
    Polygon[{{(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{-Sqrt[3]/4, 1/4, -Sqrt[3]/2}, 
      {-(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.3153394608630542, 0.15470075458961768, 0.6613990663028695], 
    Polygon[{{-Sqrt[3]/4, 1/4, -Sqrt[3]/2}, {Cos[(13*Pi)/15]/2, \
Sin[(13*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(13*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]^2, Cos[(13*Pi)/15]}, {-(Sqrt[3]*Sin[(13*Pi)/15])/2, \
Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.32978263044553324, 0.12089133841770332, 0.6613990663028695], 
    Polygon[{{Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(13*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]^2, \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.34061263251739893, 0.08575741144394561, 0.6613990663028695], 
    Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, -Sqrt[3]/2}, 
      {Cos[(14*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(13*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.3477108113096282, 0.04968390832451602, 0.6613990663028695], 
    Polygon[{{Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(29*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(14*Pi)/15], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.35099939768998417, 0.013066057908456717, 0.6613990663028695], 
    Polygon[{{Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, -Sqrt[3]/2}, {-1/2, 0, \
-Sqrt[3]/2}, {-Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, 
      {Cos[(29*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.3504423612179025, 0.02369494697229605, 0.6613990663028695], 
    Polygon[{{-1/2, 0, -Sqrt[3]/2}, {Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, \
-Sqrt[3]/2}, {Cos[(31*Pi)/30]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(31*Pi)/30], Cos[(13*Pi)/15]}, {-Sin[(13*Pi)/15], \
0, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.3460458049015389, 0.06019634505553381, 0.6613990663028695], 
    Polygon[{{Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, -Sqrt[3]/2}, 
      {Cos[(16*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(31*Pi)/30]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(31*Pi)/30], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.3378578983319338, 0.0960382193854482, 0.6613990663028695], 
    Polygon[{{Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(16*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.3259683499268936, 0.13082787888648606, 0.6613990663028695], \
Polygon[{{-Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, 
      {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(17*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(13*Pi)/15]}, 
      {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.31050742406679166, 0.16418416076894998, 0.6613990663028695], 
    Polygon[{{Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[3]/4, \
-1/4, -Sqrt[3]/2}, 
      {-(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{Cos[(17*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(17*Pi)/15], 
       Cos[(13*Pi)/15]}}]}, {RGBColor[0.29164451389075813, \
0.19574160662828483, 0.6613990663028695], 
    Polygon[{{-Sqrt[3]/4, -1/4, -Sqrt[3]/2}, {(-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}}]}, \

   {RGBColor[0.26958628538999935, 0.22515446648383558, 0.6613990663028695], 
    Polygon[{{(-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(37*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.24457441313195077, 0.25210048688798814, 0.6613990663028695], 
    Polygon[{{Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, -Sqrt[3]/2}, 
      {Cos[(19*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(37*Pi)/30], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.21688293242314213, 0.2762844416023776, 0.6613990663028695], 
    Polygon[{{Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[(5 - \
Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(19*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.18681523692103413, 0.29744136615833494, 0.6613990663028695], 
    Polygon[{{-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, {-1/4, \
-Sqrt[3]/4, -Sqrt[3]/2}, 
      {-Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.1547007545896177, 0.3153394608630542, 0.6613990663028695], 
    Polygon[{{-1/4, -Sqrt[3]/4, -Sqrt[3]/2}, {Cos[(41*Pi)/30]/2, \
Sin[(41*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(41*Pi)/30]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(41*Pi)/30], Cos[(13*Pi)/15]}, \
{-Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.12089133841770333, 0.32978263044553324, 0.6613990663028695], 
    Polygon[{{Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, -Sqrt[3]/2}, {(1 - \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(41*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.08575741144394572, 0.34061263251739893, 0.6613990663028695], 
    Polygon[{{(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(43*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(13*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.04968390832451619, 0.3477108113096282, 0.6613990663028695], 
    Polygon[{{Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, -Sqrt[3]/2}, 
      {Cos[(22*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(43*Pi)/30], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.01306605790845678, 0.35099939768998417, 0.6613990663028695], 
    Polygon[{{Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, -Sqrt[3]/2}, {0, -1/2, \
-Sqrt[3]/2}, {0, -Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
      {Cos[(22*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.023694946972296134, 0.3504423612179025, 0.6613990663028695], 
    Polygon[{{0, -1/2, -Sqrt[3]/2}, {Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, \
-Sqrt[3]/2}, {Cos[(23*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(23*Pi)/15], Cos[(13*Pi)/15]}, {0, \
-Sin[(13*Pi)/15], Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.06019634505553394, 0.34604580490153886, 0.6613990663028695], 
    Polygon[{{Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(47*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(23*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(23*Pi)/15], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.09603821938544824, 0.3378578983319338, 0.6613990663028695], 
    Polygon[{{Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, -Sqrt[3]/2}, {(-1 + \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(47*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.13082787888648606, 0.3259683499268936, 0.6613990663028695], \
Polygon[{{(-1 + Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(49*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(13*Pi)/15]}, 
      {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.16418416076894998, 0.31050742406679166, 0.6613990663028695], 
    Polygon[{{Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, -Sqrt[3]/2}, {1/4, \
-Sqrt[3]/4, -Sqrt[3]/2}, {Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, 
       Cos[(13*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(49*Pi)/30], Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.19574160662828483, 0.29164451389075813, 0.6613990663028695], 
    Polygon[{{1/4, -Sqrt[3]/4, -Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - \
Sqrt[5])/8, -Sqrt[3]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.22515446648383564, 0.2695862853899993, 0.6613990663028695], \
Polygon[{{Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, 
      {Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(26*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/15]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.25210048688798814, 0.24457441313195077, 0.6613990663028695], 
    Polygon[{{Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(53*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(26*Pi)/15], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.27628444160237753, 0.21688293242314216, 0.6613990663028695], 
    Polygon[{{Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, -Sqrt[3]/2}, {(1 + \
Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, 
      {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(53*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.29744136615833494, 0.18681523692103413, 0.6613990663028695], 
    Polygon[{{(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Sqrt[3]/4, -1/4, -Sqrt[3]/2}, 
      {(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.3153394608630542, 0.1547007545896177, 0.6613990663028695], 
    Polygon[{{Sqrt[3]/4, -1/4, -Sqrt[3]/2}, {Cos[(28*Pi)/15]/2, \
Sin[(28*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(28*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(28*Pi)/15], Cos[(13*Pi)/15]}, \
{(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.32978263044553324, 0.12089133841770333, 0.6613990663028695], 
    Polygon[{{Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, -Sqrt[3]/2}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, 
      {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(28*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.34061263251739893, 0.08575741144394573, 0.6613990663028695], 
    Polygon[{{Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, -Sqrt[3]/2}, 
      {Cos[(29*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(13*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.3477108113096282, 0.04968390832451622, 0.6613990663028695], 
    Polygon[{{Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, -Sqrt[3]/2}, 
      {Cos[(59*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(29*Pi)/15], Cos[(13*Pi)/15]}}]}, \
{RGBColor[0.35099939768998417, 0.013066057908456788, 0.6613990663028695], 
    Polygon[{{Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, -Sqrt[3]/2}, {1/2, 0, \
-Sqrt[3]/2}, {Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, 
      {Cos[(59*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/15]}}]}, 
   {RGBColor[0.27964232680251333, 0.018704156950239952, 0.6945368578950889], 
    Polygon[{{Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, \
{Cos[Pi/30]*Sin[(13*Pi)/15], Sin[Pi/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
      {((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 \
+ Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.2761553000941041, 0.04783227630667596, 0.6945368578950889], 
    Polygon[{{Cos[Pi/30]*Sin[(13*Pi)/15], Sin[Pi/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[Pi/15]*Sin[(13*Pi)/15], Sin[Pi/15]*Sin[(13*Pi)/15], 
       Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + \
Sqrt[5])*Sin[Pi/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 \
+ Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.26964265812865207, 0.07643633523434873, 0.6945368578950889], 
    Polygon[{{Cos[Pi/15]*Sin[(13*Pi)/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + \
Sqrt[5])*Sin[Pi/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.26017575477438876, 0.10420294167786245, 0.6945368578950889], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(13*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.24785831140554032, \
0.13082787888648614, 0.6945368578950889], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(13*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, 
       Cos[(13*Pi)/15]}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2328252805092466, 0.15601943847653577, 0.6945368578950889], 
    Polygon[{{(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, \
Cos[(13*Pi)/15]}, {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.21524136711787134, 0.17950161644946994, 0.6945368578950889], 
    Polygon[{{((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(7*Pi)/30]*Sin[(13*Pi)/15], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.1952992242662009, \
0.20101713714945563, 0.6945368578950889], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(13*Pi)/15], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17321734224447988, 0.22033027202929156, 0.6945368578950889], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(13*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.1492376547730691, 0.23722942234170097, 0.6945368578950889], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(-1 \
+ Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.12362288832597762, 0.2515294374594865, 0.6945368578950889], 
    Polygon[{{Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, \
Cos[(13*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(13*Pi)/15], 
       Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.09665368364463417, 0.2630736434245473, 0.6945368578950889], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.06862552097919647, 0.2717355595005496, 0.6945368578950889], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(13*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.03984548274509721, \
0.27742028392234236, 0.6945368578950889], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
      {Cos[(7*Pi)/15]*Sin[(13*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.01062888906383936, \
0.2800655336595552, 0.6945368578950889], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(13*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {0, Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
      {0, (-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.018704156950239928, \
0.27964232680251333, 0.6945368578950889], 
    Polygon[{{0, Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(13*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, 
      {((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {0, (-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.047832276306675914, 0.2761553000941041, 0.6945368578950889], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(13*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(13*Pi)/15], 
       Sin[(17*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.0764363352343487, 0.26964265812865207, 0.6945368578950889], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(17*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {-(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.10420294167786245, 0.26017575477438876, 0.6945368578950889], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(13*Pi)/15], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {-(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.13082787888648612, \
0.24785831140554032, 0.6945368578950889], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(19*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
      {-Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(1 \
- Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.15601943847653577, 0.2328252805092466, 0.6945368578950889], 
    Polygon[{{-Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, \
Cos[(13*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17950161644946988, 0.2152413671178714, 0.6945368578950889], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(11*Pi)/15]*Sin[(13*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.2010171371494556, 0.1952992242662009, 0.6945368578950889], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
      {Cos[(23*Pi)/30]*Sin[(13*Pi)/15], Sin[(23*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.22033027202929156, \
0.17321734224447988, 0.6945368578950889], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(23*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.23722942234170097, 0.1492376547730691, 0.6945368578950889], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, \
(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2515294374594865, 0.12362288832597758, 0.6945368578950889], 
    Polygon[{{-(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, \
Cos[(13*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]^2, 
       Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2630736434245473, 0.09665368364463414, 0.6945368578950889], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]^2, \
Cos[(13*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2717355595005496, 0.06862552097919648, 0.6945368578950889], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(14*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 \
+ Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.27742028392234236, \
0.03984548274509726, 0.6945368578950889], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(14*Pi)/15], Cos[(13*Pi)/15]}, 
      {Cos[(29*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.2800655336595552, \
0.010628889063839388, 0.6945368578950889], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(29*Pi)/30], Cos[(13*Pi)/15]}, {-Sin[(13*Pi)/15], 0, \
Cos[(13*Pi)/15]}, 
      {(1 - Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.27964232680251333, \
0.01870415695023996, 0.6945368578950889], 
    Polygon[{{-Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(13*Pi)/15]}, 
      {((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(1 - Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.2761553000941041, 0.04783227630667592, 0.6945368578950889], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(31*Pi)/30], Cos[(13*Pi)/15]}, 
      {Cos[(16*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(16*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(31*Pi)/30])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.26964265812865207, \
0.0764363352343487, 0.6945368578950889], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(16*Pi)/15], Cos[(13*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2601757547743888, 0.1042029416778624, 0.6945368578950889], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(17*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 \
+ Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.24785831140554032, \
0.13082787888648612, 0.6945368578950889], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(17*Pi)/15], Cos[(13*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2328252805092466, 0.15601943847653577, 0.6945368578950889], 
    Polygon[{{-(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, \
Cos[(13*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, 
       -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.21524136711787134, \
0.17950161644946994, 0.6945368578950889], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(37*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 \
+ Sqrt[5])*(1 + Sqrt[5]))/16, 
       -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.19529922426620094, 0.20101713714945557, 0.6945368578950889], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(37*Pi)/30], Cos[(13*Pi)/15]}, 
      {Cos[(19*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(19*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.17321734224447993, \
0.22033027202929154, 0.6945368578950889], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(19*Pi)/15], Cos[(13*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.1492376547730691, 0.23722942234170097, 0.6945368578950889], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {-Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, \
{(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, \
-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.12362288832597758, 0.2515294374594865, 0.6945368578950889], 
    Polygon[{{-Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, \
Cos[(13*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(41*Pi)/30], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(41*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(41*Pi)/30])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.09665368364463414, 0.2630736434245473, 0.6945368578950889], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(41*Pi)/30], Cos[(13*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {-(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.06862552097919657, 0.2717355595005496, 0.6945368578950889], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(43*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {-(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.0398454827450974, \
0.2774202839223423, 0.6945368578950889], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(43*Pi)/30], Cos[(13*Pi)/15]}, 
      {Cos[(22*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.01062888906383944, \
0.2800655336595552, 0.6945368578950889], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(22*Pi)/15], Cos[(13*Pi)/15]}, {0, -Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, 
      {0, (1 - Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.018704156950240025, \
0.27964232680251333, 0.6945368578950889], 
    Polygon[{{0, -Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(13*Pi)/15]}, 
      {((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {0, (1 - Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.047832276306676025, 0.27615530009410405, 0.6945368578950889], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(23*Pi)/15], Cos[(13*Pi)/15]}, 
      {Cos[(47*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(47*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.07643633523434873, \
0.26964265812865207, 0.6945368578950889], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(47*Pi)/30], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.1042029416778624, 0.2601757547743888, 0.6945368578950889], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.1308278788864861, \
0.24785831140554032, 0.6945368578950889], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(49*Pi)/30], Cos[(13*Pi)/15]}, 
      {Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, \
{(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.15601943847653577, 0.2328252805092466, 0.6945368578950889], 
    Polygon[{{Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, \
Cos[(13*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.17950161644947, 0.2152413671178713, 0.6945368578950889], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(26*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.20101713714945552, 0.195299224266201, 0.6945368578950889], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(26*Pi)/15], Cos[(13*Pi)/15]}, 
      {Cos[(53*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.2203302720292915, \
0.17321734224447993, 0.6945368578950889], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(53*Pi)/30], Cos[(13*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, 
       -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, \
{RGBColor[0.23722942234170097, 0.1492376547730691, 0.6945368578950889], 
    Polygon[{{((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
      {(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2515294374594865, 0.12362288832597759, 0.6945368578950889], 
    Polygon[{{(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, \
Cos[(13*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(13*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(28*Pi)/15], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2630736434245473, 0.09665368364463416, 0.6945368578950889], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(28*Pi)/15], Cos[(13*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}]}, 
   {RGBColor[0.2717355595005496, 0.06862552097919658, 0.6945368578950889], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
      {Cos[(29*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.2774202839223423, \
0.03984548274509743, 0.6945368578950889], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(29*Pi)/15], Cos[(13*Pi)/15]}, 
      {Cos[(59*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.2800655336595552, \
0.010628889063839447, 0.6945368578950889], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(59*Pi)/30], Cos[(13*Pi)/15]}, {Sin[(13*Pi)/15], 0, \
Cos[(13*Pi)/15]}, 
      {(-1 + Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}}]}, {RGBColor[0.2057784725357569, \
0.013508440270540562, 0.7200651583310282], 
    Polygon[{{(-1 + Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[Pi/30]*Sin[(14*Pi)/15], \
Sin[Pi/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, 
      {Sin[(14*Pi)/15], 0, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.20323918002962665, 0.03494414712905482, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, -Sqrt[(5 \
+ Sqrt[5])/2]/2}, 
      {Cos[Pi/15]*Sin[(14*Pi)/15], Sin[Pi/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[Pi/30]*Sin[(14*Pi)/15], Sin[Pi/30]*Sin[(14*Pi)/15], 
       Cos[(14*Pi)/15]}}]}, {RGBColor[0.19847315653655914, \
0.05599699859909025, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{Cos[Pi/15]*Sin[(14*Pi)/15], Sin[Pi/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}]}, \

   {RGBColor[0.19153261960729895, 0.07643633523434873, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(2*Pi)/15]*Sin[(14*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.18249361121684382, 0.09603821938544822, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(14*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.17145516463265364, 0.11458788870767132, 0.7200651583310282], 
    Polygon[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.15853821938544826, 0.13188210914215587, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(7*Pi)/30]*Sin[(14*Pi)/15], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.1438842962304006, 0.14773140159077336, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(4*Pi)/15]*Sin[(14*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(14*Pi)/15], 
       Sin[(7*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.12765394661612803, 0.16196211788877907, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
      {Cos[(4*Pi)/15]*Sin[(14*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.1100249936494234, 0.17441834333044323, 0.7200651583310282], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.09119058382808562, 0.1849636049031942, 0.7200651583310282], 
    Polygon[{{(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(11*Pi)/30]*Sin[(14*Pi)/15], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], 
       Cos[(14*Pi)/15]}, {Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.07135707088747081, 0.19348236651450304, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(14*Pi)/15], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], 
       Cos[(14*Pi)/15]}}]}, {RGBColor[0.05074175494578578, \
0.19988129482949085, 0.7200651583310282], 
    Polygon[{{(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(13*Pi)/30]*Sin[(14*Pi)/15], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.029570501718519892, 0.20409028185047673, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(7*Pi)/15]*Sin[(14*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(14*Pi)/15], 
       Sin[(13*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.008075267886400592, 0.20606321303487163, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {0, (-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {0, Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(14*Pi)/15], 
       Sin[(7*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.013508440270540545, 0.20577847253575693, 0.7200651583310282], 
    Polygon[{{0, (-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(8*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(8*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, 
      {0, Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.034944147129054776, 0.20323918002962665, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(17*Pi)/30]*Sin[(14*Pi)/15], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(14*Pi)/15], 
       Sin[(8*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.05599699859909023, 0.19847315653655914, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{Cos[(17*Pi)/30]*Sin[(14*Pi)/15], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], 
       Cos[(14*Pi)/15]}}]}, {RGBColor[0.07643633523434873, \
0.19153261960729895, 0.7200651583310282], 
    Polygon[{{-(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(19*Pi)/30]*Sin[(14*Pi)/15], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.09603821938544822, 0.18249361121684382, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(14*Pi)/15], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.11458788870767132, 0.17145516463265364, 0.7200651583310282], 
    Polygon[{{(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{-Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.1318821091421558, 0.15853821938544826, 0.7200651583310282], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(11*Pi)/15]*Sin[(14*Pi)/15], Sin[(11*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.14773140159077336, 0.1438842962304006, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(23*Pi)/30]*Sin[(14*Pi)/15], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(14*Pi)/15], 
       Sin[(11*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.16196211788877907, 0.127653946616128, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {Cos[(23*Pi)/30]*Sin[(14*Pi)/15], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.17441834333044323, 0.1100249936494234, 0.7200651583310282], 
    Polygon[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 \
+ Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, 
       Cos[(14*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.1849636049031942, 0.09119058382808558, 0.7200651583310282], 
    Polygon[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(13*Pi)/15]*Sin[(14*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], 
       Cos[(14*Pi)/15]}, {-(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.19348236651450304, 0.07135707088747079, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(14*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], 
       Cos[(14*Pi)/15]}}]}, {RGBColor[0.19988129482949085, \
0.0507417549457858, 0.7200651583310282], 
    Polygon[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(14*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]^2, Cos[(14*Pi)/15]}, \
{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.20409028185047673, 0.029570501718519934, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(29*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]^2, 
       Cos[(14*Pi)/15]}}]}, {RGBColor[0.20606321303487163, \
0.008075267886400613, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(1 - Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {-Sin[(14*Pi)/15], 0, \
Cos[(14*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(29*Pi)/30], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.2057784725357569, 0.013508440270540567, 0.7200651583310282], 
    Polygon[{{(1 - Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(31*Pi)/30])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(31*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(31*Pi)/30], Cos[(14*Pi)/15]}, 
      {-Sin[(14*Pi)/15], 0, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.20323918002962665, 0.03494414712905478, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(16*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(31*Pi)/30]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(31*Pi)/30], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.19847315653655914, 0.05599699859909023, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{Cos[(16*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(16*Pi)/15], 
       Cos[(14*Pi)/15]}}]}, {RGBColor[0.191532619607299, 0.07643633523434869, \
0.7200651583310282], 
    Polygon[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])^2/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(17*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(14*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.18249361121684382, 0.09603821938544821, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, 
       Cos[(14*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(17*Pi)/15], Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.17145516463265364, 0.11458788870767132, 0.7200651583310282], 
    Polygon[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
       -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{-(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.15853821938544826, 0.13188210914215587, 0.7200651583310282], 
    Polygon[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 \
+ Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(37*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(14*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.14388429623040067, 0.1477314015907733, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(19*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(37*Pi)/30], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.12765394661612803, 0.16196211788877907, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
      {Cos[(19*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.1100249936494234, 0.17441834333044323, 0.7200651583310282], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 \
+ Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, 
       Cos[(14*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.09119058382808558, 0.1849636049031942, 0.7200651583310282], 
    Polygon[{{(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
       ((-1 + Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(41*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(41*Pi)/30], 
       Cos[(14*Pi)/15]}, {-Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.07135707088747079, 0.19348236651450307, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {Cos[(41*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.05074175494578586, 0.19988129482949085, 0.7200651583310282], 
    Polygon[{{-(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(43*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(14*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.029570501718520034, 0.20409028185047673, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(22*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(22*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(43*Pi)/30], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.008075267886400653, 0.20606321303487163, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(22*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {0, (1 - Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {0, -Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(22*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.013508440270540616, 0.2057784725357569, 0.7200651583310282], 
    Polygon[{{0, (1 - Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/15])/4, 
       -Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(23*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(23*Pi)/15], Cos[(14*Pi)/15]}, 
      {0, -Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.03494414712905486, 0.20323918002962665, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(47*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(23*Pi)/15]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(23*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.055996998599090256, 0.19847315653655914, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{Cos[(47*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(47*Pi)/30], 
       Cos[(14*Pi)/15]}}]}, {RGBColor[0.07643633523434867, 0.191532619607299, \
0.7200651583310282], 
    Polygon[{{(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(49*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.0960382193854482, 0.18249361121684382, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, 
       Cos[(14*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(49*Pi)/30], Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.11458788870767132, 0.17145516463265364, 0.7200651583310282], 
    Polygon[{{(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
       -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.1318821091421559, 0.1585382193854482, 0.7200651583310282], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(26*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.1477314015907733, 0.14388429623040067, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(53*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(26*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.161962117888779, 0.12765394661612806, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {Cos[(53*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.17441834333044323, 0.1100249936494234, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 \
+ Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}, 
      {((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.1849636049031942, 0.09119058382808559, 0.7200651583310282], 
    Polygon[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, 
       ((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(28*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(28*Pi)/15], 
       Cos[(14*Pi)/15]}, {(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}}]}, 
   {RGBColor[0.19348236651450304, 0.0713570708874708, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(28*Pi)/15], 
       Cos[(14*Pi)/15]}}]}, {RGBColor[0.19988129482949085, \
0.050741754945785866, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(29*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.20409028185047673, 0.029570501718520048, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(59*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {Cos[(59*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(29*Pi)/15], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.20606321303487163, 0.008075267886400658, 0.7200651583310282], 
    Polygon[{{((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(59*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
      {(-1 + Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {Sin[(14*Pi)/15], 0, \
Cos[(14*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(59*Pi)/30], Cos[(14*Pi)/15]}}]}, \
{RGBColor[0.1296600662619849, 0.008164722292414271, 0.7377042742089712], 
    Polygon[{{Sin[(14*Pi)/15], 0, Cos[(14*Pi)/15]}, \
{Cos[Pi/30]*Sin[(14*Pi)/15], Sin[Pi/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, 
      {Cos[Pi/30]*Sin[(29*Pi)/30], Sin[Pi/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.12809632897821194, 0.02167316256295484, 0.7377042742089712], 
    Polygon[{{Cos[Pi/30]*Sin[(14*Pi)/15], Sin[Pi/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[Pi/15]*Sin[(14*Pi)/15], Sin[Pi/15]*Sin[(14*Pi)/15], 
       Cos[(14*Pi)/15]}, {Cos[Pi/15]*Sin[(29*Pi)/30], \
Sin[Pi/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
      {Cos[Pi/30]*Sin[(29*Pi)/30], Sin[Pi/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.1251291415082735, 0.03494414712905483, 0.7377042742089712], 
    Polygon[{{Cos[Pi/15]*Sin[(14*Pi)/15], Sin[Pi/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}, {Cos[Pi/15]*Sin[(29*Pi)/30], \
Sin[Pi/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.12079101297901415, 0.047832276306676, 0.7377042742089712], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
      {Cos[(2*Pi)/15]*Sin[(14*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(2*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.11512947283441224, \
0.06019634505553391, 0.7377042742089712], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(14*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, 
       Cos[(14*Pi)/15]}, {(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, \
Cos[(29*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(2*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}]}, \
{RGBColor[0.10820655009304542, 0.07190089005106834, 0.7377042742089712], 
    Polygon[{{(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}, {((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       Cos[(29*Pi)/30]}, {(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.10009809374518286, 0.08281767384897472, 0.7377042742089712], 
    Polygon[{{((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {Cos[(7*Pi)/30]*Sin[(14*Pi)/15], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(7*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.09089294173537531, \
0.0928270898814793, 0.7377042742089712], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(14*Pi)/15], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(14*Pi)/15], 
       Sin[(4*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(4*Pi)/15]*Sin[(29*Pi)/30], Sin[(4*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
      {Cos[(7*Pi)/30]*Sin[(29*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.08069194763534411, 0.101819472891925, 0.7377042742089712], 
    Polygon[{{Cos[(4*Pi)/15]*Sin[(14*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(4*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.06960687567114446, 0.10969630045027226, 0.7377042742089712], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
      {Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.05775917621091659, 0.11637127238545969, 0.7377042742089712], 
    Polygon[{{Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(14*Pi)/15], 
       Cos[(14*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
      {Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.04527865512923723, 0.1217712563081377, 0.7377042742089712], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(29*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/30], 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.0323020516267942, \
0.12583708886443012, 0.7377042742089712], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {Cos[(13*Pi)/30]*Sin[(14*Pi)/15], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(13*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.018971540087089154, \
0.12852422394202012, 0.7377042742089712], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(13*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, 
      {Cos[(7*Pi)/15]*Sin[(14*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(7*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(13*Pi)/30]*Sin[(29*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.005433172384139969, 0.12980322072667835, 0.7377042742089712], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(14*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {0, Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, 
      {0, Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(7*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.008164722292414262, 0.12966006626198492, 0.7377042742089712], 
    Polygon[{{0, Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(14*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, 
      {Cos[(8*Pi)/15]*Sin[(29*Pi)/30], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.021673162562954817, 0.12809632897821194, 0.7377042742089712], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(14*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(14*Pi)/15], 
       Sin[(17*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(17*Pi)/30]*Sin[(29*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
      {Cos[(8*Pi)/15]*Sin[(29*Pi)/30], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.03494414712905483, 0.1251291415082735, 0.7377042742089712], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(17*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(29*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/30], 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.04783227630667599, \
0.12079101297901416, 0.7377042742089712], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {Cos[(19*Pi)/30]*Sin[(14*Pi)/15], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(19*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.060196345055533895, \
0.11512947283441224, 0.7377042742089712], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(19*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, 
      {-Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{-Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {Cos[(19*Pi)/30]*Sin[(29*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.07190089005106834, 0.10820655009304542, 0.7377042742089712], 
    Polygon[{{-Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}, {-Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.08281767384897468, 0.10009809374518289, 0.7377042742089712], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
      {Cos[(11*Pi)/15]*Sin[(14*Pi)/15], Sin[(11*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(11*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.0928270898814793, \
0.09089294173537531, 0.7377042742089712], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, 
      {Cos[(23*Pi)/30]*Sin[(14*Pi)/15], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(23*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(11*Pi)/15]*Sin[(29*Pi)/30], Sin[(11*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.10181947289192501, 0.0806919476353441, 0.7377042742089712], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(23*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(23*Pi)/30]*Sin[(29*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/30], 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.10969630045027226, \
0.06960687567114446, 0.7377042742089712], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, \
{-(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, 
      {-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.1163712723854597, 0.057759176210916564, 0.7377042742089712], 
    Polygon[{{-(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(14*Pi)/15], 
       Sin[(13*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(29*Pi)/30], Sin[(13*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.1217712563081377, 0.04527865512923722, 0.7377042742089712], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(13*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.12583708886443012, 0.032302051626794205, 0.7377042742089712], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
      {Cos[(14*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]^2, Cos[(14*Pi)/15]}, \
{Cos[(14*Pi)/15]*Sin[(29*Pi)/30], Sin[(14*Pi)/15]*Sin[(29*Pi)/30], 
       Cos[(29*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.12852422394202012, 0.018971540087089178, 0.7377042742089712], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]^2, \
Cos[(14*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(29*Pi)/30], Cos[(14*Pi)/15]}, \
{Cos[(29*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]^2, Cos[(29*Pi)/30]}, 
      {Cos[(14*Pi)/15]*Sin[(29*Pi)/30], Sin[(14*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.12980322072667835, 0.005433172384139984, 0.7377042742089712], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(29*Pi)/30], Cos[(14*Pi)/15]}, {-Sin[(14*Pi)/15], 0, \
Cos[(14*Pi)/15]}, 
      {-Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, \
{Cos[(29*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]^2, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.1296600662619849, 0.008164722292414274, 0.7377042742089712], 
    Polygon[{{-Sin[(14*Pi)/15], 0, Cos[(14*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(14*Pi)/15]}, 
      {Cos[(31*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(29*Pi)/30]}, {-Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.12809632897821194, 0.02167316256295482, 0.7377042742089712], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(31*Pi)/30], Cos[(14*Pi)/15]}, 
      {Cos[(16*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(16*Pi)/15], Cos[(29*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.1251291415082735, 0.034944147129054824, 0.7377042742089712], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(16*Pi)/15], Cos[(14*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(16*Pi)/15], Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.12079101297901418, 0.04783227630667597, 0.7377042742089712], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
      {Cos[(17*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(17*Pi)/15], Cos[(29*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.11512947283441224, \
0.06019634505553388, 0.7377042742089712], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(17*Pi)/15], Cos[(14*Pi)/15]}, 
      {-(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, \
{-(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, 
      {Cos[(17*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.10820655009304542, 0.07190089005106834, 0.7377042742089712], 
    Polygon[{{-(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{-(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.10009809374518286, 0.08281767384897472, 0.7377042742089712], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {Cos[(37*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(37*Pi)/30], Cos[(29*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.09089294173537532, \
0.09282708988147928, 0.7377042742089712], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(37*Pi)/30], Cos[(14*Pi)/15]}, 
      {Cos[(19*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(19*Pi)/15], Cos[(29*Pi)/30]}, \
{Cos[(37*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.08069194763534411, 0.101819472891925, 0.7377042742089712], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(19*Pi)/15], Cos[(14*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(19*Pi)/15], Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.06960687567114446, 0.10969630045027226, 0.7377042742089712], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
      {-Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{-Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.05775917621091657, 0.1163712723854597, 0.7377042742089712], 
    Polygon[{{-Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(41*Pi)/30], Cos[(14*Pi)/15]}, \
{Cos[(41*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(29*Pi)/30]}, 
      {-Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}]}, \

   {RGBColor[0.04527865512923722, 0.1217712563081377, 0.7377042742089712], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(41*Pi)/30], Cos[(14*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(41*Pi)/30], 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.03230205162679425, \
0.12583708886443012, 0.7377042742089712], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {Cos[(43*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(43*Pi)/30], Cos[(29*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.01897154008708924, \
0.1285242239420201, 0.7377042742089712], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(43*Pi)/30], Cos[(14*Pi)/15]}, 
      {Cos[(22*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(22*Pi)/15], Cos[(29*Pi)/30]}, \
{Cos[(43*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.00543317238414001, 0.12980322072667835, 0.7377042742089712], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(22*Pi)/15], Cos[(14*Pi)/15]}, {0, -Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, 
      {0, -Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(22*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.008164722292414304, 0.1296600662619849, 0.7377042742089712], 
    Polygon[{{0, -Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(14*Pi)/15]}, 
      {Cos[(23*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(29*Pi)/30]}, {0, -Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.02167316256295487, 0.1280963289782119, 0.7377042742089712], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(23*Pi)/15], Cos[(14*Pi)/15]}, 
      {Cos[(47*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(47*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.034944147129054845, 0.1251291415082735, 0.7377042742089712], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(47*Pi)/30], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(47*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(47*Pi)/30], 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.04783227630667597, \
0.12079101297901418, 0.7377042742089712], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {Cos[(49*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(49*Pi)/30], Cos[(29*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.06019634505553388, \
0.11512947283441224, 0.7377042742089712], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(49*Pi)/30], Cos[(14*Pi)/15]}, 
      {Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {Cos[(49*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.07190089005106834, 0.10820655009304542, 0.7377042742089712], 
    Polygon[{{Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       -((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}, {Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.08281767384897473, 0.10009809374518285, 0.7377042742089712], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
      {Cos[(26*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(26*Pi)/15], Cos[(29*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.09282708988147925, \
0.09089294173537533, 0.7377042742089712], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(26*Pi)/15], Cos[(14*Pi)/15]}, 
      {Cos[(53*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(53*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(26*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.10181947289192497, 0.08069194763534414, 0.7377042742089712], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(53*Pi)/30], Cos[(14*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(53*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(53*Pi)/30], 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.10969630045027226, \
0.06960687567114446, 0.7377042742089712], 
    Polygon[{{((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
      {(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, \
{(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, 
      {((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.1163712723854597, 0.057759176210916585, 0.7377042742089712], 
    Polygon[{{(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(14*Pi)/15], 
       Sin[(14*Pi)/15]*Sin[(28*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(29*Pi)/30]}, 
      {(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.1217712563081377, 0.04527865512923722, 0.7377042742089712], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(28*Pi)/15], Cos[(14*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
       -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(28*Pi)/15], Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.12583708886443012, 0.03230205162679425, 0.7377042742089712], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
      {Cos[(29*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(29*Pi)/15], Cos[(29*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       Cos[(29*Pi)/30]}}]}, {RGBColor[0.1285242239420201, \
0.01897154008708925, 0.7377042742089712], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(29*Pi)/15], Cos[(14*Pi)/15]}, 
      {Cos[(59*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(59*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(29*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.12980322072667835, 0.005433172384140013, 0.7377042742089712], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(59*Pi)/30], Cos[(14*Pi)/15]}, {Sin[(14*Pi)/15], 0, \
Cos[(14*Pi)/15]}, 
      {Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, \
{Cos[(59*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(29*Pi)/30]}}]}, 
   {RGBColor[0.05212107716913342, 0.002731549908274302, 0.7472609476841366], 
    Polygon[{{Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, \
{Cos[Pi/30]*Sin[(29*Pi)/30], Sin[Pi/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{0, 0, -1}, 
      {0, 0, -1}}]}, {RGBColor[0.05155002774063179, 0.008164722292414286, \
0.7472609476841366], 
    Polygon[{{Cos[Pi/30]*Sin[(29*Pi)/30], Sin[Pi/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[Pi/15]*Sin[(29*Pi)/30], Sin[Pi/15]*Sin[(29*Pi)/30], 
       Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, \
{RGBColor[0.05041418542066698, 0.013508440270540597, 0.7472609476841366], 
    Polygon[{{Cos[Pi/15]*Sin[(29*Pi)/30], Sin[Pi/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}}]}, 
   {RGBColor[0.0487259947353868, 0.018704156950240004, 0.7472609476841366], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
      {Cos[(2*Pi)/15]*Sin[(29*Pi)/30], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.0465039518552158, 0.023694946972296106, 0.7472609476841366], 
    Polygon[{{Cos[(2*Pi)/15]*Sin[(29*Pi)/30], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, 
       Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, \
{RGBColor[0.0437724019469415, 0.028426130196837308, 0.7472609476841366], 
    Polygon[{{(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, \
Cos[(29*Pi)/30]}, {((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}}]}, 
   {RGBColor[0.040561272442972515, 0.032845870790391786, 0.7472609476841366], \

    Polygon[{{((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {Cos[(7*Pi)/30]*Sin[(29*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.03690574515012639, 0.03690574515012638, 0.7472609476841366], 
    Polygon[{{Cos[(7*Pi)/30]*Sin[(29*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(4*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}}]}, 
   {RGBColor[0.032845870790391786, 0.040561272442972515, 0.7472609476841366], \

    Polygon[{{Cos[(4*Pi)/15]*Sin[(29*Pi)/30], Sin[(4*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}}]}, 
   {RGBColor[0.028426130196837308, 0.0437724019469415, 0.7472609476841366], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
      {Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, \
0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.023694946972296113, 0.0465039518552158, 0.7472609476841366], 
    Polygon[{{Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, \
Cos[(29*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(29*Pi)/30], 
       Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, \
{RGBColor[0.01870415695024001, 0.0487259947353868, 0.7472609476841366], 
    Polygon[{{Cos[(11*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}}]}, 
   {RGBColor[0.013508440270540593, 0.05041418542066698, 0.7472609476841366], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {Cos[(13*Pi)/30]*Sin[(29*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.008164722292414283, 0.05155002774063179, 0.7472609476841366], 
    Polygon[{{Cos[(13*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
      {Cos[(7*Pi)/15]*Sin[(29*Pi)/30], Sin[(7*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.002731549908274302, 0.05212107716913342, 0.7472609476841366], 
    Polygon[{{Cos[(7*Pi)/15]*Sin[(29*Pi)/30], Sin[(7*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, 
      {0, 0, -1}}]}, {RGBColor[0.0027315499082742984, 0.05212107716913342, \
0.7472609476841366], 
    Polygon[{{0, Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(29*Pi)/30], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, 
      {0, 0, -1}}]}, {RGBColor[0.008164722292414276, 0.05155002774063179, \
0.7472609476841366], 
    Polygon[{{Cos[(8*Pi)/15]*Sin[(29*Pi)/30], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(17*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}}]}, 
   {RGBColor[0.013508440270540592, 0.05041418542066698, 0.7472609476841366], 
    Polygon[{{Cos[(17*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}}]}, 
   {RGBColor[0.01870415695024, 0.0487259947353868, 0.7472609476841366], 
    Polygon[{{-((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {Cos[(19*Pi)/30]*Sin[(29*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.023694946972296106, 0.0465039518552158, 0.7472609476841366], 
    Polygon[{{Cos[(19*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
      {-Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, \
0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.028426130196837308, 0.0437724019469415, 0.7472609476841366], 
    Polygon[{{-Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, \
Cos[(29*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}}]}, 
   {RGBColor[0.03284587079039178, 0.04056127244297253, 0.7472609476841366], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
      {Cos[(11*Pi)/15]*Sin[(29*Pi)/30], Sin[(11*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.03690574515012637, 0.03690574515012639, 0.7472609476841366], 
    Polygon[{{Cos[(11*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(11*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
      {Cos[(23*Pi)/30]*Sin[(29*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.04056127244297252, 0.03284587079039178, 0.7472609476841366], 
    Polygon[{{Cos[(23*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}}]}, 
   {RGBColor[0.0437724019469415, 0.028426130196837308, 0.7472609476841366], 
    Polygon[{{-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, {0, \
0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.0465039518552158, 0.023694946972296106, 0.7472609476841366], 
    Polygon[{{-(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, \
Cos[(29*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(13*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}}]}, 
   {RGBColor[0.0487259947353868, 0.01870415695024, 0.7472609476841366], 
    Polygon[{{Cos[(13*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(13*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}}]}, 
   {RGBColor[0.05041418542066698, 0.013508440270540597, 0.7472609476841366], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
      {Cos[(14*Pi)/15]*Sin[(29*Pi)/30], Sin[(14*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.05155002774063179, 0.008164722292414293, 0.7472609476841366], 
    Polygon[{{Cos[(14*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(14*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
      {Cos[(29*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]^2, Cos[(29*Pi)/30]}, \
{0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.05212107716913342, 0.002731549908274309, 0.7472609476841366], 
    Polygon[{{Cos[(29*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]^2, \
Cos[(29*Pi)/30]}, {-Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, {0, 0, -1}, 
      {0, 0, -1}}]}, {RGBColor[0.05212107716913342, 0.0027315499082743028, \
0.7472609476841366], 
    Polygon[{{-Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(29*Pi)/30]}, 
      {0, 0, -1}, {0, 0, -1}}]}, {RGBColor[0.05155002774063179, \
0.00816472229241428, 0.7472609476841366], 
    Polygon[{{Cos[(31*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(31*Pi)/30], Cos[(29*Pi)/30]}, 
      {Cos[(16*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.05041418542066698, 0.01350844027054059, 0.7472609476841366], 
    Polygon[{{Cos[(16*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(16*Pi)/15], Cos[(29*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}}]}, 
   {RGBColor[0.04872599473538681, 0.018704156950239997, 0.7472609476841366], 
    Polygon[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
      {Cos[(17*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.04650395185521581, 0.0236949469722961, 0.7472609476841366], 
    Polygon[{{Cos[(17*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(17*Pi)/15], Cos[(29*Pi)/30]}, 
      {-(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, \
{0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.0437724019469415, 0.028426130196837308, 0.7472609476841366], 
    Polygon[{{-(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, \
Cos[(29*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}}]}, 
   {RGBColor[0.040561272442972515, 0.032845870790391786, 0.7472609476841366], \

    Polygon[{{-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {Cos[(37*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.03690574515012639, 0.03690574515012637, 0.7472609476841366], 
    Polygon[{{Cos[(37*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(37*Pi)/30], Cos[(29*Pi)/30]}, 
      {Cos[(19*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.03284587079039179, 0.040561272442972515, 0.7472609476841366], 
    Polygon[{{Cos[(19*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(19*Pi)/15], Cos[(29*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}}]}, 
   {RGBColor[0.028426130196837308, 0.0437724019469415, 0.7472609476841366], 
    Polygon[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
      {-Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.023694946972296106, 0.0465039518552158, 0.7472609476841366], 
    Polygon[{{-Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, \
Cos[(29*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(41*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}}]}, 
   {RGBColor[0.018704156950240004, 0.0487259947353868, 0.7472609476841366], 
    Polygon[{{Cos[(41*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(41*Pi)/30], Cos[(29*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}}]}, 
   {RGBColor[0.013508440270540609, 0.050414185420666974, 0.7472609476841366], \

    Polygon[{{-((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {Cos[(43*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.008164722292414318, 0.05155002774063179, 0.7472609476841366], 
    Polygon[{{Cos[(43*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(43*Pi)/30], Cos[(29*Pi)/30]}, 
      {Cos[(22*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.002731549908274322, 0.05212107716913342, 0.7472609476841366], 
    Polygon[{{Cos[(22*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(22*Pi)/15], Cos[(29*Pi)/30]}, {0, -Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
      {0, 0, -1}, {0, 0, -1}}]}, {RGBColor[0.0027315499082743127, \
0.05212107716913342, 0.7472609476841366], 
    Polygon[{{0, -Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(29*Pi)/30]}, 
      {0, 0, -1}, {0, 0, -1}}]}, {RGBColor[0.008164722292414299, \
0.05155002774063179, 0.7472609476841366], 
    Polygon[{{Cos[(23*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(23*Pi)/15], Cos[(29*Pi)/30]}, 
      {Cos[(47*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.0135084402705406, 0.050414185420666974, 0.7472609476841366], 
    Polygon[{{Cos[(47*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(47*Pi)/30], Cos[(29*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}}]}, 
   {RGBColor[0.018704156950239994, 0.04872599473538681, 0.7472609476841366], 
    Polygon[{{((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {Cos[(49*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.0236949469722961, 0.04650395185521581, 0.7472609476841366], 
    Polygon[{{Cos[(49*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(49*Pi)/30], Cos[(29*Pi)/30]}, 
      {Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, \
0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.028426130196837308, 0.0437724019469415, 0.7472609476841366], 
    Polygon[{{Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, \
Cos[(29*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       -((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}}]}, 
   {RGBColor[0.03284587079039179, 0.040561272442972515, 0.7472609476841366], 
    Polygon[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
      {Cos[(26*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.03690574515012637, 0.03690574515012639, 0.7472609476841366], 
    Polygon[{{Cos[(26*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(26*Pi)/15], Cos[(29*Pi)/30]}, 
      {Cos[(53*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.0405612724429725, 0.0328458707903918, 0.7472609476841366], 
    Polygon[{{Cos[(53*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(53*Pi)/30], Cos[(29*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
       -(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}}]}, 
   {RGBColor[0.0437724019469415, 0.028426130196837308, 0.7472609476841366], 
    Polygon[{{((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
      {(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, {0, \
0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.0465039518552158, 0.023694946972296106, 0.7472609476841366], 
    Polygon[{{(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, \
Cos[(29*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(29*Pi)/30], 
       Sin[(29*Pi)/30]*Sin[(28*Pi)/15], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}}]}, 
   {RGBColor[0.0487259947353868, 0.018704156950240004, 0.7472609476841366], 
    Polygon[{{Cos[(28*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(28*Pi)/15], Cos[(29*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
       -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}}]}, 
   {RGBColor[0.050414185420666974, 0.01350844027054061, 0.7472609476841366], 
    Polygon[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
      {Cos[(29*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.05155002774063179, 0.008164722292414323, 0.7472609476841366], 
    Polygon[{{Cos[(29*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(29*Pi)/15], Cos[(29*Pi)/30]}, 
      {Cos[(59*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}}]}, 
   {RGBColor[0.05212107716913342, 0.002731549908274324, 0.7472609476841366], 
    Polygon[{{Cos[(59*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(59*Pi)/30], Cos[(29*Pi)/30]}, {Sin[(29*Pi)/30], 0, \
Cos[(29*Pi)/30]}, 
      {0, 0, -1}, {0, 0, -1}}]}}, {Line[{{0, 0, 1}, {0, 0, 1}, \
{Cos[Pi/30]*Sin[Pi/30], Sin[Pi/30]^2, Cos[Pi/30]}, {Sin[Pi/30], 0, \
Cos[Pi/30]}, 
     {0, 0, 1}}], Line[{{0, 0, 1}, {0, 0, 1}, {Cos[Pi/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[Pi/15], Cos[Pi/30]}, 
     {Cos[Pi/30]*Sin[Pi/30], Sin[Pi/30]^2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[Pi/15]*Sin[Pi/30], Sin[Pi/30]*Sin[Pi/15], Cos[Pi/30]}, {0, 0, 1}}], \

   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(2*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(2*Pi)/15], Cos[Pi/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, \
Cos[Pi/30]}, {Cos[(2*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(2*Pi)/15], 
      Cos[Pi/30]}, {0, 0, 1}}], Line[{{0, 0, 1}, {0, 0, 1}, {((1 + \
Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(7*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(7*Pi)/30], Cos[Pi/30]}, 
     {((1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(4*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(4*Pi)/15], Cos[Pi/30]}, 
     {Cos[(7*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/30], Cos[Pi/30]}, {0, \
0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[(4*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(4*Pi)/15], Cos[Pi/30]}, {0, \
0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
      ((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(11*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(11*Pi)/30], Cos[Pi/30]}, 
     {Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(11*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/30], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(13*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(13*Pi)/30], Cos[Pi/30]}, 
     {((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(7*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(7*Pi)/15], Cos[Pi/30]}, 
     {Cos[(13*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/30], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {0, Sin[Pi/30], Cos[Pi/30]}, \
{Cos[(7*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/15], Cos[Pi/30]}, {0, 0, \
1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(8*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(8*Pi)/15], Cos[Pi/30]}, {0, Sin[Pi/30], Cos[Pi/30]}, {0, 0, \
1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(17*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(17*Pi)/30], Cos[Pi/30]}, 
     {Cos[(8*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(8*Pi)/15], Cos[Pi/30]}, {0, \
0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(17*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/30], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(19*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(19*Pi)/30], Cos[Pi/30]}, 
     {-((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {Cos[(19*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/30], 
      Cos[Pi/30]}, {0, 0, 1}}], Line[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {-Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(11*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(11*Pi)/15], Cos[Pi/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(23*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(23*Pi)/30], Cos[Pi/30]}, 
     {Cos[(11*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/15], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-((1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(23*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/30], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, \
Cos[Pi/30]}, {-((1 + Sqrt[5])*Sin[Pi/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(13*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(13*Pi)/15], Cos[Pi/30]}, 
     {-(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[(13*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/15], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(14*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(14*Pi)/15], Cos[Pi/30]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(29*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(29*Pi)/30], Cos[Pi/30]}, 
     {Cos[(14*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(14*Pi)/15], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-Sin[Pi/30], 0, Cos[Pi/30]}, \
{Cos[(29*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/30], Cos[Pi/30]}, {0, 0, \
1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(31*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(31*Pi)/30], Cos[Pi/30]}, {-Sin[Pi/30], 0, Cos[Pi/30]}, {0, 0, \
1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(16*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(16*Pi)/15], Cos[Pi/30]}, 
     {Cos[(31*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(31*Pi)/30], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 \
+ Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[(16*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(16*Pi)/15], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(17*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(17*Pi)/15], Cos[Pi/30]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, \
Cos[Pi/30]}, {Cos[(17*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/15], 
      Cos[Pi/30]}, {0, 0, 1}}], Line[{{0, 0, 1}, {0, 0, 1}, {-((1 + \
Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {-(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(37*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(37*Pi)/30], Cos[Pi/30]}, 
     {-((1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(19*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(19*Pi)/15], Cos[Pi/30]}, 
     {Cos[(37*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(37*Pi)/30], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[(19*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/15], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
      -((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(41*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(41*Pi)/30], Cos[Pi/30]}, 
     {-Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {-((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(41*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(41*Pi)/30], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(43*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(43*Pi)/30], Cos[Pi/30]}, 
     {-((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(22*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(22*Pi)/15], Cos[Pi/30]}, 
     {Cos[(43*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(43*Pi)/30], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {0, -Sin[Pi/30], Cos[Pi/30]}, \
{Cos[(22*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(22*Pi)/15], Cos[Pi/30]}, {0, 0, \
1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(23*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(23*Pi)/15], Cos[Pi/30]}, {0, -Sin[Pi/30], Cos[Pi/30]}, {0, 0, \
1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(47*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(47*Pi)/30], Cos[Pi/30]}, 
     {Cos[(23*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/15], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(47*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(47*Pi)/30], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(49*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(49*Pi)/30], Cos[Pi/30]}, 
     {((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {Cos[(49*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(49*Pi)/30], 
      Cos[Pi/30]}, {0, 0, 1}}], Line[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(26*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(26*Pi)/15], Cos[Pi/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(53*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(53*Pi)/30], Cos[Pi/30]}, 
     {Cos[(26*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(26*Pi)/15], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {((1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(53*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(53*Pi)/30], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, \
Cos[Pi/30]}, {((1 + Sqrt[5])*Sin[Pi/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(28*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(28*Pi)/15], Cos[Pi/30]}, 
     {(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[(28*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(28*Pi)/15], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(29*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(29*Pi)/15], Cos[Pi/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Cos[(59*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(59*Pi)/30], Cos[Pi/30]}, 
     {Cos[(29*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/15], Cos[Pi/30]}, \
{0, 0, 1}}], 
   Line[{{0, 0, 1}, {0, 0, 1}, {Sin[Pi/30], 0, Cos[Pi/30]}, \
{Cos[(59*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(59*Pi)/30], Cos[Pi/30]}, {0, 0, \
1}}], 
   Line[{{Sin[Pi/30], 0, Cos[Pi/30]}, {Cos[Pi/30]*Sin[Pi/30], Sin[Pi/30]^2, \
Cos[Pi/30]}, {Cos[Pi/30]*Sin[Pi/15], Sin[Pi/30]*Sin[Pi/15], 
      Cos[Pi/15]}, {Sin[Pi/15], 0, Cos[Pi/15]}, {Sin[Pi/30], 0, \
Cos[Pi/30]}}], 
   Line[{{Cos[Pi/30]*Sin[Pi/30], Sin[Pi/30]^2, Cos[Pi/30]}, \
{Cos[Pi/15]*Sin[Pi/30], Sin[Pi/30]*Sin[Pi/15], Cos[Pi/30]}, 
     {Cos[Pi/15]*Sin[Pi/15], Sin[Pi/15]^2, Cos[Pi/15]}, \
{Cos[Pi/30]*Sin[Pi/15], Sin[Pi/30]*Sin[Pi/15], Cos[Pi/15]}, 
     {Cos[Pi/30]*Sin[Pi/30], Sin[Pi/30]^2, Cos[Pi/30]}}], \
Line[{{Cos[Pi/15]*Sin[Pi/30], Sin[Pi/30]*Sin[Pi/15], Cos[Pi/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
      ((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {Cos[Pi/15]*Sin[Pi/15], \
Sin[Pi/15]^2, Cos[Pi/15]}, 
     {Cos[Pi/15]*Sin[Pi/30], Sin[Pi/30]*Sin[Pi/15], Cos[Pi/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {Cos[(2*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(2*Pi)/15], 
      Cos[Pi/30]}, {Cos[(2*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(2*Pi)/15], \
Cos[Pi/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
      ((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(2*Pi)/15], Cos[Pi/30]}, \
{(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}, 
     {(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, \
{Cos[(2*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(2*Pi)/15], Cos[Pi/15]}, 
     {Cos[(2*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(2*Pi)/15], Cos[Pi/30]}}], 
   Line[{{(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}, {((1 + \
Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, 
     {(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}}], Line[{{((1 + \
Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(7*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/30], Cos[Pi/30]}, \
{Cos[(7*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/30], Cos[Pi/15]}, 
     {((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {((1 + Sqrt[5])*Sin[Pi/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}}], \
Line[{{Cos[(7*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/30], Cos[Pi/30]}, 
     {Cos[(4*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(4*Pi)/15], Cos[Pi/30]}, \
{Cos[(4*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(4*Pi)/15], Cos[Pi/15]}, 
     {Cos[(7*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/30], Cos[Pi/15]}, \
{Cos[(7*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/30], Cos[Pi/30]}}], 
   Line[{{Cos[(4*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(4*Pi)/15], Cos[Pi/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + Sqrt[5])*Sin[Pi/30])/4, 
      Cos[Pi/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {Cos[(4*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(4*Pi)/15], Cos[Pi/15]}, \
{Cos[(4*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(4*Pi)/15], Cos[Pi/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}}], 
   Line[{{Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, \
{Cos[(11*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/30], Cos[Pi/30]}, 
     {Cos[(11*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/30], Cos[Pi/15]}, \
{Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}}], \
Line[{{Cos[(11*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/30], Cos[Pi/30]}, 
     {((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {((-1 + Sqrt[5])*Sin[Pi/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, \
{Cos[(11*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/30], Cos[Pi/15]}, 
     {Cos[(11*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/30], Cos[Pi/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(13*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/30], Cos[Pi/30]}, \
{Cos[(13*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/30], Cos[Pi/15]}, 
     {((-1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {((-1 + Sqrt[5])*Sin[Pi/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}}], \
Line[{{Cos[(13*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/30], Cos[Pi/30]}, 
     {Cos[(7*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/15], Cos[Pi/30]}, \
{Cos[(7*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/15], Cos[Pi/15]}, 
     {Cos[(13*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/30], Cos[Pi/15]}, \
{Cos[(13*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/30], Cos[Pi/30]}}], 
   Line[{{Cos[(7*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/15], Cos[Pi/30]}, \
{0, Sin[Pi/30], Cos[Pi/30]}, {0, Sin[Pi/15], Cos[Pi/15]}, 
     {Cos[(7*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/15], Cos[Pi/15]}, \
{Cos[(7*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(7*Pi)/15], Cos[Pi/30]}}], 
   Line[{{0, Sin[Pi/30], Cos[Pi/30]}, {Cos[(8*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(8*Pi)/15], Cos[Pi/30]}, 
     {Cos[(8*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(8*Pi)/15], Cos[Pi/15]}, {0, \
Sin[Pi/15], Cos[Pi/15]}, {0, Sin[Pi/30], Cos[Pi/30]}}], 
   Line[{{Cos[(8*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(8*Pi)/15], Cos[Pi/30]}, \
{Cos[(17*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/30], Cos[Pi/30]}, 
     {Cos[(17*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/30], Cos[Pi/15]}, \
{Cos[(8*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(8*Pi)/15], Cos[Pi/15]}, 
     {Cos[(8*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(8*Pi)/15], Cos[Pi/30]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/30], \
Cos[Pi/30]}, {-((-1 + Sqrt[5])*Sin[Pi/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {-((-1 + \
Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(17*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/30], Cos[Pi/15]}, \
{Cos[(17*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/30], Cos[Pi/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(19*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/30], Cos[Pi/30]}, \
{Cos[(19*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/30], Cos[Pi/15]}, 
     {-((-1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {-((-1 + Sqrt[5])*Sin[Pi/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}}], \
Line[{{Cos[(19*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/30], Cos[Pi/30]}, 
     {-Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, {-Sin[Pi/15]/2, \
(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(19*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/30], Cos[Pi/15]}, \
{Cos[(19*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/30], Cos[Pi/30]}}], 
   Line[{{-Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}, {-Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {-Sin[Pi/30]/2, (Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, ((1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[(11*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/15], Cos[Pi/30]}, \
{Cos[(11*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/15], Cos[Pi/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
      ((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}}], \
Line[{{Cos[(11*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/15], Cos[Pi/30]}, 
     {Cos[(23*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/30], Cos[Pi/30]}, \
{Cos[(23*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/30], Cos[Pi/15]}, 
     {Cos[(11*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/15], Cos[Pi/15]}, \
{Cos[(11*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(11*Pi)/15], Cos[Pi/30]}}], 
   Line[{{Cos[(23*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/30], \
Cos[Pi/30]}, {-((1 + Sqrt[5])*Sin[Pi/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {-((1 + \
Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(23*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/30], Cos[Pi/15]}, \
{Cos[(23*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/30], Cos[Pi/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {-(Sqrt[3]*Sin[Pi/30])/2, \
Sin[Pi/30]/2, Cos[Pi/30]}, 
     {-(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, {-((1 + \
Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {-((1 + Sqrt[5])*Sin[Pi/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}}], 
   Line[{{-(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}, \
{Cos[(13*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/15], Cos[Pi/30]}, 
     {Cos[(13*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/15], Cos[Pi/15]}, \
{-(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, 
     {-(Sqrt[3]*Sin[Pi/30])/2, Sin[Pi/30]/2, Cos[Pi/30]}}], \
Line[{{Cos[(13*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/15], Cos[Pi/30]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
      ((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, \
{Cos[(13*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/15], Cos[Pi/15]}, 
     {Cos[(13*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(13*Pi)/15], Cos[Pi/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, ((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[(14*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(14*Pi)/15], Cos[Pi/30]}, \
{Cos[(14*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(14*Pi)/15], Cos[Pi/15]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, ((-1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
      ((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}}], \
Line[{{Cos[(14*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(14*Pi)/15], Cos[Pi/30]}, 
     {Cos[(29*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/30], Cos[Pi/30]}, \
{Cos[(29*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/30], Cos[Pi/15]}, 
     {Cos[(14*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(14*Pi)/15], Cos[Pi/15]}, \
{Cos[(14*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(14*Pi)/15], Cos[Pi/30]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/30], \
Cos[Pi/30]}, {-Sin[Pi/30], 0, Cos[Pi/30]}, {-Sin[Pi/15], 0, Cos[Pi/15]}, 
     {Cos[(29*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/30], Cos[Pi/15]}, \
{Cos[(29*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/30], Cos[Pi/30]}}], 
   Line[{{-Sin[Pi/30], 0, Cos[Pi/30]}, {Cos[(31*Pi)/30]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(31*Pi)/30], Cos[Pi/30]}, 
     {Cos[(31*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(31*Pi)/30], Cos[Pi/15]}, \
{-Sin[Pi/15], 0, Cos[Pi/15]}, {-Sin[Pi/30], 0, Cos[Pi/30]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(31*Pi)/30], \
Cos[Pi/30]}, {Cos[(16*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(16*Pi)/15], 
      Cos[Pi/30]}, {Cos[(16*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(16*Pi)/15], \
Cos[Pi/15]}, {Cos[(31*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(31*Pi)/30], 
      Cos[Pi/15]}, {Cos[(31*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(31*Pi)/30], \
Cos[Pi/30]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(16*Pi)/15], \
Cos[Pi/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
      -((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {Cos[(16*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(16*Pi)/15], Cos[Pi/15]}, \
{Cos[(16*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(16*Pi)/15], Cos[Pi/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[(17*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/15], Cos[Pi/30]}, \
{Cos[(17*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/15], Cos[Pi/15]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
      -((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}}], \
Line[{{Cos[(17*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/15], Cos[Pi/30]}, 
     {-(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}, \
{-(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, 
     {Cos[(17*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/15], Cos[Pi/15]}, \
{Cos[(17*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(17*Pi)/15], Cos[Pi/30]}}], 
   Line[{{-(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}, {-((1 + \
Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {-((1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {-(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, 
     {-(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(37*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(37*Pi)/30], Cos[Pi/30]}, \
{Cos[(37*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(37*Pi)/30], Cos[Pi/15]}, 
     {-((1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {-((1 + Sqrt[5])*Sin[Pi/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}}], \
Line[{{Cos[(37*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(37*Pi)/30], Cos[Pi/30]}, 
     {Cos[(19*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/15], Cos[Pi/30]}, \
{Cos[(19*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/15], Cos[Pi/15]}, 
     {Cos[(37*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(37*Pi)/30], Cos[Pi/15]}, \
{Cos[(37*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(37*Pi)/30], Cos[Pi/30]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/15], \
Cos[Pi/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
      -((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {Cos[(19*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/15], Cos[Pi/15]}, \
{Cos[(19*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(19*Pi)/15], Cos[Pi/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, {-Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, \
Cos[Pi/30]}, 
     {-Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}}], 
   Line[{{-Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, \
{Cos[(41*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(41*Pi)/30], Cos[Pi/30]}, 
     {Cos[(41*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(41*Pi)/30], Cos[Pi/15]}, \
{-Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {-Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}}], \
Line[{{Cos[(41*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(41*Pi)/30], Cos[Pi/30]}, 
     {-((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}, {-((-1 + Sqrt[5])*Sin[Pi/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, \
{Cos[(41*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(41*Pi)/30], Cos[Pi/15]}, 
     {Cos[(41*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(41*Pi)/30], Cos[Pi/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(43*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(43*Pi)/30], Cos[Pi/30]}, \
{Cos[(43*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(43*Pi)/30], Cos[Pi/15]}, 
     {-((-1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {-((-1 + Sqrt[5])*Sin[Pi/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}}], \
Line[{{Cos[(43*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(43*Pi)/30], Cos[Pi/30]}, 
     {Cos[(22*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(22*Pi)/15], Cos[Pi/30]}, \
{Cos[(22*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(22*Pi)/15], Cos[Pi/15]}, 
     {Cos[(43*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(43*Pi)/30], Cos[Pi/15]}, \
{Cos[(43*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(43*Pi)/30], Cos[Pi/30]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(22*Pi)/15], \
Cos[Pi/30]}, {0, -Sin[Pi/30], Cos[Pi/30]}, {0, -Sin[Pi/15], Cos[Pi/15]}, 
     {Cos[(22*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(22*Pi)/15], Cos[Pi/15]}, \
{Cos[(22*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(22*Pi)/15], Cos[Pi/30]}}], 
   Line[{{0, -Sin[Pi/30], Cos[Pi/30]}, {Cos[(23*Pi)/15]*Sin[Pi/30], \
Sin[Pi/30]*Sin[(23*Pi)/15], Cos[Pi/30]}, 
     {Cos[(23*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/15], Cos[Pi/15]}, \
{0, -Sin[Pi/15], Cos[Pi/15]}, {0, -Sin[Pi/30], Cos[Pi/30]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/15], \
Cos[Pi/30]}, {Cos[(47*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(47*Pi)/30], 
      Cos[Pi/30]}, {Cos[(47*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(47*Pi)/30], \
Cos[Pi/15]}, {Cos[(23*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/15], 
      Cos[Pi/15]}, {Cos[(23*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(23*Pi)/15], \
Cos[Pi/30]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(47*Pi)/30], \
Cos[Pi/30]}, {((-1 + Sqrt[5])*Sin[Pi/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {((-1 + \
Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(47*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(47*Pi)/30], Cos[Pi/15]}, \
{Cos[(47*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(47*Pi)/30], Cos[Pi/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, 
     {Cos[(49*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(49*Pi)/30], Cos[Pi/30]}, \
{Cos[(49*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(49*Pi)/30], Cos[Pi/15]}, 
     {((-1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {((-1 + Sqrt[5])*Sin[Pi/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}}], \
Line[{{Cos[(49*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(49*Pi)/30], Cos[Pi/30]}, 
     {Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, {Sin[Pi/15]/2, \
-(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(49*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(49*Pi)/30], Cos[Pi/15]}, \
{Cos[(49*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(49*Pi)/30], Cos[Pi/30]}}], 
   Line[{{Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}, {Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Sin[Pi/30]/2, -(Sqrt[3]*Sin[Pi/30])/2, Cos[Pi/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, -((1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[(26*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(26*Pi)/15], Cos[Pi/30]}, \
{Cos[(26*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(26*Pi)/15], Cos[Pi/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
      -((1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}}], \
Line[{{Cos[(26*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(26*Pi)/15], Cos[Pi/30]}, 
     {Cos[(53*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(53*Pi)/30], Cos[Pi/30]}, \
{Cos[(53*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(53*Pi)/30], Cos[Pi/15]}, 
     {Cos[(26*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(26*Pi)/15], Cos[Pi/15]}, \
{Cos[(26*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(26*Pi)/15], Cos[Pi/30]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(53*Pi)/30], \
Cos[Pi/30]}, {((1 + Sqrt[5])*Sin[Pi/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {((1 + \
Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(53*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(53*Pi)/30], Cos[Pi/15]}, \
{Cos[(53*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(53*Pi)/30], Cos[Pi/30]}}], 
   Line[{{((1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, Cos[Pi/30]}, {(Sqrt[3]*Sin[Pi/30])/2, \
-Sin[Pi/30]/2, Cos[Pi/30]}, 
     {(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, {((1 + \
Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {((1 + Sqrt[5])*Sin[Pi/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, \
Cos[Pi/30]}}], 
   Line[{{(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}, \
{Cos[(28*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(28*Pi)/15], Cos[Pi/30]}, 
     {Cos[(28*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(28*Pi)/15], Cos[Pi/15]}, \
{(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, 
     {(Sqrt[3]*Sin[Pi/30])/2, -Sin[Pi/30]/2, Cos[Pi/30]}}], \
Line[{{Cos[(28*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(28*Pi)/15], Cos[Pi/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Cos[Pi/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
      -((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, \
{Cos[(28*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(28*Pi)/15], Cos[Pi/15]}, 
     {Cos[(28*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(28*Pi)/15], Cos[Pi/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, -((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}, 
     {Cos[(29*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/15], Cos[Pi/30]}, \
{Cos[(29*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/15], Cos[Pi/15]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
      -((-1 + Sqrt[5])*Sin[Pi/30])/4, Cos[Pi/30]}}], \
Line[{{Cos[(29*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/15], Cos[Pi/30]}, 
     {Cos[(59*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(59*Pi)/30], Cos[Pi/30]}, \
{Cos[(59*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(59*Pi)/30], Cos[Pi/15]}, 
     {Cos[(29*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/15], Cos[Pi/15]}, \
{Cos[(29*Pi)/15]*Sin[Pi/30], Sin[Pi/30]*Sin[(29*Pi)/15], Cos[Pi/30]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(59*Pi)/30], \
Cos[Pi/30]}, {Sin[Pi/30], 0, Cos[Pi/30]}, {Sin[Pi/15], 0, Cos[Pi/15]}, 
     {Cos[(59*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(59*Pi)/30], Cos[Pi/15]}, \
{Cos[(59*Pi)/30]*Sin[Pi/30], Sin[Pi/30]*Sin[(59*Pi)/30], Cos[Pi/30]}}], 
   Line[{{Sin[Pi/15], 0, Cos[Pi/15]}, {Cos[Pi/30]*Sin[Pi/15], \
Sin[Pi/30]*Sin[Pi/15], Cos[Pi/15]}, 
     {((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}, {(-1 + Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Sin[Pi/15], 0, Cos[Pi/15]}}], Line[{{Cos[Pi/30]*Sin[Pi/15], \
Sin[Pi/30]*Sin[Pi/15], Cos[Pi/15]}, 
     {Cos[Pi/15]*Sin[Pi/15], Sin[Pi/15]^2, Cos[Pi/15]}, {((-1 + \
Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}, {Cos[Pi/30]*Sin[Pi/15], Sin[Pi/30]*Sin[Pi/15], 
      Cos[Pi/15]}}], Line[{{Cos[Pi/15]*Sin[Pi/15], Sin[Pi/15]^2, Cos[Pi/15]}, \
{(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
      ((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {((-1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}, {Cos[Pi/15]*Sin[Pi/15], Sin[Pi/15]^2, Cos[Pi/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, ((-1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {Cos[(2*Pi)/15]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(2*Pi)/15], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, Sqrt[(5 \
+ Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
      ((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}}], \
Line[{{Cos[(2*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(2*Pi)/15], Cos[Pi/15]}, 
     {(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, {(Sqrt[3]*(-1 + \
Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(2*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(2*Pi)/15], Cos[Pi/15]}}], 
   Line[{{(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}, {((1 + \
Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {Cos[(7*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/30], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, \
Cos[Pi/15]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/30], Cos[Pi/15]}, \
{Cos[(4*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(4*Pi)/15], Cos[Pi/15]}, 
     {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(7*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/30], Cos[Pi/15]}}], 
   Line[{{Cos[(4*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(4*Pi)/15], Cos[Pi/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, 
      Cos[Pi/15]}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(4*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(4*Pi)/15], Cos[Pi/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, \
Cos[Pi/15]}, {Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 \
- Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, 
      Cos[Pi/15]}}], Line[{{Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {Cos[(11*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/30], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/30], \
Cos[Pi/15]}, {((-1 + Sqrt[5])*Sin[Pi/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(11*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/30], Cos[Pi/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(13*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/30], \
Cos[Pi/15]}, {Cos[(7*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/15], \
Cos[Pi/15]}, 
     {((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(13*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/30], Cos[Pi/15]}}], 
   Line[{{Cos[(7*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(7*Pi)/15], Cos[Pi/15]}, \
{0, Sin[Pi/15], Cos[Pi/15]}, 
     {0, (-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(7*Pi)/15]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(7*Pi)/15], Cos[Pi/15]}}], 
   Line[{{0, Sin[Pi/15], Cos[Pi/15]}, {Cos[(8*Pi)/15]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(8*Pi)/15], Cos[Pi/15]}, 
     {((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {0, (-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {0, Sin[Pi/15], \
Cos[Pi/15]}}], 
   Line[{{Cos[(8*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(8*Pi)/15], Cos[Pi/15]}, \
{Cos[(17*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/30], Cos[Pi/15]}, 
     {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(8*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(8*Pi)/15], Cos[Pi/15]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/30], \
Cos[Pi/15]}, {-((-1 + Sqrt[5])*Sin[Pi/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {-(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/30], Cos[Pi/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(19*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {-(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/30], \
Cos[Pi/15]}, {-Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(19*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/30], Cos[Pi/15]}}], 
   Line[{{-Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-Sin[Pi/15]/2, (Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {Cos[(11*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/15], \
Cos[Pi/15]}, {Cos[(23*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/30], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(11*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(11*Pi)/15], Cos[Pi/15]}}], 
   Line[{{Cos[(23*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/30], \
Cos[Pi/15]}, {-((1 + Sqrt[5])*Sin[Pi/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {-((-1 + Sqrt[5])*(1 \
+ Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(23*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/30], Cos[Pi/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {-(Sqrt[3]*Sin[Pi/15])/2, \
Sin[Pi/15]/2, Cos[Pi/15]}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-((1 + Sqrt[5])*Sin[Pi/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, 
      Cos[Pi/15]}}], Line[{{-(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, \
Cos[Pi/15]}, {Cos[(13*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/15], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[Pi/15])/2, Sin[Pi/15]/2, Cos[Pi/15]}}], 
   Line[{{Cos[(13*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[Pi/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
      ((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {-((-1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(13*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(13*Pi)/15], Cos[Pi/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, ((-1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {Cos[(14*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(14*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, ((-1 \
+ Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(14*Pi)/15], \
Cos[Pi/15]}, {Cos[(29*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/30], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(14*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(14*Pi)/15], Cos[Pi/15]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/30], \
Cos[Pi/15]}, {-Sin[Pi/15], 0, Cos[Pi/15]}, 
     {(1 - Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(29*Pi)/30]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(29*Pi)/30], Cos[Pi/15]}}], 
   Line[{{-Sin[Pi/15], 0, Cos[Pi/15]}, {Cos[(31*Pi)/30]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(31*Pi)/30], Cos[Pi/15]}, 
     {((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(31*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {-Sin[Pi/15], 0, \
Cos[Pi/15]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(31*Pi)/30], \
Cos[Pi/15]}, {Cos[(16*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(16*Pi)/15], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(31*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(31*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(31*Pi)/30], Cos[Pi/15]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(16*Pi)/15], \
Cos[Pi/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
      -((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {-((-1 + Sqrt[5])*Sqrt[(5 \
+ Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(16*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(16*Pi)/15], Cos[Pi/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {Cos[(17*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 \
+ Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/15], \
Cos[Pi/15]}, {-(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(17*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(17*Pi)/15], Cos[Pi/15]}}], 
   Line[{{-(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}, {-((1 + \
Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(37*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(37*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, 
      -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-((1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, 
      Cos[Pi/15]}}], Line[{{Cos[(37*Pi)/30]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(37*Pi)/30], Cos[Pi/15]}, 
     {Cos[(19*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(37*Pi)/30]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(37*Pi)/30], Cos[Pi/15]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/15], \
Cos[Pi/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, 
      -((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(19*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(19*Pi)/15], Cos[Pi/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {-Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, \
Cos[Pi/15]}, 
     {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + Sqrt[5])*Sin[Pi/15])/4, 
      Cos[Pi/15]}}], Line[{{-Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, \
Cos[Pi/15]}, {Cos[(41*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(41*Pi)/30], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}}], 
   Line[{{Cos[(41*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(41*Pi)/30], \
Cos[Pi/15]}, {-((-1 + Sqrt[5])*Sin[Pi/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {-(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(41*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(41*Pi)/30], Cos[Pi/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(43*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(43*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {-(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(43*Pi)/30], \
Cos[Pi/15]}, {Cos[(22*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(22*Pi)/15], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(22*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(43*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(43*Pi)/30], Cos[Pi/15]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(22*Pi)/15], \
Cos[Pi/15]}, {0, -Sin[Pi/15], Cos[Pi/15]}, 
     {0, (1 - Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(22*Pi)/15]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(22*Pi)/15], Cos[Pi/15]}}], 
   Line[{{0, -Sin[Pi/15], Cos[Pi/15]}, {Cos[(23*Pi)/15]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(23*Pi)/15], Cos[Pi/15]}, 
     {((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {0, (1 - Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {0, -Sin[Pi/15], \
Cos[Pi/15]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/15], \
Cos[Pi/15]}, {Cos[(47*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(47*Pi)/30], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(23*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(23*Pi)/15], Cos[Pi/15]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(47*Pi)/30], \
Cos[Pi/15]}, {((-1 + Sqrt[5])*Sin[Pi/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(47*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(47*Pi)/30], Cos[Pi/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {Cos[(49*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(49*Pi)/30], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(49*Pi)/30], \
Cos[Pi/15]}, {Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, 
     {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(49*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(49*Pi)/30], Cos[Pi/15]}}], 
   Line[{{Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {Sin[Pi/15]/2, -(Sqrt[3]*Sin[Pi/15])/2, Cos[Pi/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {Cos[(26*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(26*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 \
- Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, -((1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(26*Pi)/15], \
Cos[Pi/15]}, {Cos[(53*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(53*Pi)/30], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(26*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(26*Pi)/15], Cos[Pi/15]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(53*Pi)/30], \
Cos[Pi/15]}, {((1 + Sqrt[5])*Sin[Pi/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {((-1 + Sqrt[5])*(1 \
+ Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(53*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(53*Pi)/30], Cos[Pi/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, Cos[Pi/15]}, {(Sqrt[3]*Sin[Pi/15])/2, \
-Sin[Pi/15]/2, Cos[Pi/15]}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{((1 + Sqrt[5])*Sin[Pi/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, 
      Cos[Pi/15]}}], Line[{{(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, \
Cos[Pi/15]}, {Cos[(28*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(28*Pi)/15], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[3]*Sin[Pi/15])/2, -Sin[Pi/15]/2, Cos[Pi/15]}}], 
   Line[{{Cos[(28*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(28*Pi)/15], \
Cos[Pi/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, 
      -((-1 + Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, {((-1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(28*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(28*Pi)/15], Cos[Pi/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 + \
Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}, 
     {Cos[(29*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/15], Cos[Pi/15]}, \
{((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/15])/2, -((-1 \
+ Sqrt[5])*Sin[Pi/15])/4, Cos[Pi/15]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/15], \
Cos[Pi/15]}, {Cos[(59*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(59*Pi)/30], 
      Cos[Pi/15]}, {((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(59*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(29*Pi)/15]*Sin[Pi/15], Sin[Pi/15]*Sin[(29*Pi)/15], Cos[Pi/15]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[Pi/15], Sin[Pi/15]*Sin[(59*Pi)/30], \
Cos[Pi/15]}, {Sin[Pi/15], 0, Cos[Pi/15]}, 
     {(-1 + Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(59*Pi)/30]*Sin[Pi/15], \
Sin[Pi/15]*Sin[(59*Pi)/30], Cos[Pi/15]}}], 
   Line[{{(-1 + Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}, 
     {Cos[Pi/30]*Sin[(2*Pi)/15], Sin[Pi/30]*Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, \
{Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}, 
     {(-1 + Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}, 
     {Cos[Pi/15]*Sin[(2*Pi)/15], Sin[Pi/15]*Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, \
{Cos[Pi/30]*Sin[(2*Pi)/15], Sin[Pi/30]*Sin[(2*Pi)/15], 
      Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + \
Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, Sqrt[(5 \
+ Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, \
{Cos[Pi/15]*Sin[(2*Pi)/15], Sin[Pi/15]*Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(2*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]^2, Cos[(2*Pi)/15]}, \
{(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]^2, Cos[(2*Pi)/15]}, {((-1 \
+ Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(7*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(2*Pi)/15]}, {((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(4*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(7*Pi)/30], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {Cos[(4*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(11*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], 
      Cos[(2*Pi)/15]}, {Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}, {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 \
+ Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(2*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(13*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(7*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(13*Pi)/30], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {0, (-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {0, Sin[(2*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(7*Pi)/15], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{0, (-1 + Sqrt[5])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(8*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(2*Pi)/15]}, 
     {0, Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, {0, (-1 + Sqrt[5])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(8*Pi)/15], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 \
+ Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(19*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(2*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {-(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Cos[(2*Pi)/15]}, {-Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}, {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(11*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(23*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(11*Pi)/15], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(23*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, \
Cos[(2*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(13*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], 
      Cos[(2*Pi)/15]}, {-(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, \
Cos[(2*Pi)/15]}, {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, Sqrt[(5 \
+ Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(2*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(14*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(29*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(14*Pi)/15], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {-Sin[(2*Pi)/15], 0, \
Cos[(2*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(29*Pi)/30], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{(1 - Sqrt[5])/4, 0, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(31*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(31*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(31*Pi)/30], 
      Cos[(2*Pi)/15]}, {-Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}, {(1 - \
Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(16*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(31*Pi)/30]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(31*Pi)/30], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(31*Pi)/30])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, \
{Cos[(16*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(2*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, 
     {Cos[(17*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{-(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(37*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(2*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(19*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(37*Pi)/30], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {Cos[(19*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{-Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(41*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(41*Pi)/30], 
      Cos[(2*Pi)/15]}, {-Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}, {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(41*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(43*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(2*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {-(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(22*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(43*Pi)/30], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {0, (1 - Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}, {0, -Sin[(2*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(22*Pi)/15], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{0, (1 - Sqrt[5])/4, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(23*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(23*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/15], 
      Cos[(2*Pi)/15]}, {0, -Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, {0, (1 - \
Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(47*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(47*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(23*Pi)/15]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(23*Pi)/15], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 \
+ Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(47*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(49*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}, 
     {Cos[(49*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Cos[(2*Pi)/15]}, {Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}, {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(26*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(2*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(53*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(53*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(26*Pi)/15], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(53*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(28*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(28*Pi)/15], 
      Cos[(2*Pi)/15]}, {(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, \
Cos[(2*Pi)/15]}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, Sqrt[(5 \
+ Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(2*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(29*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(2*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, \
Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(59*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(29*Pi)/15], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])/4, 0, Sqrt[(5 + Sqrt[5])/2]/2}, {Sin[(2*Pi)/15], 0, \
Cos[(2*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(59*Pi)/30], Cos[(2*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
      Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}, \
{Cos[Pi/30]*Sin[(2*Pi)/15], Sin[Pi/30]*Sin[(2*Pi)/15], 
      Cos[(2*Pi)/15]}, {Cos[Pi/30]/2, Sin[Pi/30]/2, Sqrt[3]/2}, {1/2, 0, \
Sqrt[3]/2}, {Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}}], 
   Line[{{Cos[Pi/30]*Sin[(2*Pi)/15], Sin[Pi/30]*Sin[(2*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[Pi/15]*Sin[(2*Pi)/15], Sin[Pi/15]*Sin[(2*Pi)/15], 
      Cos[(2*Pi)/15]}, {Cos[Pi/15]/2, Sin[Pi/15]/2, Sqrt[3]/2}, \
{Cos[Pi/30]/2, Sin[Pi/30]/2, Sqrt[3]/2}, 
     {Cos[Pi/30]*Sin[(2*Pi)/15], Sin[Pi/30]*Sin[(2*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[Pi/15]*Sin[(2*Pi)/15], Sin[Pi/15]*Sin[(2*Pi)/15], \
Cos[(2*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[Pi/15]/2, Sin[Pi/15]/2, Sqrt[3]/2}, {Cos[Pi/15]*Sin[(2*Pi)/15], \
Sin[Pi/15]*Sin[(2*Pi)/15], Cos[(2*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]^2, Cos[(2*Pi)/15]}, \
{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, Sqrt[3]/2}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(2*Pi)/15]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]^2, Cos[(2*Pi)/15]}, 
     {(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{Sqrt[3]/4, 1/4, Sqrt[3]/2}, {Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, Sqrt[3]/2}, \

     {Cos[(2*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]^2, Cos[(2*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, {((1 \
+ Sqrt[5])*Sin[(2*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(1 + \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Sqrt[3]/4, 1/4, Sqrt[3]/2}, {(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(7*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, Sqrt[3]/2}, 
     {(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, {((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(7*Pi)/30]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(7*Pi)/30], Cos[(2*Pi)/15]}, 
     {Cos[(4*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, Sqrt[3]/2}, 
     {Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(7*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(4*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(2*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(4*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {1/4, \
Sqrt[3]/4, Sqrt[3]/2}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Cos[(2*Pi)/15]}}], Line[{{Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, \
Cos[(2*Pi)/15]}, 
     {Cos[(11*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, Sqrt[3]/2}, 
     {1/4, Sqrt[3]/4, Sqrt[3]/2}, {Sin[(2*Pi)/15]/2, \
(Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(-1 + \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(11*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(13*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, Sqrt[3]/2}, 
     {(-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, {((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(13*Pi)/30]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(13*Pi)/30], Cos[(2*Pi)/15]}, 
     {Cos[(7*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, Sqrt[3]/2}, 
     {Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(13*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(2*Pi)/15]}, {0, Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, {0, 1/2, Sqrt[3]/2}, 
     {Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(7*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{0, Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(8*Pi)/15], Cos[(2*Pi)/15]}, 
     {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, Sqrt[3]/2}, {0, 1/2, Sqrt[3]/2}, \
{0, Sin[(2*Pi)/15], Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(8*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(17*Pi)/30], Cos[(2*Pi)/15]}, {Cos[(17*Pi)/30]/2, \
Sin[(17*Pi)/30]/2, Sqrt[3]/2}, 
     {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(8*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(2*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(1 - \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(17*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, Sqrt[3]/2}, 
     {(1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, {-((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(19*Pi)/30]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(19*Pi)/30], Cos[(2*Pi)/15]}, 
     {-Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {-1/4, \
Sqrt[3]/4, Sqrt[3]/2}, 
     {Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(19*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{-Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, {-1/4, Sqrt[3]/4, Sqrt[3]/2}, 
     {-Sin[(2*Pi)/15]/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {Cos[(11*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, Sqrt[3]/2}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(11*Pi)/15]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(11*Pi)/15], Cos[(2*Pi)/15]}, 
     {Cos[(23*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, Sqrt[3]/2}, 
     {Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(11*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(23*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(2*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(-1 - \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(23*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(2*Pi)/15])/2, Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{-Sqrt[3]/4, 1/4, Sqrt[3]/2}, 
     {(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, {-((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      Cos[(2*Pi)/15]}}], Line[{{-(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, 
     {Cos[(13*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, Sqrt[3]/2}, 
     {-Sqrt[3]/4, 1/4, Sqrt[3]/2}, {-(Sqrt[3]*Sin[(2*Pi)/15])/2, \
Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(13*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(13*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {Cos[(14*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, Sqrt[3]/2}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(14*Pi)/15]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(14*Pi)/15], Cos[(2*Pi)/15]}, 
     {Cos[(29*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, Sqrt[3]/2}, 
     {Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(14*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(2*Pi)/15]}, {-Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}, 
     {-1/2, 0, Sqrt[3]/2}, {Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(29*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], 
      Cos[(2*Pi)/15]}}], Line[{{-Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(31*Pi)/30], 
      Cos[(2*Pi)/15]}, {Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, Sqrt[3]/2}, \
{-1/2, 0, Sqrt[3]/2}, {-Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(16*Pi)/15], Cos[(2*Pi)/15]}, {Cos[(16*Pi)/15]/2, \
Sin[(16*Pi)/15]/2, Sqrt[3]/2}, 
     {Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(31*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(16*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {Cos[(17*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, Sqrt[3]/2}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(17*Pi)/15]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(17*Pi)/15], Cos[(2*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{-Sqrt[3]/4, -1/4, Sqrt[3]/2}, 
     {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(17*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(-1 - \
Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {-Sqrt[3]/4, -1/4, Sqrt[3]/2}, {-(Sqrt[3]*Sin[(2*Pi)/15])/2, \
-Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(37*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, Sqrt[3]/2}, 
     {(-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, {-((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(37*Pi)/30]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(37*Pi)/30], Cos[(2*Pi)/15]}, 
     {Cos[(19*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, Sqrt[3]/2}, 
     {Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(37*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(2*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {-Sqrt[(5 - \
Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(19*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {-Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {-1/4, \
-Sqrt[3]/4, Sqrt[3]/2}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Cos[(2*Pi)/15]}}], Line[{{-Sin[(2*Pi)/15]/2, \
-(Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(41*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, Sqrt[3]/2}, 
     {-1/4, -Sqrt[3]/4, Sqrt[3]/2}, {-Sin[(2*Pi)/15]/2, \
-(Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(41*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(2*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(1 - \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(41*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(43*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, Sqrt[3]/2}, 
     {(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, {-((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(43*Pi)/30]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(43*Pi)/30], Cos[(2*Pi)/15]}, 
     {Cos[(22*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, Sqrt[3]/2}, 
     {Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(43*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(2*Pi)/15]}, {0, -Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, 
     {0, -1/2, Sqrt[3]/2}, {Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(22*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(22*Pi)/15], 
      Cos[(2*Pi)/15]}}], Line[{{0, -Sin[(2*Pi)/15], Cos[(2*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/15], 
      Cos[(2*Pi)/15]}, {Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, Sqrt[3]/2}, {0, \
-1/2, Sqrt[3]/2}, {0, -Sin[(2*Pi)/15], Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(2*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(47*Pi)/30], Cos[(2*Pi)/15]}, {Cos[(47*Pi)/30]/2, \
Sin[(47*Pi)/30]/2, Sqrt[3]/2}, 
     {Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(23*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(2*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(-1 + \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(47*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {Cos[(49*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, Sqrt[3]/2}, 
     {(-1 + Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, {((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(49*Pi)/30]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(49*Pi)/30], Cos[(2*Pi)/15]}, 
     {Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {1/4, \
-Sqrt[3]/4, Sqrt[3]/2}, 
     {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(49*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {Sqrt[(5 - \
Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, {1/4, -Sqrt[3]/4, Sqrt[3]/2}, 
     {Sin[(2*Pi)/15]/2, -(Sqrt[3]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {Cos[(26*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, Sqrt[3]/2}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(26*Pi)/15]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(26*Pi)/15], Cos[(2*Pi)/15]}, 
     {Cos[(53*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, Sqrt[3]/2}, 
     {Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(26*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(2*Pi)/15]}, {((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, {(1 + \
Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(53*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(2*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, Cos[(2*Pi)/15]}, 
     {(Sqrt[3]*Sin[(2*Pi)/15])/2, -Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, \
{Sqrt[3]/4, -1/4, Sqrt[3]/2}, 
     {(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, {((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      Cos[(2*Pi)/15]}}], Line[{{(Sqrt[3]*Sin[(2*Pi)/15])/2, \
-Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}, 
     {Cos[(28*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, Sqrt[3]/2}, 
     {Sqrt[3]/4, -1/4, Sqrt[3]/2}, {(Sqrt[3]*Sin[(2*Pi)/15])/2, \
-Sin[(2*Pi)/15]/2, Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(28*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(2*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(28*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, Cos[(2*Pi)/15]}, 
     {Cos[(29*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(2*Pi)/15]}, {Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, Sqrt[3]/2}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Cos[(2*Pi)/15]}}], Line[{{Cos[(29*Pi)/15]*Sin[(2*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(29*Pi)/15], Cos[(2*Pi)/15]}, 
     {Cos[(59*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(2*Pi)/15]}, {Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, Sqrt[3]/2}, 
     {Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(29*Pi)/15]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(2*Pi)/15]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(2*Pi)/15]}, {Sin[(2*Pi)/15], 0, Cos[(2*Pi)/15]}, 
     {1/2, 0, Sqrt[3]/2}, {Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(59*Pi)/30]*Sin[(2*Pi)/15], Sin[(2*Pi)/15]*Sin[(59*Pi)/30], 
      Cos[(2*Pi)/15]}}], Line[{{1/2, 0, Sqrt[3]/2}, {Cos[Pi/30]/2, \
Sin[Pi/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, (1 + Sqrt[5])/4}, {Sqrt[(5 - \
Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {1/2, 0, Sqrt[3]/2}}], 
   Line[{{Cos[Pi/30]/2, Sin[Pi/30]/2, Sqrt[3]/2}, {Cos[Pi/15]/2, \
Sin[Pi/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
      (1 + Sqrt[5])/4}, {Cos[Pi/30]/2, Sin[Pi/30]/2, Sqrt[3]/2}}], 
   Line[{{Cos[Pi/15]/2, Sin[Pi/15]/2, Sqrt[3]/2}, {Sqrt[(5 + Sqrt[5])/2]/4, \
(-1 + Sqrt[5])/8, Sqrt[3]/2}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, (1 + Sqrt[5])/4}, {Cos[Pi/15]/2, Sin[Pi/15]/2, \
Sqrt[3]/2}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, \
{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}}], \
Line[{{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, Sqrt[3]/2}, {Sqrt[3]/4, 1/4, \
Sqrt[3]/2}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/4}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, Sqrt[3]/2}}], 
   Line[{{Sqrt[3]/4, 1/4, Sqrt[3]/2}, {(1 + Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/4, Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      (5 - Sqrt[5])/8, (1 + Sqrt[5])/4}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/4}, {Sqrt[3]/4, 1/4, Sqrt[3]/2}}], 
   Line[{{(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, \
{Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}}], 
   Line[{{Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, Sqrt[3]/2}, {Cos[(4*Pi)/15]/2, \
Sin[(4*Pi)/15]/2, Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, Sqrt[3]/2}}], \
Line[{{Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, Sqrt[3]/2}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, {(5 - Sqrt[5])/8, \
(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, Sqrt[3]/2}}], Line[{{Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, {1/4, Sqrt[3]/4, Sqrt[3]/2}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}, \
{(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      (1 + Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, \
Sqrt[3]/2}}], 
   Line[{{1/4, Sqrt[3]/4, Sqrt[3]/2}, {Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, \
Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (1 + Sqrt[5])/4}, {Sqrt[(5 - \
Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}, 
     {1/4, Sqrt[3]/4, Sqrt[3]/2}}], Line[{{Cos[(11*Pi)/30]/2, \
Sin[(11*Pi)/30]/2, Sqrt[3]/2}, {(-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, 
      Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, Sqrt[3]/2}}], Line[{{(-1 + \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {(-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}}], \
Line[{{Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, Sqrt[3]/2}, 
     {Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, Sqrt[3]/2}}], \
Line[{{Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, Sqrt[3]/2}, {0, 1/2, Sqrt[3]/2}, 
     {0, Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      (1 + Sqrt[5])/4}, {Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, Sqrt[3]/2}}], 
   Line[{{0, 1/2, Sqrt[3]/2}, {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, \
Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (1 + Sqrt[5])/4}, {0, Sqrt[(5 \
- Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, {0, 1/2, Sqrt[3]/2}}], 
   Line[{{Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, Sqrt[3]/2}, {Cos[(17*Pi)/30]/2, \
Sin[(17*Pi)/30]/2, Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, Sqrt[3]/2}}], \
Line[{{Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, Sqrt[3]/2}, 
     {(1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, Sqrt[3]/2}}], Line[{{(1 - \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {(1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}}], \
Line[{{Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, Sqrt[3]/2}, 
     {-1/4, Sqrt[3]/4, Sqrt[3]/2}, {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, Sqrt[3]/2}}], 
   Line[{{-1/4, Sqrt[3]/4, Sqrt[3]/2}, {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/8, Sqrt[3]/2}, 
     {(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
      (1 + Sqrt[5])/4}, {-1/4, Sqrt[3]/4, Sqrt[3]/2}}], Line[{{-Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      (1 + Sqrt[5])/4}, {(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, Sqrt[3]/2}}], \
Line[{{Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, Sqrt[3]/2}, 
     {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, Sqrt[3]/2}}], \
Line[{{Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, Sqrt[3]/2}, 
     {(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, Sqrt[3]/2}}], Line[{{(-1 - \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {-Sqrt[3]/4, 1/4, Sqrt[3]/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}}], 
   Line[{{-Sqrt[3]/4, 1/4, Sqrt[3]/2}, {Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, \
Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/4}, 
     {-Sqrt[3]/4, 1/4, Sqrt[3]/2}}], Line[{{Cos[(13*Pi)/15]/2, \
Sin[(13*Pi)/15]/2, Sqrt[3]/2}, {-Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, 
      Sqrt[3]/2}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, Sqrt[3]/2}}], Line[{{-Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      (1 + Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, Sqrt[3]/2}}], \
Line[{{Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, Sqrt[3]/2}, 
     {Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, Sqrt[3]/2}}], \
Line[{{Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, Sqrt[3]/2}, {-1/2, 0, \
Sqrt[3]/2}, 
     {-Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, Sqrt[3]/2}}], 
   Line[{{-1/2, 0, Sqrt[3]/2}, {Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, \
Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (1 + Sqrt[5])/4}, {-Sqrt[(5 \
- Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {-1/2, 0, Sqrt[3]/2}}], 
   Line[{{Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, Sqrt[3]/2}, \
{Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, Sqrt[3]/2}}], \
Line[{{Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, Sqrt[3]/2}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, Sqrt[3]/2}}], Line[{{-Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/15])/2, 
      (1 + Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}}], \
Line[{{Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, Sqrt[3]/2}, 
     {-Sqrt[3]/4, -1/4, Sqrt[3]/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, Sqrt[3]/2}}], 
   Line[{{-Sqrt[3]/4, -1/4, Sqrt[3]/2}, {(-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/4, Sqrt[3]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      (-5 + Sqrt[5])/8, (1 + Sqrt[5])/4}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/4}, 
     {-Sqrt[3]/4, -1/4, Sqrt[3]/2}}], Line[{{(-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(37*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + \
Sqrt[5])/8, (1 + Sqrt[5])/4}, 
     {(-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}}], \
Line[{{Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, Sqrt[3]/2}, 
     {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/15])/2, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, Sqrt[3]/2}}], \
Line[{{Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, Sqrt[3]/2}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, {(-5 + \
Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, Sqrt[3]/2}}], Line[{{-Sqrt[(5 - \
Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, 
     {-1/4, -Sqrt[3]/4, Sqrt[3]/2}, {-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}, 
     {(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}}], 
   Line[{{-1/4, -Sqrt[3]/4, Sqrt[3]/2}, {Cos[(41*Pi)/30]/2, \
Sin[(41*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (1 + Sqrt[5])/4}, {-Sqrt[(5 \
- Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}, 
     {-1/4, -Sqrt[3]/4, Sqrt[3]/2}}], Line[{{Cos[(41*Pi)/30]/2, \
Sin[(41*Pi)/30]/2, Sqrt[3]/2}, {(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, 
      Sqrt[3]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, Sqrt[3]/2}}], Line[{{(1 - \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(43*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}}], \
Line[{{Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, Sqrt[3]/2}, 
     {Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, Sqrt[3]/2}}], \
Line[{{Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, Sqrt[3]/2}, {0, -1/2, \
Sqrt[3]/2}, 
     {0, -Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
      (1 + Sqrt[5])/4}, {Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, Sqrt[3]/2}}], 
   Line[{{0, -1/2, Sqrt[3]/2}, {Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, \
Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (1 + Sqrt[5])/4}, {0, \
-Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, {0, -1/2, Sqrt[3]/2}}], 
   Line[{{Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, Sqrt[3]/2}, \
{Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, Sqrt[3]/2}}], \
Line[{{Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, Sqrt[3]/2}, 
     {(-1 + Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, Sqrt[3]/2}}], Line[{{(-1 + \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(49*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {(-1 + Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[3]/2}}], \
Line[{{Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, Sqrt[3]/2}, 
     {1/4, -Sqrt[3]/4, Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, Sqrt[3]/2}}], 
   Line[{{1/4, -Sqrt[3]/4, Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - \
Sqrt[5])/8, Sqrt[3]/2}, 
     {(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
      (1 + Sqrt[5])/4}, {1/4, -Sqrt[3]/4, Sqrt[3]/2}}], Line[{{Sqrt[(5 - \
Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(26*Pi)/15])/2, 
      (1 + Sqrt[5])/4}, {(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, Sqrt[3]/2}}], \
Line[{{Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, Sqrt[3]/2}, 
     {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(53*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, Sqrt[3]/2}}], \
Line[{{Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, Sqrt[3]/2}, 
     {(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, Sqrt[3]/2}}], Line[{{(1 + \
Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}, 
     {Sqrt[3]/4, -1/4, Sqrt[3]/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[3]/2}}], 
   Line[{{Sqrt[3]/4, -1/4, Sqrt[3]/2}, {Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, \
Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/4}, 
     {Sqrt[3]/4, -1/4, Sqrt[3]/2}}], Line[{{Cos[(28*Pi)/15]/2, \
Sin[(28*Pi)/15]/2, Sqrt[3]/2}, {Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, 
      Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, Sqrt[3]/2}}], Line[{{Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}, 
     {Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/15])/2, 
      (1 + Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, Sqrt[3]/2}}], \
Line[{{Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, Sqrt[3]/2}, 
     {Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, Sqrt[3]/2}}], \
Line[{{Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, Sqrt[3]/2}, {1/2, 0, Sqrt[3]/2}, \

     {Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      (1 + Sqrt[5])/4}, {Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, Sqrt[3]/2}}], 
   Line[{{Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
      (1 + Sqrt[5])/4}, {Cos[Pi/30]*Sin[(7*Pi)/30], \
Sin[Pi/30]*Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, {Sin[(7*Pi)/30], 0, \
Cos[(7*Pi)/30]}, 
     {Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[Pi/15]*Sin[(7*Pi)/30], Sin[Pi/15]*Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[Pi/30]*Sin[(7*Pi)/30], Sin[Pi/30]*Sin[(7*Pi)/30], 
      Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, (1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, (1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Cos[Pi/15]*Sin[(7*Pi)/30], Sin[Pi/15]*Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/15])/2, (1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(2*Pi)/15]*Sin[(7*Pi)/30], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/4}, \
{(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, 
     {Cos[(2*Pi)/15]*Sin[(7*Pi)/30], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (1 + Sqrt[5])/4}}], \
Line[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (1 + Sqrt[5])/4}, \
{Cos[(7*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]^2, Cos[(7*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(4*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]^2, 
      Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, \
{Cos[(4*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(7*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (1 + Sqrt[5])/4}}], 
   Line[{{(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
      (1 + Sqrt[5])/4}, {Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {(5 - Sqrt[5])/8, \
(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], 
      Cos[(7*Pi)/30]}, {Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}, {Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {Cos[(11*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(13*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(7*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(7*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(13*Pi)/30], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {0, Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, {0, Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      (1 + Sqrt[5])/4}}], Line[{{0, Sqrt[(5 - Sqrt[5])/2]/2, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(8*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/30]}, 
     {0, Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, {0, Sqrt[(5 - Sqrt[5])/2]/2, (1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(8*Pi)/15], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {Cos[(17*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (1 + Sqrt[5])/4}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {-Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \

     {Cos[(19*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      (1 + Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {-Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}}], 
   Line[{{(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], 
      Cos[(7*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(11*Pi)/15], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{Cos[(23*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(7*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (1 + Sqrt[5])/4}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, 
      (1 + Sqrt[5])/4}, {-(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, (1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(7*Pi)/30]}, {-(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Cos[(13*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(14*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(29*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(14*Pi)/15], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {-Sin[(7*Pi)/30], 0, \
Cos[(7*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(29*Pi)/30], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      (1 + Sqrt[5])/4}}], Line[{{-Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (1 + Sqrt[5])/4}, \
{Cos[(31*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(31*Pi)/30], 
      Cos[(7*Pi)/30]}, {-Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(16*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(31*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(31*Pi)/30], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(31*Pi)/30])/2, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Cos[(16*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}, 
     {Cos[(17*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, 
      (1 + Sqrt[5])/4}, {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, 
      (1 + Sqrt[5])/4}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
(-5 + Sqrt[5])/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(37*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(7*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-(Sqrt[(5 \
- Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(37*Pi)/30], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(37*Pi)/30])/2, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, \
{Cos[(19*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (1 + Sqrt[5])/4}}], 
   Line[{{(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
      (1 + Sqrt[5])/4}, {-Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {(-5 + Sqrt[5])/8, \
-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (1 + Sqrt[5])/4}, \
{Cos[(41*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(7*Pi)/30]}, {-Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}, {-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {Cos[(41*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (1 + Sqrt[5])/4}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(43*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-(Sqrt[(5 \
- Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(22*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(43*Pi)/30], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(43*Pi)/30])/2, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {0, -Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4}, {0, -Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(22*Pi)/15], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
      (1 + Sqrt[5])/4}}], Line[{{0, -Sqrt[(5 - Sqrt[5])/2]/2, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(23*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/15], 
      Cos[(7*Pi)/30]}, {0, -Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, {0, -Sqrt[(5 - \
Sqrt[5])/2]/2, (1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(47*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(23*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(23*Pi)/15], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/15])/2, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {Cos[(47*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(49*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \

     {Cos[(49*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + \
Sqrt[5])/4}, {(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      (1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, (1 + Sqrt[5])/4}}], 
   Line[{{(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(26*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(26*Pi)/15], 
      Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(53*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(26*Pi)/15], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(26*Pi)/15])/2, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{Cos[(53*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(53*Pi)/30], 
      Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + \
Sqrt[5])/4}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, 
      (1 + Sqrt[5])/4}, {(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}, {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, (1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (1 + Sqrt[5])/4}, \
{Cos[(28*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(7*Pi)/30]}, {(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, \
Cos[(7*Pi)/30]}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Cos[(28*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {Cos[(29*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Cos[(59*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(29*Pi)/15], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/15])/2, 
      (1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, \
(Sqrt[(5 - Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])/2]/2, 0, (1 + Sqrt[5])/4}, {Sin[(7*Pi)/30], 0, \
Cos[(7*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(59*Pi)/30], Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      (1 + Sqrt[5])/4}}], Line[{{Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}, \
{Cos[Pi/30]*Sin[(7*Pi)/30], Sin[Pi/30]*Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, 
     {Cos[Pi/30]*Sin[(4*Pi)/15], Sin[Pi/30]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, \
{Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, 
     {Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}}], Line[{{Cos[Pi/30]*Sin[(7*Pi)/30], \
Sin[Pi/30]*Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, 
     {Cos[Pi/15]*Sin[(7*Pi)/30], Sin[Pi/15]*Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[Pi/15]*Sin[(4*Pi)/15], Sin[Pi/15]*Sin[(4*Pi)/15], 
      Cos[(4*Pi)/15]}, {Cos[Pi/30]*Sin[(4*Pi)/15], Sin[Pi/30]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, 
     {Cos[Pi/30]*Sin[(7*Pi)/30], Sin[Pi/30]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}}], 
   Line[{{Cos[Pi/15]*Sin[(7*Pi)/30], Sin[Pi/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {Cos[Pi/15]*Sin[(4*Pi)/15], Sin[Pi/15]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, 
     {Cos[Pi/15]*Sin[(7*Pi)/30], Sin[Pi/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Cos[(2*Pi)/15]*Sin[(7*Pi)/30], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(7*Pi)/30], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}, {(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, 
      Cos[(7*Pi)/30]}, {(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, \
Cos[(4*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, \
{Cos[(2*Pi)/15]*Sin[(7*Pi)/30], Sin[(2*Pi)/15]*Sin[(7*Pi)/30], \
Cos[(7*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, {((1 \
+ Sqrt[5])*Sin[(7*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, \
Cos[(4*Pi)/15]}, {(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, 
      Cos[(7*Pi)/30]}}], Line[{{((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {Cos[(7*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]^2, Cos[(7*Pi)/30]}, \
{Cos[(7*Pi)/30]*Sin[(4*Pi)/15], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], 
      Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]^2, Cos[(7*Pi)/30]}, \
{Cos[(4*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], 
      Cos[(7*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]^2, \
Cos[(4*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(7*Pi)/30]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, \
{Cos[(7*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]^2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(4*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]^2, \
Cos[(4*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(4*Pi)/15], Cos[(7*Pi)/30]}}], Line[{{(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      Cos[(7*Pi)/30]}, {Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}, {Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}], 
   Line[{{Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], 
      Cos[(7*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(11*Pi)/30], Cos[(4*Pi)/15]}, 
     {Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, \
{Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(7*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(11*Pi)/30], Cos[(4*Pi)/15]}, 
     {Cos[(11*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(7*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {Cos[(13*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(13*Pi)/30], Cos[(4*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/30]}, \
{Cos[(7*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(4*Pi)/15]}, 
     {Cos[(13*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(13*Pi)/30], Cos[(7*Pi)/30]}}], \
Line[{{Cos[(7*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/30]}, 
     {0, Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, {0, Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(7*Pi)/15], 
      Cos[(4*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(7*Pi)/30], \
Sin[(7*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/30]}}], 
   Line[{{0, Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(7*Pi)/30], \
Sin[(7*Pi)/30]*Sin[(8*Pi)/15], Cos[(7*Pi)/30]}, 
     {Cos[(8*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(4*Pi)/15]}, {0, Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, 
     {0, Sin[(7*Pi)/30], Cos[(7*Pi)/30]}}], \
Line[{{Cos[(8*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/30]}, 
     {Cos[(17*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(17*Pi)/30], Cos[(4*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(4*Pi)/15]}, 
     {Cos[(8*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(17*Pi)/30], Cos[(4*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {Cos[(19*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(19*Pi)/30], Cos[(4*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/30]}, {-Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 
      Cos[(7*Pi)/30]}, {-Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, \
Cos[(4*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(19*Pi)/30], Cos[(4*Pi)/15]}, \
{Cos[(19*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/30]}}], 
   Line[{{-Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {-Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, \
Cos[(4*Pi)/15]}, {-Sin[(7*Pi)/30]/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 
      Cos[(7*Pi)/30]}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, \
((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Cos[(11*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(11*Pi)/15], Cos[(4*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(23*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(23*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(23*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(4*Pi)/15]}, 
     {Cos[(11*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(11*Pi)/15], Cos[(7*Pi)/30]}}], \
Line[{{Cos[(23*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(7*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {Cos[(23*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(23*Pi)/30], Cos[(7*Pi)/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{-(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(7*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(13*Pi)/15], Cos[(4*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, \
{-(Sqrt[3]*Sin[(7*Pi)/30])/2, Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(13*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(13*Pi)/15], Cos[(4*Pi)/15]}, 
     {Cos[(13*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(7*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Cos[(14*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(14*Pi)/15], Cos[(4*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(29*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(29*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(4*Pi)/15]}, 
     {Cos[(14*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(14*Pi)/15], Cos[(7*Pi)/30]}}], \
Line[{{Cos[(29*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(7*Pi)/30]}, 
     {-Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}, {-Sin[(4*Pi)/15], 0, \
Cos[(4*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(29*Pi)/30], 
      Cos[(4*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(7*Pi)/30], \
Sin[(7*Pi)/30]*Sin[(29*Pi)/30], Cos[(7*Pi)/30]}}], 
   Line[{{-Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/30]}, 
     {Cos[(31*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(4*Pi)/15]}, {-Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, 
     {-Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}}], \
Line[{{Cos[(31*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/30]}, 
     {Cos[(16*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(16*Pi)/15], Cos[(4*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(4*Pi)/15]}, 
     {Cos[(31*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(16*Pi)/15], Cos[(4*Pi)/15]}, 
     {Cos[(16*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(7*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Cos[(17*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(17*Pi)/15], Cos[(4*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/30]}, {-(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, 
      Cos[(7*Pi)/30]}, {-(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, \
Cos[(4*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(17*Pi)/15], Cos[(4*Pi)/15]}, \
{Cos[(17*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {-(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, \
Cos[(4*Pi)/15]}, {-(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, 
      Cos[(7*Pi)/30]}}], Line[{{-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {Cos[(37*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(37*Pi)/30], Cos[(4*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(37*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(19*Pi)/15], Cos[(7*Pi)/30]}, \
{Cos[(19*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(4*Pi)/15]}, 
     {Cos[(37*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(37*Pi)/30], Cos[(7*Pi)/30]}}], \
Line[{{Cos[(19*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {Cos[(19*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(19*Pi)/15], Cos[(7*Pi)/30]}}], Line[{{-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      Cos[(7*Pi)/30]}, {-Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, \
Cos[(7*Pi)/30]}, {-Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}], 
   Line[{{-Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(7*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(41*Pi)/30], Cos[(4*Pi)/15]}, 
     {-Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, \
{-Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(41*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(7*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(41*Pi)/30], Cos[(4*Pi)/15]}, 
     {Cos[(41*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(7*Pi)/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {Cos[(43*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(43*Pi)/30], Cos[(4*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(22*Pi)/15], Cos[(7*Pi)/30]}, \
{Cos[(22*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(4*Pi)/15]}, 
     {Cos[(43*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(43*Pi)/30], Cos[(7*Pi)/30]}}], \
Line[{{Cos[(22*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(7*Pi)/30]}, 
     {0, -Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, {0, -Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(22*Pi)/15], 
      Cos[(4*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(7*Pi)/30], \
Sin[(7*Pi)/30]*Sin[(22*Pi)/15], Cos[(7*Pi)/30]}}], 
   Line[{{0, -Sin[(7*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/30]}, 
     {Cos[(23*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(4*Pi)/15]}, {0, -Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, 
     {0, -Sin[(7*Pi)/30], Cos[(7*Pi)/30]}}], \
Line[{{Cos[(23*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/30]}, 
     {Cos[(47*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(47*Pi)/30], Cos[(4*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(4*Pi)/15]}, 
     {Cos[(23*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(7*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(47*Pi)/30], Cos[(4*Pi)/15]}, 
     {Cos[(47*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(7*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {Cos[(49*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(49*Pi)/30], Cos[(4*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/30]}, {Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, 
      Cos[(7*Pi)/30]}, {Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, \
Cos[(4*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(49*Pi)/30], Cos[(4*Pi)/15]}, \
{Cos[(49*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/30]}}], 
   Line[{{Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, \
Cos[(4*Pi)/15]}, {Sin[(7*Pi)/30]/2, -(Sqrt[3]*Sin[(7*Pi)/30])/2, 
      Cos[(7*Pi)/30]}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, \
-((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Cos[(26*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(26*Pi)/15], Cos[(4*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(53*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(53*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(4*Pi)/15]}, 
     {Cos[(26*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(26*Pi)/15], Cos[(7*Pi)/30]}}], \
Line[{{Cos[(53*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(7*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {Cos[(53*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(53*Pi)/30], Cos[(7*Pi)/30]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}, 
     {(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, Cos[(7*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(7*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(28*Pi)/15], Cos[(4*Pi)/15]}, 
     {(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, \
{(Sqrt[3]*Sin[(7*Pi)/30])/2, -Sin[(7*Pi)/30]/2, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(28*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(7*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(28*Pi)/15], Cos[(4*Pi)/15]}, 
     {Cos[(28*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(7*Pi)/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}, 
     {Cos[(29*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(29*Pi)/15], Cos[(4*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      Cos[(4*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, Cos[(7*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(7*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(59*Pi)/30], Cos[(7*Pi)/30]}, \
{Cos[(59*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(4*Pi)/15]}, 
     {Cos[(29*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(7*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(29*Pi)/15], Cos[(7*Pi)/30]}}], \
Line[{{Cos[(59*Pi)/30]*Sin[(7*Pi)/30], Sin[(7*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(7*Pi)/30]}, 
     {Sin[(7*Pi)/30], 0, Cos[(7*Pi)/30]}, {Sin[(4*Pi)/15], 0, \
Cos[(4*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(59*Pi)/30], 
      Cos[(4*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(7*Pi)/30], \
Sin[(7*Pi)/30]*Sin[(59*Pi)/30], Cos[(7*Pi)/30]}}], 
   Line[{{Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, {Cos[Pi/30]*Sin[(4*Pi)/15], \
Sin[Pi/30]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, 
     {((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 - \
Sqrt[5])/2]/2}, {(1 + Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}}], Line[{{Cos[Pi/30]*Sin[(4*Pi)/15], \
Sin[Pi/30]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, 
     {Cos[Pi/15]*Sin[(4*Pi)/15], Sin[Pi/15]*Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, \
{((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + \
Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[Pi/30]*Sin[(4*Pi)/15], Sin[Pi/30]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[Pi/15]*Sin[(4*Pi)/15], Sin[Pi/15]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[Pi/15]*Sin[(4*Pi)/15], Sin[Pi/15]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(4*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, \
((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(4*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, 
      Cos[(4*Pi)/15]}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(2*Pi)/15]*Sin[(4*Pi)/15], Sin[(2*Pi)/15]*Sin[(4*Pi)/15], 
      Cos[(4*Pi)/15]}}], Line[{{(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, \
Cos[(4*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*Sin[(4*Pi)/15])/2, \
Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {Cos[(7*Pi)/30]*Sin[(4*Pi)/15], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {(1 + \
Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(4*Pi)/15], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]^2, 
      Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(7*Pi)/30]*Sin[(4*Pi)/15], Sin[(7*Pi)/30]*Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(4*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]^2, Cos[(4*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(4*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]^2, Cos[(4*Pi)/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {(1 + \
Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}}], \
Line[{{Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {Cos[(11*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {(1 + \
Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(4*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(11*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(4*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {Cos[(13*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(7*Pi)/15], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(13*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(4*Pi)/15]}, {0, Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, 
     {0, (1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {Cos[(7*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{0, Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(8*Pi)/15], Cos[(4*Pi)/15]}, 
     {((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, {0, (1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {0, Sin[(4*Pi)/15], Cos[(4*Pi)/15]}}], \
Line[{{Cos[(8*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(4*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {Cos[(8*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(8*Pi)/15], Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(4*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(4*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(4*Pi)/15]}, {-Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(19*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], 
      Cos[(4*Pi)/15]}}], Line[{{-Sin[(4*Pi)/15]/2, \
(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{-Sin[(4*Pi)/15]/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {Cos[(11*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[(5 \
- Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, \
((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(23*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(11*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(23*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(4*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {-(1 + \
Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(23*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(4*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], \
Line[{{-(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, 
     {Cos[(13*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*Sin[(4*Pi)/15])/2, Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(13*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(4*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(13*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {Cos[(14*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, \
((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(29*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(14*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(4*Pi)/15]}, {-Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, 
     {(-1 - Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {Cos[(29*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(29*Pi)/30], Cos[(4*Pi)/15]}}], 
   Line[{{-Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(4*Pi)/15]}, 
     {((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(-1 - Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {-Sin[(4*Pi)/15], 0, \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(16*Pi)/15], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(31*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(4*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(16*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {Cos[(17*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, \
-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(4*Pi)/15]}, {-(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, 
      Cos[(4*Pi)/15]}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 \
- Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, \
{-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {-(1 + \
Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {Cos[(37*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-(1 + \
Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(37*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(19*Pi)/15], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(37*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(4*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(19*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {-Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {(-1 - \
Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, Sqrt[(5 \
- Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}}], \
Line[{{-Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {Cos[(41*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {(-1 - \
Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(41*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(4*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(41*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(4*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {Cos[(43*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
-(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(4*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(22*Pi)/15], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(43*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(4*Pi)/15]}, {0, -Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, 
     {0, (-1 - Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {Cos[(22*Pi)/15]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(22*Pi)/15], Cos[(4*Pi)/15]}}], 
   Line[{{0, -Sin[(4*Pi)/15], Cos[(4*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(4*Pi)/15]}, 
     {((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {0, (-1 - Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {0, -Sin[(4*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(47*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(23*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(4*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(47*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(4*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {Cos[(49*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(4*Pi)/15]}, {Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, 
      Cos[(4*Pi)/15]}, {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(49*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(49*Pi)/30], 
      Cos[(4*Pi)/15]}}], Line[{{Sin[(4*Pi)/15]/2, \
-(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{Sin[(4*Pi)/15]/2, -(Sqrt[3]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {Cos[(26*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[(5 \
- Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, \
-((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(53*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(26*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, {(1 + \
Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(53*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(4*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}, 
     {(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, Cos[(4*Pi)/15]}}], \
Line[{{(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}, 
     {Cos[(28*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Sin[(4*Pi)/15])/2, -Sin[(4*Pi)/15]/2, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(28*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(4*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(28*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}, 
     {Cos[(29*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(4*Pi)/15]}, {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, \
-((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(4*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(4*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(59*Pi)/30], Cos[(4*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(29*Pi)/15]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(4*Pi)/15]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(4*Pi)/15], Sin[(4*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(4*Pi)/15]}, {Sin[(4*Pi)/15], 0, Cos[(4*Pi)/15]}, 
     {(1 + Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {Cos[(59*Pi)/30]*Sin[(4*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(59*Pi)/30], Cos[(4*Pi)/15]}}], 
   Line[{{(1 + Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, 1/2}, {Sqrt[3]/2, 0, \
1/2}, {(1 + Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, Sqrt[(5 \
- Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, 1/2}, 
     {(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, 1/2}, {((1 + \
Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, Sqrt[(5 - \
Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 1/2}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{3/4, Sqrt[3]/4, 1/2}, 
     {(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 1/2}, {((1 + \
Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, {3/4, \
Sqrt[3]/4, 1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{(1 + Sqrt[5])^2/16, (Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, 
     {(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, \
Sqrt[(5 - Sqrt[5])/2]/2}, {(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {Sqrt[3]/4, 3/4, 1/2}, {Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - \
Sqrt[5])/2]/2}}], 
   Line[{{(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, 1/2}, 
     {Sqrt[3]/4, 3/4, 1/2}, {(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {0, (1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {0, Sqrt[3]/2, 1/2}, \
{(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{0, (1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[(8*Pi)/15])/2, \
(Sqrt[3]*Sin[(8*Pi)/15])/2, 1/2}, {0, Sqrt[3]/2, 1/2}, 
     {0, (1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + \
Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 1/2}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{-Sqrt[3]/4, 3/4, 1/2}, 
     {(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 1/2}, {((1 + \
Sqrt[5])*Cos[(19*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + \
Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, \
{-Sqrt[3]/4, 3/4, 1/2}, {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, Sqrt[(5 - \
Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{-3/4, Sqrt[3]/4, 1/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, {-(1 + \
Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 1/2}, {-3/4, \
Sqrt[3]/4, 1/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(-1 - Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {-Sqrt[3]/2, 0, 1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{(-1 - Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[(31*Pi)/30])/2, \
(Sqrt[3]*Sin[(31*Pi)/30])/2, 1/2}, {-Sqrt[3]/2, 0, 1/2}, 
     {(-1 - Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + \
Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(17*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{-3/4, -Sqrt[3]/4, 1/2}, 
     {(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, 1/2}, {((1 + \
Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, {-3/4, \
-Sqrt[3]/4, 1/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, 1/2}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, 
     {-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 \
- Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, Sqrt[(5 \
- Sqrt[5])/2]/2}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{-Sqrt[3]/4, -3/4, 1/2}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + \
Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, 1/2}, \
{-Sqrt[3]/4, -3/4, 1/2}, {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, 1/2}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(22*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {0, (-1 - Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {0, -Sqrt[3]/2, 1/2}, \
{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{0, (-1 - Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[(23*Pi)/15])/2, \
(Sqrt[3]*Sin[(23*Pi)/15])/2, 1/2}, {0, -Sqrt[3]/2, 1/2}, 
     {0, (-1 - Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + \
Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(49*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{Sqrt[3]/4, -3/4, 1/2}, 
     {(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, 1/2}, {((1 + \
Sqrt[5])*Cos[(49*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + \
Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, \
{Sqrt[3]/4, -3/4, 1/2}, {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, 1/2}, \
{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, Sqrt[(5 - \
Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, \
{3/4, -Sqrt[3]/4, 1/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, {(1 + \
Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, 1/2}, {3/4, \
-Sqrt[3]/4, 1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, 
      Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, 1/2}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(59*Pi)/30])/4, Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])/4, 0, Sqrt[(5 - Sqrt[5])/2]/2}, {Sqrt[3]/2, 0, 1/2}, \
{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, 1/2}, 
     {((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, \
Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{Sqrt[3]/2, 0, 1/2}, {(Sqrt[3]*Cos[Pi/30])/2, \
(Sqrt[3]*Sin[Pi/30])/2, 1/2}, {Cos[Pi/30]*Sin[(11*Pi)/30], \
Sin[Pi/30]*Sin[(11*Pi)/30], 
      Cos[(11*Pi)/30]}, {Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, {Sqrt[3]/2, 0, \
1/2}}], 
   Line[{{(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, 1/2}, \
{(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, 1/2}, 
     {Cos[Pi/15]*Sin[(11*Pi)/30], Sin[Pi/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[Pi/30]*Sin[(11*Pi)/30], Sin[Pi/30]*Sin[(11*Pi)/30], 
      Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, \
1/2}}], 
   Line[{{(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, 1/2}, {Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Cos[Pi/15]*Sin[(11*Pi)/30], Sin[Pi/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, 1/2}}], 
   Line[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 1/2}, 
     {Cos[(2*Pi)/15]*Sin[(11*Pi)/30], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 1/2}, {3/4, \
Sqrt[3]/4, 1/2}, {(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, 
      Cos[(11*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(2*Pi)/15]*Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 1/2}}], 
   Line[{{3/4, Sqrt[3]/4, 1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, 1/2}, {((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, 
     {3/4, Sqrt[3]/4, 1/2}}], Line[{{(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, 1/2}, 
     {(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 1/2}, \
{Cos[(7*Pi)/30]*Sin[(11*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], 
      Cos[(11*Pi)/30]}, {((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}}], \
Line[{{(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 1/2}, 
     {(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 1/2}, \
{Cos[(4*Pi)/15]*Sin[(11*Pi)/30], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], 
      Cos[(11*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(7*Pi)/30]*Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 1/2}}], \
Line[{{(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 1/2}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, {(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      Cos[(11*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(4*Pi)/15]*Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, 1/2}}], \
Line[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
     {Sqrt[3]/4, 3/4, 1/2}, {Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, \
Cos[(11*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}}], 
   Line[{{Sqrt[3]/4, 3/4, 1/2}, {(Sqrt[3]*Cos[(11*Pi)/30])/2, \
(Sqrt[3]*Sin[(11*Pi)/30])/2, 1/2}, 
     {Cos[(11*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]^2, Cos[(11*Pi)/30]}, \
{Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Sqrt[3]/4, 3/4, 1/2}}], Line[{{(Sqrt[3]*Cos[(11*Pi)/30])/2, \
(Sqrt[3]*Sin[(11*Pi)/30])/2, 1/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, {((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]^2, Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, 1/2}}], 
   Line[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 1/2}, 
     {Cos[(13*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(11*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 1/2}, 
     {Cos[(7*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(13*Pi)/30], Cos[(11*Pi)/30]}, \
{(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 1/2}, {0, \
Sqrt[3]/2, 1/2}, {0, Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
     {Cos[(7*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 
      1/2}}], Line[{{0, Sqrt[3]/2, 1/2}, {(Sqrt[3]*Cos[(8*Pi)/15])/2, \
(Sqrt[3]*Sin[(8*Pi)/15])/2, 1/2}, 
     {Cos[(8*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(11*Pi)/30]}, {0, Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
     {0, Sqrt[3]/2, 1/2}}], Line[{{(Sqrt[3]*Cos[(8*Pi)/15])/2, \
(Sqrt[3]*Sin[(8*Pi)/15])/2, 1/2}, 
     {(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 1/2}, \
{Cos[(17*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/30], 
      Cos[(11*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(8*Pi)/15], Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, 1/2}}], \
Line[{{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 1/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, {-((-1 \
+ Sqrt[5])*Sin[(11*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/30], 
      Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(17*Pi)/30])/2, \
(Sqrt[3]*Sin[(17*Pi)/30])/2, 1/2}}], 
   Line[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 1/2}, 
     {Cos[(19*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(11*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 1/2}, \
{-Sqrt[3]/4, 3/4, 1/2}, 
     {-Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Cos[(19*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], 
      Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(19*Pi)/30])/2, \
(Sqrt[3]*Sin[(19*Pi)/30])/2, 1/2}}], 
   Line[{{-Sqrt[3]/4, 3/4, 1/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + \
Sqrt[5]))/8, 1/2}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, \
{-Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {-Sqrt[3]/4, 3/4, 1/2}}], Line[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
     {(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 1/2}, \
{Cos[(11*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], 
      Cos[(11*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}}], \
Line[{{(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 1/2}, 
     {(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, 1/2}, \
{Cos[(23*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], 
      Cos[(11*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, 1/2}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, 
     {-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Cos[(23*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(23*Pi)/30])/2, 
      (Sqrt[3]*Sin[(23*Pi)/30])/2, 1/2}}], Line[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, \
Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, {-3/4, Sqrt[3]/4, 1/2}, 
     {-(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}}], 
   Line[{{-3/4, Sqrt[3]/4, 1/2}, {(Sqrt[3]*Cos[(13*Pi)/15])/2, \
(Sqrt[3]*Sin[(13*Pi)/15])/2, 1/2}, 
     {Cos[(13*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(11*Pi)/30]}, {-(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, 
      Cos[(11*Pi)/30]}, {-3/4, Sqrt[3]/4, 1/2}}], \
Line[{{(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 1/2}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 1/2}}], 
   Line[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 1/2}, 
     {Cos[(14*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {-Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, 1/2}, 
     {Cos[(29*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(14*Pi)/15], Cos[(11*Pi)/30]}, \
{(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, 1/2}, \
{-Sqrt[3]/2, 0, 1/2}, {-Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, 
     {Cos[(29*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(29*Pi)/30])/2, 
      (Sqrt[3]*Sin[(29*Pi)/30])/2, 1/2}}], Line[{{-Sqrt[3]/2, 0, 1/2}, \
{(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, 1/2}, 
     {Cos[(31*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(11*Pi)/30]}, {-Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, 
     {-Sqrt[3]/2, 0, 1/2}}], Line[{{(Sqrt[3]*Cos[(31*Pi)/30])/2, \
(Sqrt[3]*Sin[(31*Pi)/30])/2, 1/2}, 
     {(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, 1/2}, \
{Cos[(16*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(16*Pi)/15], 
      Cos[(11*Pi)/30]}, {Cos[(31*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(31*Pi)/30], Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Cos[(16*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(16*Pi)/15])/2, 
      (Sqrt[3]*Sin[(16*Pi)/15])/2, 1/2}}], Line[{{-Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, 
     {(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, 1/2}, \
{Cos[(17*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/15], 
      Cos[(11*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, 1/2}, \
{-3/4, -Sqrt[3]/4, 1/2}, 
     {-(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{Cos[(17*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/15], 
      Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(17*Pi)/15])/2, \
(Sqrt[3]*Sin[(17*Pi)/15])/2, 1/2}}], 
   Line[{{-3/4, -Sqrt[3]/4, 1/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, 1/2}, 
     {-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{-3/4, -Sqrt[3]/4, 1/2}}], 
   Line[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, 1/2}, 
     {Cos[(37*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(11*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, 1/2}, 
     {Cos[(19*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(37*Pi)/30], Cos[(11*Pi)/30]}, \
{(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, 1/2}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Cos[(19*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(19*Pi)/15])/2, 
      (Sqrt[3]*Sin[(19*Pi)/15])/2, 1/2}}], Line[{{-Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, {-Sqrt[3]/4, -3/4, 1/2}, 
     {-Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {-Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}}], 
   Line[{{-Sqrt[3]/4, -3/4, 1/2}, {(Sqrt[3]*Cos[(41*Pi)/30])/2, \
(Sqrt[3]*Sin[(41*Pi)/30])/2, 1/2}, 
     {Cos[(41*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(11*Pi)/30]}, {-Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, 
      Cos[(11*Pi)/30]}, {-Sqrt[3]/4, -3/4, 1/2}}], \
Line[{{(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, 1/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, {-((-1 \
+ Sqrt[5])*Sin[(11*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(41*Pi)/30])/2, \
(Sqrt[3]*Sin[(41*Pi)/30])/2, 1/2}}], 
   Line[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, \
{(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, 1/2}, 
     {Cos[(43*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, 1/2}, 
     {Cos[(22*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(43*Pi)/30], Cos[(11*Pi)/30]}, \
{(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, 1/2}, {0, \
-Sqrt[3]/2, 1/2}, {0, -Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
     {Cos[(22*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(22*Pi)/15])/2, 
      (Sqrt[3]*Sin[(22*Pi)/15])/2, 1/2}}], Line[{{0, -Sqrt[3]/2, 1/2}, \
{(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, 1/2}, 
     {Cos[(23*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(11*Pi)/30]}, {0, -Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
     {0, -Sqrt[3]/2, 1/2}}], Line[{{(Sqrt[3]*Cos[(23*Pi)/15])/2, \
(Sqrt[3]*Sin[(23*Pi)/15])/2, 1/2}, 
     {(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, 1/2}, \
{Cos[(47*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(47*Pi)/30], 
      Cos[(11*Pi)/30]}, {Cos[(23*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(23*Pi)/15], Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
     {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Cos[(47*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(47*Pi)/30])/2, 
      (Sqrt[3]*Sin[(47*Pi)/30])/2, 1/2}}], Line[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, \
-Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}, 
     {(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, 1/2}, \
{Cos[(49*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(49*Pi)/30], 
      Cos[(11*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, 1/2}, \
{Sqrt[3]/4, -3/4, 1/2}, 
     {Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Cos[(49*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(49*Pi)/30], 
      Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(49*Pi)/30])/2, \
(Sqrt[3]*Sin[(49*Pi)/30])/2, 1/2}}], 
   Line[{{Sqrt[3]/4, -3/4, 1/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + \
Sqrt[5]))/8, 1/2}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, \
{Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Sqrt[3]/4, -3/4, 1/2}}], Line[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
-(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}, 
     {(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, 1/2}, \
{Cos[(26*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(26*Pi)/15], 
      Cos[(11*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, 1/2}}], \
Line[{{(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, 1/2}, 
     {(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, 1/2}, \
{Cos[(53*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(53*Pi)/30], 
      Cos[(11*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(26*Pi)/15], Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, 1/2}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, 
     {((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Cos[(53*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(53*Pi)/30])/2, 
      (Sqrt[3]*Sin[(53*Pi)/30])/2, 1/2}}], Line[{{(Sqrt[3]*(1 + Sqrt[5]))/8, \
-Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}, {3/4, -Sqrt[3]/4, 1/2}, 
     {(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, {((1 \
+ Sqrt[5])*Sin[(11*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 1/2}}], 
   Line[{{3/4, -Sqrt[3]/4, 1/2}, {(Sqrt[3]*Cos[(28*Pi)/15])/2, \
(Sqrt[3]*Sin[(28*Pi)/15])/2, 1/2}, 
     {Cos[(28*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, 
      Cos[(11*Pi)/30]}, {3/4, -Sqrt[3]/4, 1/2}}], \
Line[{{(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, 1/2}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, 1/2}}], 
   Line[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, 1/2}, 
     {Cos[(29*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, 1/2}, \
{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, 1/2}, 
     {Cos[(59*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(29*Pi)/15], Cos[(11*Pi)/30]}, \
{(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, 1/2}}], 
   Line[{{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, 1/2}, \
{Sqrt[3]/2, 0, 1/2}, {Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, 
     {Cos[(59*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Cos[(59*Pi)/30])/2, 
      (Sqrt[3]*Sin[(59*Pi)/30])/2, 1/2}}], Line[{{Sin[(11*Pi)/30], 0, \
Cos[(11*Pi)/30]}, {Cos[Pi/30]*Sin[(11*Pi)/30], Sin[Pi/30]*Sin[(11*Pi)/30], 
      Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, (-1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {Sin[(11*Pi)/30], 0, \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[Pi/30]*Sin[(11*Pi)/30], Sin[Pi/30]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[Pi/15]*Sin[(11*Pi)/30], Sin[Pi/15]*Sin[(11*Pi)/30], 
      Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[Pi/30]*Sin[(11*Pi)/30], Sin[Pi/30]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[Pi/15]*Sin[(11*Pi)/30], Sin[Pi/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {(5 + Sqrt[5])/8, \
((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[Pi/15]*Sin[(11*Pi)/30], Sin[Pi/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Cos[(2*Pi)/15]*Sin[(11*Pi)/30], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(5 + \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(11*Pi)/30], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, 
      Cos[(11*Pi)/30]}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(2*Pi)/15]*Sin[(11*Pi)/30], Sin[(2*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      (-1 + Sqrt[5])/4}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/4}, 
     {(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Cos[(7*Pi)/30]*Sin[(11*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (-1 + Sqrt[5])/4}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      (-1 + Sqrt[5])/4}, {((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(11*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(11*Pi)/30], 
      Sin[(4*Pi)/15]*Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(7*Pi)/30]*Sin[(11*Pi)/30], Sin[(7*Pi)/30]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(4*Pi)/15]*Sin[(11*Pi)/30], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(4*Pi)/15]*Sin[(11*Pi)/30], Sin[(4*Pi)/15]*Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}], 
   Line[{{Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]^2, Cos[(11*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(11*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]^2, Cos[(11*Pi)/30]}, 
     {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]^2, Cos[(11*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Cos[(13*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (-1 + Sqrt[5])/4}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + Sqrt[5])/4}, 
     {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(11*Pi)/30]}, 
     {Cos[(7*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(Sqrt[(5 \
+ Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(7*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(7*Pi)/15], Cos[(11*Pi)/30]}, 
     {0, Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, {0, Sqrt[(5 + Sqrt[5])/2]/2, (-1 \
+ Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(7*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], 
      Cos[(11*Pi)/30]}}], Line[{{0, Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], 
      Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {0, Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {0, Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(8*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(17*Pi)/30], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(8*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(11*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Cos[(19*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (-1 + Sqrt[5])/4}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
      (-1 + Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(11*Pi)/30]}, {-Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, 
      Cos[(11*Pi)/30]}, {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{-Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      (-1 + Sqrt[5])/4}, {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (-1 + Sqrt[5])/4}, 
     {-Sin[(11*Pi)/30]/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Cos[(11*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (-1 + Sqrt[5])/4}, {-Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, 
      ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, {-(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(11*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/30]}, 
     {Cos[(23*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (-1 + Sqrt[5])/4}, {(Sqrt[(5 \
+ Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(23*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(23*Pi)/30], Cos[(11*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, 
      (-1 + Sqrt[5])/4}, {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
     {-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(11*Pi)/30])/2, Sin[(11*Pi)/30]/2, 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(13*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(13*Pi)/15], Cos[(11*Pi)/30]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(11*Pi)/30]}}], Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, \
((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Cos[(14*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(-5 - \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      (-1 + Sqrt[5])/4}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(29*Pi)/30], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(14*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/30]}, {-Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, 
     {-Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}, {Cos[(29*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(29*Pi)/30], Cos[(11*Pi)/30]}}], 
   Line[{{-Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(11*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {-Sin[(11*Pi)/30], 0, \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(16*Pi)/15], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(16*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(31*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {(-5 - \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(16*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Cos[(17*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(-5 - \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      (-1 + Sqrt[5])/4}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/30]}, {-(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, 
      Cos[(11*Pi)/30]}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, {-Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/4}, 
     {-(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Cos[(37*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (-1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(37*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(37*Pi)/30], Cos[(11*Pi)/30]}, 
     {Cos[(19*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(Sqrt[(5 \
+ Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(37*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(37*Pi)/30], 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(19*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(19*Pi)/15], Cos[(11*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {-Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
      (-1 + Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}], 
   Line[{{-Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {-Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(41*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(41*Pi)/30], Cos[(11*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(41*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(11*Pi)/30]}}], Line[{{-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, \
-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Cos[(43*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (-1 + Sqrt[5])/4}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
      (-1 + Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(22*Pi)/15], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(43*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/30]}, {0, -Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, 
     {0, -Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}, {Cos[(22*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(22*Pi)/15], Cos[(11*Pi)/30]}}], 
   Line[{{0, -Sin[(11*Pi)/30], Cos[(11*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(11*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {0, -Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {0, -Sin[(11*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(47*Pi)/30], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(47*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(47*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {Cos[(49*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (-1 + Sqrt[5])/4}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
      (-1 + Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/30]}, {Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, 
      Cos[(11*Pi)/30]}, {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(49*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      (-1 + Sqrt[5])/4}, {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (-1 + Sqrt[5])/4}, 
     {Sin[(11*Pi)/30]/2, -(Sqrt[3]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Cos[(26*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (-1 + Sqrt[5])/4}, {Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, 
      -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(26*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(26*Pi)/15], Cos[(11*Pi)/30]}, 
     {Cos[(53*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (-1 + Sqrt[5])/4}, {(Sqrt[(5 \
+ Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(26*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(26*Pi)/15], 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(53*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(53*Pi)/30], Cos[(11*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(53*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(11*Pi)/30]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}, 
     {(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, 
      (-1 + Sqrt[5])/4}, {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
     {((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, Cos[(11*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, Cos[(11*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(11*Pi)/30])/2, -Sin[(11*Pi)/30]/2, 
      Cos[(11*Pi)/30]}}], Line[{{Cos[(28*Pi)/15]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(28*Pi)/15], Cos[(11*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(28*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(11*Pi)/30]}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, \
-((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}, 
     {Cos[(29*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (-1 + Sqrt[5])/4}, {(5 + \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(11*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(59*Pi)/30], Cos[(11*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(29*Pi)/15]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/30]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(11*Pi)/30], Sin[(11*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/30]}, {Sin[(11*Pi)/30], 0, Cos[(11*Pi)/30]}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}, {Cos[(59*Pi)/30]*Sin[(11*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(59*Pi)/30], Cos[(11*Pi)/30]}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
      (-1 + Sqrt[5])/4}, {Cos[Pi/30]*Sin[(13*Pi)/30], \
Sin[Pi/30]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, {Sin[(13*Pi)/30], 0, \
Cos[(13*Pi)/30]}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
      (-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[Pi/15]*Sin[(13*Pi)/30], Sin[Pi/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[Pi/30]*Sin[(13*Pi)/30], Sin[Pi/30]*Sin[(13*Pi)/30], 
      Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, (-1 + Sqrt[5])/4}, 
     {(5 + Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, \
{Cos[Pi/15]*Sin[(13*Pi)/30], Sin[Pi/15]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{(5 + Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(2*Pi)/15]*Sin[(13*Pi)/30], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], 
      Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {(5 + Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}, 
     {Cos[(2*Pi)/15]*Sin[(13*Pi)/30], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, {((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      Cos[(13*Pi)/30]}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, 
      (-1 + Sqrt[5])/4}}], Line[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(7*Pi)/30]*Sin[(13*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(4*Pi)/15]*Sin[(13*Pi)/30], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Cos[(4*Pi)/15]*Sin[(13*Pi)/30], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/30]*Sin[(13*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], 
      Cos[(13*Pi)/30]}, {Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}, {Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(13*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], 
      Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(11*Pi)/30])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]^2, Cos[(13*Pi)/30]}, 
     {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(7*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]^2, 
      Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(13*Pi)/30])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {0, Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {0, Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(7*Pi)/15], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{0, Sqrt[(5 + Sqrt[5])/2]/2, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(8*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], 
      Cos[(13*Pi)/30]}, {0, Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, {0, Sqrt[(5 + \
Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(8*Pi)/15], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], 
      Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(17*Pi)/30])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(19*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], 
      Cos[(13*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, (-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {-Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 
      Cos[(13*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(19*Pi)/30], Cos[(13*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, {-(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      Cos[(13*Pi)/30]}, {-Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(11*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(13*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(11*Pi)/15], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
     {-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {Cos[(23*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, 
      Cos[(13*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(13*Pi)/30]}, {-(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
      Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}, {(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Cos[(13*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(14*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], 
      Cos[(13*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(29*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(14*Pi)/15], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {-Sin[(13*Pi)/30], 0, \
Cos[(13*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(29*Pi)/30], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{-Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(31*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(31*Pi)/30], 
      Cos[(13*Pi)/30]}, {-Sin[(13*Pi)/30], 0, Cos[(13*Pi)/30]}, {-Sqrt[(5 + \
Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(16*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(31*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(31*Pi)/30], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(31*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {(-5 - Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, \
{Cos[(16*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{(-5 - Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(17*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/15], 
      Cos[(13*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {(-5 - Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, 
      Cos[(13*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(17*Pi)/15], Cos[(13*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      Cos[(13*Pi)/30]}, {-(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}}], 
   Line[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(37*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(37*Pi)/30], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(37*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Cos[(19*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/15])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {-Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, 
      Cos[(13*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(41*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(13*Pi)/30]}, {-Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(41*Pi)/30])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(43*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(43*Pi)/30], 
      Cos[(13*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, (-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(22*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(43*Pi)/30], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {0, -Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}, {0, -Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(22*Pi)/15], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{0, -Sqrt[(5 + Sqrt[5])/2]/2, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(23*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/15], 
      Cos[(13*Pi)/30]}, {0, -Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, {0, -Sqrt[(5 \
+ Sqrt[5])/2]/2, (-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(47*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(23*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(23*Pi)/15], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Cos[(47*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(47*Pi)/30], 
      Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(47*Pi)/30])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (-1 + Sqrt[5])/4}, \
{Cos[(49*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(49*Pi)/30], 
      Cos[(13*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, (-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, 
      Cos[(13*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(49*Pi)/30], Cos[(13*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      Cos[(13*Pi)/30]}, {Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, \
Cos[(13*Pi)/30]}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, (-1 + \
Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(26*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(53*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(26*Pi)/15], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
     {((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {Cos[(53*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, 
      Cos[(13*Pi)/30]}, {((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, (-1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(28*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(13*Pi)/30]}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, \
Cos[(13*Pi)/30]}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, (-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(13*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, (-1 + Sqrt[5])/4}}], 
   Line[{{(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (-1 + Sqrt[5])/4}, \
{Cos[(29*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/15], 
      Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, (-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Cos[(59*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(29*Pi)/15], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(59*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, (-1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, 0, (-1 + Sqrt[5])/4}, {Sin[(13*Pi)/30], 0, \
Cos[(13*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(59*Pi)/30], Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      (-1 + Sqrt[5])/4}}], Line[{{Sin[(13*Pi)/30], 0, Cos[(13*Pi)/30]}, \
{Cos[Pi/30]*Sin[(13*Pi)/30], Sin[Pi/30]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, 
     {Cos[Pi/30]*Sin[(7*Pi)/15], Sin[Pi/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, \
{Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, 
     {Sin[(13*Pi)/30], 0, Cos[(13*Pi)/30]}}], \
Line[{{Cos[Pi/30]*Sin[(13*Pi)/30], Sin[Pi/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, 
     {Cos[Pi/15]*Sin[(13*Pi)/30], Sin[Pi/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[Pi/15]*Sin[(7*Pi)/15], Sin[Pi/15]*Sin[(7*Pi)/15], 
      Cos[(7*Pi)/15]}, {Cos[Pi/30]*Sin[(7*Pi)/15], Sin[Pi/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, 
     {Cos[Pi/30]*Sin[(13*Pi)/30], Sin[Pi/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{Cos[Pi/15]*Sin[(13*Pi)/30], Sin[Pi/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {Cos[Pi/15]*Sin[(7*Pi)/15], Sin[Pi/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, 
     {Cos[Pi/15]*Sin[(13*Pi)/30], Sin[Pi/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Cos[(2*Pi)/15]*Sin[(13*Pi)/30], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(13*Pi)/30], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, 
      Cos[(13*Pi)/30]}, {(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, \
Cos[(7*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(2*Pi)/15]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[(2*Pi)/15]*Sin[(13*Pi)/30], Sin[(2*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}, \
{((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, \
Cos[(7*Pi)/15]}, {(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, 
      Cos[(13*Pi)/30]}}], Line[{{((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {Cos[(7*Pi)/30]*Sin[(13*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(13*Pi)/30], Sin[(7*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(4*Pi)/15]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(4*Pi)/15]*Sin[(7*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, 
     {Cos[(7*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}}], \
Line[{{Cos[(4*Pi)/15]*Sin[(13*Pi)/30], Sin[(4*Pi)/15]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {Cos[(4*Pi)/15]*Sin[(7*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(4*Pi)/15]*Sin[(13*Pi)/30], Cos[(13*Pi)/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}], 
   Line[{{Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(13*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], 
      Cos[(13*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
     {Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[(13*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(11*Pi)/30]*Sin[(13*Pi)/30], Sin[(11*Pi)/30]*Sin[(13*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {Cos[(13*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]^2, Cos[(13*Pi)/30]}, \
{Cos[(13*Pi)/30]*Sin[(7*Pi)/15], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], 
      Cos[(7*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]^2, \
Cos[(13*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(7*Pi)/15], 
      Cos[(13*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]^2, \
Cos[(7*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(13*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[(13*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]^2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(7*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(13*Pi)/30]}, {0, Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, 
     {0, Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]^2, Cos[(7*Pi)/15]}, 
     {Cos[(7*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(13*Pi)/30]}}], 
   Line[{{0, Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(13*Pi)/30]}, 
     {Cos[(8*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/15]}, {0, Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
     {0, Sin[(13*Pi)/30], Cos[(13*Pi)/30]}}], \
Line[{{Cos[(8*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(13*Pi)/30]}, 
     {Cos[(17*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(17*Pi)/30], Cos[(7*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/15]}, 
     {Cos[(8*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(13*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(17*Pi)/30], Cos[(7*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {Cos[(19*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(19*Pi)/30], Cos[(7*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(13*Pi)/30]}, {-Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 
      Cos[(13*Pi)/30]}, {-Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, \
Cos[(7*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(19*Pi)/30], Cos[(7*Pi)/15]}, \
{Cos[(19*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{-Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {-Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, \
Cos[(7*Pi)/15]}, {-Sin[(13*Pi)/30]/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, 
      Cos[(13*Pi)/30]}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, \
((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Cos[(11*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(11*Pi)/15], Cos[(7*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(23*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(23*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(23*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(7*Pi)/15]}, 
     {Cos[(11*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(11*Pi)/15], Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(23*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(13*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(23*Pi)/30], Cos[(7*Pi)/15]}, 
     {Cos[(23*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}, \
{-(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(13*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(13*Pi)/15], Cos[(7*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{-(Sqrt[3]*Sin[(13*Pi)/30])/2, Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(13*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(13*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(13*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Cos[(14*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(14*Pi)/15], Cos[(7*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(29*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(29*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(7*Pi)/15]}, 
     {Cos[(14*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(14*Pi)/15], Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/30]}, {-Sin[(13*Pi)/30], 0, Cos[(13*Pi)/30]}, 
     {-Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(29*Pi)/30], Cos[(7*Pi)/15]}, 
     {Cos[(29*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{-Sin[(13*Pi)/30], 0, Cos[(13*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(13*Pi)/30]}, 
     {Cos[(31*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/15]}, {-Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, 
     {-Sin[(13*Pi)/30], 0, Cos[(13*Pi)/30]}}], \
Line[{{Cos[(31*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(13*Pi)/30]}, 
     {Cos[(16*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(16*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/15]}, 
     {Cos[(31*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(16*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(16*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Cos[(17*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(17*Pi)/15], Cos[(7*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(13*Pi)/30]}, {-(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, 
      Cos[(13*Pi)/30]}, {-(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, \
Cos[(7*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(17*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[(17*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(13*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}, \
{-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {-(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, \
Cos[(7*Pi)/15]}, {-(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, 
      Cos[(13*Pi)/30]}}], Line[{{-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {Cos[(37*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(37*Pi)/30], Cos[(7*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(37*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(19*Pi)/15], Cos[(13*Pi)/30]}, \
{Cos[(19*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/15]}, 
     {Cos[(37*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(37*Pi)/30], Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(19*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(19*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {-Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{-Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}], 
   Line[{{-Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(13*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(41*Pi)/30], Cos[(7*Pi)/15]}, 
     {-Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{-Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(41*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(13*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{Cos[(41*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(41*Pi)/30], 
      Cos[(7*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(13*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(41*Pi)/30], Cos[(13*Pi)/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {Cos[(43*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(43*Pi)/30], Cos[(7*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(22*Pi)/15], Cos[(13*Pi)/30]}, \
{Cos[(22*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(7*Pi)/15]}, 
     {Cos[(43*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(43*Pi)/30], Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/30]}, {0, -Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, 
     {0, -Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(22*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(22*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/30]}}], 
   Line[{{0, -Sin[(13*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(13*Pi)/30]}, 
     {Cos[(23*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/15]}, {0, -Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
     {0, -Sin[(13*Pi)/30], Cos[(13*Pi)/30]}}], \
Line[{{Cos[(23*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(13*Pi)/30]}, 
     {Cos[(47*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(47*Pi)/30], Cos[(7*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/15]}, 
     {Cos[(23*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(47*Pi)/30], Cos[(7*Pi)/15]}, 
     {Cos[(47*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {Cos[(49*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(13*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(49*Pi)/30], Cos[(7*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(13*Pi)/30]}, {Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, 
      Cos[(13*Pi)/30]}, {Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, \
Cos[(7*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(49*Pi)/30], Cos[(7*Pi)/15]}, \
{Cos[(49*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, \
Cos[(7*Pi)/15]}, {Sin[(13*Pi)/30]/2, -(Sqrt[3]*Sin[(13*Pi)/30])/2, 
      Cos[(13*Pi)/30]}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, \
-((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Cos[(26*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(26*Pi)/15], Cos[(7*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(53*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(53*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(7*Pi)/15]}, 
     {Cos[(26*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(26*Pi)/15], Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/30]}, {((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(53*Pi)/30], Cos[(7*Pi)/15]}, 
     {Cos[(53*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}, 
     {(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}, \
{(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, Cos[(13*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(13*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(28*Pi)/15], Cos[(7*Pi)/15]}, 
     {(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{(Sqrt[3]*Sin[(13*Pi)/30])/2, -Sin[(13*Pi)/30]/2, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(28*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(13*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(28*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(28*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(13*Pi)/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}, 
     {Cos[(29*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(29*Pi)/15], Cos[(7*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/30])/4, Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(13*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(59*Pi)/30], Cos[(13*Pi)/30]}, \
{Cos[(59*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(7*Pi)/15]}, 
     {Cos[(29*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(13*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(29*Pi)/15], Cos[(13*Pi)/30]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/30]}, {Sin[(13*Pi)/30], 0, Cos[(13*Pi)/30]}, 
     {Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(59*Pi)/30], Cos[(7*Pi)/15]}, 
     {Cos[(59*Pi)/30]*Sin[(13*Pi)/30], Sin[(13*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/30]}}], 
   Line[{{Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, {Cos[Pi/30]*Sin[(7*Pi)/15], \
Sin[Pi/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {Cos[Pi/30], Sin[Pi/30], 0}, 
     {1, 0, 0}, {Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}}], \
Line[{{Cos[Pi/30]*Sin[(7*Pi)/15], Sin[Pi/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, \

     {Cos[Pi/15]*Sin[(7*Pi)/15], Sin[Pi/15]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[Pi/15], Sin[Pi/15], 0}, {Cos[Pi/30], Sin[Pi/30], 0}, 
     {Cos[Pi/30]*Sin[(7*Pi)/15], Sin[Pi/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}}], 
   Line[{{Cos[Pi/15]*Sin[(7*Pi)/15], Sin[Pi/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, {Cos[Pi/15], Sin[Pi/15], 0}, 
     {Cos[Pi/15]*Sin[(7*Pi)/15], Sin[Pi/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(7*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(2*Pi)/15], Sin[(2*Pi)/15], 0}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(2*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
     {(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{Sqrt[3]/2, 1/2, 0}, {Cos[(2*Pi)/15], Sin[(2*Pi)/15], 0}, 
     {Cos[(2*Pi)/15]*Sin[(7*Pi)/15], Sin[(2*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, {((1 \
+ Sqrt[5])*Sin[(7*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {(1 + \
Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, {Sqrt[3]/2, 1/2, 0}, 
     {(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {Cos[(7*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(7*Pi)/30], Sin[(7*Pi)/30], 0}, 
     {(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, {((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(7*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(4*Pi)/15]*Sin[(7*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(4*Pi)/15], Sin[(4*Pi)/15], 0}, 
     {Cos[(7*Pi)/30], Sin[(7*Pi)/30], 0}, {Cos[(7*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(4*Pi)/15]*Sin[(7*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {Sqrt[(5 - \
Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}, {Cos[(4*Pi)/15], Sin[(4*Pi)/15], 0}, 
     {Cos[(4*Pi)/15]*Sin[(7*Pi)/15], Sin[(4*Pi)/15]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {1/2, \
Sqrt[3]/2, 0}, {Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}}], 
   Line[{{Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(7*Pi)/15], Sin[(11*Pi)/30]*Sin[(7*Pi)/15], 
      Cos[(7*Pi)/15]}, {Cos[(11*Pi)/30], Sin[(11*Pi)/30], 0}, {1/2, \
Sqrt[3]/2, 0}, {Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(11*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
     {((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {(-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}, {Cos[(11*Pi)/30], \
Sin[(11*Pi)/30], 0}, {Cos[(11*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(11*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {Cos[(13*Pi)/30]*Sin[(7*Pi)/15], Sin[(13*Pi)/30]*Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(13*Pi)/30], Sin[(13*Pi)/30], 0}, 
     {(-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}, {((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(13*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(13*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(7*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]^2, Cos[(7*Pi)/15]}, \
{Cos[(7*Pi)/15], Sin[(7*Pi)/15], 0}, 
     {Cos[(13*Pi)/30], Sin[(13*Pi)/30], 0}, {Cos[(13*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(13*Pi)/30]*Sin[(7*Pi)/15], Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]^2, Cos[(7*Pi)/15]}, \
{0, Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {0, 1, 0}, 
     {Cos[(7*Pi)/15], Sin[(7*Pi)/15], 0}, {Cos[(7*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]^2, Cos[(7*Pi)/15]}}], 
   Line[{{0, Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(8*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(8*Pi)/15], Sin[(8*Pi)/15], 0}, {0, 1, 0}, {0, Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(8*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(17*Pi)/30], Cos[(7*Pi)/15]}, {Cos[(17*Pi)/30], \
Sin[(17*Pi)/30], 0}, {Cos[(8*Pi)/15], Sin[(8*Pi)/15], 0}, 
     {Cos[(8*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(7*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {-(-1 + \
Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
     {Cos[(17*Pi)/30], Sin[(17*Pi)/30], 0}, {Cos[(17*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(17*Pi)/30], Cos[(7*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(19*Pi)/30], Sin[(19*Pi)/30], 0}, 
     {-(-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}, {-((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(19*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(19*Pi)/30], Cos[(7*Pi)/15]}, 
     {-Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {-1/2, \
Sqrt[3]/2, 0}, {Cos[(19*Pi)/30], Sin[(19*Pi)/30], 0}, 
     {Cos[(19*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(7*Pi)/15]}}], 
   Line[{{-Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {-Sqrt[(5 - \
Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}, {-1/2, Sqrt[3]/2, 0}, 
     {-Sin[(7*Pi)/15]/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {Cos[(11*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(11*Pi)/15], Sin[(11*Pi)/15], 0}, 
     {-Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(11*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(11*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(23*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(23*Pi)/30], Sin[(23*Pi)/30], 0}, 
     {Cos[(11*Pi)/15], Sin[(11*Pi)/15], 0}, {Cos[(11*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(11*Pi)/15], Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(23*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(7*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {-(1 + \
Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, 
     {Cos[(23*Pi)/30], Sin[(23*Pi)/30], 0}, {Cos[(23*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(23*Pi)/30], Cos[(7*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{-Sqrt[3]/2, 1/2, 0}, {-(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, 
     {-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], 
      Cos[(7*Pi)/15]}, {Cos[(13*Pi)/15], Sin[(13*Pi)/15], 0}, {-Sqrt[3]/2, \
1/2, 0}, {-(Sqrt[3]*Sin[(7*Pi)/15])/2, Sin[(7*Pi)/15]/2, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(13*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(13*Pi)/15], Cos[(7*Pi)/15]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {-Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, {Cos[(13*Pi)/15], \
Sin[(13*Pi)/15], 0}, {Cos[(13*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(13*Pi)/15], Cos[(7*Pi)/15]}}], Line[{{-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(14*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(14*Pi)/15], \
Sin[(14*Pi)/15], 0}, 
     {-Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(14*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(14*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(29*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(29*Pi)/30], Sin[(29*Pi)/30], 0}, 
     {Cos[(14*Pi)/15], Sin[(14*Pi)/15], 0}, {Cos[(14*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(14*Pi)/15], Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(7*Pi)/15]}, {-Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, {-1, 0, 0}, 
     {Cos[(29*Pi)/30], Sin[(29*Pi)/30], 0}, {Cos[(29*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(29*Pi)/30], Cos[(7*Pi)/15]}}], 
   Line[{{-Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/15]}, 
     {Cos[(31*Pi)/30], Sin[(31*Pi)/30], 0}, {-1, 0, 0}, {-Sin[(7*Pi)/15], 0, \
Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(16*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(16*Pi)/15], \
Sin[(16*Pi)/15], 0}, {Cos[(31*Pi)/30], Sin[(31*Pi)/30], 0}, 
     {Cos[(31*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(7*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, 
     {Cos[(16*Pi)/15], Sin[(16*Pi)/15], 0}, {Cos[(16*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(16*Pi)/15], Cos[(7*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {Cos[(17*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(17*Pi)/15], Sin[(17*Pi)/15], 0}, 
     {-Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(17*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(17*Pi)/15], Cos[(7*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{-Sqrt[3]/2, -1/2, 0}, {Cos[(17*Pi)/15], Sin[(17*Pi)/15], 0}, 
     {Cos[(17*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(7*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {-(1 + \
Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}, {-Sqrt[3]/2, -1/2, 0}, 
     {-(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {Cos[(37*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(37*Pi)/30], Sin[(37*Pi)/30], 0}, 
     {-(1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}, {-((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(37*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(37*Pi)/30], Cos[(7*Pi)/15]}, 
     {Cos[(19*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(19*Pi)/15], Sin[(19*Pi)/15], 0}, 
     {Cos[(37*Pi)/30], Sin[(37*Pi)/30], 0}, {Cos[(37*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(37*Pi)/30], Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {-Sqrt[(5 - \
Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, {Cos[(19*Pi)/15], Sin[(19*Pi)/15], 0}, 
     {Cos[(19*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(7*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {-Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {-1/2, \
-Sqrt[3]/2, 0}, {-Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}}], 
   Line[{{-Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{Cos[(41*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(41*Pi)/30], 
      Cos[(7*Pi)/15]}, {Cos[(41*Pi)/30], Sin[(41*Pi)/30], 0}, {-1/2, \
-Sqrt[3]/2, 0}, {-Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(41*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(41*Pi)/30], Cos[(7*Pi)/15]}, 
     {-((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {-(-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, {Cos[(41*Pi)/30], \
Sin[(41*Pi)/30], 0}, 
     {Cos[(41*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(7*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {Cos[(43*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(43*Pi)/30], Sin[(43*Pi)/30], 0}, 
     {-(-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, {-((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(43*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(43*Pi)/30], Cos[(7*Pi)/15]}, 
     {Cos[(22*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(22*Pi)/15], Sin[(22*Pi)/15], 0}, 
     {Cos[(43*Pi)/30], Sin[(43*Pi)/30], 0}, {Cos[(43*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(43*Pi)/30], Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(7*Pi)/15]}, {0, -Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, {0, -1, 0}, 
     {Cos[(22*Pi)/15], Sin[(22*Pi)/15], 0}, {Cos[(22*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(22*Pi)/15], Cos[(7*Pi)/15]}}], 
   Line[{{0, -Sin[(7*Pi)/15], Cos[(7*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/15]}, 
     {Cos[(23*Pi)/15], Sin[(23*Pi)/15], 0}, {0, -1, 0}, {0, -Sin[(7*Pi)/15], \
Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(47*Pi)/30], Cos[(7*Pi)/15]}, {Cos[(47*Pi)/30], \
Sin[(47*Pi)/30], 0}, {Cos[(23*Pi)/15], Sin[(23*Pi)/15], 0}, 
     {Cos[(23*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(7*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {(-1 + \
Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
     {Cos[(47*Pi)/30], Sin[(47*Pi)/30], 0}, {Cos[(47*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(47*Pi)/30], Cos[(7*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {Cos[(49*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(49*Pi)/30], Sin[(49*Pi)/30], 0}, 
     {(-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, {((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(49*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(49*Pi)/30], Cos[(7*Pi)/15]}, 
     {Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {1/2, \
-Sqrt[3]/2, 0}, {Cos[(49*Pi)/30], Sin[(49*Pi)/30], 0}, 
     {Cos[(49*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(7*Pi)/15]}}], 
   Line[{{Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, {Sqrt[(5 - \
Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, {1/2, -Sqrt[3]/2, 0}, 
     {Sin[(7*Pi)/15]/2, -(Sqrt[3]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {Cos[(26*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(7*Pi)/15]}, {Cos[(26*Pi)/15], Sin[(26*Pi)/15], 0}, 
     {Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(26*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(26*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(53*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(53*Pi)/30], Sin[(53*Pi)/30], 0}, 
     {Cos[(26*Pi)/15], Sin[(26*Pi)/15], 0}, {Cos[(26*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(26*Pi)/15], Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(7*Pi)/15]}, {((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, {(1 + \
Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}, 
     {Cos[(53*Pi)/30], Sin[(53*Pi)/30], 0}, {Cos[(53*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(53*Pi)/30], Cos[(7*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}, 
     {(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{Sqrt[3]/2, -1/2, 0}, {(1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}, 
     {((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, Cos[(7*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, Cos[(7*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(28*Pi)/15], 
      Cos[(7*Pi)/15]}, {Cos[(28*Pi)/15], Sin[(28*Pi)/15], 0}, {Sqrt[3]/2, \
-1/2, 0}, {(Sqrt[3]*Sin[(7*Pi)/15])/2, -Sin[(7*Pi)/15]/2, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(28*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(28*Pi)/15], Cos[(7*Pi)/15]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(7*Pi)/15])/4, Cos[(7*Pi)/15]}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, {Cos[(28*Pi)/15], \
Sin[(28*Pi)/15], 0}, {Cos[(28*Pi)/15]*Sin[(7*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(28*Pi)/15], Cos[(7*Pi)/15]}}], Line[{{(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(29*Pi)/15], Cos[(7*Pi)/15]}, {Cos[(29*Pi)/15], \
Sin[(29*Pi)/15], 0}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      Cos[(7*Pi)/15]}}], Line[{{Cos[(29*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(29*Pi)/15], Cos[(7*Pi)/15]}, 
     {Cos[(59*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(7*Pi)/15]}, {Cos[(59*Pi)/30], Sin[(59*Pi)/30], 0}, 
     {Cos[(29*Pi)/15], Sin[(29*Pi)/15], 0}, {Cos[(29*Pi)/15]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(29*Pi)/15], Cos[(7*Pi)/15]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(7*Pi)/15], Sin[(7*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(7*Pi)/15]}, {Sin[(7*Pi)/15], 0, Cos[(7*Pi)/15]}, {1, 0, 0}, 
     {Cos[(59*Pi)/30], Sin[(59*Pi)/30], 0}, {Cos[(59*Pi)/30]*Sin[(7*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(59*Pi)/30], Cos[(7*Pi)/15]}}], 
   Line[{{1, 0, 0}, {Cos[Pi/30], Sin[Pi/30], 0}, {Cos[Pi/30]*Sin[(8*Pi)/15], \
Sin[Pi/30]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
     {Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, {1, 0, 0}}], Line[{{Cos[Pi/30], \
Sin[Pi/30], 0}, {Cos[Pi/15], Sin[Pi/15], 0}, 
     {Cos[Pi/15]*Sin[(8*Pi)/15], Sin[Pi/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[Pi/30]*Sin[(8*Pi)/15], Sin[Pi/30]*Sin[(8*Pi)/15], 
      Cos[(8*Pi)/15]}, {Cos[Pi/30], Sin[Pi/30], 0}}], Line[{{Cos[Pi/15], \
Sin[Pi/15], 0}, {Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[Pi/15]*Sin[(8*Pi)/15], Sin[Pi/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[Pi/15], Sin[Pi/15], 0}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, {Cos[(2*Pi)/15], \
Sin[(2*Pi)/15], 0}, 
     {Cos[(2*Pi)/15]*Sin[(8*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}}], 
   Line[{{Cos[(2*Pi)/15], Sin[(2*Pi)/15], 0}, {Sqrt[3]/2, 1/2, 0}, \
{(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(8*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(2*Pi)/15], Sin[(2*Pi)/15], 0}}], 
   Line[{{Sqrt[3]/2, 1/2, 0}, {(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, \
{((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, 
     {Sqrt[3]/2, 1/2, 0}}], Line[{{(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, \
0}, {Cos[(7*Pi)/30], Sin[(7*Pi)/30], 0}, 
     {Cos[(7*Pi)/30]*Sin[(8*Pi)/15], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {(1 + \
Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}}], 
   Line[{{Cos[(7*Pi)/30], Sin[(7*Pi)/30], 0}, {Cos[(4*Pi)/15], \
Sin[(4*Pi)/15], 0}, {Cos[(4*Pi)/15]*Sin[(8*Pi)/15], \
Sin[(4*Pi)/15]*Sin[(8*Pi)/15], 
      Cos[(8*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(8*Pi)/15], \
Sin[(7*Pi)/30]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, {Cos[(7*Pi)/30], \
Sin[(7*Pi)/30], 0}}], 
   Line[{{Cos[(4*Pi)/15], Sin[(4*Pi)/15], 0}, {Sqrt[(5 - Sqrt[5])/2]/2, (1 + \
Sqrt[5])/4, 0}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, \
{Cos[(4*Pi)/15]*Sin[(8*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {Cos[(4*Pi)/15], Sin[(4*Pi)/15], 0}}], Line[{{Sqrt[(5 - Sqrt[5])/2]/2, \
(1 + Sqrt[5])/4, 0}, {1/2, Sqrt[3]/2, 0}, 
     {Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      Cos[(8*Pi)/15]}, {Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}}], 
   Line[{{1/2, Sqrt[3]/2, 0}, {Cos[(11*Pi)/30], Sin[(11*Pi)/30], 0}, \
{Cos[(11*Pi)/30]*Sin[(8*Pi)/15], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], 
      Cos[(8*Pi)/15]}, {Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, \
Cos[(8*Pi)/15]}, {1/2, Sqrt[3]/2, 0}}], 
   Line[{{Cos[(11*Pi)/30], Sin[(11*Pi)/30], 0}, {(-1 + Sqrt[5])/4, Sqrt[(5 + \
Sqrt[5])/2]/2, 0}, 
     {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(11*Pi)/30]*Sin[(8*Pi)/15], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(11*Pi)/30], Sin[(11*Pi)/30], 0}}], 
   Line[{{(-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}, {Cos[(13*Pi)/30], \
Sin[(13*Pi)/30], 0}, 
     {Cos[(13*Pi)/30]*Sin[(8*Pi)/15], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {(-1 + \
Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}}], 
   Line[{{Cos[(13*Pi)/30], Sin[(13*Pi)/30], 0}, {Cos[(7*Pi)/15], \
Sin[(7*Pi)/15], 0}, {Cos[(7*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(13*Pi)/30]*Sin[(8*Pi)/15], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {Cos[(13*Pi)/30], Sin[(13*Pi)/30], 0}}], Line[{{Cos[(7*Pi)/15], \
Sin[(7*Pi)/15], 0}, {0, 1, 0}, {0, Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
     {Cos[(7*Pi)/15]*Sin[(8*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(7*Pi)/15], Sin[(7*Pi)/15], 0}}], 
   Line[{{0, 1, 0}, {Cos[(8*Pi)/15], Sin[(8*Pi)/15], 0}, \
{Cos[(8*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]^2, Cos[(8*Pi)/15]}, 
     {0, Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, {0, 1, 0}}], Line[{{Cos[(8*Pi)/15], \
Sin[(8*Pi)/15], 0}, {Cos[(17*Pi)/30], Sin[(17*Pi)/30], 0}, 
     {Cos[(17*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]^2, 
      Cos[(8*Pi)/15]}, {Cos[(8*Pi)/15], Sin[(8*Pi)/15], 0}}], 
   Line[{{Cos[(17*Pi)/30], Sin[(17*Pi)/30], 0}, {-(-1 + Sqrt[5])/4, Sqrt[(5 + \
Sqrt[5])/2]/2, 0}, 
     {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(17*Pi)/30], Sin[(17*Pi)/30], 0}}], 
   Line[{{-(-1 + Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}, {Cos[(19*Pi)/30], \
Sin[(19*Pi)/30], 0}, 
     {Cos[(19*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(8*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-(-1 + \
Sqrt[5])/4, Sqrt[(5 + Sqrt[5])/2]/2, 0}}], 
   Line[{{Cos[(19*Pi)/30], Sin[(19*Pi)/30], 0}, {-1/2, Sqrt[3]/2, 0}, \
{-Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(19*Pi)/30], Sin[(19*Pi)/30], 0}}], 
   Line[{{-1/2, Sqrt[3]/2, 0}, {-Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4, \
0}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-Sin[(8*Pi)/15]/2, \
(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-1/2, Sqrt[3]/2, 0}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}, {Cos[(11*Pi)/15], \
Sin[(11*Pi)/15], 0}, 
     {Cos[(11*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-Sqrt[(5 - \
Sqrt[5])/2]/2, (1 + Sqrt[5])/4, 0}}], 
   Line[{{Cos[(11*Pi)/15], Sin[(11*Pi)/15], 0}, {Cos[(23*Pi)/30], \
Sin[(23*Pi)/30], 0}, {Cos[(23*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(23*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(11*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {Cos[(11*Pi)/15], Sin[(11*Pi)/15], 0}}], Line[{{Cos[(23*Pi)/30], \
Sin[(23*Pi)/30], 0}, {-(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, 
     {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(23*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(23*Pi)/30], Sin[(23*Pi)/30], 0}}], 
   Line[{{-(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}, {-Sqrt[3]/2, 1/2, \
0}, {-(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {-(1 + Sqrt[5])/4, Sqrt[(5 - Sqrt[5])/2]/2, 0}}], Line[{{-Sqrt[3]/2, \
1/2, 0}, {Cos[(13*Pi)/15], Sin[(13*Pi)/15], 0}, 
     {Cos[(13*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, 
      Cos[(8*Pi)/15]}, {-Sqrt[3]/2, 1/2, 0}}], Line[{{Cos[(13*Pi)/15], \
Sin[(13*Pi)/15], 0}, {-Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[(13*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(13*Pi)/15], Sin[(13*Pi)/15], 0}}], 
   Line[{{-Sqrt[(5 + Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}, {Cos[(14*Pi)/15], \
Sin[(14*Pi)/15], 0}, 
     {Cos[(14*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/2, (-1 + Sqrt[5])/4, 0}}], 
   Line[{{Cos[(14*Pi)/15], Sin[(14*Pi)/15], 0}, {Cos[(29*Pi)/30], \
Sin[(29*Pi)/30], 0}, {Cos[(29*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(29*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(14*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {Cos[(14*Pi)/15], Sin[(14*Pi)/15], 0}}], Line[{{Cos[(29*Pi)/30], \
Sin[(29*Pi)/30], 0}, {-1, 0, 0}, {-Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, 
     {Cos[(29*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(29*Pi)/30], Sin[(29*Pi)/30], 0}}], 
   Line[{{-1, 0, 0}, {Cos[(31*Pi)/30], Sin[(31*Pi)/30], 0}, \
{Cos[(31*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(8*Pi)/15]}, 
     {-Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, {-1, 0, 0}}], \
Line[{{Cos[(31*Pi)/30], Sin[(31*Pi)/30], 0}, {Cos[(16*Pi)/15], \
Sin[(16*Pi)/15], 0}, 
     {Cos[(16*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(31*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(31*Pi)/30], Cos[(8*Pi)/15]}, {Cos[(31*Pi)/30], \
Sin[(31*Pi)/30], 0}}], 
   Line[{{Cos[(16*Pi)/15], Sin[(16*Pi)/15], 0}, {-Sqrt[(5 + Sqrt[5])/2]/2, \
-(-1 + Sqrt[5])/4, 0}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[(16*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(16*Pi)/15], Sin[(16*Pi)/15], 0}}], 
   Line[{{-Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, {Cos[(17*Pi)/15], \
Sin[(17*Pi)/15], 0}, 
     {Cos[(17*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}}], 
   Line[{{Cos[(17*Pi)/15], Sin[(17*Pi)/15], 0}, {-Sqrt[3]/2, -1/2, 0}, \
{-(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, 
     {Cos[(17*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(17*Pi)/15], Sin[(17*Pi)/15], 0}}], 
   Line[{{-Sqrt[3]/2, -1/2, 0}, {-(1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, \
0}, {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{-(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, 
     {-Sqrt[3]/2, -1/2, 0}}], Line[{{-(1 + Sqrt[5])/4, -Sqrt[(5 - \
Sqrt[5])/2]/2, 0}, {Cos[(37*Pi)/30], Sin[(37*Pi)/30], 0}, 
     {Cos[(37*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(8*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-(1 + \
Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}}], 
   Line[{{Cos[(37*Pi)/30], Sin[(37*Pi)/30], 0}, {Cos[(19*Pi)/15], \
Sin[(19*Pi)/15], 0}, {Cos[(19*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(19*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(37*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(8*Pi)/15]}, 
     {Cos[(37*Pi)/30], Sin[(37*Pi)/30], 0}}], Line[{{Cos[(19*Pi)/15], \
Sin[(19*Pi)/15], 0}, {-Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[(19*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(19*Pi)/15], Sin[(19*Pi)/15], 0}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, {-1/2, -Sqrt[3]/2, \
0}, {-Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {-Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}}], Line[{{-1/2, \
-Sqrt[3]/2, 0}, {Cos[(41*Pi)/30], Sin[(41*Pi)/30], 0}, 
     {Cos[(41*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(8*Pi)/15]}, {-Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, 
      Cos[(8*Pi)/15]}, {-1/2, -Sqrt[3]/2, 0}}], Line[{{Cos[(41*Pi)/30], \
Sin[(41*Pi)/30], 0}, {-(-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, 
     {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(41*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(41*Pi)/30], Sin[(41*Pi)/30], 0}}], 
   Line[{{-(-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, {Cos[(43*Pi)/30], \
Sin[(43*Pi)/30], 0}, 
     {Cos[(43*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(8*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-(-1 + \
Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}}], 
   Line[{{Cos[(43*Pi)/30], Sin[(43*Pi)/30], 0}, {Cos[(22*Pi)/15], \
Sin[(22*Pi)/15], 0}, {Cos[(22*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(22*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(43*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(8*Pi)/15]}, 
     {Cos[(43*Pi)/30], Sin[(43*Pi)/30], 0}}], Line[{{Cos[(22*Pi)/15], \
Sin[(22*Pi)/15], 0}, {0, -1, 0}, {0, -Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
     {Cos[(22*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(22*Pi)/15], Sin[(22*Pi)/15], 0}}], 
   Line[{{0, -1, 0}, {Cos[(23*Pi)/15], Sin[(23*Pi)/15], 0}, \
{Cos[(23*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {0, -Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, {0, -1, 0}}], \
Line[{{Cos[(23*Pi)/15], Sin[(23*Pi)/15], 0}, {Cos[(47*Pi)/30], \
Sin[(47*Pi)/30], 0}, 
     {Cos[(47*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(23*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(23*Pi)/15], Cos[(8*Pi)/15]}, {Cos[(23*Pi)/15], \
Sin[(23*Pi)/15], 0}}], 
   Line[{{Cos[(47*Pi)/30], Sin[(47*Pi)/30], 0}, {(-1 + Sqrt[5])/4, -Sqrt[(5 + \
Sqrt[5])/2]/2, 0}, 
     {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(47*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(47*Pi)/30], Sin[(47*Pi)/30], 0}}], 
   Line[{{(-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}, {Cos[(49*Pi)/30], \
Sin[(49*Pi)/30], 0}, 
     {Cos[(49*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(8*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {(-1 + \
Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2, 0}}], 
   Line[{{Cos[(49*Pi)/30], Sin[(49*Pi)/30], 0}, {1/2, -Sqrt[3]/2, 0}, \
{Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(49*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(49*Pi)/30], Sin[(49*Pi)/30], 0}}], 
   Line[{{1/2, -Sqrt[3]/2, 0}, {Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, \
0}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {Sin[(8*Pi)/15]/2, \
-(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {1/2, -Sqrt[3]/2, 0}}], 
   Line[{{Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}, {Cos[(26*Pi)/15], \
Sin[(26*Pi)/15], 0}, 
     {Cos[(26*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {Sqrt[(5 - \
Sqrt[5])/2]/2, -(1 + Sqrt[5])/4, 0}}], 
   Line[{{Cos[(26*Pi)/15], Sin[(26*Pi)/15], 0}, {Cos[(53*Pi)/30], \
Sin[(53*Pi)/30], 0}, {Cos[(53*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(53*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(26*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {Cos[(26*Pi)/15], Sin[(26*Pi)/15], 0}}], Line[{{Cos[(53*Pi)/30], \
Sin[(53*Pi)/30], 0}, {(1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}, 
     {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(53*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(53*Pi)/30], Sin[(53*Pi)/30], 0}}], 
   Line[{{(1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}, {Sqrt[3]/2, -1/2, \
0}, {(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {(1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2, 0}}], Line[{{Sqrt[3]/2, \
-1/2, 0}, {Cos[(28*Pi)/15], Sin[(28*Pi)/15], 0}, 
     {Cos[(28*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, 
      Cos[(8*Pi)/15]}, {Sqrt[3]/2, -1/2, 0}}], Line[{{Cos[(28*Pi)/15], \
Sin[(28*Pi)/15], 0}, {Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[(28*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(28*Pi)/15], Sin[(28*Pi)/15], 0}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}, {Cos[(29*Pi)/15], \
Sin[(29*Pi)/15], 0}, 
     {Cos[(29*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4, 0}}], 
   Line[{{Cos[(29*Pi)/15], Sin[(29*Pi)/15], 0}, {Cos[(59*Pi)/30], \
Sin[(59*Pi)/30], 0}, {Cos[(59*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(59*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(29*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {Cos[(29*Pi)/15], Sin[(29*Pi)/15], 0}}], Line[{{Cos[(59*Pi)/30], \
Sin[(59*Pi)/30], 0}, {1, 0, 0}, {Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, 
     {Cos[(59*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(59*Pi)/30], Sin[(59*Pi)/30], 0}}], 
   Line[{{Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, {Cos[Pi/30]*Sin[(8*Pi)/15], \
Sin[Pi/30]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
     {Cos[Pi/30]*Sin[(17*Pi)/30], Sin[Pi/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}, 
     {Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}}], Line[{{Cos[Pi/30]*Sin[(8*Pi)/15], \
Sin[Pi/30]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, 
     {Cos[Pi/15]*Sin[(8*Pi)/15], Sin[Pi/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[Pi/15]*Sin[(17*Pi)/30], Sin[Pi/15]*Sin[(17*Pi)/30], 
      Cos[(17*Pi)/30]}, {Cos[Pi/30]*Sin[(17*Pi)/30], \
Sin[Pi/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {Cos[Pi/30]*Sin[(8*Pi)/15], Sin[Pi/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}], 
   Line[{{Cos[Pi/15]*Sin[(8*Pi)/15], Sin[Pi/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {Cos[Pi/15]*Sin[(17*Pi)/30], \
Sin[Pi/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {Cos[Pi/15]*Sin[(8*Pi)/15], Sin[Pi/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(8*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(2*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(8*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, 
      Cos[(8*Pi)/15]}, {(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(2*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(2*Pi)/15]*Sin[(8*Pi)/15], Sin[(2*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, {((1 \
+ Sqrt[5])*Sin[(8*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}, {(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, 
      Cos[(8*Pi)/15]}}], Line[{{((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(7*Pi)/30]*Sin[(8*Pi)/15], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(8*Pi)/15], Sin[(7*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(4*Pi)/15]*Sin[(17*Pi)/30], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, 
     {Cos[(7*Pi)/30]*Sin[(17*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(7*Pi)/30]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}}], \
Line[{{Cos[(4*Pi)/15]*Sin[(8*Pi)/15], Sin[(4*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {Cos[(4*Pi)/15]*Sin[(17*Pi)/30], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}}], Line[{{(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      Cos[(8*Pi)/15]}, {Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, \
Cos[(8*Pi)/15]}, {Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}], 
   Line[{{Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(8*Pi)/15], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], 
      Cos[(8*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[(8*Pi)/15], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {Cos[(11*Pi)/30]*Sin[(8*Pi)/15], Sin[(11*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(13*Pi)/30]*Sin[(8*Pi)/15], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(8*Pi)/15], Sin[(13*Pi)/30]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(7*Pi)/15]*Sin[(17*Pi)/30], Sin[(7*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, 
     {Cos[(13*Pi)/30]*Sin[(17*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(13*Pi)/30]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}}], \
Line[{{Cos[(7*Pi)/15]*Sin[(8*Pi)/15], Sin[(7*Pi)/15]*Sin[(8*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {0, Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, {0, Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(7*Pi)/15]*Sin[(17*Pi)/30], 
      Cos[(17*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(8*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(8*Pi)/15], Cos[(8*Pi)/15]}}], 
   Line[{{0, Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(8*Pi)/15], \
Sin[(8*Pi)/15]^2, Cos[(8*Pi)/15]}, 
     {Cos[(8*Pi)/15]*Sin[(17*Pi)/30], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {0, Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {0, Sin[(8*Pi)/15], Cos[(8*Pi)/15]}}], \
Line[{{Cos[(8*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]^2, Cos[(8*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]^2, 
      Cos[(17*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(8*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {Cos[(8*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]^2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(8*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]^2, \
Cos[(17*Pi)/30]}, 
     {Cos[(17*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(8*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(19*Pi)/30], Cos[(17*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(8*Pi)/15]}, {-Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, 
      Cos[(8*Pi)/15]}, {-Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(19*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(19*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(8*Pi)/15]}}], 
   Line[{{-Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {-Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}, {-Sin[(8*Pi)/15]/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, 
      Cos[(8*Pi)/15]}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, \
((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[(11*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(11*Pi)/15], Cos[(17*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(23*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(23*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(17*Pi)/30]}, 
     {Cos[(11*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(17*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(11*Pi)/15], Cos[(8*Pi)/15]}}], \
Line[{{Cos[(23*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(8*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {Cos[(23*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(23*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(23*Pi)/30], Cos[(8*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, \
{-(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], 
      Cos[(8*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(13*Pi)/15], Cos[(17*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{-(Sqrt[3]*Sin[(8*Pi)/15])/2, Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(13*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(13*Pi)/15], Cos[(17*Pi)/30]}, 
     {Cos[(13*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(8*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[(14*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(14*Pi)/15], Cos[(17*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(29*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(29*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(17*Pi)/30]}, 
     {Cos[(14*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(17*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(14*Pi)/15], Cos[(8*Pi)/15]}}], \
Line[{{Cos[(29*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(8*Pi)/15]}, 
     {-Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, {-Sin[(17*Pi)/30], 0, \
Cos[(17*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(29*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(29*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(8*Pi)/15]}}], 
   Line[{{-Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(8*Pi)/15]}, 
     {Cos[(31*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(17*Pi)/30]}, {-Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}, 
     {-Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}}], \
Line[{{Cos[(31*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(8*Pi)/15]}, 
     {Cos[(16*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(16*Pi)/15], Cos[(17*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(17*Pi)/30]}, 
     {Cos[(31*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(16*Pi)/15], Cos[(17*Pi)/30]}, 
     {Cos[(16*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(8*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[(17*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(17*Pi)/15], Cos[(17*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(8*Pi)/15]}, {-(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, 
      Cos[(8*Pi)/15]}, {-(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(17*Pi)/15], Cos[(17*Pi)/30]}, \
{Cos[(17*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(8*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, \
{-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {-(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, \
Cos[(17*Pi)/30]}, {-(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, 
      Cos[(8*Pi)/15]}}], Line[{{-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(37*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(37*Pi)/30], Cos[(17*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(37*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(19*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(19*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(17*Pi)/30]}, 
     {Cos[(37*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(37*Pi)/30], Cos[(8*Pi)/15]}}], \
Line[{{Cos[(19*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {Cos[(19*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(17*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(19*Pi)/15], Cos[(8*Pi)/15]}}], Line[{{-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      Cos[(8*Pi)/15]}, {-Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, \
Cos[(8*Pi)/15]}, {-Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}], 
   Line[{{-Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{Cos[(41*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(41*Pi)/30], 
      Cos[(8*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(41*Pi)/30], Cos[(17*Pi)/30]}, 
     {-Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{-Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(41*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(8*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(17*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(8*Pi)/15], \
Sin[(8*Pi)/15]*Sin[(41*Pi)/30], Cos[(8*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(43*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(43*Pi)/30], Cos[(17*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(22*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(22*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(17*Pi)/30]}, 
     {Cos[(43*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(43*Pi)/30], Cos[(8*Pi)/15]}}], \
Line[{{Cos[(22*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {0, -Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, {0, -Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(22*Pi)/15], Cos[(17*Pi)/30]}, \
{Cos[(22*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(8*Pi)/15]}}], 
   Line[{{0, -Sin[(8*Pi)/15], Cos[(8*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {Cos[(23*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(17*Pi)/30]}, {0, -Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {0, -Sin[(8*Pi)/15], Cos[(8*Pi)/15]}}], \
Line[{{Cos[(23*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(8*Pi)/15]}, 
     {Cos[(47*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(47*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(17*Pi)/30]}, 
     {Cos[(23*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(8*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(47*Pi)/30], Cos[(17*Pi)/30]}, 
     {Cos[(47*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(8*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {Cos[(49*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(8*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(49*Pi)/30], Cos[(17*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(8*Pi)/15]}, {Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, 
      Cos[(8*Pi)/15]}, {Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(49*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(49*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(8*Pi)/15]}}], 
   Line[{{Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, \
Cos[(17*Pi)/30]}, {Sin[(8*Pi)/15]/2, -(Sqrt[3]*Sin[(8*Pi)/15])/2, 
      Cos[(8*Pi)/15]}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, \
-((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[(26*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(26*Pi)/15], Cos[(17*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(53*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(53*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(17*Pi)/30]}, 
     {Cos[(26*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(17*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(26*Pi)/15], Cos[(8*Pi)/15]}}], \
Line[{{Cos[(53*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(8*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {Cos[(53*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(53*Pi)/30], Cos[(8*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}, 
     {(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, \
{(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, Cos[(8*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(28*Pi)/15], 
      Cos[(8*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(28*Pi)/15], Cos[(17*Pi)/30]}, 
     {(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{(Sqrt[3]*Sin[(8*Pi)/15])/2, -Sin[(8*Pi)/15]/2, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(28*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(8*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(28*Pi)/15], Cos[(17*Pi)/30]}, 
     {Cos[(28*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(8*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}, 
     {Cos[(29*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(29*Pi)/15], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, Cos[(8*Pi)/15]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(8*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(59*Pi)/30], Cos[(8*Pi)/15]}, \
{Cos[(59*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(17*Pi)/30]}, 
     {Cos[(29*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(17*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(8*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(29*Pi)/15], Cos[(8*Pi)/15]}}], \
Line[{{Cos[(59*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(8*Pi)/15]}, 
     {Sin[(8*Pi)/15], 0, Cos[(8*Pi)/15]}, {Sin[(17*Pi)/30], 0, \
Cos[(17*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(59*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(59*Pi)/30]*Sin[(8*Pi)/15], Sin[(8*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(8*Pi)/15]}}], 
   Line[{{Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}, {Cos[Pi/30]*Sin[(17*Pi)/30], \
Sin[Pi/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, -(-1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {Sin[(17*Pi)/30], 0, \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[Pi/30]*Sin[(17*Pi)/30], Sin[Pi/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[Pi/15]*Sin[(17*Pi)/30], Sin[Pi/15]*Sin[(17*Pi)/30], 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[Pi/30]*Sin[(17*Pi)/30], Sin[Pi/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[Pi/15]*Sin[(17*Pi)/30], Sin[Pi/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {(5 + Sqrt[5])/8, \
((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[Pi/15]*Sin[(17*Pi)/30], Sin[Pi/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {Cos[(2*Pi)/15]*Sin[(17*Pi)/30], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(-1 + Sqrt[5])/4}, {(5 + \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(17*Pi)/30], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, 
      Cos[(17*Pi)/30]}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + \
Sqrt[5])/2]/4, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(2*Pi)/15]*Sin[(17*Pi)/30], Sin[(2*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      -(-1 + Sqrt[5])/4}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + \
Sqrt[5])/2]/4, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {Cos[(7*Pi)/30]*Sin[(17*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      -(-1 + Sqrt[5])/4}, {((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(17*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(4*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(7*Pi)/30]*Sin[(17*Pi)/30], Sin[(7*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(4*Pi)/15]*Sin[(17*Pi)/30], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(4*Pi)/15]*Sin[(17*Pi)/30], Sin[(4*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}}], 
   Line[{{Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(17*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/30], 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}}], Line[{{Cos[(11*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/30]*Sin[(17*Pi)/30], Sin[(11*Pi)/30]*Sin[(17*Pi)/30], 
      Cos[(17*Pi)/30]}}], Line[{{((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {Cos[(13*Pi)/30]*Sin[(17*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
      -(-1 + Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(17*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, 
     {Cos[(7*Pi)/15]*Sin[(17*Pi)/30], Sin[(7*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 \
+ Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/30]*Sin[(17*Pi)/30], Sin[(13*Pi)/30]*Sin[(17*Pi)/30], 
      Cos[(17*Pi)/30]}}], Line[{{Cos[(7*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(7*Pi)/15]*Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {0, Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, {0, Sqrt[(5 + Sqrt[5])/2]/2, -(-1 \
+ Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(7*Pi)/15]*Sin[(17*Pi)/30], Sin[(7*Pi)/15]*Sin[(17*Pi)/30], 
      Cos[(17*Pi)/30]}}], Line[{{0, Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(17*Pi)/30], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {0, Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {0, Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(8*Pi)/15]*Sin[(17*Pi)/30], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]^2, 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(8*Pi)/15]*Sin[(17*Pi)/30], Sin[(8*Pi)/15]*Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]^2, \
Cos[(17*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]^2, Cos[(17*Pi)/30]}}], \

   Line[{{-((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {Cos[(19*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, 
      -(-1 + Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(17*Pi)/30]}, {-Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{-Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -(-1 + Sqrt[5])/4}, {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(-1 + Sqrt[5])/4}, 
     {-Sin[(17*Pi)/30]/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {Cos[(11*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, {-(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      Cos[(17*Pi)/30]}}], Line[{{Cos[(11*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(11*Pi)/15], Cos[(17*Pi)/30]}, 
     {Cos[(23*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], 
      Cos[(17*Pi)/30]}}], Line[{{Cos[(23*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(23*Pi)/30], Cos[(17*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, 
      -(-1 + Sqrt[5])/4}, {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
     {-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(17*Pi)/30])/2, Sin[(17*Pi)/30]/2, 
      Cos[(17*Pi)/30]}}], Line[{{Cos[(13*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(13*Pi)/15], Cos[(17*Pi)/30]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(17*Pi)/30]}}], Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, \
((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {Cos[(14*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(-1 + Sqrt[5])/4}, {(-5 - \
Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -(-1 + Sqrt[5])/4}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(17*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(29*Pi)/30], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(14*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(17*Pi)/30]}, {-Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}, 
     {-Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}, {Cos[(29*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(29*Pi)/30], Cos[(17*Pi)/30]}}], 
   Line[{{-Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(17*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {-Sin[(17*Pi)/30], 0, \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(16*Pi)/15], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(16*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(31*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(17*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {(-5 - \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(16*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(17*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {Cos[(17*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(-1 + Sqrt[5])/4}, {(-5 - \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -(-1 + Sqrt[5])/4}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 \
+ Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(17*Pi)/30]}, {-(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, 
      Cos[(17*Pi)/30]}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + \
Sqrt[5])/2]/4, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(17*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, {-Sqrt[(3*(5 \
+ Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + Sqrt[5])/4}, 
     {-(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {Cos[(37*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}}], Line[{{Cos[(37*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(37*Pi)/30], Cos[(17*Pi)/30]}, 
     {Cos[(19*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(37*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(37*Pi)/30], 
      Cos[(17*Pi)/30]}}], Line[{{Cos[(19*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(19*Pi)/15], Cos[(17*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(17*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {-Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
      -(-1 + Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}}], 
   Line[{{-Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {-Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}}], Line[{{Cos[(41*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(41*Pi)/30], Cos[(17*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(41*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(17*Pi)/30]}}], Line[{{-((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
-(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {Cos[(43*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
      -(-1 + Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(17*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(22*Pi)/15], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(43*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(17*Pi)/30]}, {0, -Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, 
     {0, -Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}, {Cos[(22*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(22*Pi)/15], Cos[(17*Pi)/30]}}], 
   Line[{{0, -Sin[(17*Pi)/30], Cos[(17*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(17*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {0, -Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {0, -Sin[(17*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(17*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(47*Pi)/30], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(47*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(17*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(47*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {Cos[(49*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(-1 + Sqrt[5])/4}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, 
      -(-1 + Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(17*Pi)/30]}, {Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, 
      Cos[(17*Pi)/30]}, {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(49*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(17*Pi)/30]}}], 
   Line[{{Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -(-1 + Sqrt[5])/4}, {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(-1 + Sqrt[5])/4}, 
     {Sin[(17*Pi)/30]/2, -(Sqrt[3]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {Cos[(26*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(-1 + Sqrt[5])/4}, {Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, 
      -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(17*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(53*Pi)/30], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(26*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(17*Pi)/30]}, {((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(53*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(53*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(53*Pi)/30], 
      Cos[(17*Pi)/30]}}], Line[{{((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}, 
     {(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, 
      -(-1 + Sqrt[5])/4}, {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
     {((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, Cos[(17*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, Cos[(17*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(17*Pi)/30])/2, -Sin[(17*Pi)/30]/2, 
      Cos[(17*Pi)/30]}}], Line[{{Cos[(28*Pi)/15]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(28*Pi)/15], Cos[(17*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(28*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(17*Pi)/30]}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, \
-((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}, 
     {Cos[(29*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(17*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(-1 + Sqrt[5])/4}, {(5 + \
Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(17*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(17*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(59*Pi)/30], Cos[(17*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(29*Pi)/15]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(17*Pi)/30]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(17*Pi)/30], Sin[(17*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(17*Pi)/30]}, {Sin[(17*Pi)/30], 0, Cos[(17*Pi)/30]}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}, {Cos[(59*Pi)/30]*Sin[(17*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(59*Pi)/30], Cos[(17*Pi)/30]}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
      -(-1 + Sqrt[5])/4}, {Cos[Pi/30]*Sin[(19*Pi)/30], \
Sin[Pi/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {Sin[(19*Pi)/30], 0, \
Cos[(19*Pi)/30]}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[Pi/30])/2, 
      -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[Pi/15]*Sin[(19*Pi)/30], Sin[Pi/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[Pi/30]*Sin[(19*Pi)/30], Sin[Pi/30]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/30])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -(-1 + Sqrt[5])/4}, 
     {(5 + Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, \
{Cos[Pi/15]*Sin[(19*Pi)/30], Sin[Pi/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[Pi/15])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{(5 + Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(2*Pi)/15]*Sin[(19*Pi)/30], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {(5 + Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}, 
     {Cos[(2*Pi)/15]*Sin[(19*Pi)/30], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, {((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      Cos[(19*Pi)/30]}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, 
      -(-1 + Sqrt[5])/4}}], Line[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(7*Pi)/30]*Sin[(19*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(4*Pi)/15]*Sin[(19*Pi)/30], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Cos[(4*Pi)/15]*Sin[(19*Pi)/30], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(4*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, \
Cos[(19*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/30]*Sin[(19*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}, {Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, \
Cos[(19*Pi)/30]}, {Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Cos[(11*Pi)/30]*Sin[(19*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/30]*Sin[(19*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(7*Pi)/15]*Sin[(19*Pi)/30], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(13*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(7*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {0, Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {0, Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(7*Pi)/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(7*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{0, Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(8*Pi)/15]*Sin[(19*Pi)/30], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}, {0, Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {0, Sqrt[(5 + \
Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/30]*Sin[(19*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(8*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(8*Pi)/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(19*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(19*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]^2, Cos[(19*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (5 + Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {-Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, 
      Cos[(19*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]^2, \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, {-(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      Cos[(19*Pi)/30]}, {-Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, \
Cos[(19*Pi)/30]}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(11*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(19*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(11*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(11*Pi)/15], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
     {-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Cos[(23*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, 
      Cos[(19*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(19*Pi)/30]}, {-(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, 
      Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}, {(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Cos[(13*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(14*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], 
      Cos[(19*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {(-5 - Sqrt[5])/8, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(29*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(14*Pi)/15], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {-Sin[(19*Pi)/30], 0, \
Cos[(19*Pi)/30]}, 
     {Cos[(29*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(31*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}, {Cos[(31*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(31*Pi)/30], Cos[(19*Pi)/30]}, 
     {-Sin[(19*Pi)/30], 0, Cos[(19*Pi)/30]}, {-Sqrt[(5 + Sqrt[5])/2]/2, 0, \
-(-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(16*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(31*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(31*Pi)/30], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(31*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {(-5 - Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, \
{Cos[(16*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(19*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{(-5 - Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(17*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(17*Pi)/15], 
      Cos[(19*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {(-5 - Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, 
      Cos[(19*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(17*Pi)/15], Cos[(19*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, {-((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      Cos[(19*Pi)/30]}, {-(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(37*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(19*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(37*Pi)/30], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(37*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Cos[(19*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(19*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {-Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, 
      Cos[(19*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(41*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(19*Pi)/30]}, {-Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, \
Cos[(19*Pi)/30]}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(43*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(43*Pi)/30], 
      Cos[(19*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(22*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(43*Pi)/30], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(43*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {0, -Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {0, -Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, 
     {Cos[(22*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(22*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{0, -Sqrt[(5 + Sqrt[5])/2]/2, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}, {Cos[(23*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(23*Pi)/15], Cos[(19*Pi)/30]}, 
     {0, -Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {0, -Sqrt[(5 + Sqrt[5])/2]/2, \
-(-1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(47*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(23*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(23*Pi)/15], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Cos[(47*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(47*Pi)/30], 
      Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(49*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(49*Pi)/30], 
      Cos[(19*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-5 - Sqrt[5])/8, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, 
      Cos[(19*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(49*Pi)/30], Cos[(19*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, \
{Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(26*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(26*Pi)/15])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(53*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(26*Pi)/15], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(26*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
     {((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Cos[(53*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(53*Pi)/30])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(-1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, 
      Cos[(19*Pi)/30]}, {((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(-1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(28*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(19*Pi)/30]}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -Sqrt[(5 + Sqrt[5])/2]/4, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(19*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(-1 + Sqrt[5])/4}}], 
   Line[{{(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(-1 + Sqrt[5])/4}, \
{Cos[(29*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/15], 
      Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {(5 + Sqrt[5])/8, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(-1 + Sqrt[5])/4}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Cos[(59*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(29*Pi)/15], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/15])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Cos[(59*Pi)/30])/2, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(-1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/2, 0, -(-1 + Sqrt[5])/4}, {Sin[(19*Pi)/30], 0, \
Cos[(19*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(59*Pi)/30], Cos[(19*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 + Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      -(-1 + Sqrt[5])/4}}], Line[{{Sin[(19*Pi)/30], 0, Cos[(19*Pi)/30]}, \
{Cos[Pi/30]*Sin[(19*Pi)/30], Sin[Pi/30]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, \
-1/2}, {Sqrt[3]/2, 0, -1/2}, {Sin[(19*Pi)/30], 0, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[Pi/30]*Sin[(19*Pi)/30], Sin[Pi/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[Pi/15]*Sin[(19*Pi)/30], Sin[Pi/15]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, \
-1/2}, {(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, -1/2}, 
     {Cos[Pi/30]*Sin[(19*Pi)/30], Sin[Pi/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{Cos[Pi/15]*Sin[(19*Pi)/30], Sin[Pi/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
     {(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, -1/2}, \
{Cos[Pi/15]*Sin[(19*Pi)/30], Sin[Pi/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Cos[(2*Pi)/15]*Sin[(19*Pi)/30], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 
      -1/2}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(19*Pi)/30], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, 
      Cos[(19*Pi)/30]}, {3/4, Sqrt[3]/4, -1/2}, {(Sqrt[3]*Cos[(2*Pi)/15])/2, \
(Sqrt[3]*Sin[(2*Pi)/15])/2, -1/2}, 
     {Cos[(2*Pi)/15]*Sin[(19*Pi)/30], Sin[(2*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}, \
{((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
     {3/4, Sqrt[3]/4, -1/2}, {(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, \
Cos[(19*Pi)/30]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Cos[(7*Pi)/30]*Sin[(19*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, 
      -1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, \
{((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(19*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(4*Pi)/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, -1/2}, 
     {(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, -1/2}, \
{Cos[(7*Pi)/30]*Sin[(19*Pi)/30], Sin[(7*Pi)/30]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(4*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(4*Pi)/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, -1/2}, 
     {Cos[(4*Pi)/15]*Sin[(19*Pi)/30], Sin[(4*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{Sqrt[3]/4, 3/4, -1/2}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}], \
Line[{{Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Cos[(11*Pi)/30]*Sin[(19*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(11*Pi)/30])/2, 
      (Sqrt[3]*Sin[(11*Pi)/30])/2, -1/2}, {Sqrt[3]/4, 3/4, -1/2}, \
{Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[(19*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
     {(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, -1/2}, \
{Cos[(11*Pi)/30]*Sin[(19*Pi)/30], Sin[(11*Pi)/30]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}}], Line[{{((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Cos[(13*Pi)/30]*Sin[(19*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(13*Pi)/30])/2, 
      (Sqrt[3]*Sin[(13*Pi)/30])/2, -1/2}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, \
Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
     {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(19*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, 
     {Cos[(7*Pi)/15]*Sin[(19*Pi)/30], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, 
      -1/2}, {(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, \
-1/2}, {Cos[(13*Pi)/30]*Sin[(19*Pi)/30], Sin[(13*Pi)/30]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(7*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(7*Pi)/15]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, 
     {0, Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {0, Sqrt[3]/2, -1/2}, \
{(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, -1/2}, 
     {Cos[(7*Pi)/15]*Sin[(19*Pi)/30], Sin[(7*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{0, Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(19*Pi)/30], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, 
     {(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, -1/2}, {0, \
Sqrt[3]/2, -1/2}, {0, Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(8*Pi)/15]*Sin[(19*Pi)/30], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, -1/2}, 
     {(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, -1/2}, \
{Cos[(8*Pi)/15]*Sin[(19*Pi)/30], Sin[(8*Pi)/15]*Sin[(19*Pi)/30], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(17*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(17*Pi)/30]*Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, \
{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, -1/2}, 
     {Cos[(17*Pi)/30]*Sin[(19*Pi)/30], Sin[(17*Pi)/30]*Sin[(19*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Cos[(19*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]^2, Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, -1/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, {-((-1 \
+ Sqrt[5])*Sin[(19*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], \
Line[{{Cos[(19*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]^2, Cos[(19*Pi)/30]}, 
     {-Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{-Sqrt[3]/4, 3/4, -1/2}, 
     {(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, -1/2}, \
{Cos[(19*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]^2, Cos[(19*Pi)/30]}}], 
   Line[{{-Sin[(19*Pi)/30]/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {-Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
     {-Sqrt[3]/4, 3/4, -1/2}, {-Sin[(19*Pi)/30]/2, \
(Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Cos[(11*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(11*Pi)/15])/2, 
      (Sqrt[3]*Sin[(11*Pi)/15])/2, -1/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(23*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(23*Pi)/30], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, -1/2}, 
     {(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, -1/2}, \
{Cos[(11*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(23*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(23*Pi)/30], Cos[(19*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, \
{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, -1/2}, 
     {Cos[(23*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}, \
{-3/4, Sqrt[3]/4, -1/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, {-((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], \
Line[{{-(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}, 
     {Cos[(13*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(13*Pi)/15])/2, 
      (Sqrt[3]*Sin[(13*Pi)/15])/2, -1/2}, {-3/4, Sqrt[3]/4, -1/2}, \
{-(Sqrt[3]*Sin[(19*Pi)/30])/2, Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(13*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(19*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {-Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
     {(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, -1/2}, \
{Cos[(13*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(19*Pi)/30]}}], Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, \
((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Cos[(14*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(14*Pi)/15])/2, 
      (Sqrt[3]*Sin[(14*Pi)/15])/2, -1/2}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, \
(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(29*Pi)/30], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, -1/2}, 
     {(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, -1/2}, \
{Cos[(14*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(29*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(29*Pi)/30], Cos[(19*Pi)/30]}, 
     {-Sin[(19*Pi)/30], 0, Cos[(19*Pi)/30]}, {-Sqrt[3]/2, 0, -1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, -1/2}, 
     {Cos[(29*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{-Sin[(19*Pi)/30], 0, Cos[(19*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(19*Pi)/30]}, 
     {(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, -1/2}, \
{-Sqrt[3]/2, 0, -1/2}, {-Sin[(19*Pi)/30], 0, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(16*Pi)/15], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, -1/2}, 
     {(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, -1/2}, \
{Cos[(31*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(31*Pi)/30], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(16*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(16*Pi)/15], Cos[(19*Pi)/30]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, -1/2}, 
     {Cos[(16*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(19*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Cos[(17*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(17*Pi)/15])/2, 
      (Sqrt[3]*Sin[(17*Pi)/15])/2, -1/2}, {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, \
-(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(19*Pi)/30]}, {-(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, 
      Cos[(19*Pi)/30]}, {-3/4, -Sqrt[3]/4, -1/2}, \
{(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, -1/2}, 
     {Cos[(17*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(19*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}, \
{-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
     {-3/4, -Sqrt[3]/4, -1/2}, {-(Sqrt[3]*Sin[(19*Pi)/30])/2, \
-Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Cos[(37*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(37*Pi)/30])/2, 
      (Sqrt[3]*Sin[(37*Pi)/30])/2, -1/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, \
-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
     {-((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(37*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(19*Pi)/15], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, -1/2}, 
     {(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, -1/2}, \
{Cos[(37*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(37*Pi)/30], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(19*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(19*Pi)/15], Cos[(19*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, -1/2}, 
     {Cos[(19*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(19*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {-Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{-Sqrt[3]/4, -3/4, -1/2}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}], \
Line[{{-Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Cos[(41*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(41*Pi)/30])/2, 
      (Sqrt[3]*Sin[(41*Pi)/30])/2, -1/2}, {-Sqrt[3]/4, -3/4, -1/2}, \
{-Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(41*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(19*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
     {(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, -1/2}, \
{Cos[(41*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(19*Pi)/30]}}], Line[{{-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, \
-(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Cos[(43*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(43*Pi)/30])/2, 
      (Sqrt[3]*Sin[(43*Pi)/30])/2, -1/2}, {-(Sqrt[3]*(-1 + Sqrt[5]))/8, \
-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
     {-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(19*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(22*Pi)/15], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, -1/2}, 
     {(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, -1/2}, \
{Cos[(43*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(43*Pi)/30], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(22*Pi)/15]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(22*Pi)/15], Cos[(19*Pi)/30]}, 
     {0, -Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, {0, -Sqrt[3]/2, -1/2}, \
{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, -1/2}, 
     {Cos[(22*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(19*Pi)/30]}}], 
   Line[{{0, -Sin[(19*Pi)/30], Cos[(19*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(19*Pi)/30]}, 
     {(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, -1/2}, {0, \
-Sqrt[3]/2, -1/2}, {0, -Sin[(19*Pi)/30], Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(47*Pi)/30], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, -1/2}, 
     {(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, -1/2}, \
{Cos[(23*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/15], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(47*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(47*Pi)/30], Cos[(19*Pi)/30]}, 
     {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, \
{(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, -1/2}, 
     {Cos[(47*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {Cos[(49*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(49*Pi)/30])/2, 
      (Sqrt[3]*Sin[(49*Pi)/30])/2, -1/2}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, \
-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
     {((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(19*Pi)/30]}, {Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, 
      Cos[(19*Pi)/30]}, {Sqrt[3]/4, -3/4, -1/2}, \
{(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, -1/2}, 
     {Cos[(49*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{Sin[(19*Pi)/30]/2, -(Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
     {Sqrt[3]/4, -3/4, -1/2}, {Sin[(19*Pi)/30]/2, \
-(Sqrt[3]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Cos[(26*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(26*Pi)/15])/2, 
      (Sqrt[3]*Sin[(26*Pi)/15])/2, -1/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, \
-(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(53*Pi)/30], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, -1/2}, 
     {(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, -1/2}, \
{Cos[(26*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(26*Pi)/15], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(53*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(53*Pi)/30], Cos[(19*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, \
{(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, -1/2}, 
     {Cos[(53*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}, 
     {(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}, \
{3/4, -Sqrt[3]/4, -1/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, {((1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, Cos[(19*Pi)/30]}}], \
Line[{{(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}, 
     {Cos[(28*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(28*Pi)/15])/2, 
      (Sqrt[3]*Sin[(28*Pi)/15])/2, -1/2}, {3/4, -Sqrt[3]/4, -1/2}, \
{(Sqrt[3]*Sin[(19*Pi)/30])/2, -Sin[(19*Pi)/30]/2, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(28*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, {Sqrt[(3*(5 + \
Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
     {(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, -1/2}, \
{Cos[(28*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(19*Pi)/30]}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, \
-((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}, 
     {Cos[(29*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(19*Pi)/30]}, {(Sqrt[3]*Cos[(29*Pi)/15])/2, 
      (Sqrt[3]*Sin[(29*Pi)/15])/2, -1/2}, {Sqrt[(3*(5 + Sqrt[5]))/2]/4, \
-(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(19*Pi)/30])/4, Cos[(19*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(19*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(19*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(59*Pi)/30], Cos[(19*Pi)/30]}, \
{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, -1/2}, 
     {(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, -1/2}, \
{Cos[(29*Pi)/15]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/15], 
      Cos[(19*Pi)/30]}}], Line[{{Cos[(59*Pi)/30]*Sin[(19*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(59*Pi)/30], Cos[(19*Pi)/30]}, 
     {Sin[(19*Pi)/30], 0, Cos[(19*Pi)/30]}, {Sqrt[3]/2, 0, -1/2}, \
{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, -1/2}, 
     {Cos[(59*Pi)/30]*Sin[(19*Pi)/30], Sin[(19*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(19*Pi)/30]}}], 
   Line[{{Sqrt[3]/2, 0, -1/2}, {(Sqrt[3]*Cos[Pi/30])/2, \
(Sqrt[3]*Sin[Pi/30])/2, -1/2}, {((1 + Sqrt[5])*Cos[Pi/30])/4, 
      ((1 + Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {(1 + \
Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {Sqrt[3]/2, 0, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, -1/2}, \
{(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, -Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[Pi/30])/2, (Sqrt[3]*Sin[Pi/30])/2, 
      -1/2}}], Line[{{(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, -1/2}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[Pi/15])/2, (Sqrt[3]*Sin[Pi/15])/2, 
      -1/2}}], Line[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + \
Sqrt[5]))/8, -1/2}, {(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, 
      -1/2}, {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, -1/2}, \
{3/4, Sqrt[3]/4, -1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(2*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(2*Pi)/15])/2, (Sqrt[3]*Sin[(2*Pi)/15])/2, -1/2}}], 
   Line[{{3/4, Sqrt[3]/4, -1/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -1/2}, 
     {(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {3/4, Sqrt[3]/4, -1/2}}], Line[{{(Sqrt[3]*(1 \
+ Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
     {(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, -1/2}, {((1 + \
Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {(1 + Sqrt[5])^2/16, (Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}}], \
Line[{{(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, -1/2}, 
     {(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, -1/2}, {((1 + \
Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(7*Pi)/30])/2, (Sqrt[3]*Sin[(7*Pi)/30])/2, -1/2}}], \
Line[{{(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, -1/2}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(4*Pi)/15])/2, (Sqrt[3]*Sin[(4*Pi)/15])/2, -1/2}}], \
Line[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
     {Sqrt[3]/4, 3/4, -1/2}, {(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, -Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}}], 
   Line[{{Sqrt[3]/4, 3/4, -1/2}, {(Sqrt[3]*Cos[(11*Pi)/30])/2, \
(Sqrt[3]*Sin[(11*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Sqrt[3]/4, 3/4, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, -1/2}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(11*Pi)/30])/2, (Sqrt[3]*Sin[(11*Pi)/30])/2, -1/2}}], 
   Line[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, \
{(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, -1/2}, \
{(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(13*Pi)/30])/2, (Sqrt[3]*Sin[(13*Pi)/30])/2, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, -1/2}, {0, \
Sqrt[3]/2, -1/2}, {0, (1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(7*Pi)/15])/2, (Sqrt[3]*Sin[(7*Pi)/15])/2, -1/2}}], 
   Line[{{0, Sqrt[3]/2, -1/2}, {(Sqrt[3]*Cos[(8*Pi)/15])/2, \
(Sqrt[3]*Sin[(8*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {0, (1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {0, Sqrt[3]/2, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, -1/2}, \
{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(8*Pi)/15])/2, (Sqrt[3]*Sin[(8*Pi)/15])/2, -1/2}}], \
Line[{{(Sqrt[3]*Cos[(17*Pi)/30])/2, (Sqrt[3]*Sin[(17*Pi)/30])/2, -1/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, {-((-1 \
+ Sqrt[5])*(1 + Sqrt[5]))/16, 
      ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*Cos[(17*Pi)/30])/2, \
(Sqrt[3]*Sin[(17*Pi)/30])/2, -1/2}}], 
   Line[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, \
{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, -1/2}, \
{-Sqrt[3]/4, 3/4, -1/2}, 
     {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Cos[(19*Pi)/30])/2, (Sqrt[3]*Sin[(19*Pi)/30])/2, -1/2}}], 
   Line[{{-Sqrt[3]/4, 3/4, -1/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 \
+ Sqrt[5]))/8, -1/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {-Sqrt[3]/4, 3/4, -1/2}}], \
Line[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
     {(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, -1/2}, {((1 + \
Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
(1 + Sqrt[5])^2/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, (Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, -1/2}, \
{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(11*Pi)/15])/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, -1/2}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
     {-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Cos[(23*Pi)/30])/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, -1/2}}], 
   Line[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, \
{-3/4, Sqrt[3]/4, -1/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -1/2}}], 
   Line[{{-3/4, Sqrt[3]/4, -1/2}, {(Sqrt[3]*Cos[(13*Pi)/15])/2, \
(Sqrt[3]*Sin[(13*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{-3/4, Sqrt[3]/4, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, -1/2}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(13*Pi)/15])/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, -1/2}}], 
   Line[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, (Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, -1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(14*Pi)/15])/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, -1/2}, \
{-Sqrt[3]/2, 0, -1/2}, {(-1 - Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(29*Pi)/30])/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, -1/2}}], 
   Line[{{-Sqrt[3]/2, 0, -1/2}, {(Sqrt[3]*Cos[(31*Pi)/30])/2, \
(Sqrt[3]*Sin[(31*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(-1 - Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {-Sqrt[3]/2, 0, \
-1/2}}], 
   Line[{{(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, -1/2}, \
{(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(31*Pi)/30])/2, (Sqrt[3]*Sin[(31*Pi)/30])/2, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, -1/2}, \
{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(16*Pi)/15])/2, (Sqrt[3]*Sin[(16*Pi)/15])/2, -1/2}}], 
   Line[{{-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, -1/2}, \
{-3/4, -Sqrt[3]/4, -1/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Cos[(17*Pi)/15])/2, (Sqrt[3]*Sin[(17*Pi)/15])/2, -1/2}}], 
   Line[{{-3/4, -Sqrt[3]/4, -1/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -1/2}, 
     {-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {-3/4, -Sqrt[3]/4, -1/2}}], \
Line[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
     {(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, -1/2}, {((1 + \
Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, -1/2}, \
{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(37*Pi)/30])/2, (Sqrt[3]*Sin[(37*Pi)/30])/2, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, -1/2}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, -Sqrt[(5 \
- Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(19*Pi)/15])/2, (Sqrt[3]*Sin[(19*Pi)/15])/2, -1/2}}], 
   Line[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, \
{-Sqrt[3]/4, -3/4, -1/2}, 
     {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])^2/16, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 \
+ Sqrt[5]))/8, -1/2}}], 
   Line[{{-Sqrt[3]/4, -3/4, -1/2}, {(Sqrt[3]*Cos[(41*Pi)/30])/2, \
(Sqrt[3]*Sin[(41*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-Sqrt[3]/4, -3/4, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, -1/2}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(41*Pi)/30])/2, (Sqrt[3]*Sin[(41*Pi)/30])/2, -1/2}}], 
   Line[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, \
{(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, -1/2}, \
{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(43*Pi)/30])/2, (Sqrt[3]*Sin[(43*Pi)/30])/2, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, -1/2}, \
{0, -Sqrt[3]/2, -1/2}, {0, (-1 - Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(22*Pi)/15])/2, (Sqrt[3]*Sin[(22*Pi)/15])/2, -1/2}}], 
   Line[{{0, -Sqrt[3]/2, -1/2}, {(Sqrt[3]*Cos[(23*Pi)/15])/2, \
(Sqrt[3]*Sin[(23*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {0, (-1 - Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {0, -Sqrt[3]/2, \
-1/2}}], 
   Line[{{(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, -1/2}, \
{(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(23*Pi)/15])/2, (Sqrt[3]*Sin[(23*Pi)/15])/2, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, -1/2}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(47*Pi)/30])/2, (Sqrt[3]*Sin[(47*Pi)/30])/2, -1/2}}], 
   Line[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}, \
{(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(3*(5 + Sqrt[5]))/2]/4, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, -1/2}, \
{Sqrt[3]/4, -3/4, -1/2}, 
     {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Cos[(49*Pi)/30])/2, (Sqrt[3]*Sin[(49*Pi)/30])/2, -1/2}}], 
   Line[{{Sqrt[3]/4, -3/4, -1/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 \
+ Sqrt[5]))/8, -1/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {Sqrt[3]/4, -3/4, -1/2}}], Line[{{Sqrt[(3*(5 \
- Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}, 
     {(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, -1/2}, {((1 + \
Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-(1 + Sqrt[5])^2/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(Sqrt[3]*(1 + Sqrt[5]))/8, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, -1/2}, \
{(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(26*Pi)/15])/2, (Sqrt[3]*Sin[(26*Pi)/15])/2, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, -1/2}, \
{(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, 
     {(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Cos[(53*Pi)/30])/2, (Sqrt[3]*Sin[(53*Pi)/30])/2, -1/2}}], 
   Line[{{(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -1/2}, \
{3/4, -Sqrt[3]/4, -1/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -1/2}}], 
   Line[{{3/4, -Sqrt[3]/4, -1/2}, {(Sqrt[3]*Cos[(28*Pi)/15])/2, \
(Sqrt[3]*Sin[(28*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{3/4, -Sqrt[3]/4, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, -1/2}, \
{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(28*Pi)/15])/2, (Sqrt[3]*Sin[(28*Pi)/15])/2, -1/2}}], 
   Line[{{Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}, \
{(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Sqrt[(3*(5 + Sqrt[5]))/2]/4, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, -1/2}, \
{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, -1/2}, 
     {((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(29*Pi)/15])/2, (Sqrt[3]*Sin[(29*Pi)/15])/2, -1/2}}], 
   Line[{{(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, -1/2}, \
{Sqrt[3]/2, 0, -1/2}, {(1 + Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Cos[(59*Pi)/30])/2, (Sqrt[3]*Sin[(59*Pi)/30])/2, -1/2}}], 
   Line[{{(1 + Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {((1 + \
Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {Cos[Pi/30]*Sin[(11*Pi)/15], Sin[Pi/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}, 
     {(1 + Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + Sqrt[5])*Sin[Pi/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, -Sqrt[(5 - \
Sqrt[5])/2]/2}, 
     {Cos[Pi/15]*Sin[(11*Pi)/15], Sin[Pi/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[Pi/30]*Sin[(11*Pi)/15], Sin[Pi/30]*Sin[(11*Pi)/15], 
      Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[Pi/30])/4, ((1 + \
Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + Sqrt[5])*Sin[Pi/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Cos[Pi/15]*Sin[(11*Pi)/15], Sin[Pi/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[Pi/15])/4, ((1 + \
Sqrt[5])*Sin[Pi/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, \

     {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(2*Pi)/15]*Sin[(11*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(11*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(2*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], \
Line[{{(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \

     {(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}}], 
   Line[{{(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(7*Pi)/30]*Sin[(11*Pi)/15], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {(1 + \
Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(7*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(4*Pi)/15]*Sin[(11*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(7*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(7*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, \
{Cos[(4*Pi)/15]*Sin[(11*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, 
     {((1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, -Sqrt[(5 - \
Sqrt[5])/2]/2}}], 
   Line[{{(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(11*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], 
      Cos[(11*Pi)/15]}, {Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}, {(1 + Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(11*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(13*Pi)/30]*Sin[(11*Pi)/15], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(13*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(7*Pi)/15]*Sin[(11*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(13*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(13*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(7*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {0, (1 + Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {0, Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{0, (1 + Sqrt[5])/4, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(8*Pi)/15]*Sin[(11*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], 
      Cos[(11*Pi)/15]}, {0, Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, {0, (1 + \
Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/30]*Sin[(11*Pi)/15], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(8*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(11*Pi)/15], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(17*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(19*Pi)/30]*Sin[(11*Pi)/15], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, ((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{-Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(11*Pi)/15], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{(-1 - Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + \
Sqrt[5])^2/16, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, \
((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {-Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {(-1 \
- Sqrt[5])/8, (Sqrt[3]*(1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, (1 + Sqrt[5])^2/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(11*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]^2, Cos[(11*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])^2/16, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(23*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]^2, 
      Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{Cos[(23*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], 
      Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{-(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {-(1 + Sqrt[5])^2/16, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(13*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], 
      Cos[(11*Pi)/15]}, {-(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, \
Cos[(11*Pi)/15]}, {-(Sqrt[3]*(1 + Sqrt[5]))/8, (1 + Sqrt[5])/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Cos[(13*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(13*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(14*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(14*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(29*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(14*Pi)/15], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(14*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(29*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(-1 - Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {-Sin[(11*Pi)/15], 0, \
Cos[(11*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(29*Pi)/30], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{(-1 - Sqrt[5])/4, 0, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(31*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(31*Pi)/30], 
      Cos[(11*Pi)/15]}, {-Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}, {(-1 - \
Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(16*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(31*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(31*Pi)/30], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(31*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(31*Pi)/30])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Cos[(16*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(16*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(16*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, 
      Cos[(11*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(17*Pi)/15], Cos[(11*Pi)/15]}, 
     {((1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, \
{-(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{-(1 + Sqrt[5])^2/16, -(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(37*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(11*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {-(1 + \
Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(37*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(19*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(37*Pi)/30], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(37*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(37*Pi)/30])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, \
{Cos[(19*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/15]}, 
     {((1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {-Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, 
      Cos[(11*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, -Sqrt[(5 \
- Sqrt[5])/2]/2}}], 
   Line[{{(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(41*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(41*Pi)/30], 
      Cos[(11*Pi)/15]}, {-Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, \
Cos[(11*Pi)/15]}, {(-1 - Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(41*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(43*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(43*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(22*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(43*Pi)/30], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(43*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(43*Pi)/30])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(22*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {0, (-1 - Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, {0, -Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(22*Pi)/15], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{0, (-1 - Sqrt[5])/4, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(23*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(23*Pi)/15], 
      Cos[(11*Pi)/15]}, {0, -Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, {0, (-1 - \
Sqrt[5])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(47*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(23*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(23*Pi)/15], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(23*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(23*Pi)/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(47*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(47*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(47*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + \
Sqrt[5])/2])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(49*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(49*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
      ((1 + Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{(1 + Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])^2/16, 
      -Sqrt[(5 - Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, \
-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {(1 \
+ Sqrt[5])/8, -(Sqrt[3]*(1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(26*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])^2/16, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(26*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(53*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(26*Pi)/15], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(26*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(26*Pi)/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{Cos[(53*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(53*Pi)/30], 
      Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {(1 + Sqrt[5])^2/16, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -Sqrt[(5 \
- Sqrt[5])/2]/2}}], 
   Line[{{(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, \
{Cos[(28*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(28*Pi)/15], 
      Cos[(11*Pi)/15]}, {(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, \
Cos[(11*Pi)/15]}, {(Sqrt[3]*(1 + Sqrt[5]))/8, (-1 - Sqrt[5])/8, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Cos[(28*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Cos[(28*Pi)/15])/4, 
      ((1 + Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}}], 
   Line[{{((1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(29*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(29*Pi)/15])/4, \
((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, \
-Sqrt[(5 - Sqrt[5])/2]/2}, 
     {Cos[(59*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(29*Pi)/15], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(29*Pi)/15])/4, ((1 + Sqrt[5])*Sin[(29*Pi)/15])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{((1 + Sqrt[5])*Cos[(59*Pi)/30])/4, \
((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, -Sqrt[(5 - Sqrt[5])/2]/2}, 
     {(1 + Sqrt[5])/4, 0, -Sqrt[(5 - Sqrt[5])/2]/2}, {Sin[(11*Pi)/15], 0, \
Cos[(11*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(59*Pi)/30], Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
      -Sqrt[(5 - Sqrt[5])/2]/2}}], Line[{{Sin[(11*Pi)/15], 0, \
Cos[(11*Pi)/15]}, {Cos[Pi/30]*Sin[(11*Pi)/15], Sin[Pi/30]*Sin[(11*Pi)/15], 
      Cos[(11*Pi)/15]}, {Cos[Pi/30]*Sin[(23*Pi)/30], \
Sin[Pi/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {Sin[(23*Pi)/30], 0, \
Cos[(23*Pi)/30]}, 
     {Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}}], \
Line[{{Cos[Pi/30]*Sin[(11*Pi)/15], Sin[Pi/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, 
     {Cos[Pi/15]*Sin[(11*Pi)/15], Sin[Pi/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[Pi/15]*Sin[(23*Pi)/30], Sin[Pi/15]*Sin[(23*Pi)/30], 
      Cos[(23*Pi)/30]}, {Cos[Pi/30]*Sin[(23*Pi)/30], \
Sin[Pi/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {Cos[Pi/30]*Sin[(11*Pi)/15], Sin[Pi/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{Cos[Pi/15]*Sin[(11*Pi)/15], Sin[Pi/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {Cos[Pi/15]*Sin[(23*Pi)/30], \
Sin[Pi/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {Cos[Pi/15]*Sin[(11*Pi)/15], Sin[Pi/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(11*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(2*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(11*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, 
      Cos[(11*Pi)/15]}, {(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, \
Cos[(23*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(2*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(2*Pi)/15]*Sin[(11*Pi)/15], Sin[(2*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, \
{((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}, {(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, \
Cos[(23*Pi)/30]}, {(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, 
      Cos[(11*Pi)/15]}}], Line[{{((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(7*Pi)/30]*Sin[(11*Pi)/15], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}, {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(11*Pi)/15], Sin[(7*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(4*Pi)/15]*Sin[(23*Pi)/30], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, 
     {Cos[(7*Pi)/30]*Sin[(23*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(7*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}], \
Line[{{Cos[(4*Pi)/15]*Sin[(11*Pi)/15], Sin[(4*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {Cos[(4*Pi)/15]*Sin[(23*Pi)/30], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}], 
   Line[{{Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], 
      Cos[(11*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {Cos[(11*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(13*Pi)/30]*Sin[(11*Pi)/15], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(11*Pi)/15], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, 
     {Cos[(7*Pi)/15]*Sin[(11*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(7*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(13*Pi)/30]*Sin[(23*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, 
     {Cos[(13*Pi)/30]*Sin[(11*Pi)/15], Sin[(13*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/15]*Sin[(11*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {0, Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, 
     {0, Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(7*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {Cos[(7*Pi)/15]*Sin[(11*Pi)/15], Sin[(7*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{0, Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(11*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, 
     {Cos[(8*Pi)/15]*Sin[(23*Pi)/30], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {0, Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {0, Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}], \
Line[{{Cos[(8*Pi)/15]*Sin[(11*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(11*Pi)/15], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(23*Pi)/30], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, 
     {Cos[(8*Pi)/15]*Sin[(11*Pi)/15], Sin[(8*Pi)/15]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(11*Pi)/15], Sin[(17*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(23*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], 
      Cos[(23*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(17*Pi)/30]*Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(11*Pi)/15], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[(11*Pi)/15], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}, {-Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 
      Cos[(11*Pi)/15]}, {-Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, \
Cos[(23*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(19*Pi)/30]*Sin[(11*Pi)/15], Sin[(19*Pi)/30]*Sin[(11*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{-Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {-Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, \
Cos[(23*Pi)/30]}, {-Sin[(11*Pi)/15]/2, (Sqrt[3]*Sin[(11*Pi)/15])/2, 
      Cos[(11*Pi)/15]}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, \
((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Cos[(11*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]^2, Cos[(11*Pi)/15]}, \
{Cos[(11*Pi)/15]*Sin[(23*Pi)/30], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], 
      Cos[(23*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]^2, \
Cos[(11*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(23*Pi)/30], 
      Cos[(11*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]^2, \
Cos[(23*Pi)/30]}, 
     {Cos[(11*Pi)/15]*Sin[(23*Pi)/30], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]^2, 
      Cos[(11*Pi)/15]}}], Line[{{Cos[(23*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(23*Pi)/30], Cos[(11*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {Cos[(23*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]^2, Cos[(23*Pi)/30]}, \
{Cos[(23*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], 
      Cos[(11*Pi)/15]}}], Line[{{-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, \
{-(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], 
      Cos[(11*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(13*Pi)/15], Cos[(23*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{-(Sqrt[3]*Sin[(11*Pi)/15])/2, Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(13*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(11*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(13*Pi)/15], Cos[(23*Pi)/30]}, 
     {Cos[(13*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Cos[(14*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(14*Pi)/15], Cos[(23*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(29*Pi)/30], Cos[(11*Pi)/15]}, \
{Cos[(29*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(23*Pi)/30]}, 
     {Cos[(14*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(23*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(14*Pi)/15], Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/15]}, {-Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}, 
     {-Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, \
{Cos[(29*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(23*Pi)/30]}, 
     {Cos[(29*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(11*Pi)/15]}}], 
   Line[{{-Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(11*Pi)/15]}, 
     {Cos[(31*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(23*Pi)/30]}, {-Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, 
     {-Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}}], \
Line[{{Cos[(31*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(11*Pi)/15]}, 
     {Cos[(16*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(16*Pi)/15], Cos[(23*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(23*Pi)/30]}, 
     {Cos[(31*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(16*Pi)/15], Cos[(23*Pi)/30]}, 
     {Cos[(16*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Cos[(17*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(17*Pi)/15], Cos[(23*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/15]}, {-(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, 
      Cos[(11*Pi)/15]}, {-(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, \
Cos[(23*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(17*Pi)/15], Cos[(23*Pi)/30]}, \
{Cos[(17*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, \
{-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(37*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(37*Pi)/30], Cos[(23*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(37*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(19*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(19*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(23*Pi)/30]}, 
     {Cos[(37*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(37*Pi)/30], Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(19*Pi)/15], Cos[(23*Pi)/30]}, 
     {Cos[(19*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {-Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{-Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}], 
   Line[{{-Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{Cos[(41*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(41*Pi)/30], 
      Cos[(11*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(41*Pi)/30], Cos[(23*Pi)/30]}, 
     {-Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(41*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(11*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(23*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(41*Pi)/30], Cos[(11*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(43*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(43*Pi)/30], Cos[(23*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(22*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(22*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(23*Pi)/30]}, 
     {Cos[(43*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(43*Pi)/30], Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/15]}, {0, -Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, 
     {0, -Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(22*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(23*Pi)/30]}, 
     {Cos[(22*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{0, -Sin[(11*Pi)/15], Cos[(11*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(11*Pi)/15]}, 
     {Cos[(23*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(23*Pi)/30]}, {0, -Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {0, -Sin[(11*Pi)/15], Cos[(11*Pi)/15]}}], \
Line[{{Cos[(23*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(11*Pi)/15]}, 
     {Cos[(47*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(47*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(23*Pi)/30]}, 
     {Cos[(23*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(11*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(47*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(47*Pi)/30], 
      Cos[(23*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(47*Pi)/30], Cos[(11*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {Cos[(49*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(49*Pi)/30], Cos[(23*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/15]}, {Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, 
      Cos[(11*Pi)/15]}, {Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, \
Cos[(23*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(49*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(49*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(11*Pi)/15]}}], 
   Line[{{Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, \
Cos[(23*Pi)/30]}, {Sin[(11*Pi)/15]/2, -(Sqrt[3]*Sin[(11*Pi)/15])/2, 
      Cos[(11*Pi)/15]}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, \
-((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Cos[(26*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(26*Pi)/15], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(53*Pi)/30], Cos[(11*Pi)/15]}, \
{Cos[(53*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(23*Pi)/30]}, 
     {Cos[(26*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(23*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(26*Pi)/15], Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(11*Pi)/15]}, {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(53*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(53*Pi)/30], 
      Cos[(23*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(11*Pi)/15], \
Sin[(11*Pi)/15]*Sin[(53*Pi)/30], Cos[(11*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}, 
     {(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, \
{(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, Cos[(11*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(28*Pi)/15], 
      Cos[(11*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(28*Pi)/15], Cos[(23*Pi)/30]}, 
     {(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{(Sqrt[3]*Sin[(11*Pi)/15])/2, -Sin[(11*Pi)/15]/2, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(28*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(11*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(28*Pi)/15], Cos[(23*Pi)/30]}, 
     {Cos[(28*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(11*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}, 
     {Cos[(29*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(29*Pi)/15], Cos[(23*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      Cos[(23*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(11*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(59*Pi)/30], Cos[(11*Pi)/15]}, \
{Cos[(59*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(23*Pi)/30]}, 
     {Cos[(29*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(23*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(11*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(29*Pi)/15], Cos[(11*Pi)/15]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/15]}, {Sin[(11*Pi)/15], 0, Cos[(11*Pi)/15]}, 
     {Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(59*Pi)/30], Cos[(23*Pi)/30]}, 
     {Cos[(59*Pi)/30]*Sin[(11*Pi)/15], Sin[(11*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(11*Pi)/15]}}], 
   Line[{{Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, {Cos[Pi/30]*Sin[(23*Pi)/30], \
Sin[Pi/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, -(1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {Sin[(23*Pi)/30], 0, \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[Pi/30]*Sin[(23*Pi)/30], Sin[Pi/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[Pi/15]*Sin[(23*Pi)/30], Sin[Pi/15]*Sin[(23*Pi)/30], 
      Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[Pi/30]*Sin[(23*Pi)/30], Sin[Pi/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[Pi/15]*Sin[(23*Pi)/30], Sin[Pi/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[Pi/15]*Sin[(23*Pi)/30], Sin[Pi/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {Cos[(2*Pi)/15]*Sin[(23*Pi)/30], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(1 + Sqrt[5])/4}, {Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(23*Pi)/30], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, 
      Cos[(23*Pi)/30]}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(2*Pi)/15]*Sin[(23*Pi)/30], Sin[(2*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, {(Sqrt[(5 \
- Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, 
      Cos[(23*Pi)/30]}}], Line[{{((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {Cos[(7*Pi)/30]*Sin[(23*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + Sqrt[5])/4}, 
     {((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(23*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(4*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(7*Pi)/30]*Sin[(23*Pi)/30], Sin[(7*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(4*Pi)/15]*Sin[(23*Pi)/30], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {(5 - Sqrt[5])/8, \
(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(4*Pi)/15]*Sin[(23*Pi)/30], Sin[(4*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + Sqrt[5])/4}, 
     {(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}], \
Line[{{Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {Cos[(11*Pi)/30]*Sin[(23*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(1 + Sqrt[5])/4}, {Sqrt[(5 \
- Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + Sqrt[5])/4}, 
     {Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[(23*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, {(Sqrt[(5 \
- Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(11*Pi)/30]*Sin[(23*Pi)/30], Sin[(11*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {Cos[(13*Pi)/30]*Sin[(23*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}}], Line[{{Cos[(13*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(13*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {Cos[(7*Pi)/15]*Sin[(23*Pi)/30], Sin[(7*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*Cos[(13*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/30]*Sin[(23*Pi)/30], Sin[(13*Pi)/30]*Sin[(23*Pi)/30], 
      Cos[(23*Pi)/30]}}], Line[{{Cos[(7*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(7*Pi)/15]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {0, Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {0, Sqrt[(5 - Sqrt[5])/2]/2, -(1 \
+ Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(7*Pi)/15]*Sin[(23*Pi)/30], Sin[(7*Pi)/15]*Sin[(23*Pi)/30], 
      Cos[(23*Pi)/30]}}], Line[{{0, Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(23*Pi)/30], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], 
      Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {0, Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {0, Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(8*Pi)/15]*Sin[(23*Pi)/30], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(8*Pi)/15]*Sin[(23*Pi)/30], Sin[(8*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(23*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, {-(Sqrt[(5 \
- Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(17*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(17*Pi)/30]*Sin[(23*Pi)/30], Sin[(17*Pi)/30]*Sin[(23*Pi)/30], 
      Cos[(23*Pi)/30]}}], Line[{{-((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {Cos[(19*Pi)/30]*Sin[(23*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}}], Line[{{Cos[(19*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(19*Pi)/30]*Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, 
     {-Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/30]*Sin[(23*Pi)/30], Sin[(19*Pi)/30]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{-Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {(-5 + Sqrt[5])/8, \
(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {-Sin[(23*Pi)/30]/2, (Sqrt[3]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, \
((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {Cos[(11*Pi)/15]*Sin[(23*Pi)/30], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(1 + Sqrt[5])/4}, {(-5 + \
Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[(23*Pi)/30], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(23*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]^2, 
      Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(11*Pi)/15]*Sin[(23*Pi)/30], Sin[(11*Pi)/15]*Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(23*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]^2, \
Cos[(23*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, {-(Sqrt[(5 \
- Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]^2, Cos[(23*Pi)/30]}}], \

   Line[{{-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, 
      -(1 + Sqrt[5])/4}, {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - \
Sqrt[5])/8, -(1 + Sqrt[5])/4}, 
     {-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {-(Sqrt[3]*Sin[(23*Pi)/30])/2, Sin[(23*Pi)/30]/2, 
      Cos[(23*Pi)/30]}}], Line[{{Cos[(13*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(13*Pi)/15], Cos[(23*Pi)/30]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(13*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(23*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {Cos[(14*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(1 + Sqrt[5])/4}, {-Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, 
      (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, {-(Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(23*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(29*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(14*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(23*Pi)/30]}, {-Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, 
     {-Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}, {Cos[(29*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(29*Pi)/30], Cos[(23*Pi)/30]}}], 
   Line[{{-Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(23*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {-Sin[(23*Pi)/30], 0, \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(16*Pi)/15], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(16*Pi)/15])/2, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(31*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(23*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {-Sqrt[(5 - \
Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(16*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(23*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {Cos[(17*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(1 + Sqrt[5])/4}, {-Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, 
      -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, \
{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(23*Pi)/30]}, {-(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, 
      Cos[(23*Pi)/30]}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(23*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, 
      -(1 + Sqrt[5])/4}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}, 
     {-(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {Cos[(37*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, 
      -(1 + Sqrt[5])/4}, {-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(37*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(23*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(19*Pi)/15], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/15])/2, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(37*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(23*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {(-5 + \
Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(23*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {-Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
      -(1 + Sqrt[5])/4}, {(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}], 
   Line[{{-Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {-Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}}], Line[{{Cos[(41*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(41*Pi)/30], Cos[(23*Pi)/30]}, 
     {-((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(41*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {Cos[(43*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, {-((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}}], Line[{{Cos[(43*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(43*Pi)/30], Cos[(23*Pi)/30]}, 
     {Cos[(22*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*Cos[(43*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(43*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(43*Pi)/30], 
      Cos[(23*Pi)/30]}}], Line[{{Cos[(22*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(22*Pi)/15], Cos[(23*Pi)/30]}, 
     {0, -Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, {0, -Sqrt[(5 - Sqrt[5])/2]/2, \
-(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(22*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(22*Pi)/15], 
      Cos[(23*Pi)/30]}}], Line[{{0, -Sin[(23*Pi)/30], Cos[(23*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(23*Pi)/15], 
      Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {0, -Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {0, -Sin[(23*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(23*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(47*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(47*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(23*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, {(Sqrt[(5 \
- Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(47*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(47*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(47*Pi)/30], 
      Cos[(23*Pi)/30]}}], Line[{{((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
-(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {Cos[(49*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 \
- Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(1 + Sqrt[5])/4}, {((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}}], Line[{{Cos[(49*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(49*Pi)/30], Cos[(23*Pi)/30]}, 
     {Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(49*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, {(5 - Sqrt[5])/8, \
-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {Sin[(23*Pi)/30]/2, -(Sqrt[3]*Sin[(23*Pi)/30])/2, 
      Cos[(23*Pi)/30]}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, \
-((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {Cos[(26*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(1 + Sqrt[5])/4}, {(5 - \
Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(23*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(53*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(53*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(26*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(23*Pi)/30]}, {((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, {(Sqrt[(5 \
- Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(53*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(23*Pi)/30]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}, 
     {(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + \
Sqrt[5])/8, -(1 + Sqrt[5])/4}, 
     {((1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, Cos[(23*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, Cos[(23*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[3]*Sin[(23*Pi)/30])/2, -Sin[(23*Pi)/30]/2, 
      Cos[(23*Pi)/30]}}], Line[{{Cos[(28*Pi)/15]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(28*Pi)/15], Cos[(23*Pi)/30]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(28*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(23*Pi)/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}, 
     {Cos[(29*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(23*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(1 + Sqrt[5])/4}, {Sqrt[(5 \
- Sqrt[5])*(5 + Sqrt[5])]/8, 
      -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, {(Sqrt[(5 \
+ Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(23*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(23*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(59*Pi)/30], Cos[(23*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(29*Pi)/15]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(23*Pi)/30]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(23*Pi)/30], Sin[(23*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(23*Pi)/30]}, {Sin[(23*Pi)/30], 0, Cos[(23*Pi)/30]}, 
     {Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(59*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}, {Cos[(59*Pi)/30]*Sin[(23*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(59*Pi)/30], Cos[(23*Pi)/30]}}], 
   Line[{{Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, 
      -(1 + Sqrt[5])/4}, {Cos[Pi/30]/2, Sin[Pi/30]/2, -Sqrt[3]/2}, {1/2, 0, \
-Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/30])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -(1 + Sqrt[5])/4}, {Cos[Pi/15]/2, Sin[Pi/15]/2, \
-Sqrt[3]/2}, 
     {Cos[Pi/30]/2, Sin[Pi/30]/2, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[Pi/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[Pi/30])/2, -(1 + \
Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -(1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, {Cos[Pi/15]/2, \
Sin[Pi/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[Pi/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[Pi/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, -Sqrt[3]/2}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(2*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {Sqrt[3]/4, 1/4, -Sqrt[3]/2}, 
     {Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(2*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(2*Pi)/15])/2, 
      -(1 + Sqrt[5])/4}}], Line[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + \
Sqrt[5])/4}, {(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {Sqrt[3]/4, 1/4, -Sqrt[3]/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, -Sqrt[3]/2}, 
     {(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(7*Pi)/30]/2, \
Sin[(7*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(4*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, 
     {Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(4*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(4*Pi)/15])/2, 
      -(1 + Sqrt[5])/4}}], Line[{{(5 - Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 \
+ Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {1/4, Sqrt[3]/4, -Sqrt[3]/2}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, {(5 - \
Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, -Sqrt[3]/2}, 
     {1/4, Sqrt[3]/4, -Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
     {(-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, -Sqrt[3]/2}, {(-1 + Sqrt[5])/8, \
Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(13*Pi)/30]/2, \
Sin[(13*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {0, Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {0, 1/2, -Sqrt[3]/2}, \
{Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(7*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(7*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{0, Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(8*Pi)/15])/2, 
      -(1 + Sqrt[5])/4}, {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, -Sqrt[3]/2}, \
{0, 1/2, -Sqrt[3]/2}, {0, Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(8*Pi)/15]/2, \
Sin[(8*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(8*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(8*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
     {(1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, -Sqrt[3]/2}, {(1 - Sqrt[5])/8, \
Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {-1/4, Sqrt[3]/4, -Sqrt[3]/2}, 
     {Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(19*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}}], Line[{{-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(1 + Sqrt[5])/4}, 
     {(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, 
     {-1/4, Sqrt[3]/4, -Sqrt[3]/2}, {-Sqrt[(5 - Sqrt[5])/2]/4, Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(1 + Sqrt[5])/4}}], 
   Line[{{(-5 + Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, -Sqrt[3]/2}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, {(-5 + \
Sqrt[5])/8, (Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(11*Pi)/15]/2, \
Sin[(11*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(11*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(11*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + \
Sqrt[5])/4}, {(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(23*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
(5 - Sqrt[5])/8, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {-Sqrt[3]/4, 1/4, -Sqrt[3]/2}, 
     {(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (5 - Sqrt[5])/8, -(1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, -Sqrt[3]/2}, 
     {-Sqrt[3]/4, 1/4, -Sqrt[3]/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(13*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(14*Pi)/15]/2, \
Sin[(14*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(14*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {-1/2, 0, -Sqrt[3]/2}, \
{Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(31*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}, {Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, -Sqrt[3]/2}, \
{-1/2, 0, -Sqrt[3]/2}, 
     {-Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(31*Pi)/30]/2, \
Sin[(31*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(31*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(31*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(16*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(16*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, 
     {-Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(17*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {-Sqrt[3]/4, -1/4, -Sqrt[3]/2}, 
     {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(17*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(17*Pi)/15])/2, 
      -(1 + Sqrt[5])/4}}], Line[{{-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, -(1 + \
Sqrt[5])/4}, {(-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {-Sqrt[3]/4, -1/4, -Sqrt[3]/2}, {-Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 \
- Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, -Sqrt[3]/2}, 
     {(-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(37*Pi)/30]/2, \
Sin[(37*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(37*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(37*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(19*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {(-5 + Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, 
     {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(19*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(19*Pi)/15])/2, 
      -(1 + Sqrt[5])/4}}], Line[{{(-5 + Sqrt[5])/8, -(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {-1/4, -Sqrt[3]/4, -Sqrt[3]/2}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, {(-5 + \
Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(1 + Sqrt[5])/4}, \
{Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, -Sqrt[3]/2}, 
     {-1/4, -Sqrt[3]/4, -Sqrt[3]/2}, {-Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
     {(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(41*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(41*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, -Sqrt[3]/2}, {(1 - Sqrt[5])/8, \
-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(43*Pi)/30]/2, \
Sin[(43*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(43*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(43*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {0, -Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {0, -1/2, -Sqrt[3]/2}, \
{Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(22*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(22*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{0, -Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(23*Pi)/15])/2, 
      -(1 + Sqrt[5])/4}, {Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, -Sqrt[3]/2}, \
{0, -1/2, -Sqrt[3]/2}, 
     {0, -Sqrt[(5 - Sqrt[5])/2]/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(23*Pi)/15]/2, \
Sin[(23*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(23*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(23*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
     {(-1 + Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(47*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(47*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, -Sqrt[3]/2}, {(-1 + Sqrt[5])/8, \
-Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 - Sqrt[5])*(5 + \
Sqrt[5])]/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(49*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - Sqrt[5]))/2]/4, -(1 + \
Sqrt[5])/4}, {1/4, -Sqrt[3]/4, -Sqrt[3]/2}, 
     {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(49*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(49*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}}], Line[{{Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(1 + Sqrt[5])/4}, 
     {(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, 
     {1/4, -Sqrt[3]/4, -Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[(3*(5 - \
Sqrt[5]))/2]/4, -(1 + Sqrt[5])/4}}], 
   Line[{{(5 - Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, -Sqrt[3]/2}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, {(5 - \
Sqrt[5])/8, -(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(26*Pi)/15]/2, \
Sin[(26*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(26*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(26*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(53*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, -(1 + \
Sqrt[5])/4}, {(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*Cos[(53*Pi)/30])/2, (Sqrt[(5 - Sqrt[5])/2]*Sin[(53*Pi)/30])/2, 
      -(1 + Sqrt[5])/4}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*(1 + Sqrt[5]))/8, \
(-5 + Sqrt[5])/8, -(1 + Sqrt[5])/4}, 
     {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {Sqrt[3]/4, -1/4, -Sqrt[3]/2}, 
     {(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, {(Sqrt[(5 - \
Sqrt[5])/2]*(1 + Sqrt[5]))/8, (-5 + Sqrt[5])/8, -(1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - Sqrt[5])/2]/4, -(1 + \
Sqrt[5])/4}, {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(1 + Sqrt[5])/4}, \
{Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, -Sqrt[3]/2}, 
     {Sqrt[3]/4, -1/4, -Sqrt[3]/2}, {Sqrt[(3*(5 - Sqrt[5]))/2]/4, -Sqrt[(5 - \
Sqrt[5])/2]/4, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(28*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(28*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, -Sqrt[3]/2}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, 
     {Sqrt[(5 - Sqrt[5])*(5 + Sqrt[5])]/8, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(1 + Sqrt[5])/4}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(29*Pi)/15]/2, \
Sin[(29*Pi)/15]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(29*Pi)/15])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/15])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(1 + Sqrt[5])/4}, 
     {Sqrt[(5 - Sqrt[5])/2]/2, 0, -(1 + Sqrt[5])/4}, {1/2, 0, -Sqrt[3]/2}, \
{Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Cos[(59*Pi)/30])/2, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(59*Pi)/30])/2, -(1 + Sqrt[5])/4}}], 
   Line[{{1/2, 0, -Sqrt[3]/2}, {Cos[Pi/30]/2, Sin[Pi/30]/2, -Sqrt[3]/2}, \
{Cos[Pi/30]*Sin[(13*Pi)/15], Sin[Pi/30]*Sin[(13*Pi)/15], 
      Cos[(13*Pi)/15]}, {Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, {1/2, 0, \
-Sqrt[3]/2}}], 
   Line[{{Cos[Pi/30]/2, Sin[Pi/30]/2, -Sqrt[3]/2}, {Cos[Pi/15]/2, \
Sin[Pi/15]/2, -Sqrt[3]/2}, 
     {Cos[Pi/15]*Sin[(13*Pi)/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[Pi/30]*Sin[(13*Pi)/15], Sin[Pi/30]*Sin[(13*Pi)/15], 
      Cos[(13*Pi)/15]}, {Cos[Pi/30]/2, Sin[Pi/30]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[Pi/15]/2, Sin[Pi/15]/2, -Sqrt[3]/2}, {Sqrt[(5 + Sqrt[5])/2]/4, \
(-1 + Sqrt[5])/8, -Sqrt[3]/2}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[Pi/15]*Sin[(13*Pi)/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[Pi/15]/2, Sin[Pi/15]/2, -Sqrt[3]/2}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, -Sqrt[3]/2}, 
     {Cos[(2*Pi)/15]*Sin[(13*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}}], 
   Line[{{Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, -Sqrt[3]/2}, {Sqrt[3]/4, 1/4, \
-Sqrt[3]/2}, {(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, 
      Cos[(13*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(2*Pi)/15]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
     {Cos[(2*Pi)/15]/2, Sin[(2*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{Sqrt[3]/4, 1/4, -Sqrt[3]/2}, {(1 + Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/4, -Sqrt[3]/2}, {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, \
{(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, 
     {Sqrt[3]/4, 1/4, -Sqrt[3]/2}}], Line[{{(1 + Sqrt[5])/8, Sqrt[(5 - \
Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(7*Pi)/30]*Sin[(13*Pi)/15], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {(1 + Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}}], \
Line[{{Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, -Sqrt[3]/2}, 
     {Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(4*Pi)/15]*Sin[(13*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, 
     {Cos[(7*Pi)/30]*Sin[(13*Pi)/15], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(7*Pi)/30]/2, Sin[(7*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, -Sqrt[3]/2}, {Sqrt[(5 - \
Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(4*Pi)/15]*Sin[(13*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(4*Pi)/15]/2, Sin[(4*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}, {1/4, \
Sqrt[3]/4, -Sqrt[3]/2}, {Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 
      Cos[(13*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}}], 
   Line[{{1/4, Sqrt[3]/4, -Sqrt[3]/2}, {Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, \
-Sqrt[3]/2}, {Cos[(11*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(11*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {Sin[(13*Pi)/15]/2, \
(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {1/4, Sqrt[3]/4, -Sqrt[3]/2}}], Line[{{Cos[(11*Pi)/30]/2, \
Sin[(11*Pi)/30]/2, -Sqrt[3]/2}, {(-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, 
      -Sqrt[3]/2}, {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(11*Pi)/30]*Sin[(13*Pi)/15], Sin[(11*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(11*Pi)/30]/2, Sin[(11*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{(-1 + Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, -Sqrt[3]/2}, 
     {Cos[(13*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(-1 + \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}}], 
   Line[{{Cos[(13*Pi)/30]/2, Sin[(13*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, -Sqrt[3]/2}, 
     {Cos[(7*Pi)/15]*Sin[(13*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {Cos[(13*Pi)/30]/2, \
Sin[(13*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, -Sqrt[3]/2}, {0, 1/2, \
-Sqrt[3]/2}, {0, Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
     {Cos[(7*Pi)/15]*Sin[(13*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(7*Pi)/15]/2, Sin[(7*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{0, 1/2, -Sqrt[3]/2}, {Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, \
-Sqrt[3]/2}, {Cos[(8*Pi)/15]*Sin[(13*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \

      Cos[(13*Pi)/15]}, {0, Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {0, 1/2, \
-Sqrt[3]/2}}], 
   Line[{{Cos[(8*Pi)/15]/2, Sin[(8*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, -Sqrt[3]/2}, 
     {Cos[(17*Pi)/30]*Sin[(13*Pi)/15], Sin[(17*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(13*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {Cos[(8*Pi)/15]/2, \
Sin[(8*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, -Sqrt[3]/2}, {(1 - \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(13*Pi)/15], Sin[(17*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(17*Pi)/30]/2, Sin[(17*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{(1 - Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, -Sqrt[3]/2}, 
     {Cos[(19*Pi)/30]*Sin[(13*Pi)/15], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(1 - \
Sqrt[5])/8, Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}}], 
   Line[{{Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, -Sqrt[3]/2}, {-1/4, \
Sqrt[3]/4, -Sqrt[3]/2}, {-Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 
      Cos[(13*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(19*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
     {Cos[(19*Pi)/30]/2, Sin[(19*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{-1/4, Sqrt[3]/4, -Sqrt[3]/2}, {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/8, -Sqrt[3]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, \
{-Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {-1/4, Sqrt[3]/4, -Sqrt[3]/2}}], Line[{{-Sqrt[(5 - Sqrt[5])/2]/4, (1 + \
Sqrt[5])/8, -Sqrt[3]/2}, 
     {Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(11*Pi)/15]*Sin[(13*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {-Sqrt[(5 - Sqrt[5])/2]/4, (1 + Sqrt[5])/8, -Sqrt[3]/2}}], \
Line[{{Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, -Sqrt[3]/2}, 
     {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(23*Pi)/30]*Sin[(13*Pi)/15], Sin[(23*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, 
     {Cos[(11*Pi)/15]*Sin[(13*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(11*Pi)/15]/2, Sin[(11*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, -Sqrt[3]/2}, {(-1 - \
Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(23*Pi)/30]*Sin[(13*Pi)/15], Sin[(23*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(23*Pi)/30]/2, Sin[(23*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{-Sqrt[3]/4, 1/4, -Sqrt[3]/2}, {-(Sqrt[3]*Sin[(13*Pi)/15])/2, \
Sin[(13*Pi)/15]/2, 
      Cos[(13*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {(-1 - Sqrt[5])/8, Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}}], 
   Line[{{-Sqrt[3]/4, 1/4, -Sqrt[3]/2}, {Cos[(13*Pi)/15]/2, \
Sin[(13*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(13*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]^2, 
      Cos[(13*Pi)/15]}, {-(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, \
Cos[(13*Pi)/15]}, {-Sqrt[3]/4, 1/4, -Sqrt[3]/2}}], 
   Line[{{Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(13*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]^2, Cos[(13*Pi)/15]}, \
{Cos[(13*Pi)/15]/2, Sin[(13*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{-Sqrt[(5 + Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, -Sqrt[3]/2}, 
     {Cos[(14*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(13*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (-1 + Sqrt[5])/8, -Sqrt[3]/2}}], 
   Line[{{Cos[(14*Pi)/15]/2, Sin[(14*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, -Sqrt[3]/2}, 
     {Cos[(29*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(14*Pi)/15], Cos[(13*Pi)/15]}, {Cos[(14*Pi)/15]/2, \
Sin[(14*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, -Sqrt[3]/2}, {-1/2, 0, \
-Sqrt[3]/2}, {-Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, 
     {Cos[(29*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(29*Pi)/30]/2, Sin[(29*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{-1/2, 0, -Sqrt[3]/2}, {Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, \
-Sqrt[3]/2}, {Cos[(31*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(31*Pi)/30], Cos[(13*Pi)/15]}, {-Sin[(13*Pi)/15], \
0, Cos[(13*Pi)/15]}, {-1/2, 0, -Sqrt[3]/2}}], 
   Line[{{Cos[(31*Pi)/30]/2, Sin[(31*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, -Sqrt[3]/2}, 
     {Cos[(16*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(31*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(31*Pi)/30], Cos[(13*Pi)/15]}, {Cos[(31*Pi)/30]/2, \
Sin[(31*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(16*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(16*Pi)/15]/2, Sin[(16*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{-Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, -Sqrt[3]/2}, 
     {Cos[(17*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(13*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {-Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}}], 
   Line[{{Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[3]/4, \
-1/4, -Sqrt[3]/2}, {-(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, 
      Cos[(13*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(17*Pi)/15], Cos[(13*Pi)/15]}, 
     {Cos[(17*Pi)/15]/2, Sin[(17*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{-Sqrt[3]/4, -1/4, -Sqrt[3]/2}, {(-1 - Sqrt[5])/8, -Sqrt[(5 - \
Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{-Sqrt[3]/4, -1/4, -Sqrt[3]/2}}], 
   Line[{{(-1 - Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, -Sqrt[3]/2}, 
     {Cos[(37*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(-1 - \
Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}}], 
   Line[{{Cos[(37*Pi)/30]/2, Sin[(37*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, -Sqrt[3]/2}, 
     {Cos[(19*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(37*Pi)/30], Cos[(13*Pi)/15]}, {Cos[(37*Pi)/30]/2, \
Sin[(37*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, -Sqrt[3]/2}, {-Sqrt[(5 - \
Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(19*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(19*Pi)/15]/2, Sin[(19*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{-Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}, {-1/4, \
-Sqrt[3]/4, -Sqrt[3]/2}, 
     {-Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {-Sqrt[(5 - \
Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}}], 
   Line[{{-1/4, -Sqrt[3]/4, -Sqrt[3]/2}, {Cos[(41*Pi)/30]/2, \
Sin[(41*Pi)/30]/2, -Sqrt[3]/2}, {Cos[(41*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(41*Pi)/30], Cos[(13*Pi)/15]}, {-Sin[(13*Pi)/15]/2, \
-(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {-1/4, -Sqrt[3]/4, -Sqrt[3]/2}}], Line[{{Cos[(41*Pi)/30]/2, \
Sin[(41*Pi)/30]/2, -Sqrt[3]/2}, {(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, 
      -Sqrt[3]/2}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(41*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(41*Pi)/30]/2, Sin[(41*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{(1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, -Sqrt[3]/2}, 
     {Cos[(43*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(13*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(1 - \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}}], 
   Line[{{Cos[(43*Pi)/30]/2, Sin[(43*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, -Sqrt[3]/2}, 
     {Cos[(22*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(43*Pi)/30], Cos[(13*Pi)/15]}, {Cos[(43*Pi)/30]/2, \
Sin[(43*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, -Sqrt[3]/2}, {0, -1/2, \
-Sqrt[3]/2}, {0, -Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
     {Cos[(22*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(22*Pi)/15]/2, Sin[(22*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{0, -1/2, -Sqrt[3]/2}, {Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, \
-Sqrt[3]/2}, {Cos[(23*Pi)/15]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(23*Pi)/15], Cos[(13*Pi)/15]}, {0, \
-Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {0, -1/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(23*Pi)/15]/2, Sin[(23*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, -Sqrt[3]/2}, 
     {Cos[(47*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(23*Pi)/15]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(23*Pi)/15], Cos[(13*Pi)/15]}, {Cos[(23*Pi)/15]/2, \
Sin[(23*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, -Sqrt[3]/2}, {(-1 + \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(47*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(47*Pi)/30]/2, Sin[(47*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{(-1 + Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}, \
{Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, -Sqrt[3]/2}, 
     {Cos[(49*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(-1 + \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/4, -Sqrt[3]/2}}], 
   Line[{{Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, -Sqrt[3]/2}, {1/4, \
-Sqrt[3]/4, -Sqrt[3]/2}, {Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, 
      Cos[(13*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(49*Pi)/30], Cos[(13*Pi)/15]}, 
     {Cos[(49*Pi)/30]/2, Sin[(49*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{1/4, -Sqrt[3]/4, -Sqrt[3]/2}, {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - \
Sqrt[5])/8, -Sqrt[3]/2}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, \
{Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {1/4, -Sqrt[3]/4, -Sqrt[3]/2}}], Line[{{Sqrt[(5 - Sqrt[5])/2]/4, (-1 - \
Sqrt[5])/8, -Sqrt[3]/2}, 
     {Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(26*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Sqrt[(5 - Sqrt[5])/2]/4, (-1 - Sqrt[5])/8, -Sqrt[3]/2}}], \
Line[{{Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, -Sqrt[3]/2}, 
     {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, -Sqrt[3]/2}, \
{Cos[(53*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/15]}, 
     {Cos[(26*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(26*Pi)/15]/2, Sin[(26*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, -Sqrt[3]/2}, {(1 + \
Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, 
     {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(53*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(53*Pi)/30]/2, Sin[(53*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}, {Sqrt[3]/4, \
-1/4, -Sqrt[3]/2}, {(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, 
      Cos[(13*Pi)/15]}, {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {(1 + Sqrt[5])/8, -Sqrt[(5 - Sqrt[5])/2]/4, -Sqrt[3]/2}}], 
   Line[{{Sqrt[3]/4, -1/4, -Sqrt[3]/2}, {Cos[(28*Pi)/15]/2, \
Sin[(28*Pi)/15]/2, -Sqrt[3]/2}, {Cos[(28*Pi)/15]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(28*Pi)/15], Cos[(13*Pi)/15]}, \
{(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, 
     {Sqrt[3]/4, -1/4, -Sqrt[3]/2}}], Line[{{Cos[(28*Pi)/15]/2, \
Sin[(28*Pi)/15]/2, -Sqrt[3]/2}, {Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, 
      -Sqrt[3]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(28*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(28*Pi)/15]/2, Sin[(28*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{Sqrt[(5 + Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}, \
{Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, -Sqrt[3]/2}, 
     {Cos[(29*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(13*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {Sqrt[(5 + \
Sqrt[5])/2]/4, (1 - Sqrt[5])/8, -Sqrt[3]/2}}], 
   Line[{{Cos[(29*Pi)/15]/2, Sin[(29*Pi)/15]/2, -Sqrt[3]/2}, \
{Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, -Sqrt[3]/2}, 
     {Cos[(59*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(29*Pi)/15], Cos[(13*Pi)/15]}, {Cos[(29*Pi)/15]/2, \
Sin[(29*Pi)/15]/2, -Sqrt[3]/2}}], 
   Line[{{Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, -Sqrt[3]/2}, {1/2, 0, \
-Sqrt[3]/2}, {Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, 
     {Cos[(59*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(59*Pi)/30]/2, Sin[(59*Pi)/30]/2, -Sqrt[3]/2}}], 
   Line[{{Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, {Cos[Pi/30]*Sin[(13*Pi)/15], \
Sin[Pi/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 \
+ Sqrt[5])/2]/2}, {(-1 + Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}}], \
Line[{{Cos[Pi/30]*Sin[(13*Pi)/15], Sin[Pi/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, 
     {Cos[Pi/15]*Sin[(13*Pi)/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + \
Sqrt[5])*Sin[Pi/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + \
Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[Pi/30]*Sin[(13*Pi)/15], Sin[Pi/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[Pi/15]*Sin[(13*Pi)/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + \
Sqrt[5])*Sin[Pi/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[Pi/15]*Sin[(13*Pi)/15], Sin[Pi/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(13*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, \
((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(13*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, 
      Cos[(13*Pi)/15]}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(2*Pi)/15]*Sin[(13*Pi)/15], Sin[(2*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + \
Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(7*Pi)/30]*Sin[(13*Pi)/15], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(13*Pi)/15], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(13*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(7*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(7*Pi)/30]*Sin[(13*Pi)/15], Sin[(7*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(4*Pi)/15]*Sin[(13*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(4*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(4*Pi)/15]*Sin[(13*Pi)/15], Sin[(4*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(-1 \
+ Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}], 
   Line[{{Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(13*Pi)/15], Sin[(11*Pi)/30]*Sin[(13*Pi)/15], 
      Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 
      Cos[(13*Pi)/15]}}], Line[{{Cos[(11*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(11*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
     {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 \
+ Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(11*Pi)/30]*Sin[(13*Pi)/15], Sin[(11*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(13*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, 
     {Cos[(7*Pi)/15]*Sin[(13*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(13*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/15]*Sin[(13*Pi)/15], Sin[(7*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {0, Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
     {0, (-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(7*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(7*Pi)/15]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}}], 
   Line[{{0, Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(13*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {0, (-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {0, Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(8*Pi)/15]*Sin[(13*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(17*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(8*Pi)/15]*Sin[(13*Pi)/15], Sin[(8*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(13*Pi)/15], Sin[(17*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {-(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(17*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/30]*Sin[(13*Pi)/15], Sin[(17*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(13*Pi)/15], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {-(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[(13*Pi)/15], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {-Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, 
      Cos[(13*Pi)/15]}, {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(19*Pi)/30]*Sin[(13*Pi)/15], Sin[(19*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{-Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-Sin[(13*Pi)/15]/2, (Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(11*Pi)/15]*Sin[(13*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[(13*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(23*Pi)/30]*Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(11*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(11*Pi)/15]*Sin[(13*Pi)/15], Sin[(11*Pi)/15]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(23*Pi)/30]*Sin[(13*Pi)/15], Sin[(23*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(23*Pi)/30]*Sin[(13*Pi)/15], Sin[(23*Pi)/30]*Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, \
(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]^2, 
      Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(13*Pi)/15])/2, Sin[(13*Pi)/15]/2, 
      Cos[(13*Pi)/15]}}], Line[{{Cos[(13*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]^2, Cos[(13*Pi)/15]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(13*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]^2, Cos[(13*Pi)/15]}}], \

   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(14*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, \
((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(29*Pi)/30], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(14*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(13*Pi)/15]}, {-Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, 
     {(1 - Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(29*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(29*Pi)/30], Cos[(13*Pi)/15]}}], 
   Line[{{-Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(13*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(31*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {-Sin[(13*Pi)/15], 0, \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(16*Pi)/15], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(16*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(31*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(16*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(16*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(17*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, \
-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(13*Pi)/15]}, {-(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, 
      Cos[(13*Pi)/15]}, {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, 
      -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(13*Pi)/15])/2, \
-Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(37*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, 
      -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(37*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(19*Pi)/15], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(19*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(37*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(19*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(19*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {-Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(1 \
- Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, \
-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}], 
   Line[{{-Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, \
{Cos[(41*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(41*Pi)/30], 
      Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, 
      Cos[(13*Pi)/15]}}], Line[{{Cos[(41*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(41*Pi)/30], Cos[(13*Pi)/15]}, 
     {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {-(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(41*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(41*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(13*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(43*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {-(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(13*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(22*Pi)/15], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(43*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(43*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(13*Pi)/15]}, {0, -Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, 
     {0, (1 - Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(22*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(22*Pi)/15], Cos[(13*Pi)/15]}}], 
   Line[{{0, -Sin[(13*Pi)/15], Cos[(13*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(13*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {0, (1 - Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {0, -Sin[(13*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(47*Pi)/30], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(47*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(23*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(47*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(47*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(13*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {Cos[(49*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
-(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(13*Pi)/15]}, {Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, 
      Cos[(13*Pi)/15]}, {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(49*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(13*Pi)/15]}}], 
   Line[{{Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Sin[(13*Pi)/15]/2, -(Sqrt[3]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(26*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(53*Pi)/30], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(53*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(26*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(26*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/15]}, {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(53*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(13*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}, 
     {(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(13*Pi)/15])/2, Cos[(13*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, Cos[(13*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(28*Pi)/15], 
      Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[3]*Sin[(13*Pi)/15])/2, -Sin[(13*Pi)/15]/2, 
      Cos[(13*Pi)/15]}}], Line[{{Cos[(28*Pi)/15]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(28*Pi)/15], Cos[(13*Pi)/15]}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(28*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}, 
     {Cos[(29*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(13*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(13*Pi)/15])/2, \
-((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(13*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(13*Pi)/15], 
      Sin[(13*Pi)/15]*Sin[(59*Pi)/30], Cos[(13*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(29*Pi)/15]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(13*Pi)/15]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(13*Pi)/15], Sin[(13*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(13*Pi)/15]}, {Sin[(13*Pi)/15], 0, Cos[(13*Pi)/15]}, 
     {(-1 + Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[(59*Pi)/30]*Sin[(13*Pi)/15], \
Sin[(13*Pi)/15]*Sin[(59*Pi)/30], Cos[(13*Pi)/15]}}], 
   Line[{{(-1 + Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {((-1 + \
Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}, {Cos[Pi/30]*Sin[(14*Pi)/15], \
Sin[Pi/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {Sin[(14*Pi)/15], 0, \
Cos[(14*Pi)/15]}, 
     {(-1 + Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + Sqrt[5])*Sin[Pi/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, -Sqrt[(5 \
+ Sqrt[5])/2]/2}, 
     {Cos[Pi/15]*Sin[(14*Pi)/15], Sin[Pi/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[Pi/30]*Sin[(14*Pi)/15], Sin[Pi/30]*Sin[(14*Pi)/15], 
      Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[Pi/30])/4, ((-1 + \
Sqrt[5])*Sin[Pi/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, -Sqrt[(5 \
+ Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{Cos[Pi/15]*Sin[(14*Pi)/15], Sin[Pi/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[Pi/15])/4, ((-1 + Sqrt[5])*Sin[Pi/15])/4, -Sqrt[(5 \
+ Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(2*Pi)/15]*Sin[(14*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(14*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(2*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(2*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(7*Pi)/30]*Sin[(14*Pi)/15], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(7*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(4*Pi)/15]*Sin[(14*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(7*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(7*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {Cos[(4*Pi)/15]*Sin[(14*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(4*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(4*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(11*Pi)/30]*Sin[(14*Pi)/15], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], 
      Cos[(14*Pi)/15]}, {Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}, {(-1 + Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -Sqrt[(5 \
+ Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(11*Pi)/30]*Sin[(14*Pi)/15], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(11*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(11*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(13*Pi)/30]*Sin[(14*Pi)/15], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(13*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(7*Pi)/15]*Sin[(14*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(13*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(13*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(7*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {0, (-1 + Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {0, Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(7*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(7*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(7*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{0, (-1 + Sqrt[5])/4, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(8*Pi)/15]*Sin[(14*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], 
      Cos[(14*Pi)/15]}, {0, Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {0, (-1 + \
Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(8*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/30]*Sin[(14*Pi)/15], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(8*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(8*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(8*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(8*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(14*Pi)/15], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(17*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(17*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-(-1 + Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(19*Pi)/30]*Sin[(14*Pi)/15], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-(-1 + \
Sqrt[5])^2/16, ((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(14*Pi)/15], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(19*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{-Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {(1 - Sqrt[5])/8, (Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(11*Pi)/15]*Sin[(14*Pi)/15], Sin[(11*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, ((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(11*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(23*Pi)/30]*Sin[(14*Pi)/15], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(11*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(11*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(23*Pi)/30]*Sin[(14*Pi)/15], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(23*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(23*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, 
      Cos[(14*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, (Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(13*Pi)/15]*Sin[(14*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], 
      Cos[(14*Pi)/15]}, {-(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}, {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (-1 + Sqrt[5])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(14*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(13*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(13*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(14*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]^2, Cos[(14*Pi)/15]}, \
{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, (-1 + Sqrt[5])^2/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(29*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(14*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]^2, 
      Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(14*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {-Sin[(14*Pi)/15], 0, \
Cos[(14*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(29*Pi)/30], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(29*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{(1 - Sqrt[5])/4, 0, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(31*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(31*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(31*Pi)/30], 
      Cos[(14*Pi)/15]}, {-Sin[(14*Pi)/15], 0, Cos[(14*Pi)/15]}, {(1 - \
Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(31*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(16*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(16*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(31*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(31*Pi)/30], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(31*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(31*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(16*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {Cos[(16*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(16*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(16*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(17*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(14*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, 
      Cos[(14*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(17*Pi)/15], Cos[(14*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(17*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(17*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{-(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, 
     {-(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}}], 
   Line[{{-((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(37*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(14*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-((-1 + \
Sqrt[5])*(1 + Sqrt[5]))/16, 
      -(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}}], \

   Line[{{((-1 + Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + \
Sqrt[5])*Sin[(37*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(19*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(19*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(37*Pi)/30], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(37*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(37*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(19*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {Cos[(19*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(19*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(19*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {-Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, 
      Cos[(14*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(41*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(41*Pi)/30], 
      Cos[(14*Pi)/15]}, {-Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, \
Cos[(14*Pi)/15]}, {(1 - Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(41*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(41*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(41*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{-(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(43*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(14*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(43*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(22*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(43*Pi)/30], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(43*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(43*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(22*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {0, (1 - Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, {0, -Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(22*Pi)/15], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(22*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(22*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{0, (1 - Sqrt[5])/4, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(23*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(23*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(23*Pi)/15], 
      Cos[(14*Pi)/15]}, {0, -Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, {0, (1 - \
Sqrt[5])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + \
Sqrt[5])*Sin[(23*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(47*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(47*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(23*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(23*Pi)/15], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(23*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(23*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(47*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(47*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(47*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(47*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(-1 + Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(49*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {(-1 + \
Sqrt[5])^2/16, -((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, 
      Cos[(14*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(49*Pi)/30], Cos[(14*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(49*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(49*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, 
      -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {(-1 + Sqrt[5])/8, -(Sqrt[3]*(-1 + Sqrt[5]))/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + \
Sqrt[5]))/16, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(26*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*(-1 + Sqrt[5]))/8, -((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(26*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(53*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(53*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(26*Pi)/15], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(26*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(26*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(53*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Cos[(53*Pi)/30])/4, 
      ((-1 + Sqrt[5])*Sin[(53*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, 
     {((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {((-1 + Sqrt[5])*(1 + Sqrt[5]))/16, -(Sqrt[(5 - Sqrt[5])/2]*(-1 + \
Sqrt[5]))/8, -Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, -Sqrt[(5 + \
Sqrt[5])/2]/2}, {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, 
      ((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, \
{Cos[(28*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(28*Pi)/15], 
      Cos[(14*Pi)/15]}, {(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, \
Cos[(14*Pi)/15]}, {(Sqrt[3]*(-1 + Sqrt[5]))/8, (1 - Sqrt[5])/8, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(14*Pi)/15]}, 
     {((-1 + Sqrt[5])*Cos[(28*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(28*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}}], 
   Line[{{((-1 + Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(29*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Sqrt[(5 + Sqrt[5])/2])/8, -(-1 + Sqrt[5])^2/16, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(29*Pi)/15])/4, \
((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, \
-Sqrt[(5 + Sqrt[5])/2]/2}, 
     {Cos[(59*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(29*Pi)/15], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(29*Pi)/15])/4, ((-1 + Sqrt[5])*Sin[(29*Pi)/15])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{((-1 + Sqrt[5])*Cos[(59*Pi)/30])/4, \
((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, -Sqrt[(5 + Sqrt[5])/2]/2}, 
     {(-1 + Sqrt[5])/4, 0, -Sqrt[(5 + Sqrt[5])/2]/2}, {Sin[(14*Pi)/15], 0, \
Cos[(14*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(59*Pi)/30], Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Cos[(59*Pi)/30])/4, ((-1 + Sqrt[5])*Sin[(59*Pi)/30])/4, 
      -Sqrt[(5 + Sqrt[5])/2]/2}}], Line[{{Sin[(14*Pi)/15], 0, \
Cos[(14*Pi)/15]}, {Cos[Pi/30]*Sin[(14*Pi)/15], Sin[Pi/30]*Sin[(14*Pi)/15], 
      Cos[(14*Pi)/15]}, {Cos[Pi/30]*Sin[(29*Pi)/30], \
Sin[Pi/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {Sin[(29*Pi)/30], 0, \
Cos[(29*Pi)/30]}, 
     {Sin[(14*Pi)/15], 0, Cos[(14*Pi)/15]}}], \
Line[{{Cos[Pi/30]*Sin[(14*Pi)/15], Sin[Pi/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, 
     {Cos[Pi/15]*Sin[(14*Pi)/15], Sin[Pi/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[Pi/15]*Sin[(29*Pi)/30], Sin[Pi/15]*Sin[(29*Pi)/30], 
      Cos[(29*Pi)/30]}, {Cos[Pi/30]*Sin[(29*Pi)/30], \
Sin[Pi/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {Cos[Pi/30]*Sin[(14*Pi)/15], Sin[Pi/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{Cos[Pi/15]*Sin[(14*Pi)/15], Sin[Pi/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {Cos[Pi/15]*Sin[(29*Pi)/30], \
Sin[Pi/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {Cos[Pi/15]*Sin[(14*Pi)/15], Sin[Pi/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {Cos[(2*Pi)/15]*Sin[(14*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(2*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(2*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(14*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, 
      Cos[(14*Pi)/15]}, {(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, \
Cos[(29*Pi)/30]}, {Cos[(2*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(2*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(2*Pi)/15]*Sin[(14*Pi)/15], Sin[(2*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, \
{((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, \
Cos[(29*Pi)/30]}, {(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, 
      Cos[(14*Pi)/15]}}], Line[{{((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(7*Pi)/30]*Sin[(14*Pi)/15], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(7*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(7*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(14*Pi)/15], Sin[(7*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(4*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(4*Pi)/15]*Sin[(29*Pi)/30], Sin[(4*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
     {Cos[(7*Pi)/30]*Sin[(29*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(7*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(7*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}], \
Line[{{Cos[(4*Pi)/15]*Sin[(14*Pi)/15], Sin[(4*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {Cos[(4*Pi)/15]*Sin[(29*Pi)/30], Sin[(4*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(4*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}], 
   Line[{{Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{Cos[(11*Pi)/30]*Sin[(14*Pi)/15], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], 
      Cos[(14*Pi)/15]}, {Cos[(11*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[(14*Pi)/15], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {Cos[(11*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(11*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {Cos[(11*Pi)/30]*Sin[(14*Pi)/15], Sin[(11*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(13*Pi)/30]*Sin[(14*Pi)/15], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(13*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(13*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(14*Pi)/15], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, 
     {Cos[(7*Pi)/15]*Sin[(14*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(7*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(7*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(13*Pi)/30]*Sin[(29*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
     {Cos[(13*Pi)/30]*Sin[(14*Pi)/15], Sin[(13*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(7*Pi)/15]*Sin[(14*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {0, Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, 
     {0, Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {Cos[(7*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(7*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {Cos[(7*Pi)/15]*Sin[(14*Pi)/15], Sin[(7*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{0, Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(8*Pi)/15]*Sin[(14*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, 
     {Cos[(8*Pi)/15]*Sin[(29*Pi)/30], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {0, Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}], \
Line[{{Cos[(8*Pi)/15]*Sin[(14*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, 
     {Cos[(17*Pi)/30]*Sin[(14*Pi)/15], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(17*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(29*Pi)/30], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
     {Cos[(8*Pi)/15]*Sin[(14*Pi)/15], Sin[(8*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(14*Pi)/15], Sin[(17*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(17*Pi)/30]*Sin[(29*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/30], 
      Cos[(29*Pi)/30]}, {Cos[(17*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(17*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(19*Pi)/30]*Sin[(14*Pi)/15], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(19*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[(14*Pi)/15], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {-Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 
      Cos[(14*Pi)/15]}, {-Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, \
Cos[(29*Pi)/30]}, {Cos[(19*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(19*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(19*Pi)/30]*Sin[(14*Pi)/15], Sin[(19*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{-Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      ((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {-Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, \
Cos[(29*Pi)/30]}, {-Sin[(14*Pi)/15]/2, (Sqrt[3]*Sin[(14*Pi)/15])/2, 
      Cos[(14*Pi)/15]}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, \
((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {Cos[(11*Pi)/15]*Sin[(14*Pi)/15], Sin[(11*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(11*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(11*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[(14*Pi)/15], Sin[(11*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(23*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(23*Pi)/30]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(23*Pi)/30]*Sin[(29*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
     {Cos[(11*Pi)/15]*Sin[(29*Pi)/30], Sin[(11*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(11*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(11*Pi)/15]*Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(23*Pi)/30]*Sin[(14*Pi)/15], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {Cos[(23*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(23*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {Cos[(23*Pi)/30]*Sin[(14*Pi)/15], Sin[(23*Pi)/30]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {-(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, \
{-(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, \
{Cos[(13*Pi)/15]*Sin[(14*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], 
      Cos[(14*Pi)/15]}, {Cos[(13*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(13*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, \
{-(Sqrt[3]*Sin[(14*Pi)/15])/2, Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(13*Pi)/15]*Sin[(14*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      ((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {Cos[(13*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(13*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {Cos[(13*Pi)/15]*Sin[(14*Pi)/15], Sin[(13*Pi)/15]*Sin[(14*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {Cos[(14*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]^2, Cos[(14*Pi)/15]}, \
{Cos[(14*Pi)/15]*Sin[(29*Pi)/30], Sin[(14*Pi)/15]*Sin[(29*Pi)/30], 
      Cos[(29*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, ((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]^2, \
Cos[(14*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(29*Pi)/30], 
      Cos[(14*Pi)/15]}, {Cos[(29*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]^2, \
Cos[(29*Pi)/30]}, 
     {Cos[(14*Pi)/15]*Sin[(29*Pi)/30], Sin[(14*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(14*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]^2, 
      Cos[(14*Pi)/15]}}], Line[{{Cos[(29*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(29*Pi)/30], Cos[(14*Pi)/15]}, 
     {-Sin[(14*Pi)/15], 0, Cos[(14*Pi)/15]}, {-Sin[(29*Pi)/30], 0, \
Cos[(29*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]^2, 
      Cos[(29*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(29*Pi)/30], Cos[(14*Pi)/15]}}], 
   Line[{{-Sin[(14*Pi)/15], 0, Cos[(14*Pi)/15]}, \
{Cos[(31*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(14*Pi)/15]}, 
     {Cos[(31*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(29*Pi)/30]}, {-Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, 
     {-Sin[(14*Pi)/15], 0, Cos[(14*Pi)/15]}}], \
Line[{{Cos[(31*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(14*Pi)/15]}, 
     {Cos[(16*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(16*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(16*Pi)/15], Cos[(29*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(29*Pi)/30]}, 
     {Cos[(31*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(31*Pi)/30], \
Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(14*Pi)/15]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(16*Pi)/15], Cos[(29*Pi)/30]}, 
     {Cos[(16*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(16*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {Cos[(17*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(17*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(17*Pi)/15], Cos[(29*Pi)/30]}, {-(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(14*Pi)/15]}, {-(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, 
      Cos[(14*Pi)/15]}, {-(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, \
Cos[(29*Pi)/30]}, {Cos[(17*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(17*Pi)/15], Cos[(29*Pi)/30]}, \
{Cos[(17*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(17*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{-(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, \
{-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{-(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(37*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(37*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(37*Pi)/30], Cos[(29*Pi)/30]}, {-((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(37*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(37*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(19*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(19*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(19*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(29*Pi)/30]}, 
     {Cos[(37*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(37*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(37*Pi)/30], Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(14*Pi)/15]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {-(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(19*Pi)/15], Cos[(29*Pi)/30]}, 
     {Cos[(19*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(19*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {-Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{-Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}], 
   Line[{{-Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{Cos[(41*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(41*Pi)/30], 
      Cos[(14*Pi)/15]}, {Cos[(41*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(41*Pi)/30], Cos[(29*Pi)/30]}, 
     {-Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{-Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(41*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(41*Pi)/30], \
Cos[(14*Pi)/15]}, {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {-((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(29*Pi)/30]}, {Cos[(41*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(41*Pi)/30], Cos[(14*Pi)/15]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(43*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(43*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(43*Pi)/30], Cos[(29*Pi)/30]}, {-((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(43*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(22*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(22*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(22*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(29*Pi)/30]}, 
     {Cos[(43*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(43*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(43*Pi)/30], Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(14*Pi)/15]}, {0, -Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, 
     {0, -Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(22*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(29*Pi)/30]}, 
     {Cos[(22*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(22*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{0, -Sin[(14*Pi)/15], Cos[(14*Pi)/15]}, \
{Cos[(23*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(14*Pi)/15]}, 
     {Cos[(23*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(29*Pi)/30]}, {0, -Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {0, -Sin[(14*Pi)/15], Cos[(14*Pi)/15]}}], \
Line[{{Cos[(23*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(14*Pi)/15]}, 
     {Cos[(47*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(47*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(47*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(29*Pi)/30]}, 
     {Cos[(23*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(23*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(47*Pi)/30], \
Cos[(14*Pi)/15]}, {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(47*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(47*Pi)/30], 
      Cos[(29*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(47*Pi)/30], Cos[(14*Pi)/15]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {Cos[(49*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(14*Pi)/15]}, {Cos[(49*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(49*Pi)/30], Cos[(29*Pi)/30]}, {((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(14*Pi)/15]}, {Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, 
      Cos[(14*Pi)/15]}, {Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, \
Cos[(29*Pi)/30]}, {Cos[(49*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(49*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(49*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(49*Pi)/30], \
Cos[(14*Pi)/15]}}], 
   Line[{{Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      -((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, \
Cos[(29*Pi)/30]}, {Sin[(14*Pi)/15]/2, -(Sqrt[3]*Sin[(14*Pi)/15])/2, 
      Cos[(14*Pi)/15]}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, \
-((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {Cos[(26*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(26*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(26*Pi)/15], Cos[(29*Pi)/30]}, {(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(26*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(53*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(53*Pi)/30], Cos[(14*Pi)/15]}, \
{Cos[(53*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(29*Pi)/30]}, 
     {Cos[(26*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(29*Pi)/30]}, {Cos[(26*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(26*Pi)/15], Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(53*Pi)/30], \
Cos[(14*Pi)/15]}, {((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, {((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(53*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(53*Pi)/30], 
      Cos[(29*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(14*Pi)/15], \
Sin[(14*Pi)/15]*Sin[(53*Pi)/30], Cos[(14*Pi)/15]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}, 
     {(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, \
{(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {((1 + Sqrt[5])*Sin[(14*Pi)/15])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(14*Pi)/15])/2, Cos[(14*Pi)/15]}}], 
   Line[{{(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}, \
{Cos[(28*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(28*Pi)/15], 
      Cos[(14*Pi)/15]}, {Cos[(28*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(28*Pi)/15], Cos[(29*Pi)/30]}, 
     {(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, \
{(Sqrt[3]*Sin[(14*Pi)/15])/2, -Sin[(14*Pi)/15]/2, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(28*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(14*Pi)/15]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, 
      -((-1 + Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {Cos[(28*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(28*Pi)/15], Cos[(29*Pi)/30]}, 
     {Cos[(28*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(28*Pi)/15], \
Cos[(14*Pi)/15]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}, 
     {Cos[(29*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(29*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(29*Pi)/15], Cos[(29*Pi)/30]}, {(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      Cos[(29*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(14*Pi)/15])/2, -((-1 + \
Sqrt[5])*Sin[(14*Pi)/15])/4, Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(29*Pi)/15], \
Cos[(14*Pi)/15]}, {Cos[(59*Pi)/30]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(59*Pi)/30], Cos[(14*Pi)/15]}, \
{Cos[(59*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(29*Pi)/30]}, 
     {Cos[(29*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(29*Pi)/30]}, {Cos[(29*Pi)/15]*Sin[(14*Pi)/15], 
      Sin[(14*Pi)/15]*Sin[(29*Pi)/15], Cos[(14*Pi)/15]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(14*Pi)/15]}, {Sin[(14*Pi)/15], 0, Cos[(14*Pi)/15]}, 
     {Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(59*Pi)/30], Cos[(29*Pi)/30]}, 
     {Cos[(59*Pi)/30]*Sin[(14*Pi)/15], Sin[(14*Pi)/15]*Sin[(59*Pi)/30], \
Cos[(14*Pi)/15]}}], 
   Line[{{Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, {Cos[Pi/30]*Sin[(29*Pi)/30], \
Sin[Pi/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}}], \
Line[{{Cos[Pi/30]*Sin[(29*Pi)/30], Sin[Pi/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
     {Cos[Pi/15]*Sin[(29*Pi)/30], Sin[Pi/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {Cos[Pi/30]*Sin[(29*Pi)/30], Sin[Pi/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}], 
   Line[{{Cos[Pi/15]*Sin[(29*Pi)/30], Sin[Pi/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}, {Cos[Pi/15]*Sin[(29*Pi)/30], Sin[Pi/15]*Sin[(29*Pi)/30], 
      Cos[(29*Pi)/30]}}], Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, \
((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {Cos[(2*Pi)/15]*Sin[(29*Pi)/30], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(2*Pi)/15]*Sin[(29*Pi)/30], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, 
      Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, \
{Cos[(2*Pi)/15]*Sin[(29*Pi)/30], Sin[(2*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, \
{((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}, {(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, 
      Cos[(29*Pi)/30]}}], Line[{{((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 \
- Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {Cos[(7*Pi)/30]*Sin[(29*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(7*Pi)/30]*Sin[(29*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(4*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(4*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}, {Cos[(7*Pi)/30]*Sin[(29*Pi)/30], Sin[(7*Pi)/30]*Sin[(29*Pi)/30], 
      Cos[(29*Pi)/30]}}], Line[{{Cos[(4*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(4*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {Cos[(4*Pi)/15]*Sin[(29*Pi)/30], Sin[(4*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}], 
   Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, \
0, -1}, {0, 0, -1}, {(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}], \
Line[{{Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {Cos[(11*Pi)/30]*Sin[(29*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(11*Pi)/30]*Sin[(29*Pi)/30], Sin[(11*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}, {Cos[(11*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(11*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {Cos[(13*Pi)/30]*Sin[(29*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(13*Pi)/30]*Sin[(29*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
     {Cos[(7*Pi)/15]*Sin[(29*Pi)/30], Sin[(7*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {Cos[(13*Pi)/30]*Sin[(29*Pi)/30], Sin[(13*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(7*Pi)/15]*Sin[(29*Pi)/30], Sin[(7*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, 
     {0, 0, -1}, {Cos[(7*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(7*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{0, Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(8*Pi)/15]*Sin[(29*Pi)/30], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, 
     {0, 0, -1}, {0, Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}], \
Line[{{Cos[(8*Pi)/15]*Sin[(29*Pi)/30], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, 
     {Cos[(17*Pi)/30]*Sin[(29*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {Cos[(8*Pi)/15]*Sin[(29*Pi)/30], Sin[(8*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/30]*Sin[(29*Pi)/30], Sin[(17*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      (Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}, {Cos[(17*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(17*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {Cos[(19*Pi)/30]*Sin[(29*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {-((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(19*Pi)/30]*Sin[(29*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {-Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, \
{Cos[(19*Pi)/30]*Sin[(29*Pi)/30], Sin[(19*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}], 
   Line[{{-Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      ((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}, {-Sin[(29*Pi)/30]/2, (Sqrt[3]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}}], Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, \
((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {Cos[(11*Pi)/15]*Sin[(29*Pi)/30], Sin[(11*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(11*Pi)/15]*Sin[(29*Pi)/30], Sin[(11*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(23*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}, {Cos[(11*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(11*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(23*Pi)/30]*Sin[(29*Pi)/30], Sin[(23*Pi)/30]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      (Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}, {Cos[(23*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(23*Pi)/30]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {-(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, {0, \
0, -1}, {0, 0, -1}, 
     {-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, (Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, \
{Cos[(13*Pi)/15]*Sin[(29*Pi)/30], Sin[(13*Pi)/15]*Sin[(29*Pi)/30], 
      Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, \
{-(Sqrt[3]*Sin[(29*Pi)/30])/2, Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(13*Pi)/15]*Sin[(29*Pi)/30], Sin[(13*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      ((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}, {Cos[(13*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(13*Pi)/15]*Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {Cos[(14*Pi)/15]*Sin[(29*Pi)/30], Sin[(14*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, ((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(14*Pi)/15]*Sin[(29*Pi)/30], Sin[(14*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(29*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]^2, 
      Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, \
{Cos[(14*Pi)/15]*Sin[(29*Pi)/30], Sin[(14*Pi)/15]*Sin[(29*Pi)/30], \
Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]^2, \
Cos[(29*Pi)/30]}, {-Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}, 
     {Cos[(29*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]^2, Cos[(29*Pi)/30]}}], \

   Line[{{-Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, \
{Cos[(31*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, 
     {0, 0, -1}, {-Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(31*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(31*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(16*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(16*Pi)/15], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}, {Cos[(31*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(31*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(16*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(16*Pi)/15], \
Cos[(29*Pi)/30]}, {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}, {Cos[(16*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(16*Pi)/15], Cos[(29*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {Cos[(17*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {-(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(17*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(29*Pi)/30]}, {-(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, 
      Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, \
{Cos[(17*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(17*Pi)/15], \
Cos[(29*Pi)/30]}}], 
   Line[{{-(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, \
{-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}, {-(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, 
      Cos[(29*Pi)/30]}}], Line[{{-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, \
-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {Cos[(37*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(37*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(37*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(19*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(19*Pi)/15], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}, {Cos[(37*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(37*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(19*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(19*Pi)/15], \
Cos[(29*Pi)/30]}, {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}, {Cos[(19*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(19*Pi)/15], Cos[(29*Pi)/30]}}], 
   Line[{{-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {-Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, \
0, -1}, {0, 0, -1}, 
     {-(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}], 
   Line[{{-Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{Cos[(41*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(41*Pi)/30], 
      Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, {-Sin[(29*Pi)/30]/2, \
-(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(41*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(41*Pi)/30], \
Cos[(29*Pi)/30]}, {-((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}, {Cos[(41*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(41*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{-((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {Cos[(43*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {-((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(43*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(43*Pi)/30], \
Cos[(29*Pi)/30]}, {Cos[(22*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(22*Pi)/15], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}, {Cos[(43*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(43*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(22*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(22*Pi)/15], \
Cos[(29*Pi)/30]}, {0, -Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, 
     {0, 0, -1}, {Cos[(22*Pi)/15]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(22*Pi)/15], Cos[(29*Pi)/30]}}], 
   Line[{{0, -Sin[(29*Pi)/30], Cos[(29*Pi)/30]}, \
{Cos[(23*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(29*Pi)/30]}, {0, 0, -1}, 
     {0, 0, -1}, {0, -Sin[(29*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(23*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(23*Pi)/15], \
Cos[(29*Pi)/30]}, {Cos[(47*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(47*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}, {Cos[(23*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(23*Pi)/15], Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(47*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(47*Pi)/30], \
Cos[(29*Pi)/30]}, {((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}, {Cos[(47*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(47*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {Cos[(49*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 + \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(49*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(29*Pi)/30]}, {Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, \
{Cos[(49*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(49*Pi)/30], \
Cos[(29*Pi)/30]}}], 
   Line[{{Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, \
{(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      -((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}, {Sin[(29*Pi)/30]/2, -(Sqrt[3]*Sin[(29*Pi)/30])/2, 
      Cos[(29*Pi)/30]}}], Line[{{(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, \
-((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {Cos[(26*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(26*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(26*Pi)/15], \
Cos[(29*Pi)/30]}, {Cos[(53*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(53*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}, {Cos[(26*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(26*Pi)/15], Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(53*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(53*Pi)/30], \
Cos[(29*Pi)/30]}, {((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, 
      -(Sqrt[(5 - Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, {0, 0, \
-1}, {0, 0, -1}, {Cos[(53*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(53*Pi)/30], Cos[(29*Pi)/30]}}], 
   Line[{{((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}, 
     {(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, {0, \
0, -1}, {0, 0, -1}, 
     {((1 + Sqrt[5])*Sin[(29*Pi)/30])/4, -(Sqrt[(5 - \
Sqrt[5])/2]*Sin[(29*Pi)/30])/2, Cos[(29*Pi)/30]}}], 
   Line[{{(Sqrt[3]*Sin[(29*Pi)/30])/2, -Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}, \
{Cos[(28*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(28*Pi)/15], 
      Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, {(Sqrt[3]*Sin[(29*Pi)/30])/2, \
-Sin[(29*Pi)/30]/2, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(28*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(28*Pi)/15], \
Cos[(29*Pi)/30]}, {(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, 
      -((-1 + Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, {0, 0, -1}, {0, \
0, -1}, {Cos[(28*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(28*Pi)/15], Cos[(29*Pi)/30]}}], 
   Line[{{(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}, 
     {Cos[(29*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, -1}, 
     {(Sqrt[(5 + Sqrt[5])/2]*Sin[(29*Pi)/30])/2, -((-1 + \
Sqrt[5])*Sin[(29*Pi)/30])/4, Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(29*Pi)/15]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(29*Pi)/15], \
Cos[(29*Pi)/30]}, {Cos[(59*Pi)/30]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(59*Pi)/30], Cos[(29*Pi)/30]}, {0, 0, -1}, {0, 0, \
-1}, {Cos[(29*Pi)/15]*Sin[(29*Pi)/30], 
      Sin[(29*Pi)/30]*Sin[(29*Pi)/15], Cos[(29*Pi)/30]}}], 
   Line[{{Cos[(59*Pi)/30]*Sin[(29*Pi)/30], Sin[(29*Pi)/30]*Sin[(59*Pi)/30], \
Cos[(29*Pi)/30]}, {Sin[(29*Pi)/30], 0, Cos[(29*Pi)/30]}, {0, 0, -1}, 
     {0, 0, -1}, {Cos[(59*Pi)/30]*Sin[(29*Pi)/30], \
Sin[(29*Pi)/30]*Sin[(59*Pi)/30], Cos[(29*Pi)/30]}}]}}, {Lighting -> False}]\
\>", "\<\
-Graphics3D-\
\>"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
load MeanNode and Closedline only if the ParametricMesh package is not loaded \
\
\>", "Subsection"],

Cell["\<\

MeanNode[ nl_] := 0.25 Plus @@  Drop[nl, -1]
ClosedLine[ ptlist_ ] := Line[ Append[ ptlist, First[ptlist]] ]
\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
Thread[ {t0, t1, ndt} = N[ { 0, Pi, Pi / 30} ]]
Thread[ {p0, p1, ndp} = N[{0,  2 Pi, Pi / 30} ] ]\
\>", "Input"],

Cell[OutputFormData["\<\
{0., 3.141592653589793, 0.10471975511965977}\
\>", "\<\
{0., 3.14159, 0.10472}\
\>"], "Output"],

Cell[OutputFormData["\<\
{0., 6.283185307179586, 0.10471975511965977}\
\>", "\<\
{0., 6.28319, 0.10472}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["f = { ns , tau2^0.5} /. srule ", "Input"],

Cell[OutputFormData["\<\
{-Cos[t]^2 + 5*Cos[p]^2*Sin[t]^2 + 2*Sin[p]^2*Sin[t]^2, (Cos[t]^2 + \
25*Cos[p]^2*Sin[t]^2 + 4*Sin[p]^2*Sin[t]^2 - 
   (-Cos[t]^2 + 5*Cos[p]^2*Sin[t]^2 + 2*Sin[p]^2*Sin[t]^2)^2)^0.5}\
\>", "\<\
        2           2       2           2       2         2            2      \
 2           2       2
{-Cos[t]  + 5 Cos[p]  Sin[t]  + 2 Sin[p]  Sin[t] , (Cos[t]  + 25 Cos[p]  \
Sin[t]  + 4 Sin[p]  Sin[t]  - 
 
             2           2       2           2       2 2 0.5
     (-Cos[t]  + 5 Cos[p]  Sin[t]  + 2 Sin[p]  Sin[t] ) )   }\
\>"], "Output"]
}, Open  ]],

Cell["\<\
    tt = Range @@ {t0, t1, ndt};
    pp = Range @@ {p0, p1, ndp};
    thenodes = Outer[ List, tt, pp] ;  
    
    meshnodes = Map[ f  /.Thread[{t,p}\[Rule]#]&, thenodes, {2}];
    thequads = Map[   Flatten[#,1][[{1,2,4,3}]]  & ,Flatten[ Partition[ \
meshnodes, {2,2}, {1,1}], 1]];
    themesh = Map[ ClosedLine, thequads];\
\>", "Input"],

Cell[CellGroupData[{

Cell["Show[ Graphics[ themesh ]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.15873 0.0147151 0.197282 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .01472 L
.03416 .13726 L
.03422 .13777 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03399 .13576 L
.03416 .13726 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03372 .13329 L
.03399 .13576 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03335 .12991 L
.03372 .13329 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03291 .12567 L
.03335 .12991 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03242 .12068 L
.03291 .12567 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03189 .11505 L
.03242 .12068 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03134 .10895 L
.03189 .11505 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03081 .10257 L
.03134 .10895 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03031 .09615 L
.03081 .10257 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02987 .09001 L
.03031 .09615 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02951 .08453 L
.02987 .09001 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02924 .08012 L
.02951 .08453 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02907 .07724 L
.02924 .08012 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02901 .07624 L
.02907 .07724 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02907 .07724 L
.02901 .07624 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02924 .08012 L
.02907 .07724 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02951 .08453 L
.02924 .08012 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02987 .09001 L
.02951 .08453 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03031 .09615 L
.02987 .09001 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03081 .10257 L
.03031 .09615 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03134 .10895 L
.03081 .10257 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03189 .11505 L
.03134 .10895 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03242 .12068 L
.03189 .11505 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03291 .12567 L
.03242 .12068 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03335 .12991 L
.03291 .12567 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03372 .13329 L
.03335 .12991 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03399 .13576 L
.03372 .13329 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03416 .13726 L
.03399 .13576 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03422 .13777 L
.03416 .13726 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03416 .13726 L
.03422 .13777 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03399 .13576 L
.03416 .13726 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03372 .13329 L
.03399 .13576 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03335 .12991 L
.03372 .13329 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03291 .12567 L
.03335 .12991 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03242 .12068 L
.03291 .12567 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03189 .11505 L
.03242 .12068 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03134 .10895 L
.03189 .11505 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03081 .10257 L
.03134 .10895 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03031 .09615 L
.03081 .10257 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02987 .09001 L
.03031 .09615 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02951 .08453 L
.02987 .09001 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02924 .08012 L
.02951 .08453 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02907 .07724 L
.02924 .08012 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02901 .07624 L
.02907 .07724 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02907 .07724 L
.02901 .07624 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02924 .08012 L
.02907 .07724 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02951 .08453 L
.02924 .08012 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.02987 .09001 L
.02951 .08453 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03031 .09615 L
.02987 .09001 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03081 .10257 L
.03031 .09615 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03134 .10895 L
.03081 .10257 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03189 .11505 L
.03134 .10895 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03242 .12068 L
.03189 .11505 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03291 .12567 L
.03242 .12068 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03335 .12991 L
.03291 .12567 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03372 .13329 L
.03335 .12991 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03399 .13576 L
.03372 .13329 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03416 .13726 L
.03399 .13576 L
.02381 .01472 L
s
.02381 .01472 m
.02381 .01472 L
.03422 .13777 L
.03416 .13726 L
.02381 .01472 L
s
.03422 .13777 m
.03416 .13726 L
.06475 .25447 L
.06498 .25544 L
.03422 .13777 L
s
.03416 .13726 m
.03399 .13576 L
.06409 .25156 L
.06475 .25447 L
.03416 .13726 L
s
.03399 .13576 m
.03372 .13329 L
.06301 .24678 L
.06409 .25156 L
.03399 .13576 L
s
.03372 .13329 m
.03335 .12991 L
.06157 .24021 L
.06301 .24678 L
.03372 .13329 L
s
.03335 .12991 m
.03291 .12567 L
.05983 .23198 L
.06157 .24021 L
.03335 .12991 L
s
.03291 .12567 m
.03242 .12068 L
.05787 .22228 L
.05983 .23198 L
.03291 .12567 L
s
.03242 .12068 m
.03189 .11505 L
.05576 .21131 L
.05787 .22228 L
.03242 .12068 L
s
.03189 .11505 m
.03134 .10895 L
.05361 .1994 L
.05576 .21131 L
.03189 .11505 L
s
.03134 .10895 m
.03081 .10257 L
.05151 .18691 L
.05361 .1994 L
.03134 .10895 L
s
.03081 .10257 m
.03031 .09615 L
.04954 .17432 L
.05151 .18691 L
.03081 .10257 L
s
.03031 .09615 m
.02987 .09001 L
.0478 .16225 L
.04954 .17432 L
.03031 .09615 L
s
.02987 .09001 m
.02951 .08453 L
.04636 .15144 L
.0478 .16225 L
.02987 .09001 L
s
.02951 .08453 m
.02924 .08012 L
.04528 .14275 L
.04636 .15144 L
.02951 .08453 L
s
.02924 .08012 m
.02907 .07724 L
.04462 .13706 L
.04528 .14275 L
.02924 .08012 L
s
.02907 .07724 m
.02901 .07624 L
.04439 .13508 L
.04462 .13706 L
.02907 .07724 L
s
.02901 .07624 m
.02907 .07724 L
.04462 .13706 L
.04439 .13508 L
.02901 .07624 L
s
.02907 .07724 m
.02924 .08012 L
.04528 .14275 L
.04462 .13706 L
.02907 .07724 L
s
.02924 .08012 m
.02951 .08453 L
.04636 .15144 L
.04528 .14275 L
.02924 .08012 L
s
.02951 .08453 m
.02987 .09001 L
.0478 .16225 L
.04636 .15144 L
.02951 .08453 L
s
.02987 .09001 m
.03031 .09615 L
.04954 .17432 L
.0478 .16225 L
.02987 .09001 L
s
.03031 .09615 m
.03081 .10257 L
.05151 .18691 L
.04954 .17432 L
.03031 .09615 L
s
.03081 .10257 m
.03134 .10895 L
.05361 .1994 L
.05151 .18691 L
.03081 .10257 L
s
.03134 .10895 m
.03189 .11505 L
.05576 .21131 L
.05361 .1994 L
.03134 .10895 L
s
.03189 .11505 m
.03242 .12068 L
.05787 .22228 L
.05576 .21131 L
.03189 .11505 L
s
.03242 .12068 m
.03291 .12567 L
.05983 .23198 L
.05787 .22228 L
.03242 .12068 L
s
.03291 .12567 m
.03335 .12991 L
.06157 .24021 L
.05983 .23198 L
.03291 .12567 L
s
.03335 .12991 m
.03372 .13329 L
.06301 .24678 L
.06157 .24021 L
.03335 .12991 L
s
.03372 .13329 m
.03399 .13576 L
.06409 .25156 L
.06301 .24678 L
.03372 .13329 L
s
.03399 .13576 m
.03416 .13726 L
.06475 .25447 L
.06409 .25156 L
.03399 .13576 L
s
.03416 .13726 m
.03422 .13777 L
.06498 .25544 L
.06475 .25447 L
.03416 .13726 L
s
.03422 .13777 m
.03416 .13726 L
.06475 .25447 L
.06498 .25544 L
.03422 .13777 L
s
.03416 .13726 m
.03399 .13576 L
.06409 .25156 L
.06475 .25447 L
.03416 .13726 L
s
.03399 .13576 m
.03372 .13329 L
.06301 .24678 L
.06409 .25156 L
.03399 .13576 L
s
.03372 .13329 m
.03335 .12991 L
.06157 .24021 L
.06301 .24678 L
.03372 .13329 L
s
.03335 .12991 m
.03291 .12567 L
.05983 .23198 L
.06157 .24021 L
.03335 .12991 L
s
.03291 .12567 m
.03242 .12068 L
.05787 .22228 L
.05983 .23198 L
.03291 .12567 L
s
.03242 .12068 m
.03189 .11505 L
.05576 .21131 L
.05787 .22228 L
.03242 .12068 L
s
.03189 .11505 m
.03134 .10895 L
.05361 .1994 L
.05576 .21131 L
.03189 .11505 L
s
.03134 .10895 m
.03081 .10257 L
.05151 .18691 L
.05361 .1994 L
.03134 .10895 L
s
.03081 .10257 m
.03031 .09615 L
.04954 .17432 L
.05151 .18691 L
.03081 .10257 L
s
.03031 .09615 m
.02987 .09001 L
.0478 .16225 L
.04954 .17432 L
.03031 .09615 L
s
.02987 .09001 m
.02951 .08453 L
.04636 .15144 L
.0478 .16225 L
.02987 .09001 L
s
.02951 .08453 m
.02924 .08012 L
.04528 .14275 L
.04636 .15144 L
.02951 .08453 L
s
.02924 .08012 m
.02907 .07724 L
.04462 .13706 L
.04528 .14275 L
.02924 .08012 L
s
.02907 .07724 m
.02901 .07624 L
.04439 .13508 L
.04462 .13706 L
.02907 .07724 L
s
.02901 .07624 m
.02907 .07724 L
.04462 .13706 L
.04439 .13508 L
.02901 .07624 L
s
.02907 .07724 m
.02924 .08012 L
.04528 .14275 L
.04462 .13706 L
.02907 .07724 L
s
.02924 .08012 m
.02951 .08453 L
.04636 .15144 L
.04528 .14275 L
.02924 .08012 L
s
.02951 .08453 m
.02987 .09001 L
.0478 .16225 L
.04636 .15144 L
.02951 .08453 L
s
.02987 .09001 m
.03031 .09615 L
.04954 .17432 L
.0478 .16225 L
.02987 .09001 L
s
.03031 .09615 m
.03081 .10257 L
.05151 .18691 L
.04954 .17432 L
.03031 .09615 L
s
.03081 .10257 m
.03134 .10895 L
.05361 .1994 L
.05151 .18691 L
.03081 .10257 L
s
.03134 .10895 m
.03189 .11505 L
.05576 .21131 L
.05361 .1994 L
.03134 .10895 L
s
.03189 .11505 m
.03242 .12068 L
.05787 .22228 L
.05576 .21131 L
.03189 .11505 L
s
.03242 .12068 m
.03291 .12567 L
.05983 .23198 L
.05787 .22228 L
.03242 .12068 L
s
.03291 .12567 m
.03335 .12991 L
.06157 .24021 L
.05983 .23198 L
.03291 .12567 L
s
.03335 .12991 m
.03372 .13329 L
.06301 .24678 L
.06157 .24021 L
.03335 .12991 L
s
.03372 .13329 m
.03399 .13576 L
.06409 .25156 L
.06301 .24678 L
.03372 .13329 L
s
.03399 .13576 m
.03416 .13726 L
.06475 .25447 L
.06409 .25156 L
.03399 .13576 L
s
.03416 .13726 m
.03422 .13777 L
.06498 .25544 L
.06475 .25447 L
.03416 .13726 L
s
.06498 .25544 m
.06475 .25447 L
.11426 .36121 L
.11475 .36259 L
.06498 .25544 L
s
.06475 .25447 m
.06409 .25156 L
.11279 .3571 L
.11426 .36121 L
.06475 .25447 L
s
.06409 .25156 m
.06301 .24678 L
.11041 .35032 L
.11279 .3571 L
.06409 .25156 L
s
.06301 .24678 m
.06157 .24021 L
.10723 .34097 L
.11041 .35032 L
.06301 .24678 L
s
.06157 .24021 m
.05983 .23198 L
.10339 .32924 L
.10723 .34097 L
.06157 .24021 L
s
.05983 .23198 m
.05787 .22228 L
.09904 .31535 L
.10339 .32924 L
.05983 .23198 L
s
.05787 .22228 m
.05576 .21131 L
.09439 .29962 L
.09904 .31535 L
.05787 .22228 L
s
.05576 .21131 m
.05361 .1994 L
.08964 .28245 L
.09439 .29962 L
.05576 .21131 L
s
.05361 .1994 m
.05151 .18691 L
.08499 .26439 L
.08964 .28245 L
.05361 .1994 L
s
.05151 .18691 m
.04954 .17432 L
.08065 .24611 L
.08499 .26439 L
.05151 .18691 L
s
.04954 .17432 m
.0478 .16225 L
.0768 .22852 L
.08065 .24611 L
.04954 .17432 L
s
.0478 .16225 m
.04636 .15144 L
.07362 .2127 L
.0768 .22852 L
.0478 .16225 L
s
.04636 .15144 m
.04528 .14275 L
.07125 .19995 L
.07362 .2127 L
.04636 .15144 L
s
.04528 .14275 m
.04462 .13706 L
.06978 .19158 L
.07125 .19995 L
.04528 .14275 L
s
.04462 .13706 m
.04439 .13508 L
.06928 .18865 L
.06978 .19158 L
.04462 .13706 L
s
.04439 .13508 m
.04462 .13706 L
.06978 .19158 L
.06928 .18865 L
.04439 .13508 L
s
.04462 .13706 m
.04528 .14275 L
.07125 .19995 L
.06978 .19158 L
.04462 .13706 L
s
.04528 .14275 m
.04636 .15144 L
.07362 .2127 L
.07125 .19995 L
.04528 .14275 L
s
.04636 .15144 m
.0478 .16225 L
.0768 .22852 L
.07362 .2127 L
.04636 .15144 L
s
.0478 .16225 m
.04954 .17432 L
.08065 .24611 L
.0768 .22852 L
.0478 .16225 L
s
.04954 .17432 m
.05151 .18691 L
.08499 .26439 L
.08065 .24611 L
.04954 .17432 L
s
.05151 .18691 m
.05361 .1994 L
.08964 .28245 L
.08499 .26439 L
.05151 .18691 L
s
.05361 .1994 m
.05576 .21131 L
.09439 .29962 L
.08964 .28245 L
.05361 .1994 L
s
.05576 .21131 m
.05787 .22228 L
.09904 .31535 L
.09439 .29962 L
.05576 .21131 L
s
.05787 .22228 m
.05983 .23198 L
.10339 .32924 L
.09904 .31535 L
.05787 .22228 L
s
.05983 .23198 m
.06157 .24021 L
.10723 .34097 L
.10339 .32924 L
.05983 .23198 L
s
.06157 .24021 m
.06301 .24678 L
.11041 .35032 L
.10723 .34097 L
.06157 .24021 L
s
.06301 .24678 m
.06409 .25156 L
.11279 .3571 L
.11041 .35032 L
.06301 .24678 L
s
.06409 .25156 m
.06475 .25447 L
.11426 .36121 L
.11279 .3571 L
.06409 .25156 L
s
.06475 .25447 m
.06498 .25544 L
.11475 .36259 L
.11426 .36121 L
.06475 .25447 L
s
.06498 .25544 m
.06475 .25447 L
.11426 .36121 L
.11475 .36259 L
.06498 .25544 L
s
.06475 .25447 m
.06409 .25156 L
.11279 .3571 L
.11426 .36121 L
.06475 .25447 L
s
.06409 .25156 m
.06301 .24678 L
.11041 .35032 L
.11279 .3571 L
.06409 .25156 L
s
.06301 .24678 m
.06157 .24021 L
.10723 .34097 L
.11041 .35032 L
.06301 .24678 L
s
.06157 .24021 m
.05983 .23198 L
.10339 .32924 L
.10723 .34097 L
.06157 .24021 L
s
.05983 .23198 m
.05787 .22228 L
.09904 .31535 L
.10339 .32924 L
.05983 .23198 L
s
.05787 .22228 m
.05576 .21131 L
.09439 .29962 L
.09904 .31535 L
.05787 .22228 L
s
.05576 .21131 m
.05361 .1994 L
.08964 .28245 L
.09439 .29962 L
.05576 .21131 L
s
.05361 .1994 m
.05151 .18691 L
.08499 .26439 L
.08964 .28245 L
.05361 .1994 L
s
.05151 .18691 m
.04954 .17432 L
.08065 .24611 L
.08499 .26439 L
.05151 .18691 L
s
.04954 .17432 m
.0478 .16225 L
.0768 .22852 L
.08065 .24611 L
.04954 .17432 L
s
.0478 .16225 m
.04636 .15144 L
.07362 .2127 L
.0768 .22852 L
.0478 .16225 L
s
.04636 .15144 m
.04528 .14275 L
.07125 .19995 L
.07362 .2127 L
.04636 .15144 L
s
.04528 .14275 m
.04462 .13706 L
.06978 .19158 L
.07125 .19995 L
.04528 .14275 L
s
.04462 .13706 m
.04439 .13508 L
.06928 .18865 L
.06978 .19158 L
.04462 .13706 L
s
.04439 .13508 m
.04462 .13706 L
.06978 .19158 L
.06928 .18865 L
.04439 .13508 L
s
.04462 .13706 m
.04528 .14275 L
.07125 .19995 L
.06978 .19158 L
.04462 .13706 L
s
.04528 .14275 m
.04636 .15144 L
.07362 .2127 L
.07125 .19995 L
.04528 .14275 L
s
.04636 .15144 m
.0478 .16225 L
.0768 .22852 L
.07362 .2127 L
.04636 .15144 L
s
.0478 .16225 m
.04954 .17432 L
.08065 .24611 L
.0768 .22852 L
.0478 .16225 L
s
.04954 .17432 m
.05151 .18691 L
.08499 .26439 L
.08065 .24611 L
.04954 .17432 L
s
.05151 .18691 m
.05361 .1994 L
.08964 .28245 L
.08499 .26439 L
.05151 .18691 L
s
.05361 .1994 m
.05576 .21131 L
.09439 .29962 L
.08964 .28245 L
.05361 .1994 L
s
.05576 .21131 m
.05787 .22228 L
.09904 .31535 L
.09439 .29962 L
.05576 .21131 L
s
.05787 .22228 m
.05983 .23198 L
.10339 .32924 L
.09904 .31535 L
.05787 .22228 L
s
.05983 .23198 m
.06157 .24021 L
.10723 .34097 L
.10339 .32924 L
.05983 .23198 L
s
.06157 .24021 m
.06301 .24678 L
.11041 .35032 L
.10723 .34097 L
.06157 .24021 L
s
.06301 .24678 m
.06409 .25156 L
.11279 .3571 L
.11041 .35032 L
.06301 .24678 L
s
.06409 .25156 m
.06475 .25447 L
.11426 .36121 L
.11279 .3571 L
.06409 .25156 L
s
.06475 .25447 m
.06498 .25544 L
.11475 .36259 L
.11426 .36121 L
.06475 .25447 L
s
.11475 .36259 m
.11426 .36121 L
.18051 .45285 L
.18137 .45454 L
.11475 .36259 L
s
.11426 .36121 m
.11279 .3571 L
.17796 .44781 L
.18051 .45285 L
.11426 .36121 L
s
.11279 .3571 m
.11041 .35032 L
.17384 .43948 L
.17796 .44781 L
.11279 .3571 L
s
.11041 .35032 m
.10723 .34097 L
.16833 .42796 L
.17384 .43948 L
.11041 .35032 L
s
.10723 .34097 m
.10339 .32924 L
.16167 .41343 L
.16833 .42796 L
.10723 .34097 L
s
.10339 .32924 m
.09904 .31535 L
.15415 .39615 L
.16167 .41343 L
.10339 .32924 L
s
.09904 .31535 m
.09439 .29962 L
.14609 .37646 L
.15415 .39615 L
.09904 .31535 L
s
.09439 .29962 m
.08964 .28245 L
.13786 .35485 L
.14609 .37646 L
.09439 .29962 L
s
.08964 .28245 m
.08499 .26439 L
.12981 .33198 L
.13786 .35485 L
.08964 .28245 L
s
.08499 .26439 m
.08065 .24611 L
.12228 .30871 L
.12981 .33198 L
.08499 .26439 L
s
.08065 .24611 m
.0768 .22852 L
.11562 .28617 L
.12228 .30871 L
.08065 .24611 L
s
.0768 .22852 m
.07362 .2127 L
.11011 .2658 L
.11562 .28617 L
.0768 .22852 L
s
.07362 .2127 m
.07125 .19995 L
.10599 .2493 L
.11011 .2658 L
.07362 .2127 L
s
.07125 .19995 m
.06978 .19158 L
.10345 .23844 L
.10599 .2493 L
.07125 .19995 L
s
.06978 .19158 m
.06928 .18865 L
.10259 .23463 L
.10345 .23844 L
.06978 .19158 L
s
.06928 .18865 m
.06978 .19158 L
.10345 .23844 L
.10259 .23463 L
.06928 .18865 L
s
.06978 .19158 m
.07125 .19995 L
.10599 .2493 L
.10345 .23844 L
.06978 .19158 L
s
.07125 .19995 m
.07362 .2127 L
.11011 .2658 L
.10599 .2493 L
.07125 .19995 L
s
.07362 .2127 m
.0768 .22852 L
.11562 .28617 L
.11011 .2658 L
.07362 .2127 L
s
.0768 .22852 m
.08065 .24611 L
.12228 .30871 L
.11562 .28617 L
.0768 .22852 L
s
.08065 .24611 m
.08499 .26439 L
.12981 .33198 L
.12228 .30871 L
.08065 .24611 L
s
.08499 .26439 m
.08964 .28245 L
.13786 .35485 L
.12981 .33198 L
.08499 .26439 L
s
.08964 .28245 m
.09439 .29962 L
.14609 .37646 L
.13786 .35485 L
.08964 .28245 L
s
.09439 .29962 m
.09904 .31535 L
.15415 .39615 L
.14609 .37646 L
.09439 .29962 L
s
.09904 .31535 m
.10339 .32924 L
.16167 .41343 L
.15415 .39615 L
.09904 .31535 L
s
.10339 .32924 m
.10723 .34097 L
.16833 .42796 L
.16167 .41343 L
.10339 .32924 L
s
.10723 .34097 m
.11041 .35032 L
.17384 .43948 L
.16833 .42796 L
.10723 .34097 L
s
.11041 .35032 m
.11279 .3571 L
.17796 .44781 L
.17384 .43948 L
.11041 .35032 L
s
.11279 .3571 m
.11426 .36121 L
.18051 .45285 L
.17796 .44781 L
.11279 .3571 L
s
.11426 .36121 m
.11475 .36259 L
.18137 .45454 L
.18051 .45285 L
.11426 .36121 L
s
.11475 .36259 m
.11426 .36121 L
.18051 .45285 L
.18137 .45454 L
.11475 .36259 L
s
.11426 .36121 m
.11279 .3571 L
.17796 .44781 L
.18051 .45285 L
.11426 .36121 L
s
.11279 .3571 m
.11041 .35032 L
.17384 .43948 L
.17796 .44781 L
.11279 .3571 L
s
.11041 .35032 m
.10723 .34097 L
.16833 .42796 L
.17384 .43948 L
.11041 .35032 L
s
.10723 .34097 m
.10339 .32924 L
.16167 .41343 L
.16833 .42796 L
.10723 .34097 L
s
.10339 .32924 m
.09904 .31535 L
.15415 .39615 L
.16167 .41343 L
.10339 .32924 L
s
.09904 .31535 m
.09439 .29962 L
.14609 .37646 L
.15415 .39615 L
.09904 .31535 L
s
.09439 .29962 m
.08964 .28245 L
.13786 .35485 L
.14609 .37646 L
.09439 .29962 L
s
.08964 .28245 m
.08499 .26439 L
.12981 .33198 L
.13786 .35485 L
.08964 .28245 L
s
.08499 .26439 m
.08065 .24611 L
.12228 .30871 L
.12981 .33198 L
.08499 .26439 L
s
.08065 .24611 m
.0768 .22852 L
.11562 .28617 L
.12228 .30871 L
.08065 .24611 L
s
.0768 .22852 m
.07362 .2127 L
.11011 .2658 L
.11562 .28617 L
.0768 .22852 L
s
.07362 .2127 m
.07125 .19995 L
.10599 .2493 L
.11011 .2658 L
.07362 .2127 L
s
.07125 .19995 m
.06978 .19158 L
.10345 .23844 L
.10599 .2493 L
.07125 .19995 L
s
.06978 .19158 m
.06928 .18865 L
.10259 .23463 L
.10345 .23844 L
.06978 .19158 L
s
.06928 .18865 m
.06978 .19158 L
.10345 .23844 L
.10259 .23463 L
.06928 .18865 L
s
.06978 .19158 m
.07125 .19995 L
.10599 .2493 L
.10345 .23844 L
.06978 .19158 L
s
.07125 .19995 m
.07362 .2127 L
.11011 .2658 L
.10599 .2493 L
.07125 .19995 L
s
.07362 .2127 m
.0768 .22852 L
.11562 .28617 L
.11011 .2658 L
.07362 .2127 L
s
.0768 .22852 m
.08065 .24611 L
.12228 .30871 L
.11562 .28617 L
.0768 .22852 L
s
.08065 .24611 m
.08499 .26439 L
.12981 .33198 L
.12228 .30871 L
.08065 .24611 L
s
.08499 .26439 m
.08964 .28245 L
.13786 .35485 L
.12981 .33198 L
.08499 .26439 L
s
.08964 .28245 m
.09439 .29962 L
.14609 .37646 L
.13786 .35485 L
.08964 .28245 L
s
.09439 .29962 m
.09904 .31535 L
.15415 .39615 L
.14609 .37646 L
.09439 .29962 L
s
.09904 .31535 m
.10339 .32924 L
.16167 .41343 L
.15415 .39615 L
.09904 .31535 L
s
.10339 .32924 m
.10723 .34097 L
.16833 .42796 L
.16167 .41343 L
.10339 .32924 L
s
.10723 .34097 m
.11041 .35032 L
.17384 .43948 L
.16833 .42796 L
.10723 .34097 L
s
.11041 .35032 m
.11279 .3571 L
.17796 .44781 L
.17384 .43948 L
.11041 .35032 L
s
.11279 .3571 m
.11426 .36121 L
.18051 .45285 L
.17796 .44781 L
.11279 .3571 L
s
.11426 .36121 m
.11475 .36259 L
.18137 .45454 L
.18051 .45285 L
.11426 .36121 L
s
.18137 .45454 m
.18051 .45285 L
.2606 .5254 L
.2619 .52727 L
.18137 .45454 L
s
.18051 .45285 m
.17796 .44781 L
.25676 .51979 L
.2606 .5254 L
.18051 .45285 L
s
.17796 .44781 m
.17384 .43948 L
.25054 .51048 L
.25676 .51979 L
.17796 .44781 L
s
.17384 .43948 m
.16833 .42796 L
.24221 .49756 L
.25054 .51048 L
.17384 .43948 L
s
.16833 .42796 m
.16167 .41343 L
.23214 .48115 L
.24221 .49756 L
.16833 .42796 L
s
.16167 .41343 m
.15415 .39615 L
.22077 .46147 L
.23214 .48115 L
.16167 .41343 L
s
.15415 .39615 m
.14609 .37646 L
.2086 .43887 L
.22077 .46147 L
.15415 .39615 L
s
.14609 .37646 m
.13786 .35485 L
.19616 .41385 L
.2086 .43887 L
.14609 .37646 L
s
.13786 .35485 m
.12981 .33198 L
.18399 .38714 L
.19616 .41385 L
.13786 .35485 L
s
.12981 .33198 m
.12228 .30871 L
.17262 .35974 L
.18399 .38714 L
.12981 .33198 L
s
.12228 .30871 m
.11562 .28617 L
.16255 .33299 L
.17262 .35974 L
.12228 .30871 L
s
.11562 .28617 m
.11011 .2658 L
.15423 .30863 L
.16255 .33299 L
.11562 .28617 L
s
.11011 .2658 m
.10599 .2493 L
.148 .28876 L
.15423 .30863 L
.11011 .2658 L
s
.10599 .2493 m
.10345 .23844 L
.14416 .27561 L
.148 .28876 L
.10599 .2493 L
s
.10345 .23844 m
.10259 .23463 L
.14286 .27099 L
.14416 .27561 L
.10345 .23844 L
s
.10259 .23463 m
.10345 .23844 L
.14416 .27561 L
.14286 .27099 L
.10259 .23463 L
s
.10345 .23844 m
.10599 .2493 L
.148 .28876 L
.14416 .27561 L
.10345 .23844 L
s
.10599 .2493 m
.11011 .2658 L
.15423 .30863 L
.148 .28876 L
.10599 .2493 L
s
.11011 .2658 m
.11562 .28617 L
.16255 .33299 L
.15423 .30863 L
.11011 .2658 L
s
.11562 .28617 m
.12228 .30871 L
.17262 .35974 L
.16255 .33299 L
.11562 .28617 L
s
.12228 .30871 m
.12981 .33198 L
.18399 .38714 L
.17262 .35974 L
.12228 .30871 L
s
.12981 .33198 m
.13786 .35485 L
.19616 .41385 L
.18399 .38714 L
.12981 .33198 L
s
.13786 .35485 m
.14609 .37646 L
.2086 .43887 L
.19616 .41385 L
.13786 .35485 L
s
.14609 .37646 m
.15415 .39615 L
.22077 .46147 L
.2086 .43887 L
.14609 .37646 L
s
.15415 .39615 m
.16167 .41343 L
.23214 .48115 L
.22077 .46147 L
.15415 .39615 L
s
.16167 .41343 m
.16833 .42796 L
.24221 .49756 L
.23214 .48115 L
.16167 .41343 L
s
.16833 .42796 m
.17384 .43948 L
.25054 .51048 L
.24221 .49756 L
.16833 .42796 L
s
.17384 .43948 m
.17796 .44781 L
.25676 .51979 L
.25054 .51048 L
.17384 .43948 L
s
.17796 .44781 m
.18051 .45285 L
.2606 .5254 L
.25676 .51979 L
.17796 .44781 L
s
.18051 .45285 m
.18137 .45454 L
.2619 .52727 L
.2606 .5254 L
.18051 .45285 L
s
.18137 .45454 m
.18051 .45285 L
.2606 .5254 L
.2619 .52727 L
.18137 .45454 L
s
.18051 .45285 m
.17796 .44781 L
.25676 .51979 L
.2606 .5254 L
.18051 .45285 L
s
.17796 .44781 m
.17384 .43948 L
.25054 .51048 L
.25676 .51979 L
.17796 .44781 L
s
.17384 .43948 m
.16833 .42796 L
.24221 .49756 L
.25054 .51048 L
.17384 .43948 L
s
.16833 .42796 m
.16167 .41343 L
.23214 .48115 L
.24221 .49756 L
.16833 .42796 L
s
.16167 .41343 m
.15415 .39615 L
.22077 .46147 L
.23214 .48115 L
.16167 .41343 L
s
.15415 .39615 m
.14609 .37646 L
.2086 .43887 L
.22077 .46147 L
.15415 .39615 L
s
.14609 .37646 m
.13786 .35485 L
.19616 .41385 L
.2086 .43887 L
.14609 .37646 L
s
.13786 .35485 m
.12981 .33198 L
.18399 .38714 L
.19616 .41385 L
.13786 .35485 L
s
.12981 .33198 m
.12228 .30871 L
.17262 .35974 L
.18399 .38714 L
.12981 .33198 L
s
.12228 .30871 m
.11562 .28617 L
.16255 .33299 L
.17262 .35974 L
.12228 .30871 L
s
.11562 .28617 m
.11011 .2658 L
.15423 .30863 L
.16255 .33299 L
.11562 .28617 L
s
.11011 .2658 m
.10599 .2493 L
.148 .28876 L
.15423 .30863 L
.11011 .2658 L
s
.10599 .2493 m
.10345 .23844 L
.14416 .27561 L
.148 .28876 L
.10599 .2493 L
s
.10345 .23844 m
.10259 .23463 L
.14286 .27099 L
.14416 .27561 L
.10345 .23844 L
s
.10259 .23463 m
.10345 .23844 L
.14416 .27561 L
.14286 .27099 L
.10259 .23463 L
s
.10345 .23844 m
.10599 .2493 L
.148 .28876 L
.14416 .27561 L
.10345 .23844 L
s
.10599 .2493 m
.11011 .2658 L
.15423 .30863 L
.148 .28876 L
.10599 .2493 L
s
.11011 .2658 m
.11562 .28617 L
.16255 .33299 L
.15423 .30863 L
.11011 .2658 L
s
.11562 .28617 m
.12228 .30871 L
.17262 .35974 L
.16255 .33299 L
.11562 .28617 L
s
.12228 .30871 m
.12981 .33198 L
.18399 .38714 L
.17262 .35974 L
.12228 .30871 L
s
.12981 .33198 m
.13786 .35485 L
.19616 .41385 L
.18399 .38714 L
.12981 .33198 L
s
.13786 .35485 m
.14609 .37646 L
.2086 .43887 L
.19616 .41385 L
.13786 .35485 L
s
.14609 .37646 m
.15415 .39615 L
.22077 .46147 L
.2086 .43887 L
.14609 .37646 L
s
.15415 .39615 m
.16167 .41343 L
.23214 .48115 L
.22077 .46147 L
.15415 .39615 L
s
.16167 .41343 m
.16833 .42796 L
.24221 .49756 L
.23214 .48115 L
.16167 .41343 L
s
.16833 .42796 m
.17384 .43948 L
.25054 .51048 L
.24221 .49756 L
.16833 .42796 L
s
.17384 .43948 m
.17796 .44781 L
.25676 .51979 L
.25054 .51048 L
.17384 .43948 L
s
.17796 .44781 m
.18051 .45285 L
.2606 .5254 L
.25676 .51979 L
.17796 .44781 L
s
.18051 .45285 m
.18137 .45454 L
.2619 .52727 L
.2606 .5254 L
.18051 .45285 L
s
.2619 .52727 m
.2606 .5254 L
.35105 .57569 L
.35285 .57759 L
.2619 .52727 L
s
.2606 .5254 m
.25676 .51979 L
.34574 .56995 L
.35105 .57569 L
.2606 .5254 L
s
.25676 .51979 m
.25054 .51048 L
.33714 .56038 L
.34574 .56995 L
.25676 .51979 L
s
.25054 .51048 m
.24221 .49756 L
.32563 .54697 L
.33714 .56038 L
.25054 .51048 L
s
.24221 .49756 m
.23214 .48115 L
.31172 .52976 L
.32563 .54697 L
.24221 .49756 L
s
.23214 .48115 m
.22077 .46147 L
.29601 .50887 L
.31172 .52976 L
.23214 .48115 L
s
.22077 .46147 m
.2086 .43887 L
.27919 .48459 L
.29601 .50887 L
.22077 .46147 L
s
.2086 .43887 m
.19616 .41385 L
.26199 .45737 L
.27919 .48459 L
.2086 .43887 L
s
.19616 .41385 m
.18399 .38714 L
.24517 .42795 L
.26199 .45737 L
.19616 .41385 L
s
.18399 .38714 m
.17262 .35974 L
.22946 .39741 L
.24517 .42795 L
.18399 .38714 L
s
.17262 .35974 m
.16255 .33299 L
.21555 .36727 L
.22946 .39741 L
.17262 .35974 L
s
.16255 .33299 m
.15423 .30863 L
.20404 .33954 L
.21555 .36727 L
.16255 .33299 L
s
.15423 .30863 m
.148 .28876 L
.19544 .31672 L
.20404 .33954 L
.15423 .30863 L
s
.148 .28876 m
.14416 .27561 L
.19013 .30152 L
.19544 .31672 L
.148 .28876 L
s
.14416 .27561 m
.14286 .27099 L
.18833 .29615 L
.19013 .30152 L
.14416 .27561 L
s
.14286 .27099 m
.14416 .27561 L
.19013 .30152 L
.18833 .29615 L
.14286 .27099 L
s
.14416 .27561 m
.148 .28876 L
.19544 .31672 L
.19013 .30152 L
.14416 .27561 L
s
.148 .28876 m
.15423 .30863 L
.20404 .33954 L
.19544 .31672 L
.148 .28876 L
s
.15423 .30863 m
.16255 .33299 L
.21555 .36727 L
.20404 .33954 L
.15423 .30863 L
s
.16255 .33299 m
.17262 .35974 L
.22946 .39741 L
.21555 .36727 L
.16255 .33299 L
s
.17262 .35974 m
.18399 .38714 L
.24517 .42795 L
.22946 .39741 L
.17262 .35974 L
s
.18399 .38714 m
.19616 .41385 L
.26199 .45737 L
.24517 .42795 L
.18399 .38714 L
s
.19616 .41385 m
.2086 .43887 L
.27919 .48459 L
.26199 .45737 L
.19616 .41385 L
s
.2086 .43887 m
.22077 .46147 L
.29601 .50887 L
.27919 .48459 L
.2086 .43887 L
s
.22077 .46147 m
.23214 .48115 L
.31172 .52976 L
.29601 .50887 L
.22077 .46147 L
s
.23214 .48115 m
.24221 .49756 L
.32563 .54697 L
.31172 .52976 L
.23214 .48115 L
s
.24221 .49756 m
.25054 .51048 L
.33714 .56038 L
.32563 .54697 L
.24221 .49756 L
s
.25054 .51048 m
.25676 .51979 L
.34574 .56995 L
.33714 .56038 L
.25054 .51048 L
s
.25676 .51979 m
.2606 .5254 L
.35105 .57569 L
.34574 .56995 L
.25676 .51979 L
s
.2606 .5254 m
.2619 .52727 L
.35285 .57759 L
.35105 .57569 L
.2606 .5254 L
s
.2619 .52727 m
.2606 .5254 L
.35105 .57569 L
.35285 .57759 L
.2619 .52727 L
s
.2606 .5254 m
.25676 .51979 L
.34574 .56995 L
.35105 .57569 L
.2606 .5254 L
s
.25676 .51979 m
.25054 .51048 L
.33714 .56038 L
.34574 .56995 L
.25676 .51979 L
s
.25054 .51048 m
.24221 .49756 L
.32563 .54697 L
.33714 .56038 L
.25054 .51048 L
s
.24221 .49756 m
.23214 .48115 L
.31172 .52976 L
.32563 .54697 L
.24221 .49756 L
s
.23214 .48115 m
.22077 .46147 L
.29601 .50887 L
.31172 .52976 L
.23214 .48115 L
s
.22077 .46147 m
.2086 .43887 L
.27919 .48459 L
.29601 .50887 L
.22077 .46147 L
s
.2086 .43887 m
.19616 .41385 L
.26199 .45737 L
.27919 .48459 L
.2086 .43887 L
s
.19616 .41385 m
.18399 .38714 L
.24517 .42795 L
.26199 .45737 L
.19616 .41385 L
s
.18399 .38714 m
.17262 .35974 L
.22946 .39741 L
.24517 .42795 L
.18399 .38714 L
s
.17262 .35974 m
.16255 .33299 L
.21555 .36727 L
.22946 .39741 L
.17262 .35974 L
s
.16255 .33299 m
.15423 .30863 L
.20404 .33954 L
.21555 .36727 L
.16255 .33299 L
s
.15423 .30863 m
.148 .28876 L
.19544 .31672 L
.20404 .33954 L
.15423 .30863 L
s
.148 .28876 m
.14416 .27561 L
.19013 .30152 L
.19544 .31672 L
.148 .28876 L
s
.14416 .27561 m
.14286 .27099 L
.18833 .29615 L
.19013 .30152 L
.14416 .27561 L
s
.14286 .27099 m
.14416 .27561 L
.19013 .30152 L
.18833 .29615 L
.14286 .27099 L
s
.14416 .27561 m
.148 .28876 L
.19544 .31672 L
.19013 .30152 L
.14416 .27561 L
s
.148 .28876 m
.15423 .30863 L
.20404 .33954 L
.19544 .31672 L
.148 .28876 L
s
.15423 .30863 m
.16255 .33299 L
.21555 .36727 L
.20404 .33954 L
.15423 .30863 L
s
.16255 .33299 m
.17262 .35974 L
.22946 .39741 L
.21555 .36727 L
.16255 .33299 L
s
.17262 .35974 m
.18399 .38714 L
.24517 .42795 L
.22946 .39741 L
.17262 .35974 L
s
.18399 .38714 m
.19616 .41385 L
.26199 .45737 L
.24517 .42795 L
.18399 .38714 L
s
.19616 .41385 m
.2086 .43887 L
.27919 .48459 L
.26199 .45737 L
.19616 .41385 L
s
.2086 .43887 m
.22077 .46147 L
.29601 .50887 L
.27919 .48459 L
.2086 .43887 L
s
.22077 .46147 m
.23214 .48115 L
.31172 .52976 L
.29601 .50887 L
.22077 .46147 L
s
.23214 .48115 m
.24221 .49756 L
.32563 .54697 L
.31172 .52976 L
.23214 .48115 L
s
.24221 .49756 m
.25054 .51048 L
.33714 .56038 L
.32563 .54697 L
.24221 .49756 L
s
.25054 .51048 m
.25676 .51979 L
.34574 .56995 L
.33714 .56038 L
.25054 .51048 L
s
.25676 .51979 m
.2606 .5254 L
.35105 .57569 L
.34574 .56995 L
.25676 .51979 L
s
.2606 .5254 m
.2619 .52727 L
.35285 .57759 L
.35105 .57569 L
.2606 .5254 L
s
.35285 .57759 m
.35105 .57569 L
.44789 .60155 L
.45022 .60332 L
.35285 .57759 L
s
.35105 .57569 m
.34574 .56995 L
.44101 .5962 L
.44789 .60155 L
.35105 .57569 L
s
.34574 .56995 m
.33714 .56038 L
.42987 .58717 L
.44101 .5962 L
.34574 .56995 L
s
.33714 .56038 m
.32563 .54697 L
.41495 .57432 L
.42987 .58717 L
.33714 .56038 L
s
.32563 .54697 m
.31172 .52976 L
.39692 .55754 L
.41495 .57432 L
.32563 .54697 L
s
.31172 .52976 m
.29601 .50887 L
.37656 .53679 L
.39692 .55754 L
.31172 .52976 L
s
.29601 .50887 m
.27919 .48459 L
.35476 .51219 L
.37656 .53679 L
.29601 .50887 L
s
.27919 .48459 m
.26199 .45737 L
.33248 .48409 L
.35476 .51219 L
.27919 .48459 L
s
.26199 .45737 m
.24517 .42795 L
.31068 .4532 L
.33248 .48409 L
.26199 .45737 L
s
.24517 .42795 m
.22946 .39741 L
.29032 .4206 L
.31068 .4532 L
.24517 .42795 L
s
.22946 .39741 m
.21555 .36727 L
.27229 .38794 L
.29032 .4206 L
.22946 .39741 L
s
.21555 .36727 m
.20404 .33954 L
.25738 .35749 L
.27229 .38794 L
.21555 .36727 L
s
.20404 .33954 m
.19544 .31672 L
.24623 .33213 L
.25738 .35749 L
.20404 .33954 L
s
.19544 .31672 m
.19013 .30152 L
.23935 .31507 L
.24623 .33213 L
.19544 .31672 L
s
.19013 .30152 m
.18833 .29615 L
.23702 .30902 L
.23935 .31507 L
.19013 .30152 L
s
.18833 .29615 m
.19013 .30152 L
.23935 .31507 L
.23702 .30902 L
.18833 .29615 L
s
.19013 .30152 m
.19544 .31672 L
.24623 .33213 L
.23935 .31507 L
.19013 .30152 L
s
.19544 .31672 m
.20404 .33954 L
.25738 .35749 L
.24623 .33213 L
.19544 .31672 L
s
.20404 .33954 m
.21555 .36727 L
.27229 .38794 L
.25738 .35749 L
.20404 .33954 L
s
.21555 .36727 m
.22946 .39741 L
.29032 .4206 L
.27229 .38794 L
.21555 .36727 L
s
.22946 .39741 m
.24517 .42795 L
.31068 .4532 L
.29032 .4206 L
.22946 .39741 L
s
.24517 .42795 m
.26199 .45737 L
.33248 .48409 L
.31068 .4532 L
.24517 .42795 L
s
.26199 .45737 m
.27919 .48459 L
.35476 .51219 L
.33248 .48409 L
.26199 .45737 L
s
.27919 .48459 m
.29601 .50887 L
.37656 .53679 L
.35476 .51219 L
.27919 .48459 L
s
.29601 .50887 m
.31172 .52976 L
.39692 .55754 L
.37656 .53679 L
.29601 .50887 L
s
.31172 .52976 m
.32563 .54697 L
.41495 .57432 L
.39692 .55754 L
.31172 .52976 L
s
.32563 .54697 m
.33714 .56038 L
.42987 .58717 L
.41495 .57432 L
.32563 .54697 L
s
.33714 .56038 m
.34574 .56995 L
.44101 .5962 L
.42987 .58717 L
.33714 .56038 L
s
.34574 .56995 m
.35105 .57569 L
.44789 .60155 L
.44101 .5962 L
.34574 .56995 L
s
.35105 .57569 m
.35285 .57759 L
.45022 .60332 L
.44789 .60155 L
.35105 .57569 L
s
.35285 .57759 m
.35105 .57569 L
.44789 .60155 L
.45022 .60332 L
.35285 .57759 L
s
.35105 .57569 m
.34574 .56995 L
.44101 .5962 L
.44789 .60155 L
.35105 .57569 L
s
.34574 .56995 m
.33714 .56038 L
.42987 .58717 L
.44101 .5962 L
.34574 .56995 L
s
.33714 .56038 m
.32563 .54697 L
.41495 .57432 L
.42987 .58717 L
.33714 .56038 L
s
.32563 .54697 m
.31172 .52976 L
.39692 .55754 L
.41495 .57432 L
.32563 .54697 L
s
.31172 .52976 m
.29601 .50887 L
.37656 .53679 L
.39692 .55754 L
.31172 .52976 L
s
.29601 .50887 m
.27919 .48459 L
.35476 .51219 L
.37656 .53679 L
.29601 .50887 L
s
.27919 .48459 m
.26199 .45737 L
.33248 .48409 L
.35476 .51219 L
.27919 .48459 L
s
.26199 .45737 m
.24517 .42795 L
.31068 .4532 L
.33248 .48409 L
.26199 .45737 L
s
.24517 .42795 m
.22946 .39741 L
.29032 .4206 L
.31068 .4532 L
.24517 .42795 L
s
.22946 .39741 m
.21555 .36727 L
.27229 .38794 L
.29032 .4206 L
.22946 .39741 L
s
.21555 .36727 m
.20404 .33954 L
.25738 .35749 L
.27229 .38794 L
.21555 .36727 L
s
.20404 .33954 m
.19544 .31672 L
.24623 .33213 L
.25738 .35749 L
.20404 .33954 L
s
.19544 .31672 m
.19013 .30152 L
.23935 .31507 L
.24623 .33213 L
.19544 .31672 L
s
.19013 .30152 m
.18833 .29615 L
.23702 .30902 L
.23935 .31507 L
.19013 .30152 L
s
.18833 .29615 m
.19013 .30152 L
.23935 .31507 L
.23702 .30902 L
.18833 .29615 L
s
.19013 .30152 m
.19544 .31672 L
.24623 .33213 L
.23935 .31507 L
.19013 .30152 L
s
.19544 .31672 m
.20404 .33954 L
.25738 .35749 L
.24623 .33213 L
.19544 .31672 L
s
.20404 .33954 m
.21555 .36727 L
.27229 .38794 L
.25738 .35749 L
.20404 .33954 L
s
.21555 .36727 m
.22946 .39741 L
.29032 .4206 L
.27229 .38794 L
.21555 .36727 L
s
.22946 .39741 m
.24517 .42795 L
.31068 .4532 L
.29032 .4206 L
.22946 .39741 L
s
.24517 .42795 m
.26199 .45737 L
.33248 .48409 L
.31068 .4532 L
.24517 .42795 L
s
.26199 .45737 m
.27919 .48459 L
.35476 .51219 L
.33248 .48409 L
.26199 .45737 L
s
.27919 .48459 m
.29601 .50887 L
.37656 .53679 L
.35476 .51219 L
.27919 .48459 L
s
.29601 .50887 m
.31172 .52976 L
.39692 .55754 L
.37656 .53679 L
.29601 .50887 L
s
.31172 .52976 m
.32563 .54697 L
.41495 .57432 L
.39692 .55754 L
.31172 .52976 L
s
.32563 .54697 m
.33714 .56038 L
.42987 .58717 L
.41495 .57432 L
.32563 .54697 L
s
.33714 .56038 m
.34574 .56995 L
.44101 .5962 L
.42987 .58717 L
.33714 .56038 L
s
.34574 .56995 m
.35105 .57569 L
.44789 .60155 L
.44101 .5962 L
.34574 .56995 L
s
.35105 .57569 m
.35285 .57759 L
.45022 .60332 L
.44789 .60155 L
.35105 .57569 L
s
.45022 .60332 m
.44789 .60155 L
.5469 .60189 L
.54978 .60332 L
.45022 .60332 L
s
.44789 .60155 m
.44101 .5962 L
.53841 .5975 L
.5469 .60189 L
.44789 .60155 L
s
.44101 .5962 m
.42987 .58717 L
.52466 .58993 L
.53841 .5975 L
.44101 .5962 L
s
.42987 .58717 m
.41495 .57432 L
.50627 .57882 L
.52466 .58993 L
.42987 .58717 L
s
.41495 .57432 m
.39692 .55754 L
.48403 .56383 L
.50627 .57882 L
.41495 .57432 L
s
.39692 .55754 m
.37656 .53679 L
.45892 .54466 L
.48403 .56383 L
.39692 .55754 L
s
.37656 .53679 m
.35476 .51219 L
.43203 .5212 L
.45892 .54466 L
.37656 .53679 L
s
.35476 .51219 m
.33248 .48409 L
.40454 .49364 L
.43203 .5212 L
.35476 .51219 L
s
.33248 .48409 m
.31068 .4532 L
.37765 .46254 L
.40454 .49364 L
.33248 .48409 L
s
.31068 .4532 m
.29032 .4206 L
.35254 .42897 L
.37765 .46254 L
.31068 .4532 L
s
.29032 .4206 m
.27229 .38794 L
.3303 .39465 L
.35254 .42897 L
.29032 .4206 L
s
.27229 .38794 m
.25738 .35749 L
.31191 .36207 L
.3303 .39465 L
.27229 .38794 L
s
.25738 .35749 m
.24623 .33213 L
.29816 .3345 L
.31191 .36207 L
.25738 .35749 L
s
.24623 .33213 m
.23935 .31507 L
.28967 .31573 L
.29816 .3345 L
.24623 .33213 L
s
.23935 .31507 m
.23702 .30902 L
.28679 .30902 L
.28967 .31573 L
.23935 .31507 L
s
.23702 .30902 m
.23935 .31507 L
.28967 .31573 L
.28679 .30902 L
.23702 .30902 L
s
.23935 .31507 m
.24623 .33213 L
.29816 .3345 L
.28967 .31573 L
.23935 .31507 L
s
.24623 .33213 m
.25738 .35749 L
.31191 .36207 L
.29816 .3345 L
.24623 .33213 L
s
.25738 .35749 m
.27229 .38794 L
.3303 .39465 L
.31191 .36207 L
.25738 .35749 L
s
.27229 .38794 m
.29032 .4206 L
.35254 .42897 L
.3303 .39465 L
.27229 .38794 L
s
.29032 .4206 m
.31068 .4532 L
.37765 .46254 L
.35254 .42897 L
.29032 .4206 L
s
.31068 .4532 m
.33248 .48409 L
.40454 .49364 L
.37765 .46254 L
.31068 .4532 L
s
.33248 .48409 m
.35476 .51219 L
.43203 .5212 L
.40454 .49364 L
.33248 .48409 L
s
.35476 .51219 m
.37656 .53679 L
.45892 .54466 L
.43203 .5212 L
.35476 .51219 L
s
.37656 .53679 m
.39692 .55754 L
.48403 .56383 L
.45892 .54466 L
.37656 .53679 L
s
.39692 .55754 m
.41495 .57432 L
.50627 .57882 L
.48403 .56383 L
.39692 .55754 L
s
.41495 .57432 m
.42987 .58717 L
.52466 .58993 L
.50627 .57882 L
.41495 .57432 L
s
.42987 .58717 m
.44101 .5962 L
.53841 .5975 L
.52466 .58993 L
.42987 .58717 L
s
.44101 .5962 m
.44789 .60155 L
.5469 .60189 L
.53841 .5975 L
.44101 .5962 L
s
.44789 .60155 m
.45022 .60332 L
.54978 .60332 L
.5469 .60189 L
.44789 .60155 L
s
.45022 .60332 m
.44789 .60155 L
.5469 .60189 L
.54978 .60332 L
.45022 .60332 L
s
.44789 .60155 m
.44101 .5962 L
.53841 .5975 L
.5469 .60189 L
.44789 .60155 L
s
.44101 .5962 m
.42987 .58717 L
.52466 .58993 L
.53841 .5975 L
.44101 .5962 L
s
.42987 .58717 m
.41495 .57432 L
.50627 .57882 L
.52466 .58993 L
.42987 .58717 L
s
.41495 .57432 m
.39692 .55754 L
.48403 .56383 L
.50627 .57882 L
.41495 .57432 L
s
.39692 .55754 m
.37656 .53679 L
.45892 .54466 L
.48403 .56383 L
.39692 .55754 L
s
.37656 .53679 m
.35476 .51219 L
.43203 .5212 L
.45892 .54466 L
.37656 .53679 L
s
.35476 .51219 m
.33248 .48409 L
.40454 .49364 L
.43203 .5212 L
.35476 .51219 L
s
.33248 .48409 m
.31068 .4532 L
.37765 .46254 L
.40454 .49364 L
.33248 .48409 L
s
.31068 .4532 m
.29032 .4206 L
.35254 .42897 L
.37765 .46254 L
.31068 .4532 L
s
.29032 .4206 m
.27229 .38794 L
.3303 .39465 L
.35254 .42897 L
.29032 .4206 L
s
.27229 .38794 m
.25738 .35749 L
.31191 .36207 L
.3303 .39465 L
.27229 .38794 L
s
.25738 .35749 m
.24623 .33213 L
.29816 .3345 L
.31191 .36207 L
.25738 .35749 L
s
.24623 .33213 m
.23935 .31507 L
.28967 .31573 L
.29816 .3345 L
.24623 .33213 L
s
.23935 .31507 m
.23702 .30902 L
.28679 .30902 L
.28967 .31573 L
.23935 .31507 L
s
.23702 .30902 m
.23935 .31507 L
.28967 .31573 L
.28679 .30902 L
.23702 .30902 L
s
.23935 .31507 m
.24623 .33213 L
.29816 .3345 L
.28967 .31573 L
.23935 .31507 L
s
.24623 .33213 m
.25738 .35749 L
.31191 .36207 L
.29816 .3345 L
.24623 .33213 L
s
.25738 .35749 m
.27229 .38794 L
.3303 .39465 L
.31191 .36207 L
.25738 .35749 L
s
.27229 .38794 m
.29032 .4206 L
.35254 .42897 L
.3303 .39465 L
.27229 .38794 L
s
.29032 .4206 m
.31068 .4532 L
.37765 .46254 L
.35254 .42897 L
.29032 .4206 L
s
.31068 .4532 m
.33248 .48409 L
.40454 .49364 L
.37765 .46254 L
.31068 .4532 L
s
.33248 .48409 m
.35476 .51219 L
.43203 .5212 L
.40454 .49364 L
.33248 .48409 L
s
.35476 .51219 m
.37656 .53679 L
.45892 .54466 L
.43203 .5212 L
.35476 .51219 L
s
.37656 .53679 m
.39692 .55754 L
.48403 .56383 L
.45892 .54466 L
.37656 .53679 L
s
.39692 .55754 m
.41495 .57432 L
.50627 .57882 L
.48403 .56383 L
.39692 .55754 L
s
.41495 .57432 m
.42987 .58717 L
.52466 .58993 L
.50627 .57882 L
.41495 .57432 L
s
.42987 .58717 m
.44101 .5962 L
.53841 .5975 L
.52466 .58993 L
.42987 .58717 L
s
.44101 .5962 m
.44789 .60155 L
.5469 .60189 L
.53841 .5975 L
.44101 .5962 L
s
.44789 .60155 m
.45022 .60332 L
.54978 .60332 L
.5469 .60189 L
.44789 .60155 L
s
.54978 .60332 m
.5469 .60189 L
.64375 .57673 L
.64715 .57759 L
.54978 .60332 L
s
.5469 .60189 m
.53841 .5975 L
.63368 .57397 L
.64375 .57673 L
.5469 .60189 L
s
.53841 .5975 m
.52466 .58993 L
.61739 .56888 L
.63368 .57397 L
.53841 .5975 L
s
.52466 .58993 m
.50627 .57882 L
.59559 .56083 L
.61739 .56888 L
.52466 .58993 L
s
.50627 .57882 m
.48403 .56383 L
.56923 .54909 L
.59559 .56083 L
.50627 .57882 L
s
.48403 .56383 m
.45892 .54466 L
.53947 .53305 L
.56923 .54909 L
.48403 .56383 L
s
.45892 .54466 m
.43203 .5212 L
.5076 .51225 L
.53947 .53305 L
.45892 .54466 L
s
.43203 .5212 m
.40454 .49364 L
.47503 .48663 L
.5076 .51225 L
.43203 .5212 L
s
.40454 .49364 m
.37765 .46254 L
.44316 .45657 L
.47503 .48663 L
.40454 .49364 L
s
.37765 .46254 m
.35254 .42897 L
.4134 .42306 L
.44316 .45657 L
.37765 .46254 L
s
.35254 .42897 m
.3303 .39465 L
.38704 .38786 L
.4134 .42306 L
.35254 .42897 L
s
.3303 .39465 m
.31191 .36207 L
.36524 .35363 L
.38704 .38786 L
.3303 .39465 L
s
.31191 .36207 m
.29816 .3345 L
.34895 .32405 L
.36524 .35363 L
.31191 .36207 L
s
.29816 .3345 m
.28967 .31573 L
.33889 .30355 L
.34895 .32405 L
.29816 .3345 L
s
.28967 .31573 m
.28679 .30902 L
.33548 .29615 L
.33889 .30355 L
.28967 .31573 L
s
.28679 .30902 m
.28967 .31573 L
.33889 .30355 L
.33548 .29615 L
.28679 .30902 L
s
.28967 .31573 m
.29816 .3345 L
.34895 .32405 L
.33889 .30355 L
.28967 .31573 L
s
.29816 .3345 m
.31191 .36207 L
.36524 .35363 L
.34895 .32405 L
.29816 .3345 L
s
.31191 .36207 m
.3303 .39465 L
.38704 .38786 L
.36524 .35363 L
.31191 .36207 L
s
.3303 .39465 m
.35254 .42897 L
.4134 .42306 L
.38704 .38786 L
.3303 .39465 L
s
.35254 .42897 m
.37765 .46254 L
.44316 .45657 L
.4134 .42306 L
.35254 .42897 L
s
.37765 .46254 m
.40454 .49364 L
.47503 .48663 L
.44316 .45657 L
.37765 .46254 L
s
.40454 .49364 m
.43203 .5212 L
.5076 .51225 L
.47503 .48663 L
.40454 .49364 L
s
.43203 .5212 m
.45892 .54466 L
.53947 .53305 L
.5076 .51225 L
.43203 .5212 L
s
.45892 .54466 m
.48403 .56383 L
.56923 .54909 L
.53947 .53305 L
.45892 .54466 L
s
.48403 .56383 m
.50627 .57882 L
.59559 .56083 L
.56923 .54909 L
.48403 .56383 L
s
.50627 .57882 m
.52466 .58993 L
.61739 .56888 L
.59559 .56083 L
.50627 .57882 L
s
.52466 .58993 m
.53841 .5975 L
.63368 .57397 L
.61739 .56888 L
.52466 .58993 L
s
.53841 .5975 m
.5469 .60189 L
.64375 .57673 L
.63368 .57397 L
.53841 .5975 L
s
.5469 .60189 m
.54978 .60332 L
.64715 .57759 L
.64375 .57673 L
.5469 .60189 L
s
.54978 .60332 m
.5469 .60189 L
.64375 .57673 L
.64715 .57759 L
.54978 .60332 L
s
.5469 .60189 m
.53841 .5975 L
.63368 .57397 L
.64375 .57673 L
.5469 .60189 L
s
.53841 .5975 m
.52466 .58993 L
.61739 .56888 L
.63368 .57397 L
.53841 .5975 L
s
.52466 .58993 m
.50627 .57882 L
.59559 .56083 L
.61739 .56888 L
.52466 .58993 L
s
.50627 .57882 m
.48403 .56383 L
.56923 .54909 L
.59559 .56083 L
.50627 .57882 L
s
.48403 .56383 m
.45892 .54466 L
.53947 .53305 L
.56923 .54909 L
.48403 .56383 L
s
.45892 .54466 m
.43203 .5212 L
.5076 .51225 L
.53947 .53305 L
.45892 .54466 L
s
.43203 .5212 m
.40454 .49364 L
.47503 .48663 L
.5076 .51225 L
.43203 .5212 L
s
.40454 .49364 m
.37765 .46254 L
.44316 .45657 L
.47503 .48663 L
.40454 .49364 L
s
.37765 .46254 m
.35254 .42897 L
.4134 .42306 L
.44316 .45657 L
.37765 .46254 L
s
.35254 .42897 m
.3303 .39465 L
.38704 .38786 L
.4134 .42306 L
.35254 .42897 L
s
.3303 .39465 m
.31191 .36207 L
.36524 .35363 L
.38704 .38786 L
.3303 .39465 L
s
.31191 .36207 m
.29816 .3345 L
.34895 .32405 L
.36524 .35363 L
.31191 .36207 L
s
.29816 .3345 m
.28967 .31573 L
.33889 .30355 L
.34895 .32405 L
.29816 .3345 L
s
.28967 .31573 m
.28679 .30902 L
.33548 .29615 L
.33889 .30355 L
.28967 .31573 L
s
.28679 .30902 m
.28967 .31573 L
.33889 .30355 L
.33548 .29615 L
.28679 .30902 L
s
.28967 .31573 m
.29816 .3345 L
.34895 .32405 L
.33889 .30355 L
.28967 .31573 L
s
.29816 .3345 m
.31191 .36207 L
.36524 .35363 L
.34895 .32405 L
.29816 .3345 L
s
.31191 .36207 m
.3303 .39465 L
.38704 .38786 L
.36524 .35363 L
.31191 .36207 L
s
.3303 .39465 m
.35254 .42897 L
.4134 .42306 L
.38704 .38786 L
.3303 .39465 L
s
.35254 .42897 m
.37765 .46254 L
.44316 .45657 L
.4134 .42306 L
.35254 .42897 L
s
.37765 .46254 m
.40454 .49364 L
.47503 .48663 L
.44316 .45657 L
.37765 .46254 L
s
.40454 .49364 m
.43203 .5212 L
.5076 .51225 L
.47503 .48663 L
.40454 .49364 L
s
.43203 .5212 m
.45892 .54466 L
.53947 .53305 L
.5076 .51225 L
.43203 .5212 L
s
.45892 .54466 m
.48403 .56383 L
.56923 .54909 L
.53947 .53305 L
.45892 .54466 L
s
.48403 .56383 m
.50627 .57882 L
.59559 .56083 L
.56923 .54909 L
.48403 .56383 L
s
.50627 .57882 m
.52466 .58993 L
.61739 .56888 L
.59559 .56083 L
.50627 .57882 L
s
.52466 .58993 m
.53841 .5975 L
.63368 .57397 L
.61739 .56888 L
.52466 .58993 L
s
.53841 .5975 m
.5469 .60189 L
.64375 .57673 L
.63368 .57397 L
.53841 .5975 L
s
.5469 .60189 m
.54978 .60332 L
.64715 .57759 L
.64375 .57673 L
.5469 .60189 L
s
.64715 .57759 m
.64375 .57673 L
.73419 .52725 L
.7381 .52727 L
.64715 .57759 L
s
.64375 .57673 m
.63368 .57397 L
.72266 .52691 L
.73419 .52725 L
.64375 .57673 L
s
.63368 .57397 m
.61739 .56888 L
.70399 .52551 L
.72266 .52691 L
.63368 .57397 L
s
.61739 .56888 m
.59559 .56083 L
.67901 .52198 L
.70399 .52551 L
.61739 .56888 L
s
.59559 .56083 m
.56923 .54909 L
.64881 .51511 L
.67901 .52198 L
.59559 .56083 L
s
.56923 .54909 m
.53947 .53305 L
.61471 .50379 L
.64881 .51511 L
.56923 .54909 L
s
.53947 .53305 m
.5076 .51225 L
.57819 .48717 L
.61471 .50379 L
.53947 .53305 L
s
.5076 .51225 m
.47503 .48663 L
.54086 .46484 L
.57819 .48717 L
.5076 .51225 L
s
.47503 .48663 m
.44316 .45657 L
.50434 .43698 L
.54086 .46484 L
.47503 .48663 L
s
.44316 .45657 m
.4134 .42306 L
.47024 .40443 L
.50434 .43698 L
.44316 .45657 L
s
.4134 .42306 m
.38704 .38786 L
.44004 .36894 L
.47024 .40443 L
.4134 .42306 L
s
.38704 .38786 m
.36524 .35363 L
.41506 .33332 L
.44004 .36894 L
.38704 .38786 L
s
.36524 .35363 m
.34895 .32405 L
.39639 .30167 L
.41506 .33332 L
.36524 .35363 L
s
.34895 .32405 m
.33889 .30355 L
.38485 .27921 L
.39639 .30167 L
.34895 .32405 L
s
.33889 .30355 m
.33548 .29615 L
.38095 .27099 L
.38485 .27921 L
.33889 .30355 L
s
.33548 .29615 m
.33889 .30355 L
.38485 .27921 L
.38095 .27099 L
.33548 .29615 L
s
.33889 .30355 m
.34895 .32405 L
.39639 .30167 L
.38485 .27921 L
.33889 .30355 L
s
.34895 .32405 m
.36524 .35363 L
.41506 .33332 L
.39639 .30167 L
.34895 .32405 L
s
.36524 .35363 m
.38704 .38786 L
.44004 .36894 L
.41506 .33332 L
.36524 .35363 L
s
.38704 .38786 m
.4134 .42306 L
.47024 .40443 L
.44004 .36894 L
.38704 .38786 L
s
.4134 .42306 m
.44316 .45657 L
.50434 .43698 L
.47024 .40443 L
.4134 .42306 L
s
.44316 .45657 m
.47503 .48663 L
.54086 .46484 L
.50434 .43698 L
.44316 .45657 L
s
.47503 .48663 m
.5076 .51225 L
.57819 .48717 L
.54086 .46484 L
.47503 .48663 L
s
.5076 .51225 m
.53947 .53305 L
.61471 .50379 L
.57819 .48717 L
.5076 .51225 L
s
.53947 .53305 m
.56923 .54909 L
.64881 .51511 L
.61471 .50379 L
.53947 .53305 L
s
.56923 .54909 m
.59559 .56083 L
.67901 .52198 L
.64881 .51511 L
.56923 .54909 L
s
.59559 .56083 m
.61739 .56888 L
.70399 .52551 L
.67901 .52198 L
.59559 .56083 L
s
.61739 .56888 m
.63368 .57397 L
.72266 .52691 L
.70399 .52551 L
.61739 .56888 L
s
.63368 .57397 m
.64375 .57673 L
.73419 .52725 L
.72266 .52691 L
.63368 .57397 L
s
.64375 .57673 m
.64715 .57759 L
.7381 .52727 L
.73419 .52725 L
.64375 .57673 L
s
.64715 .57759 m
.64375 .57673 L
.73419 .52725 L
.7381 .52727 L
.64715 .57759 L
s
.64375 .57673 m
.63368 .57397 L
.72266 .52691 L
.73419 .52725 L
.64375 .57673 L
s
.63368 .57397 m
.61739 .56888 L
.70399 .52551 L
.72266 .52691 L
.63368 .57397 L
s
.61739 .56888 m
.59559 .56083 L
.67901 .52198 L
.70399 .52551 L
.61739 .56888 L
s
.59559 .56083 m
.56923 .54909 L
.64881 .51511 L
.67901 .52198 L
.59559 .56083 L
s
.56923 .54909 m
.53947 .53305 L
.61471 .50379 L
.64881 .51511 L
.56923 .54909 L
s
.53947 .53305 m
.5076 .51225 L
.57819 .48717 L
.61471 .50379 L
.53947 .53305 L
s
.5076 .51225 m
.47503 .48663 L
.54086 .46484 L
.57819 .48717 L
.5076 .51225 L
s
.47503 .48663 m
.44316 .45657 L
.50434 .43698 L
.54086 .46484 L
.47503 .48663 L
s
.44316 .45657 m
.4134 .42306 L
.47024 .40443 L
.50434 .43698 L
.44316 .45657 L
s
.4134 .42306 m
.38704 .38786 L
.44004 .36894 L
.47024 .40443 L
.4134 .42306 L
s
.38704 .38786 m
.36524 .35363 L
.41506 .33332 L
.44004 .36894 L
.38704 .38786 L
s
.36524 .35363 m
.34895 .32405 L
.39639 .30167 L
.41506 .33332 L
.36524 .35363 L
s
.34895 .32405 m
.33889 .30355 L
.38485 .27921 L
.39639 .30167 L
.34895 .32405 L
s
.33889 .30355 m
.33548 .29615 L
.38095 .27099 L
.38485 .27921 L
.33889 .30355 L
s
.33548 .29615 m
.33889 .30355 L
.38485 .27921 L
.38095 .27099 L
.33548 .29615 L
s
.33889 .30355 m
.34895 .32405 L
.39639 .30167 L
.38485 .27921 L
.33889 .30355 L
s
.34895 .32405 m
.36524 .35363 L
.41506 .33332 L
.39639 .30167 L
.34895 .32405 L
s
.36524 .35363 m
.38704 .38786 L
.44004 .36894 L
.41506 .33332 L
.36524 .35363 L
s
.38704 .38786 m
.4134 .42306 L
.47024 .40443 L
.44004 .36894 L
.38704 .38786 L
s
.4134 .42306 m
.44316 .45657 L
.50434 .43698 L
.47024 .40443 L
.4134 .42306 L
s
.44316 .45657 m
.47503 .48663 L
.54086 .46484 L
.50434 .43698 L
.44316 .45657 L
s
.47503 .48663 m
.5076 .51225 L
.57819 .48717 L
.54086 .46484 L
.47503 .48663 L
s
.5076 .51225 m
.53947 .53305 L
.61471 .50379 L
.57819 .48717 L
.5076 .51225 L
s
.53947 .53305 m
.56923 .54909 L
.64881 .51511 L
.61471 .50379 L
.53947 .53305 L
s
.56923 .54909 m
.59559 .56083 L
.67901 .52198 L
.64881 .51511 L
.56923 .54909 L
s
.59559 .56083 m
.61739 .56888 L
.70399 .52551 L
.67901 .52198 L
.59559 .56083 L
s
.61739 .56888 m
.63368 .57397 L
.72266 .52691 L
.70399 .52551 L
.61739 .56888 L
s
.63368 .57397 m
.64375 .57673 L
.73419 .52725 L
.72266 .52691 L
.63368 .57397 L
s
.64375 .57673 m
.64715 .57759 L
.7381 .52727 L
.73419 .52725 L
.64375 .57673 L
s
.7381 .52727 m
.73419 .52725 L
.81429 .45574 L
.81863 .45454 L
.7381 .52727 L
s
.73419 .52725 m
.72266 .52691 L
.80145 .45886 L
.81429 .45574 L
.73419 .52725 L
s
.72266 .52691 m
.70399 .52551 L
.78068 .46267 L
.80145 .45886 L
.72266 .52691 L
s
.70399 .52551 m
.67901 .52198 L
.75289 .46541 L
.78068 .46267 L
.70399 .52551 L
s
.67901 .52198 m
.64881 .51511 L
.71928 .46518 L
.75289 .46541 L
.67901 .52198 L
s
.64881 .51511 m
.61471 .50379 L
.68133 .46024 L
.71928 .46518 L
.64881 .51511 L
s
.61471 .50379 m
.57819 .48717 L
.6407 .44924 L
.68133 .46024 L
.61471 .50379 L
s
.57819 .48717 m
.54086 .46484 L
.59916 .43143 L
.6407 .44924 L
.57819 .48717 L
s
.54086 .46484 m
.50434 .43698 L
.55852 .40671 L
.59916 .43143 L
.54086 .46484 L
s
.50434 .43698 m
.47024 .40443 L
.52057 .37579 L
.55852 .40671 L
.50434 .43698 L
s
.47024 .40443 m
.44004 .36894 L
.48697 .34037 L
.52057 .37579 L
.47024 .40443 L
s
.44004 .36894 m
.41506 .33332 L
.45917 .30331 L
.48697 .34037 L
.44004 .36894 L
s
.41506 .33332 m
.39639 .30167 L
.4384 .26912 L
.45917 .30331 L
.41506 .33332 L
s
.39639 .30167 m
.38485 .27921 L
.42556 .24403 L
.4384 .26912 L
.39639 .30167 L
s
.38485 .27921 m
.38095 .27099 L
.42122 .23463 L
.42556 .24403 L
.38485 .27921 L
s
.38095 .27099 m
.38485 .27921 L
.42556 .24403 L
.42122 .23463 L
.38095 .27099 L
s
.38485 .27921 m
.39639 .30167 L
.4384 .26912 L
.42556 .24403 L
.38485 .27921 L
s
.39639 .30167 m
.41506 .33332 L
.45917 .30331 L
.4384 .26912 L
.39639 .30167 L
s
.41506 .33332 m
.44004 .36894 L
.48697 .34037 L
.45917 .30331 L
.41506 .33332 L
s
.44004 .36894 m
.47024 .40443 L
.52057 .37579 L
.48697 .34037 L
.44004 .36894 L
s
.47024 .40443 m
.50434 .43698 L
.55852 .40671 L
.52057 .37579 L
.47024 .40443 L
s
.50434 .43698 m
.54086 .46484 L
.59916 .43143 L
.55852 .40671 L
.50434 .43698 L
s
.54086 .46484 m
.57819 .48717 L
.6407 .44924 L
.59916 .43143 L
.54086 .46484 L
s
.57819 .48717 m
.61471 .50379 L
.68133 .46024 L
.6407 .44924 L
.57819 .48717 L
s
.61471 .50379 m
.64881 .51511 L
.71928 .46518 L
.68133 .46024 L
.61471 .50379 L
s
.64881 .51511 m
.67901 .52198 L
.75289 .46541 L
.71928 .46518 L
.64881 .51511 L
s
.67901 .52198 m
.70399 .52551 L
.78068 .46267 L
.75289 .46541 L
.67901 .52198 L
s
.70399 .52551 m
.72266 .52691 L
.80145 .45886 L
.78068 .46267 L
.70399 .52551 L
s
.72266 .52691 m
.73419 .52725 L
.81429 .45574 L
.80145 .45886 L
.72266 .52691 L
s
.73419 .52725 m
.7381 .52727 L
.81863 .45454 L
.81429 .45574 L
.73419 .52725 L
s
.7381 .52727 m
.73419 .52725 L
.81429 .45574 L
.81863 .45454 L
.7381 .52727 L
s
.73419 .52725 m
.72266 .52691 L
.80145 .45886 L
.81429 .45574 L
.73419 .52725 L
s
.72266 .52691 m
.70399 .52551 L
.78068 .46267 L
.80145 .45886 L
.72266 .52691 L
s
.70399 .52551 m
.67901 .52198 L
.75289 .46541 L
.78068 .46267 L
.70399 .52551 L
s
.67901 .52198 m
.64881 .51511 L
.71928 .46518 L
.75289 .46541 L
.67901 .52198 L
s
.64881 .51511 m
.61471 .50379 L
.68133 .46024 L
.71928 .46518 L
.64881 .51511 L
s
.61471 .50379 m
.57819 .48717 L
.6407 .44924 L
.68133 .46024 L
.61471 .50379 L
s
.57819 .48717 m
.54086 .46484 L
.59916 .43143 L
.6407 .44924 L
.57819 .48717 L
s
.54086 .46484 m
.50434 .43698 L
.55852 .40671 L
.59916 .43143 L
.54086 .46484 L
s
.50434 .43698 m
.47024 .40443 L
.52057 .37579 L
.55852 .40671 L
.50434 .43698 L
s
.47024 .40443 m
.44004 .36894 L
.48697 .34037 L
.52057 .37579 L
.47024 .40443 L
s
.44004 .36894 m
.41506 .33332 L
.45917 .30331 L
.48697 .34037 L
.44004 .36894 L
s
.41506 .33332 m
.39639 .30167 L
.4384 .26912 L
.45917 .30331 L
.41506 .33332 L
s
.39639 .30167 m
.38485 .27921 L
.42556 .24403 L
.4384 .26912 L
.39639 .30167 L
s
.38485 .27921 m
.38095 .27099 L
.42122 .23463 L
.42556 .24403 L
.38485 .27921 L
s
.38095 .27099 m
.38485 .27921 L
.42556 .24403 L
.42122 .23463 L
.38095 .27099 L
s
.38485 .27921 m
.39639 .30167 L
.4384 .26912 L
.42556 .24403 L
.38485 .27921 L
s
.39639 .30167 m
.41506 .33332 L
.45917 .30331 L
.4384 .26912 L
.39639 .30167 L
s
.41506 .33332 m
.44004 .36894 L
.48697 .34037 L
.45917 .30331 L
.41506 .33332 L
s
.44004 .36894 m
.47024 .40443 L
.52057 .37579 L
.48697 .34037 L
.44004 .36894 L
s
.47024 .40443 m
.50434 .43698 L
.55852 .40671 L
.52057 .37579 L
.47024 .40443 L
s
.50434 .43698 m
.54086 .46484 L
.59916 .43143 L
.55852 .40671 L
.50434 .43698 L
s
.54086 .46484 m
.57819 .48717 L
.6407 .44924 L
.59916 .43143 L
.54086 .46484 L
s
.57819 .48717 m
.61471 .50379 L
.68133 .46024 L
.6407 .44924 L
.57819 .48717 L
s
.61471 .50379 m
.64881 .51511 L
.71928 .46518 L
.68133 .46024 L
.61471 .50379 L
s
.64881 .51511 m
.67901 .52198 L
.75289 .46541 L
.71928 .46518 L
.64881 .51511 L
s
.67901 .52198 m
.70399 .52551 L
.78068 .46267 L
.75289 .46541 L
.67901 .52198 L
s
.70399 .52551 m
.72266 .52691 L
.80145 .45886 L
.78068 .46267 L
.70399 .52551 L
s
.72266 .52691 m
.73419 .52725 L
.81429 .45574 L
.80145 .45886 L
.72266 .52691 L
s
.73419 .52725 m
.7381 .52727 L
.81863 .45454 L
.81429 .45574 L
.73419 .52725 L
s
.81863 .45454 m
.81429 .45574 L
.88054 .36561 L
.88525 .36259 L
.81863 .45454 L
s
.81429 .45574 m
.80145 .45886 L
.86663 .37381 L
.88054 .36561 L
.81429 .45574 L
s
.80145 .45886 m
.78068 .46267 L
.84412 .38499 L
.86663 .37381 L
.80145 .45886 L
s
.78068 .46267 m
.75289 .46541 L
.81399 .39625 L
.84412 .38499 L
.78068 .46267 L
s
.75289 .46541 m
.71928 .46518 L
.77757 .40467 L
.81399 .39625 L
.75289 .46541 L
s
.71928 .46518 m
.68133 .46024 L
.73644 .40773 L
.77757 .40467 L
.71928 .46518 L
s
.68133 .46024 m
.6407 .44924 L
.6924 .40361 L
.73644 .40773 L
.68133 .46024 L
s
.6407 .44924 m
.59916 .43143 L
.64738 .39122 L
.6924 .40361 L
.6407 .44924 L
s
.59916 .43143 m
.55852 .40671 L
.60334 .37027 L
.64738 .39122 L
.59916 .43143 L
s
.55852 .40671 m
.52057 .37579 L
.56221 .34133 L
.60334 .37027 L
.55852 .40671 L
s
.52057 .37579 m
.48697 .34037 L
.52578 .30598 L
.56221 .34133 L
.52057 .37579 L
s
.48697 .34037 m
.45917 .30331 L
.49566 .26705 L
.52578 .30598 L
.48697 .34037 L
s
.45917 .30331 m
.4384 .26912 L
.47315 .22926 L
.49566 .26705 L
.45917 .30331 L
s
.4384 .26912 m
.42556 .24403 L
.45923 .20004 L
.47315 .22926 L
.4384 .26912 L
s
.42556 .24403 m
.42122 .23463 L
.45453 .18865 L
.45923 .20004 L
.42556 .24403 L
s
.42122 .23463 m
.42556 .24403 L
.45923 .20004 L
.45453 .18865 L
.42122 .23463 L
s
.42556 .24403 m
.4384 .26912 L
.47315 .22926 L
.45923 .20004 L
.42556 .24403 L
s
.4384 .26912 m
.45917 .30331 L
.49566 .26705 L
.47315 .22926 L
.4384 .26912 L
s
.45917 .30331 m
.48697 .34037 L
.52578 .30598 L
.49566 .26705 L
.45917 .30331 L
s
.48697 .34037 m
.52057 .37579 L
.56221 .34133 L
.52578 .30598 L
.48697 .34037 L
s
.52057 .37579 m
.55852 .40671 L
.60334 .37027 L
.56221 .34133 L
.52057 .37579 L
s
.55852 .40671 m
.59916 .43143 L
.64738 .39122 L
.60334 .37027 L
.55852 .40671 L
s
.59916 .43143 m
.6407 .44924 L
.6924 .40361 L
.64738 .39122 L
.59916 .43143 L
s
.6407 .44924 m
.68133 .46024 L
.73644 .40773 L
.6924 .40361 L
.6407 .44924 L
s
.68133 .46024 m
.71928 .46518 L
.77757 .40467 L
.73644 .40773 L
.68133 .46024 L
s
.71928 .46518 m
.75289 .46541 L
.81399 .39625 L
.77757 .40467 L
.71928 .46518 L
s
.75289 .46541 m
.78068 .46267 L
.84412 .38499 L
.81399 .39625 L
.75289 .46541 L
s
.78068 .46267 m
.80145 .45886 L
.86663 .37381 L
.84412 .38499 L
.78068 .46267 L
s
.80145 .45886 m
.81429 .45574 L
.88054 .36561 L
.86663 .37381 L
.80145 .45886 L
s
.81429 .45574 m
.81863 .45454 L
.88525 .36259 L
.88054 .36561 L
.81429 .45574 L
s
.81863 .45454 m
.81429 .45574 L
.88054 .36561 L
.88525 .36259 L
.81863 .45454 L
s
.81429 .45574 m
.80145 .45886 L
.86663 .37381 L
.88054 .36561 L
.81429 .45574 L
s
.80145 .45886 m
.78068 .46267 L
.84412 .38499 L
.86663 .37381 L
.80145 .45886 L
s
.78068 .46267 m
.75289 .46541 L
.81399 .39625 L
.84412 .38499 L
.78068 .46267 L
s
.75289 .46541 m
.71928 .46518 L
.77757 .40467 L
.81399 .39625 L
.75289 .46541 L
s
.71928 .46518 m
.68133 .46024 L
.73644 .40773 L
.77757 .40467 L
.71928 .46518 L
s
.68133 .46024 m
.6407 .44924 L
.6924 .40361 L
.73644 .40773 L
.68133 .46024 L
s
.6407 .44924 m
.59916 .43143 L
.64738 .39122 L
.6924 .40361 L
.6407 .44924 L
s
.59916 .43143 m
.55852 .40671 L
.60334 .37027 L
.64738 .39122 L
.59916 .43143 L
s
.55852 .40671 m
.52057 .37579 L
.56221 .34133 L
.60334 .37027 L
.55852 .40671 L
s
.52057 .37579 m
.48697 .34037 L
.52578 .30598 L
.56221 .34133 L
.52057 .37579 L
s
.48697 .34037 m
.45917 .30331 L
.49566 .26705 L
.52578 .30598 L
.48697 .34037 L
s
.45917 .30331 m
.4384 .26912 L
.47315 .22926 L
.49566 .26705 L
.45917 .30331 L
s
.4384 .26912 m
.42556 .24403 L
.45923 .20004 L
.47315 .22926 L
.4384 .26912 L
s
.42556 .24403 m
.42122 .23463 L
.45453 .18865 L
.45923 .20004 L
.42556 .24403 L
s
.42122 .23463 m
.42556 .24403 L
.45923 .20004 L
.45453 .18865 L
.42122 .23463 L
s
.42556 .24403 m
.4384 .26912 L
.47315 .22926 L
.45923 .20004 L
.42556 .24403 L
s
.4384 .26912 m
.45917 .30331 L
.49566 .26705 L
.47315 .22926 L
.4384 .26912 L
s
.45917 .30331 m
.48697 .34037 L
.52578 .30598 L
.49566 .26705 L
.45917 .30331 L
s
.48697 .34037 m
.52057 .37579 L
.56221 .34133 L
.52578 .30598 L
.48697 .34037 L
s
.52057 .37579 m
.55852 .40671 L
.60334 .37027 L
.56221 .34133 L
.52057 .37579 L
s
.55852 .40671 m
.59916 .43143 L
.64738 .39122 L
.60334 .37027 L
.55852 .40671 L
s
.59916 .43143 m
.6407 .44924 L
.6924 .40361 L
.64738 .39122 L
.59916 .43143 L
s
.6407 .44924 m
.68133 .46024 L
.73644 .40773 L
.6924 .40361 L
.6407 .44924 L
s
.68133 .46024 m
.71928 .46518 L
.77757 .40467 L
.73644 .40773 L
.68133 .46024 L
s
.71928 .46518 m
.75289 .46541 L
.81399 .39625 L
.77757 .40467 L
.71928 .46518 L
s
.75289 .46541 m
.78068 .46267 L
.84412 .38499 L
.81399 .39625 L
.75289 .46541 L
s
.78068 .46267 m
.80145 .45886 L
.86663 .37381 L
.84412 .38499 L
.78068 .46267 L
s
.80145 .45886 m
.81429 .45574 L
.88054 .36561 L
.86663 .37381 L
.80145 .45886 L
s
.81429 .45574 m
.81863 .45454 L
.88525 .36259 L
.88054 .36561 L
.81429 .45574 L
s
.88525 .36259 m
.88054 .36561 L
.93004 .26157 L
.93502 .25544 L
.88525 .36259 L
s
.88054 .36561 m
.86663 .37381 L
.91533 .27802 L
.93004 .26157 L
.88054 .36561 L
s
.86663 .37381 m
.84412 .38499 L
.89152 .30019 L
.91533 .27802 L
.86663 .37381 L
s
.84412 .38499 m
.81399 .39625 L
.85965 .32298 L
.89152 .30019 L
.84412 .38499 L
s
.81399 .39625 m
.77757 .40467 L
.82112 .34214 L
.85965 .32298 L
.81399 .39625 L
s
.77757 .40467 m
.73644 .40773 L
.77761 .35448 L
.82112 .34214 L
.77757 .40467 L
s
.73644 .40773 m
.6924 .40361 L
.73103 .3579 L
.77761 .35448 L
.73644 .40773 L
s
.6924 .40361 m
.64738 .39122 L
.68341 .35122 L
.73103 .3579 L
.6924 .40361 L
s
.64738 .39122 m
.60334 .37027 L
.63682 .33411 L
.68341 .35122 L
.64738 .39122 L
s
.60334 .37027 m
.56221 .34133 L
.59332 .30708 L
.63682 .33411 L
.60334 .37027 L
s
.56221 .34133 m
.52578 .30598 L
.55479 .27152 L
.59332 .30708 L
.56221 .34133 L
s
.52578 .30598 m
.49566 .26705 L
.52292 .22997 L
.55479 .27152 L
.52578 .30598 L
s
.49566 .26705 m
.47315 .22926 L
.49911 .18684 L
.52292 .22997 L
.49566 .26705 L
s
.47315 .22926 m
.45923 .20004 L
.48439 .15046 L
.49911 .18684 L
.47315 .22926 L
s
.45923 .20004 m
.45453 .18865 L
.47942 .13508 L
.48439 .15046 L
.45923 .20004 L
s
.45453 .18865 m
.45923 .20004 L
.48439 .15046 L
.47942 .13508 L
.45453 .18865 L
s
.45923 .20004 m
.47315 .22926 L
.49911 .18684 L
.48439 .15046 L
.45923 .20004 L
s
.47315 .22926 m
.49566 .26705 L
.52292 .22997 L
.49911 .18684 L
.47315 .22926 L
s
.49566 .26705 m
.52578 .30598 L
.55479 .27152 L
.52292 .22997 L
.49566 .26705 L
s
.52578 .30598 m
.56221 .34133 L
.59332 .30708 L
.55479 .27152 L
.52578 .30598 L
s
.56221 .34133 m
.60334 .37027 L
.63682 .33411 L
.59332 .30708 L
.56221 .34133 L
s
.60334 .37027 m
.64738 .39122 L
.68341 .35122 L
.63682 .33411 L
.60334 .37027 L
s
.64738 .39122 m
.6924 .40361 L
.73103 .3579 L
.68341 .35122 L
.64738 .39122 L
s
.6924 .40361 m
.73644 .40773 L
.77761 .35448 L
.73103 .3579 L
.6924 .40361 L
s
.73644 .40773 m
.77757 .40467 L
.82112 .34214 L
.77761 .35448 L
.73644 .40773 L
s
.77757 .40467 m
.81399 .39625 L
.85965 .32298 L
.82112 .34214 L
.77757 .40467 L
s
.81399 .39625 m
.84412 .38499 L
.89152 .30019 L
.85965 .32298 L
.81399 .39625 L
s
.84412 .38499 m
.86663 .37381 L
.91533 .27802 L
.89152 .30019 L
.84412 .38499 L
s
.86663 .37381 m
.88054 .36561 L
.93004 .26157 L
.91533 .27802 L
.86663 .37381 L
s
.88054 .36561 m
.88525 .36259 L
.93502 .25544 L
.93004 .26157 L
.88054 .36561 L
s
.88525 .36259 m
.88054 .36561 L
.93004 .26157 L
.93502 .25544 L
.88525 .36259 L
s
.88054 .36561 m
.86663 .37381 L
.91533 .27802 L
.93004 .26157 L
.88054 .36561 L
s
.86663 .37381 m
.84412 .38499 L
.89152 .30019 L
.91533 .27802 L
.86663 .37381 L
s
.84412 .38499 m
.81399 .39625 L
.85965 .32298 L
.89152 .30019 L
.84412 .38499 L
s
.81399 .39625 m
.77757 .40467 L
.82112 .34214 L
.85965 .32298 L
.81399 .39625 L
s
.77757 .40467 m
.73644 .40773 L
.77761 .35448 L
.82112 .34214 L
.77757 .40467 L
s
.73644 .40773 m
.6924 .40361 L
.73103 .3579 L
.77761 .35448 L
.73644 .40773 L
s
.6924 .40361 m
.64738 .39122 L
.68341 .35122 L
.73103 .3579 L
.6924 .40361 L
s
.64738 .39122 m
.60334 .37027 L
.63682 .33411 L
.68341 .35122 L
.64738 .39122 L
s
.60334 .37027 m
.56221 .34133 L
.59332 .30708 L
.63682 .33411 L
.60334 .37027 L
s
.56221 .34133 m
.52578 .30598 L
.55479 .27152 L
.59332 .30708 L
.56221 .34133 L
s
.52578 .30598 m
.49566 .26705 L
.52292 .22997 L
.55479 .27152 L
.52578 .30598 L
s
.49566 .26705 m
.47315 .22926 L
.49911 .18684 L
.52292 .22997 L
.49566 .26705 L
s
.47315 .22926 m
.45923 .20004 L
.48439 .15046 L
.49911 .18684 L
.47315 .22926 L
s
.45923 .20004 m
.45453 .18865 L
.47942 .13508 L
.48439 .15046 L
.45923 .20004 L
s
.45453 .18865 m
.45923 .20004 L
.48439 .15046 L
.47942 .13508 L
.45453 .18865 L
s
.45923 .20004 m
.47315 .22926 L
.49911 .18684 L
.48439 .15046 L
.45923 .20004 L
s
.47315 .22926 m
.49566 .26705 L
.52292 .22997 L
.49911 .18684 L
.47315 .22926 L
s
.49566 .26705 m
.52578 .30598 L
.55479 .27152 L
.52292 .22997 L
.49566 .26705 L
s
.52578 .30598 m
.56221 .34133 L
.59332 .30708 L
.55479 .27152 L
.52578 .30598 L
s
.56221 .34133 m
.60334 .37027 L
.63682 .33411 L
.59332 .30708 L
.56221 .34133 L
s
.60334 .37027 m
.64738 .39122 L
.68341 .35122 L
.63682 .33411 L
.60334 .37027 L
s
.64738 .39122 m
.6924 .40361 L
.73103 .3579 L
.68341 .35122 L
.64738 .39122 L
s
.6924 .40361 m
.73644 .40773 L
.77761 .35448 L
.73103 .3579 L
.6924 .40361 L
s
.73644 .40773 m
.77757 .40467 L
.82112 .34214 L
.77761 .35448 L
.73644 .40773 L
s
.77757 .40467 m
.81399 .39625 L
.85965 .32298 L
.82112 .34214 L
.77757 .40467 L
s
.81399 .39625 m
.84412 .38499 L
.89152 .30019 L
.85965 .32298 L
.81399 .39625 L
s
.84412 .38499 m
.86663 .37381 L
.91533 .27802 L
.89152 .30019 L
.84412 .38499 L
s
.86663 .37381 m
.88054 .36561 L
.93004 .26157 L
.91533 .27802 L
.86663 .37381 L
s
.88054 .36561 m
.88525 .36259 L
.93502 .25544 L
.93004 .26157 L
.88054 .36561 L
s
.93502 .25544 m
.93004 .26157 L
.96064 .15154 L
.96578 .13777 L
.93502 .25544 L
s
.93004 .26157 m
.91533 .27802 L
.94543 .18449 L
.96064 .15154 L
.93004 .26157 L
s
.91533 .27802 m
.89152 .30019 L
.92081 .22365 L
.94543 .18449 L
.91533 .27802 L
s
.89152 .30019 m
.85965 .32298 L
.88787 .26083 L
.92081 .22365 L
.89152 .30019 L
s
.85965 .32298 m
.82112 .34214 L
.84804 .2914 L
.88787 .26083 L
.85965 .32298 L
s
.82112 .34214 m
.77761 .35448 L
.80306 .31255 L
.84804 .2914 L
.82112 .34214 L
s
.77761 .35448 m
.73103 .3579 L
.75491 .32259 L
.80306 .31255 L
.77761 .35448 L
s
.73103 .3579 m
.68341 .35122 L
.70568 .32066 L
.75491 .32259 L
.73103 .3579 L
s
.68341 .35122 m
.63682 .33411 L
.65752 .3066 L
.70568 .32066 L
.68341 .35122 L
s
.63682 .33411 m
.59332 .30708 L
.61254 .28094 L
.65752 .3066 L
.63682 .33411 L
s
.59332 .30708 m
.55479 .27152 L
.57271 .24488 L
.61254 .28094 L
.59332 .30708 L
s
.55479 .27152 m
.52292 .22997 L
.53977 .20037 L
.57271 .24488 L
.55479 .27152 L
s
.52292 .22997 m
.49911 .18684 L
.51516 .15054 L
.53977 .20037 L
.52292 .22997 L
s
.49911 .18684 m
.48439 .15046 L
.49994 .10197 L
.51516 .15054 L
.49911 .18684 L
s
.48439 .15046 m
.47942 .13508 L
.4948 .07624 L
.49994 .10197 L
.48439 .15046 L
s
.47942 .13508 m
.48439 .15046 L
.49994 .10197 L
.4948 .07624 L
.47942 .13508 L
s
.48439 .15046 m
.49911 .18684 L
.51516 .15054 L
.49994 .10197 L
.48439 .15046 L
s
.49911 .18684 m
.52292 .22997 L
.53977 .20037 L
.51516 .15054 L
.49911 .18684 L
s
.52292 .22997 m
.55479 .27152 L
.57271 .24488 L
.53977 .20037 L
.52292 .22997 L
s
.55479 .27152 m
.59332 .30708 L
.61254 .28094 L
.57271 .24488 L
.55479 .27152 L
s
.59332 .30708 m
.63682 .33411 L
.65752 .3066 L
.61254 .28094 L
.59332 .30708 L
s
.63682 .33411 m
.68341 .35122 L
.70568 .32066 L
.65752 .3066 L
.63682 .33411 L
s
.68341 .35122 m
.73103 .3579 L
.75491 .32259 L
.70568 .32066 L
.68341 .35122 L
s
.73103 .3579 m
.77761 .35448 L
.80306 .31255 L
.75491 .32259 L
.73103 .3579 L
s
.77761 .35448 m
.82112 .34214 L
.84804 .2914 L
.80306 .31255 L
.77761 .35448 L
s
.82112 .34214 m
.85965 .32298 L
.88787 .26083 L
.84804 .2914 L
.82112 .34214 L
s
.85965 .32298 m
.89152 .30019 L
.92081 .22365 L
.88787 .26083 L
.85965 .32298 L
s
.89152 .30019 m
.91533 .27802 L
.94543 .18449 L
.92081 .22365 L
.89152 .30019 L
s
.91533 .27802 m
.93004 .26157 L
.96064 .15154 L
.94543 .18449 L
.91533 .27802 L
s
.93004 .26157 m
.93502 .25544 L
.96578 .13777 L
.96064 .15154 L
.93004 .26157 L
s
.93502 .25544 m
.93004 .26157 L
.96064 .15154 L
.96578 .13777 L
.93502 .25544 L
s
.93004 .26157 m
.91533 .27802 L
.94543 .18449 L
.96064 .15154 L
.93004 .26157 L
s
.91533 .27802 m
.89152 .30019 L
.92081 .22365 L
.94543 .18449 L
.91533 .27802 L
s
.89152 .30019 m
.85965 .32298 L
.88787 .26083 L
.92081 .22365 L
.89152 .30019 L
s
.85965 .32298 m
.82112 .34214 L
.84804 .2914 L
.88787 .26083 L
.85965 .32298 L
s
.82112 .34214 m
.77761 .35448 L
.80306 .31255 L
.84804 .2914 L
.82112 .34214 L
s
.77761 .35448 m
.73103 .3579 L
.75491 .32259 L
.80306 .31255 L
.77761 .35448 L
s
.73103 .3579 m
.68341 .35122 L
.70568 .32066 L
.75491 .32259 L
.73103 .3579 L
s
.68341 .35122 m
.63682 .33411 L
.65752 .3066 L
.70568 .32066 L
.68341 .35122 L
s
.63682 .33411 m
.59332 .30708 L
.61254 .28094 L
.65752 .3066 L
.63682 .33411 L
s
.59332 .30708 m
.55479 .27152 L
.57271 .24488 L
.61254 .28094 L
.59332 .30708 L
s
.55479 .27152 m
.52292 .22997 L
.53977 .20037 L
.57271 .24488 L
.55479 .27152 L
s
.52292 .22997 m
.49911 .18684 L
.51516 .15054 L
.53977 .20037 L
.52292 .22997 L
s
.49911 .18684 m
.48439 .15046 L
.49994 .10197 L
.51516 .15054 L
.49911 .18684 L
s
.48439 .15046 m
.47942 .13508 L
.4948 .07624 L
.49994 .10197 L
.48439 .15046 L
s
.47942 .13508 m
.48439 .15046 L
.49994 .10197 L
.4948 .07624 L
.47942 .13508 L
s
.48439 .15046 m
.49911 .18684 L
.51516 .15054 L
.49994 .10197 L
.48439 .15046 L
s
.49911 .18684 m
.52292 .22997 L
.53977 .20037 L
.51516 .15054 L
.49911 .18684 L
s
.52292 .22997 m
.55479 .27152 L
.57271 .24488 L
.53977 .20037 L
.52292 .22997 L
s
.55479 .27152 m
.59332 .30708 L
.61254 .28094 L
.57271 .24488 L
.55479 .27152 L
s
.59332 .30708 m
.63682 .33411 L
.65752 .3066 L
.61254 .28094 L
.59332 .30708 L
s
.63682 .33411 m
.68341 .35122 L
.70568 .32066 L
.65752 .3066 L
.63682 .33411 L
s
.68341 .35122 m
.73103 .3579 L
.75491 .32259 L
.70568 .32066 L
.68341 .35122 L
s
.73103 .3579 m
.77761 .35448 L
.80306 .31255 L
.75491 .32259 L
.73103 .3579 L
s
.77761 .35448 m
.82112 .34214 L
.84804 .2914 L
.80306 .31255 L
.77761 .35448 L
s
.82112 .34214 m
.85965 .32298 L
.88787 .26083 L
.84804 .2914 L
.82112 .34214 L
s
.85965 .32298 m
.89152 .30019 L
.92081 .22365 L
.88787 .26083 L
.85965 .32298 L
s
.89152 .30019 m
.91533 .27802 L
.94543 .18449 L
.92081 .22365 L
.89152 .30019 L
s
.91533 .27802 m
.93004 .26157 L
.96064 .15154 L
.94543 .18449 L
.91533 .27802 L
s
.93004 .26157 m
.93502 .25544 L
.96578 .13777 L
.96064 .15154 L
.93004 .26157 L
s
.96578 .13777 m
.96064 .15154 L
.97099 .07624 L
.97619 .01472 L
.96578 .13777 L
s
.96064 .15154 m
.94543 .18449 L
.95561 .13508 L
.97099 .07624 L
.96064 .15154 L
s
.94543 .18449 m
.92081 .22365 L
.93072 .18865 L
.95561 .13508 L
.94543 .18449 L
s
.92081 .22365 m
.88787 .26083 L
.89741 .23463 L
.93072 .18865 L
.92081 .22365 L
s
.88787 .26083 m
.84804 .2914 L
.85714 .27099 L
.89741 .23463 L
.88787 .26083 L
s
.84804 .2914 m
.80306 .31255 L
.81167 .29615 L
.85714 .27099 L
.84804 .2914 L
s
.80306 .31255 m
.75491 .32259 L
.76298 .30902 L
.81167 .29615 L
.80306 .31255 L
s
.75491 .32259 m
.70568 .32066 L
.71321 .30902 L
.76298 .30902 L
.75491 .32259 L
s
.70568 .32066 m
.65752 .3066 L
.66452 .29615 L
.71321 .30902 L
.70568 .32066 L
s
.65752 .3066 m
.61254 .28094 L
.61905 .27099 L
.66452 .29615 L
.65752 .3066 L
s
.61254 .28094 m
.57271 .24488 L
.57878 .23463 L
.61905 .27099 L
.61254 .28094 L
s
.57271 .24488 m
.53977 .20037 L
.54547 .18865 L
.57878 .23463 L
.57271 .24488 L
s
.53977 .20037 m
.51516 .15054 L
.52058 .13508 L
.54547 .18865 L
.53977 .20037 L
s
.51516 .15054 m
.49994 .10197 L
.5052 .07624 L
.52058 .13508 L
.51516 .15054 L
s
.49994 .10197 m
.4948 .07624 L
.5 .01472 L
.5052 .07624 L
.49994 .10197 L
s
.4948 .07624 m
.49994 .10197 L
.5052 .07624 L
.5 .01472 L
.4948 .07624 L
s
.49994 .10197 m
.51516 .15054 L
.52058 .13508 L
.5052 .07624 L
.49994 .10197 L
s
.51516 .15054 m
.53977 .20037 L
.54547 .18865 L
.52058 .13508 L
.51516 .15054 L
s
.53977 .20037 m
.57271 .24488 L
.57878 .23463 L
.54547 .18865 L
.53977 .20037 L
s
.57271 .24488 m
.61254 .28094 L
.61905 .27099 L
.57878 .23463 L
.57271 .24488 L
s
.61254 .28094 m
.65752 .3066 L
.66452 .29615 L
.61905 .27099 L
.61254 .28094 L
s
.65752 .3066 m
.70568 .32066 L
.71321 .30902 L
.66452 .29615 L
.65752 .3066 L
s
.70568 .32066 m
.75491 .32259 L
.76298 .30902 L
.71321 .30902 L
.70568 .32066 L
s
.75491 .32259 m
.80306 .31255 L
.81167 .29615 L
.76298 .30902 L
.75491 .32259 L
s
.80306 .31255 m
.84804 .2914 L
.85714 .27099 L
.81167 .29615 L
.80306 .31255 L
s
.84804 .2914 m
.88787 .26083 L
.89741 .23463 L
.85714 .27099 L
.84804 .2914 L
s
.88787 .26083 m
.92081 .22365 L
.93072 .18865 L
.89741 .23463 L
.88787 .26083 L
s
.92081 .22365 m
.94543 .18449 L
.95561 .13508 L
.93072 .18865 L
.92081 .22365 L
s
.94543 .18449 m
.96064 .15154 L
.97099 .07624 L
.95561 .13508 L
.94543 .18449 L
s
.96064 .15154 m
.96578 .13777 L
.97619 .01472 L
.97099 .07624 L
.96064 .15154 L
s
.96578 .13777 m
.96064 .15154 L
.97099 .07624 L
.97619 .01472 L
.96578 .13777 L
s
.96064 .15154 m
.94543 .18449 L
.95561 .13508 L
.97099 .07624 L
.96064 .15154 L
s
.94543 .18449 m
.92081 .22365 L
.93072 .18865 L
.95561 .13508 L
.94543 .18449 L
s
.92081 .22365 m
.88787 .26083 L
.89741 .23463 L
.93072 .18865 L
.92081 .22365 L
s
.88787 .26083 m
.84804 .2914 L
.85714 .27099 L
.89741 .23463 L
.88787 .26083 L
s
.84804 .2914 m
.80306 .31255 L
.81167 .29615 L
.85714 .27099 L
.84804 .2914 L
s
.80306 .31255 m
.75491 .32259 L
.76298 .30902 L
.81167 .29615 L
.80306 .31255 L
s
.75491 .32259 m
.70568 .32066 L
.71321 .30902 L
.76298 .30902 L
.75491 .32259 L
s
.70568 .32066 m
.65752 .3066 L
.66452 .29615 L
.71321 .30902 L
.70568 .32066 L
s
.65752 .3066 m
.61254 .28094 L
.61905 .27099 L
.66452 .29615 L
.65752 .3066 L
s
.61254 .28094 m
.57271 .24488 L
.57878 .23463 L
.61905 .27099 L
.61254 .28094 L
s
.57271 .24488 m
.53977 .20037 L
.54547 .18865 L
.57878 .23463 L
.57271 .24488 L
s
.53977 .20037 m
.51516 .15054 L
.52058 .13508 L
.54547 .18865 L
.53977 .20037 L
s
.51516 .15054 m
.49994 .10197 L
.5052 .07624 L
.52058 .13508 L
.51516 .15054 L
s
.49994 .10197 m
.4948 .07624 L
.5 .01472 L
.5052 .07624 L
.49994 .10197 L
s
.4948 .07624 m
.49994 .10197 L
.5052 .07624 L
.5 .01472 L
.4948 .07624 L
s
.49994 .10197 m
.51516 .15054 L
.52058 .13508 L
.5052 .07624 L
.49994 .10197 L
s
.51516 .15054 m
.53977 .20037 L
.54547 .18865 L
.52058 .13508 L
.51516 .15054 L
s
.53977 .20037 m
.57271 .24488 L
.57878 .23463 L
.54547 .18865 L
.53977 .20037 L
s
.57271 .24488 m
.61254 .28094 L
.61905 .27099 L
.57878 .23463 L
.57271 .24488 L
s
.61254 .28094 m
.65752 .3066 L
.66452 .29615 L
.61905 .27099 L
.61254 .28094 L
s
.65752 .3066 m
.70568 .32066 L
.71321 .30902 L
.66452 .29615 L
.65752 .3066 L
s
.70568 .32066 m
.75491 .32259 L
.76298 .30902 L
.71321 .30902 L
.70568 .32066 L
s
.75491 .32259 m
.80306 .31255 L
.81167 .29615 L
.76298 .30902 L
.75491 .32259 L
s
.80306 .31255 m
.84804 .2914 L
.85714 .27099 L
.81167 .29615 L
.80306 .31255 L
s
.84804 .2914 m
.88787 .26083 L
.89741 .23463 L
.85714 .27099 L
.84804 .2914 L
s
.88787 .26083 m
.92081 .22365 L
.93072 .18865 L
.89741 .23463 L
.88787 .26083 L
s
.92081 .22365 m
.94543 .18449 L
.95561 .13508 L
.93072 .18865 L
.92081 .22365 L
s
.94543 .18449 m
.96064 .15154 L
.97099 .07624 L
.95561 .13508 L
.94543 .18449 L
s
.96064 .15154 m
.96578 .13777 L
.97619 .01472 L
.97099 .07624 L
.96064 .15154 L
s
.97619 .01472 m
.97099 .07624 L
.96064 .15154 L
.96578 .13777 L
.97619 .01472 L
s
.97099 .07624 m
.95561 .13508 L
.94543 .18449 L
.96064 .15154 L
.97099 .07624 L
s
.95561 .13508 m
.93072 .18865 L
.92081 .22365 L
.94543 .18449 L
.95561 .13508 L
s
.93072 .18865 m
.89741 .23463 L
.88787 .26083 L
.92081 .22365 L
.93072 .18865 L
s
.89741 .23463 m
.85714 .27099 L
.84804 .2914 L
.88787 .26083 L
.89741 .23463 L
s
.85714 .27099 m
.81167 .29615 L
.80306 .31255 L
.84804 .2914 L
.85714 .27099 L
s
.81167 .29615 m
.76298 .30902 L
.75491 .32259 L
.80306 .31255 L
.81167 .29615 L
s
.76298 .30902 m
.71321 .30902 L
.70568 .32066 L
.75491 .32259 L
.76298 .30902 L
s
.71321 .30902 m
.66452 .29615 L
.65752 .3066 L
.70568 .32066 L
.71321 .30902 L
s
.66452 .29615 m
.61905 .27099 L
.61254 .28094 L
.65752 .3066 L
.66452 .29615 L
s
.61905 .27099 m
.57878 .23463 L
.57271 .24488 L
.61254 .28094 L
.61905 .27099 L
s
.57878 .23463 m
.54547 .18865 L
.53977 .20037 L
.57271 .24488 L
.57878 .23463 L
s
.54547 .18865 m
.52058 .13508 L
.51516 .15054 L
.53977 .20037 L
.54547 .18865 L
s
.52058 .13508 m
.5052 .07624 L
.49994 .10197 L
.51516 .15054 L
.52058 .13508 L
s
.5052 .07624 m
.5 .01472 L
.4948 .07624 L
.49994 .10197 L
.5052 .07624 L
s
.5 .01472 m
.5052 .07624 L
.49994 .10197 L
.4948 .07624 L
.5 .01472 L
s
.5052 .07624 m
.52058 .13508 L
.51516 .15054 L
.49994 .10197 L
.5052 .07624 L
s
.52058 .13508 m
.54547 .18865 L
.53977 .20037 L
.51516 .15054 L
.52058 .13508 L
s
.54547 .18865 m
.57878 .23463 L
.57271 .24488 L
.53977 .20037 L
.54547 .18865 L
s
.57878 .23463 m
.61905 .27099 L
.61254 .28094 L
.57271 .24488 L
.57878 .23463 L
s
.61905 .27099 m
.66452 .29615 L
.65752 .3066 L
.61254 .28094 L
.61905 .27099 L
s
.66452 .29615 m
.71321 .30902 L
.70568 .32066 L
.65752 .3066 L
.66452 .29615 L
s
.71321 .30902 m
.76298 .30902 L
.75491 .32259 L
.70568 .32066 L
.71321 .30902 L
s
.76298 .30902 m
.81167 .29615 L
.80306 .31255 L
.75491 .32259 L
.76298 .30902 L
s
.81167 .29615 m
.85714 .27099 L
.84804 .2914 L
.80306 .31255 L
.81167 .29615 L
s
.85714 .27099 m
.89741 .23463 L
.88787 .26083 L
.84804 .2914 L
.85714 .27099 L
s
.89741 .23463 m
.93072 .18865 L
.92081 .22365 L
.88787 .26083 L
.89741 .23463 L
s
.93072 .18865 m
.95561 .13508 L
.94543 .18449 L
.92081 .22365 L
.93072 .18865 L
s
.95561 .13508 m
.97099 .07624 L
.96064 .15154 L
.94543 .18449 L
.95561 .13508 L
s
.97099 .07624 m
.97619 .01472 L
.96578 .13777 L
.96064 .15154 L
.97099 .07624 L
s
.97619 .01472 m
.97099 .07624 L
.96064 .15154 L
.96578 .13777 L
.97619 .01472 L
s
.97099 .07624 m
.95561 .13508 L
.94543 .18449 L
.96064 .15154 L
.97099 .07624 L
s
.95561 .13508 m
.93072 .18865 L
.92081 .22365 L
.94543 .18449 L
.95561 .13508 L
s
.93072 .18865 m
.89741 .23463 L
.88787 .26083 L
.92081 .22365 L
.93072 .18865 L
s
.89741 .23463 m
.85714 .27099 L
.84804 .2914 L
.88787 .26083 L
.89741 .23463 L
s
.85714 .27099 m
.81167 .29615 L
.80306 .31255 L
.84804 .2914 L
.85714 .27099 L
s
.81167 .29615 m
.76298 .30902 L
.75491 .32259 L
.80306 .31255 L
.81167 .29615 L
s
.76298 .30902 m
.71321 .30902 L
.70568 .32066 L
.75491 .32259 L
.76298 .30902 L
s
.71321 .30902 m
.66452 .29615 L
.65752 .3066 L
.70568 .32066 L
.71321 .30902 L
s
.66452 .29615 m
.61905 .27099 L
.61254 .28094 L
.65752 .3066 L
.66452 .29615 L
s
.61905 .27099 m
.57878 .23463 L
.57271 .24488 L
.61254 .28094 L
.61905 .27099 L
s
.57878 .23463 m
.54547 .18865 L
.53977 .20037 L
.57271 .24488 L
.57878 .23463 L
s
.54547 .18865 m
.52058 .13508 L
.51516 .15054 L
.53977 .20037 L
.54547 .18865 L
s
.52058 .13508 m
.5052 .07624 L
.49994 .10197 L
.51516 .15054 L
.52058 .13508 L
s
.5052 .07624 m
.5 .01472 L
.4948 .07624 L
.49994 .10197 L
.5052 .07624 L
s
.5 .01472 m
.5052 .07624 L
.49994 .10197 L
.4948 .07624 L
.5 .01472 L
s
.5052 .07624 m
.52058 .13508 L
.51516 .15054 L
.49994 .10197 L
.5052 .07624 L
s
.52058 .13508 m
.54547 .18865 L
.53977 .20037 L
.51516 .15054 L
.52058 .13508 L
s
.54547 .18865 m
.57878 .23463 L
.57271 .24488 L
.53977 .20037 L
.54547 .18865 L
s
.57878 .23463 m
.61905 .27099 L
.61254 .28094 L
.57271 .24488 L
.57878 .23463 L
s
.61905 .27099 m
.66452 .29615 L
.65752 .3066 L
.61254 .28094 L
.61905 .27099 L
s
.66452 .29615 m
.71321 .30902 L
.70568 .32066 L
.65752 .3066 L
.66452 .29615 L
s
.71321 .30902 m
.76298 .30902 L
.75491 .32259 L
.70568 .32066 L
.71321 .30902 L
s
.76298 .30902 m
.81167 .29615 L
.80306 .31255 L
.75491 .32259 L
.76298 .30902 L
s
.81167 .29615 m
.85714 .27099 L
.84804 .2914 L
.80306 .31255 L
.81167 .29615 L
s
.85714 .27099 m
.89741 .23463 L
.88787 .26083 L
.84804 .2914 L
.85714 .27099 L
s
.89741 .23463 m
.93072 .18865 L
.92081 .22365 L
.88787 .26083 L
.89741 .23463 L
s
.93072 .18865 m
.95561 .13508 L
.94543 .18449 L
.92081 .22365 L
.93072 .18865 L
s
.95561 .13508 m
.97099 .07624 L
.96064 .15154 L
.94543 .18449 L
.95561 .13508 L
s
.97099 .07624 m
.97619 .01472 L
.96578 .13777 L
.96064 .15154 L
.97099 .07624 L
s
.96578 .13777 m
.96064 .15154 L
.93004 .26157 L
.93502 .25544 L
.96578 .13777 L
s
.96064 .15154 m
.94543 .18449 L
.91533 .27802 L
.93004 .26157 L
.96064 .15154 L
s
.94543 .18449 m
.92081 .22365 L
.89152 .30019 L
.91533 .27802 L
.94543 .18449 L
s
.92081 .22365 m
.88787 .26083 L
.85965 .32298 L
.89152 .30019 L
.92081 .22365 L
s
.88787 .26083 m
.84804 .2914 L
.82112 .34214 L
.85965 .32298 L
.88787 .26083 L
s
.84804 .2914 m
.80306 .31255 L
.77761 .35448 L
.82112 .34214 L
.84804 .2914 L
s
.80306 .31255 m
.75491 .32259 L
.73103 .3579 L
.77761 .35448 L
.80306 .31255 L
s
.75491 .32259 m
.70568 .32066 L
.68341 .35122 L
.73103 .3579 L
.75491 .32259 L
s
.70568 .32066 m
.65752 .3066 L
.63682 .33411 L
.68341 .35122 L
.70568 .32066 L
s
.65752 .3066 m
.61254 .28094 L
.59332 .30708 L
.63682 .33411 L
.65752 .3066 L
s
.61254 .28094 m
.57271 .24488 L
.55479 .27152 L
.59332 .30708 L
.61254 .28094 L
s
.57271 .24488 m
.53977 .20037 L
.52292 .22997 L
.55479 .27152 L
.57271 .24488 L
s
.53977 .20037 m
.51516 .15054 L
.49911 .18684 L
.52292 .22997 L
.53977 .20037 L
s
.51516 .15054 m
.49994 .10197 L
.48439 .15046 L
.49911 .18684 L
.51516 .15054 L
s
.49994 .10197 m
.4948 .07624 L
.47942 .13508 L
.48439 .15046 L
.49994 .10197 L
s
.4948 .07624 m
.49994 .10197 L
.48439 .15046 L
.47942 .13508 L
.4948 .07624 L
s
.49994 .10197 m
.51516 .15054 L
.49911 .18684 L
.48439 .15046 L
.49994 .10197 L
s
.51516 .15054 m
.53977 .20037 L
.52292 .22997 L
.49911 .18684 L
.51516 .15054 L
s
.53977 .20037 m
.57271 .24488 L
.55479 .27152 L
.52292 .22997 L
.53977 .20037 L
s
.57271 .24488 m
.61254 .28094 L
.59332 .30708 L
.55479 .27152 L
.57271 .24488 L
s
.61254 .28094 m
.65752 .3066 L
.63682 .33411 L
.59332 .30708 L
.61254 .28094 L
s
.65752 .3066 m
.70568 .32066 L
.68341 .35122 L
.63682 .33411 L
.65752 .3066 L
s
.70568 .32066 m
.75491 .32259 L
.73103 .3579 L
.68341 .35122 L
.70568 .32066 L
s
.75491 .32259 m
.80306 .31255 L
.77761 .35448 L
.73103 .3579 L
.75491 .32259 L
s
.80306 .31255 m
.84804 .2914 L
.82112 .34214 L
.77761 .35448 L
.80306 .31255 L
s
.84804 .2914 m
.88787 .26083 L
.85965 .32298 L
.82112 .34214 L
.84804 .2914 L
s
.88787 .26083 m
.92081 .22365 L
.89152 .30019 L
.85965 .32298 L
.88787 .26083 L
s
.92081 .22365 m
.94543 .18449 L
.91533 .27802 L
.89152 .30019 L
.92081 .22365 L
s
.94543 .18449 m
.96064 .15154 L
.93004 .26157 L
.91533 .27802 L
.94543 .18449 L
s
.96064 .15154 m
.96578 .13777 L
.93502 .25544 L
.93004 .26157 L
.96064 .15154 L
s
.96578 .13777 m
.96064 .15154 L
.93004 .26157 L
.93502 .25544 L
.96578 .13777 L
s
.96064 .15154 m
.94543 .18449 L
.91533 .27802 L
.93004 .26157 L
.96064 .15154 L
s
.94543 .18449 m
.92081 .22365 L
.89152 .30019 L
.91533 .27802 L
.94543 .18449 L
s
.92081 .22365 m
.88787 .26083 L
.85965 .32298 L
.89152 .30019 L
.92081 .22365 L
s
.88787 .26083 m
.84804 .2914 L
.82112 .34214 L
.85965 .32298 L
.88787 .26083 L
s
.84804 .2914 m
.80306 .31255 L
.77761 .35448 L
.82112 .34214 L
.84804 .2914 L
s
.80306 .31255 m
.75491 .32259 L
.73103 .3579 L
.77761 .35448 L
.80306 .31255 L
s
.75491 .32259 m
.70568 .32066 L
.68341 .35122 L
.73103 .3579 L
.75491 .32259 L
s
.70568 .32066 m
.65752 .3066 L
.63682 .33411 L
.68341 .35122 L
.70568 .32066 L
s
.65752 .3066 m
.61254 .28094 L
.59332 .30708 L
.63682 .33411 L
.65752 .3066 L
s
.61254 .28094 m
.57271 .24488 L
.55479 .27152 L
.59332 .30708 L
.61254 .28094 L
s
.57271 .24488 m
.53977 .20037 L
.52292 .22997 L
.55479 .27152 L
.57271 .24488 L
s
.53977 .20037 m
.51516 .15054 L
.49911 .18684 L
.52292 .22997 L
.53977 .20037 L
s
.51516 .15054 m
.49994 .10197 L
.48439 .15046 L
.49911 .18684 L
.51516 .15054 L
s
.49994 .10197 m
.4948 .07624 L
.47942 .13508 L
.48439 .15046 L
.49994 .10197 L
s
.4948 .07624 m
.49994 .10197 L
.48439 .15046 L
.47942 .13508 L
.4948 .07624 L
s
.49994 .10197 m
.51516 .15054 L
.49911 .18684 L
.48439 .15046 L
.49994 .10197 L
s
.51516 .15054 m
.53977 .20037 L
.52292 .22997 L
.49911 .18684 L
.51516 .15054 L
s
.53977 .20037 m
.57271 .24488 L
.55479 .27152 L
.52292 .22997 L
.53977 .20037 L
s
.57271 .24488 m
.61254 .28094 L
.59332 .30708 L
.55479 .27152 L
.57271 .24488 L
s
.61254 .28094 m
.65752 .3066 L
.63682 .33411 L
.59332 .30708 L
.61254 .28094 L
s
.65752 .3066 m
.70568 .32066 L
.68341 .35122 L
.63682 .33411 L
.65752 .3066 L
s
.70568 .32066 m
.75491 .32259 L
.73103 .3579 L
.68341 .35122 L
.70568 .32066 L
s
.75491 .32259 m
.80306 .31255 L
.77761 .35448 L
.73103 .3579 L
.75491 .32259 L
s
.80306 .31255 m
.84804 .2914 L
.82112 .34214 L
.77761 .35448 L
.80306 .31255 L
s
.84804 .2914 m
.88787 .26083 L
.85965 .32298 L
.82112 .34214 L
.84804 .2914 L
s
.88787 .26083 m
.92081 .22365 L
.89152 .30019 L
.85965 .32298 L
.88787 .26083 L
s
.92081 .22365 m
.94543 .18449 L
.91533 .27802 L
.89152 .30019 L
.92081 .22365 L
s
.94543 .18449 m
.96064 .15154 L
.93004 .26157 L
.91533 .27802 L
.94543 .18449 L
s
.96064 .15154 m
.96578 .13777 L
.93502 .25544 L
.93004 .26157 L
.96064 .15154 L
s
.93502 .25544 m
.93004 .26157 L
.88054 .36561 L
.88525 .36259 L
.93502 .25544 L
s
.93004 .26157 m
.91533 .27802 L
.86663 .37381 L
.88054 .36561 L
.93004 .26157 L
s
.91533 .27802 m
.89152 .30019 L
.84412 .38499 L
.86663 .37381 L
.91533 .27802 L
s
.89152 .30019 m
.85965 .32298 L
.81399 .39625 L
.84412 .38499 L
.89152 .30019 L
s
.85965 .32298 m
.82112 .34214 L
.77757 .40467 L
.81399 .39625 L
.85965 .32298 L
s
.82112 .34214 m
.77761 .35448 L
.73644 .40773 L
.77757 .40467 L
.82112 .34214 L
s
.77761 .35448 m
.73103 .3579 L
.6924 .40361 L
.73644 .40773 L
.77761 .35448 L
s
.73103 .3579 m
.68341 .35122 L
.64738 .39122 L
.6924 .40361 L
.73103 .3579 L
s
.68341 .35122 m
.63682 .33411 L
.60334 .37027 L
.64738 .39122 L
.68341 .35122 L
s
.63682 .33411 m
.59332 .30708 L
.56221 .34133 L
.60334 .37027 L
.63682 .33411 L
s
.59332 .30708 m
.55479 .27152 L
.52578 .30598 L
.56221 .34133 L
.59332 .30708 L
s
.55479 .27152 m
.52292 .22997 L
.49566 .26705 L
.52578 .30598 L
.55479 .27152 L
s
.52292 .22997 m
.49911 .18684 L
.47315 .22926 L
.49566 .26705 L
.52292 .22997 L
s
.49911 .18684 m
.48439 .15046 L
.45923 .20004 L
.47315 .22926 L
.49911 .18684 L
s
.48439 .15046 m
.47942 .13508 L
.45453 .18865 L
.45923 .20004 L
.48439 .15046 L
s
.47942 .13508 m
.48439 .15046 L
.45923 .20004 L
.45453 .18865 L
.47942 .13508 L
s
.48439 .15046 m
.49911 .18684 L
.47315 .22926 L
.45923 .20004 L
.48439 .15046 L
s
.49911 .18684 m
.52292 .22997 L
.49566 .26705 L
.47315 .22926 L
.49911 .18684 L
s
.52292 .22997 m
.55479 .27152 L
.52578 .30598 L
.49566 .26705 L
.52292 .22997 L
s
.55479 .27152 m
.59332 .30708 L
.56221 .34133 L
.52578 .30598 L
.55479 .27152 L
s
.59332 .30708 m
.63682 .33411 L
.60334 .37027 L
.56221 .34133 L
.59332 .30708 L
s
.63682 .33411 m
.68341 .35122 L
.64738 .39122 L
.60334 .37027 L
.63682 .33411 L
s
.68341 .35122 m
.73103 .3579 L
.6924 .40361 L
.64738 .39122 L
.68341 .35122 L
s
.73103 .3579 m
.77761 .35448 L
.73644 .40773 L
.6924 .40361 L
.73103 .3579 L
s
.77761 .35448 m
.82112 .34214 L
.77757 .40467 L
.73644 .40773 L
.77761 .35448 L
s
.82112 .34214 m
.85965 .32298 L
.81399 .39625 L
.77757 .40467 L
.82112 .34214 L
s
.85965 .32298 m
.89152 .30019 L
.84412 .38499 L
.81399 .39625 L
.85965 .32298 L
s
.89152 .30019 m
.91533 .27802 L
.86663 .37381 L
.84412 .38499 L
.89152 .30019 L
s
.91533 .27802 m
.93004 .26157 L
.88054 .36561 L
.86663 .37381 L
.91533 .27802 L
s
.93004 .26157 m
.93502 .25544 L
.88525 .36259 L
.88054 .36561 L
.93004 .26157 L
s
.93502 .25544 m
.93004 .26157 L
.88054 .36561 L
.88525 .36259 L
.93502 .25544 L
s
.93004 .26157 m
.91533 .27802 L
.86663 .37381 L
.88054 .36561 L
.93004 .26157 L
s
.91533 .27802 m
.89152 .30019 L
.84412 .38499 L
.86663 .37381 L
.91533 .27802 L
s
.89152 .30019 m
.85965 .32298 L
.81399 .39625 L
.84412 .38499 L
.89152 .30019 L
s
.85965 .32298 m
.82112 .34214 L
.77757 .40467 L
.81399 .39625 L
.85965 .32298 L
s
.82112 .34214 m
.77761 .35448 L
.73644 .40773 L
.77757 .40467 L
.82112 .34214 L
s
.77761 .35448 m
.73103 .3579 L
.6924 .40361 L
.73644 .40773 L
.77761 .35448 L
s
.73103 .3579 m
.68341 .35122 L
.64738 .39122 L
.6924 .40361 L
.73103 .3579 L
s
.68341 .35122 m
.63682 .33411 L
.60334 .37027 L
.64738 .39122 L
.68341 .35122 L
s
.63682 .33411 m
.59332 .30708 L
.56221 .34133 L
.60334 .37027 L
.63682 .33411 L
s
.59332 .30708 m
.55479 .27152 L
.52578 .30598 L
.56221 .34133 L
.59332 .30708 L
s
.55479 .27152 m
.52292 .22997 L
.49566 .26705 L
.52578 .30598 L
.55479 .27152 L
s
.52292 .22997 m
.49911 .18684 L
.47315 .22926 L
.49566 .26705 L
.52292 .22997 L
s
.49911 .18684 m
.48439 .15046 L
.45923 .20004 L
.47315 .22926 L
.49911 .18684 L
s
.48439 .15046 m
.47942 .13508 L
.45453 .18865 L
.45923 .20004 L
.48439 .15046 L
s
.47942 .13508 m
.48439 .15046 L
.45923 .20004 L
.45453 .18865 L
.47942 .13508 L
s
.48439 .15046 m
.49911 .18684 L
.47315 .22926 L
.45923 .20004 L
.48439 .15046 L
s
.49911 .18684 m
.52292 .22997 L
.49566 .26705 L
.47315 .22926 L
.49911 .18684 L
s
.52292 .22997 m
.55479 .27152 L
.52578 .30598 L
.49566 .26705 L
.52292 .22997 L
s
.55479 .27152 m
.59332 .30708 L
.56221 .34133 L
.52578 .30598 L
.55479 .27152 L
s
.59332 .30708 m
.63682 .33411 L
.60334 .37027 L
.56221 .34133 L
.59332 .30708 L
s
.63682 .33411 m
.68341 .35122 L
.64738 .39122 L
.60334 .37027 L
.63682 .33411 L
s
.68341 .35122 m
.73103 .3579 L
.6924 .40361 L
.64738 .39122 L
.68341 .35122 L
s
.73103 .3579 m
.77761 .35448 L
.73644 .40773 L
.6924 .40361 L
.73103 .3579 L
s
.77761 .35448 m
.82112 .34214 L
.77757 .40467 L
.73644 .40773 L
.77761 .35448 L
s
.82112 .34214 m
.85965 .32298 L
.81399 .39625 L
.77757 .40467 L
.82112 .34214 L
s
.85965 .32298 m
.89152 .30019 L
.84412 .38499 L
.81399 .39625 L
.85965 .32298 L
s
.89152 .30019 m
.91533 .27802 L
.86663 .37381 L
.84412 .38499 L
.89152 .30019 L
s
.91533 .27802 m
.93004 .26157 L
.88054 .36561 L
.86663 .37381 L
.91533 .27802 L
s
.93004 .26157 m
.93502 .25544 L
.88525 .36259 L
.88054 .36561 L
.93004 .26157 L
s
.88525 .36259 m
.88054 .36561 L
.81429 .45574 L
.81863 .45454 L
.88525 .36259 L
s
.88054 .36561 m
.86663 .37381 L
.80145 .45886 L
.81429 .45574 L
.88054 .36561 L
s
.86663 .37381 m
.84412 .38499 L
.78068 .46267 L
.80145 .45886 L
.86663 .37381 L
s
.84412 .38499 m
.81399 .39625 L
.75289 .46541 L
.78068 .46267 L
.84412 .38499 L
s
.81399 .39625 m
.77757 .40467 L
.71928 .46518 L
.75289 .46541 L
.81399 .39625 L
s
.77757 .40467 m
.73644 .40773 L
.68133 .46024 L
.71928 .46518 L
.77757 .40467 L
s
.73644 .40773 m
.6924 .40361 L
.6407 .44924 L
.68133 .46024 L
.73644 .40773 L
s
.6924 .40361 m
.64738 .39122 L
.59916 .43143 L
.6407 .44924 L
.6924 .40361 L
s
.64738 .39122 m
.60334 .37027 L
.55852 .40671 L
.59916 .43143 L
.64738 .39122 L
s
.60334 .37027 m
.56221 .34133 L
.52057 .37579 L
.55852 .40671 L
.60334 .37027 L
s
.56221 .34133 m
.52578 .30598 L
.48697 .34037 L
.52057 .37579 L
.56221 .34133 L
s
.52578 .30598 m
.49566 .26705 L
.45917 .30331 L
.48697 .34037 L
.52578 .30598 L
s
.49566 .26705 m
.47315 .22926 L
.4384 .26912 L
.45917 .30331 L
.49566 .26705 L
s
.47315 .22926 m
.45923 .20004 L
.42556 .24403 L
.4384 .26912 L
.47315 .22926 L
s
.45923 .20004 m
.45453 .18865 L
.42122 .23463 L
.42556 .24403 L
.45923 .20004 L
s
.45453 .18865 m
.45923 .20004 L
.42556 .24403 L
.42122 .23463 L
.45453 .18865 L
s
.45923 .20004 m
.47315 .22926 L
.4384 .26912 L
.42556 .24403 L
.45923 .20004 L
s
.47315 .22926 m
.49566 .26705 L
.45917 .30331 L
.4384 .26912 L
.47315 .22926 L
s
.49566 .26705 m
.52578 .30598 L
.48697 .34037 L
.45917 .30331 L
.49566 .26705 L
s
.52578 .30598 m
.56221 .34133 L
.52057 .37579 L
.48697 .34037 L
.52578 .30598 L
s
.56221 .34133 m
.60334 .37027 L
.55852 .40671 L
.52057 .37579 L
.56221 .34133 L
s
.60334 .37027 m
.64738 .39122 L
.59916 .43143 L
.55852 .40671 L
.60334 .37027 L
s
.64738 .39122 m
.6924 .40361 L
.6407 .44924 L
.59916 .43143 L
.64738 .39122 L
s
.6924 .40361 m
.73644 .40773 L
.68133 .46024 L
.6407 .44924 L
.6924 .40361 L
s
.73644 .40773 m
.77757 .40467 L
.71928 .46518 L
.68133 .46024 L
.73644 .40773 L
s
.77757 .40467 m
.81399 .39625 L
.75289 .46541 L
.71928 .46518 L
.77757 .40467 L
s
.81399 .39625 m
.84412 .38499 L
.78068 .46267 L
.75289 .46541 L
.81399 .39625 L
s
.84412 .38499 m
.86663 .37381 L
.80145 .45886 L
.78068 .46267 L
.84412 .38499 L
s
.86663 .37381 m
.88054 .36561 L
.81429 .45574 L
.80145 .45886 L
.86663 .37381 L
s
.88054 .36561 m
.88525 .36259 L
.81863 .45454 L
.81429 .45574 L
.88054 .36561 L
s
.88525 .36259 m
.88054 .36561 L
.81429 .45574 L
.81863 .45454 L
.88525 .36259 L
s
.88054 .36561 m
.86663 .37381 L
.80145 .45886 L
.81429 .45574 L
.88054 .36561 L
s
.86663 .37381 m
.84412 .38499 L
.78068 .46267 L
.80145 .45886 L
.86663 .37381 L
s
.84412 .38499 m
.81399 .39625 L
.75289 .46541 L
.78068 .46267 L
.84412 .38499 L
s
.81399 .39625 m
.77757 .40467 L
.71928 .46518 L
.75289 .46541 L
.81399 .39625 L
s
.77757 .40467 m
.73644 .40773 L
.68133 .46024 L
.71928 .46518 L
.77757 .40467 L
s
.73644 .40773 m
.6924 .40361 L
.6407 .44924 L
.68133 .46024 L
.73644 .40773 L
s
.6924 .40361 m
.64738 .39122 L
.59916 .43143 L
.6407 .44924 L
.6924 .40361 L
s
.64738 .39122 m
.60334 .37027 L
.55852 .40671 L
.59916 .43143 L
.64738 .39122 L
s
.60334 .37027 m
.56221 .34133 L
.52057 .37579 L
.55852 .40671 L
.60334 .37027 L
s
.56221 .34133 m
.52578 .30598 L
.48697 .34037 L
.52057 .37579 L
.56221 .34133 L
s
.52578 .30598 m
.49566 .26705 L
.45917 .30331 L
.48697 .34037 L
.52578 .30598 L
s
.49566 .26705 m
.47315 .22926 L
.4384 .26912 L
.45917 .30331 L
.49566 .26705 L
s
.47315 .22926 m
.45923 .20004 L
.42556 .24403 L
.4384 .26912 L
.47315 .22926 L
s
.45923 .20004 m
.45453 .18865 L
.42122 .23463 L
.42556 .24403 L
.45923 .20004 L
s
.45453 .18865 m
.45923 .20004 L
.42556 .24403 L
.42122 .23463 L
.45453 .18865 L
s
.45923 .20004 m
.47315 .22926 L
.4384 .26912 L
.42556 .24403 L
.45923 .20004 L
s
.47315 .22926 m
.49566 .26705 L
.45917 .30331 L
.4384 .26912 L
.47315 .22926 L
s
.49566 .26705 m
.52578 .30598 L
.48697 .34037 L
.45917 .30331 L
.49566 .26705 L
s
.52578 .30598 m
.56221 .34133 L
.52057 .37579 L
.48697 .34037 L
.52578 .30598 L
s
.56221 .34133 m
.60334 .37027 L
.55852 .40671 L
.52057 .37579 L
.56221 .34133 L
s
.60334 .37027 m
.64738 .39122 L
.59916 .43143 L
.55852 .40671 L
.60334 .37027 L
s
.64738 .39122 m
.6924 .40361 L
.6407 .44924 L
.59916 .43143 L
.64738 .39122 L
s
.6924 .40361 m
.73644 .40773 L
.68133 .46024 L
.6407 .44924 L
.6924 .40361 L
s
.73644 .40773 m
.77757 .40467 L
.71928 .46518 L
.68133 .46024 L
.73644 .40773 L
s
.77757 .40467 m
.81399 .39625 L
.75289 .46541 L
.71928 .46518 L
.77757 .40467 L
s
.81399 .39625 m
.84412 .38499 L
.78068 .46267 L
.75289 .46541 L
.81399 .39625 L
s
.84412 .38499 m
.86663 .37381 L
.80145 .45886 L
.78068 .46267 L
.84412 .38499 L
s
.86663 .37381 m
.88054 .36561 L
.81429 .45574 L
.80145 .45886 L
.86663 .37381 L
s
.88054 .36561 m
.88525 .36259 L
.81863 .45454 L
.81429 .45574 L
.88054 .36561 L
s
.81863 .45454 m
.81429 .45574 L
.73419 .52725 L
.7381 .52727 L
.81863 .45454 L
s
.81429 .45574 m
.80145 .45886 L
.72266 .52691 L
.73419 .52725 L
.81429 .45574 L
s
.80145 .45886 m
.78068 .46267 L
.70399 .52551 L
.72266 .52691 L
.80145 .45886 L
s
.78068 .46267 m
.75289 .46541 L
.67901 .52198 L
.70399 .52551 L
.78068 .46267 L
s
.75289 .46541 m
.71928 .46518 L
.64881 .51511 L
.67901 .52198 L
.75289 .46541 L
s
.71928 .46518 m
.68133 .46024 L
.61471 .50379 L
.64881 .51511 L
.71928 .46518 L
s
.68133 .46024 m
.6407 .44924 L
.57819 .48717 L
.61471 .50379 L
.68133 .46024 L
s
.6407 .44924 m
.59916 .43143 L
.54086 .46484 L
.57819 .48717 L
.6407 .44924 L
s
.59916 .43143 m
.55852 .40671 L
.50434 .43698 L
.54086 .46484 L
.59916 .43143 L
s
.55852 .40671 m
.52057 .37579 L
.47024 .40443 L
.50434 .43698 L
.55852 .40671 L
s
.52057 .37579 m
.48697 .34037 L
.44004 .36894 L
.47024 .40443 L
.52057 .37579 L
s
.48697 .34037 m
.45917 .30331 L
.41506 .33332 L
.44004 .36894 L
.48697 .34037 L
s
.45917 .30331 m
.4384 .26912 L
.39639 .30167 L
.41506 .33332 L
.45917 .30331 L
s
.4384 .26912 m
.42556 .24403 L
.38485 .27921 L
.39639 .30167 L
.4384 .26912 L
s
.42556 .24403 m
.42122 .23463 L
.38095 .27099 L
.38485 .27921 L
.42556 .24403 L
s
.42122 .23463 m
.42556 .24403 L
.38485 .27921 L
.38095 .27099 L
.42122 .23463 L
s
.42556 .24403 m
.4384 .26912 L
.39639 .30167 L
.38485 .27921 L
.42556 .24403 L
s
.4384 .26912 m
.45917 .30331 L
.41506 .33332 L
.39639 .30167 L
.4384 .26912 L
s
.45917 .30331 m
.48697 .34037 L
.44004 .36894 L
.41506 .33332 L
.45917 .30331 L
s
.48697 .34037 m
.52057 .37579 L
.47024 .40443 L
.44004 .36894 L
.48697 .34037 L
s
.52057 .37579 m
.55852 .40671 L
.50434 .43698 L
.47024 .40443 L
.52057 .37579 L
s
.55852 .40671 m
.59916 .43143 L
.54086 .46484 L
.50434 .43698 L
.55852 .40671 L
s
.59916 .43143 m
.6407 .44924 L
.57819 .48717 L
.54086 .46484 L
.59916 .43143 L
s
.6407 .44924 m
.68133 .46024 L
.61471 .50379 L
.57819 .48717 L
.6407 .44924 L
s
.68133 .46024 m
.71928 .46518 L
.64881 .51511 L
.61471 .50379 L
.68133 .46024 L
s
.71928 .46518 m
.75289 .46541 L
.67901 .52198 L
.64881 .51511 L
.71928 .46518 L
s
.75289 .46541 m
.78068 .46267 L
.70399 .52551 L
.67901 .52198 L
.75289 .46541 L
s
.78068 .46267 m
.80145 .45886 L
.72266 .52691 L
.70399 .52551 L
.78068 .46267 L
s
.80145 .45886 m
.81429 .45574 L
.73419 .52725 L
.72266 .52691 L
.80145 .45886 L
s
.81429 .45574 m
.81863 .45454 L
.7381 .52727 L
.73419 .52725 L
.81429 .45574 L
s
.81863 .45454 m
.81429 .45574 L
.73419 .52725 L
.7381 .52727 L
.81863 .45454 L
s
.81429 .45574 m
.80145 .45886 L
.72266 .52691 L
.73419 .52725 L
.81429 .45574 L
s
.80145 .45886 m
.78068 .46267 L
.70399 .52551 L
.72266 .52691 L
.80145 .45886 L
s
.78068 .46267 m
.75289 .46541 L
.67901 .52198 L
.70399 .52551 L
.78068 .46267 L
s
.75289 .46541 m
.71928 .46518 L
.64881 .51511 L
.67901 .52198 L
.75289 .46541 L
s
.71928 .46518 m
.68133 .46024 L
.61471 .50379 L
.64881 .51511 L
.71928 .46518 L
s
.68133 .46024 m
.6407 .44924 L
.57819 .48717 L
.61471 .50379 L
.68133 .46024 L
s
.6407 .44924 m
.59916 .43143 L
.54086 .46484 L
.57819 .48717 L
.6407 .44924 L
s
.59916 .43143 m
.55852 .40671 L
.50434 .43698 L
.54086 .46484 L
.59916 .43143 L
s
.55852 .40671 m
.52057 .37579 L
.47024 .40443 L
.50434 .43698 L
.55852 .40671 L
s
.52057 .37579 m
.48697 .34037 L
.44004 .36894 L
.47024 .40443 L
.52057 .37579 L
s
.48697 .34037 m
.45917 .30331 L
.41506 .33332 L
.44004 .36894 L
.48697 .34037 L
s
.45917 .30331 m
.4384 .26912 L
.39639 .30167 L
.41506 .33332 L
.45917 .30331 L
s
.4384 .26912 m
.42556 .24403 L
.38485 .27921 L
.39639 .30167 L
.4384 .26912 L
s
.42556 .24403 m
.42122 .23463 L
.38095 .27099 L
.38485 .27921 L
.42556 .24403 L
s
.42122 .23463 m
.42556 .24403 L
.38485 .27921 L
.38095 .27099 L
.42122 .23463 L
s
.42556 .24403 m
.4384 .26912 L
.39639 .30167 L
.38485 .27921 L
.42556 .24403 L
s
.4384 .26912 m
.45917 .30331 L
.41506 .33332 L
.39639 .30167 L
.4384 .26912 L
s
.45917 .30331 m
.48697 .34037 L
.44004 .36894 L
.41506 .33332 L
.45917 .30331 L
s
.48697 .34037 m
.52057 .37579 L
.47024 .40443 L
.44004 .36894 L
.48697 .34037 L
s
.52057 .37579 m
.55852 .40671 L
.50434 .43698 L
.47024 .40443 L
.52057 .37579 L
s
.55852 .40671 m
.59916 .43143 L
.54086 .46484 L
.50434 .43698 L
.55852 .40671 L
s
.59916 .43143 m
.6407 .44924 L
.57819 .48717 L
.54086 .46484 L
.59916 .43143 L
s
.6407 .44924 m
.68133 .46024 L
.61471 .50379 L
.57819 .48717 L
.6407 .44924 L
s
.68133 .46024 m
.71928 .46518 L
.64881 .51511 L
.61471 .50379 L
.68133 .46024 L
s
.71928 .46518 m
.75289 .46541 L
.67901 .52198 L
.64881 .51511 L
.71928 .46518 L
s
.75289 .46541 m
.78068 .46267 L
.70399 .52551 L
.67901 .52198 L
.75289 .46541 L
s
.78068 .46267 m
.80145 .45886 L
.72266 .52691 L
.70399 .52551 L
.78068 .46267 L
s
.80145 .45886 m
.81429 .45574 L
.73419 .52725 L
.72266 .52691 L
.80145 .45886 L
s
.81429 .45574 m
.81863 .45454 L
.7381 .52727 L
.73419 .52725 L
.81429 .45574 L
s
.7381 .52727 m
.73419 .52725 L
.64375 .57673 L
.64715 .57759 L
.7381 .52727 L
s
.73419 .52725 m
.72266 .52691 L
.63368 .57397 L
.64375 .57673 L
.73419 .52725 L
s
.72266 .52691 m
.70399 .52551 L
.61739 .56888 L
.63368 .57397 L
.72266 .52691 L
s
.70399 .52551 m
.67901 .52198 L
.59559 .56083 L
.61739 .56888 L
.70399 .52551 L
s
.67901 .52198 m
.64881 .51511 L
.56923 .54909 L
.59559 .56083 L
.67901 .52198 L
s
.64881 .51511 m
.61471 .50379 L
.53947 .53305 L
.56923 .54909 L
.64881 .51511 L
s
.61471 .50379 m
.57819 .48717 L
.5076 .51225 L
.53947 .53305 L
.61471 .50379 L
s
.57819 .48717 m
.54086 .46484 L
.47503 .48663 L
.5076 .51225 L
.57819 .48717 L
s
.54086 .46484 m
.50434 .43698 L
.44316 .45657 L
.47503 .48663 L
.54086 .46484 L
s
.50434 .43698 m
.47024 .40443 L
.4134 .42306 L
.44316 .45657 L
.50434 .43698 L
s
.47024 .40443 m
.44004 .36894 L
.38704 .38786 L
.4134 .42306 L
.47024 .40443 L
s
.44004 .36894 m
.41506 .33332 L
.36524 .35363 L
.38704 .38786 L
.44004 .36894 L
s
.41506 .33332 m
.39639 .30167 L
.34895 .32405 L
.36524 .35363 L
.41506 .33332 L
s
.39639 .30167 m
.38485 .27921 L
.33889 .30355 L
.34895 .32405 L
.39639 .30167 L
s
.38485 .27921 m
.38095 .27099 L
.33548 .29615 L
.33889 .30355 L
.38485 .27921 L
s
.38095 .27099 m
.38485 .27921 L
.33889 .30355 L
.33548 .29615 L
.38095 .27099 L
s
.38485 .27921 m
.39639 .30167 L
.34895 .32405 L
.33889 .30355 L
.38485 .27921 L
s
.39639 .30167 m
.41506 .33332 L
.36524 .35363 L
.34895 .32405 L
.39639 .30167 L
s
.41506 .33332 m
.44004 .36894 L
.38704 .38786 L
.36524 .35363 L
.41506 .33332 L
s
.44004 .36894 m
.47024 .40443 L
.4134 .42306 L
.38704 .38786 L
.44004 .36894 L
s
.47024 .40443 m
.50434 .43698 L
.44316 .45657 L
.4134 .42306 L
.47024 .40443 L
s
.50434 .43698 m
.54086 .46484 L
.47503 .48663 L
.44316 .45657 L
.50434 .43698 L
s
.54086 .46484 m
.57819 .48717 L
.5076 .51225 L
.47503 .48663 L
.54086 .46484 L
s
.57819 .48717 m
.61471 .50379 L
.53947 .53305 L
.5076 .51225 L
.57819 .48717 L
s
.61471 .50379 m
.64881 .51511 L
.56923 .54909 L
.53947 .53305 L
.61471 .50379 L
s
.64881 .51511 m
.67901 .52198 L
.59559 .56083 L
.56923 .54909 L
.64881 .51511 L
s
.67901 .52198 m
.70399 .52551 L
.61739 .56888 L
.59559 .56083 L
.67901 .52198 L
s
.70399 .52551 m
.72266 .52691 L
.63368 .57397 L
.61739 .56888 L
.70399 .52551 L
s
.72266 .52691 m
.73419 .52725 L
.64375 .57673 L
.63368 .57397 L
.72266 .52691 L
s
.73419 .52725 m
.7381 .52727 L
.64715 .57759 L
.64375 .57673 L
.73419 .52725 L
s
.7381 .52727 m
.73419 .52725 L
.64375 .57673 L
.64715 .57759 L
.7381 .52727 L
s
.73419 .52725 m
.72266 .52691 L
.63368 .57397 L
.64375 .57673 L
.73419 .52725 L
s
.72266 .52691 m
.70399 .52551 L
.61739 .56888 L
.63368 .57397 L
.72266 .52691 L
s
.70399 .52551 m
.67901 .52198 L
.59559 .56083 L
.61739 .56888 L
.70399 .52551 L
s
.67901 .52198 m
.64881 .51511 L
.56923 .54909 L
.59559 .56083 L
.67901 .52198 L
s
.64881 .51511 m
.61471 .50379 L
.53947 .53305 L
.56923 .54909 L
.64881 .51511 L
s
.61471 .50379 m
.57819 .48717 L
.5076 .51225 L
.53947 .53305 L
.61471 .50379 L
s
.57819 .48717 m
.54086 .46484 L
.47503 .48663 L
.5076 .51225 L
.57819 .48717 L
s
.54086 .46484 m
.50434 .43698 L
.44316 .45657 L
.47503 .48663 L
.54086 .46484 L
s
.50434 .43698 m
.47024 .40443 L
.4134 .42306 L
.44316 .45657 L
.50434 .43698 L
s
.47024 .40443 m
.44004 .36894 L
.38704 .38786 L
.4134 .42306 L
.47024 .40443 L
s
.44004 .36894 m
.41506 .33332 L
.36524 .35363 L
.38704 .38786 L
.44004 .36894 L
s
.41506 .33332 m
.39639 .30167 L
.34895 .32405 L
.36524 .35363 L
.41506 .33332 L
s
.39639 .30167 m
.38485 .27921 L
.33889 .30355 L
.34895 .32405 L
.39639 .30167 L
s
.38485 .27921 m
.38095 .27099 L
.33548 .29615 L
.33889 .30355 L
.38485 .27921 L
s
.38095 .27099 m
.38485 .27921 L
.33889 .30355 L
.33548 .29615 L
.38095 .27099 L
s
.38485 .27921 m
.39639 .30167 L
.34895 .32405 L
.33889 .30355 L
.38485 .27921 L
s
.39639 .30167 m
.41506 .33332 L
.36524 .35363 L
.34895 .32405 L
.39639 .30167 L
s
.41506 .33332 m
.44004 .36894 L
.38704 .38786 L
.36524 .35363 L
.41506 .33332 L
s
.44004 .36894 m
.47024 .40443 L
.4134 .42306 L
.38704 .38786 L
.44004 .36894 L
s
.47024 .40443 m
.50434 .43698 L
.44316 .45657 L
.4134 .42306 L
.47024 .40443 L
s
.50434 .43698 m
.54086 .46484 L
.47503 .48663 L
.44316 .45657 L
.50434 .43698 L
s
.54086 .46484 m
.57819 .48717 L
.5076 .51225 L
.47503 .48663 L
.54086 .46484 L
s
.57819 .48717 m
.61471 .50379 L
.53947 .53305 L
.5076 .51225 L
.57819 .48717 L
s
.61471 .50379 m
.64881 .51511 L
.56923 .54909 L
.53947 .53305 L
.61471 .50379 L
s
.64881 .51511 m
.67901 .52198 L
.59559 .56083 L
.56923 .54909 L
.64881 .51511 L
s
.67901 .52198 m
.70399 .52551 L
.61739 .56888 L
.59559 .56083 L
.67901 .52198 L
s
.70399 .52551 m
.72266 .52691 L
.63368 .57397 L
.61739 .56888 L
.70399 .52551 L
s
.72266 .52691 m
.73419 .52725 L
.64375 .57673 L
.63368 .57397 L
.72266 .52691 L
s
.73419 .52725 m
.7381 .52727 L
.64715 .57759 L
.64375 .57673 L
.73419 .52725 L
s
.64715 .57759 m
.64375 .57673 L
.5469 .60189 L
.54978 .60332 L
.64715 .57759 L
s
.64375 .57673 m
.63368 .57397 L
.53841 .5975 L
.5469 .60189 L
.64375 .57673 L
s
.63368 .57397 m
.61739 .56888 L
.52466 .58993 L
.53841 .5975 L
.63368 .57397 L
s
.61739 .56888 m
.59559 .56083 L
.50627 .57882 L
.52466 .58993 L
.61739 .56888 L
s
.59559 .56083 m
.56923 .54909 L
.48403 .56383 L
.50627 .57882 L
.59559 .56083 L
s
.56923 .54909 m
.53947 .53305 L
.45892 .54466 L
.48403 .56383 L
.56923 .54909 L
s
.53947 .53305 m
.5076 .51225 L
.43203 .5212 L
.45892 .54466 L
.53947 .53305 L
s
.5076 .51225 m
.47503 .48663 L
.40454 .49364 L
.43203 .5212 L
.5076 .51225 L
s
.47503 .48663 m
.44316 .45657 L
.37765 .46254 L
.40454 .49364 L
.47503 .48663 L
s
.44316 .45657 m
.4134 .42306 L
.35254 .42897 L
.37765 .46254 L
.44316 .45657 L
s
.4134 .42306 m
.38704 .38786 L
.3303 .39465 L
.35254 .42897 L
.4134 .42306 L
s
.38704 .38786 m
.36524 .35363 L
.31191 .36207 L
.3303 .39465 L
.38704 .38786 L
s
.36524 .35363 m
.34895 .32405 L
.29816 .3345 L
.31191 .36207 L
.36524 .35363 L
s
.34895 .32405 m
.33889 .30355 L
.28967 .31573 L
.29816 .3345 L
.34895 .32405 L
s
.33889 .30355 m
.33548 .29615 L
.28679 .30902 L
.28967 .31573 L
.33889 .30355 L
s
.33548 .29615 m
.33889 .30355 L
.28967 .31573 L
.28679 .30902 L
.33548 .29615 L
s
.33889 .30355 m
.34895 .32405 L
.29816 .3345 L
.28967 .31573 L
.33889 .30355 L
s
.34895 .32405 m
.36524 .35363 L
.31191 .36207 L
.29816 .3345 L
.34895 .32405 L
s
.36524 .35363 m
.38704 .38786 L
.3303 .39465 L
.31191 .36207 L
.36524 .35363 L
s
.38704 .38786 m
.4134 .42306 L
.35254 .42897 L
.3303 .39465 L
.38704 .38786 L
s
.4134 .42306 m
.44316 .45657 L
.37765 .46254 L
.35254 .42897 L
.4134 .42306 L
s
.44316 .45657 m
.47503 .48663 L
.40454 .49364 L
.37765 .46254 L
.44316 .45657 L
s
.47503 .48663 m
.5076 .51225 L
.43203 .5212 L
.40454 .49364 L
.47503 .48663 L
s
.5076 .51225 m
.53947 .53305 L
.45892 .54466 L
.43203 .5212 L
.5076 .51225 L
s
.53947 .53305 m
.56923 .54909 L
.48403 .56383 L
.45892 .54466 L
.53947 .53305 L
s
.56923 .54909 m
.59559 .56083 L
.50627 .57882 L
.48403 .56383 L
.56923 .54909 L
s
.59559 .56083 m
.61739 .56888 L
.52466 .58993 L
.50627 .57882 L
.59559 .56083 L
s
.61739 .56888 m
.63368 .57397 L
.53841 .5975 L
.52466 .58993 L
.61739 .56888 L
s
.63368 .57397 m
.64375 .57673 L
.5469 .60189 L
.53841 .5975 L
.63368 .57397 L
s
.64375 .57673 m
.64715 .57759 L
.54978 .60332 L
.5469 .60189 L
.64375 .57673 L
s
.64715 .57759 m
.64375 .57673 L
.5469 .60189 L
.54978 .60332 L
.64715 .57759 L
s
.64375 .57673 m
.63368 .57397 L
.53841 .5975 L
.5469 .60189 L
.64375 .57673 L
s
.63368 .57397 m
.61739 .56888 L
.52466 .58993 L
.53841 .5975 L
.63368 .57397 L
s
.61739 .56888 m
.59559 .56083 L
.50627 .57882 L
.52466 .58993 L
.61739 .56888 L
s
.59559 .56083 m
.56923 .54909 L
.48403 .56383 L
.50627 .57882 L
.59559 .56083 L
s
.56923 .54909 m
.53947 .53305 L
.45892 .54466 L
.48403 .56383 L
.56923 .54909 L
s
.53947 .53305 m
.5076 .51225 L
.43203 .5212 L
.45892 .54466 L
.53947 .53305 L
s
.5076 .51225 m
.47503 .48663 L
.40454 .49364 L
.43203 .5212 L
.5076 .51225 L
s
.47503 .48663 m
.44316 .45657 L
.37765 .46254 L
.40454 .49364 L
.47503 .48663 L
s
.44316 .45657 m
.4134 .42306 L
.35254 .42897 L
.37765 .46254 L
.44316 .45657 L
s
.4134 .42306 m
.38704 .38786 L
.3303 .39465 L
.35254 .42897 L
.4134 .42306 L
s
.38704 .38786 m
.36524 .35363 L
.31191 .36207 L
.3303 .39465 L
.38704 .38786 L
s
.36524 .35363 m
.34895 .32405 L
.29816 .3345 L
.31191 .36207 L
.36524 .35363 L
s
.34895 .32405 m
.33889 .30355 L
.28967 .31573 L
.29816 .3345 L
.34895 .32405 L
s
.33889 .30355 m
.33548 .29615 L
.28679 .30902 L
.28967 .31573 L
.33889 .30355 L
s
.33548 .29615 m
.33889 .30355 L
.28967 .31573 L
.28679 .30902 L
.33548 .29615 L
s
.33889 .30355 m
.34895 .32405 L
.29816 .3345 L
.28967 .31573 L
.33889 .30355 L
s
.34895 .32405 m
.36524 .35363 L
.31191 .36207 L
.29816 .3345 L
.34895 .32405 L
s
.36524 .35363 m
.38704 .38786 L
.3303 .39465 L
.31191 .36207 L
.36524 .35363 L
s
.38704 .38786 m
.4134 .42306 L
.35254 .42897 L
.3303 .39465 L
.38704 .38786 L
s
.4134 .42306 m
.44316 .45657 L
.37765 .46254 L
.35254 .42897 L
.4134 .42306 L
s
.44316 .45657 m
.47503 .48663 L
.40454 .49364 L
.37765 .46254 L
.44316 .45657 L
s
.47503 .48663 m
.5076 .51225 L
.43203 .5212 L
.40454 .49364 L
.47503 .48663 L
s
.5076 .51225 m
.53947 .53305 L
.45892 .54466 L
.43203 .5212 L
.5076 .51225 L
s
.53947 .53305 m
.56923 .54909 L
.48403 .56383 L
.45892 .54466 L
.53947 .53305 L
s
.56923 .54909 m
.59559 .56083 L
.50627 .57882 L
.48403 .56383 L
.56923 .54909 L
s
.59559 .56083 m
.61739 .56888 L
.52466 .58993 L
.50627 .57882 L
.59559 .56083 L
s
.61739 .56888 m
.63368 .57397 L
.53841 .5975 L
.52466 .58993 L
.61739 .56888 L
s
.63368 .57397 m
.64375 .57673 L
.5469 .60189 L
.53841 .5975 L
.63368 .57397 L
s
.64375 .57673 m
.64715 .57759 L
.54978 .60332 L
.5469 .60189 L
.64375 .57673 L
s
.54978 .60332 m
.5469 .60189 L
.44789 .60155 L
.45022 .60332 L
.54978 .60332 L
s
.5469 .60189 m
.53841 .5975 L
.44101 .5962 L
.44789 .60155 L
.5469 .60189 L
s
.53841 .5975 m
.52466 .58993 L
.42987 .58717 L
.44101 .5962 L
.53841 .5975 L
s
.52466 .58993 m
.50627 .57882 L
.41495 .57432 L
.42987 .58717 L
.52466 .58993 L
s
.50627 .57882 m
.48403 .56383 L
.39692 .55754 L
.41495 .57432 L
.50627 .57882 L
s
.48403 .56383 m
.45892 .54466 L
.37656 .53679 L
.39692 .55754 L
.48403 .56383 L
s
.45892 .54466 m
.43203 .5212 L
.35476 .51219 L
.37656 .53679 L
.45892 .54466 L
s
.43203 .5212 m
.40454 .49364 L
.33248 .48409 L
.35476 .51219 L
.43203 .5212 L
s
.40454 .49364 m
.37765 .46254 L
.31068 .4532 L
.33248 .48409 L
.40454 .49364 L
s
.37765 .46254 m
.35254 .42897 L
.29032 .4206 L
.31068 .4532 L
.37765 .46254 L
s
.35254 .42897 m
.3303 .39465 L
.27229 .38794 L
.29032 .4206 L
.35254 .42897 L
s
.3303 .39465 m
.31191 .36207 L
.25738 .35749 L
.27229 .38794 L
.3303 .39465 L
s
.31191 .36207 m
.29816 .3345 L
.24623 .33213 L
.25738 .35749 L
.31191 .36207 L
s
.29816 .3345 m
.28967 .31573 L
.23935 .31507 L
.24623 .33213 L
.29816 .3345 L
s
.28967 .31573 m
.28679 .30902 L
.23702 .30902 L
.23935 .31507 L
.28967 .31573 L
s
.28679 .30902 m
.28967 .31573 L
.23935 .31507 L
.23702 .30902 L
.28679 .30902 L
s
.28967 .31573 m
.29816 .3345 L
.24623 .33213 L
.23935 .31507 L
.28967 .31573 L
s
.29816 .3345 m
.31191 .36207 L
.25738 .35749 L
.24623 .33213 L
.29816 .3345 L
s
.31191 .36207 m
.3303 .39465 L
.27229 .38794 L
.25738 .35749 L
.31191 .36207 L
s
.3303 .39465 m
.35254 .42897 L
.29032 .4206 L
.27229 .38794 L
.3303 .39465 L
s
.35254 .42897 m
.37765 .46254 L
.31068 .4532 L
.29032 .4206 L
.35254 .42897 L
s
.37765 .46254 m
.40454 .49364 L
.33248 .48409 L
.31068 .4532 L
.37765 .46254 L
s
.40454 .49364 m
.43203 .5212 L
.35476 .51219 L
.33248 .48409 L
.40454 .49364 L
s
.43203 .5212 m
.45892 .54466 L
.37656 .53679 L
.35476 .51219 L
.43203 .5212 L
s
.45892 .54466 m
.48403 .56383 L
.39692 .55754 L
.37656 .53679 L
.45892 .54466 L
s
.48403 .56383 m
.50627 .57882 L
.41495 .57432 L
.39692 .55754 L
.48403 .56383 L
s
.50627 .57882 m
.52466 .58993 L
.42987 .58717 L
.41495 .57432 L
.50627 .57882 L
s
.52466 .58993 m
.53841 .5975 L
.44101 .5962 L
.42987 .58717 L
.52466 .58993 L
s
.53841 .5975 m
.5469 .60189 L
.44789 .60155 L
.44101 .5962 L
.53841 .5975 L
s
.5469 .60189 m
.54978 .60332 L
.45022 .60332 L
.44789 .60155 L
.5469 .60189 L
s
.54978 .60332 m
.5469 .60189 L
.44789 .60155 L
.45022 .60332 L
.54978 .60332 L
s
.5469 .60189 m
.53841 .5975 L
.44101 .5962 L
.44789 .60155 L
.5469 .60189 L
s
.53841 .5975 m
.52466 .58993 L
.42987 .58717 L
.44101 .5962 L
.53841 .5975 L
s
.52466 .58993 m
.50627 .57882 L
.41495 .57432 L
.42987 .58717 L
.52466 .58993 L
s
.50627 .57882 m
.48403 .56383 L
.39692 .55754 L
.41495 .57432 L
.50627 .57882 L
s
.48403 .56383 m
.45892 .54466 L
.37656 .53679 L
.39692 .55754 L
.48403 .56383 L
s
.45892 .54466 m
.43203 .5212 L
.35476 .51219 L
.37656 .53679 L
.45892 .54466 L
s
.43203 .5212 m
.40454 .49364 L
.33248 .48409 L
.35476 .51219 L
.43203 .5212 L
s
.40454 .49364 m
.37765 .46254 L
.31068 .4532 L
.33248 .48409 L
.40454 .49364 L
s
.37765 .46254 m
.35254 .42897 L
.29032 .4206 L
.31068 .4532 L
.37765 .46254 L
s
.35254 .42897 m
.3303 .39465 L
.27229 .38794 L
.29032 .4206 L
.35254 .42897 L
s
.3303 .39465 m
.31191 .36207 L
.25738 .35749 L
.27229 .38794 L
.3303 .39465 L
s
.31191 .36207 m
.29816 .3345 L
.24623 .33213 L
.25738 .35749 L
.31191 .36207 L
s
.29816 .3345 m
.28967 .31573 L
.23935 .31507 L
.24623 .33213 L
.29816 .3345 L
s
.28967 .31573 m
.28679 .30902 L
.23702 .30902 L
.23935 .31507 L
.28967 .31573 L
s
.28679 .30902 m
.28967 .31573 L
.23935 .31507 L
.23702 .30902 L
.28679 .30902 L
s
.28967 .31573 m
.29816 .3345 L
.24623 .33213 L
.23935 .31507 L
.28967 .31573 L
s
.29816 .3345 m
.31191 .36207 L
.25738 .35749 L
.24623 .33213 L
.29816 .3345 L
s
.31191 .36207 m
.3303 .39465 L
.27229 .38794 L
.25738 .35749 L
.31191 .36207 L
s
.3303 .39465 m
.35254 .42897 L
.29032 .4206 L
.27229 .38794 L
.3303 .39465 L
s
.35254 .42897 m
.37765 .46254 L
.31068 .4532 L
.29032 .4206 L
.35254 .42897 L
s
.37765 .46254 m
.40454 .49364 L
.33248 .48409 L
.31068 .4532 L
.37765 .46254 L
s
.40454 .49364 m
.43203 .5212 L
.35476 .51219 L
.33248 .48409 L
.40454 .49364 L
s
.43203 .5212 m
.45892 .54466 L
.37656 .53679 L
.35476 .51219 L
.43203 .5212 L
s
.45892 .54466 m
.48403 .56383 L
.39692 .55754 L
.37656 .53679 L
.45892 .54466 L
s
.48403 .56383 m
.50627 .57882 L
.41495 .57432 L
.39692 .55754 L
.48403 .56383 L
s
.50627 .57882 m
.52466 .58993 L
.42987 .58717 L
.41495 .57432 L
.50627 .57882 L
s
.52466 .58993 m
.53841 .5975 L
.44101 .5962 L
.42987 .58717 L
.52466 .58993 L
s
.53841 .5975 m
.5469 .60189 L
.44789 .60155 L
.44101 .5962 L
.53841 .5975 L
s
.5469 .60189 m
.54978 .60332 L
.45022 .60332 L
.44789 .60155 L
.5469 .60189 L
s
.45022 .60332 m
.44789 .60155 L
.35105 .57569 L
.35285 .57759 L
.45022 .60332 L
s
.44789 .60155 m
.44101 .5962 L
.34574 .56995 L
.35105 .57569 L
.44789 .60155 L
s
.44101 .5962 m
.42987 .58717 L
.33714 .56038 L
.34574 .56995 L
.44101 .5962 L
s
.42987 .58717 m
.41495 .57432 L
.32563 .54697 L
.33714 .56038 L
.42987 .58717 L
s
.41495 .57432 m
.39692 .55754 L
.31172 .52976 L
.32563 .54697 L
.41495 .57432 L
s
.39692 .55754 m
.37656 .53679 L
.29601 .50887 L
.31172 .52976 L
.39692 .55754 L
s
.37656 .53679 m
.35476 .51219 L
.27919 .48459 L
.29601 .50887 L
.37656 .53679 L
s
.35476 .51219 m
.33248 .48409 L
.26199 .45737 L
.27919 .48459 L
.35476 .51219 L
s
.33248 .48409 m
.31068 .4532 L
.24517 .42795 L
.26199 .45737 L
.33248 .48409 L
s
.31068 .4532 m
.29032 .4206 L
.22946 .39741 L
.24517 .42795 L
.31068 .4532 L
s
.29032 .4206 m
.27229 .38794 L
.21555 .36727 L
.22946 .39741 L
.29032 .4206 L
s
.27229 .38794 m
.25738 .35749 L
.20404 .33954 L
.21555 .36727 L
.27229 .38794 L
s
.25738 .35749 m
.24623 .33213 L
.19544 .31672 L
.20404 .33954 L
.25738 .35749 L
s
.24623 .33213 m
.23935 .31507 L
.19013 .30152 L
.19544 .31672 L
.24623 .33213 L
s
.23935 .31507 m
.23702 .30902 L
.18833 .29615 L
.19013 .30152 L
.23935 .31507 L
s
.23702 .30902 m
.23935 .31507 L
.19013 .30152 L
.18833 .29615 L
.23702 .30902 L
s
.23935 .31507 m
.24623 .33213 L
.19544 .31672 L
.19013 .30152 L
.23935 .31507 L
s
.24623 .33213 m
.25738 .35749 L
.20404 .33954 L
.19544 .31672 L
.24623 .33213 L
s
.25738 .35749 m
.27229 .38794 L
.21555 .36727 L
.20404 .33954 L
.25738 .35749 L
s
.27229 .38794 m
.29032 .4206 L
.22946 .39741 L
.21555 .36727 L
.27229 .38794 L
s
.29032 .4206 m
.31068 .4532 L
.24517 .42795 L
.22946 .39741 L
.29032 .4206 L
s
.31068 .4532 m
.33248 .48409 L
.26199 .45737 L
.24517 .42795 L
.31068 .4532 L
s
.33248 .48409 m
.35476 .51219 L
.27919 .48459 L
.26199 .45737 L
.33248 .48409 L
s
.35476 .51219 m
.37656 .53679 L
.29601 .50887 L
.27919 .48459 L
.35476 .51219 L
s
.37656 .53679 m
.39692 .55754 L
.31172 .52976 L
.29601 .50887 L
.37656 .53679 L
s
.39692 .55754 m
.41495 .57432 L
.32563 .54697 L
.31172 .52976 L
.39692 .55754 L
s
.41495 .57432 m
.42987 .58717 L
.33714 .56038 L
.32563 .54697 L
.41495 .57432 L
s
.42987 .58717 m
.44101 .5962 L
.34574 .56995 L
.33714 .56038 L
.42987 .58717 L
s
.44101 .5962 m
.44789 .60155 L
.35105 .57569 L
.34574 .56995 L
.44101 .5962 L
s
.44789 .60155 m
.45022 .60332 L
.35285 .57759 L
.35105 .57569 L
.44789 .60155 L
s
.45022 .60332 m
.44789 .60155 L
.35105 .57569 L
.35285 .57759 L
.45022 .60332 L
s
.44789 .60155 m
.44101 .5962 L
.34574 .56995 L
.35105 .57569 L
.44789 .60155 L
s
.44101 .5962 m
.42987 .58717 L
.33714 .56038 L
.34574 .56995 L
.44101 .5962 L
s
.42987 .58717 m
.41495 .57432 L
.32563 .54697 L
.33714 .56038 L
.42987 .58717 L
s
.41495 .57432 m
.39692 .55754 L
.31172 .52976 L
.32563 .54697 L
.41495 .57432 L
s
.39692 .55754 m
.37656 .53679 L
.29601 .50887 L
.31172 .52976 L
.39692 .55754 L
s
.37656 .53679 m
.35476 .51219 L
.27919 .48459 L
.29601 .50887 L
.37656 .53679 L
s
.35476 .51219 m
.33248 .48409 L
.26199 .45737 L
.27919 .48459 L
.35476 .51219 L
s
.33248 .48409 m
.31068 .4532 L
.24517 .42795 L
.26199 .45737 L
.33248 .48409 L
s
.31068 .4532 m
.29032 .4206 L
.22946 .39741 L
.24517 .42795 L
.31068 .4532 L
s
.29032 .4206 m
.27229 .38794 L
.21555 .36727 L
.22946 .39741 L
.29032 .4206 L
s
.27229 .38794 m
.25738 .35749 L
.20404 .33954 L
.21555 .36727 L
.27229 .38794 L
s
.25738 .35749 m
.24623 .33213 L
.19544 .31672 L
.20404 .33954 L
.25738 .35749 L
s
.24623 .33213 m
.23935 .31507 L
.19013 .30152 L
.19544 .31672 L
.24623 .33213 L
s
.23935 .31507 m
.23702 .30902 L
.18833 .29615 L
.19013 .30152 L
.23935 .31507 L
s
.23702 .30902 m
.23935 .31507 L
.19013 .30152 L
.18833 .29615 L
.23702 .30902 L
s
.23935 .31507 m
.24623 .33213 L
.19544 .31672 L
.19013 .30152 L
.23935 .31507 L
s
.24623 .33213 m
.25738 .35749 L
.20404 .33954 L
.19544 .31672 L
.24623 .33213 L
s
.25738 .35749 m
.27229 .38794 L
.21555 .36727 L
.20404 .33954 L
.25738 .35749 L
s
.27229 .38794 m
.29032 .4206 L
.22946 .39741 L
.21555 .36727 L
.27229 .38794 L
s
.29032 .4206 m
.31068 .4532 L
.24517 .42795 L
.22946 .39741 L
.29032 .4206 L
s
.31068 .4532 m
.33248 .48409 L
.26199 .45737 L
.24517 .42795 L
.31068 .4532 L
s
.33248 .48409 m
.35476 .51219 L
.27919 .48459 L
.26199 .45737 L
.33248 .48409 L
s
.35476 .51219 m
.37656 .53679 L
.29601 .50887 L
.27919 .48459 L
.35476 .51219 L
s
.37656 .53679 m
.39692 .55754 L
.31172 .52976 L
.29601 .50887 L
.37656 .53679 L
s
.39692 .55754 m
.41495 .57432 L
.32563 .54697 L
.31172 .52976 L
.39692 .55754 L
s
.41495 .57432 m
.42987 .58717 L
.33714 .56038 L
.32563 .54697 L
.41495 .57432 L
s
.42987 .58717 m
.44101 .5962 L
.34574 .56995 L
.33714 .56038 L
.42987 .58717 L
s
.44101 .5962 m
.44789 .60155 L
.35105 .57569 L
.34574 .56995 L
.44101 .5962 L
s
.44789 .60155 m
.45022 .60332 L
.35285 .57759 L
.35105 .57569 L
.44789 .60155 L
s
.35285 .57759 m
.35105 .57569 L
.2606 .5254 L
.2619 .52727 L
.35285 .57759 L
s
.35105 .57569 m
.34574 .56995 L
.25676 .51979 L
.2606 .5254 L
.35105 .57569 L
s
.34574 .56995 m
.33714 .56038 L
.25054 .51048 L
.25676 .51979 L
.34574 .56995 L
s
.33714 .56038 m
.32563 .54697 L
.24221 .49756 L
.25054 .51048 L
.33714 .56038 L
s
.32563 .54697 m
.31172 .52976 L
.23214 .48115 L
.24221 .49756 L
.32563 .54697 L
s
.31172 .52976 m
.29601 .50887 L
.22077 .46147 L
.23214 .48115 L
.31172 .52976 L
s
.29601 .50887 m
.27919 .48459 L
.2086 .43887 L
.22077 .46147 L
.29601 .50887 L
s
.27919 .48459 m
.26199 .45737 L
.19616 .41385 L
.2086 .43887 L
.27919 .48459 L
s
.26199 .45737 m
.24517 .42795 L
.18399 .38714 L
.19616 .41385 L
.26199 .45737 L
s
.24517 .42795 m
.22946 .39741 L
.17262 .35974 L
.18399 .38714 L
.24517 .42795 L
s
.22946 .39741 m
.21555 .36727 L
.16255 .33299 L
.17262 .35974 L
.22946 .39741 L
s
.21555 .36727 m
.20404 .33954 L
.15423 .30863 L
.16255 .33299 L
.21555 .36727 L
s
.20404 .33954 m
.19544 .31672 L
.148 .28876 L
.15423 .30863 L
.20404 .33954 L
s
.19544 .31672 m
.19013 .30152 L
.14416 .27561 L
.148 .28876 L
.19544 .31672 L
s
.19013 .30152 m
.18833 .29615 L
.14286 .27099 L
.14416 .27561 L
.19013 .30152 L
s
.18833 .29615 m
.19013 .30152 L
.14416 .27561 L
.14286 .27099 L
.18833 .29615 L
s
.19013 .30152 m
.19544 .31672 L
.148 .28876 L
.14416 .27561 L
.19013 .30152 L
s
.19544 .31672 m
.20404 .33954 L
.15423 .30863 L
.148 .28876 L
.19544 .31672 L
s
.20404 .33954 m
.21555 .36727 L
.16255 .33299 L
.15423 .30863 L
.20404 .33954 L
s
.21555 .36727 m
.22946 .39741 L
.17262 .35974 L
.16255 .33299 L
.21555 .36727 L
s
.22946 .39741 m
.24517 .42795 L
.18399 .38714 L
.17262 .35974 L
.22946 .39741 L
s
.24517 .42795 m
.26199 .45737 L
.19616 .41385 L
.18399 .38714 L
.24517 .42795 L
s
.26199 .45737 m
.27919 .48459 L
.2086 .43887 L
.19616 .41385 L
.26199 .45737 L
s
.27919 .48459 m
.29601 .50887 L
.22077 .46147 L
.2086 .43887 L
.27919 .48459 L
s
.29601 .50887 m
.31172 .52976 L
.23214 .48115 L
.22077 .46147 L
.29601 .50887 L
s
.31172 .52976 m
.32563 .54697 L
.24221 .49756 L
.23214 .48115 L
.31172 .52976 L
s
.32563 .54697 m
.33714 .56038 L
.25054 .51048 L
.24221 .49756 L
.32563 .54697 L
s
.33714 .56038 m
.34574 .56995 L
.25676 .51979 L
.25054 .51048 L
.33714 .56038 L
s
.34574 .56995 m
.35105 .57569 L
.2606 .5254 L
.25676 .51979 L
.34574 .56995 L
s
.35105 .57569 m
.35285 .57759 L
.2619 .52727 L
.2606 .5254 L
.35105 .57569 L
s
.35285 .57759 m
.35105 .57569 L
.2606 .5254 L
.2619 .52727 L
.35285 .57759 L
s
.35105 .57569 m
.34574 .56995 L
.25676 .51979 L
.2606 .5254 L
.35105 .57569 L
s
.34574 .56995 m
.33714 .56038 L
.25054 .51048 L
.25676 .51979 L
.34574 .56995 L
s
.33714 .56038 m
.32563 .54697 L
.24221 .49756 L
.25054 .51048 L
.33714 .56038 L
s
.32563 .54697 m
.31172 .52976 L
.23214 .48115 L
.24221 .49756 L
.32563 .54697 L
s
.31172 .52976 m
.29601 .50887 L
.22077 .46147 L
.23214 .48115 L
.31172 .52976 L
s
.29601 .50887 m
.27919 .48459 L
.2086 .43887 L
.22077 .46147 L
.29601 .50887 L
s
.27919 .48459 m
.26199 .45737 L
.19616 .41385 L
.2086 .43887 L
.27919 .48459 L
s
.26199 .45737 m
.24517 .42795 L
.18399 .38714 L
.19616 .41385 L
.26199 .45737 L
s
.24517 .42795 m
.22946 .39741 L
.17262 .35974 L
.18399 .38714 L
.24517 .42795 L
s
.22946 .39741 m
.21555 .36727 L
.16255 .33299 L
.17262 .35974 L
.22946 .39741 L
s
.21555 .36727 m
.20404 .33954 L
.15423 .30863 L
.16255 .33299 L
.21555 .36727 L
s
.20404 .33954 m
.19544 .31672 L
.148 .28876 L
.15423 .30863 L
.20404 .33954 L
s
.19544 .31672 m
.19013 .30152 L
.14416 .27561 L
.148 .28876 L
.19544 .31672 L
s
.19013 .30152 m
.18833 .29615 L
.14286 .27099 L
.14416 .27561 L
.19013 .30152 L
s
.18833 .29615 m
.19013 .30152 L
.14416 .27561 L
.14286 .27099 L
.18833 .29615 L
s
.19013 .30152 m
.19544 .31672 L
.148 .28876 L
.14416 .27561 L
.19013 .30152 L
s
.19544 .31672 m
.20404 .33954 L
.15423 .30863 L
.148 .28876 L
.19544 .31672 L
s
.20404 .33954 m
.21555 .36727 L
.16255 .33299 L
.15423 .30863 L
.20404 .33954 L
s
.21555 .36727 m
.22946 .39741 L
.17262 .35974 L
.16255 .33299 L
.21555 .36727 L
s
.22946 .39741 m
.24517 .42795 L
.18399 .38714 L
.17262 .35974 L
.22946 .39741 L
s
.24517 .42795 m
.26199 .45737 L
.19616 .41385 L
.18399 .38714 L
.24517 .42795 L
s
.26199 .45737 m
.27919 .48459 L
.2086 .43887 L
.19616 .41385 L
.26199 .45737 L
s
.27919 .48459 m
.29601 .50887 L
.22077 .46147 L
.2086 .43887 L
.27919 .48459 L
s
.29601 .50887 m
.31172 .52976 L
.23214 .48115 L
.22077 .46147 L
.29601 .50887 L
s
.31172 .52976 m
.32563 .54697 L
.24221 .49756 L
.23214 .48115 L
.31172 .52976 L
s
.32563 .54697 m
.33714 .56038 L
.25054 .51048 L
.24221 .49756 L
.32563 .54697 L
s
.33714 .56038 m
.34574 .56995 L
.25676 .51979 L
.25054 .51048 L
.33714 .56038 L
s
.34574 .56995 m
.35105 .57569 L
.2606 .5254 L
.25676 .51979 L
.34574 .56995 L
s
.35105 .57569 m
.35285 .57759 L
.2619 .52727 L
.2606 .5254 L
.35105 .57569 L
s
.2619 .52727 m
.2606 .5254 L
.18051 .45285 L
.18137 .45454 L
.2619 .52727 L
s
.2606 .5254 m
.25676 .51979 L
.17796 .44781 L
.18051 .45285 L
.2606 .5254 L
s
.25676 .51979 m
.25054 .51048 L
.17384 .43948 L
.17796 .44781 L
.25676 .51979 L
s
.25054 .51048 m
.24221 .49756 L
.16833 .42796 L
.17384 .43948 L
.25054 .51048 L
s
.24221 .49756 m
.23214 .48115 L
.16167 .41343 L
.16833 .42796 L
.24221 .49756 L
s
.23214 .48115 m
.22077 .46147 L
.15415 .39615 L
.16167 .41343 L
.23214 .48115 L
s
.22077 .46147 m
.2086 .43887 L
.14609 .37646 L
.15415 .39615 L
.22077 .46147 L
s
.2086 .43887 m
.19616 .41385 L
.13786 .35485 L
.14609 .37646 L
.2086 .43887 L
s
.19616 .41385 m
.18399 .38714 L
.12981 .33198 L
.13786 .35485 L
.19616 .41385 L
s
.18399 .38714 m
.17262 .35974 L
.12228 .30871 L
.12981 .33198 L
.18399 .38714 L
s
.17262 .35974 m
.16255 .33299 L
.11562 .28617 L
.12228 .30871 L
.17262 .35974 L
s
.16255 .33299 m
.15423 .30863 L
.11011 .2658 L
.11562 .28617 L
.16255 .33299 L
s
.15423 .30863 m
.148 .28876 L
.10599 .2493 L
.11011 .2658 L
.15423 .30863 L
s
.148 .28876 m
.14416 .27561 L
.10345 .23844 L
.10599 .2493 L
.148 .28876 L
s
.14416 .27561 m
.14286 .27099 L
.10259 .23463 L
.10345 .23844 L
.14416 .27561 L
s
.14286 .27099 m
.14416 .27561 L
.10345 .23844 L
.10259 .23463 L
.14286 .27099 L
s
.14416 .27561 m
.148 .28876 L
.10599 .2493 L
.10345 .23844 L
.14416 .27561 L
s
.148 .28876 m
.15423 .30863 L
.11011 .2658 L
.10599 .2493 L
.148 .28876 L
s
.15423 .30863 m
.16255 .33299 L
.11562 .28617 L
.11011 .2658 L
.15423 .30863 L
s
.16255 .33299 m
.17262 .35974 L
.12228 .30871 L
.11562 .28617 L
.16255 .33299 L
s
.17262 .35974 m
.18399 .38714 L
.12981 .33198 L
.12228 .30871 L
.17262 .35974 L
s
.18399 .38714 m
.19616 .41385 L
.13786 .35485 L
.12981 .33198 L
.18399 .38714 L
s
.19616 .41385 m
.2086 .43887 L
.14609 .37646 L
.13786 .35485 L
.19616 .41385 L
s
.2086 .43887 m
.22077 .46147 L
.15415 .39615 L
.14609 .37646 L
.2086 .43887 L
s
.22077 .46147 m
.23214 .48115 L
.16167 .41343 L
.15415 .39615 L
.22077 .46147 L
s
.23214 .48115 m
.24221 .49756 L
.16833 .42796 L
.16167 .41343 L
.23214 .48115 L
s
.24221 .49756 m
.25054 .51048 L
.17384 .43948 L
.16833 .42796 L
.24221 .49756 L
s
.25054 .51048 m
.25676 .51979 L
.17796 .44781 L
.17384 .43948 L
.25054 .51048 L
s
.25676 .51979 m
.2606 .5254 L
.18051 .45285 L
.17796 .44781 L
.25676 .51979 L
s
.2606 .5254 m
.2619 .52727 L
.18137 .45454 L
.18051 .45285 L
.2606 .5254 L
s
.2619 .52727 m
.2606 .5254 L
.18051 .45285 L
.18137 .45454 L
.2619 .52727 L
s
.2606 .5254 m
.25676 .51979 L
.17796 .44781 L
.18051 .45285 L
.2606 .5254 L
s
.25676 .51979 m
.25054 .51048 L
.17384 .43948 L
.17796 .44781 L
.25676 .51979 L
s
.25054 .51048 m
.24221 .49756 L
.16833 .42796 L
.17384 .43948 L
.25054 .51048 L
s
.24221 .49756 m
.23214 .48115 L
.16167 .41343 L
.16833 .42796 L
.24221 .49756 L
s
.23214 .48115 m
.22077 .46147 L
.15415 .39615 L
.16167 .41343 L
.23214 .48115 L
s
.22077 .46147 m
.2086 .43887 L
.14609 .37646 L
.15415 .39615 L
.22077 .46147 L
s
.2086 .43887 m
.19616 .41385 L
.13786 .35485 L
.14609 .37646 L
.2086 .43887 L
s
.19616 .41385 m
.18399 .38714 L
.12981 .33198 L
.13786 .35485 L
.19616 .41385 L
s
.18399 .38714 m
.17262 .35974 L
.12228 .30871 L
.12981 .33198 L
.18399 .38714 L
s
.17262 .35974 m
.16255 .33299 L
.11562 .28617 L
.12228 .30871 L
.17262 .35974 L
s
.16255 .33299 m
.15423 .30863 L
.11011 .2658 L
.11562 .28617 L
.16255 .33299 L
s
.15423 .30863 m
.148 .28876 L
.10599 .2493 L
.11011 .2658 L
.15423 .30863 L
s
.148 .28876 m
.14416 .27561 L
.10345 .23844 L
.10599 .2493 L
.148 .28876 L
s
.14416 .27561 m
.14286 .27099 L
.10259 .23463 L
.10345 .23844 L
.14416 .27561 L
s
.14286 .27099 m
.14416 .27561 L
.10345 .23844 L
.10259 .23463 L
.14286 .27099 L
s
.14416 .27561 m
.148 .28876 L
.10599 .2493 L
.10345 .23844 L
.14416 .27561 L
s
.148 .28876 m
.15423 .30863 L
.11011 .2658 L
.10599 .2493 L
.148 .28876 L
s
.15423 .30863 m
.16255 .33299 L
.11562 .28617 L
.11011 .2658 L
.15423 .30863 L
s
.16255 .33299 m
.17262 .35974 L
.12228 .30871 L
.11562 .28617 L
.16255 .33299 L
s
.17262 .35974 m
.18399 .38714 L
.12981 .33198 L
.12228 .30871 L
.17262 .35974 L
s
.18399 .38714 m
.19616 .41385 L
.13786 .35485 L
.12981 .33198 L
.18399 .38714 L
s
.19616 .41385 m
.2086 .43887 L
.14609 .37646 L
.13786 .35485 L
.19616 .41385 L
s
.2086 .43887 m
.22077 .46147 L
.15415 .39615 L
.14609 .37646 L
.2086 .43887 L
s
.22077 .46147 m
.23214 .48115 L
.16167 .41343 L
.15415 .39615 L
.22077 .46147 L
s
.23214 .48115 m
.24221 .49756 L
.16833 .42796 L
.16167 .41343 L
.23214 .48115 L
s
.24221 .49756 m
.25054 .51048 L
.17384 .43948 L
.16833 .42796 L
.24221 .49756 L
s
.25054 .51048 m
.25676 .51979 L
.17796 .44781 L
.17384 .43948 L
.25054 .51048 L
s
.25676 .51979 m
.2606 .5254 L
.18051 .45285 L
.17796 .44781 L
.25676 .51979 L
s
.2606 .5254 m
.2619 .52727 L
.18137 .45454 L
.18051 .45285 L
.2606 .5254 L
s
.18137 .45454 m
.18051 .45285 L
.11426 .36121 L
.11475 .36259 L
.18137 .45454 L
s
.18051 .45285 m
.17796 .44781 L
.11279 .3571 L
.11426 .36121 L
.18051 .45285 L
s
.17796 .44781 m
.17384 .43948 L
.11041 .35032 L
.11279 .3571 L
.17796 .44781 L
s
.17384 .43948 m
.16833 .42796 L
.10723 .34097 L
.11041 .35032 L
.17384 .43948 L
s
.16833 .42796 m
.16167 .41343 L
.10339 .32924 L
.10723 .34097 L
.16833 .42796 L
s
.16167 .41343 m
.15415 .39615 L
.09904 .31535 L
.10339 .32924 L
.16167 .41343 L
s
.15415 .39615 m
.14609 .37646 L
.09439 .29962 L
.09904 .31535 L
.15415 .39615 L
s
.14609 .37646 m
.13786 .35485 L
.08964 .28245 L
.09439 .29962 L
.14609 .37646 L
s
.13786 .35485 m
.12981 .33198 L
.08499 .26439 L
.08964 .28245 L
.13786 .35485 L
s
.12981 .33198 m
.12228 .30871 L
.08065 .24611 L
.08499 .26439 L
.12981 .33198 L
s
.12228 .30871 m
.11562 .28617 L
.0768 .22852 L
.08065 .24611 L
.12228 .30871 L
s
.11562 .28617 m
.11011 .2658 L
.07362 .2127 L
.0768 .22852 L
.11562 .28617 L
s
.11011 .2658 m
.10599 .2493 L
.07125 .19995 L
.07362 .2127 L
.11011 .2658 L
s
.10599 .2493 m
.10345 .23844 L
.06978 .19158 L
.07125 .19995 L
.10599 .2493 L
s
.10345 .23844 m
.10259 .23463 L
.06928 .18865 L
.06978 .19158 L
.10345 .23844 L
s
.10259 .23463 m
.10345 .23844 L
.06978 .19158 L
.06928 .18865 L
.10259 .23463 L
s
.10345 .23844 m
.10599 .2493 L
.07125 .19995 L
.06978 .19158 L
.10345 .23844 L
s
.10599 .2493 m
.11011 .2658 L
.07362 .2127 L
.07125 .19995 L
.10599 .2493 L
s
.11011 .2658 m
.11562 .28617 L
.0768 .22852 L
.07362 .2127 L
.11011 .2658 L
s
.11562 .28617 m
.12228 .30871 L
.08065 .24611 L
.0768 .22852 L
.11562 .28617 L
s
.12228 .30871 m
.12981 .33198 L
.08499 .26439 L
.08065 .24611 L
.12228 .30871 L
s
.12981 .33198 m
.13786 .35485 L
.08964 .28245 L
.08499 .26439 L
.12981 .33198 L
s
.13786 .35485 m
.14609 .37646 L
.09439 .29962 L
.08964 .28245 L
.13786 .35485 L
s
.14609 .37646 m
.15415 .39615 L
.09904 .31535 L
.09439 .29962 L
.14609 .37646 L
s
.15415 .39615 m
.16167 .41343 L
.10339 .32924 L
.09904 .31535 L
.15415 .39615 L
s
.16167 .41343 m
.16833 .42796 L
.10723 .34097 L
.10339 .32924 L
.16167 .41343 L
s
.16833 .42796 m
.17384 .43948 L
.11041 .35032 L
.10723 .34097 L
.16833 .42796 L
s
.17384 .43948 m
.17796 .44781 L
.11279 .3571 L
.11041 .35032 L
.17384 .43948 L
s
.17796 .44781 m
.18051 .45285 L
.11426 .36121 L
.11279 .3571 L
.17796 .44781 L
s
.18051 .45285 m
.18137 .45454 L
.11475 .36259 L
.11426 .36121 L
.18051 .45285 L
s
.18137 .45454 m
.18051 .45285 L
.11426 .36121 L
.11475 .36259 L
.18137 .45454 L
s
.18051 .45285 m
.17796 .44781 L
.11279 .3571 L
.11426 .36121 L
.18051 .45285 L
s
.17796 .44781 m
.17384 .43948 L
.11041 .35032 L
.11279 .3571 L
.17796 .44781 L
s
.17384 .43948 m
.16833 .42796 L
.10723 .34097 L
.11041 .35032 L
.17384 .43948 L
s
.16833 .42796 m
.16167 .41343 L
.10339 .32924 L
.10723 .34097 L
.16833 .42796 L
s
.16167 .41343 m
.15415 .39615 L
.09904 .31535 L
.10339 .32924 L
.16167 .41343 L
s
.15415 .39615 m
.14609 .37646 L
.09439 .29962 L
.09904 .31535 L
.15415 .39615 L
s
.14609 .37646 m
.13786 .35485 L
.08964 .28245 L
.09439 .29962 L
.14609 .37646 L
s
.13786 .35485 m
.12981 .33198 L
.08499 .26439 L
.08964 .28245 L
.13786 .35485 L
s
.12981 .33198 m
.12228 .30871 L
.08065 .24611 L
.08499 .26439 L
.12981 .33198 L
s
.12228 .30871 m
.11562 .28617 L
.0768 .22852 L
.08065 .24611 L
.12228 .30871 L
s
.11562 .28617 m
.11011 .2658 L
.07362 .2127 L
.0768 .22852 L
.11562 .28617 L
s
.11011 .2658 m
.10599 .2493 L
.07125 .19995 L
.07362 .2127 L
.11011 .2658 L
s
.10599 .2493 m
.10345 .23844 L
.06978 .19158 L
.07125 .19995 L
.10599 .2493 L
s
.10345 .23844 m
.10259 .23463 L
.06928 .18865 L
.06978 .19158 L
.10345 .23844 L
s
.10259 .23463 m
.10345 .23844 L
.06978 .19158 L
.06928 .18865 L
.10259 .23463 L
s
.10345 .23844 m
.10599 .2493 L
.07125 .19995 L
.06978 .19158 L
.10345 .23844 L
s
.10599 .2493 m
.11011 .2658 L
.07362 .2127 L
.07125 .19995 L
.10599 .2493 L
s
.11011 .2658 m
.11562 .28617 L
.0768 .22852 L
.07362 .2127 L
.11011 .2658 L
s
.11562 .28617 m
.12228 .30871 L
.08065 .24611 L
.0768 .22852 L
.11562 .28617 L
s
.12228 .30871 m
.12981 .33198 L
.08499 .26439 L
.08065 .24611 L
.12228 .30871 L
s
.12981 .33198 m
.13786 .35485 L
.08964 .28245 L
.08499 .26439 L
.12981 .33198 L
s
.13786 .35485 m
.14609 .37646 L
.09439 .29962 L
.08964 .28245 L
.13786 .35485 L
s
.14609 .37646 m
.15415 .39615 L
.09904 .31535 L
.09439 .29962 L
.14609 .37646 L
s
.15415 .39615 m
.16167 .41343 L
.10339 .32924 L
.09904 .31535 L
.15415 .39615 L
s
.16167 .41343 m
.16833 .42796 L
.10723 .34097 L
.10339 .32924 L
.16167 .41343 L
s
.16833 .42796 m
.17384 .43948 L
.11041 .35032 L
.10723 .34097 L
.16833 .42796 L
s
.17384 .43948 m
.17796 .44781 L
.11279 .3571 L
.11041 .35032 L
.17384 .43948 L
s
.17796 .44781 m
.18051 .45285 L
.11426 .36121 L
.11279 .3571 L
.17796 .44781 L
s
.18051 .45285 m
.18137 .45454 L
.11475 .36259 L
.11426 .36121 L
.18051 .45285 L
s
.11475 .36259 m
.11426 .36121 L
.06475 .25447 L
.06498 .25544 L
.11475 .36259 L
s
.11426 .36121 m
.11279 .3571 L
.06409 .25156 L
.06475 .25447 L
.11426 .36121 L
s
.11279 .3571 m
.11041 .35032 L
.06301 .24678 L
.06409 .25156 L
.11279 .3571 L
s
.11041 .35032 m
.10723 .34097 L
.06157 .24021 L
.06301 .24678 L
.11041 .35032 L
s
.10723 .34097 m
.10339 .32924 L
.05983 .23198 L
.06157 .24021 L
.10723 .34097 L
s
.10339 .32924 m
.09904 .31535 L
.05787 .22228 L
.05983 .23198 L
.10339 .32924 L
s
.09904 .31535 m
.09439 .29962 L
.05576 .21131 L
.05787 .22228 L
.09904 .31535 L
s
.09439 .29962 m
.08964 .28245 L
.05361 .1994 L
.05576 .21131 L
.09439 .29962 L
s
.08964 .28245 m
.08499 .26439 L
.05151 .18691 L
.05361 .1994 L
.08964 .28245 L
s
.08499 .26439 m
.08065 .24611 L
.04954 .17432 L
.05151 .18691 L
.08499 .26439 L
s
.08065 .24611 m
.0768 .22852 L
.0478 .16225 L
.04954 .17432 L
.08065 .24611 L
s
.0768 .22852 m
.07362 .2127 L
.04636 .15144 L
.0478 .16225 L
.0768 .22852 L
s
.07362 .2127 m
.07125 .19995 L
.04528 .14275 L
.04636 .15144 L
.07362 .2127 L
s
.07125 .19995 m
.06978 .19158 L
.04462 .13706 L
.04528 .14275 L
.07125 .19995 L
s
.06978 .19158 m
.06928 .18865 L
.04439 .13508 L
.04462 .13706 L
.06978 .19158 L
s
.06928 .18865 m
.06978 .19158 L
.04462 .13706 L
.04439 .13508 L
.06928 .18865 L
s
.06978 .19158 m
.07125 .19995 L
.04528 .14275 L
.04462 .13706 L
.06978 .19158 L
s
.07125 .19995 m
.07362 .2127 L
.04636 .15144 L
.04528 .14275 L
.07125 .19995 L
s
.07362 .2127 m
.0768 .22852 L
.0478 .16225 L
.04636 .15144 L
.07362 .2127 L
s
.0768 .22852 m
.08065 .24611 L
.04954 .17432 L
.0478 .16225 L
.0768 .22852 L
s
.08065 .24611 m
.08499 .26439 L
.05151 .18691 L
.04954 .17432 L
.08065 .24611 L
s
.08499 .26439 m
.08964 .28245 L
.05361 .1994 L
.05151 .18691 L
.08499 .26439 L
s
.08964 .28245 m
.09439 .29962 L
.05576 .21131 L
.05361 .1994 L
.08964 .28245 L
s
.09439 .29962 m
.09904 .31535 L
.05787 .22228 L
.05576 .21131 L
.09439 .29962 L
s
.09904 .31535 m
.10339 .32924 L
.05983 .23198 L
.05787 .22228 L
.09904 .31535 L
s
.10339 .32924 m
.10723 .34097 L
.06157 .24021 L
.05983 .23198 L
.10339 .32924 L
s
.10723 .34097 m
.11041 .35032 L
.06301 .24678 L
.06157 .24021 L
.10723 .34097 L
s
.11041 .35032 m
.11279 .3571 L
.06409 .25156 L
.06301 .24678 L
.11041 .35032 L
s
.11279 .3571 m
.11426 .36121 L
.06475 .25447 L
.06409 .25156 L
.11279 .3571 L
s
.11426 .36121 m
.11475 .36259 L
.06498 .25544 L
.06475 .25447 L
.11426 .36121 L
s
.11475 .36259 m
.11426 .36121 L
.06475 .25447 L
.06498 .25544 L
.11475 .36259 L
s
.11426 .36121 m
.11279 .3571 L
.06409 .25156 L
.06475 .25447 L
.11426 .36121 L
s
.11279 .3571 m
.11041 .35032 L
.06301 .24678 L
.06409 .25156 L
.11279 .3571 L
s
.11041 .35032 m
.10723 .34097 L
.06157 .24021 L
.06301 .24678 L
.11041 .35032 L
s
.10723 .34097 m
.10339 .32924 L
.05983 .23198 L
.06157 .24021 L
.10723 .34097 L
s
.10339 .32924 m
.09904 .31535 L
.05787 .22228 L
.05983 .23198 L
.10339 .32924 L
s
.09904 .31535 m
.09439 .29962 L
.05576 .21131 L
.05787 .22228 L
.09904 .31535 L
s
.09439 .29962 m
.08964 .28245 L
.05361 .1994 L
.05576 .21131 L
.09439 .29962 L
s
.08964 .28245 m
.08499 .26439 L
.05151 .18691 L
.05361 .1994 L
.08964 .28245 L
s
.08499 .26439 m
.08065 .24611 L
.04954 .17432 L
.05151 .18691 L
.08499 .26439 L
s
.08065 .24611 m
.0768 .22852 L
.0478 .16225 L
.04954 .17432 L
.08065 .24611 L
s
.0768 .22852 m
.07362 .2127 L
.04636 .15144 L
.0478 .16225 L
.0768 .22852 L
s
.07362 .2127 m
.07125 .19995 L
.04528 .14275 L
.04636 .15144 L
.07362 .2127 L
s
.07125 .19995 m
.06978 .19158 L
.04462 .13706 L
.04528 .14275 L
.07125 .19995 L
s
.06978 .19158 m
.06928 .18865 L
.04439 .13508 L
.04462 .13706 L
.06978 .19158 L
s
.06928 .18865 m
.06978 .19158 L
.04462 .13706 L
.04439 .13508 L
.06928 .18865 L
s
.06978 .19158 m
.07125 .19995 L
.04528 .14275 L
.04462 .13706 L
.06978 .19158 L
s
.07125 .19995 m
.07362 .2127 L
.04636 .15144 L
.04528 .14275 L
.07125 .19995 L
s
.07362 .2127 m
.0768 .22852 L
.0478 .16225 L
.04636 .15144 L
.07362 .2127 L
s
.0768 .22852 m
.08065 .24611 L
.04954 .17432 L
.0478 .16225 L
.0768 .22852 L
s
.08065 .24611 m
.08499 .26439 L
.05151 .18691 L
.04954 .17432 L
.08065 .24611 L
s
.08499 .26439 m
.08964 .28245 L
.05361 .1994 L
.05151 .18691 L
.08499 .26439 L
s
.08964 .28245 m
.09439 .29962 L
.05576 .21131 L
.05361 .1994 L
.08964 .28245 L
s
.09439 .29962 m
.09904 .31535 L
.05787 .22228 L
.05576 .21131 L
.09439 .29962 L
s
.09904 .31535 m
.10339 .32924 L
.05983 .23198 L
.05787 .22228 L
.09904 .31535 L
s
.10339 .32924 m
.10723 .34097 L
.06157 .24021 L
.05983 .23198 L
.10339 .32924 L
s
.10723 .34097 m
.11041 .35032 L
.06301 .24678 L
.06157 .24021 L
.10723 .34097 L
s
.11041 .35032 m
.11279 .3571 L
.06409 .25156 L
.06301 .24678 L
.11041 .35032 L
s
.11279 .3571 m
.11426 .36121 L
.06475 .25447 L
.06409 .25156 L
.11279 .3571 L
s
.11426 .36121 m
.11475 .36259 L
.06498 .25544 L
.06475 .25447 L
.11426 .36121 L
s
.06498 .25544 m
.06475 .25447 L
.03416 .13726 L
.03422 .13777 L
.06498 .25544 L
s
.06475 .25447 m
.06409 .25156 L
.03399 .13576 L
.03416 .13726 L
.06475 .25447 L
s
.06409 .25156 m
.06301 .24678 L
.03372 .13329 L
.03399 .13576 L
.06409 .25156 L
s
.06301 .24678 m
.06157 .24021 L
.03335 .12991 L
.03372 .13329 L
.06301 .24678 L
s
.06157 .24021 m
.05983 .23198 L
.03291 .12567 L
.03335 .12991 L
.06157 .24021 L
s
.05983 .23198 m
.05787 .22228 L
.03242 .12068 L
.03291 .12567 L
.05983 .23198 L
s
.05787 .22228 m
.05576 .21131 L
.03189 .11505 L
.03242 .12068 L
.05787 .22228 L
s
.05576 .21131 m
.05361 .1994 L
.03134 .10895 L
.03189 .11505 L
.05576 .21131 L
s
.05361 .1994 m
.05151 .18691 L
.03081 .10257 L
.03134 .10895 L
.05361 .1994 L
s
.05151 .18691 m
.04954 .17432 L
.03031 .09615 L
.03081 .10257 L
.05151 .18691 L
s
.04954 .17432 m
.0478 .16225 L
.02987 .09001 L
.03031 .09615 L
.04954 .17432 L
s
.0478 .16225 m
.04636 .15144 L
.02951 .08453 L
.02987 .09001 L
.0478 .16225 L
s
.04636 .15144 m
.04528 .14275 L
.02924 .08012 L
.02951 .08453 L
.04636 .15144 L
s
.04528 .14275 m
.04462 .13706 L
.02907 .07724 L
.02924 .08012 L
.04528 .14275 L
s
.04462 .13706 m
.04439 .13508 L
.02901 .07624 L
.02907 .07724 L
.04462 .13706 L
s
.04439 .13508 m
.04462 .13706 L
.02907 .07724 L
.02901 .07624 L
.04439 .13508 L
s
.04462 .13706 m
.04528 .14275 L
.02924 .08012 L
.02907 .07724 L
.04462 .13706 L
s
.04528 .14275 m
.04636 .15144 L
.02951 .08453 L
.02924 .08012 L
.04528 .14275 L
s
.04636 .15144 m
.0478 .16225 L
.02987 .09001 L
.02951 .08453 L
.04636 .15144 L
s
.0478 .16225 m
.04954 .17432 L
.03031 .09615 L
.02987 .09001 L
.0478 .16225 L
s
.04954 .17432 m
.05151 .18691 L
.03081 .10257 L
.03031 .09615 L
.04954 .17432 L
s
.05151 .18691 m
.05361 .1994 L
.03134 .10895 L
.03081 .10257 L
.05151 .18691 L
s
.05361 .1994 m
.05576 .21131 L
.03189 .11505 L
.03134 .10895 L
.05361 .1994 L
s
.05576 .21131 m
.05787 .22228 L
.03242 .12068 L
.03189 .11505 L
.05576 .21131 L
s
.05787 .22228 m
.05983 .23198 L
.03291 .12567 L
.03242 .12068 L
.05787 .22228 L
s
.05983 .23198 m
.06157 .24021 L
.03335 .12991 L
.03291 .12567 L
.05983 .23198 L
s
.06157 .24021 m
.06301 .24678 L
.03372 .13329 L
.03335 .12991 L
.06157 .24021 L
s
.06301 .24678 m
.06409 .25156 L
.03399 .13576 L
.03372 .13329 L
.06301 .24678 L
s
.06409 .25156 m
.06475 .25447 L
.03416 .13726 L
.03399 .13576 L
.06409 .25156 L
s
.06475 .25447 m
.06498 .25544 L
.03422 .13777 L
.03416 .13726 L
.06475 .25447 L
s
.06498 .25544 m
.06475 .25447 L
.03416 .13726 L
.03422 .13777 L
.06498 .25544 L
s
.06475 .25447 m
.06409 .25156 L
.03399 .13576 L
.03416 .13726 L
.06475 .25447 L
s
.06409 .25156 m
.06301 .24678 L
.03372 .13329 L
.03399 .13576 L
.06409 .25156 L
s
.06301 .24678 m
.06157 .24021 L
.03335 .12991 L
.03372 .13329 L
.06301 .24678 L
s
.06157 .24021 m
.05983 .23198 L
.03291 .12567 L
.03335 .12991 L
.06157 .24021 L
s
.05983 .23198 m
.05787 .22228 L
.03242 .12068 L
.03291 .12567 L
.05983 .23198 L
s
.05787 .22228 m
.05576 .21131 L
.03189 .11505 L
.03242 .12068 L
.05787 .22228 L
s
.05576 .21131 m
.05361 .1994 L
.03134 .10895 L
.03189 .11505 L
.05576 .21131 L
s
.05361 .1994 m
.05151 .18691 L
.03081 .10257 L
.03134 .10895 L
.05361 .1994 L
s
.05151 .18691 m
.04954 .17432 L
.03031 .09615 L
.03081 .10257 L
.05151 .18691 L
s
.04954 .17432 m
.0478 .16225 L
.02987 .09001 L
.03031 .09615 L
.04954 .17432 L
s
.0478 .16225 m
.04636 .15144 L
.02951 .08453 L
.02987 .09001 L
.0478 .16225 L
s
.04636 .15144 m
.04528 .14275 L
.02924 .08012 L
.02951 .08453 L
.04636 .15144 L
s
.04528 .14275 m
.04462 .13706 L
.02907 .07724 L
.02924 .08012 L
.04528 .14275 L
s
.04462 .13706 m
.04439 .13508 L
.02901 .07624 L
.02907 .07724 L
.04462 .13706 L
s
.04439 .13508 m
.04462 .13706 L
.02907 .07724 L
.02901 .07624 L
.04439 .13508 L
s
.04462 .13706 m
.04528 .14275 L
.02924 .08012 L
.02907 .07724 L
.04462 .13706 L
s
.04528 .14275 m
.04636 .15144 L
.02951 .08453 L
.02924 .08012 L
.04528 .14275 L
s
.04636 .15144 m
.0478 .16225 L
.02987 .09001 L
.02951 .08453 L
.04636 .15144 L
s
.0478 .16225 m
.04954 .17432 L
.03031 .09615 L
.02987 .09001 L
.0478 .16225 L
s
.04954 .17432 m
.05151 .18691 L
.03081 .10257 L
.03031 .09615 L
.04954 .17432 L
s
.05151 .18691 m
.05361 .1994 L
.03134 .10895 L
.03081 .10257 L
.05151 .18691 L
s
.05361 .1994 m
.05576 .21131 L
.03189 .11505 L
.03134 .10895 L
.05361 .1994 L
s
.05576 .21131 m
.05787 .22228 L
.03242 .12068 L
.03189 .11505 L
.05576 .21131 L
s
.05787 .22228 m
.05983 .23198 L
.03291 .12567 L
.03242 .12068 L
.05787 .22228 L
s
.05983 .23198 m
.06157 .24021 L
.03335 .12991 L
.03291 .12567 L
.05983 .23198 L
s
.06157 .24021 m
.06301 .24678 L
.03372 .13329 L
.03335 .12991 L
.06157 .24021 L
s
.06301 .24678 m
.06409 .25156 L
.03399 .13576 L
.03372 .13329 L
.06301 .24678 L
s
.06409 .25156 m
.06475 .25447 L
.03416 .13726 L
.03399 .13576 L
.06409 .25156 L
s
.06475 .25447 m
.06498 .25544 L
.03422 .13777 L
.03416 .13726 L
.06475 .25447 L
s
.03422 .13777 m
.03416 .13726 L
.02381 .01472 L
.02381 .01472 L
.03422 .13777 L
s
.03416 .13726 m
.03399 .13576 L
.02381 .01472 L
.02381 .01472 L
.03416 .13726 L
s
.03399 .13576 m
.03372 .13329 L
.02381 .01472 L
.02381 .01472 L
.03399 .13576 L
s
.03372 .13329 m
.03335 .12991 L
.02381 .01472 L
.02381 .01472 L
.03372 .13329 L
s
.03335 .12991 m
.03291 .12567 L
.02381 .01472 L
.02381 .01472 L
.03335 .12991 L
s
.03291 .12567 m
.03242 .12068 L
.02381 .01472 L
.02381 .01472 L
.03291 .12567 L
s
.03242 .12068 m
.03189 .11505 L
.02381 .01472 L
.02381 .01472 L
.03242 .12068 L
s
.03189 .11505 m
.03134 .10895 L
.02381 .01472 L
.02381 .01472 L
.03189 .11505 L
s
.03134 .10895 m
.03081 .10257 L
.02381 .01472 L
.02381 .01472 L
.03134 .10895 L
s
.03081 .10257 m
.03031 .09615 L
.02381 .01472 L
.02381 .01472 L
.03081 .10257 L
s
.03031 .09615 m
.02987 .09001 L
.02381 .01472 L
.02381 .01472 L
.03031 .09615 L
s
.02987 .09001 m
.02951 .08453 L
.02381 .01472 L
.02381 .01472 L
.02987 .09001 L
s
.02951 .08453 m
.02924 .08012 L
.02381 .01472 L
.02381 .01472 L
.02951 .08453 L
s
.02924 .08012 m
.02907 .07724 L
.02381 .01472 L
.02381 .01472 L
.02924 .08012 L
s
.02907 .07724 m
.02901 .07624 L
.02381 .01472 L
.02381 .01472 L
.02907 .07724 L
s
.02901 .07624 m
.02907 .07724 L
.02381 .01472 L
.02381 .01472 L
.02901 .07624 L
s
.02907 .07724 m
.02924 .08012 L
.02381 .01472 L
.02381 .01472 L
.02907 .07724 L
s
.02924 .08012 m
.02951 .08453 L
.02381 .01472 L
.02381 .01472 L
.02924 .08012 L
s
.02951 .08453 m
.02987 .09001 L
.02381 .01472 L
.02381 .01472 L
.02951 .08453 L
s
.02987 .09001 m
.03031 .09615 L
.02381 .01472 L
.02381 .01472 L
.02987 .09001 L
s
.03031 .09615 m
.03081 .10257 L
.02381 .01472 L
.02381 .01472 L
.03031 .09615 L
s
.03081 .10257 m
.03134 .10895 L
.02381 .01472 L
.02381 .01472 L
.03081 .10257 L
s
.03134 .10895 m
.03189 .11505 L
.02381 .01472 L
.02381 .01472 L
.03134 .10895 L
s
.03189 .11505 m
.03242 .12068 L
.02381 .01472 L
.02381 .01472 L
.03189 .11505 L
s
.03242 .12068 m
.03291 .12567 L
.02381 .01472 L
.02381 .01472 L
.03242 .12068 L
s
.03291 .12567 m
.03335 .12991 L
.02381 .01472 L
.02381 .01472 L
.03291 .12567 L
s
.03335 .12991 m
.03372 .13329 L
.02381 .01472 L
.02381 .01472 L
.03335 .12991 L
s
.03372 .13329 m
.03399 .13576 L
.02381 .01472 L
.02381 .01472 L
.03372 .13329 L
s
.03399 .13576 m
.03416 .13726 L
.02381 .01472 L
.02381 .01472 L
.03399 .13576 L
s
.03416 .13726 m
.03422 .13777 L
.02381 .01472 L
.02381 .01472 L
.03416 .13726 L
s
.03422 .13777 m
.03416 .13726 L
.02381 .01472 L
.02381 .01472 L
.03422 .13777 L
s
.03416 .13726 m
.03399 .13576 L
.02381 .01472 L
.02381 .01472 L
.03416 .13726 L
s
.03399 .13576 m
.03372 .13329 L
.02381 .01472 L
.02381 .01472 L
.03399 .13576 L
s
.03372 .13329 m
.03335 .12991 L
.02381 .01472 L
.02381 .01472 L
.03372 .13329 L
s
.03335 .12991 m
.03291 .12567 L
.02381 .01472 L
.02381 .01472 L
.03335 .12991 L
s
.03291 .12567 m
.03242 .12068 L
.02381 .01472 L
.02381 .01472 L
.03291 .12567 L
s
.03242 .12068 m
.03189 .11505 L
.02381 .01472 L
.02381 .01472 L
.03242 .12068 L
s
.03189 .11505 m
.03134 .10895 L
.02381 .01472 L
.02381 .01472 L
.03189 .11505 L
s
.03134 .10895 m
.03081 .10257 L
.02381 .01472 L
.02381 .01472 L
.03134 .10895 L
s
.03081 .10257 m
.03031 .09615 L
.02381 .01472 L
.02381 .01472 L
.03081 .10257 L
s
.03031 .09615 m
.02987 .09001 L
.02381 .01472 L
.02381 .01472 L
.03031 .09615 L
s
.02987 .09001 m
.02951 .08453 L
.02381 .01472 L
.02381 .01472 L
.02987 .09001 L
s
.02951 .08453 m
.02924 .08012 L
.02381 .01472 L
.02381 .01472 L
.02951 .08453 L
s
.02924 .08012 m
.02907 .07724 L
.02381 .01472 L
.02381 .01472 L
.02924 .08012 L
s
.02907 .07724 m
.02901 .07624 L
.02381 .01472 L
.02381 .01472 L
.02907 .07724 L
s
.02901 .07624 m
.02907 .07724 L
.02381 .01472 L
.02381 .01472 L
.02901 .07624 L
s
.02907 .07724 m
.02924 .08012 L
.02381 .01472 L
.02381 .01472 L
.02907 .07724 L
s
.02924 .08012 m
.02951 .08453 L
.02381 .01472 L
.02381 .01472 L
.02924 .08012 L
s
.02951 .08453 m
.02987 .09001 L
.02381 .01472 L
.02381 .01472 L
.02951 .08453 L
s
.02987 .09001 m
.03031 .09615 L
.02381 .01472 L
.02381 .01472 L
.02987 .09001 L
s
.03031 .09615 m
.03081 .10257 L
.02381 .01472 L
.02381 .01472 L
.03031 .09615 L
s
.03081 .10257 m
.03134 .10895 L
.02381 .01472 L
.02381 .01472 L
.03081 .10257 L
s
.03134 .10895 m
.03189 .11505 L
.02381 .01472 L
.02381 .01472 L
.03134 .10895 L
s
.03189 .11505 m
.03242 .12068 L
.02381 .01472 L
.02381 .01472 L
.03189 .11505 L
s
.03242 .12068 m
.03291 .12567 L
.02381 .01472 L
.02381 .01472 L
.03242 .12068 L
s
.03291 .12567 m
.03335 .12991 L
.02381 .01472 L
.02381 .01472 L
.03291 .12567 L
s
.03335 .12991 m
.03372 .13329 L
.02381 .01472 L
.02381 .01472 L
.03335 .12991 L
s
.03372 .13329 m
.03399 .13576 L
.02381 .01472 L
.02381 .01472 L
.03372 .13329 L
s
.03399 .13576 m
.03416 .13726 L
.02381 .01472 L
.02381 .01472 L
.03399 .13576 L
s
.03416 .13726 m
.03422 .13777 L
.02381 .01472 L
.02381 .01472 L
.03416 .13726 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.15782, -0.0746048, \
0.0220057, 0.0177054}}],

Cell[OutputFormData["\<\
Graphics[{Line[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, \
0.6211835161491764}, {-0.9344428022014168, 0.623735072453278}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9358597315848943, 0.613577092391689}, \
{-0.9348009477166837, 0.6211835161491764}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721149}, \
{-0.9358597315848943, 0.613577092391689}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279119}, \
{-0.9375728798703992, 0.6010618457721149}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196118}, \
{-0.9398655197725243, 0.5838857533279119}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, \
{-0.9426374519262397, 0.5624063276196118}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.508595070176279}, \
{-0.945767529595222, 0.5371028573756114}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9525452499365675, 0.4776706018498101}, \
{-0.9491189533655577, 0.508595070176279}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.4453237472356564}, \
{-0.9525452499365675, 0.4776706018498101}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9590267513758856, 0.4128060526669478}, \
{-0.9558966737069031, 0.4453237472356564}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.961798683529601, 0.3816816923272188}, \
{-0.9590267513758856, 0.4128060526669478}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, \
{-0.961798683529601, 0.3816816923272188}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9658044717172308, 0.33154008354139414}, \
{-0.964091323431726, 0.35386023041001824}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9668632555854415, 0.31695593148714024}, \
{-0.9658044717172308, 0.33154008354139414}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9672214011007084, 0.311867536226639}, \
{-0.9668632555854415, 0.31695593148714024}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9668632555854415, 0.31695593148714024}, \
{-0.9672214011007084, 0.311867536226639}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9658044717172308, 0.33154008354139414}, \
{-0.9668632555854415, 0.31695593148714024}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, \
{-0.9658044717172308, 0.33154008354139414}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.961798683529601, 0.38168169232721855}, \
{-0.964091323431726, 0.35386023041001824}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9590267513758856, 0.4128060526669478}, \
{-0.961798683529601, 0.38168169232721855}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.4453237472356564}, \
{-0.9590267513758856, 0.4128060526669478}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9525452499365675, 0.47767060184980986}, \
{-0.9558966737069031, 0.4453237472356564}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.508595070176279}, \
{-0.9525452499365675, 0.47767060184980986}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, \
{-0.9491189533655577, 0.508595070176279}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196116}, \
{-0.945767529595222, 0.5371028573756114}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279119}, \
{-0.9426374519262397, 0.5624063276196116}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721149}, \
{-0.9398655197725243, 0.5838857533279119}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9358597315848944, 0.6135770923916888}, \
{-0.9375728798703992, 0.6010618457721149}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9358597315848944, 0.6135770923916888}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9344428022014168, 0.623735072453278}, \
{-0.9348009477166837, 0.6211835161491764}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9344428022014168, 0.623735072453278}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9358597315848943, 0.613577092391689}, \
{-0.9348009477166837, 0.6211835161491764}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721151}, \
{-0.9358597315848943, 0.613577092391689}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279119}, \
{-0.9375728798703992, 0.6010618457721151}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196118}, \
{-0.9398655197725243, 0.5838857533279119}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, \
{-0.9426374519262397, 0.5624063276196118}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.508595070176279}, \
{-0.945767529595222, 0.5371028573756114}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9525452499365675, 0.4776706018498101}, \
{-0.9491189533655577, 0.508595070176279}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.4453237472356564}, \
{-0.9525452499365675, 0.4776706018498101}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9590267513758856, 0.4128060526669481}, \
{-0.9558966737069031, 0.4453237472356564}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.961798683529601, 0.3816816923272188}, \
{-0.9590267513758856, 0.4128060526669481}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, \
{-0.961798683529601, 0.3816816923272188}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9658044717172308, 0.33154008354139414}, \
{-0.964091323431726, 0.35386023041001824}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9668632555854414, 0.31695593148714096}, \
{-0.9658044717172308, 0.33154008354139414}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9672214011007084, 0.311867536226639}, \
{-0.9668632555854414, 0.31695593148714096}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9668632555854415, 0.31695593148714024}, \
{-0.9672214011007084, 0.311867536226639}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9658044717172309, 0.33154008354139347}, \
{-0.9668632555854415, 0.31695593148714024}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, \
{-0.9658044717172309, 0.33154008354139347}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9617986835296011, 0.38168169232721827}, \
{-0.964091323431726, 0.35386023041001824}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9590267513758856, 0.41280605266694753}, \
{-0.9617986835296011, 0.38168169232721827}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.44532374723565615}, \
{-0.9590267513758856, 0.41280605266694753}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9525452499365675, 0.47767060184980986}, \
{-0.9558966737069031, 0.44532374723565615}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.5085950701762788}, \
{-0.9525452499365675, 0.47767060184980986}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, \
{-0.9491189533655577, 0.5085950701762788}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196116}, \
{-0.945767529595222, 0.5371028573756114}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279117}, \
{-0.9426374519262397, 0.5624063276196116}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721149}, \
{-0.9398655197725243, 0.5838857533279117}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9358597315848944, 0.6135770923916888}, \
{-0.9375728798703992, 0.6010618457721149}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9358597315848944, 0.6135770923916888}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9344428022014168, 0.623735072453278}, \
{-0.9348009477166837, 0.6211835161491764}, {-1., 0.}}], 
  Line[{{-0.9344428022014168, 0.623735072453278}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112804, 1.2152748245287444}, 
    {-0.7406363729278029, 1.2202099292274005}, {-0.9344428022014168, \
0.623735072453278}}], 
  Line[{{-0.9348009477166837, 0.6211835161491764}, {-0.9358597315848943, \
0.613577092391689}, {-0.7462421638484733, 1.2005567894684717}, 
    {-0.7420533023112804, 1.2152748245287444}, {-0.9348009477166837, \
0.6211835161491764}}], 
  Line[{{-0.9358597315848943, 0.613577092391689}, {-0.9375728798703992, \
0.6010618457721149}, {-0.7530198841898188, 1.1763209525760518}, 
    {-0.7462421638484733, 1.2005567894684717}, {-0.9358597315848943, \
0.613577092391689}}], 
  Line[{{-0.9375728798703992, 0.6010618457721149}, {-0.9398655197725243, \
0.5838857533279119}, {-0.7620902444332892, 1.143020501605284}, 
    {-0.7530198841898188, 1.1763209525760518}, {-0.9375728798703992, \
0.6010618457721149}}], 
  Line[{{-0.9398655197725243, 0.5838857533279119}, {-0.9426374519262397, \
0.5624063276196118}, {-0.7730568263118275, 1.1013148858947208}, 
    {-0.7620902444332892, 1.143020501605284}, {-0.9398655197725243, \
0.5838857533279119}}], 
  Line[{{-0.9426374519262397, 0.5624063276196118}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738435, 1.0520980143876293}, 
    {-0.7730568263118275, 1.1013148858947208}, {-0.9426374519262397, \
0.5624063276196118}}], 
  Line[{{-0.945767529595222, 0.5371028573756114}, {-0.9491189533655577, \
0.508595070176279}, {-0.7986995593545068, 0.9965396214846545}, 
    {-0.7854403375738435, 1.0520980143876293}, {-0.945767529595222, \
0.5371028573756114}}], 
  Line[{{-0.9491189533655577, 0.508595070176279}, {-0.9525452499365675, \
0.4776706018498101}, {-0.8122550000371975, 0.9361441841071271}, 
    {-0.7986995593545068, 0.9965396214846545}, {-0.9491189533655577, \
0.508595070176279}}], 
  Line[{{-0.9525452499365675, 0.4776706018498101}, {-0.9558966737069031, \
0.4453237472356564}, {-0.8255142218178609, 0.8728320775698118}, 
    {-0.8122550000371975, 0.9361441841071271}, {-0.9525452499365675, \
0.4776706018498101}}], 
  Line[{{-0.9558966737069031, 0.4453237472356564}, {-0.9590267513758856, \
0.4128060526669478}, {-0.8378977330798768, 0.8090441125945328}, 
    {-0.8255142218178609, 0.8728320775698118}, {-0.9558966737069031, \
0.4453237472356564}}], 
  Line[{{-0.9590267513758856, 0.4128060526669478}, {-0.961798683529601, \
0.3816816923272188}, {-0.8488643149584152, 0.7478557941640108}, 
    {-0.8378977330798768, 0.8090441125945328}, {-0.9590267513758856, \
0.4128060526669478}}], 
  Line[{{-0.961798683529601, 0.3816816923272188}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018857, 0.6930472461935369}, 
    {-0.8488643149584152, 0.7478557941640108}, {-0.961798683529601, \
0.3816816923272188}}], 
  Line[{{-0.964091323431726, 0.35386023041001824}, {-0.9658044717172308, \
0.33154008354139414}, {-0.864712395543231, 0.6489952411032603}, 
    {-0.8579346752018857, 0.6930472461935369}, {-0.964091323431726, \
0.35386023041001824}}], 
  Line[{{-0.9658044717172308, 0.33154008354139414}, {-0.9668632555854415, \
0.31695593148714024}, {-0.868901257080424, 0.6201700772082609}, 
    {-0.864712395543231, 0.6489952411032603}, {-0.9658044717172308, \
0.33154008354139414}}], 
  Line[{{-0.9668632555854415, 0.31695593148714024}, {-0.9672214011007084, \
0.311867536226639}, {-0.8703181864639015, 0.6101049646137003}, 
    {-0.868901257080424, 0.6201700772082609}, {-0.9668632555854415, \
0.31695593148714024}}], 
  Line[{{-0.9672214011007084, 0.311867536226639}, {-0.9668632555854415, \
0.31695593148714024}, {-0.8689012570804241, 0.6201700772082606}, 
    {-0.8703181864639015, 0.6101049646137003}, {-0.9672214011007084, \
0.311867536226639}}], 
  Line[{{-0.9668632555854415, 0.31695593148714024}, {-0.9658044717172308, \
0.33154008354139414}, {-0.864712395543231, 0.6489952411032603}, 
    {-0.8689012570804241, 0.6201700772082606}, {-0.9668632555854415, \
0.31695593148714024}}], 
  Line[{{-0.9658044717172308, 0.33154008354139414}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018857, 0.6930472461935366}, 
    {-0.864712395543231, 0.6489952411032603}, {-0.9658044717172308, \
0.33154008354139414}}], 
  Line[{{-0.964091323431726, 0.35386023041001824}, {-0.961798683529601, \
0.38168169232721855}, {-0.8488643149584152, 0.7478557941640107}, 
    {-0.8579346752018857, 0.6930472461935366}, {-0.964091323431726, \
0.35386023041001824}}], 
  Line[{{-0.961798683529601, 0.38168169232721855}, {-0.9590267513758856, \
0.4128060526669478}, {-0.8378977330798769, 0.8090441125945326}, 
    {-0.8488643149584152, 0.7478557941640107}, {-0.961798683529601, \
0.38168169232721855}}], 
  Line[{{-0.9590267513758856, 0.4128060526669478}, {-0.9558966737069031, \
0.4453237472356564}, {-0.8255142218178609, 0.8728320775698117}, 
    {-0.8378977330798769, 0.8090441125945326}, {-0.9590267513758856, \
0.4128060526669478}}], 
  Line[{{-0.9558966737069031, 0.4453237472356564}, {-0.9525452499365675, \
0.47767060184980986}, {-0.8122550000371976, 0.9361441841071267}, 
    {-0.8255142218178609, 0.8728320775698117}, {-0.9558966737069031, \
0.4453237472356564}}], 
  Line[{{-0.9525452499365675, 0.47767060184980986}, {-0.9491189533655577, \
0.508595070176279}, {-0.7986995593545069, 0.9965396214846542}, 
    {-0.8122550000371976, 0.9361441841071267}, {-0.9525452499365675, \
0.47767060184980986}}], 
  Line[{{-0.9491189533655577, 0.508595070176279}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738435, 1.0520980143876293}, 
    {-0.7986995593545069, 0.9965396214846542}, {-0.9491189533655577, \
0.508595070176279}}], 
  Line[{{-0.945767529595222, 0.5371028573756114}, {-0.9426374519262397, \
0.5624063276196116}, {-0.7730568263118276, 1.1013148858947206}, 
    {-0.7854403375738435, 1.0520980143876293}, {-0.945767529595222, \
0.5371028573756114}}], 
  Line[{{-0.9426374519262397, 0.5624063276196116}, {-0.9398655197725243, \
0.5838857533279119}, {-0.7620902444332892, 1.1430205016052837}, 
    {-0.7730568263118276, 1.1013148858947206}, {-0.9426374519262397, \
0.5624063276196116}}], 
  Line[{{-0.9398655197725243, 0.5838857533279119}, {-0.9375728798703992, \
0.6010618457721149}, {-0.7530198841898188, 1.1763209525760518}, 
    {-0.7620902444332892, 1.1430205016052837}, {-0.9398655197725243, \
0.5838857533279119}}], 
  Line[{{-0.9375728798703992, 0.6010618457721149}, {-0.9358597315848944, \
0.6135770923916888}, {-0.7462421638484733, 1.2005567894684717}, 
    {-0.7530198841898188, 1.1763209525760518}, {-0.9375728798703992, \
0.6010618457721149}}], 
  Line[{{-0.9358597315848944, 0.6135770923916888}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112804, 1.2152748245287444}, 
    {-0.7462421638484733, 1.2005567894684717}, {-0.9358597315848944, \
0.6135770923916888}}], 
  Line[{{-0.9348009477166837, 0.6211835161491764}, {-0.9344428022014168, \
0.623735072453278}, {-0.7406363729278029, 1.2202099292274005}, 
    {-0.7420533023112804, 1.2152748245287444}, {-0.9348009477166837, \
0.6211835161491764}}], 
  Line[{{-0.9344428022014168, 0.623735072453278}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112804, 1.2152748245287444}, 
    {-0.7406363729278029, 1.2202099292274005}, {-0.9344428022014168, \
0.623735072453278}}], 
  Line[{{-0.9348009477166837, 0.6211835161491764}, {-0.9358597315848943, \
0.613577092391689}, {-0.7462421638484733, 1.2005567894684717}, 
    {-0.7420533023112804, 1.2152748245287444}, {-0.9348009477166837, \
0.6211835161491764}}], 
  Line[{{-0.9358597315848943, 0.613577092391689}, {-0.9375728798703992, \
0.6010618457721151}, {-0.7530198841898188, 1.1763209525760518}, 
    {-0.7462421638484733, 1.2005567894684717}, {-0.9358597315848943, \
0.613577092391689}}], 
  Line[{{-0.9375728798703992, 0.6010618457721151}, {-0.9398655197725243, \
0.5838857533279119}, {-0.7620902444332891, 1.1430205016052841}, 
    {-0.7530198841898188, 1.1763209525760518}, {-0.9375728798703992, \
0.6010618457721151}}], 
  Line[{{-0.9398655197725243, 0.5838857533279119}, {-0.9426374519262397, \
0.5624063276196118}, {-0.7730568263118276, 1.1013148858947208}, 
    {-0.7620902444332891, 1.1430205016052841}, {-0.9398655197725243, \
0.5838857533279119}}], 
  Line[{{-0.9426374519262397, 0.5624063276196118}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738434, 1.0520980143876295}, 
    {-0.7730568263118276, 1.1013148858947208}, {-0.9426374519262397, \
0.5624063276196118}}], 
  Line[{{-0.945767529595222, 0.5371028573756114}, {-0.9491189533655577, \
0.508595070176279}, {-0.7986995593545068, 0.9965396214846547}, 
    {-0.7854403375738434, 1.0520980143876295}, {-0.945767529595222, \
0.5371028573756114}}], 
  Line[{{-0.9491189533655577, 0.508595070176279}, {-0.9525452499365675, \
0.4776706018498101}, {-0.8122550000371975, 0.9361441841071272}, 
    {-0.7986995593545068, 0.9965396214846547}, {-0.9491189533655577, \
0.508595070176279}}], 
  Line[{{-0.9525452499365675, 0.4776706018498101}, {-0.9558966737069031, \
0.4453237472356564}, {-0.825514221817861, 0.8728320775698117}, 
    {-0.8122550000371975, 0.9361441841071272}, {-0.9525452499365675, \
0.4776706018498101}}], 
  Line[{{-0.9558966737069031, 0.4453237472356564}, {-0.9590267513758856, \
0.4128060526669481}, {-0.8378977330798767, 0.8090441125945331}, 
    {-0.825514221817861, 0.8728320775698117}, {-0.9558966737069031, \
0.4453237472356564}}], 
  Line[{{-0.9590267513758856, 0.4128060526669481}, {-0.961798683529601, \
0.3816816923272188}, {-0.8488643149584152, 0.747855794164011}, 
    {-0.8378977330798767, 0.8090441125945331}, {-0.9590267513758856, \
0.4128060526669481}}], 
  Line[{{-0.961798683529601, 0.3816816923272188}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018856, 0.6930472461935369}, 
    {-0.8488643149584152, 0.747855794164011}, {-0.961798683529601, \
0.3816816923272188}}], 
  Line[{{-0.964091323431726, 0.35386023041001824}, {-0.9658044717172308, \
0.33154008354139414}, {-0.864712395543231, 0.6489952411032606}, 
    {-0.8579346752018856, 0.6930472461935369}, {-0.964091323431726, \
0.35386023041001824}}], 
  Line[{{-0.9658044717172308, 0.33154008354139414}, {-0.9668632555854414, \
0.31695593148714096}, {-0.868901257080424, 0.6201700772082609}, 
    {-0.864712395543231, 0.6489952411032606}, {-0.9658044717172308, \
0.33154008354139414}}], 
  Line[{{-0.9668632555854414, 0.31695593148714096}, {-0.9672214011007084, \
0.311867536226639}, {-0.8703181864639015, 0.6101049646137003}, 
    {-0.868901257080424, 0.6201700772082609}, {-0.9668632555854414, \
0.31695593148714096}}], 
  Line[{{-0.9672214011007084, 0.311867536226639}, {-0.9668632555854415, \
0.31695593148714024}, {-0.8689012570804241, 0.6201700772082606}, 
    {-0.8703181864639015, 0.6101049646137003}, {-0.9672214011007084, \
0.311867536226639}}], 
  Line[{{-0.9668632555854415, 0.31695593148714024}, {-0.9658044717172309, \
0.33154008354139347}, {-0.8647123955432311, 0.64899524110326}, 
    {-0.8689012570804241, 0.6201700772082606}, {-0.9668632555854415, \
0.31695593148714024}}], 
  Line[{{-0.9658044717172309, 0.33154008354139347}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018857, 0.6930472461935366}, 
    {-0.8647123955432311, 0.64899524110326}, {-0.9658044717172309, \
0.33154008354139347}}], 
  Line[{{-0.964091323431726, 0.35386023041001824}, {-0.9617986835296011, \
0.38168169232721827}, {-0.8488643149584153, 0.7478557941640104}, 
    {-0.8579346752018857, 0.6930472461935366}, {-0.964091323431726, \
0.35386023041001824}}], 
  Line[{{-0.9617986835296011, 0.38168169232721827}, {-0.9590267513758856, \
0.41280605266694753}, {-0.8378977330798769, 0.8090441125945322}, 
    {-0.8488643149584153, 0.7478557941640104}, {-0.9617986835296011, \
0.38168169232721827}}], 
  Line[{{-0.9590267513758856, 0.41280605266694753}, {-0.9558966737069031, \
0.44532374723565615}, {-0.8255142218178609, 0.8728320775698117}, 
    {-0.8378977330798769, 0.8090441125945322}, {-0.9590267513758856, \
0.41280605266694753}}], 
  Line[{{-0.9558966737069031, 0.44532374723565615}, {-0.9525452499365675, \
0.47767060184980986}, {-0.8122550000371977, 0.9361441841071265}, 
    {-0.8255142218178609, 0.8728320775698117}, {-0.9558966737069031, \
0.44532374723565615}}], 
  Line[{{-0.9525452499365675, 0.47767060184980986}, {-0.9491189533655577, \
0.5085950701762788}, {-0.798699559354507, 0.9965396214846538}, 
    {-0.8122550000371977, 0.9361441841071265}, {-0.9525452499365675, \
0.47767060184980986}}], 
  Line[{{-0.9491189533655577, 0.5085950701762788}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738435, 1.0520980143876293}, 
    {-0.798699559354507, 0.9965396214846538}, {-0.9491189533655577, \
0.5085950701762788}}], 
  Line[{{-0.945767529595222, 0.5371028573756114}, {-0.9426374519262397, \
0.5624063276196116}, {-0.7730568263118276, 1.1013148858947206}, 
    {-0.7854403375738435, 1.0520980143876293}, {-0.945767529595222, \
0.5371028573756114}}], 
  Line[{{-0.9426374519262397, 0.5624063276196116}, {-0.9398655197725243, \
0.5838857533279117}, {-0.7620902444332892, 1.1430205016052835}, 
    {-0.7730568263118276, 1.1013148858947206}, {-0.9426374519262397, \
0.5624063276196116}}], 
  Line[{{-0.9398655197725243, 0.5838857533279117}, {-0.9375728798703992, \
0.6010618457721149}, {-0.7530198841898188, 1.1763209525760518}, 
    {-0.7620902444332892, 1.1430205016052835}, {-0.9398655197725243, \
0.5838857533279117}}], 
  Line[{{-0.9375728798703992, 0.6010618457721149}, {-0.9358597315848944, \
0.6135770923916888}, {-0.7462421638484733, 1.2005567894684717}, 
    {-0.7530198841898188, 1.1763209525760518}, {-0.9375728798703992, \
0.6010618457721149}}], 
  Line[{{-0.9358597315848944, 0.6135770923916888}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112803, 1.2152748245287444}, 
    {-0.7462421638484733, 1.2005567894684717}, {-0.9358597315848944, \
0.6135770923916888}}], 
  Line[{{-0.9348009477166837, 0.6211835161491764}, {-0.9344428022014168, \
0.623735072453278}, {-0.7406363729278029, 1.2202099292274005}, 
    {-0.7420533023112803, 1.2152748245287444}, {-0.9348009477166837, \
0.6211835161491764}}], 
  Line[{{-0.7406363729278029, 1.2202099292274005}, {-0.7420533023112804, \
1.2152748245287444}, {-0.4301810607938247, 1.7563683493937294}, 
    {-0.42705098312484224, 1.7633557568774194}, {-0.7406363729278029, \
1.2202099292274005}}], 
  Line[{{-0.7420533023112804, 1.2152748245287444}, {-0.7462421638484733, \
1.2005567894684717}, {-0.43943449438685805, 1.7355139912456732}, 
    {-0.4301810607938247, 1.7563683493937294}, {-0.7420533023112804, \
1.2152748245287444}}], 
  Line[{{-0.7462421638484733, 1.2005567894684717}, {-0.7530198841898188, \
1.1763209525760518}, {-0.45440686445302647, 1.7011229525643672}, 
    {-0.43943449438685805, 1.7355139912456732}, {-0.7462421638484733, \
1.2005567894684717}}], 
  Line[{{-0.7530198841898188, 1.1763209525760518}, {-0.7620902444332892, \
1.143020501605284}, {-0.4744438065750352, 1.653768235803273}, 
    {-0.45440686445302647, 1.7011229525643672}, {-0.7530198841898188, \
1.1763209525760518}}], 
  Line[{{-0.7620902444332892, 1.143020501605284}, {-0.7730568263118275, \
1.1013148858947208}, {-0.49866961023423695, 1.5943005668830774}, 
    {-0.4744438065750352, 1.653768235803273}, {-0.7620902444332892, \
1.143020501605284}}], 
  Line[{{-0.7730568263118275, 1.1013148858947208}, {-0.7854403375738435, \
1.0520980143876293}, {-0.5260254915624212, 1.523900157708533}, 
    {-0.49866961023423695, 1.5943005668830774}, {-0.7730568263118275, \
1.1013148858947208}}], 
  Line[{{-0.7854403375738435, 1.0520980143876293}, {-0.7986995593545068, \
0.9965396214846545}, {-0.5553158672774633, 1.444148941758488}, 
    {-0.5260254915624212, 1.523900157708533}, {-0.7854403375738435, \
1.0520980143876293}}], 
  Line[{{-0.7986995593545068, 0.9965396214846545}, {-0.8122550000371975, \
0.9361441841071271}, {-0.5852606074097999, 1.3571288512592452}, 
    {-0.5553158672774633, 1.444148941758488}, {-0.7986995593545068, \
0.9965396214846545}}], 
  Line[{{-0.8122550000371975, 0.9361441841071271}, {-0.8255142218178609, \
0.8728320775698118}, {-0.6145509831248422, 1.2655525104241707}, 
    {-0.5852606074097999, 1.3571288512592452}, {-0.8122550000371975, \
0.9361441841071271}}], 
  Line[{{-0.8255142218178609, 0.8728320775698118}, {-0.8378977330798768, \
0.8090441125945328}, {-0.6419068644530264, 1.1729281630054869}, 
    {-0.6145509831248422, 1.2655525104241707}, {-0.8255142218178609, \
0.8728320775698118}}], 
  Line[{{-0.8378977330798768, 0.8090441125945328}, {-0.8488643149584152, \
0.7478557941640108}, {-0.6661326681122282, 1.0837396094369778}, 
    {-0.6419068644530264, 1.1729281630054869}, {-0.8378977330798768, \
0.8090441125945328}}], 
  Line[{{-0.8488643149584152, 0.7478557941640108}, {-0.8579346752018857, \
0.6930472461935369}, {-0.686169610234237, 1.0035621274868154}, 
    {-0.6661326681122282, 1.0837396094369778}, {-0.8488643149584152, \
0.7478557941640108}}], 
  Line[{{-0.8579346752018857, 0.6930472461935369}, {-0.864712395543231, \
0.6489952411032603}, {-0.7011419803004051, 0.9389137397717197}, 
    {-0.686169610234237, 1.0035621274868154}, {-0.8579346752018857, \
0.6930472461935369}}], 
  Line[{{-0.864712395543231, 0.6489952411032603}, {-0.868901257080424, \
0.6201700772082609}, {-0.7103954138934387, 0.8965062230902947}, 
    {-0.7011419803004051, 0.9389137397717197}, {-0.864712395543231, \
0.6489952411032603}}], 
  Line[{{-0.868901257080424, 0.6201700772082609}, {-0.8703181864639015, \
0.6101049646137003}, {-0.7135254915624211, 0.8816778784387097}, 
    {-0.7103954138934387, 0.8965062230902947}, {-0.868901257080424, \
0.6201700772082609}}], 
  Line[{{-0.8703181864639015, 0.6101049646137003}, {-0.8689012570804241, \
0.6201700772082606}, {-0.7103954138934387, 0.8965062230902947}, 
    {-0.7135254915624211, 0.8816778784387097}, {-0.8703181864639015, \
0.6101049646137003}}], 
  Line[{{-0.8689012570804241, 0.6201700772082606}, {-0.864712395543231, \
0.6489952411032603}, {-0.7011419803004052, 0.9389137397717193}, 
    {-0.7103954138934387, 0.8965062230902947}, {-0.8689012570804241, \
0.6201700772082606}}], 
  Line[{{-0.864712395543231, 0.6489952411032603}, {-0.8579346752018857, \
0.6930472461935366}, {-0.686169610234237, 1.0035621274868152}, 
    {-0.7011419803004052, 0.9389137397717193}, {-0.864712395543231, \
0.6489952411032603}}], 
  Line[{{-0.8579346752018857, 0.6930472461935366}, {-0.8488643149584152, \
0.7478557941640107}, {-0.6661326681122282, 1.0837396094369778}, 
    {-0.686169610234237, 1.0035621274868152}, {-0.8579346752018857, \
0.6930472461935366}}], 
  Line[{{-0.8488643149584152, 0.7478557941640107}, {-0.8378977330798769, \
0.8090441125945326}, {-0.6419068644530265, 1.1729281630054864}, 
    {-0.6661326681122282, 1.0837396094369778}, {-0.8488643149584152, \
0.7478557941640107}}], 
  Line[{{-0.8378977330798769, 0.8090441125945326}, {-0.8255142218178609, \
0.8728320775698117}, {-0.6145509831248422, 1.2655525104241705}, 
    {-0.6419068644530265, 1.1729281630054864}, {-0.8378977330798769, \
0.8090441125945326}}], 
  Line[{{-0.8255142218178609, 0.8728320775698117}, {-0.8122550000371976, \
0.9361441841071267}, {-0.5852606074098001, 1.357128851259245}, 
    {-0.6145509831248422, 1.2655525104241705}, {-0.8255142218178609, \
0.8728320775698117}}], 
  Line[{{-0.8122550000371976, 0.9361441841071267}, {-0.7986995593545069, \
0.9965396214846542}, {-0.5553158672774634, 1.4441489417584878}, 
    {-0.5852606074098001, 1.357128851259245}, {-0.8122550000371976, \
0.9361441841071267}}], 
  Line[{{-0.7986995593545069, 0.9965396214846542}, {-0.7854403375738435, \
1.0520980143876293}, {-0.5260254915624212, 1.523900157708533}, 
    {-0.5553158672774634, 1.4441489417584878}, {-0.7986995593545069, \
0.9965396214846542}}], 
  Line[{{-0.7854403375738435, 1.0520980143876293}, {-0.7730568263118276, \
1.1013148858947206}, {-0.4986696102342371, 1.594300566883077}, 
    {-0.5260254915624212, 1.523900157708533}, {-0.7854403375738435, \
1.0520980143876293}}], 
  Line[{{-0.7730568263118276, 1.1013148858947206}, {-0.7620902444332892, \
1.1430205016052837}, {-0.47444380657503515, 1.653768235803273}, 
    {-0.4986696102342371, 1.594300566883077}, {-0.7730568263118276, \
1.1013148858947206}}], 
  Line[{{-0.7620902444332892, 1.1430205016052837}, {-0.7530198841898188, \
1.1763209525760518}, {-0.45440686445302647, 1.7011229525643672}, 
    {-0.47444380657503515, 1.653768235803273}, {-0.7620902444332892, \
1.1430205016052837}}], 
  Line[{{-0.7530198841898188, 1.1763209525760518}, {-0.7462421638484733, \
1.2005567894684717}, {-0.4394344943868581, 1.735513991245673}, 
    {-0.45440686445302647, 1.7011229525643672}, {-0.7530198841898188, \
1.1763209525760518}}], 
  Line[{{-0.7462421638484733, 1.2005567894684717}, {-0.7420533023112804, \
1.2152748245287444}, {-0.4301810607938247, 1.7563683493937294}, 
    {-0.4394344943868581, 1.735513991245673}, {-0.7462421638484733, \
1.2005567894684717}}], 
  Line[{{-0.7420533023112804, 1.2152748245287444}, {-0.7406363729278029, \
1.2202099292274005}, {-0.42705098312484224, 1.7633557568774194}, 
    {-0.4301810607938247, 1.7563683493937294}, {-0.7420533023112804, \
1.2152748245287444}}], 
  Line[{{-0.7406363729278029, 1.2202099292274005}, {-0.7420533023112804, \
1.2152748245287444}, {-0.43018106079382457, 1.7563683493937297}, 
    {-0.42705098312484224, 1.7633557568774194}, {-0.7406363729278029, \
1.2202099292274005}}], 
  Line[{{-0.7420533023112804, 1.2152748245287444}, {-0.7462421638484733, \
1.2005567894684717}, {-0.4394344943868581, 1.7355139912456732}, 
    {-0.43018106079382457, 1.7563683493937297}, {-0.7420533023112804, \
1.2152748245287444}}], 
  Line[{{-0.7462421638484733, 1.2005567894684717}, {-0.7530198841898188, \
1.1763209525760518}, {-0.45440686445302636, 1.7011229525643672}, 
    {-0.4394344943868581, 1.7355139912456732}, {-0.7462421638484733, \
1.2005567894684717}}], 
  Line[{{-0.7530198841898188, 1.1763209525760518}, {-0.7620902444332891, \
1.1430205016052841}, {-0.47444380657503504, 1.6537682358032735}, 
    {-0.45440686445302636, 1.7011229525643672}, {-0.7530198841898188, \
1.1763209525760518}}], 
  Line[{{-0.7620902444332891, 1.1430205016052841}, {-0.7730568263118276, \
1.1013148858947208}, {-0.4986696102342368, 1.5943005668830776}, 
    {-0.47444380657503504, 1.6537682358032735}, {-0.7620902444332891, \
1.1430205016052841}}], 
  Line[{{-0.7730568263118276, 1.1013148858947208}, {-0.7854403375738434, \
1.0520980143876295}, {-0.526025491562421, 1.5239001577085334}, 
    {-0.4986696102342368, 1.5943005668830776}, {-0.7730568263118276, \
1.1013148858947208}}], 
  Line[{{-0.7854403375738434, 1.0520980143876295}, {-0.7986995593545068, \
0.9965396214846547}, {-0.5553158672774632, 1.4441489417584885}, 
    {-0.526025491562421, 1.5239001577085334}, {-0.7854403375738434, \
1.0520980143876295}}], 
  Line[{{-0.7986995593545068, 0.9965396214846547}, {-0.8122550000371975, \
0.9361441841071272}, {-0.5852606074097999, 1.3571288512592454}, 
    {-0.5553158672774632, 1.4441489417584885}, {-0.7986995593545068, \
0.9965396214846547}}], 
  Line[{{-0.8122550000371975, 0.9361441841071272}, {-0.825514221817861, \
0.8728320775698117}, {-0.6145509831248421, 1.265552510424171}, 
    {-0.5852606074097999, 1.3571288512592454}, {-0.8122550000371975, \
0.9361441841071272}}], 
  Line[{{-0.825514221817861, 0.8728320775698117}, {-0.8378977330798767, \
0.8090441125945331}, {-0.6419068644530262, 1.1729281630054873}, 
    {-0.6145509831248421, 1.265552510424171}, {-0.825514221817861, \
0.8728320775698117}}], 
  Line[{{-0.8378977330798767, 0.8090441125945331}, {-0.8488643149584152, \
0.747855794164011}, {-0.6661326681122279, 1.0837396094369784}, 
    {-0.6419068644530262, 1.1729281630054873}, {-0.8378977330798767, \
0.8090441125945331}}], 
  Line[{{-0.8488643149584152, 0.747855794164011}, {-0.8579346752018856, \
0.6930472461935369}, {-0.6861696102342368, 1.0035621274868156}, 
    {-0.6661326681122279, 1.0837396094369784}, {-0.8488643149584152, \
0.747855794164011}}], 
  Line[{{-0.8579346752018856, 0.6930472461935369}, {-0.864712395543231, \
0.6489952411032606}, {-0.7011419803004051, 0.9389137397717197}, 
    {-0.6861696102342368, 1.0035621274868156}, {-0.8579346752018856, \
0.6930472461935369}}], 
  Line[{{-0.864712395543231, 0.6489952411032606}, {-0.868901257080424, \
0.6201700772082609}, {-0.7103954138934386, 0.8965062230902949}, 
    {-0.7011419803004051, 0.9389137397717197}, {-0.864712395543231, \
0.6489952411032606}}], 
  Line[{{-0.868901257080424, 0.6201700772082609}, {-0.8703181864639015, \
0.6101049646137003}, {-0.7135254915624211, 0.8816778784387097}, 
    {-0.7103954138934386, 0.8965062230902949}, {-0.868901257080424, \
0.6201700772082609}}], 
  Line[{{-0.8703181864639015, 0.6101049646137003}, {-0.8689012570804241, \
0.6201700772082606}, {-0.7103954138934387, 0.8965062230902945}, 
    {-0.7135254915624211, 0.8816778784387097}, {-0.8703181864639015, \
0.6101049646137003}}], 
  Line[{{-0.8689012570804241, 0.6201700772082606}, {-0.8647123955432311, \
0.64899524110326}, {-0.7011419803004053, 0.938913739771719}, 
    {-0.7103954138934387, 0.8965062230902945}, {-0.8689012570804241, \
0.6201700772082606}}], 
  Line[{{-0.8647123955432311, 0.64899524110326}, {-0.8579346752018857, \
0.6930472461935366}, {-0.686169610234237, 1.0035621274868152}, 
    {-0.7011419803004053, 0.938913739771719}, {-0.8647123955432311, \
0.64899524110326}}], 
  Line[{{-0.8579346752018857, 0.6930472461935366}, {-0.8488643149584153, \
0.7478557941640104}, {-0.6661326681122283, 1.0837396094369776}, 
    {-0.686169610234237, 1.0035621274868152}, {-0.8579346752018857, \
0.6930472461935366}}], 
  Line[{{-0.8488643149584153, 0.7478557941640104}, {-0.8378977330798769, \
0.8090441125945322}, {-0.6419068644530266, 1.172928163005486}, 
    {-0.6661326681122283, 1.0837396094369776}, {-0.8488643149584153, \
0.7478557941640104}}], 
  Line[{{-0.8378977330798769, 0.8090441125945322}, {-0.8255142218178609, \
0.8728320775698117}, {-0.6145509831248424, 1.2655525104241703}, 
    {-0.6419068644530266, 1.172928163005486}, {-0.8378977330798769, \
0.8090441125945322}}], 
  Line[{{-0.8255142218178609, 0.8728320775698117}, {-0.8122550000371977, \
0.9361441841071265}, {-0.5852606074098001, 1.357128851259245}, 
    {-0.6145509831248424, 1.2655525104241703}, {-0.8255142218178609, \
0.8728320775698117}}], 
  Line[{{-0.8122550000371977, 0.9361441841071265}, {-0.798699559354507, \
0.9965396214846538}, {-0.5553158672774636, 1.4441489417584874}, 
    {-0.5852606074098001, 1.357128851259245}, {-0.8122550000371977, \
0.9361441841071265}}], 
  Line[{{-0.798699559354507, 0.9965396214846538}, {-0.7854403375738435, \
1.0520980143876293}, {-0.5260254915624211, 1.5239001577085332}, 
    {-0.5553158672774636, 1.4441489417584874}, {-0.798699559354507, \
0.9965396214846538}}], 
  Line[{{-0.7854403375738435, 1.0520980143876293}, {-0.7730568263118276, \
1.1013148858947206}, {-0.49866961023423706, 1.594300566883077}, 
    {-0.5260254915624211, 1.5239001577085332}, {-0.7854403375738435, \
1.0520980143876293}}], 
  Line[{{-0.7730568263118276, 1.1013148858947206}, {-0.7620902444332892, \
1.1430205016052835}, {-0.4744438065750353, 1.6537682358032726}, 
    {-0.49866961023423706, 1.594300566883077}, {-0.7730568263118276, \
1.1013148858947206}}], 
  Line[{{-0.7620902444332892, 1.1430205016052835}, {-0.7530198841898188, \
1.1763209525760518}, {-0.4544068644530264, 1.7011229525643672}, 
    {-0.4744438065750353, 1.6537682358032726}, {-0.7620902444332892, \
1.1430205016052835}}], 
  Line[{{-0.7530198841898188, 1.1763209525760518}, {-0.7462421638484733, \
1.2005567894684717}, {-0.4394344943868581, 1.735513991245673}, 
    {-0.4544068644530264, 1.7011229525643672}, {-0.7530198841898188, \
1.1763209525760518}}], 
  Line[{{-0.7462421638484733, 1.2005567894684717}, {-0.7420533023112803, \
1.2152748245287444}, {-0.4301810607938246, 1.7563683493937294}, 
    {-0.4394344943868581, 1.735513991245673}, {-0.7462421638484733, \
1.2005567894684717}}], 
  Line[{{-0.7420533023112803, 1.2152748245287444}, {-0.7406363729278029, \
1.2202099292274005}, {-0.42705098312484224, 1.7633557568774194}, 
    {-0.4301810607938246, 1.7563683493937294}, {-0.7420533023112803, \
1.2152748245287444}}], 
  Line[{{-0.42705098312484224, 1.7633557568774194}, {-0.4301810607938247, \
1.7563683493937294}, {-0.012814536647682145, 2.2208803408437956}, 
    {-0.007391819076574713, 2.2294344764321825}, {-0.42705098312484224, \
1.7633557568774194}}], 
  Line[{{-0.4301810607938247, 1.7563683493937294}, {-0.43943449438685805, \
1.7355139912456732}, {-0.028845690582060914, 2.195318553032826}, 
    {-0.012814536647682145, 2.2208803408437956}, {-0.4301810607938247, \
1.7563683493937294}}], 
  Line[{{-0.43943449438685805, 1.7355139912456732}, {-0.45440686445302647, \
1.7011229525643672}, {-0.05478464252676769, 2.1530633066599703}, 
    {-0.028845690582060914, 2.195318553032826}, {-0.43943449438685805, \
1.7355139912456732}}], 
  Line[{{-0.45440686445302647, 1.7011229525643672}, {-0.4744438065750352, \
1.653768235803273}, {-0.08949773581291746, 2.0946793219544757}, 
    {-0.05478464252676769, 2.1530633066599703}, {-0.45440686445302647, \
1.7011229525643672}}], 
  Line[{{-0.4744438065750352, 1.653768235803273}, {-0.49866961023423695, \
1.5943005668830774}, {-0.1314678416920028, 2.0210434859217035}, 
    {-0.08949773581291746, 2.0946793219544757}, {-0.4744438065750352, \
1.653768235803273}}], 
  Line[{{-0.49866961023423695, 1.5943005668830774}, {-0.5260254915624212, \
1.523900157708533}, {-0.17886066514219576, 1.933432094411191}, 
    {-0.1314678416920028, 2.0210434859217035}, {-0.49866961023423695, \
1.5943005668830774}}], 
  Line[{{-0.5260254915624212, 1.523900157708533}, {-0.5553158672774633, \
1.444148941758488}, {-0.2296049123627243, 1.833636456582809}, 
    {-0.17886066514219576, 1.933432094411191}, {-0.5260254915624212, \
1.523900157708533}}], 
  Line[{{-0.5553158672774633, 1.444148941758488}, {-0.5852606074097999, \
1.3571288512592452}, {-0.28148281625213767, 1.7241122839361493}, 
    {-0.2296049123627243, 1.833636456582809}, {-0.5553158672774633, \
1.444148941758488}}], 
  Line[{{-0.5852606074097999, 1.3571288512592452}, {-0.6145509831248422, \
1.2655525104241707}, {-0.3322270634726663, 1.6081701375219566}, 
    {-0.28148281625213767, 1.7241122839361493}, {-0.5852606074097999, \
1.3571288512592452}}], 
  Line[{{-0.6145509831248422, 1.2655525104241707}, {-0.6419068644530264, \
1.1729281630054869}, {-0.3796198869228592, 1.490209713504239}, 
    {-0.3322270634726663, 1.6081701375219566}, {-0.6145509831248422, \
1.2655525104241707}}], 
  Line[{{-0.6419068644530264, 1.1729281630054869}, {-0.6661326681122282, \
1.0837396094369778}, {-0.4215899928019446, 1.3759750672106554}, 
    {-0.3796198869228592, 1.490209713504239}, {-0.6419068644530264, \
1.1729281630054869}}], 
  Line[{{-0.6661326681122282, 1.0837396094369778}, {-0.686169610234237, \
1.0035621274868154}, {-0.45630308608809433, 1.2727298803122147}, 
    {-0.4215899928019446, 1.3759750672106554}, {-0.6661326681122282, \
1.0837396094369778}}], 
  Line[{{-0.686169610234237, 1.0035621274868154}, {-0.7011419803004051, \
0.9389137397717197}, {-0.482242038032801, 1.189085281951672}, 
    {-0.45630308608809433, 1.2727298803122147}, {-0.686169610234237, \
1.0035621274868154}}], 
  Line[{{-0.7011419803004051, 0.9389137397717197}, {-0.7103954138934387, \
0.8965062230902947}, {-0.4982731919671799, 1.1340136417284856}, 
    {-0.482242038032801, 1.189085281951672}, {-0.7011419803004051, \
0.9389137397717197}}], 
  Line[{{-0.7103954138934387, 0.8965062230902947}, {-0.7135254915624211, \
0.8816778784387097}, {-0.5036959095382874, 1.1147172382160913}, 
    {-0.4982731919671799, 1.1340136417284856}, {-0.7103954138934387, \
0.8965062230902947}}], 
  Line[{{-0.7135254915624211, 0.8816778784387097}, {-0.7103954138934387, \
0.8965062230902947}, {-0.49827319196717995, 1.1340136417284856}, 
    {-0.5036959095382874, 1.1147172382160913}, {-0.7135254915624211, \
0.8816778784387097}}], 
  Line[{{-0.7103954138934387, 0.8965062230902947}, {-0.7011419803004052, \
0.9389137397717193}, {-0.482242038032801, 1.1890852819516717}, 
    {-0.49827319196717995, 1.1340136417284856}, {-0.7103954138934387, \
0.8965062230902947}}], 
  Line[{{-0.7011419803004052, 0.9389137397717193}, {-0.686169610234237, \
1.0035621274868152}, {-0.4563030860880944, 1.2727298803122145}, 
    {-0.482242038032801, 1.1890852819516717}, {-0.7011419803004052, \
0.9389137397717193}}], 
  Line[{{-0.686169610234237, 1.0035621274868152}, {-0.6661326681122282, \
1.0837396094369778}, {-0.42158999280194476, 1.375975067210655}, 
    {-0.4563030860880944, 1.2727298803122145}, {-0.686169610234237, \
1.0035621274868152}}], 
  Line[{{-0.6661326681122282, 1.0837396094369778}, {-0.6419068644530265, \
1.1729281630054864}, {-0.3796198869228593, 1.4902097135042385}, 
    {-0.42158999280194476, 1.375975067210655}, {-0.6661326681122282, \
1.0837396094369778}}], 
  Line[{{-0.6419068644530265, 1.1729281630054864}, {-0.6145509831248422, \
1.2655525104241705}, {-0.3322270634726663, 1.6081701375219564}, 
    {-0.3796198869228593, 1.4902097135042385}, {-0.6419068644530265, \
1.1729281630054864}}], 
  Line[{{-0.6145509831248422, 1.2655525104241705}, {-0.5852606074098001, \
1.357128851259245}, {-0.2814828162521379, 1.724112283936149}, 
    {-0.3322270634726663, 1.6081701375219564}, {-0.6145509831248422, \
1.2655525104241705}}], 
  Line[{{-0.5852606074098001, 1.357128851259245}, {-0.5553158672774634, \
1.4441489417584878}, {-0.22960491236272457, 1.8336364565828085}, 
    {-0.2814828162521379, 1.724112283936149}, {-0.5852606074098001, \
1.357128851259245}}], 
  Line[{{-0.5553158672774634, 1.4441489417584878}, {-0.5260254915624212, \
1.523900157708533}, {-0.1788606651421958, 1.933432094411191}, 
    {-0.22960491236272457, 1.8336364565828085}, {-0.5553158672774634, \
1.4441489417584878}}], 
  Line[{{-0.5260254915624212, 1.523900157708533}, {-0.4986696102342371, \
1.594300566883077}, {-0.13146784169200298, 2.021043485921703}, 
    {-0.1788606651421958, 1.933432094411191}, {-0.5260254915624212, \
1.523900157708533}}], 
  Line[{{-0.4986696102342371, 1.594300566883077}, {-0.47444380657503515, \
1.653768235803273}, {-0.0894977358129174, 2.0946793219544757}, 
    {-0.13146784169200298, 2.021043485921703}, {-0.4986696102342371, \
1.594300566883077}}], 
  Line[{{-0.47444380657503515, 1.653768235803273}, {-0.45440686445302647, \
1.7011229525643672}, {-0.05478464252676767, 2.1530633066599703}, 
    {-0.0894977358129174, 2.0946793219544757}, {-0.47444380657503515, \
1.653768235803273}}], 
  Line[{{-0.45440686445302647, 1.7011229525643672}, {-0.4394344943868581, \
1.735513991245673}, {-0.02884569058206097, 2.1953185530328256}, 
    {-0.05478464252676767, 2.1530633066599703}, {-0.45440686445302647, \
1.7011229525643672}}], 
  Line[{{-0.4394344943868581, 1.735513991245673}, {-0.4301810607938247, \
1.7563683493937294}, {-0.012814536647682125, 2.2208803408437956}, 
    {-0.02884569058206097, 2.1953185530328256}, {-0.4394344943868581, \
1.735513991245673}}], 
  Line[{{-0.4301810607938247, 1.7563683493937294}, {-0.42705098312484224, \
1.7633557568774194}, {-0.007391819076574713, 2.2294344764321825}, 
    {-0.012814536647682125, 2.2208803408437956}, {-0.4301810607938247, \
1.7563683493937294}}], 
  Line[{{-0.42705098312484224, 1.7633557568774194}, {-0.43018106079382457, \
1.7563683493937297}, {-0.012814536647682062, 2.2208803408437956}, 
    {-0.007391819076574713, 2.2294344764321825}, {-0.42705098312484224, \
1.7633557568774194}}], 
  Line[{{-0.43018106079382457, 1.7563683493937297}, {-0.4394344943868581, \
1.7355139912456732}, {-0.02884569058206095, 2.195318553032826}, 
    {-0.012814536647682062, 2.2208803408437956}, {-0.43018106079382457, \
1.7563683493937297}}], 
  Line[{{-0.4394344943868581, 1.7355139912456732}, {-0.45440686445302636, \
1.7011229525643672}, {-0.0547846425267676, 2.1530633066599703}, 
    {-0.02884569058206095, 2.195318553032826}, {-0.4394344943868581, \
1.7355139912456732}}], 
  Line[{{-0.45440686445302636, 1.7011229525643672}, {-0.47444380657503504, \
1.6537682358032735}, {-0.08949773581291712, 2.094679321954476}, 
    {-0.0547846425267676, 2.1530633066599703}, {-0.45440686445302636, \
1.7011229525643672}}], 
  Line[{{-0.47444380657503504, 1.6537682358032735}, {-0.4986696102342368, \
1.5943005668830776}, {-0.13146784169200265, 2.0210434859217035}, 
    {-0.08949773581291712, 2.094679321954476}, {-0.47444380657503504, \
1.6537682358032735}}], 
  Line[{{-0.4986696102342368, 1.5943005668830776}, {-0.526025491562421, \
1.5239001577085334}, {-0.17886066514219567, 1.9334320944111911}, 
    {-0.13146784169200265, 2.0210434859217035}, {-0.4986696102342368, \
1.5943005668830776}}], 
  Line[{{-0.526025491562421, 1.5239001577085334}, {-0.5553158672774632, \
1.4441489417584885}, {-0.2296049123627241, 1.8336364565828094}, 
    {-0.17886066514219567, 1.9334320944111911}, {-0.526025491562421, \
1.5239001577085334}}], 
  Line[{{-0.5553158672774632, 1.4441489417584885}, {-0.5852606074097999, \
1.3571288512592454}, {-0.2814828162521375, 1.7241122839361496}, 
    {-0.2296049123627241, 1.8336364565828094}, {-0.5553158672774632, \
1.4441489417584885}}], 
  Line[{{-0.5852606074097999, 1.3571288512592454}, {-0.6145509831248421, \
1.265552510424171}, {-0.33222706347266606, 1.6081701375219568}, 
    {-0.2814828162521375, 1.7241122839361496}, {-0.5852606074097999, \
1.3571288512592454}}], 
  Line[{{-0.6145509831248421, 1.265552510424171}, {-0.6419068644530262, \
1.1729281630054873}, {-0.379619886922859, 1.4902097135042394}, 
    {-0.33222706347266606, 1.6081701375219568}, {-0.6145509831248421, \
1.265552510424171}}], 
  Line[{{-0.6419068644530262, 1.1729281630054873}, {-0.6661326681122279, \
1.0837396094369784}, {-0.4215899928019444, 1.3759750672106559}, 
    {-0.379619886922859, 1.4902097135042394}, {-0.6419068644530262, \
1.1729281630054873}}], 
  Line[{{-0.6661326681122279, 1.0837396094369784}, {-0.6861696102342368, \
1.0035621274868156}, {-0.45630308608809433, 1.2727298803122147}, 
    {-0.4215899928019444, 1.3759750672106559}, {-0.6661326681122279, \
1.0837396094369784}}], 
  Line[{{-0.6861696102342368, 1.0035621274868156}, {-0.7011419803004051, \
0.9389137397717197}, {-0.4822420380328009, 1.1890852819516722}, 
    {-0.45630308608809433, 1.2727298803122147}, {-0.6861696102342368, \
1.0035621274868156}}], 
  Line[{{-0.7011419803004051, 0.9389137397717197}, {-0.7103954138934386, \
0.8965062230902949}, {-0.4982731919671798, 1.1340136417284858}, 
    {-0.4822420380328009, 1.1890852819516722}, {-0.7011419803004051, \
0.9389137397717197}}], 
  Line[{{-0.7103954138934386, 0.8965062230902949}, {-0.7135254915624211, \
0.8816778784387097}, {-0.5036959095382874, 1.1147172382160913}, 
    {-0.4982731919671798, 1.1340136417284858}, {-0.7103954138934386, \
0.8965062230902949}}], 
  Line[{{-0.7135254915624211, 0.8816778784387097}, {-0.7103954138934387, \
0.8965062230902945}, {-0.49827319196717995, 1.1340136417284854}, 
    {-0.5036959095382874, 1.1147172382160913}, {-0.7135254915624211, \
0.8816778784387097}}], 
  Line[{{-0.7103954138934387, 0.8965062230902945}, {-0.7011419803004053, \
0.938913739771719}, {-0.48224203803280125, 1.1890852819516713}, 
    {-0.49827319196717995, 1.1340136417284854}, {-0.7103954138934387, \
0.8965062230902945}}], 
  Line[{{-0.7011419803004053, 0.938913739771719}, {-0.686169610234237, \
1.0035621274868152}, {-0.4563030860880944, 1.2727298803122145}, 
    {-0.48224203803280125, 1.1890852819516713}, {-0.7011419803004053, \
0.938913739771719}}], 
  Line[{{-0.686169610234237, 1.0035621274868152}, {-0.6661326681122283, \
1.0837396094369776}, {-0.42158999280194487, 1.3759750672106545}, 
    {-0.4563030860880944, 1.2727298803122145}, {-0.686169610234237, \
1.0035621274868152}}], 
  Line[{{-0.6661326681122283, 1.0837396094369776}, {-0.6419068644530266, \
1.172928163005486}, {-0.3796198869228595, 1.490209713504238}, 
    {-0.42158999280194487, 1.3759750672106545}, {-0.6661326681122283, \
1.0837396094369776}}], 
  Line[{{-0.6419068644530266, 1.172928163005486}, {-0.6145509831248424, \
1.2655525104241703}, {-0.3322270634726664, 1.6081701375219564}, 
    {-0.3796198869228595, 1.490209713504238}, {-0.6419068644530266, \
1.172928163005486}}], 
  Line[{{-0.6145509831248424, 1.2655525104241703}, {-0.5852606074098001, \
1.357128851259245}, {-0.28148281625213795, 1.7241122839361487}, 
    {-0.3322270634726664, 1.6081701375219564}, {-0.6145509831248424, \
1.2655525104241703}}], 
  Line[{{-0.5852606074098001, 1.357128851259245}, {-0.5553158672774636, \
1.4441489417584874}, {-0.22960491236272482, 1.833636456582808}, 
    {-0.28148281625213795, 1.7241122839361487}, {-0.5852606074098001, \
1.357128851259245}}], 
  Line[{{-0.5553158672774636, 1.4441489417584874}, {-0.5260254915624211, \
1.5239001577085332}, {-0.17886066514219578, 1.933432094411191}, 
    {-0.22960491236272482, 1.833636456582808}, {-0.5553158672774636, \
1.4441489417584874}}], 
  Line[{{-0.5260254915624211, 1.5239001577085332}, {-0.49866961023423706, \
1.594300566883077}, {-0.13146784169200307, 2.021043485921703}, 
    {-0.17886066514219578, 1.933432094411191}, {-0.5260254915624211, \
1.5239001577085332}}], 
  Line[{{-0.49866961023423706, 1.594300566883077}, {-0.4744438065750353, \
1.6537682358032726}, {-0.0894977358129177, 2.0946793219544753}, 
    {-0.13146784169200307, 2.021043485921703}, {-0.49866961023423706, \
1.594300566883077}}], 
  Line[{{-0.4744438065750353, 1.6537682358032726}, {-0.4544068644530264, \
1.7011229525643672}, {-0.054784642526767645, 2.1530633066599703}, 
    {-0.0894977358129177, 2.0946793219544753}, {-0.4744438065750353, \
1.6537682358032726}}], 
  Line[{{-0.4544068644530264, 1.7011229525643672}, {-0.4394344943868581, \
1.735513991245673}, {-0.02884569058206095, 2.1953185530328256}, 
    {-0.054784642526767645, 2.1530633066599703}, {-0.4544068644530264, \
1.7011229525643672}}], 
  Line[{{-0.4394344943868581, 1.735513991245673}, {-0.4301810607938246, \
1.7563683493937294}, {-0.012814536647682086, 2.2208803408437956}, 
    {-0.02884569058206095, 2.1953185530328256}, {-0.4394344943868581, \
1.735513991245673}}], 
  Line[{{-0.4301810607938246, 1.7563683493937294}, {-0.42705098312484224, \
1.7633557568774194}, {-0.007391819076574713, 2.2294344764321825}, 
    {-0.012814536647682086, 2.2208803408437956}, {-0.4301810607938246, \
1.7563683493937294}}], 
  Line[{{-0.007391819076574713, 2.2294344764321825}, {-0.012814536647682145, \
2.2208803408437956}, {0.4918053502751766, 2.588583579753018}, 
    {0.49999999999999967, 2.5980762113533156}, {-0.007391819076574713, \
2.2294344764321825}}], 
  Line[{{-0.012814536647682145, 2.2208803408437956}, {-0.028845690582060914, \
2.195318553032826}, {0.4675795466159753, 2.5601613609103286}, 
    {0.4918053502751766, 2.588583579753018}, {-0.012814536647682145, \
2.2208803408437956}}], 
  Line[{{-0.028845690582060914, 2.195318553032826}, {-0.05478464252676769, \
2.1530633066599703}, {0.42838137289060485, 2.512998012254406}, 
    {0.4675795466159753, 2.5601613609103286}, {-0.028845690582060914, \
2.195318553032826}}], 
  Line[{{-0.05478464252676769, 2.1530633066599703}, {-0.08949773581291746, \
2.0946793219544757}, {0.3759239773845714, 2.4474780907945557}, 
    {0.42838137289060485, 2.512998012254406}, {-0.05478464252676769, \
2.1530633066599703}}], 
  Line[{{-0.08949773581291746, 2.0946793219544757}, {-0.1314678416920028, \
2.0210434859217035}, {0.31249999999999983, 2.364285039922217}, 
    {0.3759239773845714, 2.4474780907945557}, {-0.08949773581291746, \
2.0946793219544757}}], 
  Line[{{-0.1314678416920028, 2.0210434859217035}, {-0.17886066514219576, \
1.933432094411191}, {0.24088137289060504, 2.2645409632922457}, 
    {0.31249999999999983, 2.364285039922217}, {-0.1314678416920028, \
2.0210434859217035}}], 
  Line[{{-0.17886066514219576, 1.933432094411191}, {-0.2296049123627243, \
1.833636456582809}, {0.16419817372536988, 2.1499828315181597}, 
    {0.24088137289060504, 2.2645409632922457}, {-0.17886066514219576, \
1.933432094411191}}], 
  Line[{{-0.2296049123627243, 1.833636456582809}, {-0.28148281625213767, \
1.7241122839361493}, {0.08580182627462962, 2.0231783980979894}, 
    {0.16419817372536988, 2.1499828315181597}, {-0.2296049123627243, \
1.833636456582809}}], 
  Line[{{-0.28148281625213767, 1.7241122839361493}, {-0.3322270634726663, \
1.6081701375219566}, {0.009118627109394484, 1.8877889819588953}, 
    {0.08580182627462962, 2.0231783980979894}, {-0.28148281625213767, \
1.7241122839361493}}], 
  Line[{{-0.3322270634726663, 1.6081701375219566}, {-0.3796198869228592, \
1.490209713504239}, {-0.06250000000000011, 1.7488835724541527}, 
    {0.009118627109394484, 1.8877889819588953}, {-0.3322270634726663, \
1.6081701375219566}}], 
  Line[{{-0.3796198869228592, 1.490209713504239}, {-0.4215899928019446, \
1.3759750672106554}, {-0.125923977384572, 1.6132809148526015}, 
    {-0.06250000000000011, 1.7488835724541527}, {-0.3796198869228592, \
1.490209713504239}}], 
  Line[{{-0.4215899928019446, 1.3759750672106554}, {-0.45630308608809433, \
1.2727298803122147}, {-0.17838137289060557, 1.4898021598760776}, 
    {-0.125923977384572, 1.6132809148526015}, {-0.4215899928019446, \
1.3759750672106554}}], 
  Line[{{-0.45630308608809433, 1.2727298803122147}, {-0.482242038032801, \
1.189085281951672}, {-0.21757954661597556, 1.389101261457407}, 
    {-0.17838137289060557, 1.4898021598760776}, {-0.45630308608809433, \
1.2727298803122147}}], 
  Line[{{-0.482242038032801, 1.189085281951672}, {-0.4982731919671799, \
1.1340136417284856}, {-0.2418053502751773, 1.3224570770546993}, 
    {-0.21757954661597556, 1.389101261457407}, {-0.482242038032801, \
1.189085281951672}}], 
  Line[{{-0.4982731919671799, 1.1340136417284856}, {-0.5036959095382874, \
1.1147172382160913}, {-0.2500000000000002, 1.299038105676658}, 
    {-0.2418053502751773, 1.3224570770546993}, {-0.4982731919671799, \
1.1340136417284856}}], 
  Line[{{-0.5036959095382874, 1.1147172382160913}, {-0.49827319196717995, \
1.1340136417284856}, {-0.2418053502751773, 1.3224570770546993}, 
    {-0.2500000000000002, 1.299038105676658}, {-0.5036959095382874, \
1.1147172382160913}}], 
  Line[{{-0.49827319196717995, 1.1340136417284856}, {-0.482242038032801, \
1.1890852819516717}, {-0.21757954661597556, 1.3891012614574068}, 
    {-0.2418053502751773, 1.3224570770546993}, {-0.49827319196717995, \
1.1340136417284856}}], 
  Line[{{-0.482242038032801, 1.1890852819516717}, {-0.4563030860880944, \
1.2727298803122145}, {-0.17838137289060557, 1.4898021598760776}, 
    {-0.21757954661597556, 1.3891012614574068}, {-0.482242038032801, \
1.1890852819516717}}], 
  Line[{{-0.4563030860880944, 1.2727298803122145}, {-0.42158999280194476, \
1.375975067210655}, {-0.12592397738457223, 1.6132809148526013}, 
    {-0.17838137289060557, 1.4898021598760776}, {-0.4563030860880944, \
1.2727298803122145}}], 
  Line[{{-0.42158999280194476, 1.375975067210655}, {-0.3796198869228593, \
1.4902097135042385}, {-0.06250000000000044, 1.7488835724541523}, 
    {-0.12592397738457223, 1.6132809148526013}, {-0.42158999280194476, \
1.375975067210655}}], 
  Line[{{-0.3796198869228593, 1.4902097135042385}, {-0.3322270634726663, \
1.6081701375219564}, {0.009118627109394317, 1.887788981958895}, 
    {-0.06250000000000044, 1.7488835724541523}, {-0.3796198869228593, \
1.4902097135042385}}], 
  Line[{{-0.3322270634726663, 1.6081701375219564}, {-0.2814828162521379, \
1.724112283936149}, {0.08580182627462934, 2.023178398097989}, 
    {0.009118627109394317, 1.887788981958895}, {-0.3322270634726663, \
1.6081701375219564}}], 
  Line[{{-0.2814828162521379, 1.724112283936149}, {-0.22960491236272457, \
1.8336364565828085}, {0.1641981737253695, 2.1499828315181593}, 
    {0.08580182627462934, 2.023178398097989}, {-0.2814828162521379, \
1.724112283936149}}], 
  Line[{{-0.22960491236272457, 1.8336364565828085}, {-0.1788606651421958, \
1.933432094411191}, {0.2408813728906049, 2.264540963292246}, 
    {0.1641981737253695, 2.1499828315181593}, {-0.22960491236272457, \
1.8336364565828085}}], 
  Line[{{-0.1788606651421958, 1.933432094411191}, {-0.13146784169200298, \
2.021043485921703}, {0.31249999999999944, 2.3642850399222164}, 
    {0.2408813728906049, 2.264540963292246}, {-0.1788606651421958, \
1.933432094411191}}], 
  Line[{{-0.13146784169200298, 2.021043485921703}, {-0.0894977358129174, \
2.0946793219544757}, {0.3759239773845713, 2.447478090794556}, 
    {0.31249999999999944, 2.3642850399222164}, {-0.13146784169200298, \
2.021043485921703}}], 
  Line[{{-0.0894977358129174, 2.0946793219544757}, {-0.05478464252676767, \
2.1530633066599703}, {0.42838137289060485, 2.512998012254406}, 
    {0.3759239773845713, 2.447478090794556}, {-0.0894977358129174, \
2.0946793219544757}}], 
  Line[{{-0.05478464252676767, 2.1530633066599703}, {-0.02884569058206097, \
2.1953185530328256}, {0.46757954661597495, 2.560161360910328}, 
    {0.42838137289060485, 2.512998012254406}, {-0.05478464252676767, \
2.1530633066599703}}], 
  Line[{{-0.02884569058206097, 2.1953185530328256}, {-0.012814536647682125, \
2.2208803408437956}, {0.49180535027517663, 2.588583579753018}, 
    {0.46757954661597495, 2.560161360910328}, {-0.02884569058206097, \
2.1953185530328256}}], 
  Line[{{-0.012814536647682125, 2.2208803408437956}, {-0.007391819076574713, \
2.2294344764321825}, {0.49999999999999967, 2.5980762113533156}, 
    {0.49180535027517663, 2.588583579753018}, {-0.012814536647682125, \
2.2208803408437956}}], 
  Line[{{-0.007391819076574713, 2.2294344764321825}, {-0.012814536647682062, \
2.2208803408437956}, {0.49180535027517697, 2.588583579753018}, 
    {0.49999999999999967, 2.5980762113533156}, {-0.007391819076574713, \
2.2294344764321825}}], 
  Line[{{-0.012814536647682062, 2.2208803408437956}, {-0.02884569058206095, \
2.195318553032826}, {0.46757954661597523, 2.5601613609103286}, 
    {0.49180535027517697, 2.588583579753018}, {-0.012814536647682062, \
2.2208803408437956}}], 
  Line[{{-0.02884569058206095, 2.195318553032826}, {-0.0547846425267676, \
2.1530633066599703}, {0.428381372890605, 2.512998012254406}, 
    {0.46757954661597523, 2.5601613609103286}, {-0.02884569058206095, \
2.195318553032826}}], 
  Line[{{-0.0547846425267676, 2.1530633066599703}, {-0.08949773581291712, \
2.094679321954476}, {0.3759239773845719, 2.4474780907945566}, 
    {0.428381372890605, 2.512998012254406}, {-0.0547846425267676, \
2.1530633066599703}}], 
  Line[{{-0.08949773581291712, 2.094679321954476}, {-0.13146784169200265, \
2.0210434859217035}, {0.31249999999999994, 2.3642850399222173}, 
    {0.3759239773845719, 2.4474780907945566}, {-0.08949773581291712, \
2.094679321954476}}], 
  Line[{{-0.13146784169200265, 2.0210434859217035}, {-0.17886066514219567, \
1.9334320944111911}, {0.2408813728906052, 2.264540963292246}, 
    {0.31249999999999994, 2.3642850399222173}, {-0.13146784169200265, \
2.0210434859217035}}], 
  Line[{{-0.17886066514219567, 1.9334320944111911}, {-0.2296049123627241, \
1.8336364565828094}, {0.16419817372537018, 2.14998283151816}, 
    {0.2408813728906052, 2.264540963292246}, {-0.17886066514219567, \
1.9334320944111911}}], 
  Line[{{-0.2296049123627241, 1.8336364565828094}, {-0.2814828162521375, \
1.7241122839361496}, {0.0858018262746299, 2.02317839809799}, 
    {0.16419817372537018, 2.14998283151816}, {-0.2296049123627241, \
1.8336364565828094}}], 
  Line[{{-0.2814828162521375, 1.7241122839361496}, {-0.33222706347266606, \
1.6081701375219568}, {0.009118627109394595, 1.8877889819588956}, 
    {0.0858018262746299, 2.02317839809799}, {-0.2814828162521375, \
1.7241122839361496}}], 
  Line[{{-0.33222706347266606, 1.6081701375219568}, {-0.379619886922859, \
1.4902097135042394}, {-0.062499999999999944, 1.7488835724541534}, 
    {0.009118627109394595, 1.8877889819588956}, {-0.33222706347266606, \
1.6081701375219568}}], 
  Line[{{-0.379619886922859, 1.4902097135042394}, {-0.4215899928019444, \
1.3759750672106559}, {-0.12592397738457173, 1.6132809148526024}, 
    {-0.062499999999999944, 1.7488835724541534}, {-0.379619886922859, \
1.4902097135042394}}], 
  Line[{{-0.4215899928019444, 1.3759750672106559}, {-0.45630308608809433, \
1.2727298803122147}, {-0.17838137289060546, 1.4898021598760776}, 
    {-0.12592397738457173, 1.6132809148526024}, {-0.4215899928019444, \
1.3759750672106559}}], 
  Line[{{-0.45630308608809433, 1.2727298803122147}, {-0.4822420380328009, \
1.1890852819516722}, {-0.21757954661597534, 1.3891012614574072}, 
    {-0.17838137289060546, 1.4898021598760776}, {-0.45630308608809433, \
1.2727298803122147}}], 
  Line[{{-0.4822420380328009, 1.1890852819516722}, {-0.4982731919671798, \
1.1340136417284858}, {-0.2418053502751772, 1.3224570770546997}, 
    {-0.21757954661597534, 1.3891012614574072}, {-0.4822420380328009, \
1.1890852819516722}}], 
  Line[{{-0.4982731919671798, 1.1340136417284858}, {-0.5036959095382874, \
1.1147172382160913}, {-0.2500000000000002, 1.299038105676658}, 
    {-0.2418053502751772, 1.3224570770546997}, {-0.4982731919671798, \
1.1340136417284858}}], 
  Line[{{-0.5036959095382874, 1.1147172382160913}, {-0.49827319196717995, \
1.1340136417284854}, {-0.2418053502751774, 1.322457077054699}, 
    {-0.2500000000000002, 1.299038105676658}, {-0.5036959095382874, \
1.1147172382160913}}], 
  Line[{{-0.49827319196717995, 1.1340136417284854}, {-0.48224203803280125, \
1.1890852819516713}, {-0.21757954661597584, 1.389101261457406}, 
    {-0.2418053502751774, 1.322457077054699}, {-0.49827319196717995, \
1.1340136417284854}}], 
  Line[{{-0.48224203803280125, 1.1890852819516713}, {-0.4563030860880944, \
1.2727298803122145}, {-0.17838137289060568, 1.4898021598760773}, 
    {-0.21757954661597584, 1.389101261457406}, {-0.48224203803280125, \
1.1890852819516713}}], 
  Line[{{-0.4563030860880944, 1.2727298803122145}, {-0.42158999280194487, \
1.3759750672106545}, {-0.12592397738457234, 1.6132809148526008}, 
    {-0.17838137289060568, 1.4898021598760773}, {-0.4563030860880944, \
1.2727298803122145}}], 
  Line[{{-0.42158999280194487, 1.3759750672106545}, {-0.3796198869228595, \
1.490209713504238}, {-0.06250000000000078, 1.7488835724541516}, 
    {-0.12592397738457234, 1.6132809148526008}, {-0.42158999280194487, \
1.3759750672106545}}], 
  Line[{{-0.3796198869228595, 1.490209713504238}, {-0.3322270634726664, \
1.6081701375219564}, {0.009118627109394317, 1.8877889819588949}, 
    {-0.06250000000000078, 1.7488835724541516}, {-0.3796198869228595, \
1.490209713504238}}], 
  Line[{{-0.3322270634726664, 1.6081701375219564}, {-0.28148281625213795, \
1.7241122839361487}, {0.08580182627462918, 2.0231783980979885}, 
    {0.009118627109394317, 1.8877889819588949}, {-0.3322270634726664, \
1.6081701375219564}}], 
  Line[{{-0.28148281625213795, 1.7241122839361487}, {-0.22960491236272482, \
1.833636456582808}, {0.1641981737253691, 2.149982831518159}, 
    {0.08580182627462918, 2.0231783980979885}, {-0.28148281625213795, \
1.7241122839361487}}], 
  Line[{{-0.22960491236272482, 1.833636456582808}, {-0.17886066514219578, \
1.933432094411191}, {0.24088137289060496, 2.264540963292246}, 
    {0.1641981737253691, 2.149982831518159}, {-0.22960491236272482, \
1.833636456582808}}], 
  Line[{{-0.17886066514219578, 1.933432094411191}, {-0.13146784169200307, \
2.021043485921703}, {0.31249999999999944, 2.3642850399222164}, 
    {0.24088137289060496, 2.264540963292246}, {-0.17886066514219578, \
1.933432094411191}}], 
  Line[{{-0.13146784169200307, 2.021043485921703}, {-0.0894977358129177, \
2.0946793219544753}, {0.375923977384571, 2.4474780907945557}, 
    {0.31249999999999944, 2.3642850399222164}, {-0.13146784169200307, \
2.021043485921703}}], 
  Line[{{-0.0894977358129177, 2.0946793219544753}, {-0.054784642526767645, \
2.1530633066599703}, {0.4283813728906049, 2.512998012254406}, 
    {0.375923977384571, 2.4474780907945557}, {-0.0894977358129177, \
2.0946793219544753}}], 
  Line[{{-0.054784642526767645, 2.1530633066599703}, {-0.02884569058206095, \
2.1953185530328256}, {0.46757954661597495, 2.560161360910328}, 
    {0.4283813728906049, 2.512998012254406}, {-0.054784642526767645, \
2.1530633066599703}}], 
  Line[{{-0.02884569058206095, 2.1953185530328256}, {-0.012814536647682086, \
2.2208803408437956}, {0.4918053502751767, 2.588583579753018}, 
    {0.46757954661597495, 2.560161360910328}, {-0.02884569058206095, \
2.1953185530328256}}], 
  Line[{{-0.012814536647682086, 2.2208803408437956}, {-0.007391819076574713, \
2.2294344764321825}, {0.49999999999999967, 2.5980762113533156}, 
    {0.4918053502751767, 2.588583579753018}, {-0.012814536647682086, \
2.2208803408437956}}], 
  Line[{{0.49999999999999967, 2.5980762113533156}, {0.4918053502751766, \
2.588583579753018}, {1.0616242894813523, 2.8434972909653364}, 
    {1.0729490168751576, 2.8531695488854605}, {0.49999999999999967, \
2.5980762113533156}}], 
  Line[{{0.4918053502751766, 2.588583579753018}, {0.4675795466159753, \
2.5601613609103286}, {1.0281450522291173, 2.8144424077524013}, 
    {1.0616242894813523, 2.8434972909653364}, {0.4918053502751766, \
2.588583579753018}}], 
  Line[{{0.4675795466159753, 2.5601613609103286}, {0.42838137289060485, \
2.512998012254406}, {0.9739745084375786, 2.7659262761959793}, 
    {1.0281450522291173, 2.8144424077524013}, {0.4675795466159753, \
2.5601613609103286}}], 
  Line[{{0.42838137289060485, 2.512998012254406}, {0.3759239773845714, \
2.4474780907945557}, {0.9014801708095362, 2.697933958917173}, 
    {0.9739745084375786, 2.7659262761959793}, {0.42838137289060485, \
2.512998012254406}}], 
  Line[{{0.3759239773845714, 2.4474780907945557}, {0.31249999999999983, \
2.364285039922217}, {0.813830389765763, 2.6106791787633683}, 
    {0.9014801708095362, 2.697933958917173}, {0.3759239773845714, \
2.4474780907945557}}], 
  Line[{{0.31249999999999983, 2.364285039922217}, {0.24088137289060504, \
2.2645409632922457}, {0.714855881328184, 2.504820390287959}, 
    {0.813830389765763, 2.6106791787633683}, {0.31249999999999983, \
2.364285039922217}}], 
  Line[{{0.24088137289060504, 2.2645409632922457}, {0.16419817372536988, \
2.1499828315181597}, {0.6088823064479068, 2.381720267244781}, 
    {0.714855881328184, 2.504820390287959}, {0.24088137289060504, \
2.2645409632922457}}], 
  Line[{{0.16419817372536988, 2.1499828315181597}, {0.08580182627462962, \
2.0231783980979894}, {0.5005412188648298, 2.2437468595288657}, 
    {0.6088823064479068, 2.381720267244781}, {0.16419817372536988, \
2.1499828315181597}}], 
  Line[{{0.08580182627462962, 2.0231783980979894}, {0.009118627109394484, \
1.8877889819588953}, {0.39456764398455235, 2.0946223601372336}, 
    {0.5005412188648298, 2.2437468595288657}, {0.08580182627462962, \
2.0231783980979894}}], 
  Line[{{0.009118627109394484, 1.8877889819588953}, {-0.06250000000000011, \
1.7488835724541527}, {0.2955931355469736, 1.9398272078772507}, 
    {0.39456764398455235, 2.0946223601372336}, {0.009118627109394484, \
1.8877889819588953}}], 
  Line[{{-0.06250000000000011, 1.7488835724541527}, {-0.125923977384572, \
1.6132809148526015}, {0.20794335450320006, 1.7870411277345812}, 
    {0.2955931355469736, 1.9398272078772507}, {-0.06250000000000011, \
1.7488835724541527}}], 
  Line[{{-0.125923977384572, 1.6132809148526015}, {-0.17838137289060557, \
1.4898021598760776}, {0.13544901687515765, 1.6464961680271788}, 
    {0.20794335450320006, 1.7870411277345812}, {-0.125923977384572, \
1.6132809148526015}}], 
  Line[{{-0.17838137289060557, 1.4898021598760776}, {-0.21757954661597556, \
1.389101261457407}, {0.08127847308361946, 1.5308481540548229}, 
    {0.13544901687515765, 1.6464961680271788}, {-0.17838137289060557, \
1.4898021598760776}}], 
  Line[{{-0.21757954661597556, 1.389101261457407}, {-0.2418053502751773, \
1.3224570770546993}, {0.047799235831384124, 1.4537753723488893}, 
    {0.08127847308361946, 1.5308481540548229}, {-0.21757954661597556, \
1.389101261457407}}], 
  Line[{{-0.2418053502751773, 1.3224570770546993}, {-0.2500000000000002, \
1.299038105676658}, {0.03647450843757882, 1.4265847744427302}, 
    {0.047799235831384124, 1.4537753723488893}, {-0.2418053502751773, \
1.3224570770546993}}], 
  Line[{{-0.2500000000000002, 1.299038105676658}, {-0.2418053502751773, \
1.3224570770546993}, {0.047799235831384124, 1.453775372348889}, 
    {0.03647450843757882, 1.4265847744427302}, {-0.2500000000000002, \
1.299038105676658}}], 
  Line[{{-0.2418053502751773, 1.3224570770546993}, {-0.21757954661597556, \
1.3891012614574068}, {0.08127847308361935, 1.5308481540548224}, 
    {0.047799235831384124, 1.453775372348889}, {-0.2418053502751773, \
1.3224570770546993}}], 
  Line[{{-0.21757954661597556, 1.3891012614574068}, {-0.17838137289060557, \
1.4898021598760776}, {0.13544901687515776, 1.6464961680271788}, 
    {0.08127847308361935, 1.5308481540548224}, {-0.21757954661597556, \
1.3891012614574068}}], 
  Line[{{-0.17838137289060557, 1.4898021598760776}, {-0.12592397738457223, \
1.6132809148526013}, {0.20794335450319978, 1.7870411277345808}, 
    {0.13544901687515776, 1.6464961680271788}, {-0.17838137289060557, \
1.4898021598760776}}], 
  Line[{{-0.12592397738457223, 1.6132809148526013}, {-0.06250000000000044, \
1.7488835724541523}, {0.29559313554697325, 1.9398272078772505}, 
    {0.20794335450319978, 1.7870411277345808}, {-0.12592397738457223, \
1.6132809148526013}}], 
  Line[{{-0.06250000000000044, 1.7488835724541523}, {0.009118627109394317, \
1.887788981958895}, {0.39456764398455224, 2.094622360137233}, 
    {0.29559313554697325, 1.9398272078772505}, {-0.06250000000000044, \
1.7488835724541523}}], 
  Line[{{0.009118627109394317, 1.887788981958895}, {0.08580182627462934, \
2.023178398097989}, {0.5005412188648295, 2.243746859528865}, 
    {0.39456764398455224, 2.094622360137233}, {0.009118627109394317, \
1.887788981958895}}], 
  Line[{{0.08580182627462934, 2.023178398097989}, {0.1641981737253695, \
2.1499828315181593}, {0.6088823064479062, 2.3817202672447806}, 
    {0.5005412188648295, 2.243746859528865}, {0.08580182627462934, \
2.023178398097989}}], 
  Line[{{0.1641981737253695, 2.1499828315181593}, {0.2408813728906049, \
2.264540963292246}, {0.7148558813281839, 2.504820390287959}, 
    {0.6088823064479062, 2.3817202672447806}, {0.1641981737253695, \
2.1499828315181593}}], 
  Line[{{0.2408813728906049, 2.264540963292246}, {0.31249999999999944, \
2.3642850399222164}, {0.8138303897657626, 2.610679178763368}, 
    {0.7148558813281839, 2.504820390287959}, {0.2408813728906049, \
2.264540963292246}}], 
  Line[{{0.31249999999999944, 2.3642850399222164}, {0.3759239773845713, \
2.447478090794556}, {0.9014801708095362, 2.697933958917173}, 
    {0.8138303897657626, 2.610679178763368}, {0.31249999999999944, \
2.3642850399222164}}], 
  Line[{{0.3759239773845713, 2.447478090794556}, {0.42838137289060485, \
2.512998012254406}, {0.9739745084375787, 2.765926276195979}, 
    {0.9014801708095362, 2.697933958917173}, {0.3759239773845713, \
2.447478090794556}}], 
  Line[{{0.42838137289060485, 2.512998012254406}, {0.46757954661597495, \
2.560161360910328}, {1.0281450522291171, 2.8144424077524013}, 
    {0.9739745084375787, 2.765926276195979}, {0.42838137289060485, \
2.512998012254406}}], 
  Line[{{0.46757954661597495, 2.560161360910328}, {0.49180535027517663, \
2.588583579753018}, {1.0616242894813523, 2.8434972909653364}, 
    {1.0281450522291171, 2.8144424077524013}, {0.46757954661597495, \
2.560161360910328}}], 
  Line[{{0.49180535027517663, 2.588583579753018}, {0.49999999999999967, \
2.5980762113533156}, {1.0729490168751576, 2.8531695488854605}, 
    {1.0616242894813523, 2.8434972909653364}, {0.49180535027517663, \
2.588583579753018}}], 
  Line[{{0.49999999999999967, 2.5980762113533156}, {0.49180535027517697, \
2.588583579753018}, {1.0616242894813526, 2.843497290965337}, 
    {1.0729490168751576, 2.8531695488854605}, {0.49999999999999967, \
2.5980762113533156}}], 
  Line[{{0.49180535027517697, 2.588583579753018}, {0.46757954661597523, \
2.5601613609103286}, {1.0281450522291173, 2.8144424077524013}, 
    {1.0616242894813526, 2.843497290965337}, {0.49180535027517697, \
2.588583579753018}}], 
  Line[{{0.46757954661597523, 2.5601613609103286}, {0.428381372890605, \
2.512998012254406}, {0.973974508437579, 2.7659262761959793}, 
    {1.0281450522291173, 2.8144424077524013}, {0.46757954661597523, \
2.5601613609103286}}], 
  Line[{{0.428381372890605, 2.512998012254406}, {0.3759239773845719, \
2.4474780907945566}, {0.901480170809537, 2.6979339589171736}, 
    {0.973974508437579, 2.7659262761959793}, {0.428381372890605, \
2.512998012254406}}], 
  Line[{{0.3759239773845719, 2.4474780907945566}, {0.31249999999999994, \
2.3642850399222173}, {0.8138303897657633, 2.6106791787633687}, 
    {0.901480170809537, 2.6979339589171736}, {0.3759239773845719, \
2.4474780907945566}}], 
  Line[{{0.31249999999999994, 2.3642850399222173}, {0.2408813728906052, \
2.264540963292246}, {0.7148558813281845, 2.504820390287959}, 
    {0.8138303897657633, 2.6106791787633687}, {0.31249999999999994, \
2.3642850399222173}}], 
  Line[{{0.2408813728906052, 2.264540963292246}, {0.16419817372537018, \
2.14998283151816}, {0.6088823064479071, 2.3817202672447815}, 
    {0.7148558813281845, 2.504820390287959}, {0.2408813728906052, \
2.264540963292246}}], 
  Line[{{0.16419817372537018, 2.14998283151816}, {0.0858018262746299, \
2.02317839809799}, {0.5005412188648302, 2.243746859528866}, 
    {0.6088823064479071, 2.3817202672447815}, {0.16419817372537018, \
2.14998283151816}}], 
  Line[{{0.0858018262746299, 2.02317839809799}, {0.009118627109394595, \
1.8877889819588956}, {0.3945676439845526, 2.0946223601372336}, 
    {0.5005412188648302, 2.243746859528866}, {0.0858018262746299, \
2.02317839809799}}], 
  Line[{{0.009118627109394595, 1.8877889819588956}, {-0.062499999999999944, \
1.7488835724541534}, {0.295593135546974, 1.9398272078772514}, 
    {0.3945676439845526, 2.0946223601372336}, {0.009118627109394595, \
1.8877889819588956}}], 
  Line[{{-0.062499999999999944, 1.7488835724541534}, {-0.12592397738457173, \
1.6132809148526024}, {0.20794335450320034, 1.7870411277345821}, 
    {0.295593135546974, 1.9398272078772514}, {-0.062499999999999944, \
1.7488835724541534}}], 
  Line[{{-0.12592397738457173, 1.6132809148526024}, {-0.17838137289060546, \
1.4898021598760776}, {0.13544901687515776, 1.646496168027179}, 
    {0.20794335450320034, 1.7870411277345821}, {-0.12592397738457173, \
1.6132809148526024}}], 
  Line[{{-0.17838137289060546, 1.4898021598760776}, {-0.21757954661597534, \
1.3891012614574072}, {0.08127847308361968, 1.530848154054823}, 
    {0.13544901687515776, 1.646496168027179}, {-0.17838137289060546, \
1.4898021598760776}}], 
  Line[{{-0.21757954661597534, 1.3891012614574072}, {-0.2418053502751772, \
1.3224570770546997}, {0.047799235831384346, 1.4537753723488895}, 
    {0.08127847308361968, 1.530848154054823}, {-0.21757954661597534, \
1.3891012614574072}}], 
  Line[{{-0.2418053502751772, 1.3224570770546997}, {-0.2500000000000002, \
1.299038105676658}, {0.03647450843757882, 1.4265847744427302}, 
    {0.047799235831384346, 1.4537753723488895}, {-0.2418053502751772, \
1.3224570770546997}}], 
  Line[{{-0.2500000000000002, 1.299038105676658}, {-0.2418053502751774, \
1.322457077054699}, {0.04779923583138401, 1.4537753723488889}, 
    {0.03647450843757882, 1.4265847744427302}, {-0.2500000000000002, \
1.299038105676658}}], 
  Line[{{-0.2418053502751774, 1.322457077054699}, {-0.21757954661597584, \
1.389101261457406}, {0.08127847308361902, 1.530848154054822}, 
    {0.04779923583138401, 1.4537753723488889}, {-0.2418053502751774, \
1.322457077054699}}], 
  Line[{{-0.21757954661597584, 1.389101261457406}, {-0.17838137289060568, \
1.4898021598760773}, {0.1354490168751576, 1.6464961680271786}, 
    {0.08127847308361902, 1.530848154054822}, {-0.21757954661597584, \
1.389101261457406}}], 
  Line[{{-0.17838137289060568, 1.4898021598760773}, {-0.12592397738457234, \
1.6132809148526008}, {0.20794335450319956, 1.7870411277345803}, 
    {0.1354490168751576, 1.6464961680271786}, {-0.17838137289060568, \
1.4898021598760773}}], 
  Line[{{-0.12592397738457234, 1.6132809148526008}, {-0.06250000000000078, \
1.7488835724541516}, {0.2955931355469728, 1.9398272078772496}, 
    {0.20794335450319956, 1.7870411277345803}, {-0.12592397738457234, \
1.6132809148526008}}], 
  Line[{{-0.06250000000000078, 1.7488835724541516}, {0.009118627109394317, \
1.8877889819588949}, {0.39456764398455213, 2.0946223601372327}, 
    {0.2955931355469728, 1.9398272078772496}, {-0.06250000000000078, \
1.7488835724541516}}], 
  Line[{{0.009118627109394317, 1.8877889819588949}, {0.08580182627462918, \
2.0231783980979885}, {0.5005412188648293, 2.2437468595288648}, 
    {0.39456764398455213, 2.0946223601372327}, {0.009118627109394317, \
1.8877889819588949}}], 
  Line[{{0.08580182627462918, 2.0231783980979885}, {0.1641981737253691, \
2.149982831518159}, {0.6088823064479056, 2.38172026724478}, 
    {0.5005412188648293, 2.2437468595288648}, {0.08580182627462918, \
2.0231783980979885}}], 
  Line[{{0.1641981737253691, 2.149982831518159}, {0.24088137289060496, \
2.264540963292246}, {0.714855881328184, 2.504820390287959}, 
    {0.6088823064479056, 2.38172026724478}, {0.1641981737253691, \
2.149982831518159}}], 
  Line[{{0.24088137289060496, 2.264540963292246}, {0.31249999999999944, \
2.3642850399222164}, {0.8138303897657625, 2.610679178763368}, 
    {0.714855881328184, 2.504820390287959}, {0.24088137289060496, \
2.264540963292246}}], 
  Line[{{0.31249999999999944, 2.3642850399222164}, {0.375923977384571, \
2.4474780907945557}, {0.9014801708095358, 2.6979339589171727}, 
    {0.8138303897657625, 2.610679178763368}, {0.31249999999999944, \
2.3642850399222164}}], 
  Line[{{0.375923977384571, 2.4474780907945557}, {0.4283813728906049, \
2.512998012254406}, {0.9739745084375787, 2.765926276195979}, 
    {0.9014801708095358, 2.6979339589171727}, {0.375923977384571, \
2.4474780907945557}}], 
  Line[{{0.4283813728906049, 2.512998012254406}, {0.46757954661597495, \
2.560161360910328}, {1.0281450522291171, 2.8144424077524013}, 
    {0.9739745084375787, 2.765926276195979}, {0.4283813728906049, \
2.512998012254406}}], 
  Line[{{0.46757954661597495, 2.560161360910328}, {0.4918053502751767, \
2.588583579753018}, {1.0616242894813523, 2.8434972909653364}, 
    {1.0281450522291171, 2.8144424077524013}, {0.46757954661597495, \
2.560161360910328}}], 
  Line[{{0.4918053502751767, 2.588583579753018}, {0.49999999999999967, \
2.5980762113533156}, {1.0729490168751576, 2.8531695488854605}, 
    {1.0616242894813523, 2.8434972909653364}, {0.4918053502751767, \
2.588583579753018}}], 
  Line[{{1.0729490168751576, 2.8531695488854605}, {1.0616242894813523, \
2.8434972909653364}, {1.6717384590328979, 2.9745950829027943}, 
    {1.6864146101970388, 2.98356568610482}, {1.0729490168751576, \
2.8531695488854605}}], 
  Line[{{1.0616242894813523, 2.8434972909653364}, {1.0281450522291173, \
2.8144424077524013}, {1.6283514237703351, 2.9474883844565616}, 
    {1.6717384590328979, 2.9745950829027943}, {1.0616242894813523, \
2.8434972909653364}}], 
  Line[{{1.0281450522291173, 2.8144424077524013}, {0.9739745084375786, \
2.7659262761959793}, {1.5581497260444177, 2.9017190909782276}, 
    {1.6283514237703351, 2.9474883844565616}, {1.0281450522291173, \
2.8144424077524013}}], 
  Line[{{0.9739745084375786, 2.7659262761959793}, {0.9014801708095362, \
2.697933958917173}, {1.4642015169108888, 2.836596676593442}, 
    {1.5581497260444177, 2.9017190909782276}, {0.9739745084375786, \
2.7659262761959793}}], 
  Line[{{0.9014801708095362, 2.697933958917173}, {0.813830389765763, \
2.6106791787633683}, {1.3506127839224091, 2.751525170659194}, 
    {1.4642015169108888, 2.836596676593442}, {0.9014801708095362, \
2.697933958917173}}], 
  Line[{{0.813830389765763, 2.6106791787633683}, {0.714855881328184, \
2.504820390287959}, {1.2223478997697876, 2.646328981764321}, 
    {1.3506127839224091, 2.751525170659194}, {0.813830389765763, \
2.6106791787633683}}], 
  Line[{{0.714855881328184, 2.504820390287959}, {0.6088823064479068, \
2.381720267244781}, {1.0850126553736965, 2.5216249314090464}, 
    {1.2223478997697876, 2.646328981764321}, {0.714855881328184, \
2.504820390287959}}], 
  Line[{{0.6088823064479068, 2.381720267244781}, {0.5005412188648298, \
2.2437468595288657}, {0.9446092599218617, 2.3792297776658287}, 
    {1.0850126553736965, 2.5216249314090464}, {0.6088823064479068, \
2.381720267244781}}], 
  Line[{{0.5005412188648298, 2.2437468595288657}, {0.39456764398455235, \
2.0946223601372336}, {0.8072740155257703, 2.222607239695348}, 
    {0.9446092599218617, 2.3792297776658287}, {0.5005412188648298, \
2.2437468595288657}}], 
  Line[{{0.39456764398455235, 2.0946223601372336}, {0.2955931355469736, \
1.9398272078772507}, {0.6790091313731493, 2.0573688751735335}, 
    {0.8072740155257703, 2.222607239695348}, {0.39456764398455235, \
2.0946223601372336}}], 
  Line[{{0.2955931355469736, 1.9398272078772507}, {0.20794335450320006, \
1.7870411277345812}, {0.5654203983846692, 1.8918241808350187}, 
    {0.6790091313731493, 2.0573688751735335}, {0.2955931355469736, \
1.9398272078772507}}], 
  Line[{{0.20794335450320006, 1.7870411277345812}, {0.13544901687515765, \
1.6464961680271788}, {0.47147218925114043, 1.7374623647519978}, 
    {0.5654203983846692, 1.8918241808350187}, {0.20794335450320006, \
1.7870411277345812}}], 
  Line[{{0.13544901687515765, 1.6464961680271788}, {0.08127847308361946, \
1.5308481540548229}, {0.40127049152522337, 1.6089224974238359}, 
    {0.47147218925114043, 1.7374623647519978}, {0.13544901687515765, \
1.6464961680271788}}], 
  Line[{{0.08127847308361946, 1.5308481540548229}, {0.047799235831384124, \
1.4537753723488893}, {0.35788345626266027, 1.5224519023538965}, 
    {0.40127049152522337, 1.6089224974238359}, {0.08127847308361946, \
1.5308481540548229}}], 
  Line[{{0.047799235831384124, 1.4537753723488893}, {0.03647450843757882, \
1.4265847744427302}, {0.3432073050985194, 1.49178284305241}, 
    {0.35788345626266027, 1.5224519023538965}, {0.047799235831384124, \
1.4537753723488893}}], 
  Line[{{0.03647450843757882, 1.4265847744427302}, {0.047799235831384124, \
1.453775372348889}, {0.35788345626266027, 1.5224519023538965}, 
    {0.3432073050985194, 1.49178284305241}, {0.03647450843757882, \
1.4265847744427302}}], 
  Line[{{0.047799235831384124, 1.453775372348889}, {0.08127847308361935, \
1.5308481540548224}, {0.40127049152522326, 1.6089224974238354}, 
    {0.35788345626266027, 1.5224519023538965}, {0.047799235831384124, \
1.453775372348889}}], 
  Line[{{0.08127847308361935, 1.5308481540548224}, {0.13544901687515776, \
1.6464961680271788}, {0.4714721892511405, 1.7374623647519976}, 
    {0.40127049152522326, 1.6089224974238354}, {0.08127847308361935, \
1.5308481540548224}}], 
  Line[{{0.13544901687515776, 1.6464961680271788}, {0.20794335450319978, \
1.7870411277345808}, {0.5654203983846688, 1.8918241808350182}, 
    {0.4714721892511405, 1.7374623647519976}, {0.13544901687515776, \
1.6464961680271788}}], 
  Line[{{0.20794335450319978, 1.7870411277345808}, {0.29559313554697325, \
1.9398272078772505}, {0.6790091313731489, 2.0573688751735326}, 
    {0.5654203983846688, 1.8918241808350182}, {0.20794335450319978, \
1.7870411277345808}}], 
  Line[{{0.29559313554697325, 1.9398272078772505}, {0.39456764398455224, \
2.094622360137233}, {0.80727401552577, 2.2226072396953476}, 
    {0.6790091313731489, 2.0573688751735326}, {0.29559313554697325, \
1.9398272078772505}}], 
  Line[{{0.39456764398455224, 2.094622360137233}, {0.5005412188648295, \
2.243746859528865}, {0.9446092599218614, 2.379229777665828}, 
    {0.80727401552577, 2.2226072396953476}, {0.39456764398455224, \
2.094622360137233}}], 
  Line[{{0.5005412188648295, 2.243746859528865}, {0.6088823064479062, \
2.3817202672447806}, {1.0850126553736956, 2.521624931409046}, 
    {0.9446092599218614, 2.379229777665828}, {0.5005412188648295, \
2.243746859528865}}], 
  Line[{{0.6088823064479062, 2.3817202672447806}, {0.7148558813281839, \
2.504820390287959}, {1.2223478997697876, 2.646328981764321}, 
    {1.0850126553736956, 2.521624931409046}, {0.6088823064479062, \
2.3817202672447806}}], 
  Line[{{0.7148558813281839, 2.504820390287959}, {0.8138303897657626, \
2.610679178763368}, {1.3506127839224085, 2.7515251706591934}, 
    {1.2223478997697876, 2.646328981764321}, {0.7148558813281839, \
2.504820390287959}}], 
  Line[{{0.8138303897657626, 2.610679178763368}, {0.9014801708095362, \
2.697933958917173}, {1.4642015169108888, 2.836596676593442}, 
    {1.3506127839224085, 2.7515251706591934}, {0.8138303897657626, \
2.610679178763368}}], 
  Line[{{0.9014801708095362, 2.697933958917173}, {0.9739745084375787, \
2.765926276195979}, {1.5581497260444177, 2.9017190909782276}, 
    {1.4642015169108888, 2.836596676593442}, {0.9014801708095362, \
2.697933958917173}}], 
  Line[{{0.9739745084375787, 2.765926276195979}, {1.0281450522291171, \
2.8144424077524013}, {1.628351423770335, 2.9474883844565616}, 
    {1.5581497260444177, 2.9017190909782276}, {0.9739745084375787, \
2.765926276195979}}], 
  Line[{{1.0281450522291171, 2.8144424077524013}, {1.0616242894813523, \
2.8434972909653364}, {1.6717384590328979, 2.9745950829027943}, 
    {1.628351423770335, 2.9474883844565616}, {1.0281450522291171, \
2.8144424077524013}}], 
  Line[{{1.0616242894813523, 2.8434972909653364}, {1.0729490168751576, \
2.8531695488854605}, {1.6864146101970388, 2.98356568610482}, 
    {1.6717384590328979, 2.9745950829027943}, {1.0616242894813523, \
2.8434972909653364}}], 
  Line[{{1.0729490168751576, 2.8531695488854605}, {1.0616242894813526, \
2.843497290965337}, {1.6717384590328983, 2.974595082902794}, 
    {1.6864146101970388, 2.98356568610482}, {1.0729490168751576, \
2.8531695488854605}}], 
  Line[{{1.0616242894813526, 2.843497290965337}, {1.0281450522291173, \
2.8144424077524013}, {1.6283514237703351, 2.947488384456561}, 
    {1.6717384590328983, 2.974595082902794}, {1.0616242894813526, \
2.843497290965337}}], 
  Line[{{1.0281450522291173, 2.8144424077524013}, {0.973974508437579, \
2.7659262761959793}, {1.558149726044418, 2.9017190909782276}, 
    {1.6283514237703351, 2.947488384456561}, {1.0281450522291173, \
2.8144424077524013}}], 
  Line[{{0.973974508437579, 2.7659262761959793}, {0.901480170809537, \
2.6979339589171736}, {1.4642015169108895, 2.836596676593442}, 
    {1.558149726044418, 2.9017190909782276}, {0.973974508437579, \
2.7659262761959793}}], 
  Line[{{0.901480170809537, 2.6979339589171736}, {0.8138303897657633, \
2.6106791787633687}, {1.3506127839224094, 2.751525170659194}, 
    {1.4642015169108895, 2.836596676593442}, {0.901480170809537, \
2.6979339589171736}}], 
  Line[{{0.8138303897657633, 2.6106791787633687}, {0.7148558813281845, \
2.504820390287959}, {1.2223478997697883, 2.646328981764321}, 
    {1.3506127839224094, 2.751525170659194}, {0.8138303897657633, \
2.6106791787633687}}], 
  Line[{{0.7148558813281845, 2.504820390287959}, {0.6088823064479071, \
2.3817202672447815}, {1.085012655373697, 2.521624931409047}, 
    {1.2223478997697883, 2.646328981764321}, {0.7148558813281845, \
2.504820390287959}}], 
  Line[{{0.6088823064479071, 2.3817202672447815}, {0.5005412188648302, \
2.243746859528866}, {0.9446092599218623, 2.379229777665829}, 
    {1.085012655373697, 2.521624931409047}, {0.6088823064479071, \
2.3817202672447815}}], 
  Line[{{0.5005412188648302, 2.243746859528866}, {0.3945676439845526, \
2.0946223601372336}, {0.8072740155257706, 2.222607239695348}, 
    {0.9446092599218623, 2.379229777665829}, {0.5005412188648302, \
2.243746859528866}}], 
  Line[{{0.3945676439845526, 2.0946223601372336}, {0.295593135546974, \
1.9398272078772514}, {0.6790091313731498, 2.057368875173534}, 
    {0.8072740155257706, 2.222607239695348}, {0.3945676439845526, \
2.0946223601372336}}], 
  Line[{{0.295593135546974, 1.9398272078772514}, {0.20794335450320034, \
1.7870411277345821}, {0.5654203983846697, 1.8918241808350196}, 
    {0.6790091313731498, 2.057368875173534}, {0.295593135546974, \
1.9398272078772514}}], 
  Line[{{0.20794335450320034, 1.7870411277345821}, {0.13544901687515776, \
1.646496168027179}, {0.4714721892511406, 1.7374623647519978}, 
    {0.5654203983846697, 1.8918241808350196}, {0.20794335450320034, \
1.7870411277345821}}], 
  Line[{{0.13544901687515776, 1.646496168027179}, {0.08127847308361968, \
1.530848154054823}, {0.40127049152522365, 1.608922497423836}, 
    {0.4714721892511406, 1.7374623647519978}, {0.13544901687515776, \
1.646496168027179}}], 
  Line[{{0.08127847308361968, 1.530848154054823}, {0.047799235831384346, \
1.4537753723488895}, {0.3578834562626605, 1.5224519023538967}, 
    {0.40127049152522365, 1.608922497423836}, {0.08127847308361968, \
1.530848154054823}}], 
  Line[{{0.047799235831384346, 1.4537753723488895}, {0.03647450843757882, \
1.4265847744427302}, {0.3432073050985194, 1.49178284305241}, 
    {0.3578834562626605, 1.5224519023538967}, {0.047799235831384346, \
1.4537753723488895}}], 
  Line[{{0.03647450843757882, 1.4265847744427302}, {0.04779923583138401, \
1.4537753723488889}, {0.35788345626266016, 1.5224519023538963}, 
    {0.3432073050985194, 1.49178284305241}, {0.03647450843757882, \
1.4265847744427302}}], 
  Line[{{0.04779923583138401, 1.4537753723488889}, {0.08127847308361902, \
1.530848154054822}, {0.40127049152522287, 1.608922497423835}, 
    {0.35788345626266016, 1.5224519023538963}, {0.04779923583138401, \
1.4537753723488889}}], 
  Line[{{0.08127847308361902, 1.530848154054822}, {0.1354490168751576, \
1.6464961680271786}, {0.4714721892511403, 1.7374623647519973}, 
    {0.40127049152522287, 1.608922497423835}, {0.08127847308361902, \
1.530848154054822}}], 
  Line[{{0.1354490168751576, 1.6464961680271786}, {0.20794335450319956, \
1.7870411277345803}, {0.5654203983846685, 1.8918241808350178}, 
    {0.4714721892511403, 1.7374623647519973}, {0.1354490168751576, \
1.6464961680271786}}], 
  Line[{{0.20794335450319956, 1.7870411277345803}, {0.2955931355469728, \
1.9398272078772496}, {0.6790091313731483, 2.057368875173532}, 
    {0.5654203983846685, 1.8918241808350178}, {0.20794335450319956, \
1.7870411277345803}}], 
  Line[{{0.2955931355469728, 1.9398272078772496}, {0.39456764398455213, \
2.0946223601372327}, {0.80727401552577, 2.2226072396953476}, 
    {0.6790091313731483, 2.057368875173532}, {0.2955931355469728, \
1.9398272078772496}}], 
  Line[{{0.39456764398455213, 2.0946223601372327}, {0.5005412188648293, \
2.2437468595288648}, {0.944609259921861, 2.379229777665828}, 
    {0.80727401552577, 2.2226072396953476}, {0.39456764398455213, \
2.0946223601372327}}], 
  Line[{{0.5005412188648293, 2.2437468595288648}, {0.6088823064479056, \
2.38172026724478}, {1.085012655373695, 2.521624931409045}, 
    {0.944609259921861, 2.379229777665828}, {0.5005412188648293, \
2.2437468595288648}}], 
  Line[{{0.6088823064479056, 2.38172026724478}, {0.714855881328184, \
2.504820390287959}, {1.2223478997697876, 2.646328981764321}, 
    {1.085012655373695, 2.521624931409045}, {0.6088823064479056, \
2.38172026724478}}], 
  Line[{{0.714855881328184, 2.504820390287959}, {0.8138303897657625, \
2.610679178763368}, {1.3506127839224085, 2.7515251706591934}, 
    {1.2223478997697876, 2.646328981764321}, {0.714855881328184, \
2.504820390287959}}], 
  Line[{{0.8138303897657625, 2.610679178763368}, {0.9014801708095358, \
2.6979339589171727}, {1.4642015169108882, 2.836596676593441}, 
    {1.3506127839224085, 2.7515251706591934}, {0.8138303897657625, \
2.610679178763368}}], 
  Line[{{0.9014801708095358, 2.6979339589171727}, {0.9739745084375787, \
2.765926276195979}, {1.5581497260444177, 2.901719090978228}, 
    {1.4642015169108882, 2.836596676593441}, {0.9014801708095358, \
2.6979339589171727}}], 
  Line[{{0.9739745084375787, 2.765926276195979}, {1.0281450522291171, \
2.8144424077524013}, {1.628351423770335, 2.9474883844565616}, 
    {1.5581497260444177, 2.901719090978228}, {0.9739745084375787, \
2.765926276195979}}], 
  Line[{{1.0281450522291171, 2.8144424077524013}, {1.0616242894813523, \
2.8434972909653364}, {1.671738459032898, 2.9745950829027943}, 
    {1.628351423770335, 2.9474883844565616}, {1.0281450522291171, \
2.8144424077524013}}], 
  Line[{{1.0616242894813523, 2.8434972909653364}, {1.0729490168751576, \
2.8531695488854605}, {1.6864146101970388, 2.98356568610482}, 
    {1.671738459032898, 2.9745950829027943}, {1.0616242894813523, \
2.8434972909653364}}], 
  Line[{{1.6864146101970388, 2.98356568610482}, {1.6717384590328979, \
2.9745950829027943}, {2.2954829420678085, 2.9763034938899464}, 
    {2.3135853898029595, 2.98356568610482}, {1.6864146101970388, \
2.98356568610482}}], 
  Line[{{1.6717384590328979, 2.9745950829027943}, {1.6283514237703351, \
2.9474883844565616}, {2.241966762693565, 2.9540812792513704}, 
    {2.2954829420678085, 2.9763034938899464}, {1.6717384590328979, \
2.9745950829027943}}], 
  Line[{{1.6283514237703351, 2.9474883844565616}, {1.5581497260444177, \
2.9017190909782276}, {2.1553757655180017, 2.9156867970745455}, 
    {2.241966762693565, 2.9540812792513704}, {1.6283514237703351, \
2.9474883844565616}}], 
  Line[{{1.5581497260444177, 2.9017190909782276}, {1.4642015169108888, \
2.836596676593442}, {2.039494392627396, 2.859399797409293}, 
    {2.1553757655180017, 2.9156867970745455}, {1.5581497260444177, \
2.9017190909782276}}], 
  Line[{{1.4642015169108888, 2.836596676593442}, {1.3506127839224091, \
2.751525170659194}, {1.8993872160775895, 2.7833940695732022}, 
    {2.039494392627396, 2.859399797409293}, {1.4642015169108888, \
2.836596676593442}}], 
  Line[{{1.3506127839224091, 2.751525170659194}, {1.2223478997697876, \
2.646328981764321}, {1.7411775917926318, 2.686221801523239}, 
    {1.8993872160775895, 2.7833940695732022}, {1.3506127839224091, \
2.751525170659194}}], 
  Line[{{1.2223478997697876, 2.646328981764321}, {1.0850126553736965, \
2.5216249314090464}, {1.5717800395277828, 2.567335508777075}, 
    {1.7411775917926318, 2.686221801523239}, {1.2223478997697876, \
2.646328981764321}}], 
  Line[{{1.0850126553736965, 2.5216249314090464}, {0.9446092599218617, \
2.3792297776658287}, {1.3985980451766564, 2.427623046285348}, 
    {1.5717800395277828, 2.567335508777075}, {1.0850126553736965, \
2.5216249314090464}}], 
  Line[{{0.9446092599218617, 2.3792297776658287}, {0.8072740155257703, \
2.222607239695348}, {1.2292004929118074, 2.2699589047379565}, 
    {1.3985980451766564, 2.427623046285348}, {0.9446092599218617, \
2.3792297776658287}}], 
  Line[{{0.8072740155257703, 2.222607239695348}, {0.6790091313731493, \
2.0573688751735335}, {1.07099086862685, 2.099799626225554}, 
    {1.2292004929118074, 2.2699589047379565}, {0.8072740155257703, \
2.222607239695348}}], 
  Line[{{0.6790091313731493, 2.0573688751735335}, {0.5654203983846692, \
1.8918241808350187}, {0.9308836920770429, 1.9258466260207312}, 
    {1.07099086862685, 2.099799626225554}, {0.6790091313731493, \
2.0573688751735335}}], 
  Line[{{0.5654203983846692, 1.8918241808350187}, {0.47147218925114043, \
1.7374623647519978}, {0.8150023191864373, 1.760690570377689}, 
    {0.9308836920770429, 1.9258466260207312}, {0.5654203983846692, \
1.8918241808350187}}], 
  Line[{{0.47147218925114043, 1.7374623647519978}, {0.40127049152522337, \
1.6089224974238359}, {0.7284113220108746, 1.6209688555409116}, 
    {0.8150023191864373, 1.760690570377689}, {0.47147218925114043, \
1.7374623647519978}}], 
  Line[{{0.40127049152522337, 1.6089224974238359}, {0.35788345626266027, \
1.5224519023538965}, {0.6748951426366303, 1.525787133086728}, 
    {0.7284113220108746, 1.6209688555409116}, {0.40127049152522337, \
1.6089224974238359}}], 
  Line[{{0.35788345626266027, 1.5224519023538965}, {0.3432073050985194, \
1.49178284305241}, {0.6567926949014797, 1.4917828430524098}, 
    {0.6748951426366303, 1.525787133086728}, {0.35788345626266027, \
1.5224519023538965}}], 
  Line[{{0.3432073050985194, 1.49178284305241}, {0.35788345626266027, \
1.5224519023538965}, {0.6748951426366303, 1.5257871330867279}, 
    {0.6567926949014797, 1.4917828430524098}, {0.3432073050985194, \
1.49178284305241}}], 
  Line[{{0.35788345626266027, 1.5224519023538965}, {0.40127049152522326, \
1.6089224974238354}, {0.7284113220108744, 1.6209688555409114}, 
    {0.6748951426366303, 1.5257871330867279}, {0.35788345626266027, \
1.5224519023538965}}], 
  Line[{{0.40127049152522326, 1.6089224974238354}, {0.4714721892511405, \
1.7374623647519976}, {0.8150023191864375, 1.7606905703776887}, 
    {0.7284113220108744, 1.6209688555409114}, {0.40127049152522326, \
1.6089224974238354}}], 
  Line[{{0.4714721892511405, 1.7374623647519976}, {0.5654203983846688, \
1.8918241808350182}, {0.9308836920770425, 1.9258466260207305}, 
    {0.8150023191864375, 1.7606905703776887}, {0.4714721892511405, \
1.7374623647519976}}], 
  Line[{{0.5654203983846688, 1.8918241808350182}, {0.6790091313731489, \
2.0573688751735326}, {1.0709908686268492, 2.099799626225553}, 
    {0.9308836920770425, 1.9258466260207305}, {0.5654203983846688, \
1.8918241808350182}}], 
  Line[{{0.6790091313731489, 2.0573688751735326}, {0.80727401552577, \
2.2226072396953476}, {1.229200492911807, 2.269958904737956}, 
    {1.0709908686268492, 2.099799626225553}, {0.6790091313731489, \
2.0573688751735326}}], 
  Line[{{0.80727401552577, 2.2226072396953476}, {0.9446092599218614, \
2.379229777665828}, {1.3985980451766555, 2.4276230462853476}, 
    {1.229200492911807, 2.269958904737956}, {0.80727401552577, \
2.2226072396953476}}], 
  Line[{{0.9446092599218614, 2.379229777665828}, {1.0850126553736956, \
2.521624931409046}, {1.571780039527782, 2.5673355087770746}, 
    {1.3985980451766555, 2.4276230462853476}, {0.9446092599218614, \
2.379229777665828}}], 
  Line[{{1.0850126553736956, 2.521624931409046}, {1.2223478997697876, \
2.646328981764321}, {1.7411775917926315, 2.686221801523239}, 
    {1.571780039527782, 2.5673355087770746}, {1.0850126553736956, \
2.521624931409046}}], 
  Line[{{1.2223478997697876, 2.646328981764321}, {1.3506127839224085, \
2.7515251706591934}, {1.8993872160775886, 2.7833940695732022}, 
    {1.7411775917926315, 2.686221801523239}, {1.2223478997697876, \
2.646328981764321}}], 
  Line[{{1.3506127839224085, 2.7515251706591934}, {1.4642015169108888, \
2.836596676593442}, {2.039494392627396, 2.859399797409293}, 
    {1.8993872160775886, 2.7833940695732022}, {1.3506127839224085, \
2.7515251706591934}}], 
  Line[{{1.4642015169108888, 2.836596676593442}, {1.5581497260444177, \
2.9017190909782276}, {2.1553757655180017, 2.9156867970745455}, 
    {2.039494392627396, 2.859399797409293}, {1.4642015169108888, \
2.836596676593442}}], 
  Line[{{1.5581497260444177, 2.9017190909782276}, {1.628351423770335, \
2.9474883844565616}, {2.241966762693565, 2.95408127925137}, 
    {2.1553757655180017, 2.9156867970745455}, {1.5581497260444177, \
2.9017190909782276}}], 
  Line[{{1.628351423770335, 2.9474883844565616}, {1.6717384590328979, \
2.9745950829027943}, {2.2954829420678085, 2.9763034938899464}, 
    {2.241966762693565, 2.95408127925137}, {1.628351423770335, \
2.9474883844565616}}], 
  Line[{{1.6717384590328979, 2.9745950829027943}, {1.6864146101970388, \
2.98356568610482}, {2.3135853898029595, 2.98356568610482}, 
    {2.2954829420678085, 2.9763034938899464}, {1.6717384590328979, \
2.9745950829027943}}], 
  Line[{{1.6864146101970388, 2.98356568610482}, {1.6717384590328983, \
2.974595082902794}, {2.2954829420678093, 2.9763034938899464}, 
    {2.3135853898029595, 2.98356568610482}, {1.6864146101970388, \
2.98356568610482}}], 
  Line[{{1.6717384590328983, 2.974595082902794}, {1.6283514237703351, \
2.947488384456561}, {2.241966762693565, 2.9540812792513704}, 
    {2.2954829420678093, 2.9763034938899464}, {1.6717384590328983, \
2.974595082902794}}], 
  Line[{{1.6283514237703351, 2.947488384456561}, {1.558149726044418, \
2.9017190909782276}, {2.155375765518002, 2.9156867970745455}, 
    {2.241966762693565, 2.9540812792513704}, {1.6283514237703351, \
2.947488384456561}}], 
  Line[{{1.558149726044418, 2.9017190909782276}, {1.4642015169108895, \
2.836596676593442}, {2.0394943926273967, 2.859399797409293}, 
    {2.155375765518002, 2.9156867970745455}, {1.558149726044418, \
2.9017190909782276}}], 
  Line[{{1.4642015169108895, 2.836596676593442}, {1.3506127839224094, \
2.751525170659194}, {1.8993872160775902, 2.7833940695732027}, 
    {2.0394943926273967, 2.859399797409293}, {1.4642015169108895, \
2.836596676593442}}], 
  Line[{{1.3506127839224094, 2.751525170659194}, {1.2223478997697883, \
2.646328981764321}, {1.7411775917926322, 2.6862218015232395}, 
    {1.8993872160775902, 2.7833940695732027}, {1.3506127839224094, \
2.751525170659194}}], 
  Line[{{1.2223478997697883, 2.646328981764321}, {1.085012655373697, \
2.521624931409047}, {1.5717800395277832, 2.5673355087770755}, 
    {1.7411775917926322, 2.6862218015232395}, {1.2223478997697883, \
2.646328981764321}}], 
  Line[{{1.085012655373697, 2.521624931409047}, {0.9446092599218623, \
2.379229777665829}, {1.3985980451766569, 2.4276230462853485}, 
    {1.5717800395277832, 2.5673355087770755}, {1.085012655373697, \
2.521624931409047}}], 
  Line[{{0.9446092599218623, 2.379229777665829}, {0.8072740155257706, \
2.222607239695348}, {1.2292004929118077, 2.269958904737957}, 
    {1.3985980451766569, 2.4276230462853485}, {0.9446092599218623, \
2.379229777665829}}], 
  Line[{{0.8072740155257706, 2.222607239695348}, {0.6790091313731498, \
2.057368875173534}, {1.0709908686268503, 2.0997996262255545}, 
    {1.2292004929118077, 2.269958904737957}, {0.8072740155257706, \
2.222607239695348}}], 
  Line[{{0.6790091313731498, 2.057368875173534}, {0.5654203983846697, \
1.8918241808350196}, {0.9308836920770434, 1.9258466260207323}, 
    {1.0709908686268503, 2.0997996262255545}, {0.6790091313731498, \
2.057368875173534}}], 
  Line[{{0.5654203983846697, 1.8918241808350196}, {0.4714721892511406, \
1.7374623647519978}, {0.8150023191864375, 1.760690570377689}, 
    {0.9308836920770434, 1.9258466260207323}, {0.5654203983846697, \
1.8918241808350196}}], 
  Line[{{0.4714721892511406, 1.7374623647519978}, {0.40127049152522365, \
1.608922497423836}, {0.728411322010875, 1.620968855540912}, 
    {0.8150023191864375, 1.760690570377689}, {0.4714721892511406, \
1.7374623647519978}}], 
  Line[{{0.40127049152522365, 1.608922497423836}, {0.3578834562626605, \
1.5224519023538967}, {0.6748951426366308, 1.5257871330867285}, 
    {0.728411322010875, 1.620968855540912}, {0.40127049152522365, \
1.608922497423836}}], 
  Line[{{0.3578834562626605, 1.5224519023538967}, {0.3432073050985194, \
1.49178284305241}, {0.6567926949014797, 1.4917828430524098}, 
    {0.6748951426366308, 1.5257871330867285}, {0.3578834562626605, \
1.5224519023538967}}], 
  Line[{{0.3432073050985194, 1.49178284305241}, {0.35788345626266016, \
1.5224519023538963}, {0.6748951426366302, 1.5257871330867274}, 
    {0.6567926949014797, 1.4917828430524098}, {0.3432073050985194, \
1.49178284305241}}], 
  Line[{{0.35788345626266016, 1.5224519023538963}, {0.40127049152522287, \
1.608922497423835}, {0.7284113220108738, 1.6209688555409107}, 
    {0.6748951426366302, 1.5257871330867274}, {0.35788345626266016, \
1.5224519023538963}}], 
  Line[{{0.40127049152522287, 1.608922497423835}, {0.4714721892511403, \
1.7374623647519973}, {0.8150023191864373, 1.7606905703776887}, 
    {0.7284113220108738, 1.6209688555409107}, {0.40127049152522287, \
1.608922497423835}}], 
  Line[{{0.4714721892511403, 1.7374623647519973}, {0.5654203983846685, \
1.8918241808350178}, {0.930883692077042, 1.92584662602073}, 
    {0.8150023191864373, 1.7606905703776887}, {0.4714721892511403, \
1.7374623647519973}}], 
  Line[{{0.5654203983846685, 1.8918241808350178}, {0.6790091313731483, \
2.057368875173532}, {1.0709908686268486, 2.0997996262255523}, 
    {0.930883692077042, 1.92584662602073}, {0.5654203983846685, \
1.8918241808350178}}], 
  Line[{{0.6790091313731483, 2.057368875173532}, {0.80727401552577, \
2.2226072396953476}, {1.229200492911807, 2.269958904737956}, 
    {1.0709908686268486, 2.0997996262255523}, {0.6790091313731483, \
2.057368875173532}}], 
  Line[{{0.80727401552577, 2.2226072396953476}, {0.944609259921861, \
2.379229777665828}, {1.3985980451766553, 2.427623046285347}, 
    {1.229200492911807, 2.269958904737956}, {0.80727401552577, \
2.2226072396953476}}], 
  Line[{{0.944609259921861, 2.379229777665828}, {1.085012655373695, \
2.521624931409045}, {1.571780039527781, 2.5673355087770737}, 
    {1.3985980451766553, 2.427623046285347}, {0.944609259921861, \
2.379229777665828}}], 
  Line[{{1.085012655373695, 2.521624931409045}, {1.2223478997697876, \
2.646328981764321}, {1.7411775917926318, 2.686221801523239}, 
    {1.571780039527781, 2.5673355087770737}, {1.085012655373695, \
2.521624931409045}}], 
  Line[{{1.2223478997697876, 2.646328981764321}, {1.3506127839224085, \
2.7515251706591934}, {1.8993872160775886, 2.7833940695732022}, 
    {1.7411775917926318, 2.686221801523239}, {1.2223478997697876, \
2.646328981764321}}], 
  Line[{{1.3506127839224085, 2.7515251706591934}, {1.4642015169108882, \
2.836596676593441}, {2.0394943926273954, 2.8593997974092926}, 
    {1.8993872160775886, 2.7833940695732022}, {1.3506127839224085, \
2.7515251706591934}}], 
  Line[{{1.4642015169108882, 2.836596676593441}, {1.5581497260444177, \
2.901719090978228}, {2.1553757655180017, 2.9156867970745455}, 
    {2.0394943926273954, 2.8593997974092926}, {1.4642015169108882, \
2.836596676593441}}], 
  Line[{{1.5581497260444177, 2.901719090978228}, {1.628351423770335, \
2.9474883844565616}, {2.241966762693565, 2.95408127925137}, 
    {2.1553757655180017, 2.9156867970745455}, {1.5581497260444177, \
2.901719090978228}}], 
  Line[{{1.628351423770335, 2.9474883844565616}, {1.671738459032898, \
2.9745950829027943}, {2.295482942067809, 2.9763034938899455}, 
    {2.241966762693565, 2.95408127925137}, {1.628351423770335, \
2.9474883844565616}}], 
  Line[{{1.671738459032898, 2.9745950829027943}, {1.6864146101970388, \
2.98356568610482}, {2.3135853898029595, 2.98356568610482}, 
    {2.295482942067809, 2.9763034938899455}, {1.671738459032898, \
2.9745950829027943}}], 
  Line[{{2.3135853898029595, 2.98356568610482}, {2.2954829420678085, \
2.9763034938899464}, {2.9055971116193557, 2.8487773266631815}, 
    {2.9270509831248424, 2.8531695488854605}, {2.3135853898029595, \
2.98356568610482}}], 
  Line[{{2.2954829420678085, 2.9763034938899464}, {2.241966762693565, \
2.9540812792513704}, {2.842173134234785, 2.834803496770629}, 
    {2.9055971116193557, 2.8487773266631815}, {2.2954829420678085, \
2.9763034938899464}}], 
  Line[{{2.241966762693565, 2.9540812792513704}, {2.1553757655180017, \
2.9156867970745455}, {2.739550983124842, 2.809014835019403}, 
    {2.842173134234785, 2.834803496770629}, {2.241966762693565, \
2.9540812792513704}}], 
  Line[{{2.1553757655180017, 2.9156867970745455}, {2.039494392627396, \
2.859399797409293}, {2.602215738728751, 2.768181798733441}, 
    {2.739550983124842, 2.809014835019403}, {2.1553757655180017, \
2.9156867970745455}}], 
  Line[{{2.039494392627396, 2.859399797409293}, {1.8993872160775895, \
2.7833940695732022}, {2.4361696102342374, 2.7087103854853694}, 
    {2.602215738728751, 2.768181798733441}, {2.039494392627396, \
2.859399797409293}}], 
  Line[{{1.8993872160775895, 2.7833940695732022}, {1.7411775917926318, \
2.686221801523239}, {2.248669610234237, 2.6273597595826383}, 
    {2.4361696102342374, 2.7087103854853694}, {1.8993872160775895, \
2.7833940695732022}}], 
  Line[{{1.7411775917926318, 2.686221801523239}, {1.5717800395277828, \
2.567335508777075}, {2.047910388453574, 2.521960112821855}, 
    {2.248669610234237, 2.6273597595826383}, {1.7411775917926318, \
2.686221801523239}}], 
  Line[{{1.5717800395277828, 2.567335508777075}, {1.3985980451766564, \
2.427623046285348}, {1.8426660862336899, 2.392089327116677}, 
    {2.047910388453574, 2.521960112821855}, {1.5717800395277828, \
2.567335508777075}}], 
  Line[{{1.3985980451766564, 2.427623046285348}, {1.2292004929118074, \
2.2699589047379565}, {1.6419068644530264, 2.239718051509763}, 
    {1.8426660862336899, 2.392089327116677}, {1.3985980451766564, \
2.427623046285348}}], 
  Line[{{1.2292004929118074, 2.2699589047379565}, {1.07099086862685, \
2.099799626225554}, {1.4544068644530266, 2.0698782028004876}, 
    {1.6419068644530264, 2.239718051509763}, {1.2292004929118074, \
2.2699589047379565}}], 
  Line[{{1.07099086862685, 2.099799626225554}, {0.9308836920770429, \
1.9258466260207312}, {1.2883607359585132, 1.8914277190459865}, 
    {1.4544068644530266, 2.0698782028004876}, {1.07099086862685, \
2.099799626225554}}], 
  Line[{{0.9308836920770429, 1.9258466260207312}, {0.8150023191864373, \
1.760690570377689}, {1.151025491562421, 1.7178957504272223}, 
    {1.2883607359585132, 1.8914277190459865}, {0.9308836920770429, \
1.9258466260207312}}], 
  Line[{{0.8150023191864373, 1.760690570377689}, {0.7284113220108746, \
1.6209688555409116}, {1.0484033404524793, 1.5679671136605229}, 
    {1.151025491562421, 1.7178957504272223}, {0.8150023191864373, \
1.760690570377689}}], 
  Line[{{0.7284113220108746, 1.6209688555409116}, {0.6748951426366303, \
1.525787133086728}, {0.9849793630679075, 1.464075901868194}, 
    {1.0484033404524793, 1.5679671136605229}, {0.7284113220108746, \
1.6209688555409116}}], 
  Line[{{0.6748951426366303, 1.525787133086728}, {0.6567926949014797, \
1.4917828430524098}, {0.9635254915624212, 1.4265847744427302}, 
    {0.9849793630679075, 1.464075901868194}, {0.6748951426366303, \
1.525787133086728}}], 
  Line[{{0.6567926949014797, 1.4917828430524098}, {0.6748951426366303, \
1.5257871330867279}, {0.9849793630679075, 1.4640759018681935}, 
    {0.9635254915624212, 1.4265847744427302}, {0.6567926949014797, \
1.4917828430524098}}], 
  Line[{{0.6748951426366303, 1.5257871330867279}, {0.7284113220108744, \
1.6209688555409114}, {1.0484033404524793, 1.5679671136605227}, 
    {0.9849793630679075, 1.4640759018681935}, {0.6748951426366303, \
1.5257871330867279}}], 
  Line[{{0.7284113220108744, 1.6209688555409114}, {0.8150023191864375, \
1.7606905703776887}, {1.1510254915624212, 1.7178957504272216}, 
    {1.0484033404524793, 1.5679671136605227}, {0.7284113220108744, \
1.6209688555409114}}], 
  Line[{{0.8150023191864375, 1.7606905703776887}, {0.9308836920770425, \
1.9258466260207305}, {1.2883607359585123, 1.8914277190459858}, 
    {1.1510254915624212, 1.7178957504272216}, {0.8150023191864375, \
1.7606905703776887}}], 
  Line[{{0.9308836920770425, 1.9258466260207305}, {1.0709908686268492, \
2.099799626225553}, {1.4544068644530257, 2.069878202800487}, 
    {1.2883607359585123, 1.8914277190459858}, {0.9308836920770425, \
1.9258466260207305}}], 
  Line[{{1.0709908686268492, 2.099799626225553}, {1.229200492911807, \
2.269958904737956}, {1.6419068644530261, 2.239718051509763}, 
    {1.4544068644530257, 2.069878202800487}, {1.0709908686268492, \
2.099799626225553}}], 
  Line[{{1.229200492911807, 2.269958904737956}, {1.3985980451766555, \
2.4276230462853476}, {1.842666086233689, 2.3920893271166768}, 
    {1.6419068644530261, 2.239718051509763}, {1.229200492911807, \
2.269958904737956}}], 
  Line[{{1.3985980451766555, 2.4276230462853476}, {1.571780039527782, \
2.5673355087770746}, {2.0479103884535728, 2.521960112821855}, 
    {1.842666086233689, 2.3920893271166768}, {1.3985980451766555, \
2.4276230462853476}}], 
  Line[{{1.571780039527782, 2.5673355087770746}, {1.7411775917926315, \
2.686221801523239}, {2.248669610234237, 2.627359759582638}, 
    {2.0479103884535728, 2.521960112821855}, {1.571780039527782, \
2.5673355087770746}}], 
  Line[{{1.7411775917926315, 2.686221801523239}, {1.8993872160775886, \
2.7833940695732022}, {2.436169610234236, 2.70871038548537}, 
    {2.248669610234237, 2.627359759582638}, {1.7411775917926315, \
2.686221801523239}}], 
  Line[{{1.8993872160775886, 2.7833940695732022}, {2.039494392627396, \
2.859399797409293}, {2.6022157387287503, 2.7681817987334414}, 
    {2.436169610234236, 2.70871038548537}, {1.8993872160775886, \
2.7833940695732022}}], 
  Line[{{2.039494392627396, 2.859399797409293}, {2.1553757655180017, \
2.9156867970745455}, {2.739550983124842, 2.809014835019403}, 
    {2.6022157387287503, 2.7681817987334414}, {2.039494392627396, \
2.859399797409293}}], 
  Line[{{2.1553757655180017, 2.9156867970745455}, {2.241966762693565, \
2.95408127925137}, {2.842173134234784, 2.834803496770629}, 
    {2.739550983124842, 2.809014835019403}, {2.1553757655180017, \
2.9156867970745455}}], 
  Line[{{2.241966762693565, 2.95408127925137}, {2.2954829420678085, \
2.9763034938899464}, {2.9055971116193557, 2.8487773266631815}, 
    {2.842173134234784, 2.834803496770629}, {2.241966762693565, \
2.95408127925137}}], 
  Line[{{2.2954829420678085, 2.9763034938899464}, {2.3135853898029595, \
2.98356568610482}, {2.9270509831248424, 2.8531695488854605}, 
    {2.9055971116193557, 2.8487773266631815}, {2.2954829420678085, \
2.9763034938899464}}], 
  Line[{{2.3135853898029595, 2.98356568610482}, {2.2954829420678093, \
2.9763034938899464}, {2.9055971116193566, 2.8487773266631806}, 
    {2.9270509831248424, 2.8531695488854605}, {2.3135853898029595, \
2.98356568610482}}], 
  Line[{{2.2954829420678093, 2.9763034938899464}, {2.241966762693565, \
2.9540812792513704}, {2.8421731342347845, 2.8348034967706295}, 
    {2.9055971116193566, 2.8487773266631806}, {2.2954829420678093, \
2.9763034938899464}}], 
  Line[{{2.241966762693565, 2.9540812792513704}, {2.155375765518002, \
2.9156867970745455}, {2.739550983124843, 2.8090148350194024}, 
    {2.8421731342347845, 2.8348034967706295}, {2.241966762693565, \
2.9540812792513704}}], 
  Line[{{2.155375765518002, 2.9156867970745455}, {2.0394943926273967, \
2.859399797409293}, {2.6022157387287517, 2.7681817987334414}, 
    {2.739550983124843, 2.8090148350194024}, {2.155375765518002, \
2.9156867970745455}}], 
  Line[{{2.0394943926273967, 2.859399797409293}, {1.8993872160775902, \
2.7833940695732027}, {2.436169610234238, 2.70871038548537}, 
    {2.6022157387287517, 2.7681817987334414}, {2.0394943926273967, \
2.859399797409293}}], 
  Line[{{1.8993872160775902, 2.7833940695732027}, {1.7411775917926322, \
2.6862218015232395}, {2.2486696102342374, 2.6273597595826383}, 
    {2.436169610234238, 2.70871038548537}, {1.8993872160775902, \
2.7833940695732027}}], 
  Line[{{1.7411775917926322, 2.6862218015232395}, {1.5717800395277832, \
2.5673355087770755}, {2.047910388453575, 2.521960112821855}, 
    {2.2486696102342374, 2.6273597595826383}, {1.7411775917926322, \
2.6862218015232395}}], 
  Line[{{1.5717800395277832, 2.5673355087770755}, {1.3985980451766569, \
2.4276230462853485}, {1.8426660862336905, 2.3920893271166777}, 
    {2.047910388453575, 2.521960112821855}, {1.5717800395277832, \
2.5673355087770755}}], 
  Line[{{1.3985980451766569, 2.4276230462853485}, {1.2292004929118077, \
2.269958904737957}, {1.641906864453027, 2.239718051509763}, 
    {1.8426660862336905, 2.3920893271166777}, {1.3985980451766569, \
2.4276230462853485}}], 
  Line[{{1.2292004929118077, 2.269958904737957}, {1.0709908686268503, \
2.0997996262255545}, {1.4544068644530275, 2.069878202800488}, 
    {1.641906864453027, 2.239718051509763}, {1.2292004929118077, \
2.269958904737957}}], 
  Line[{{1.0709908686268503, 2.0997996262255545}, {0.9308836920770434, \
1.9258466260207323}, {1.2883607359585136, 1.8914277190459876}, 
    {1.4544068644530275, 2.069878202800488}, {1.0709908686268503, \
2.0997996262255545}}], 
  Line[{{0.9308836920770434, 1.9258466260207323}, {0.8150023191864375, \
1.760690570377689}, {1.1510254915624212, 1.7178957504272223}, 
    {1.2883607359585136, 1.8914277190459876}, {0.9308836920770434, \
1.9258466260207323}}], 
  Line[{{0.8150023191864375, 1.760690570377689}, {0.728411322010875, \
1.620968855540912}, {1.0484033404524797, 1.5679671136605233}, 
    {1.1510254915624212, 1.7178957504272223}, {0.8150023191864375, \
1.760690570377689}}], 
  Line[{{0.728411322010875, 1.620968855540912}, {0.6748951426366308, \
1.5257871330867285}, {0.9849793630679078, 1.4640759018681944}, 
    {1.0484033404524797, 1.5679671136605233}, {0.728411322010875, \
1.620968855540912}}], 
  Line[{{0.6748951426366308, 1.5257871330867285}, {0.6567926949014797, \
1.4917828430524098}, {0.9635254915624212, 1.4265847744427302}, 
    {0.9849793630679078, 1.4640759018681944}, {0.6748951426366308, \
1.5257871330867285}}], 
  Line[{{0.6567926949014797, 1.4917828430524098}, {0.6748951426366302, \
1.5257871330867274}, {0.9849793630679072, 1.4640759018681933}, 
    {0.9635254915624212, 1.4265847744427302}, {0.6567926949014797, \
1.4917828430524098}}], 
  Line[{{0.6748951426366302, 1.5257871330867274}, {0.7284113220108738, \
1.6209688555409107}, {1.0484033404524786, 1.5679671136605218}, 
    {0.9849793630679072, 1.4640759018681933}, {0.6748951426366302, \
1.5257871330867274}}], 
  Line[{{0.7284113220108738, 1.6209688555409107}, {0.8150023191864373, \
1.7606905703776887}, {1.151025491562421, 1.7178957504272216}, 
    {1.0484033404524786, 1.5679671136605218}, {0.7284113220108738, \
1.6209688555409107}}], 
  Line[{{0.8150023191864373, 1.7606905703776887}, {0.930883692077042, \
1.92584662602073}, {1.288360735958512, 1.8914277190459854}, 
    {1.151025491562421, 1.7178957504272216}, {0.8150023191864373, \
1.7606905703776887}}], 
  Line[{{0.930883692077042, 1.92584662602073}, {1.0709908686268486, \
2.0997996262255523}, {1.4544068644530252, 2.069878202800486}, 
    {1.288360735958512, 1.8914277190459854}, {0.930883692077042, \
1.92584662602073}}], 
  Line[{{1.0709908686268486, 2.0997996262255523}, {1.229200492911807, \
2.269958904737956}, {1.6419068644530261, 2.239718051509763}, 
    {1.4544068644530252, 2.069878202800486}, {1.0709908686268486, \
2.0997996262255523}}], 
  Line[{{1.229200492911807, 2.269958904737956}, {1.3985980451766553, \
2.427623046285347}, {1.8426660862336885, 2.3920893271166768}, 
    {1.6419068644530261, 2.239718051509763}, {1.229200492911807, \
2.269958904737956}}], 
  Line[{{1.3985980451766553, 2.427623046285347}, {1.571780039527781, \
2.5673355087770737}, {2.047910388453572, 2.521960112821854}, 
    {1.8426660862336885, 2.3920893271166768}, {1.3985980451766553, \
2.427623046285347}}], 
  Line[{{1.571780039527781, 2.5673355087770737}, {1.7411775917926318, \
2.686221801523239}, {2.248669610234237, 2.6273597595826383}, 
    {2.047910388453572, 2.521960112821854}, {1.571780039527781, \
2.5673355087770737}}], 
  Line[{{1.7411775917926318, 2.686221801523239}, {1.8993872160775886, \
2.7833940695732022}, {2.436169610234236, 2.7087103854853694}, 
    {2.248669610234237, 2.6273597595826383}, {1.7411775917926318, \
2.686221801523239}}], 
  Line[{{1.8993872160775886, 2.7833940695732022}, {2.0394943926273954, \
2.8593997974092926}, {2.602215738728749, 2.7681817987334414}, 
    {2.436169610234236, 2.7087103854853694}, {1.8993872160775886, \
2.7833940695732022}}], 
  Line[{{2.0394943926273954, 2.8593997974092926}, {2.1553757655180017, \
2.9156867970745455}, {2.739550983124842, 2.809014835019403}, 
    {2.602215738728749, 2.7681817987334414}, {2.0394943926273954, \
2.8593997974092926}}], 
  Line[{{2.1553757655180017, 2.9156867970745455}, {2.241966762693565, \
2.95408127925137}, {2.842173134234784, 2.834803496770629}, 
    {2.739550983124842, 2.809014835019403}, {2.1553757655180017, \
2.9156867970745455}}], 
  Line[{{2.241966762693565, 2.95408127925137}, {2.295482942067809, \
2.9763034938899455}, {2.905597111619356, 2.848777326663181}, 
    {2.842173134234784, 2.834803496770629}, {2.241966762693565, \
2.95408127925137}}], 
  Line[{{2.295482942067809, 2.9763034938899455}, {2.3135853898029595, \
2.98356568610482}, {2.9270509831248424, 2.8531695488854605}, 
    {2.905597111619356, 2.848777326663181}, {2.295482942067809, \
2.9763034938899455}}], 
  Line[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193557, \
2.8487773266631815}, {3.4754160508255305, 2.5979598975817524}, 
    {3.4999999999999996, 2.598076211353316}, {2.9270509831248424, \
2.8531695488854605}}], 
  Line[{{2.9055971116193557, 2.8487773266631815}, {2.842173134234785, \
2.834803496770629}, {3.402738639847926, 2.5962550390555568}, 
    {3.4754160508255305, 2.5979598975817524}, {2.9055971116193557, \
2.8487773266631815}}], 
  Line[{{2.842173134234785, 2.834803496770629}, {2.739550983124842, \
2.809014835019403}, {3.285144118671815, 2.5891768866299363}, 
    {3.402738639847926, 2.5962550390555568}, {2.842173134234785, \
2.834803496770629}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.602215738728751, \
2.768181798733441}, {3.1277719321537143, 2.5712732770958877}, 
    {3.285144118671815, 2.5891768866299363}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.602215738728751, 2.768181798733441}, {2.4361696102342374, \
2.7087103854853694}, {2.9375, 2.536452985962878}, 
    {3.1277719321537143, 2.5712732770958877}, {2.602215738728751, \
2.768181798733441}}], 
  Line[{{2.4361696102342374, 2.7087103854853694}, {2.248669610234237, \
2.6273597595826383}, {2.7226441186718153, 2.479055835144598}, 
    {2.9375, 2.536452985962878}, {2.4361696102342374, 2.7087103854853694}}], 
  Line[{{2.248669610234237, 2.6273597595826383}, {2.047910388453574, \
2.521960112821855}, {2.4925945211761102, 2.394814022264695}, 
    {2.7226441186718153, 2.479055835144598}, {2.248669610234237, \
2.6273597595826383}}], 
  Line[{{2.047910388453574, 2.521960112821855}, {1.8426660862336899, \
2.392089327116677}, {2.2574054788238893, 2.281657041700859}, 
    {2.4925945211761102, 2.394814022264695}, {2.047910388453574, \
2.521960112821855}}], 
  Line[{{1.8426660862336899, 2.392089327116677}, {1.6419068644530264, \
2.239718051509763}, {2.027355881328184, 2.14040166785146}, 
    {2.2574054788238893, 2.281657041700859}, {1.8426660862336899, \
2.392089327116677}}], 
  Line[{{1.6419068644530264, 2.239718051509763}, {1.4544068644530266, \
2.0698782028004876}, {1.8124999999999998, 1.9754350786598887}, 
    {2.027355881328184, 2.14040166785146}, {1.6419068644530264, \
2.239718051509763}}], 
  Line[{{1.4544068644530266, 2.0698782028004876}, {1.2883607359585132, \
1.8914277190459865}, {1.6222280678462844, 1.7955424168801202}, 
    {1.8124999999999998, 1.9754350786598887}, {1.4544068644530266, \
2.0698782028004876}}], 
  Line[{{1.2883607359585132, 1.8914277190459865}, {1.151025491562421, \
1.7178957504272223}, {1.4648558813281836, 1.61498867371741}, 
    {1.6222280678462844, 1.7955424168801202}, {1.2883607359585132, \
1.8914277190459865}}], 
  Line[{{1.151025491562421, 1.7178957504272223}, {1.0484033404524793, \
1.5679671136605229}, {1.3472613601520738, 1.4545502220637494}, 
    {1.4648558813281836, 1.61498867371741}, {1.151025491562421, \
1.7178957504272223}}], 
  Line[{{1.0484033404524793, 1.5679671136605229}, {0.9849793630679075, \
1.464075901868194}, {1.2745839491744684, 1.340717494749769}, 
    {1.3472613601520738, 1.4545502220637494}, {1.0484033404524793, \
1.5679671136605229}}], 
  Line[{{0.9849793630679075, 1.464075901868194}, {0.9635254915624212, \
1.4265847744427302}, {1.2499999999999996, 1.2990381056766582}, 
    {1.2745839491744684, 1.340717494749769}, {0.9849793630679075, \
1.464075901868194}}], 
  Line[{{0.9635254915624212, 1.4265847744427302}, {0.9849793630679075, \
1.4640759018681935}, {1.2745839491744684, 1.3407174947497689}, 
    {1.2499999999999996, 1.2990381056766582}, {0.9635254915624212, \
1.4265847744427302}}], 
  Line[{{0.9849793630679075, 1.4640759018681935}, {1.0484033404524793, \
1.5679671136605227}, {1.3472613601520735, 1.4545502220637487}, 
    {1.2745839491744684, 1.3407174947497689}, {0.9849793630679075, \
1.4640759018681935}}], 
  Line[{{1.0484033404524793, 1.5679671136605227}, {1.1510254915624212, \
1.7178957504272216}, {1.4648558813281838, 1.6149886737174097}, 
    {1.3472613601520735, 1.4545502220637487}, {1.0484033404524793, \
1.5679671136605227}}], 
  Line[{{1.1510254915624212, 1.7178957504272216}, {1.2883607359585123, \
1.8914277190459858}, {1.622228067846284, 1.7955424168801195}, 
    {1.4648558813281838, 1.6149886737174097}, {1.1510254915624212, \
1.7178957504272216}}], 
  Line[{{1.2883607359585123, 1.8914277190459858}, {1.4544068644530257, \
2.069878202800487}, {1.8124999999999991, 1.975435078659888}, 
    {1.622228067846284, 1.7955424168801195}, {1.2883607359585123, \
1.8914277190459858}}], 
  Line[{{1.4544068644530257, 2.069878202800487}, {1.6419068644530261, \
2.239718051509763}, {2.0273558813281833, 2.1404016678514597}, 
    {1.8124999999999991, 1.975435078659888}, {1.4544068644530257, \
2.069878202800487}}], 
  Line[{{1.6419068644530261, 2.239718051509763}, {1.842666086233689, \
2.3920893271166768}, {2.2574054788238884, 2.2816570417008584}, 
    {2.0273558813281833, 2.1404016678514597}, {1.6419068644530261, \
2.239718051509763}}], 
  Line[{{1.842666086233689, 2.3920893271166768}, {2.0479103884535728, \
2.521960112821855}, {2.492594521176109, 2.394814022264695}, 
    {2.2574054788238884, 2.2816570417008584}, {1.842666086233689, \
2.3920893271166768}}], 
  Line[{{2.0479103884535728, 2.521960112821855}, {2.248669610234237, \
2.627359759582638}, {2.7226441186718153, 2.479055835144598}, 
    {2.492594521176109, 2.394814022264695}, {2.0479103884535728, \
2.521960112821855}}], 
  Line[{{2.248669610234237, 2.627359759582638}, {2.436169610234236, \
2.70871038548537}, {2.9374999999999987, 2.536452985962878}, 
    {2.7226441186718153, 2.479055835144598}, {2.248669610234237, \
2.627359759582638}}], 
  Line[{{2.436169610234236, 2.70871038548537}, {2.6022157387287503, \
2.7681817987334414}, {3.1277719321537147, 2.5712732770958873}, 
    {2.9374999999999987, 2.536452985962878}, {2.436169610234236, \
2.70871038548537}}], 
  Line[{{2.6022157387287503, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {3.2851441186718153, 2.589176886629936}, 
    {3.1277719321537147, 2.5712732770958873}, {2.6022157387287503, \
2.7681817987334414}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {3.4027386398479256, 2.5962550390555554}, 
    {3.2851441186718153, 2.589176886629936}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.842173134234784, 2.834803496770629}, {2.9055971116193557, \
2.8487773266631815}, {3.4754160508255305, 2.5979598975817524}, 
    {3.4027386398479256, 2.5962550390555554}, {2.842173134234784, \
2.834803496770629}}], 
  Line[{{2.9055971116193557, 2.8487773266631815}, {2.9270509831248424, \
2.8531695488854605}, {3.4999999999999996, 2.598076211353316}, 
    {3.4754160508255305, 2.5979598975817524}, {2.9055971116193557, \
2.8487773266631815}}], 
  Line[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193566, \
2.8487773266631806}, {3.4754160508255314, 2.5979598975817515}, 
    {3.4999999999999996, 2.598076211353316}, {2.9270509831248424, \
2.8531695488854605}}], 
  Line[{{2.9055971116193566, 2.8487773266631806}, {2.8421731342347845, \
2.8348034967706295}, {3.402738639847926, 2.5962550390555568}, 
    {3.4754160508255314, 2.5979598975817515}, {2.9055971116193566, \
2.8487773266631806}}], 
  Line[{{2.8421731342347845, 2.8348034967706295}, {2.739550983124843, \
2.8090148350194024}, {3.2851441186718158, 2.589176886629936}, 
    {3.402738639847926, 2.5962550390555568}, {2.8421731342347845, \
2.8348034967706295}}], 
  Line[{{2.739550983124843, 2.8090148350194024}, {2.6022157387287517, \
2.7681817987334414}, {3.1277719321537156, 2.5712732770958877}, 
    {3.2851441186718158, 2.589176886629936}, {2.739550983124843, \
2.8090148350194024}}], 
  Line[{{2.6022157387287517, 2.7681817987334414}, {2.436169610234238, \
2.70871038548537}, {2.9375000000000004, 2.5364529859628786}, 
    {3.1277719321537156, 2.5712732770958877}, {2.6022157387287517, \
2.7681817987334414}}], 
  Line[{{2.436169610234238, 2.70871038548537}, {2.2486696102342374, \
2.6273597595826383}, {2.722644118671816, 2.479055835144598}, 
    {2.9375000000000004, 2.5364529859628786}, {2.436169610234238, \
2.70871038548537}}], 
  Line[{{2.2486696102342374, 2.6273597595826383}, {2.047910388453575, \
2.521960112821855}, {2.492594521176111, 2.3948140222646956}, 
    {2.722644118671816, 2.479055835144598}, {2.2486696102342374, \
2.6273597595826383}}], 
  Line[{{2.047910388453575, 2.521960112821855}, {1.8426660862336905, \
2.3920893271166777}, {2.25740547882389, 2.281657041700859}, 
    {2.492594521176111, 2.3948140222646956}, {2.047910388453575, \
2.521960112821855}}], 
  Line[{{1.8426660862336905, 2.3920893271166777}, {1.641906864453027, \
2.239718051509763}, {2.0273558813281842, 2.14040166785146}, 
    {2.25740547882389, 2.281657041700859}, {1.8426660862336905, \
2.3920893271166777}}], 
  Line[{{1.641906864453027, 2.239718051509763}, {1.4544068644530275, \
2.069878202800488}, {1.8125000000000004, 1.9754350786598895}, 
    {2.0273558813281842, 2.14040166785146}, {1.641906864453027, \
2.239718051509763}}], 
  Line[{{1.4544068644530275, 2.069878202800488}, {1.2883607359585136, \
1.8914277190459876}, {1.6222280678462853, 1.7955424168801213}, 
    {1.8125000000000004, 1.9754350786598895}, {1.4544068644530275, \
2.069878202800488}}], 
  Line[{{1.2883607359585136, 1.8914277190459876}, {1.1510254915624212, \
1.7178957504272223}, {1.4648558813281838, 1.6149886737174104}, 
    {1.6222280678462853, 1.7955424168801213}, {1.2883607359585136, \
1.8914277190459876}}], 
  Line[{{1.1510254915624212, 1.7178957504272223}, {1.0484033404524797, \
1.5679671136605233}, {1.3472613601520744, 1.4545502220637496}, 
    {1.4648558813281838, 1.6149886737174104}, {1.1510254915624212, \
1.7178957504272223}}], 
  Line[{{1.0484033404524797, 1.5679671136605233}, {0.9849793630679078, \
1.4640759018681944}, {1.2745839491744688, 1.3407174947497695}, 
    {1.3472613601520744, 1.4545502220637496}, {1.0484033404524797, \
1.5679671136605233}}], 
  Line[{{0.9849793630679078, 1.4640759018681944}, {0.9635254915624212, \
1.4265847744427302}, {1.2499999999999996, 1.2990381056766582}, 
    {1.2745839491744688, 1.3407174947497695}, {0.9849793630679078, \
1.4640759018681944}}], 
  Line[{{0.9635254915624212, 1.4265847744427302}, {0.9849793630679072, \
1.4640759018681933}, {1.2745839491744682, 1.3407174947497684}, 
    {1.2499999999999996, 1.2990381056766582}, {0.9635254915624212, \
1.4265847744427302}}], 
  Line[{{0.9849793630679072, 1.4640759018681933}, {1.0484033404524786, \
1.5679671136605218}, {1.3472613601520729, 1.454550222063748}, 
    {1.2745839491744682, 1.3407174947497684}, {0.9849793630679072, \
1.4640759018681933}}], 
  Line[{{1.0484033404524786, 1.5679671136605218}, {1.151025491562421, \
1.7178957504272216}, {1.4648558813281836, 1.6149886737174093}, 
    {1.3472613601520729, 1.454550222063748}, {1.0484033404524786, \
1.5679671136605218}}], 
  Line[{{1.151025491562421, 1.7178957504272216}, {1.288360735958512, \
1.8914277190459854}, {1.622228067846283, 1.7955424168801193}, 
    {1.4648558813281836, 1.6149886737174093}, {1.151025491562421, \
1.7178957504272216}}], 
  Line[{{1.288360735958512, 1.8914277190459854}, {1.4544068644530252, \
2.069878202800486}, {1.8124999999999982, 1.975435078659887}, 
    {1.622228067846283, 1.7955424168801193}, {1.288360735958512, \
1.8914277190459854}}], 
  Line[{{1.4544068644530252, 2.069878202800486}, {1.6419068644530261, \
2.239718051509763}, {2.0273558813281833, 2.1404016678514592}, 
    {1.8124999999999982, 1.975435078659887}, {1.4544068644530252, \
2.069878202800486}}], 
  Line[{{1.6419068644530261, 2.239718051509763}, {1.8426660862336885, \
2.3920893271166768}, {2.257405478823888, 2.281657041700858}, 
    {2.0273558813281833, 2.1404016678514592}, {1.6419068644530261, \
2.239718051509763}}], 
  Line[{{1.8426660862336885, 2.3920893271166768}, {2.047910388453572, \
2.521960112821854}, {2.492594521176108, 2.3948140222646943}, 
    {2.257405478823888, 2.281657041700858}, {1.8426660862336885, \
2.3920893271166768}}], 
  Line[{{2.047910388453572, 2.521960112821854}, {2.248669610234237, \
2.6273597595826383}, {2.7226441186718153, 2.479055835144598}, 
    {2.492594521176108, 2.3948140222646943}, {2.047910388453572, \
2.521960112821854}}], 
  Line[{{2.248669610234237, 2.6273597595826383}, {2.436169610234236, \
2.7087103854853694}, {2.9374999999999987, 2.5364529859628777}, 
    {2.7226441186718153, 2.479055835144598}, {2.248669610234237, \
2.6273597595826383}}], 
  Line[{{2.436169610234236, 2.7087103854853694}, {2.602215738728749, \
2.7681817987334414}, {3.1277719321537134, 2.5712732770958864}, 
    {2.9374999999999987, 2.5364529859628777}, {2.436169610234236, \
2.7087103854853694}}], 
  Line[{{2.602215738728749, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {3.2851441186718153, 2.589176886629936}, 
    {3.1277719321537134, 2.5712732770958864}, {2.602215738728749, \
2.7681817987334414}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {3.4027386398479256, 2.5962550390555554}, 
    {3.2851441186718153, 2.589176886629936}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.842173134234784, 2.834803496770629}, {2.905597111619356, \
2.848777326663181}, {3.475416050825531, 2.5979598975817515}, 
    {3.4027386398479256, 2.5962550390555554}, {2.842173134234784, \
2.834803496770629}}], 
  Line[{{2.905597111619356, 2.848777326663181}, {2.9270509831248424, \
2.8531695488854605}, {3.4999999999999996, 2.598076211353316}, 
    {3.475416050825531, 2.5979598975817515}, {2.905597111619356, \
2.848777326663181}}], 
  Line[{{3.4999999999999996, 2.598076211353316}, {3.4754160508255305, \
2.5979598975817524}, {3.98003593774839, 2.235484296800204}, 
    {4.007391819076574, 2.229434476432184}, {3.4999999999999996, \
2.598076211353316}}], 
  Line[{{3.4754160508255305, 2.5979598975817524}, {3.402738639847926, \
2.5962550390555568}, {3.8991638770459622, 2.251331326578102}, 
    {3.98003593774839, 2.235484296800204}, {3.4754160508255305, \
2.5979598975817524}}], 
  Line[{{3.402738639847926, 2.5962550390555568}, {3.285144118671815, \
2.5891768866299363}, {3.768310134089188, 2.270646210820903}, 
    {3.8991638770459622, 2.251331326578102}, {3.402738639847926, \
2.5962550390555568}}], 
  Line[{{3.285144118671815, 2.5891768866299363}, {3.1277719321537143, \
2.5712732770958877}, {3.593193645351204, 2.284543605895154}, 
    {3.768310134089188, 2.270646210820903}, {3.285144118671815, \
2.5891768866299363}}], 
  Line[{{3.1277719321537143, 2.5712732770958877}, {2.9375, \
2.536452985962878}, {3.381467841692003, 2.283369148915068}, 
    {3.593193645351204, 2.284543605895154}, {3.1277719321537143, \
2.5712732770958877}}], 
  Line[{{2.9375, 2.536452985962878}, {2.7226441186718153, 2.479055835144598}, \
{3.1423861567046165, 2.2583039834915453}, 
    {3.381467841692003, 2.283369148915068}, {2.9375, 2.536452985962878}}], 
  Line[{{2.7226441186718153, 2.479055835144598}, {2.4925945211761102, \
2.394814022264695}, {2.886397607264205, 2.202570463435661}, 
    {3.1423861567046165, 2.2583039834915453}, {2.7226441186718153, \
2.479055835144598}}], 
  Line[{{2.4925945211761102, 2.394814022264695}, {2.2574054788238893, \
2.281657041700859}, {2.624690121350657, 2.112263515546569}, 
    {2.886397607264205, 2.202570463435661}, {2.4925945211761102, \
2.394814022264695}}], 
  Line[{{2.2574054788238893, 2.281657041700859}, {2.027355881328184, \
2.14040166785146}, {2.3687015719102447, 1.9869545564435858}, 
    {2.624690121350657, 2.112263515546569}, {2.2574054788238893, \
2.281657041700859}}], 
  Line[{{2.027355881328184, 2.14040166785146}, {1.8124999999999998, \
1.9754350786598887}, {2.129619886922859, 1.83026852905604}, 
    {2.3687015719102447, 1.9869545564435858}, {2.027355881328184, \
2.14040166785146}}], 
  Line[{{1.8124999999999998, 1.9754350786598887}, {1.6222280678462844, \
1.7955424168801202}, {1.9178940832636575, 1.6506863454327518}, 
    {2.129619886922859, 1.83026852905604}, {1.8124999999999998, \
1.9754350786598887}}], 
  Line[{{1.6222280678462844, 1.7955424168801202}, {1.4648558813281836, \
1.61498867371741}, {1.7427775945256727, 1.4628718195622261}, 
    {1.9178940832636575, 1.6506863454327518}, {1.6222280678462844, \
1.7955424168801202}}], 
  Line[{{1.4648558813281836, 1.61498867371741}, {1.3472613601520738, \
1.4545502220637494}, {1.6119238515688996, 1.2895708590441468}, 
    {1.7427775945256727, 1.4628718195622261}, {1.4648558813281836, \
1.61498867371741}}], 
  Line[{{1.3472613601520738, 1.4545502220637494}, {1.2745839491744684, \
1.340717494749769}, {1.5310517908664711, 1.162354288726182}, 
    {1.6119238515688996, 1.2895708590441468}, {1.3472613601520738, \
1.4545502220637494}}], 
  Line[{{1.2745839491744684, 1.340717494749769}, {1.2499999999999996, \
1.2990381056766582}, {1.503695909538287, 1.1147172382160917}, 
    {1.5310517908664711, 1.162354288726182}, {1.2745839491744684, \
1.340717494749769}}], 
  Line[{{1.2499999999999996, 1.2990381056766582}, {1.2745839491744684, \
1.3407174947497689}, {1.5310517908664711, 1.1623542887261817}, 
    {1.503695909538287, 1.1147172382160917}, {1.2499999999999996, \
1.2990381056766582}}], 
  Line[{{1.2745839491744684, 1.3407174947497689}, {1.3472613601520735, \
1.4545502220637487}, {1.6119238515688992, 1.2895708590441464}, 
    {1.5310517908664711, 1.1623542887261817}, {1.2745839491744684, \
1.3407174947497689}}], 
  Line[{{1.3472613601520735, 1.4545502220637487}, {1.4648558813281838, \
1.6149886737174097}, {1.742777594525673, 1.4628718195622257}, 
    {1.6119238515688992, 1.2895708590441464}, {1.3472613601520735, \
1.4545502220637487}}], 
  Line[{{1.4648558813281838, 1.6149886737174097}, {1.622228067846284, \
1.7955424168801195}, {1.9178940832636566, 1.6506863454327514}, 
    {1.742777594525673, 1.4628718195622257}, {1.4648558813281838, \
1.6149886737174097}}], 
  Line[{{1.622228067846284, 1.7955424168801195}, {1.8124999999999991, \
1.975435078659888}, {2.129619886922858, 1.8302685290560394}, 
    {1.9178940832636566, 1.6506863454327514}, {1.622228067846284, \
1.7955424168801195}}], 
  Line[{{1.8124999999999991, 1.975435078659888}, {2.0273558813281833, \
2.1404016678514597}, {2.368701571910244, 1.9869545564435858}, 
    {2.129619886922858, 1.8302685290560394}, {1.8124999999999991, \
1.975435078659888}}], 
  Line[{{2.0273558813281833, 2.1404016678514597}, {2.2574054788238884, \
2.2816570417008584}, {2.624690121350656, 2.112263515546568}, 
    {2.368701571910244, 1.9869545564435858}, {2.0273558813281833, \
2.1404016678514597}}], 
  Line[{{2.2574054788238884, 2.2816570417008584}, {2.492594521176109, \
2.394814022264695}, {2.8863976072642035, 2.202570463435661}, 
    {2.624690121350656, 2.112263515546568}, {2.2574054788238884, \
2.2816570417008584}}], 
  Line[{{2.492594521176109, 2.394814022264695}, {2.7226441186718153, \
2.479055835144598}, {3.1423861567046165, 2.258303983491545}, 
    {2.8863976072642035, 2.202570463435661}, {2.492594521176109, \
2.394814022264695}}], 
  Line[{{2.7226441186718153, 2.479055835144598}, {2.9374999999999987, \
2.536452985962878}, {3.3814678416920017, 2.2833691489150683}, 
    {3.1423861567046165, 2.258303983491545}, {2.7226441186718153, \
2.479055835144598}}], 
  Line[{{2.9374999999999987, 2.536452985962878}, {3.1277719321537147, \
2.5712732770958873}, {3.593193645351204, 2.284543605895154}, 
    {3.3814678416920017, 2.2833691489150683}, {2.9374999999999987, \
2.536452985962878}}], 
  Line[{{3.1277719321537147, 2.5712732770958873}, {3.2851441186718153, \
2.589176886629936}, {3.768310134089188, 2.270646210820903}, 
    {3.593193645351204, 2.284543605895154}, {3.1277719321537147, \
2.5712732770958873}}], 
  Line[{{3.2851441186718153, 2.589176886629936}, {3.4027386398479256, \
2.5962550390555554}, {3.899163877045962, 2.251331326578102}, 
    {3.768310134089188, 2.270646210820903}, {3.2851441186718153, \
2.589176886629936}}], 
  Line[{{3.4027386398479256, 2.5962550390555554}, {3.4754160508255305, \
2.5979598975817524}, {3.98003593774839, 2.235484296800204}, 
    {3.899163877045962, 2.251331326578102}, {3.4027386398479256, \
2.5962550390555554}}], 
  Line[{{3.4754160508255305, 2.5979598975817524}, {3.4999999999999996, \
2.598076211353316}, {4.007391819076574, 2.229434476432184}, 
    {3.98003593774839, 2.235484296800204}, {3.4754160508255305, \
2.5979598975817524}}], 
  Line[{{3.4999999999999996, 2.598076211353316}, {3.4754160508255314, \
2.5979598975817515}, {3.9800359377483905, 2.235484296800204}, 
    {4.007391819076574, 2.229434476432184}, {3.4999999999999996, \
2.598076211353316}}], 
  Line[{{3.4754160508255314, 2.5979598975817515}, {3.402738639847926, \
2.5962550390555568}, {3.8991638770459622, 2.251331326578102}, 
    {3.9800359377483905, 2.235484296800204}, {3.4754160508255314, \
2.5979598975817515}}], 
  Line[{{3.402738639847926, 2.5962550390555568}, {3.2851441186718158, \
2.589176886629936}, {3.7683101340891887, 2.2706462108209022}, 
    {3.8991638770459622, 2.251331326578102}, {3.402738639847926, \
2.5962550390555568}}], 
  Line[{{3.2851441186718158, 2.589176886629936}, {3.1277719321537156, \
2.5712732770958877}, {3.5931936453512052, 2.284543605895154}, 
    {3.7683101340891887, 2.2706462108209022}, {3.2851441186718158, \
2.589176886629936}}], 
  Line[{{3.1277719321537156, 2.5712732770958877}, {2.9375000000000004, \
2.5364529859628786}, {3.3814678416920034, 2.2833691489150687}, 
    {3.5931936453512052, 2.284543605895154}, {3.1277719321537156, \
2.5712732770958877}}], 
  Line[{{2.9375000000000004, 2.5364529859628786}, {2.722644118671816, \
2.479055835144598}, {3.1423861567046174, 2.2583039834915453}, 
    {3.3814678416920034, 2.2833691489150687}, {2.9375000000000004, \
2.5364529859628786}}], 
  Line[{{2.722644118671816, 2.479055835144598}, {2.492594521176111, \
2.3948140222646956}, {2.8863976072642057, 2.202570463435661}, 
    {3.1423861567046174, 2.2583039834915453}, {2.722644118671816, \
2.479055835144598}}], 
  Line[{{2.492594521176111, 2.3948140222646956}, {2.25740547882389, \
2.281657041700859}, {2.6246901213506577, 2.112263515546569}, 
    {2.8863976072642057, 2.202570463435661}, {2.492594521176111, \
2.3948140222646956}}], 
  Line[{{2.25740547882389, 2.281657041700859}, {2.0273558813281842, \
2.14040166785146}, {2.368701571910245, 1.9869545564435862}, 
    {2.6246901213506577, 2.112263515546569}, {2.25740547882389, \
2.281657041700859}}], 
  Line[{{2.0273558813281842, 2.14040166785146}, {1.8125000000000004, \
1.9754350786598895}, {2.12961988692286, 1.8302685290560408}, 
    {2.368701571910245, 1.9869545564435862}, {2.0273558813281842, \
2.14040166785146}}], 
  Line[{{1.8125000000000004, 1.9754350786598895}, {1.6222280678462853, \
1.7955424168801213}, {1.9178940832636582, 1.6506863454327532}, 
    {2.12961988692286, 1.8302685290560408}, {1.8125000000000004, \
1.9754350786598895}}], 
  Line[{{1.6222280678462853, 1.7955424168801213}, {1.4648558813281838, \
1.6149886737174104}, {1.7427775945256732, 1.4628718195622263}, 
    {1.9178940832636582, 1.6506863454327532}, {1.6222280678462853, \
1.7955424168801213}}], 
  Line[{{1.4648558813281838, 1.6149886737174104}, {1.3472613601520744, \
1.4545502220637496}, {1.6119238515689, 1.2895708590441473}, 
    {1.7427775945256732, 1.4628718195622263}, {1.4648558813281838, \
1.6149886737174104}}], 
  Line[{{1.3472613601520744, 1.4545502220637496}, {1.2745839491744688, \
1.3407174947497695}, {1.5310517908664716, 1.1623542887261822}, 
    {1.6119238515689, 1.2895708590441473}, {1.3472613601520744, \
1.4545502220637496}}], 
  Line[{{1.2745839491744688, 1.3407174947497695}, {1.2499999999999996, \
1.2990381056766582}, {1.503695909538287, 1.1147172382160917}, 
    {1.5310517908664716, 1.1623542887261822}, {1.2745839491744688, \
1.3407174947497695}}], 
  Line[{{1.2499999999999996, 1.2990381056766582}, {1.2745839491744682, \
1.3407174947497684}, {1.531051790866471, 1.162354288726181}, 
    {1.503695909538287, 1.1147172382160917}, {1.2499999999999996, \
1.2990381056766582}}], 
  Line[{{1.2745839491744682, 1.3407174947497684}, {1.3472613601520729, \
1.454550222063748}, {1.6119238515688985, 1.2895708590441455}, 
    {1.531051790866471, 1.162354288726181}, {1.2745839491744682, \
1.3407174947497684}}], 
  Line[{{1.3472613601520729, 1.454550222063748}, {1.4648558813281836, \
1.6149886737174093}, {1.7427775945256727, 1.4628718195622255}, 
    {1.6119238515688985, 1.2895708590441455}, {1.3472613601520729, \
1.454550222063748}}], 
  Line[{{1.4648558813281836, 1.6149886737174093}, {1.622228067846283, \
1.7955424168801193}, {1.917894083263656, 1.6506863454327507}, 
    {1.7427775945256727, 1.4628718195622255}, {1.4648558813281836, \
1.6149886737174093}}], 
  Line[{{1.622228067846283, 1.7955424168801193}, {1.8124999999999982, \
1.975435078659887}, {2.129619886922857, 1.830268529056039}, 
    {1.917894083263656, 1.6506863454327507}, {1.622228067846283, \
1.7955424168801193}}], 
  Line[{{1.8124999999999982, 1.975435078659887}, {2.0273558813281833, \
2.1404016678514592}, {2.368701571910244, 1.9869545564435853}, 
    {2.129619886922857, 1.830268529056039}, {1.8124999999999982, \
1.975435078659887}}], 
  Line[{{2.0273558813281833, 2.1404016678514592}, {2.257405478823888, \
2.281657041700858}, {2.6246901213506555, 2.1122635155465685}, 
    {2.368701571910244, 1.9869545564435853}, {2.0273558813281833, \
2.1404016678514592}}], 
  Line[{{2.257405478823888, 2.281657041700858}, {2.492594521176108, \
2.3948140222646943}, {2.886397607264202, 2.2025704634356607}, 
    {2.6246901213506555, 2.1122635155465685}, {2.257405478823888, \
2.281657041700858}}], 
  Line[{{2.492594521176108, 2.3948140222646943}, {2.7226441186718153, \
2.479055835144598}, {3.1423861567046165, 2.2583039834915453}, 
    {2.886397607264202, 2.2025704634356607}, {2.492594521176108, \
2.3948140222646943}}], 
  Line[{{2.7226441186718153, 2.479055835144598}, {2.9374999999999987, \
2.5364529859628777}, {3.381467841692001, 2.283369148915069}, 
    {3.1423861567046165, 2.2583039834915453}, {2.7226441186718153, \
2.479055835144598}}], 
  Line[{{2.9374999999999987, 2.5364529859628777}, {3.1277719321537134, \
2.5712732770958864}, {3.5931936453512026, 2.284543605895154}, 
    {3.381467841692001, 2.283369148915069}, {2.9374999999999987, \
2.5364529859628777}}], 
  Line[{{3.1277719321537134, 2.5712732770958864}, {3.2851441186718153, \
2.589176886629936}, {3.7683101340891882, 2.2706462108209022}, 
    {3.5931936453512026, 2.284543605895154}, {3.1277719321537134, \
2.5712732770958864}}], 
  Line[{{3.2851441186718153, 2.589176886629936}, {3.4027386398479256, \
2.5962550390555554}, {3.899163877045962, 2.251331326578102}, 
    {3.7683101340891882, 2.2706462108209022}, {3.2851441186718153, \
2.589176886629936}}], 
  Line[{{3.4027386398479256, 2.5962550390555554}, {3.475416050825531, \
2.5979598975817515}, {3.98003593774839, 2.235484296800204}, 
    {3.899163877045962, 2.251331326578102}, {3.4027386398479256, \
2.5962550390555554}}], 
  Line[{{3.475416050825531, 2.5979598975817515}, {3.4999999999999996, \
2.598076211353316}, {4.007391819076574, 2.229434476432184}, 
    {3.98003593774839, 2.235484296800204}, {3.475416050825531, \
2.5979598975817515}}], 
  Line[{{4.007391819076574, 2.229434476432184}, {3.98003593774839, \
2.235484296800204}, {4.397402461894532, 1.7786275248098211}, 
    {4.4270509831248415, 1.763355756877421}, {4.007391819076574, \
2.229434476432184}}], 
  Line[{{3.98003593774839, 2.235484296800204}, {3.8991638770459622, \
2.251331326578102}, {4.309752680850759, 1.8202053857959228}, 
    {4.397402461894532, 1.7786275248098211}, {3.98003593774839, \
2.235484296800204}}], 
  Line[{{3.8991638770459622, 2.251331326578102}, {3.768310134089188, \
2.270646210820903}, {4.167932356015447, 1.8768892930626264}, 
    {4.309752680850759, 1.8202053857959228}, {3.8991638770459622, \
2.251331326578102}}], 
  Line[{{3.768310134089188, 2.270646210820903}, {3.593193645351204, \
2.284543605895154}, {3.9781397161133216, 1.9339672857886054}, 
    {4.167932356015447, 1.8768892930626264}, {3.768310134089188, \
2.270646210820903}}], 
  Line[{{3.593193645351204, 2.284543605895154}, {3.381467841692003, \
2.283369148915068}, {3.748669610234237, 1.976615915035449}, 
    {3.9781397161133216, 1.9339672857886054}, {3.593193645351204, \
2.284543605895154}}], 
  Line[{{3.381467841692003, 2.283369148915068}, {3.1423861567046165, \
2.2583039834915453}, {3.489550983124842, 1.99216913656241}, 
    {3.748669610234237, 1.976615915035449}, {3.381467841692003, \
2.283369148915068}}], 
  Line[{{3.1423861567046165, 2.2583039834915453}, {2.886397607264205, \
2.202570463435661}, {3.2121085621789436, 1.9712852585698504}, 
    {3.489550983124842, 1.99216913656241}, {3.1423861567046165, \
2.2583039834915453}}], 
  Line[{{2.886397607264205, 2.202570463435661}, {2.624690121350657, \
2.112263515546569}, {2.928467912508319, 1.9084543807995193}, 
    {3.2121085621789436, 1.9712852585698504}, {2.886397607264205, \
2.202570463435661}}], 
  Line[{{2.624690121350657, 2.112263515546569}, {2.3687015719102447, \
1.9869545564435858}, {2.6510254915624207, 1.802245636601361}, 
    {2.928467912508319, 1.9084543807995193}, {2.624690121350657, \
2.112263515546569}}], 
  Line[{{2.3687015719102447, 1.9869545564435858}, {2.129619886922859, \
1.83026852905604}, {2.391906864453026, 1.65558951844325}, 
    {2.6510254915624207, 1.802245636601361}, {2.3687015719102447, \
1.9869545564435858}}], 
  Line[{{2.129619886922859, 1.83026852905604}, {1.9178940832636575, \
1.6506863454327518}, {2.162436758573941, 1.4764049667388985}, 
    {2.391906864453026, 1.65558951844325}, {2.129619886922859, \
1.83026852905604}}], 
  Line[{{1.9178940832636575, 1.6506863454327518}, {1.7427775945256727, \
1.4628718195622261}, {1.9726441186718153, 1.2790742990138144}, 
    {2.162436758573941, 1.4764049667388985}, {1.9178940832636575, \
1.6506863454327518}}], 
  Line[{{1.7427775945256727, 1.4628718195622261}, {1.6119238515688996, \
1.2895708590441468}, {1.8308237938365037, 1.0875191232355925}, 
    {1.9726441186718153, 1.2790742990138144}, {1.7427775945256727, \
1.4628718195622261}}], 
  Line[{{1.6119238515688996, 1.2895708590441468}, {1.5310517908664711, \
1.162354288726182}, {1.7431740127927302, 0.9393665425693404}, 
    {1.8308237938365037, 1.0875191232355925}, {1.6119238515688996, \
1.2895708590441468}}], 
  Line[{{1.5310517908664711, 1.162354288726182}, {1.503695909538287, \
1.1147172382160917}, {1.713525491562421, 0.8816778784387097}, 
    {1.7431740127927302, 0.9393665425693404}, {1.5310517908664711, \
1.162354288726182}}], 
  Line[{{1.503695909538287, 1.1147172382160917}, {1.5310517908664711, \
1.1623542887261817}, {1.7431740127927302, 0.9393665425693399}, 
    {1.713525491562421, 0.8816778784387097}, {1.503695909538287, \
1.1147172382160917}}], 
  Line[{{1.5310517908664711, 1.1623542887261817}, {1.6119238515688992, \
1.2895708590441464}, {1.8308237938365037, 1.0875191232355916}, 
    {1.7431740127927302, 0.9393665425693399}, {1.5310517908664711, \
1.1623542887261817}}], 
  Line[{{1.6119238515688992, 1.2895708590441464}, {1.742777594525673, \
1.4628718195622257}, {1.9726441186718155, 1.2790742990138138}, 
    {1.8308237938365037, 1.0875191232355916}, {1.6119238515688992, \
1.2895708590441464}}], 
  Line[{{1.742777594525673, 1.4628718195622257}, {1.9178940832636566, \
1.6506863454327514}, {2.16243675857394, 1.4764049667388985}, 
    {1.9726441186718155, 1.2790742990138138}, {1.742777594525673, \
1.4628718195622257}}], 
  Line[{{1.9178940832636566, 1.6506863454327514}, {2.129619886922858, \
1.8302685290560394}, {2.3919068644530252, 1.6555895184432492}, 
    {2.16243675857394, 1.4764049667388985}, {1.9178940832636566, \
1.6506863454327514}}], 
  Line[{{2.129619886922858, 1.8302685290560394}, {2.368701571910244, \
1.9869545564435858}, {2.6510254915624203, 1.8022456366013613}, 
    {2.3919068644530252, 1.6555895184432492}, {2.129619886922858, \
1.8302685290560394}}], 
  Line[{{2.368701571910244, 1.9869545564435858}, {2.624690121350656, \
2.112263515546568}, {2.928467912508318, 1.9084543807995193}, 
    {2.6510254915624203, 1.8022456366013613}, {2.368701571910244, \
1.9869545564435858}}], 
  Line[{{2.624690121350656, 2.112263515546568}, {2.8863976072642035, \
2.202570463435661}, {3.2121085621789423, 1.97128525856985}, 
    {2.928467912508318, 1.9084543807995193}, {2.624690121350656, \
2.112263515546568}}], 
  Line[{{2.8863976072642035, 2.202570463435661}, {3.1423861567046165, \
2.258303983491545}, {3.4895509831248415, 1.99216913656241}, 
    {3.2121085621789423, 1.97128525856985}, {2.8863976072642035, \
2.202570463435661}}], 
  Line[{{3.1423861567046165, 2.258303983491545}, {3.3814678416920017, \
2.2833691489150683}, {3.748669610234236, 1.976615915035449}, 
    {3.4895509831248415, 1.99216913656241}, {3.1423861567046165, \
2.258303983491545}}], 
  Line[{{3.3814678416920017, 2.2833691489150683}, {3.593193645351204, \
2.284543605895154}, {3.9781397161133216, 1.9339672857886054}, 
    {3.748669610234236, 1.976615915035449}, {3.3814678416920017, \
2.2833691489150683}}], 
  Line[{{3.593193645351204, 2.284543605895154}, {3.768310134089188, \
2.270646210820903}, {4.167932356015447, 1.8768892930626264}, 
    {3.9781397161133216, 1.9339672857886054}, {3.593193645351204, \
2.284543605895154}}], 
  Line[{{3.768310134089188, 2.270646210820903}, {3.899163877045962, \
2.251331326578102}, {4.3097526808507585, 1.8202053857959228}, 
    {4.167932356015447, 1.8768892930626264}, {3.768310134089188, \
2.270646210820903}}], 
  Line[{{3.899163877045962, 2.251331326578102}, {3.98003593774839, \
2.235484296800204}, {4.397402461894532, 1.7786275248098211}, 
    {4.3097526808507585, 1.8202053857959228}, {3.899163877045962, \
2.251331326578102}}], 
  Line[{{3.98003593774839, 2.235484296800204}, {4.007391819076574, \
2.229434476432184}, {4.4270509831248415, 1.763355756877421}, 
    {4.397402461894532, 1.7786275248098211}, {3.98003593774839, \
2.235484296800204}}], 
  Line[{{4.007391819076574, 2.229434476432184}, {3.9800359377483905, \
2.235484296800204}, {4.397402461894533, 1.7786275248098191}, 
    {4.4270509831248415, 1.763355756877421}, {4.007391819076574, \
2.229434476432184}}], 
  Line[{{3.9800359377483905, 2.235484296800204}, {3.8991638770459622, \
2.251331326578102}, {4.309752680850759, 1.8202053857959217}, 
    {4.397402461894533, 1.7786275248098191}, {3.9800359377483905, \
2.235484296800204}}], 
  Line[{{3.8991638770459622, 2.251331326578102}, {3.7683101340891887, \
2.2706462108209022}, {4.167932356015448, 1.8768892930626255}, 
    {4.309752680850759, 1.8202053857959217}, {3.8991638770459622, \
2.251331326578102}}], 
  Line[{{3.7683101340891887, 2.2706462108209022}, {3.5931936453512052, \
2.284543605895154}, {3.9781397161133234, 1.9339672857886037}, 
    {4.167932356015448, 1.8768892930626255}, {3.7683101340891887, \
2.2706462108209022}}], 
  Line[{{3.5931936453512052, 2.284543605895154}, {3.3814678416920034, \
2.2833691489150687}, {3.7486696102342374, 1.976615915035449}, 
    {3.9781397161133234, 1.9339672857886037}, {3.5931936453512052, \
2.284543605895154}}], 
  Line[{{3.3814678416920034, 2.2833691489150687}, {3.1423861567046174, \
2.2583039834915453}, {3.489550983124843, 1.9921691365624095}, 
    {3.7486696102342374, 1.976615915035449}, {3.3814678416920034, \
2.2833691489150687}}], 
  Line[{{3.1423861567046174, 2.2583039834915453}, {2.8863976072642057, \
2.202570463435661}, {3.212108562178945, 1.9712852585698495}, 
    {3.489550983124843, 1.9921691365624095}, {3.1423861567046174, \
2.2583039834915453}}], 
  Line[{{2.8863976072642057, 2.202570463435661}, {2.6246901213506577, \
2.112263515546569}, {2.9284679125083204, 1.9084543807995193}, 
    {3.212108562178945, 1.9712852585698495}, {2.8863976072642057, \
2.202570463435661}}], 
  Line[{{2.6246901213506577, 2.112263515546569}, {2.368701571910245, \
1.9869545564435862}, {2.6510254915624216, 1.8022456366013608}, 
    {2.9284679125083204, 1.9084543807995193}, {2.6246901213506577, \
2.112263515546569}}], 
  Line[{{2.368701571910245, 1.9869545564435862}, {2.12961988692286, \
1.8302685290560408}, {2.3919068644530275, 1.6555895184432503}, 
    {2.6510254915624216, 1.8022456366013608}, {2.368701571910245, \
1.9869545564435862}}], 
  Line[{{2.12961988692286, 1.8302685290560408}, {1.9178940832636582, \
1.6506863454327532}, {2.162436758573942, 1.4764049667388996}, 
    {2.3919068644530275, 1.6555895184432503}, {2.12961988692286, \
1.8302685290560408}}], 
  Line[{{1.9178940832636582, 1.6506863454327532}, {1.7427775945256732, \
1.4628718195622263}, {1.9726441186718158, 1.2790742990138144}, 
    {2.162436758573942, 1.4764049667388996}, {1.9178940832636582, \
1.6506863454327532}}], 
  Line[{{1.7427775945256732, 1.4628718195622263}, {1.6119238515689, \
1.2895708590441473}, {1.8308237938365044, 1.0875191232355932}, 
    {1.9726441186718158, 1.2790742990138144}, {1.7427775945256732, \
1.4628718195622263}}], 
  Line[{{1.6119238515689, 1.2895708590441473}, {1.5310517908664716, \
1.1623542887261822}, {1.7431740127927307, 0.9393665425693408}, 
    {1.8308237938365044, 1.0875191232355932}, {1.6119238515689, \
1.2895708590441473}}], 
  Line[{{1.5310517908664716, 1.1623542887261822}, {1.503695909538287, \
1.1147172382160917}, {1.713525491562421, 0.8816778784387097}, 
    {1.7431740127927307, 0.9393665425693408}, {1.5310517908664716, \
1.1623542887261822}}], 
  Line[{{1.503695909538287, 1.1147172382160917}, {1.531051790866471, \
1.162354288726181}, {1.74317401279273, 0.9393665425693394}, 
    {1.713525491562421, 0.8816778784387097}, {1.503695909538287, \
1.1147172382160917}}], 
  Line[{{1.531051790866471, 1.162354288726181}, {1.6119238515688985, \
1.2895708590441455}, {1.8308237938365028, 1.087519123235591}, 
    {1.74317401279273, 0.9393665425693394}, {1.531051790866471, \
1.162354288726181}}], 
  Line[{{1.6119238515688985, 1.2895708590441455}, {1.7427775945256727, \
1.4628718195622255}, {1.9726441186718153, 1.2790742990138133}, 
    {1.8308237938365028, 1.087519123235591}, {1.6119238515688985, \
1.2895708590441455}}], 
  Line[{{1.7427775945256727, 1.4628718195622255}, {1.917894083263656, \
1.6506863454327507}, {2.1624367585739397, 1.4764049667388974}, 
    {1.9726441186718153, 1.2790742990138133}, {1.7427775945256727, \
1.4628718195622255}}], 
  Line[{{1.917894083263656, 1.6506863454327507}, {2.129619886922857, \
1.830268529056039}, {2.3919068644530244, 1.655589518443248}, 
    {2.1624367585739397, 1.4764049667388974}, {1.917894083263656, \
1.6506863454327507}}], 
  Line[{{2.129619886922857, 1.830268529056039}, {2.368701571910244, \
1.9869545564435853}, {2.6510254915624203, 1.8022456366013608}, 
    {2.3919068644530244, 1.655589518443248}, {2.129619886922857, \
1.830268529056039}}], 
  Line[{{2.368701571910244, 1.9869545564435853}, {2.6246901213506555, \
2.1122635155465685}, {2.9284679125083177, 1.9084543807995193}, 
    {2.6510254915624203, 1.8022456366013608}, {2.368701571910244, \
1.9869545564435853}}], 
  Line[{{2.6246901213506555, 2.1122635155465685}, {2.886397607264202, \
2.2025704634356607}, {3.212108562178941, 1.971285258569849}, 
    {2.9284679125083177, 1.9084543807995193}, {2.6246901213506555, \
2.1122635155465685}}], 
  Line[{{2.886397607264202, 2.2025704634356607}, {3.1423861567046165, \
2.2583039834915453}, {3.489550983124842, 1.992169136562409}, 
    {3.212108562178941, 1.971285258569849}, {2.886397607264202, \
2.2025704634356607}}], 
  Line[{{3.1423861567046165, 2.2583039834915453}, {3.381467841692001, \
2.283369148915069}, {3.748669610234235, 1.9766159150354499}, 
    {3.489550983124842, 1.992169136562409}, {3.1423861567046165, \
2.2583039834915453}}], 
  Line[{{3.381467841692001, 2.283369148915069}, {3.5931936453512026, \
2.284543605895154}, {3.9781397161133203, 1.9339672857886054}, 
    {3.748669610234235, 1.9766159150354499}, {3.381467841692001, \
2.283369148915069}}], 
  Line[{{3.5931936453512026, 2.284543605895154}, {3.7683101340891882, \
2.2706462108209022}, {4.167932356015447, 1.8768892930626275}, 
    {3.9781397161133203, 1.9339672857886054}, {3.5931936453512026, \
2.284543605895154}}], 
  Line[{{3.7683101340891882, 2.2706462108209022}, {3.899163877045962, \
2.251331326578102}, {4.309752680850759, 1.8202053857959208}, 
    {4.167932356015447, 1.8768892930626275}, {3.7683101340891882, \
2.2706462108209022}}], 
  Line[{{3.899163877045962, 2.251331326578102}, {3.98003593774839, \
2.235484296800204}, {4.397402461894532, 1.7786275248098211}, 
    {4.309752680850759, 1.8202053857959208}, {3.899163877045962, \
2.251331326578102}}], 
  Line[{{3.98003593774839, 2.235484296800204}, {4.007391819076574, \
2.229434476432184}, {4.4270509831248415, 1.763355756877421}, 
    {4.397402461894532, 1.7786275248098211}, {3.98003593774839, \
2.235484296800204}}], 
  Line[{{4.4270509831248415, 1.763355756877421}, {4.397402461894532, \
1.7786275248098211}, {4.709274703411987, 1.251297555701461}, 
    {4.740636372927802, 1.220209929227404}, {4.4270509831248415, \
1.763355756877421}}], 
  Line[{{4.397402461894532, 1.7786275248098211}, {4.309752680850759, \
1.8202053857959228}, {4.616560350312374, 1.334684931108052}, 
    {4.709274703411987, 1.251297555701461}, {4.397402461894532, \
1.7786275248098211}}], 
  Line[{{4.309752680850759, 1.8202053857959228}, {4.167932356015447, \
1.8768892930626264}, {4.466545375752238, 1.4470248504530114}, 
    {4.616560350312374, 1.334684931108052}, {4.309752680850759, \
1.8202053857959228}}], 
  Line[{{4.167932356015447, 1.8768892930626264}, {3.9781397161133216, \
1.9339672857886054}, {4.265786153971575, 1.5625819810819581}, 
    {4.466545375752238, 1.4470248504530114}, {4.167932356015447, \
1.8768892930626264}}], 
  Line[{{3.9781397161133216, 1.9339672857886054}, {3.748669610234237, \
1.976615915035449}, {4.023056826311827, 1.6596693760099304}, 
    {4.265786153971575, 1.5625819810819581}, {3.9781397161133216, \
1.9339672857886054}}], 
  Line[{{3.748669610234237, 1.976615915035449}, {3.489550983124842, \
1.99216913656241}, {3.748965829136264, 1.7222389198769967}, 
    {4.023056826311827, 1.6596693760099304}, {3.748669610234237, \
1.976615915035449}}], 
  Line[{{3.489550983124842, 1.99216913656241}, {3.2121085621789436, \
1.9712852585698504}, {3.455492254255987, 1.7395717696563653}, 
    {3.748965829136264, 1.7222389198769967}, {3.489550983124842, \
1.99216913656241}}], 
  Line[{{3.2121085621789436, 1.9712852585698504}, {2.928467912508319, \
1.9084543807995193}, {3.1554623051357167, 1.705691841463223}, 
    {3.455492254255987, 1.7395717696563653}, {3.2121085621789436, \
1.9712852585698504}}], 
  Line[{{2.928467912508319, 1.9084543807995193}, {2.6510254915624207, \
1.802245636601361}, {2.8619887302554394, 1.6189603147994474}, 
    {3.1554623051357167, 1.705691841463223}, {2.928467912508319, \
1.9084543807995193}}], 
  Line[{{2.6510254915624207, 1.802245636601361}, {2.391906864453026, \
1.65558951844325}, {2.5878977330798767, 1.4819447816621802}, 
    {2.8619887302554394, 1.6189603147994474}, {2.6510254915624207, \
1.802245636601361}}], 
  Line[{{2.391906864453026, 1.65558951844325}, {2.162436758573941, \
1.4764049667388985}, {2.345168405420128, 1.3017122836390165}, 
    {2.5878977330798767, 1.4819447816621802}, {2.391906864453026, \
1.65558951844325}}], 
  Line[{{2.162436758573941, 1.4764049667388985}, {1.9726441186718153, \
1.2790742990138144}, {2.144409183639464, 1.0910840571723013}, 
    {2.345168405420128, 1.3017122836390165}, {2.162436758573941, \
1.4764049667388985}}], 
  Line[{{1.9726441186718153, 1.2790742990138144}, {1.8308237938365037, \
1.0875191232355925}, {1.9943942090793294, 0.8724918816600732}, 
    {2.144409183639464, 1.0910840571723013}, {1.9726441186718153, \
1.2790742990138144}}], 
  Line[{{1.8308237938365037, 1.0875191232355925}, {1.7431740127927302, \
0.9393665425693404}, {1.9016798559797152, 0.6880869119781089}, 
    {1.9943942090793294, 0.8724918816600732}, {1.8308237938365037, \
1.0875191232355925}}], 
  Line[{{1.7431740127927302, 0.9393665425693404}, {1.713525491562421, \
0.8816778784387097}, {1.8703181864639011, 0.6101049646137006}, 
    {1.9016798559797152, 0.6880869119781089}, {1.7431740127927302, \
0.9393665425693404}}], 
  Line[{{1.713525491562421, 0.8816778784387097}, {1.7431740127927302, \
0.9393665425693399}, {1.9016798559797154, 0.6880869119781076}, 
    {1.8703181864639011, 0.6101049646137006}, {1.713525491562421, \
0.8816778784387097}}], 
  Line[{{1.7431740127927302, 0.9393665425693399}, {1.8308237938365037, \
1.0875191232355916}, {1.9943942090793292, 0.8724918816600722}, 
    {1.9016798559797154, 0.6880869119781076}, {1.7431740127927302, \
0.9393665425693399}}], 
  Line[{{1.8308237938365037, 1.0875191232355916}, {1.9726441186718155, \
1.2790742990138138}, {2.144409183639464, 1.0910840571723004}, 
    {1.9943942090793292, 0.8724918816600722}, {1.8308237938365037, \
1.0875191232355916}}], 
  Line[{{1.9726441186718155, 1.2790742990138138}, {2.16243675857394, \
1.4764049667388985}, {2.345168405420127, 1.3017122836390158}, 
    {2.144409183639464, 1.0910840571723004}, {1.9726441186718155, \
1.2790742990138138}}], 
  Line[{{2.16243675857394, 1.4764049667388985}, {2.3919068644530252, \
1.6555895184432492}, {2.5878977330798754, 1.48194478166218}, 
    {2.345168405420127, 1.3017122836390158}, {2.16243675857394, \
1.4764049667388985}}], 
  Line[{{2.3919068644530252, 1.6555895184432492}, {2.6510254915624203, \
1.8022456366013613}, {2.8619887302554385, 1.6189603147994478}, 
    {2.5878977330798754, 1.48194478166218}, {2.3919068644530252, \
1.6555895184432492}}], 
  Line[{{2.6510254915624203, 1.8022456366013613}, {2.928467912508318, \
1.9084543807995193}, {3.155462305135716, 1.7056918414632214}, 
    {2.8619887302554385, 1.6189603147994478}, {2.6510254915624203, \
1.8022456366013613}}], 
  Line[{{2.928467912508318, 1.9084543807995193}, {3.2121085621789423, \
1.97128525856985}, {3.4554922542559856, 1.7395717696563653}, 
    {3.155462305135716, 1.7056918414632214}, {2.928467912508318, \
1.9084543807995193}}], 
  Line[{{3.2121085621789423, 1.97128525856985}, {3.4895509831248415, \
1.99216913656241}, {3.7489658291362637, 1.7222389198769967}, 
    {3.4554922542559856, 1.7395717696563653}, {3.2121085621789423, \
1.97128525856985}}], 
  Line[{{3.4895509831248415, 1.99216913656241}, {3.748669610234236, \
1.976615915035449}, {4.023056826311826, 1.6596693760099326}, 
    {3.7489658291362637, 1.7222389198769967}, {3.4895509831248415, \
1.99216913656241}}], 
  Line[{{3.748669610234236, 1.976615915035449}, {3.9781397161133216, \
1.9339672857886054}, {4.265786153971575, 1.5625819810819581}, 
    {4.023056826311826, 1.6596693760099326}, {3.748669610234236, \
1.976615915035449}}], 
  Line[{{3.9781397161133216, 1.9339672857886054}, {4.167932356015447, \
1.8768892930626264}, {4.466545375752238, 1.4470248504530114}, 
    {4.265786153971575, 1.5625819810819581}, {3.9781397161133216, \
1.9339672857886054}}], 
  Line[{{4.167932356015447, 1.8768892930626264}, {4.3097526808507585, \
1.8202053857959228}, {4.616560350312374, 1.3346849311080506}, 
    {4.466545375752238, 1.4470248504530114}, {4.167932356015447, \
1.8768892930626264}}], 
  Line[{{4.3097526808507585, 1.8202053857959228}, {4.397402461894532, \
1.7786275248098211}, {4.709274703411987, 1.251297555701461}, 
    {4.616560350312374, 1.3346849311080506}, {4.3097526808507585, \
1.8202053857959228}}], 
  Line[{{4.397402461894532, 1.7786275248098211}, {4.4270509831248415, \
1.763355756877421}, {4.740636372927802, 1.220209929227404}, 
    {4.709274703411987, 1.251297555701461}, {4.397402461894532, \
1.7786275248098211}}], 
  Line[{{4.4270509831248415, 1.763355756877421}, {4.397402461894533, \
1.7786275248098191}, {4.709274703411988, 1.251297555701461}, 
    {4.740636372927802, 1.220209929227404}, {4.4270509831248415, \
1.763355756877421}}], 
  Line[{{4.397402461894533, 1.7786275248098191}, {4.309752680850759, \
1.8202053857959217}, {4.616560350312374, 1.334684931108052}, 
    {4.709274703411988, 1.251297555701461}, {4.397402461894533, \
1.7786275248098191}}], 
  Line[{{4.309752680850759, 1.8202053857959217}, {4.167932356015448, \
1.8768892930626255}, {4.46654537575224, 1.447024850453009}, 
    {4.616560350312374, 1.334684931108052}, {4.309752680850759, \
1.8202053857959217}}], 
  Line[{{4.167932356015448, 1.8768892930626255}, {3.9781397161133234, \
1.9339672857886037}, {4.265786153971577, 1.562581981081957}, 
    {4.46654537575224, 1.447024850453009}, {4.167932356015448, \
1.8768892930626255}}], 
  Line[{{3.9781397161133234, 1.9339672857886037}, {3.7486696102342374, \
1.976615915035449}, {4.023056826311828, 1.6596693760099304}, 
    {4.265786153971577, 1.562581981081957}, {3.9781397161133234, \
1.9339672857886037}}], 
  Line[{{3.7486696102342374, 1.976615915035449}, {3.489550983124843, \
1.9921691365624095}, {3.7489658291362646, 1.7222389198769967}, 
    {4.023056826311828, 1.6596693760099304}, {3.7486696102342374, \
1.976615915035449}}], 
  Line[{{3.489550983124843, 1.9921691365624095}, {3.212108562178945, \
1.9712852585698495}, {3.4554922542559883, 1.7395717696563648}, 
    {3.7489658291362646, 1.7222389198769967}, {3.489550983124843, \
1.9921691365624095}}], 
  Line[{{3.212108562178945, 1.9712852585698495}, {2.9284679125083204, \
1.9084543807995193}, {3.1554623051357176, 1.705691841463223}, 
    {3.4554922542559883, 1.7395717696563648}, {3.212108562178945, \
1.9712852585698495}}], 
  Line[{{2.9284679125083204, 1.9084543807995193}, {2.6510254915624216, \
1.8022456366013608}, {2.86198873025544, 1.6189603147994478}, 
    {3.1554623051357176, 1.705691841463223}, {2.9284679125083204, \
1.9084543807995193}}], 
  Line[{{2.6510254915624216, 1.8022456366013608}, {2.3919068644530275, \
1.6555895184432503}, {2.5878977330798776, 1.481944781662181}, 
    {2.86198873025544, 1.6189603147994478}, {2.6510254915624216, \
1.8022456366013608}}], 
  Line[{{2.3919068644530275, 1.6555895184432503}, {2.162436758573942, \
1.4764049667388996}, {2.3451684054201287, 1.3017122836390178}, 
    {2.5878977330798776, 1.481944781662181}, {2.3919068644530275, \
1.6555895184432503}}], 
  Line[{{2.162436758573942, 1.4764049667388996}, {1.9726441186718158, \
1.2790742990138144}, {2.1444091836394645, 1.0910840571723013}, 
    {2.3451684054201287, 1.3017122836390178}, {2.162436758573942, \
1.4764049667388996}}], 
  Line[{{1.9726441186718158, 1.2790742990138144}, {1.8308237938365044, \
1.0875191232355932}, {1.99439420907933, 0.872491881660074}, 
    {2.1444091836394645, 1.0910840571723013}, {1.9726441186718158, \
1.2790742990138144}}], 
  Line[{{1.8308237938365044, 1.0875191232355932}, {1.7431740127927307, \
0.9393665425693408}, {1.901679855979716, 0.6880869119781089}, 
    {1.99439420907933, 0.872491881660074}, {1.8308237938365044, \
1.0875191232355932}}], 
  Line[{{1.7431740127927307, 0.9393665425693408}, {1.713525491562421, \
0.8816778784387097}, {1.8703181864639011, 0.6101049646137006}, 
    {1.901679855979716, 0.6880869119781089}, {1.7431740127927307, \
0.9393665425693408}}], 
  Line[{{1.713525491562421, 0.8816778784387097}, {1.74317401279273, \
0.9393665425693394}, {1.901679855979715, 0.6880869119781076}, 
    {1.8703181864639011, 0.6101049646137006}, {1.713525491562421, \
0.8816778784387097}}], 
  Line[{{1.74317401279273, 0.9393665425693394}, {1.8308237938365028, \
1.087519123235591}, {1.9943942090793283, 0.8724918816600712}, 
    {1.901679855979715, 0.6880869119781076}, {1.74317401279273, \
0.9393665425693394}}], 
  Line[{{1.8308237938365028, 1.087519123235591}, {1.9726441186718153, \
1.2790742990138133}, {2.1444091836394636, 1.0910840571723008}, 
    {1.9943942090793283, 0.8724918816600712}, {1.8308237938365028, \
1.087519123235591}}], 
  Line[{{1.9726441186718153, 1.2790742990138133}, {2.1624367585739397, \
1.4764049667388974}, {2.345168405420126, 1.3017122836390158}, 
    {2.1444091836394636, 1.0910840571723008}, {1.9726441186718153, \
1.2790742990138133}}], 
  Line[{{2.1624367585739397, 1.4764049667388974}, {2.3919068644530244, \
1.655589518443248}, {2.5878977330798745, 1.4819447816621785}, 
    {2.345168405420126, 1.3017122836390158}, {2.1624367585739397, \
1.4764049667388974}}], 
  Line[{{2.3919068644530244, 1.655589518443248}, {2.6510254915624203, \
1.8022456366013608}, {2.8619887302554385, 1.6189603147994474}, 
    {2.5878977330798745, 1.4819447816621785}, {2.3919068644530244, \
1.655589518443248}}], 
  Line[{{2.6510254915624203, 1.8022456366013608}, {2.9284679125083177, \
1.9084543807995193}, {3.155462305135715, 1.7056918414632225}, 
    {2.8619887302554385, 1.6189603147994474}, {2.6510254915624203, \
1.8022456366013608}}], 
  Line[{{2.9284679125083177, 1.9084543807995193}, {3.212108562178941, \
1.971285258569849}, {3.455492254255984, 1.7395717696563653}, 
    {3.155462305135715, 1.7056918414632225}, {2.9284679125083177, \
1.9084543807995193}}], 
  Line[{{3.212108562178941, 1.971285258569849}, {3.489550983124842, \
1.992169136562409}, {3.748965829136264, 1.7222389198769967}, 
    {3.455492254255984, 1.7395717696563653}, {3.212108562178941, \
1.971285258569849}}], 
  Line[{{3.489550983124842, 1.992169136562409}, {3.748669610234235, \
1.9766159150354499}, {4.023056826311826, 1.6596693760099326}, 
    {3.748965829136264, 1.7222389198769967}, {3.489550983124842, \
1.992169136562409}}], 
  Line[{{3.748669610234235, 1.9766159150354499}, {3.9781397161133203, \
1.9339672857886054}, {4.265786153971574, 1.5625819810819614}, 
    {4.023056826311826, 1.6596693760099326}, {3.748669610234235, \
1.9766159150354499}}], 
  Line[{{3.9781397161133203, 1.9339672857886054}, {4.167932356015447, \
1.8768892930626275}, {4.466545375752238, 1.4470248504530128}, 
    {4.265786153971574, 1.5625819810819614}, {3.9781397161133203, \
1.9339672857886054}}], 
  Line[{{4.167932356015447, 1.8768892930626275}, {4.309752680850759, \
1.8202053857959208}, {4.616560350312374, 1.3346849311080506}, 
    {4.466545375752238, 1.4470248504530128}, {4.167932356015447, \
1.8768892930626275}}], 
  Line[{{4.309752680850759, 1.8202053857959208}, {4.397402461894532, \
1.7786275248098211}, {4.709274703411988, 1.251297555701458}, 
    {4.616560350312374, 1.3346849311080506}, {4.309752680850759, \
1.8202053857959208}}], 
  Line[{{4.397402461894532, 1.7786275248098211}, {4.4270509831248415, \
1.763355756877421}, {4.740636372927802, 1.220209929227404}, 
    {4.709274703411988, 1.251297555701458}, {4.397402461894532, \
1.7786275248098211}}], 
  Line[{{4.740636372927802, 1.220209929227404}, {4.709274703411987, \
1.251297555701461}, {4.902022348817391, 0.693545187289426}, 
    {4.934442802201416, 0.6237350724532809}, {4.740636372927802, \
1.220209929227404}}], 
  Line[{{4.709274703411987, 1.251297555701461}, {4.616560350312374, \
1.334684931108052}, {4.806177918048795, 0.8605642566348376}, 
    {4.902022348817391, 0.693545187289426}, {4.709274703411987, \
1.251297555701461}}], 
  Line[{{4.616560350312374, 1.334684931108052}, {4.466545375752238, \
1.4470248504530114}, {4.651098371432819, 1.0590770192391419}, 
    {4.806177918048795, 0.8605642566348376}, {4.616560350312374, \
1.334684931108052}}], 
  Line[{{4.466545375752238, 1.4470248504530114}, {4.265786153971575, \
1.5625819810819581}, {4.44356142931081, 1.2475429541754062}, 
    {4.651098371432819, 1.0590770192391419}, {4.466545375752238, \
1.4470248504530114}}], 
  Line[{{4.265786153971575, 1.5625819810819581}, {4.023056826311827, \
1.6596693760099304}, {4.19263745192624, 1.4024710170213415}, 
    {4.44356142931081, 1.2475429541754062}, {4.265786153971575, \
1.5625819810819581}}], 
  Line[{{4.023056826311827, 1.6596693760099304}, {3.748965829136264, \
1.7222389198769967}, {3.9092930211576427, 1.5096856680207968}, 
    {4.19263745192624, 1.4024710170213415}, {4.023056826311827, \
1.6596693760099304}}], 
  Line[{{3.748965829136264, 1.7222389198769967}, {3.455492254255987, \
1.7395717696563653}, {3.605911648267038, 1.560594218929799}, 
    {3.9092930211576427, 1.5096856680207968}, {3.748965829136264, \
1.7222389198769967}}], 
  Line[{{3.455492254255987, 1.7395717696563653}, {3.1554623051357167, \
1.705691841463223}, {3.2957525550350866, 1.5507915961279441}, 
    {3.605911648267038, 1.560594218929799}, {3.455492254255987, \
1.7395717696563653}}], 
  Line[{{3.1554623051357167, 1.705691841463223}, {2.8619887302554394, \
1.6189603147994474}, {2.9923711821444816, 1.4795217391705875}, 
    {3.2957525550350866, 1.5507915961279441}, {3.1554623051357167, \
1.705691841463223}}], 
  Line[{{2.8619887302554394, 1.6189603147994474}, {2.5878977330798767, \
1.4819447816621802}, {2.7090267513758857, 1.3494565251821808}, 
    {2.9923711821444816, 1.4795217391705875}, {2.8619887302554394, \
1.6189603147994474}}], 
  Line[{{2.5878977330798767, 1.4819447816621802}, {2.345168405420128, \
1.3017122836390165}, {2.458102773991314, 1.1666712321091814}, 
    {2.7090267513758857, 1.3494565251821808}, {2.5878977330798767, \
1.4819447816621802}}], 
  Line[{{2.345168405420128, 1.3017122836390165}, {2.144409183639464, \
1.0910840571723013}, {2.2505658318693045, 0.9410557119019621}, 
    {2.458102773991314, 1.1666712321091814}, {2.345168405420128, \
1.3017122836390165}}], 
  Line[{{2.144409183639464, 1.0910840571723013}, {1.9943942090793294, \
0.8724918816600732}, {2.0954862852533296, 0.688485888369732}, 
    {2.2505658318693045, 0.9410557119019621}, {2.144409183639464, \
1.0910840571723013}}], 
  Line[{{1.9943942090793294, 0.8724918816600732}, {1.9016798559797152, \
0.6880869119781089}, {1.999641854484733, 0.442263528432697}, 
    {2.0954862852533296, 0.688485888369732}, {1.9943942090793294, \
0.8724918816600732}}], 
  Line[{{1.9016798559797152, 0.6880869119781089}, {1.8703181864639011, \
0.6101049646137006}, {1.9672214011007083, 0.311867536226639}, 
    {1.999641854484733, 0.442263528432697}, {1.9016798559797152, \
0.6880869119781089}}], 
  Line[{{1.8703181864639011, 0.6101049646137006}, {1.9016798559797154, \
0.6880869119781076}, {1.999641854484733, 0.442263528432696}, 
    {1.9672214011007083, 0.311867536226639}, {1.8703181864639011, \
0.6101049646137006}}], 
  Line[{{1.9016798559797154, 0.6880869119781076}, {1.9943942090793292, \
0.8724918816600722}, {2.095486285253329, 0.6884858883697308}, 
    {1.999641854484733, 0.442263528432696}, {1.9016798559797154, \
0.6880869119781076}}], 
  Line[{{1.9943942090793292, 0.8724918816600722}, {2.144409183639464, \
1.0910840571723004}, {2.250565831869305, 0.9410557119019607}, 
    {2.095486285253329, 0.6884858883697308}, {1.9943942090793292, \
0.8724918816600722}}], 
  Line[{{2.144409183639464, 1.0910840571723004}, {2.345168405420127, \
1.3017122836390158}, {2.458102773991313, 1.166671232109181}, 
    {2.250565831869305, 0.9410557119019607}, {2.144409183639464, \
1.0910840571723004}}], 
  Line[{{2.345168405420127, 1.3017122836390158}, {2.5878977330798754, \
1.48194478166218}, {2.7090267513758843, 1.3494565251821808}, 
    {2.458102773991313, 1.166671232109181}, {2.345168405420127, \
1.3017122836390158}}], 
  Line[{{2.5878977330798754, 1.48194478166218}, {2.8619887302554385, \
1.6189603147994478}, {2.992371182144481, 1.479521739170588}, 
    {2.7090267513758843, 1.3494565251821808}, {2.5878977330798754, \
1.48194478166218}}], 
  Line[{{2.8619887302554385, 1.6189603147994478}, {3.155462305135716, \
1.7056918414632214}, {3.2957525550350857, 1.5507915961279435}, 
    {2.992371182144481, 1.479521739170588}, {2.8619887302554385, \
1.6189603147994478}}], 
  Line[{{3.155462305135716, 1.7056918414632214}, {3.4554922542559856, \
1.7395717696563653}, {3.6059116482670364, 1.5605942189298}, 
    {3.2957525550350857, 1.5507915961279435}, {3.155462305135716, \
1.7056918414632214}}], 
  Line[{{3.4554922542559856, 1.7395717696563653}, {3.7489658291362637, \
1.7222389198769967}, {3.9092930211576427, 1.5096856680207968}, 
    {3.6059116482670364, 1.5605942189298}, {3.4554922542559856, \
1.7395717696563653}}], 
  Line[{{3.7489658291362637, 1.7222389198769967}, {4.023056826311826, \
1.6596693760099326}, {4.192637451926238, 1.4024710170213415}, 
    {3.9092930211576427, 1.5096856680207968}, {3.7489658291362637, \
1.7222389198769967}}], 
  Line[{{4.023056826311826, 1.6596693760099326}, {4.265786153971575, \
1.5625819810819581}, {4.443561429310811, 1.247542954175402}, 
    {4.192637451926238, 1.4024710170213415}, {4.023056826311826, \
1.6596693760099326}}], 
  Line[{{4.265786153971575, 1.5625819810819581}, {4.466545375752238, \
1.4470248504530114}, {4.651098371432819, 1.0590770192391419}, 
    {4.443561429310811, 1.247542954175402}, {4.265786153971575, \
1.5625819810819581}}], 
  Line[{{4.466545375752238, 1.4470248504530114}, {4.616560350312374, \
1.3346849311080506}, {4.806177918048795, 0.8605642566348355}, 
    {4.651098371432819, 1.0590770192391419}, {4.466545375752238, \
1.4470248504530114}}], 
  Line[{{4.616560350312374, 1.3346849311080506}, {4.709274703411987, \
1.251297555701461}, {4.902022348817391, 0.693545187289426}, 
    {4.806177918048795, 0.8605642566348355}, {4.616560350312374, \
1.3346849311080506}}], 
  Line[{{4.709274703411987, 1.251297555701461}, {4.740636372927802, \
1.220209929227404}, {4.934442802201416, 0.6237350724532809}, 
    {4.902022348817391, 0.693545187289426}, {4.709274703411987, \
1.251297555701461}}], 
  Line[{{4.740636372927802, 1.220209929227404}, {4.709274703411988, \
1.251297555701461}, {4.9020223488173915, 0.6935451872894235}, 
    {4.934442802201416, 0.6237350724532809}, {4.740636372927802, \
1.220209929227404}}], 
  Line[{{4.709274703411988, 1.251297555701461}, {4.616560350312374, \
1.334684931108052}, {4.806177918048795, 0.8605642566348376}, 
    {4.9020223488173915, 0.6935451872894235}, {4.709274703411988, \
1.251297555701461}}], 
  Line[{{4.616560350312374, 1.334684931108052}, {4.46654537575224, \
1.447024850453009}, {4.651098371432821, 1.0590770192391368}, 
    {4.806177918048795, 0.8605642566348376}, {4.616560350312374, \
1.334684931108052}}], 
  Line[{{4.46654537575224, 1.447024850453009}, {4.265786153971577, \
1.562581981081957}, {4.443561429310812, 1.247542954175402}, 
    {4.651098371432821, 1.0590770192391368}, {4.46654537575224, \
1.447024850453009}}], 
  Line[{{4.265786153971577, 1.562581981081957}, {4.023056826311828, \
1.6596693760099304}, {4.19263745192624, 1.4024710170213426}, 
    {4.443561429310812, 1.247542954175402}, {4.265786153971577, \
1.562581981081957}}], 
  Line[{{4.023056826311828, 1.6596693760099304}, {3.7489658291362646, \
1.7222389198769967}, {3.9092930211576435, 1.5096856680207968}, 
    {4.19263745192624, 1.4024710170213426}, {4.023056826311828, \
1.6596693760099304}}], 
  Line[{{3.7489658291362646, 1.7222389198769967}, {3.4554922542559883, \
1.7395717696563648}, {3.605911648267039, 1.560594218929799}, 
    {3.9092930211576435, 1.5096856680207968}, {3.7489658291362646, \
1.7222389198769967}}], 
  Line[{{3.4554922542559883, 1.7395717696563648}, {3.1554623051357176, \
1.705691841463223}, {3.2957525550350875, 1.5507915961279446}, 
    {3.605911648267039, 1.560594218929799}, {3.4554922542559883, \
1.7395717696563648}}], 
  Line[{{3.1554623051357176, 1.705691841463223}, {2.86198873025544, \
1.6189603147994478}, {2.992371182144482, 1.4795217391705875}, 
    {3.2957525550350875, 1.5507915961279446}, {3.1554623051357176, \
1.705691841463223}}], 
  Line[{{2.86198873025544, 1.6189603147994478}, {2.5878977330798776, \
1.481944781662181}, {2.7090267513758866, 1.3494565251821808}, 
    {2.992371182144482, 1.4795217391705875}, {2.86198873025544, \
1.6189603147994478}}], 
  Line[{{2.5878977330798776, 1.481944781662181}, {2.3451684054201287, \
1.3017122836390178}, {2.458102773991315, 1.1666712321091826}, 
    {2.7090267513758866, 1.3494565251821808}, {2.5878977330798776, \
1.481944781662181}}], 
  Line[{{2.3451684054201287, 1.3017122836390178}, {2.1444091836394645, \
1.0910840571723013}, {2.250565831869305, 0.9410557119019621}, 
    {2.458102773991315, 1.1666712321091826}, {2.3451684054201287, \
1.3017122836390178}}], 
  Line[{{2.1444091836394645, 1.0910840571723013}, {1.99439420907933, \
0.872491881660074}, {2.09548628525333, 0.6884858883697327}, 
    {2.250565831869305, 0.9410557119019621}, {2.1444091836394645, \
1.0910840571723013}}], 
  Line[{{1.99439420907933, 0.872491881660074}, {1.901679855979716, \
0.6880869119781089}, {1.9996418544847336, 0.442263528432698}, 
    {2.09548628525333, 0.6884858883697327}, {1.99439420907933, \
0.872491881660074}}], 
  Line[{{1.901679855979716, 0.6880869119781089}, {1.8703181864639011, \
0.6101049646137006}, {1.9672214011007083, 0.311867536226639}, 
    {1.9996418544847336, 0.442263528432698}, {1.901679855979716, \
0.6880869119781089}}], 
  Line[{{1.8703181864639011, 0.6101049646137006}, {1.901679855979715, \
0.6880869119781076}, {1.9996418544847328, 0.442263528432695}, 
    {1.9672214011007083, 0.311867536226639}, {1.8703181864639011, \
0.6101049646137006}}], 
  Line[{{1.901679855979715, 0.6880869119781076}, {1.9943942090793283, \
0.8724918816600712}, {2.0954862852533283, 0.6884858883697301}, 
    {1.9996418544847328, 0.442263528432695}, {1.901679855979715, \
0.6880869119781076}}], 
  Line[{{1.9943942090793283, 0.8724918816600712}, {2.1444091836394636, \
1.0910840571723008}, {2.2505658318693045, 0.9410557119019607}, 
    {2.0954862852533283, 0.6884858883697301}, {1.9943942090793283, \
0.8724918816600712}}], 
  Line[{{2.1444091836394636, 1.0910840571723008}, {2.345168405420126, \
1.3017122836390158}, {2.458102773991312, 1.1666712321091806}, 
    {2.2505658318693045, 0.9410557119019607}, {2.1444091836394636, \
1.0910840571723008}}], 
  Line[{{2.345168405420126, 1.3017122836390158}, {2.5878977330798745, \
1.4819447816621785}, {2.709026751375883, 1.3494565251821795}, 
    {2.458102773991312, 1.1666712321091806}, {2.345168405420126, \
1.3017122836390158}}], 
  Line[{{2.5878977330798745, 1.4819447816621785}, {2.8619887302554385, \
1.6189603147994474}, {2.992371182144481, 1.4795217391705868}, 
    {2.709026751375883, 1.3494565251821795}, {2.5878977330798745, \
1.4819447816621785}}], 
  Line[{{2.8619887302554385, 1.6189603147994474}, {3.155462305135715, \
1.7056918414632225}, {3.295752555035085, 1.5507915961279446}, 
    {2.992371182144481, 1.4795217391705868}, {2.8619887302554385, \
1.6189603147994474}}], 
  Line[{{3.155462305135715, 1.7056918414632225}, {3.455492254255984, \
1.7395717696563653}, {3.605911648267035, 1.560594218929799}, 
    {3.295752555035085, 1.5507915961279446}, {3.155462305135715, \
1.7056918414632225}}], 
  Line[{{3.455492254255984, 1.7395717696563653}, {3.748965829136264, \
1.7222389198769967}, {3.9092930211576427, 1.5096856680207968}, 
    {3.605911648267035, 1.560594218929799}, {3.455492254255984, \
1.7395717696563653}}], 
  Line[{{3.748965829136264, 1.7222389198769967}, {4.023056826311826, \
1.6596693760099326}, {4.192637451926238, 1.4024710170213415}, 
    {3.9092930211576427, 1.5096856680207968}, {3.748965829136264, \
1.7222389198769967}}], 
  Line[{{4.023056826311826, 1.6596693760099326}, {4.265786153971574, \
1.5625819810819614}, {4.443561429310809, 1.2475429541754033}, 
    {4.192637451926238, 1.4024710170213415}, {4.023056826311826, \
1.6596693760099326}}], 
  Line[{{4.265786153971574, 1.5625819810819614}, {4.466545375752238, \
1.4470248504530128}, {4.651098371432819, 1.0590770192391419}, 
    {4.443561429310809, 1.2475429541754033}, {4.265786153971574, \
1.5625819810819614}}], 
  Line[{{4.466545375752238, 1.4470248504530128}, {4.616560350312374, \
1.3346849311080506}, {4.806177918048795, 0.8605642566348355}, 
    {4.651098371432819, 1.0590770192391419}, {4.466545375752238, \
1.4470248504530128}}], 
  Line[{{4.616560350312374, 1.3346849311080506}, {4.709274703411988, \
1.251297555701458}, {4.9020223488173915, 0.6935451872894184}, 
    {4.806177918048795, 0.8605642566348355}, {4.616560350312374, \
1.3346849311080506}}], 
  Line[{{4.709274703411988, 1.251297555701458}, {4.740636372927802, \
1.220209929227404}, {4.934442802201416, 0.6237350724532809}, 
    {4.9020223488173915, 0.6935451872894184}, {4.709274703411988, \
1.251297555701458}}], 
  Line[{{4.934442802201416, 0.6237350724532809}, {4.902022348817391, \
0.693545187289426}, {4.967221401100708, 0.3118675362266461}, {5., 0.}, 
    {4.934442802201416, 0.6237350724532809}}], Line[{{4.902022348817391, \
0.693545187289426}, {4.806177918048795, 0.8605642566348376}, 
    {4.870318186463902, 0.6101049646136962}, {4.967221401100708, \
0.3118675362266461}, {4.902022348817391, 0.693545187289426}}], 
  Line[{{4.806177918048795, 0.8605642566348376}, {4.651098371432819, \
1.0590770192391419}, {4.713525491562421, 0.8816778784387095}, 
    {4.870318186463902, 0.6101049646136962}, {4.806177918048795, \
0.8605642566348376}}], 
  Line[{{4.651098371432819, 1.0590770192391419}, {4.44356142931081, \
1.2475429541754062}, {4.503695909538287, 1.1147172382160924}, 
    {4.713525491562421, 0.8816778784387095}, {4.651098371432819, \
1.0590770192391419}}], 
  Line[{{4.44356142931081, 1.2475429541754062}, {4.19263745192624, \
1.4024710170213415}, {4.25, 1.2990381056766593}, 
    {4.503695909538287, 1.1147172382160924}, {4.44356142931081, \
1.2475429541754062}}], 
  Line[{{4.19263745192624, 1.4024710170213415}, {3.9092930211576427, \
1.5096856680207968}, {3.963525491562421, 1.4265847744427318}, 
    {4.25, 1.2990381056766593}, {4.19263745192624, 1.4024710170213415}}], 
  Line[{{3.9092930211576427, 1.5096856680207968}, {3.605911648267038, \
1.560594218929799}, {3.6567926949014806, 1.49178284305241}, 
    {3.963525491562421, 1.4265847744427318}, {3.9092930211576427, \
1.5096856680207968}}], 
  Line[{{3.605911648267038, 1.560594218929799}, {3.2957525550350866, \
1.5507915961279441}, {3.3432073050985194, 1.4917828430524107}, 
    {3.6567926949014806, 1.49178284305241}, {3.605911648267038, \
1.560594218929799}}], 
  Line[{{3.2957525550350866, 1.5507915961279441}, {2.9923711821444816, \
1.4795217391705875}, {3.036474508437579, 1.4265847744427305}, 
    {3.3432073050985194, 1.4917828430524107}, {3.2957525550350866, \
1.5507915961279441}}], 
  Line[{{2.9923711821444816, 1.4795217391705875}, {2.7090267513758857, \
1.3494565251821808}, {2.75, 1.2990381056766587}, 
    {3.036474508437579, 1.4265847744427305}, {2.9923711821444816, \
1.4795217391705875}}], 
  Line[{{2.7090267513758857, 1.3494565251821808}, {2.458102773991314, \
1.1666712321091814}, {2.496304090461713, 1.1147172382160917}, 
    {2.75, 1.2990381056766587}, {2.7090267513758857, 1.3494565251821808}}], 
  Line[{{2.458102773991314, 1.1666712321091814}, {2.2505658318693045, \
0.9410557119019621}, {2.286474508437579, 0.88167787843871}, 
    {2.496304090461713, 1.1147172382160917}, {2.458102773991314, \
1.1666712321091814}}], 
  Line[{{2.2505658318693045, 0.9410557119019621}, {2.0954862852533296, \
0.688485888369732}, {2.1296818135360986, 0.6101049646137013}, 
    {2.286474508437579, 0.88167787843871}, {2.2505658318693045, \
0.9410557119019621}}], 
  Line[{{2.0954862852533296, 0.688485888369732}, {1.999641854484733, \
0.442263528432697}, {2.0327785988992915, 0.31186753622664043}, 
    {2.1296818135360986, 0.6101049646137013}, {2.0954862852533296, \
0.688485888369732}}], 
  Line[{{1.999641854484733, 0.442263528432697}, {1.9672214011007083, \
0.311867536226639}, {2., 0.}, {2.0327785988992915, 0.31186753622664043}, 
    {1.999641854484733, 0.442263528432697}}], Line[{{1.9672214011007083, \
0.311867536226639}, {1.999641854484733, 0.442263528432696}, 
    {2.0327785988992915, 0.311867536226639}, {2., 0.}, {1.9672214011007083, \
0.311867536226639}}], 
  Line[{{1.999641854484733, 0.442263528432696}, {2.095486285253329, \
0.6884858883697308}, {2.1296818135360986, 0.6101049646136991}, 
    {2.0327785988992915, 0.311867536226639}, {1.999641854484733, \
0.442263528432696}}], 
  Line[{{2.095486285253329, 0.6884858883697308}, {2.250565831869305, \
0.9410557119019607}, {2.286474508437579, 0.8816778784387095}, 
    {2.1296818135360986, 0.6101049646136991}, {2.095486285253329, \
0.6884858883697308}}], 
  Line[{{2.250565831869305, 0.9410557119019607}, {2.458102773991313, \
1.166671232109181}, {2.496304090461712, 1.1147172382160913}, 
    {2.286474508437579, 0.8816778784387095}, {2.250565831869305, \
0.9410557119019607}}], 
  Line[{{2.458102773991313, 1.166671232109181}, {2.7090267513758843, \
1.3494565251821808}, {2.749999999999999, 1.299038105676658}, 
    {2.496304090461712, 1.1147172382160913}, {2.458102773991313, \
1.166671232109181}}], 
  Line[{{2.7090267513758843, 1.3494565251821808}, {2.992371182144481, \
1.479521739170588}, {3.0364745084375784, 1.4265847744427305}, 
    {2.749999999999999, 1.299038105676658}, {2.7090267513758843, \
1.3494565251821808}}], 
  Line[{{2.992371182144481, 1.479521739170588}, {3.2957525550350857, \
1.5507915961279435}, {3.3432073050985185, 1.4917828430524107}, 
    {3.0364745084375784, 1.4265847744427305}, {2.992371182144481, \
1.479521739170588}}], 
  Line[{{3.2957525550350857, 1.5507915961279435}, {3.6059116482670364, \
1.5605942189298}, {3.656792694901479, 1.4917828430524112}, 
    {3.3432073050985185, 1.4917828430524107}, {3.2957525550350857, \
1.5507915961279435}}], 
  Line[{{3.6059116482670364, 1.5605942189298}, {3.9092930211576427, \
1.5096856680207968}, {3.963525491562421, 1.4265847744427305}, 
    {3.656792694901479, 1.4917828430524112}, {3.6059116482670364, \
1.5605942189298}}], 
  Line[{{3.9092930211576427, 1.5096856680207968}, {4.192637451926238, \
1.4024710170213415}, {4.249999999999999, 1.299038105676658}, 
    {3.963525491562421, 1.4265847744427305}, {3.9092930211576427, \
1.5096856680207968}}], 
  Line[{{4.192637451926238, 1.4024710170213415}, {4.443561429310811, \
1.247542954175402}, {4.503695909538286, 1.1147172382160955}, 
    {4.249999999999999, 1.299038105676658}, {4.192637451926238, \
1.4024710170213415}}], 
  Line[{{4.443561429310811, 1.247542954175402}, {4.651098371432819, \
1.0590770192391419}, {4.713525491562421, 0.8816778784387115}, 
    {4.503695909538286, 1.1147172382160955}, {4.443561429310811, \
1.247542954175402}}], 
  Line[{{4.651098371432819, 1.0590770192391419}, {4.806177918048795, \
0.8605642566348355}, {4.870318186463901, 0.6101049646136991}, 
    {4.713525491562421, 0.8816778784387115}, {4.651098371432819, \
1.0590770192391419}}], 
  Line[{{4.806177918048795, 0.8605642566348355}, {4.902022348817391, \
0.693545187289426}, {4.967221401100708, 0.3118675362266461}, 
    {4.870318186463901, 0.6101049646136991}, {4.806177918048795, \
0.8605642566348355}}], 
  Line[{{4.902022348817391, 0.693545187289426}, {4.934442802201416, \
0.6237350724532809}, {5., 0.}, {4.967221401100708, 0.3118675362266461}, 
    {4.902022348817391, 0.693545187289426}}], Line[{{4.934442802201416, \
0.6237350724532809}, {4.9020223488173915, 0.6935451872894235}, 
    {4.967221401100709, 0.31186753622662905}, {5., 0.}, {4.934442802201416, \
0.6237350724532809}}], 
  Line[{{4.9020223488173915, 0.6935451872894235}, {4.806177918048795, \
0.8605642566348376}, {4.870318186463902, 0.6101049646136962}, 
    {4.967221401100709, 0.31186753622662905}, {4.9020223488173915, \
0.6935451872894235}}], 
  Line[{{4.806177918048795, 0.8605642566348376}, {4.651098371432821, \
1.0590770192391368}, {4.713525491562422, 0.8816778784387075}, 
    {4.870318186463902, 0.6101049646136962}, {4.806177918048795, \
0.8605642566348376}}], 
  Line[{{4.651098371432821, 1.0590770192391368}, {4.443561429310812, \
1.247542954175402}, {4.503695909538288, 1.1147172382160924}, 
    {4.713525491562422, 0.8816778784387075}, {4.651098371432821, \
1.0590770192391368}}], 
  Line[{{4.443561429310812, 1.247542954175402}, {4.19263745192624, \
1.4024710170213426}, {4.250000000000001, 1.299038105676658}, 
    {4.503695909538288, 1.1147172382160924}, {4.443561429310812, \
1.247542954175402}}], 
  Line[{{4.19263745192624, 1.4024710170213426}, {3.9092930211576435, \
1.5096856680207968}, {3.9635254915624225, 1.426584774442728}, 
    {4.250000000000001, 1.299038105676658}, {4.19263745192624, \
1.4024710170213426}}], 
  Line[{{3.9092930211576435, 1.5096856680207968}, {3.605911648267039, \
1.560594218929799}, {3.656792694901482, 1.491782843052409}, 
    {3.9635254915624225, 1.426584774442728}, {3.9092930211576435, \
1.5096856680207968}}], 
  Line[{{3.605911648267039, 1.560594218929799}, {3.2957525550350875, \
1.5507915961279446}, {3.3432073050985207, 1.49178284305241}, 
    {3.656792694901482, 1.491782843052409}, {3.605911648267039, \
1.560594218929799}}], 
  Line[{{3.2957525550350875, 1.5507915961279446}, {2.992371182144482, \
1.4795217391705875}, {3.0364745084375793, 1.4265847744427311}, 
    {3.3432073050985207, 1.49178284305241}, {3.2957525550350875, \
1.5507915961279446}}], 
  Line[{{2.992371182144482, 1.4795217391705875}, {2.7090267513758866, \
1.3494565251821808}, {2.7500000000000013, 1.2990381056766587}, 
    {3.0364745084375793, 1.4265847744427311}, {2.992371182144482, \
1.4795217391705875}}], 
  Line[{{2.7090267513758866, 1.3494565251821808}, {2.458102773991315, \
1.1666712321091826}, {2.496304090461714, 1.1147172382160933}, 
    {2.7500000000000013, 1.2990381056766587}, {2.7090267513758866, \
1.3494565251821808}}], 
  Line[{{2.458102773991315, 1.1666712321091826}, {2.250565831869305, \
0.9410557119019621}, {2.2864745084375793, 0.88167787843871}, 
    {2.496304090461714, 1.1147172382160933}, {2.458102773991315, \
1.1666712321091826}}], 
  Line[{{2.250565831869305, 0.9410557119019621}, {2.09548628525333, \
0.6884858883697327}, {2.1296818135360995, 0.6101049646137006}, 
    {2.2864745084375793, 0.88167787843871}, {2.250565831869305, \
0.9410557119019621}}], 
  Line[{{2.09548628525333, 0.6884858883697327}, {1.9996418544847336, \
0.442263528432698}, {2.0327785988992924, 0.31186753622664043}, 
    {2.1296818135360995, 0.6101049646137006}, {2.09548628525333, \
0.6884858883697327}}], 
  Line[{{1.9996418544847336, 0.442263528432698}, {1.9672214011007083, \
0.311867536226639}, {2., 0.}, {2.0327785988992924, 0.31186753622664043}, 
    {1.9996418544847336, 0.442263528432698}}], Line[{{1.9672214011007083, \
0.311867536226639}, {1.9996418544847328, 0.442263528432695}, 
    {2.0327785988992915, 0.31186753622663616}, {2., 0.}, {1.9672214011007083, \
0.311867536226639}}], 
  Line[{{1.9996418544847328, 0.442263528432695}, {2.0954862852533283, \
0.6884858883697301}, {2.1296818135360978, 0.6101049646136977}, 
    {2.0327785988992915, 0.31186753622663616}, {1.9996418544847328, \
0.442263528432695}}], 
  Line[{{2.0954862852533283, 0.6884858883697301}, {2.2505658318693045, \
0.9410557119019607}, {2.2864745084375784, 0.8816778784387095}, 
    {2.1296818135360978, 0.6101049646136977}, {2.0954862852533283, \
0.6884858883697301}}], 
  Line[{{2.2505658318693045, 0.9410557119019607}, {2.458102773991312, \
1.1666712321091806}, {2.4963040904617113, 1.1147172382160908}, 
    {2.2864745084375784, 0.8816778784387095}, {2.2505658318693045, \
0.9410557119019607}}], 
  Line[{{2.458102773991312, 1.1666712321091806}, {2.709026751375883, \
1.3494565251821795}, {2.7499999999999982, 1.2990381056766562}, 
    {2.4963040904617113, 1.1147172382160908}, {2.458102773991312, \
1.1666712321091806}}], 
  Line[{{2.709026751375883, 1.3494565251821795}, {2.992371182144481, \
1.4795217391705868}, {3.0364745084375784, 1.4265847744427305}, 
    {2.7499999999999982, 1.2990381056766562}, {2.709026751375883, \
1.3494565251821795}}], 
  Line[{{2.992371182144481, 1.4795217391705868}, {3.295752555035085, \
1.5507915961279446}, {3.3432073050985176, 1.4917828430524107}, 
    {3.0364745084375784, 1.4265847744427305}, {2.992371182144481, \
1.4795217391705868}}], 
  Line[{{3.295752555035085, 1.5507915961279446}, {3.605911648267035, \
1.560594218929799}, {3.6567926949014775, 1.49178284305241}, 
    {3.3432073050985176, 1.4917828430524107}, {3.295752555035085, \
1.5507915961279446}}], 
  Line[{{3.605911648267035, 1.560594218929799}, {3.9092930211576427, \
1.5096856680207968}, {3.963525491562421, 1.4265847744427305}, 
    {3.6567926949014775, 1.49178284305241}, {3.605911648267035, \
1.560594218929799}}], 
  Line[{{3.9092930211576427, 1.5096856680207968}, {4.192637451926238, \
1.4024710170213415}, {4.249999999999998, 1.2990381056766607}, 
    {3.963525491562421, 1.4265847744427305}, {3.9092930211576427, \
1.5096856680207968}}], 
  Line[{{4.192637451926238, 1.4024710170213415}, {4.443561429310809, \
1.2475429541754033}, {4.503695909538285, 1.114717238216094}, 
    {4.249999999999998, 1.2990381056766607}, {4.192637451926238, \
1.4024710170213415}}], 
  Line[{{4.443561429310809, 1.2475429541754033}, {4.651098371432819, \
1.0590770192391419}, {4.713525491562421, 0.8816778784387115}, 
    {4.503695909538285, 1.114717238216094}, {4.443561429310809, \
1.2475429541754033}}], 
  Line[{{4.651098371432819, 1.0590770192391419}, {4.806177918048795, \
0.8605642566348355}, {4.870318186463901, 0.6101049646136991}, 
    {4.713525491562421, 0.8816778784387115}, {4.651098371432819, \
1.0590770192391419}}], 
  Line[{{4.806177918048795, 0.8605642566348355}, {4.9020223488173915, \
0.6935451872894184}, {4.967221401100708, 0.3118675362266461}, 
    {4.870318186463901, 0.6101049646136991}, {4.806177918048795, \
0.8605642566348355}}], 
  Line[{{4.9020223488173915, 0.6935451872894184}, {4.934442802201416, \
0.6237350724532809}, {5., 0.}, {4.967221401100708, 0.3118675362266461}, 
    {4.9020223488173915, 0.6935451872894184}}], Line[{{5., 0.}, \
{4.967221401100708, 0.3118675362266461}, {4.902022348817392, \
0.6935451872894184}, 
    {4.934442802201418, 0.6237350724532723}, {5., 0.}}], \
Line[{{4.967221401100708, 0.3118675362266461}, {4.870318186463902, \
0.6101049646136962}, 
    {4.806177918048797, 0.8605642566348314}, {4.902022348817392, \
0.6935451872894184}, {4.967221401100708, 0.3118675362266461}}], 
  Line[{{4.870318186463902, 0.6101049646136962}, {4.713525491562421, \
0.8816778784387095}, {4.651098371432821, 1.0590770192391386}, 
    {4.806177918048797, 0.8605642566348314}, {4.870318186463902, \
0.6101049646136962}}], 
  Line[{{4.713525491562421, 0.8816778784387095}, {4.503695909538287, \
1.1147172382160924}, {4.443561429310812, 1.247542954175402}, 
    {4.651098371432821, 1.0590770192391386}, {4.713525491562421, \
0.8816778784387095}}], 
  Line[{{4.503695909538287, 1.1147172382160924}, {4.25, 1.2990381056766593}, \
{4.192637451926241, 1.4024710170213401}, 
    {4.443561429310812, 1.247542954175402}, {4.503695909538287, \
1.1147172382160924}}], 
  Line[{{4.25, 1.2990381056766593}, {3.963525491562421, 1.4265847744427318}, \
{3.909293021157644, 1.5096856680207957}, 
    {4.192637451926241, 1.4024710170213401}, {4.25, 1.2990381056766593}}], 
  Line[{{3.963525491562421, 1.4265847744427318}, {3.6567926949014806, \
1.49178284305241}, {3.605911648267039, 1.5605942189297979}, 
    {3.909293021157644, 1.5096856680207957}, {3.963525491562421, \
1.4265847744427318}}], 
  Line[{{3.6567926949014806, 1.49178284305241}, {3.3432073050985194, \
1.4917828430524107}, {3.2957525550350875, 1.5507915961279435}, 
    {3.605911648267039, 1.5605942189297979}, {3.6567926949014806, \
1.49178284305241}}], 
  Line[{{3.3432073050985194, 1.4917828430524107}, {3.036474508437579, \
1.4265847744427305}, {2.9923711821444825, 1.4795217391705868}, 
    {3.2957525550350875, 1.5507915961279435}, {3.3432073050985194, \
1.4917828430524107}}], 
  Line[{{3.036474508437579, 1.4265847744427305}, {2.75, 1.2990381056766587}, \
{2.7090267513758866, 1.3494565251821795}, 
    {2.9923711821444825, 1.4795217391705868}, {3.036474508437579, \
1.4265847744427305}}], 
  Line[{{2.75, 1.2990381056766587}, {2.496304090461713, 1.1147172382160917}, \
{2.458102773991315, 1.1666712321091803}, 
    {2.7090267513758866, 1.3494565251821795}, {2.75, 1.2990381056766587}}], 
  Line[{{2.496304090461713, 1.1147172382160917}, {2.286474508437579, \
0.88167787843871}, {2.2505658318693054, 0.9410557119019611}, 
    {2.458102773991315, 1.1666712321091803}, {2.496304090461713, \
1.1147172382160917}}], 
  Line[{{2.286474508437579, 0.88167787843871}, {2.1296818135360986, \
0.6101049646137013}, {2.09548628525333, 0.6884858883697313}, 
    {2.2505658318693054, 0.9410557119019611}, {2.286474508437579, \
0.88167787843871}}], 
  Line[{{2.1296818135360986, 0.6101049646137013}, {2.0327785988992915, \
0.31186753622664043}, {1.9996418544847334, 0.442263528432696}, 
    {2.09548628525333, 0.6884858883697313}, {2.1296818135360986, \
0.6101049646137013}}], 
  Line[{{2.0327785988992915, 0.31186753622664043}, {2., 0.}, \
{1.9672214011007088, 0.31186753622663826}, {1.9996418544847334, \
0.442263528432696}, 
    {2.0327785988992915, 0.31186753622664043}}], Line[{{2., 0.}, \
{2.0327785988992915, 0.311867536226639}, {1.9996418544847336, \
0.442263528432694}, 
    {1.9672214011007088, 0.31186753622663826}, {2., 0.}}], 
  Line[{{2.0327785988992915, 0.311867536226639}, {2.1296818135360986, \
0.6101049646136991}, {2.09548628525333, 0.6884858883697295}, 
    {1.9996418544847336, 0.442263528432694}, {2.0327785988992915, \
0.311867536226639}}], 
  Line[{{2.1296818135360986, 0.6101049646136991}, {2.286474508437579, \
0.8816778784387095}, {2.2505658318693054, 0.9410557119019607}, 
    {2.09548628525333, 0.6884858883697295}, {2.1296818135360986, \
0.6101049646136991}}], 
  Line[{{2.286474508437579, 0.8816778784387095}, {2.496304090461712, \
1.1147172382160913}, {2.458102773991314, 1.16667123210918}, 
    {2.2505658318693054, 0.9410557119019607}, {2.286474508437579, \
0.8816778784387095}}], 
  Line[{{2.496304090461712, 1.1147172382160913}, {2.749999999999999, \
1.299038105676658}, {2.7090267513758852, 1.3494565251821795}, 
    {2.458102773991314, 1.16667123210918}, {2.496304090461712, \
1.1147172382160913}}], 
  Line[{{2.749999999999999, 1.299038105676658}, {3.0364745084375784, \
1.4265847744427305}, {2.992371182144482, 1.4795217391705868}, 
    {2.7090267513758852, 1.3494565251821795}, {2.749999999999999, \
1.299038105676658}}], 
  Line[{{3.0364745084375784, 1.4265847744427305}, {3.3432073050985185, \
1.4917828430524107}, {3.2957525550350866, 1.550791596127943}, 
    {2.992371182144482, 1.4795217391705868}, {3.0364745084375784, \
1.4265847744427305}}], 
  Line[{{3.3432073050985185, 1.4917828430524107}, {3.656792694901479, \
1.4917828430524112}, {3.6059116482670377, 1.5605942189297983}, 
    {3.2957525550350866, 1.550791596127943}, {3.3432073050985185, \
1.4917828430524107}}], 
  Line[{{3.656792694901479, 1.4917828430524112}, {3.963525491562421, \
1.4265847744427305}, {3.909293021157644, 1.5096856680207946}, 
    {3.6059116482670377, 1.5605942189297983}, {3.656792694901479, \
1.4917828430524112}}], 
  Line[{{3.963525491562421, 1.4265847744427305}, {4.249999999999999, \
1.299038105676658}, {4.19263745192624, 1.4024710170213388}, 
    {3.909293021157644, 1.5096856680207946}, {3.963525491562421, \
1.4265847744427305}}], 
  Line[{{4.249999999999999, 1.299038105676658}, {4.503695909538286, \
1.1147172382160955}, {4.4435614293108125, 1.2475429541753977}, 
    {4.19263745192624, 1.4024710170213388}, {4.249999999999999, \
1.299038105676658}}], 
  Line[{{4.503695909538286, 1.1147172382160955}, {4.713525491562421, \
0.8816778784387115}, {4.651098371432821, 1.0590770192391386}, 
    {4.4435614293108125, 1.2475429541753977}, {4.503695909538286, \
1.1147172382160955}}], 
  Line[{{4.713525491562421, 0.8816778784387115}, {4.870318186463901, \
0.6101049646136991}, {4.806177918048797, 0.8605642566348294}, 
    {4.651098371432821, 1.0590770192391386}, {4.713525491562421, \
0.8816778784387115}}], 
  Line[{{4.870318186463901, 0.6101049646136991}, {4.967221401100708, \
0.3118675362266461}, {4.902022348817392, 0.6935451872894184}, 
    {4.806177918048797, 0.8605642566348294}, {4.870318186463901, \
0.6101049646136991}}], 
  Line[{{4.967221401100708, 0.3118675362266461}, {5., 0.}, \
{4.934442802201418, 0.6237350724532723}, {4.902022348817392, \
0.6935451872894184}, 
    {4.967221401100708, 0.3118675362266461}}], Line[{{5., 0.}, \
{4.967221401100709, 0.31186753622662905}, {4.902022348817393, \
0.6935451872894158}, 
    {4.934442802201418, 0.6237350724532723}, {5., 0.}}], \
Line[{{4.967221401100709, 0.31186753622662905}, {4.870318186463902, \
0.6101049646136962}, 
    {4.806177918048797, 0.8605642566348314}, {4.902022348817393, \
0.6935451872894158}, {4.967221401100709, 0.31186753622662905}}], 
  Line[{{4.870318186463902, 0.6101049646136962}, {4.713525491562422, \
0.8816778784387075}, {4.651098371432822, 1.0590770192391352}, 
    {4.806177918048797, 0.8605642566348314}, {4.870318186463902, \
0.6101049646136962}}], 
  Line[{{4.713525491562422, 0.8816778784387075}, {4.503695909538288, \
1.1147172382160924}, {4.443561429310814, 1.2475429541753962}, 
    {4.651098371432822, 1.0590770192391352}, {4.713525491562422, \
0.8816778784387075}}], 
  Line[{{4.503695909538288, 1.1147172382160924}, {4.250000000000001, \
1.299038105676658}, {4.192637451926242, 1.4024710170213401}, 
    {4.443561429310814, 1.2475429541753962}, {4.503695909538288, \
1.1147172382160924}}], 
  Line[{{4.250000000000001, 1.299038105676658}, {3.9635254915624225, \
1.426584774442728}, {3.9092930211576453, 1.5096856680207935}, 
    {4.192637451926242, 1.4024710170213401}, {4.250000000000001, \
1.299038105676658}}], 
  Line[{{3.9635254915624225, 1.426584774442728}, {3.656792694901482, \
1.491782843052409}, {3.6059116482670404, 1.5605942189297979}, 
    {3.9092930211576453, 1.5096856680207935}, {3.9635254915624225, \
1.426584774442728}}], 
  Line[{{3.656792694901482, 1.491782843052409}, {3.3432073050985207, \
1.49178284305241}, {3.295752555035089, 1.550791596127943}, 
    {3.6059116482670404, 1.5605942189297979}, {3.656792694901482, \
1.491782843052409}}], 
  Line[{{3.3432073050985207, 1.49178284305241}, {3.0364745084375793, \
1.4265847744427311}, {2.992371182144483, 1.4795217391705875}, 
    {3.295752555035089, 1.550791596127943}, {3.3432073050985207, \
1.49178284305241}}], 
  Line[{{3.0364745084375793, 1.4265847744427311}, {2.7500000000000013, \
1.2990381056766587}, {2.7090267513758874, 1.3494565251821806}, 
    {2.992371182144483, 1.4795217391705875}, {3.0364745084375793, \
1.4265847744427311}}], 
  Line[{{2.7500000000000013, 1.2990381056766587}, {2.496304090461714, \
1.1147172382160933}, {2.4581027739913157, 1.1666712321091814}, 
    {2.7090267513758874, 1.3494565251821806}, {2.7500000000000013, \
1.2990381056766587}}], 
  Line[{{2.496304090461714, 1.1147172382160933}, {2.2864745084375793, \
0.88167787843871}, {2.250565831869306, 0.9410557119019607}, 
    {2.4581027739913157, 1.1666712321091814}, {2.496304090461714, \
1.1147172382160933}}], 
  Line[{{2.2864745084375793, 0.88167787843871}, {2.1296818135360995, \
0.6101049646137006}, {2.095486285253331, 0.6884858883697308}, 
    {2.250565831869306, 0.9410557119019607}, {2.2864745084375793, \
0.88167787843871}}], 
  Line[{{2.1296818135360995, 0.6101049646137006}, {2.0327785988992924, \
0.31186753622664043}, {1.999641854484734, 0.442263528432697}, 
    {2.095486285253331, 0.6884858883697308}, {2.1296818135360995, \
0.6101049646137006}}], 
  Line[{{2.0327785988992924, 0.31186753622664043}, {2., 0.}, \
{1.9672214011007088, 0.31186753622663826}, {1.999641854484734, \
0.442263528432697}, 
    {2.0327785988992924, 0.31186753622664043}}], Line[{{2., 0.}, \
{2.0327785988992915, 0.31186753622663616}, 
    {1.9996418544847332, 0.442263528432694}, {1.9672214011007088, \
0.31186753622663826}, {2., 0.}}], 
  Line[{{2.0327785988992915, 0.31186753622663616}, {2.1296818135360978, \
0.6101049646136977}, {2.095486285253329, 0.6884858883697281}, 
    {1.9996418544847332, 0.442263528432694}, {2.0327785988992915, \
0.31186753622663616}}], 
  Line[{{2.1296818135360978, 0.6101049646136977}, {2.2864745084375784, \
0.8816778784387095}, {2.250565831869305, 0.9410557119019607}, 
    {2.095486285253329, 0.6884858883697281}, {2.1296818135360978, \
0.6101049646136977}}], 
  Line[{{2.2864745084375784, 0.8816778784387095}, {2.4963040904617113, \
1.1147172382160908}, {2.458102773991313, 1.1666712321091794}, 
    {2.250565831869305, 0.9410557119019607}, {2.2864745084375784, \
0.8816778784387095}}], 
  Line[{{2.4963040904617113, 1.1147172382160908}, {2.7499999999999982, \
1.2990381056766562}, {2.709026751375884, 1.3494565251821788}, 
    {2.458102773991313, 1.1666712321091794}, {2.4963040904617113, \
1.1147172382160908}}], 
  Line[{{2.7499999999999982, 1.2990381056766562}, {3.0364745084375784, \
1.4265847744427305}, {2.992371182144482, 1.4795217391705862}, 
    {2.709026751375884, 1.3494565251821788}, {2.7499999999999982, \
1.2990381056766562}}], 
  Line[{{3.0364745084375784, 1.4265847744427305}, {3.3432073050985176, \
1.4917828430524107}, {3.2957525550350857, 1.5507915961279441}, 
    {2.992371182144482, 1.4795217391705862}, {3.0364745084375784, \
1.4265847744427305}}], 
  Line[{{3.3432073050985176, 1.4917828430524107}, {3.6567926949014775, \
1.49178284305241}, {3.605911648267036, 1.5605942189297983}, 
    {3.2957525550350857, 1.5507915961279441}, {3.3432073050985176, \
1.4917828430524107}}], 
  Line[{{3.6567926949014775, 1.49178284305241}, {3.963525491562421, \
1.4265847744427305}, {3.9092930211576444, 1.5096856680207935}, 
    {3.605911648267036, 1.5605942189297983}, {3.6567926949014775, \
1.49178284305241}}], 
  Line[{{3.963525491562421, 1.4265847744427305}, {4.249999999999998, \
1.2990381056766607}, {4.19263745192624, 1.4024710170213388}, 
    {3.9092930211576444, 1.5096856680207935}, {3.963525491562421, \
1.4265847744427305}}], 
  Line[{{4.249999999999998, 1.2990381056766607}, {4.503695909538285, \
1.114717238216094}, {4.443561429310811, 1.2475429541754004}, 
    {4.19263745192624, 1.4024710170213388}, {4.249999999999998, \
1.2990381056766607}}], 
  Line[{{4.503695909538285, 1.114717238216094}, {4.713525491562421, \
0.8816778784387115}, {4.651098371432821, 1.0590770192391386}, 
    {4.443561429310811, 1.2475429541754004}, {4.503695909538285, \
1.114717238216094}}], 
  Line[{{4.713525491562421, 0.8816778784387115}, {4.870318186463901, \
0.6101049646136991}, {4.806177918048797, 0.8605642566348294}, 
    {4.651098371432821, 1.0590770192391386}, {4.713525491562421, \
0.8816778784387115}}], 
  Line[{{4.870318186463901, 0.6101049646136991}, {4.967221401100708, \
0.3118675362266461}, {4.902022348817393, 0.6935451872894107}, 
    {4.806177918048797, 0.8605642566348294}, {4.870318186463901, \
0.6101049646136991}}], 
  Line[{{4.967221401100708, 0.3118675362266461}, {5., 0.}, \
{4.934442802201418, 0.6237350724532723}, {4.902022348817393, \
0.6935451872894107}, 
    {4.967221401100708, 0.3118675362266461}}], Line[{{4.934442802201418, \
0.6237350724532723}, {4.902022348817392, 0.6935451872894184}, 
    {4.709274703411989, 1.2512975557014567}, {4.740636372927804, \
1.2202099292273982}, {4.934442802201418, 0.6237350724532723}}], 
  Line[{{4.902022348817392, 0.6935451872894184}, {4.806177918048797, \
0.8605642566348314}, {4.616560350312376, 1.3346849311080466}, 
    {4.709274703411989, 1.2512975557014567}, {4.902022348817392, \
0.6935451872894184}}], 
  Line[{{4.806177918048797, 0.8605642566348314}, {4.651098371432821, \
1.0590770192391386}, {4.46654537575224, 1.4470248504530079}, 
    {4.616560350312376, 1.3346849311080466}, {4.806177918048797, \
0.8605642566348314}}], 
  Line[{{4.651098371432821, 1.0590770192391386}, {4.443561429310812, \
1.247542954175402}, {4.265786153971577, 1.5625819810819546}, 
    {4.46654537575224, 1.4470248504530079}, {4.651098371432821, \
1.0590770192391386}}], 
  Line[{{4.443561429310812, 1.247542954175402}, {4.192637451926241, \
1.4024710170213401}, {4.023056826311829, 1.6596693760099273}, 
    {4.265786153971577, 1.5625819810819546}, {4.443561429310812, \
1.247542954175402}}], 
  Line[{{4.192637451926241, 1.4024710170213401}, {3.909293021157644, \
1.5096856680207957}, {3.7489658291362655, 1.7222389198769947}, 
    {4.023056826311829, 1.6596693760099273}, {4.192637451926241, \
1.4024710170213401}}], 
  Line[{{3.909293021157644, 1.5096856680207957}, {3.605911648267039, \
1.5605942189297979}, {3.4554922542559883, 1.7395717696563637}, 
    {3.7489658291362655, 1.7222389198769947}, {3.909293021157644, \
1.5096856680207957}}], 
  Line[{{3.605911648267039, 1.5605942189297979}, {3.2957525550350875, \
1.5507915961279435}, {3.1554623051357176, 1.705691841463222}, 
    {3.4554922542559883, 1.7395717696563637}, {3.605911648267039, \
1.5605942189297979}}], 
  Line[{{3.2957525550350875, 1.5507915961279435}, {2.9923711821444825, \
1.4795217391705868}, {2.8619887302554403, 1.6189603147994467}, 
    {3.1554623051357176, 1.705691841463222}, {3.2957525550350875, \
1.5507915961279435}}], 
  Line[{{2.9923711821444825, 1.4795217391705868}, {2.7090267513758866, \
1.3494565251821795}, {2.5878977330798776, 1.4819447816621785}, 
    {2.8619887302554403, 1.6189603147994467}, {2.9923711821444825, \
1.4795217391705868}}], 
  Line[{{2.7090267513758866, 1.3494565251821795}, {2.458102773991315, \
1.1666712321091803}, {2.3451684054201287, 1.3017122836390151}, 
    {2.5878977330798776, 1.4819447816621785}, {2.7090267513758866, \
1.3494565251821795}}], 
  Line[{{2.458102773991315, 1.1666712321091803}, {2.2505658318693054, \
0.9410557119019611}, {2.144409183639465, 1.0910840571723}, 
    {2.3451684054201287, 1.3017122836390151}, {2.458102773991315, \
1.1666712321091803}}], 
  Line[{{2.2505658318693054, 0.9410557119019611}, {2.09548628525333, \
0.6884858883697313}, {1.99439420907933, 0.8724918816600724}, 
    {2.144409183639465, 1.0910840571723}, {2.2505658318693054, \
0.9410557119019611}}], 
  Line[{{2.09548628525333, 0.6884858883697313}, {1.9996418544847334, \
0.442263528432696}, {1.901679855979716, 0.6880869119781076}, 
    {1.99439420907933, 0.8724918816600724}, {2.09548628525333, \
0.6884858883697313}}], 
  Line[{{1.9996418544847334, 0.442263528432696}, {1.9672214011007088, \
0.31186753622663826}, {1.8703181864639018, 0.6101049646136991}, 
    {1.901679855979716, 0.6880869119781076}, {1.9996418544847334, \
0.442263528432696}}], 
  Line[{{1.9672214011007088, 0.31186753622663826}, {1.9996418544847336, \
0.442263528432694}, {1.901679855979716, 0.6880869119781069}, 
    {1.8703181864639018, 0.6101049646136991}, {1.9672214011007088, \
0.31186753622663826}}], 
  Line[{{1.9996418544847336, 0.442263528432694}, {2.09548628525333, \
0.6884858883697295}, {1.9943942090793298, 0.8724918816600712}, 
    {1.901679855979716, 0.6880869119781069}, {1.9996418544847336, \
0.442263528432694}}], 
  Line[{{2.09548628525333, 0.6884858883697295}, {2.2505658318693054, \
0.9410557119019607}, {2.144409183639465, 1.0910840571722995}, 
    {1.9943942090793298, 0.8724918816600712}, {2.09548628525333, \
0.6884858883697295}}], 
  Line[{{2.2505658318693054, 0.9410557119019607}, {2.458102773991314, \
1.16667123210918}, {2.345168405420128, 1.301712283639015}, 
    {2.144409183639465, 1.0910840571722995}, {2.2505658318693054, \
0.9410557119019607}}], 
  Line[{{2.458102773991314, 1.16667123210918}, {2.7090267513758852, \
1.3494565251821795}, {2.5878977330798767, 1.4819447816621778}, 
    {2.345168405420128, 1.301712283639015}, {2.458102773991314, \
1.16667123210918}}], 
  Line[{{2.7090267513758852, 1.3494565251821795}, {2.992371182144482, \
1.4795217391705868}, {2.86198873025544, 1.6189603147994462}, 
    {2.5878977330798767, 1.4819447816621778}, {2.7090267513758852, \
1.3494565251821795}}], 
  Line[{{2.992371182144482, 1.4795217391705868}, {3.2957525550350866, \
1.550791596127943}, {3.1554623051357167, 1.705691841463221}, 
    {2.86198873025544, 1.6189603147994462}, {2.992371182144482, \
1.4795217391705868}}], 
  Line[{{3.2957525550350866, 1.550791596127943}, {3.6059116482670377, \
1.5605942189297983}, {3.4554922542559865, 1.7395717696563644}, 
    {3.1554623051357167, 1.705691841463221}, {3.2957525550350866, \
1.550791596127943}}], 
  Line[{{3.6059116482670377, 1.5605942189297983}, {3.909293021157644, \
1.5096856680207946}, {3.748965829136265, 1.7222389198769947}, 
    {3.4554922542559865, 1.7395717696563644}, {3.6059116482670377, \
1.5605942189297983}}], 
  Line[{{3.909293021157644, 1.5096856680207946}, {4.19263745192624, \
1.4024710170213388}, {4.023056826311827, 1.6596693760099293}, 
    {3.748965829136265, 1.7222389198769947}, {3.909293021157644, \
1.5096856680207946}}], 
  Line[{{4.19263745192624, 1.4024710170213388}, {4.4435614293108125, \
1.2475429541753977}, {4.265786153971577, 1.5625819810819535}, 
    {4.023056826311827, 1.6596693760099293}, {4.19263745192624, \
1.4024710170213388}}], 
  Line[{{4.4435614293108125, 1.2475429541753977}, {4.651098371432821, \
1.0590770192391386}, {4.46654537575224, 1.447024850453009}, 
    {4.265786153971577, 1.5625819810819535}, {4.4435614293108125, \
1.2475429541753977}}], 
  Line[{{4.651098371432821, 1.0590770192391386}, {4.806177918048797, \
0.8605642566348294}, {4.616560350312375, 1.3346849311080493}, 
    {4.46654537575224, 1.447024850453009}, {4.651098371432821, \
1.0590770192391386}}], 
  Line[{{4.806177918048797, 0.8605642566348294}, {4.902022348817392, \
0.6935451872894184}, {4.709274703411989, 1.2512975557014567}, 
    {4.616560350312375, 1.3346849311080493}, {4.806177918048797, \
0.8605642566348294}}], 
  Line[{{4.902022348817392, 0.6935451872894184}, {4.934442802201418, \
0.6237350724532723}, {4.740636372927804, 1.2202099292273982}, 
    {4.709274703411989, 1.2512975557014567}, {4.902022348817392, \
0.6935451872894184}}], 
  Line[{{4.934442802201418, 0.6237350724532723}, {4.902022348817393, \
0.6935451872894158}, {4.70927470341199, 1.2512975557014552}, 
    {4.740636372927804, 1.2202099292273982}, {4.934442802201418, \
0.6237350724532723}}], 
  Line[{{4.902022348817393, 0.6935451872894158}, {4.806177918048797, \
0.8605642566348314}, {4.616560350312376, 1.3346849311080466}, 
    {4.70927470341199, 1.2512975557014552}, {4.902022348817393, \
0.6935451872894158}}], 
  Line[{{4.806177918048797, 0.8605642566348314}, {4.651098371432822, \
1.0590770192391352}, {4.466545375752241, 1.4470248504530079}, 
    {4.616560350312376, 1.3346849311080466}, {4.806177918048797, \
0.8605642566348314}}], 
  Line[{{4.651098371432822, 1.0590770192391352}, {4.443561429310814, \
1.2475429541753962}, {4.265786153971579, 1.5625819810819535}, 
    {4.466545375752241, 1.4470248504530079}, {4.651098371432822, \
1.0590770192391352}}], 
  Line[{{4.443561429310814, 1.2475429541753962}, {4.192637451926242, \
1.4024710170213401}, {4.02305682631183, 1.6596693760099261}, 
    {4.265786153971579, 1.5625819810819535}, {4.443561429310814, \
1.2475429541753962}}], 
  Line[{{4.192637451926242, 1.4024710170213401}, {3.9092930211576453, \
1.5096856680207935}, {3.7489658291362664, 1.7222389198769943}, 
    {4.02305682631183, 1.6596693760099261}, {4.192637451926242, \
1.4024710170213401}}], 
  Line[{{3.9092930211576453, 1.5096856680207935}, {3.6059116482670404, \
1.5605942189297979}, {3.455492254255989, 1.7395717696563633}, 
    {3.7489658291362664, 1.7222389198769943}, {3.9092930211576453, \
1.5096856680207935}}], 
  Line[{{3.6059116482670404, 1.5605942189297979}, {3.295752555035089, \
1.550791596127943}, {3.155462305135719, 1.705691841463221}, 
    {3.455492254255989, 1.7395717696563633}, {3.6059116482670404, \
1.5605942189297979}}], 
  Line[{{3.295752555035089, 1.550791596127943}, {2.992371182144483, \
1.4795217391705875}, {2.861988730255441, 1.6189603147994462}, 
    {3.155462305135719, 1.705691841463221}, {3.295752555035089, \
1.550791596127943}}], 
  Line[{{2.992371182144483, 1.4795217391705875}, {2.7090267513758874, \
1.3494565251821806}, {2.5878977330798785, 1.4819447816621794}, 
    {2.861988730255441, 1.6189603147994462}, {2.992371182144483, \
1.4795217391705875}}], 
  Line[{{2.7090267513758874, 1.3494565251821806}, {2.4581027739913157, \
1.1666712321091814}, {2.3451684054201296, 1.301712283639017}, 
    {2.5878977330798785, 1.4819447816621794}, {2.7090267513758874, \
1.3494565251821806}}], 
  Line[{{2.4581027739913157, 1.1666712321091814}, {2.250565831869306, \
0.9410557119019607}, {2.144409183639465, 1.0910840571723004}, 
    {2.3451684054201296, 1.301712283639017}, {2.4581027739913157, \
1.1666712321091814}}], 
  Line[{{2.250565831869306, 0.9410557119019607}, {2.095486285253331, \
0.6884858883697308}, {1.9943942090793307, 0.8724918816600724}, 
    {2.144409183639465, 1.0910840571723004}, {2.250565831869306, \
0.9410557119019607}}], 
  Line[{{2.095486285253331, 0.6884858883697308}, {1.999641854484734, \
0.442263528432697}, {1.9016798559797166, 0.6880869119781079}, 
    {1.9943942090793307, 0.8724918816600724}, {2.095486285253331, \
0.6884858883697308}}], 
  Line[{{1.999641854484734, 0.442263528432697}, {1.9672214011007088, \
0.31186753622663826}, {1.8703181864639018, 0.6101049646136991}, 
    {1.9016798559797166, 0.6880869119781079}, {1.999641854484734, \
0.442263528432697}}], 
  Line[{{1.9672214011007088, 0.31186753622663826}, {1.9996418544847332, \
0.442263528432694}, {1.9016798559797157, 0.6880869119781062}, 
    {1.8703181864639018, 0.6101049646136991}, {1.9672214011007088, \
0.31186753622663826}}], 
  Line[{{1.9996418544847332, 0.442263528432694}, {2.095486285253329, \
0.6884858883697281}, {1.994394209079329, 0.8724918816600701}, 
    {1.9016798559797157, 0.6880869119781062}, {1.9996418544847332, \
0.442263528432694}}], 
  Line[{{2.095486285253329, 0.6884858883697281}, {2.250565831869305, \
0.9410557119019607}, {2.1444091836394645, 1.0910840571722995}, 
    {1.994394209079329, 0.8724918816600701}, {2.095486285253329, \
0.6884858883697281}}], 
  Line[{{2.250565831869305, 0.9410557119019607}, {2.458102773991313, \
1.1666712321091794}, {2.345168405420127, 1.3017122836390145}, 
    {2.1444091836394645, 1.0910840571722995}, {2.250565831869305, \
0.9410557119019607}}], 
  Line[{{2.458102773991313, 1.1666712321091794}, {2.709026751375884, \
1.3494565251821788}, {2.587897733079876, 1.481944781662177}, 
    {2.345168405420127, 1.3017122836390145}, {2.458102773991313, \
1.1666712321091794}}], 
  Line[{{2.709026751375884, 1.3494565251821788}, {2.992371182144482, \
1.4795217391705862}, {2.8619887302554394, 1.6189603147994462}, 
    {2.587897733079876, 1.481944781662177}, {2.709026751375884, \
1.3494565251821788}}], 
  Line[{{2.992371182144482, 1.4795217391705862}, {3.2957525550350857, \
1.5507915961279441}, {3.1554623051357167, 1.7056918414632198}, 
    {2.8619887302554394, 1.6189603147994462}, {2.992371182144482, \
1.4795217391705862}}], 
  Line[{{3.2957525550350857, 1.5507915961279441}, {3.605911648267036, \
1.5605942189297983}, {3.455492254255985, 1.7395717696563637}, 
    {3.1554623051357167, 1.7056918414632198}, {3.2957525550350857, \
1.5507915961279441}}], 
  Line[{{3.605911648267036, 1.5605942189297983}, {3.9092930211576444, \
1.5096856680207935}, {3.7489658291362655, 1.7222389198769938}, 
    {3.455492254255985, 1.7395717696563637}, {3.605911648267036, \
1.5605942189297983}}], 
  Line[{{3.9092930211576444, 1.5096856680207935}, {4.19263745192624, \
1.4024710170213388}, {4.023056826311827, 1.6596693760099281}, 
    {3.7489658291362655, 1.7222389198769938}, {3.9092930211576444, \
1.5096856680207935}}], 
  Line[{{4.19263745192624, 1.4024710170213388}, {4.443561429310811, \
1.2475429541754004}, {4.265786153971575, 1.562581981081956}, 
    {4.023056826311827, 1.6596693760099281}, {4.19263745192624, \
1.4024710170213388}}], 
  Line[{{4.443561429310811, 1.2475429541754004}, {4.651098371432821, \
1.0590770192391386}, {4.46654537575224, 1.447024850453009}, 
    {4.265786153971575, 1.562581981081956}, {4.443561429310811, \
1.2475429541754004}}], 
  Line[{{4.651098371432821, 1.0590770192391386}, {4.806177918048797, \
0.8605642566348294}, {4.616560350312375, 1.3346849311080493}, 
    {4.46654537575224, 1.447024850453009}, {4.651098371432821, \
1.0590770192391386}}], 
  Line[{{4.806177918048797, 0.8605642566348294}, {4.902022348817393, \
0.6935451872894107}, {4.70927470341199, 1.2512975557014525}, 
    {4.616560350312375, 1.3346849311080493}, {4.806177918048797, \
0.8605642566348294}}], 
  Line[{{4.902022348817393, 0.6935451872894107}, {4.934442802201418, \
0.6237350724532723}, {4.740636372927804, 1.2202099292273982}, 
    {4.70927470341199, 1.2512975557014525}, {4.902022348817393, \
0.6935451872894107}}], 
  Line[{{4.740636372927804, 1.2202099292273982}, {4.709274703411989, \
1.2512975557014567}, {4.397402461894534, 1.7786275248098171}, 
    {4.427050983124843, 1.763355756877417}, {4.740636372927804, \
1.2202099292273982}}], 
  Line[{{4.709274703411989, 1.2512975557014567}, {4.616560350312376, \
1.3346849311080466}, {4.309752680850761, 1.82020538579592}, 
    {4.397402461894534, 1.7786275248098171}, {4.709274703411989, \
1.2512975557014567}}], 
  Line[{{4.616560350312376, 1.3346849311080466}, {4.46654537575224, \
1.4470248504530079}, {4.167932356015448, 1.8768892930626255}, 
    {4.309752680850761, 1.82020538579592}, {4.616560350312376, \
1.3346849311080466}}], 
  Line[{{4.46654537575224, 1.4470248504530079}, {4.265786153971577, \
1.5625819810819546}, {3.9781397161133225, 1.9339672857886046}, 
    {4.167932356015448, 1.8768892930626255}, {4.46654537575224, \
1.4470248504530079}}], 
  Line[{{4.265786153971577, 1.5625819810819546}, {4.023056826311829, \
1.6596693760099273}, {3.748669610234238, 1.976615915035448}, 
    {3.9781397161133225, 1.9339672857886046}, {4.265786153971577, \
1.5625819810819546}}], 
  Line[{{4.023056826311829, 1.6596693760099273}, {3.7489658291362655, \
1.7222389198769947}, {3.489550983124843, 1.9921691365624095}, 
    {3.748669610234238, 1.976615915035448}, {4.023056826311829, \
1.6596693760099273}}], 
  Line[{{3.7489658291362655, 1.7222389198769947}, {3.4554922542559883, \
1.7395717696563637}, {3.212108562178944, 1.97128525856985}, 
    {3.489550983124843, 1.9921691365624095}, {3.7489658291362655, \
1.7222389198769947}}], 
  Line[{{3.4554922542559883, 1.7395717696563637}, {3.1554623051357176, \
1.705691841463222}, {2.92846791250832, 1.908454380799519}, 
    {3.212108562178944, 1.97128525856985}, {3.4554922542559883, \
1.7395717696563637}}], 
  Line[{{3.1554623051357176, 1.705691841463222}, {2.8619887302554403, \
1.6189603147994467}, {2.6510254915624216, 1.8022456366013602}, 
    {2.92846791250832, 1.908454380799519}, {3.1554623051357176, \
1.705691841463222}}], 
  Line[{{2.8619887302554403, 1.6189603147994467}, {2.5878977330798776, \
1.4819447816621785}, {2.391906864453027, 1.6555895184432492}, 
    {2.6510254915624216, 1.8022456366013602}, {2.8619887302554403, \
1.6189603147994467}}], 
  Line[{{2.5878977330798776, 1.4819447816621785}, {2.3451684054201287, \
1.3017122836390151}, {2.162436758573942, 1.4764049667388979}, 
    {2.391906864453027, 1.6555895184432492}, {2.5878977330798776, \
1.4819447816621785}}], 
  Line[{{2.3451684054201287, 1.3017122836390151}, {2.144409183639465, \
1.0910840571723}, {1.972644118671816, 1.2790742990138138}, 
    {2.162436758573942, 1.4764049667388979}, {2.3451684054201287, \
1.3017122836390151}}], 
  Line[{{2.144409183639465, 1.0910840571723}, {1.99439420907933, \
0.8724918816600724}, {1.8308237938365044, 1.0875191232355923}, 
    {1.972644118671816, 1.2790742990138138}, {2.144409183639465, \
1.0910840571723}}], 
  Line[{{1.99439420907933, 0.8724918816600724}, {1.901679855979716, \
0.6880869119781076}, {1.7431740127927307, 0.9393665425693399}, 
    {1.8308237938365044, 1.0875191232355923}, {1.99439420907933, \
0.8724918816600724}}], 
  Line[{{1.901679855979716, 0.6880869119781076}, {1.8703181864639018, \
0.6101049646136991}, {1.7135254915624214, 0.8816778784387095}, 
    {1.7431740127927307, 0.9393665425693399}, {1.901679855979716, \
0.6880869119781076}}], 
  Line[{{1.8703181864639018, 0.6101049646136991}, {1.901679855979716, \
0.6880869119781069}, {1.7431740127927309, 0.9393665425693389}, 
    {1.7135254915624214, 0.8816778784387095}, {1.8703181864639018, \
0.6101049646136991}}], 
  Line[{{1.901679855979716, 0.6880869119781069}, {1.9943942090793298, \
0.8724918816600712}, {1.8308237938365042, 1.0875191232355914}, 
    {1.7431740127927309, 0.9393665425693389}, {1.901679855979716, \
0.6880869119781069}}], 
  Line[{{1.9943942090793298, 0.8724918816600712}, {2.144409183639465, \
1.0910840571722995}, {1.9726441186718162, 1.279074299013813}, 
    {1.8308237938365042, 1.0875191232355914}, {1.9943942090793298, \
0.8724918816600712}}], 
  Line[{{2.144409183639465, 1.0910840571722995}, {2.345168405420128, \
1.301712283639015}, {2.162436758573941, 1.4764049667388972}, 
    {1.9726441186718162, 1.279074299013813}, {2.144409183639465, \
1.0910840571722995}}], 
  Line[{{2.345168405420128, 1.301712283639015}, {2.5878977330798767, \
1.4819447816621778}, {2.391906864453026, 1.6555895184432483}, 
    {2.162436758573941, 1.4764049667388972}, {2.345168405420128, \
1.301712283639015}}], 
  Line[{{2.5878977330798767, 1.4819447816621778}, {2.86198873025544, \
1.6189603147994462}, {2.6510254915624207, 1.8022456366013606}, 
    {2.391906864453026, 1.6555895184432483}, {2.5878977330798767, \
1.4819447816621778}}], 
  Line[{{2.86198873025544, 1.6189603147994462}, {3.1554623051357167, \
1.705691841463221}, {2.928467912508319, 1.9084543807995185}, 
    {2.6510254915624207, 1.8022456366013606}, {2.86198873025544, \
1.6189603147994462}}], 
  Line[{{3.1554623051357167, 1.705691841463221}, {3.4554922542559865, \
1.7395717696563644}, {3.212108562178943, 1.9712852585698486}, 
    {2.928467912508319, 1.9084543807995185}, {3.1554623051357167, \
1.705691841463221}}], 
  Line[{{3.4554922542559865, 1.7395717696563644}, {3.748965829136265, \
1.7222389198769947}, {3.489550983124843, 1.9921691365624086}, 
    {3.212108562178943, 1.9712852585698486}, {3.4554922542559865, \
1.7395717696563644}}], 
  Line[{{3.748965829136265, 1.7222389198769947}, {4.023056826311827, \
1.6596693760099293}, {3.7486696102342365, 1.976615915035448}, 
    {3.489550983124843, 1.9921691365624086}, {3.748965829136265, \
1.7222389198769947}}], 
  Line[{{4.023056826311827, 1.6596693760099293}, {4.265786153971577, \
1.5625819810819535}, {3.9781397161133225, 1.9339672857886046}, 
    {3.7486696102342365, 1.976615915035448}, {4.023056826311827, \
1.6596693760099293}}], 
  Line[{{4.265786153971577, 1.5625819810819535}, {4.46654537575224, \
1.447024850453009}, {4.167932356015448, 1.8768892930626255}, 
    {3.9781397161133225, 1.9339672857886046}, {4.265786153971577, \
1.5625819810819535}}], 
  Line[{{4.46654537575224, 1.447024850453009}, {4.616560350312375, \
1.3346849311080493}, {4.309752680850761, 1.820205385795918}, 
    {4.167932356015448, 1.8768892930626255}, {4.46654537575224, \
1.447024850453009}}], 
  Line[{{4.616560350312375, 1.3346849311080493}, {4.709274703411989, \
1.2512975557014567}, {4.397402461894534, 1.7786275248098171}, 
    {4.309752680850761, 1.820205385795918}, {4.616560350312375, \
1.3346849311080493}}], 
  Line[{{4.709274703411989, 1.2512975557014567}, {4.740636372927804, \
1.2202099292273982}, {4.427050983124843, 1.763355756877417}, 
    {4.397402461894534, 1.7786275248098171}, {4.709274703411989, \
1.2512975557014567}}], 
  Line[{{4.740636372927804, 1.2202099292273982}, {4.70927470341199, \
1.2512975557014552}, {4.397402461894535, 1.778627524809816}, 
    {4.427050983124843, 1.763355756877417}, {4.740636372927804, \
1.2202099292273982}}], 
  Line[{{4.70927470341199, 1.2512975557014552}, {4.616560350312376, \
1.3346849311080466}, {4.309752680850761, 1.8202053857959188}, 
    {4.397402461894535, 1.778627524809816}, {4.70927470341199, \
1.2512975557014552}}], 
  Line[{{4.616560350312376, 1.3346849311080466}, {4.466545375752241, \
1.4470248504530079}, {4.167932356015449, 1.8768892930626246}, 
    {4.309752680850761, 1.8202053857959188}, {4.616560350312376, \
1.3346849311080466}}], 
  Line[{{4.466545375752241, 1.4470248504530079}, {4.265786153971579, \
1.5625819810819535}, {3.978139716113324, 1.9339672857886037}, 
    {4.167932356015449, 1.8768892930626246}, {4.466545375752241, \
1.4470248504530079}}], 
  Line[{{4.265786153971579, 1.5625819810819535}, {4.02305682631183, \
1.6596693760099261}, {3.7486696102342387, 1.9766159150354476}, 
    {3.978139716113324, 1.9339672857886037}, {4.265786153971579, \
1.5625819810819535}}], 
  Line[{{4.02305682631183, 1.6596693760099261}, {3.7489658291362664, \
1.7222389198769943}, {3.4895509831248437, 1.9921691365624086}, 
    {3.7486696102342387, 1.9766159150354476}, {4.02305682631183, \
1.6596693760099261}}], 
  Line[{{3.7489658291362664, 1.7222389198769943}, {3.455492254255989, \
1.7395717696563633}, {3.2121085621789454, 1.971285258569849}, 
    {3.4895509831248437, 1.9921691365624086}, {3.7489658291362664, \
1.7222389198769943}}], 
  Line[{{3.455492254255989, 1.7395717696563633}, {3.155462305135719, \
1.705691841463221}, {2.928467912508321, 1.9084543807995193}, 
    {3.2121085621789454, 1.971285258569849}, {3.455492254255989, \
1.7395717696563633}}], 
  Line[{{3.155462305135719, 1.705691841463221}, {2.861988730255441, \
1.6189603147994462}, {2.651025491562422, 1.8022456366013606}, 
    {2.928467912508321, 1.9084543807995193}, {3.155462305135719, \
1.705691841463221}}], 
  Line[{{2.861988730255441, 1.6189603147994462}, {2.5878977330798785, \
1.4819447816621794}, {2.391906864453028, 1.6555895184432494}, 
    {2.651025491562422, 1.8022456366013606}, {2.861988730255441, \
1.6189603147994462}}], 
  Line[{{2.5878977330798785, 1.4819447816621794}, {2.3451684054201296, \
1.301712283639017}, {2.1624367585739424, 1.4764049667388996}, 
    {2.391906864453028, 1.6555895184432494}, {2.5878977330798785, \
1.4819447816621794}}], 
  Line[{{2.3451684054201296, 1.301712283639017}, {2.144409183639465, \
1.0910840571723004}, {1.9726441186718164, 1.2790742990138138}, 
    {2.1624367585739424, 1.4764049667388996}, {2.3451684054201296, \
1.301712283639017}}], 
  Line[{{2.144409183639465, 1.0910840571723004}, {1.9943942090793307, \
0.8724918816600724}, {1.830823793836505, 1.0875191232355925}, 
    {1.9726441186718164, 1.2790742990138138}, {2.144409183639465, \
1.0910840571723004}}], 
  Line[{{1.9943942090793307, 0.8724918816600724}, {1.9016798559797166, \
0.6880869119781079}, {1.7431740127927313, 0.9393665425693402}, 
    {1.830823793836505, 1.0875191232355925}, {1.9943942090793307, \
0.8724918816600724}}], 
  Line[{{1.9016798559797166, 0.6880869119781079}, {1.8703181864639018, \
0.6101049646136991}, {1.7135254915624214, 0.8816778784387095}, 
    {1.7431740127927313, 0.9393665425693402}, {1.9016798559797166, \
0.6880869119781079}}], 
  Line[{{1.8703181864639018, 0.6101049646136991}, {1.9016798559797157, \
0.6880869119781062}, {1.7431740127927304, 0.9393665425693389}, 
    {1.7135254915624214, 0.8816778784387095}, {1.8703181864639018, \
0.6101049646136991}}], 
  Line[{{1.9016798559797157, 0.6880869119781062}, {1.994394209079329, \
0.8724918816600701}, {1.8308237938365033, 1.0875191232355905}, 
    {1.7431740127927304, 0.9393665425693389}, {1.9016798559797157, \
0.6880869119781062}}], 
  Line[{{1.994394209079329, 0.8724918816600701}, {2.1444091836394645, \
1.0910840571722995}, {1.9726441186718158, 1.279074299013813}, 
    {1.8308237938365033, 1.0875191232355905}, {1.994394209079329, \
0.8724918816600701}}], 
  Line[{{2.1444091836394645, 1.0910840571722995}, {2.345168405420127, \
1.3017122836390145}, {2.16243675857394, 1.476404966738897}, 
    {1.9726441186718158, 1.279074299013813}, {2.1444091836394645, \
1.0910840571722995}}], 
  Line[{{2.345168405420127, 1.3017122836390145}, {2.587897733079876, \
1.481944781662177}, {2.391906864453025, 1.6555895184432476}, 
    {2.16243675857394, 1.476404966738897}, {2.345168405420127, \
1.3017122836390145}}], 
  Line[{{2.587897733079876, 1.481944781662177}, {2.8619887302554394, \
1.6189603147994462}, {2.6510254915624207, 1.8022456366013606}, 
    {2.391906864453025, 1.6555895184432476}, {2.587897733079876, \
1.481944781662177}}], 
  Line[{{2.8619887302554394, 1.6189603147994462}, {3.1554623051357167, \
1.7056918414632198}, {2.928467912508318, 1.908454380799519}, 
    {2.6510254915624207, 1.8022456366013606}, {2.8619887302554394, \
1.6189603147994462}}], 
  Line[{{3.1554623051357167, 1.7056918414632198}, {3.455492254255985, \
1.7395717696563637}, {3.2121085621789414, 1.9712852585698495}, 
    {2.928467912508318, 1.908454380799519}, {3.1554623051357167, \
1.7056918414632198}}], 
  Line[{{3.455492254255985, 1.7395717696563637}, {3.7489658291362655, \
1.7222389198769938}, {3.489550983124843, 1.9921691365624086}, 
    {3.2121085621789414, 1.9712852585698495}, {3.455492254255985, \
1.7395717696563637}}], 
  Line[{{3.7489658291362655, 1.7222389198769938}, {4.023056826311827, \
1.6596693760099281}, {3.748669610234236, 1.976615915035449}, 
    {3.489550983124843, 1.9921691365624086}, {3.7489658291362655, \
1.7222389198769938}}], 
  Line[{{4.023056826311827, 1.6596693760099281}, {4.265786153971575, \
1.562581981081956}, {3.978139716113321, 1.9339672857886046}, 
    {3.748669610234236, 1.976615915035449}, {4.023056826311827, \
1.6596693760099281}}], 
  Line[{{4.265786153971575, 1.562581981081956}, {4.46654537575224, \
1.447024850453009}, {4.167932356015449, 1.8768892930626246}, 
    {3.978139716113321, 1.9339672857886046}, {4.265786153971575, \
1.562581981081956}}], 
  Line[{{4.46654537575224, 1.447024850453009}, {4.616560350312375, \
1.3346849311080493}, {4.309752680850761, 1.820205385795918}, 
    {4.167932356015449, 1.8768892930626246}, {4.46654537575224, \
1.447024850453009}}], 
  Line[{{4.616560350312375, 1.3346849311080493}, {4.70927470341199, \
1.2512975557014525}, {4.397402461894534, 1.7786275248098171}, 
    {4.309752680850761, 1.820205385795918}, {4.616560350312375, \
1.3346849311080493}}], 
  Line[{{4.70927470341199, 1.2512975557014525}, {4.740636372927804, \
1.2202099292273982}, {4.427050983124843, 1.763355756877417}, 
    {4.397402461894534, 1.7786275248098171}, {4.70927470341199, \
1.2512975557014525}}], 
  Line[{{4.427050983124843, 1.763355756877417}, {4.397402461894534, \
1.7786275248098171}, {3.980035937748391, 2.235484296800203}, 
    {4.007391819076576, 2.2294344764321816}, {4.427050983124843, \
1.763355756877417}}], 
  Line[{{4.397402461894534, 1.7786275248098171}, {4.309752680850761, \
1.82020538579592}, {3.8991638770459636, 2.2513313265781}, 
    {3.980035937748391, 2.235484296800203}, {4.397402461894534, \
1.7786275248098171}}], 
  Line[{{4.309752680850761, 1.82020538579592}, {4.167932356015448, \
1.8768892930626255}, {3.7683101340891887, 2.2706462108209022}, 
    {3.8991638770459636, 2.2513313265781}, {4.309752680850761, \
1.82020538579592}}], 
  Line[{{4.167932356015448, 1.8768892930626255}, {3.9781397161133225, \
1.9339672857886046}, {3.593193645351205, 2.284543605895154}, 
    {3.7683101340891887, 2.2706462108209022}, {4.167932356015448, \
1.8768892930626255}}], 
  Line[{{3.9781397161133225, 1.9339672857886046}, {3.748669610234238, \
1.976615915035448}, {3.3814678416920034, 2.283369148915068}, 
    {3.593193645351205, 2.284543605895154}, {3.9781397161133225, \
1.9339672857886046}}], 
  Line[{{3.748669610234238, 1.976615915035448}, {3.489550983124843, \
1.9921691365624095}, {3.1423861567046174, 2.258303983491545}, 
    {3.3814678416920034, 2.283369148915068}, {3.748669610234238, \
1.976615915035448}}], 
  Line[{{3.489550983124843, 1.9921691365624095}, {3.212108562178944, \
1.97128525856985}, {2.8863976072642052, 2.202570463435661}, 
    {3.1423861567046174, 2.258303983491545}, {3.489550983124843, \
1.9921691365624095}}], 
  Line[{{3.212108562178944, 1.97128525856985}, {2.92846791250832, \
1.908454380799519}, {2.6246901213506577, 2.1122635155465685}, 
    {2.8863976072642052, 2.202570463435661}, {3.212108562178944, \
1.97128525856985}}], 
  Line[{{2.92846791250832, 1.908454380799519}, {2.6510254915624216, \
1.8022456366013602}, {2.368701571910245, 1.9869545564435855}, 
    {2.6246901213506577, 2.1122635155465685}, {2.92846791250832, \
1.908454380799519}}], 
  Line[{{2.6510254915624216, 1.8022456366013602}, {2.391906864453027, \
1.6555895184432492}, {2.12961988692286, 1.8302685290560392}, 
    {2.368701571910245, 1.9869545564435855}, {2.6510254915624216, \
1.8022456366013602}}], 
  Line[{{2.391906864453027, 1.6555895184432492}, {2.162436758573942, \
1.4764049667388979}, {1.9178940832636582, 1.6506863454327514}, 
    {2.12961988692286, 1.8302685290560392}, {2.391906864453027, \
1.6555895184432492}}], 
  Line[{{2.162436758573942, 1.4764049667388979}, {1.972644118671816, \
1.2790742990138138}, {1.7427775945256736, 1.4628718195622255}, 
    {1.9178940832636582, 1.6506863454327514}, {2.162436758573942, \
1.4764049667388979}}], 
  Line[{{1.972644118671816, 1.2790742990138138}, {1.8308237938365044, \
1.0875191232355923}, {1.6119238515689, 1.2895708590441461}, 
    {1.7427775945256736, 1.4628718195622255}, {1.972644118671816, \
1.2790742990138138}}], 
  Line[{{1.8308237938365044, 1.0875191232355923}, {1.7431740127927307, \
0.9393665425693399}, {1.5310517908664718, 1.1623542887261813}, 
    {1.6119238515689, 1.2895708590441461}, {1.8308237938365044, \
1.0875191232355923}}], 
  Line[{{1.7431740127927307, 0.9393665425693399}, {1.7135254915624214, \
0.8816778784387095}, {1.5036959095382878, 1.114717238216091}, 
    {1.5310517908664718, 1.1623542887261813}, {1.7431740127927307, \
0.9393665425693399}}], 
  Line[{{1.7135254915624214, 0.8816778784387095}, {1.7431740127927309, \
0.9393665425693389}, {1.531051790866472, 1.1623542887261806}, 
    {1.5036959095382878, 1.114717238216091}, {1.7135254915624214, \
0.8816778784387095}}], 
  Line[{{1.7431740127927309, 0.9393665425693389}, {1.8308237938365042, \
1.0875191232355914}, {1.6119238515688998, 1.289570859044146}, 
    {1.531051790866472, 1.1623542887261806}, {1.7431740127927309, \
0.9393665425693389}}], 
  Line[{{1.8308237938365042, 1.0875191232355914}, {1.9726441186718162, \
1.279074299013813}, {1.7427775945256734, 1.4628718195622255}, 
    {1.6119238515688998, 1.289570859044146}, {1.8308237938365042, \
1.0875191232355914}}], 
  Line[{{1.9726441186718162, 1.279074299013813}, {2.162436758573941, \
1.4764049667388972}, {1.9178940832636575, 1.650686345432751}, 
    {1.7427775945256734, 1.4628718195622255}, {1.9726441186718162, \
1.279074299013813}}], 
  Line[{{2.162436758573941, 1.4764049667388972}, {2.391906864453026, \
1.6555895184432483}, {2.129619886922859, 1.8302685290560388}, 
    {1.9178940832636575, 1.650686345432751}, {2.162436758573941, \
1.4764049667388972}}], 
  Line[{{2.391906864453026, 1.6555895184432483}, {2.6510254915624207, \
1.8022456366013606}, {2.368701571910245, 1.9869545564435847}, 
    {2.129619886922859, 1.8302685290560388}, {2.391906864453026, \
1.6555895184432483}}], 
  Line[{{2.6510254915624207, 1.8022456366013606}, {2.928467912508319, \
1.9084543807995185}, {2.624690121350657, 2.112263515546568}, 
    {2.368701571910245, 1.9869545564435847}, {2.6510254915624207, \
1.8022456366013606}}], 
  Line[{{2.928467912508319, 1.9084543807995185}, {3.212108562178943, \
1.9712852585698486}, {2.886397607264204, 2.202570463435661}, 
    {2.624690121350657, 2.112263515546568}, {2.928467912508319, \
1.9084543807995185}}], 
  Line[{{3.212108562178943, 1.9712852585698486}, {3.489550983124843, \
1.9921691365624086}, {3.1423861567046174, 2.258303983491545}, 
    {2.886397607264204, 2.202570463435661}, {3.212108562178943, \
1.9712852585698486}}], 
  Line[{{3.489550983124843, 1.9921691365624086}, {3.7486696102342365, \
1.976615915035448}, {3.3814678416920025, 2.283369148915068}, 
    {3.1423861567046174, 2.258303983491545}, {3.489550983124843, \
1.9921691365624086}}], 
  Line[{{3.7486696102342365, 1.976615915035448}, {3.9781397161133225, \
1.9339672857886046}, {3.593193645351205, 2.284543605895153}, 
    {3.3814678416920025, 2.283369148915068}, {3.7486696102342365, \
1.976615915035448}}], 
  Line[{{3.9781397161133225, 1.9339672857886046}, {4.167932356015448, \
1.8768892930626255}, {3.7683101340891887, 2.2706462108209022}, 
    {3.593193645351205, 2.284543605895153}, {3.9781397161133225, \
1.9339672857886046}}], 
  Line[{{4.167932356015448, 1.8768892930626255}, {4.309752680850761, \
1.820205385795918}, {3.8991638770459627, 2.251331326578101}, 
    {3.7683101340891887, 2.2706462108209022}, {4.167932356015448, \
1.8768892930626255}}], 
  Line[{{4.309752680850761, 1.820205385795918}, {4.397402461894534, \
1.7786275248098171}, {3.980035937748391, 2.235484296800203}, 
    {3.8991638770459627, 2.251331326578101}, {4.309752680850761, \
1.820205385795918}}], 
  Line[{{4.397402461894534, 1.7786275248098171}, {4.427050983124843, \
1.763355756877417}, {4.007391819076576, 2.2294344764321816}, 
    {3.980035937748391, 2.235484296800203}, {4.397402461894534, \
1.7786275248098171}}], 
  Line[{{4.427050983124843, 1.763355756877417}, {4.397402461894535, \
1.778627524809816}, {3.9800359377483914, 2.235484296800203}, 
    {4.007391819076576, 2.2294344764321816}, {4.427050983124843, \
1.763355756877417}}], 
  Line[{{4.397402461894535, 1.778627524809816}, {4.309752680850761, \
1.8202053857959188}, {3.899163877045963, 2.251331326578101}, 
    {3.9800359377483914, 2.235484296800203}, {4.397402461894535, \
1.778627524809816}}], 
  Line[{{4.309752680850761, 1.8202053857959188}, {4.167932356015449, \
1.8768892930626246}, {3.7683101340891896, 2.2706462108209013}, 
    {3.899163877045963, 2.251331326578101}, {4.309752680850761, \
1.8202053857959188}}], 
  Line[{{4.167932356015449, 1.8768892930626246}, {3.978139716113324, \
1.9339672857886037}, {3.593193645351206, 2.284543605895153}, 
    {3.7683101340891896, 2.2706462108209013}, {4.167932356015449, \
1.8768892930626246}}], 
  Line[{{3.978139716113324, 1.9339672857886037}, {3.7486696102342387, \
1.9766159150354476}, {3.3814678416920043, 2.2833691489150674}, 
    {3.593193645351206, 2.284543605895153}, {3.978139716113324, \
1.9339672857886037}}], 
  Line[{{3.7486696102342387, 1.9766159150354476}, {3.4895509831248437, \
1.9921691365624086}, {3.1423861567046183, 2.258303983491545}, 
    {3.3814678416920043, 2.2833691489150674}, {3.7486696102342387, \
1.9766159150354476}}], 
  Line[{{3.4895509831248437, 1.9921691365624086}, {3.2121085621789454, \
1.971285258569849}, {2.886397607264206, 2.202570463435661}, 
    {3.1423861567046183, 2.258303983491545}, {3.4895509831248437, \
1.9921691365624086}}], 
  Line[{{3.2121085621789454, 1.971285258569849}, {2.928467912508321, \
1.9084543807995193}, {2.6246901213506586, 2.1122635155465685}, 
    {2.886397607264206, 2.202570463435661}, {3.2121085621789454, \
1.971285258569849}}], 
  Line[{{2.928467912508321, 1.9084543807995193}, {2.651025491562422, \
1.8022456366013606}, {2.368701571910246, 1.9869545564435855}, 
    {2.6246901213506586, 2.1122635155465685}, {2.928467912508321, \
1.9084543807995193}}], 
  Line[{{2.651025491562422, 1.8022456366013606}, {2.391906864453028, \
1.6555895184432494}, {2.1296198869228604, 1.83026852905604}, 
    {2.368701571910246, 1.9869545564435855}, {2.651025491562422, \
1.8022456366013606}}], 
  Line[{{2.391906864453028, 1.6555895184432494}, {2.1624367585739424, \
1.4764049667388996}, {1.917894083263659, 1.6506863454327527}, 
    {2.1296198869228604, 1.83026852905604}, {2.391906864453028, \
1.6555895184432494}}], 
  Line[{{2.1624367585739424, 1.4764049667388996}, {1.9726441186718164, \
1.2790742990138138}, {1.7427775945256738, 1.4628718195622255}, 
    {1.917894083263659, 1.6506863454327527}, {2.1624367585739424, \
1.4764049667388996}}], 
  Line[{{1.9726441186718164, 1.2790742990138138}, {1.830823793836505, \
1.0875191232355925}, {1.6119238515689007, 1.2895708590441464}, 
    {1.7427775945256738, 1.4628718195622255}, {1.9726441186718164, \
1.2790742990138138}}], 
  Line[{{1.830823793836505, 1.0875191232355925}, {1.7431740127927313, \
0.9393665425693402}, {1.5310517908664723, 1.1623542887261817}, 
    {1.6119238515689007, 1.2895708590441464}, {1.830823793836505, \
1.0875191232355925}}], 
  Line[{{1.7431740127927313, 0.9393665425693402}, {1.7135254915624214, \
0.8816778784387095}, {1.5036959095382878, 1.114717238216091}, 
    {1.5310517908664723, 1.1623542887261817}, {1.7431740127927313, \
0.9393665425693402}}], 
  Line[{{1.7135254915624214, 0.8816778784387095}, {1.7431740127927304, \
0.9393665425693389}, {1.5310517908664716, 1.1623542887261806}, 
    {1.5036959095382878, 1.114717238216091}, {1.7135254915624214, \
0.8816778784387095}}], 
  Line[{{1.7431740127927304, 0.9393665425693389}, {1.8308237938365033, \
1.0875191232355905}, {1.6119238515688992, 1.289570859044145}, 
    {1.5310517908664716, 1.1623542887261806}, {1.7431740127927304, \
0.9393665425693389}}], 
  Line[{{1.8308237938365033, 1.0875191232355905}, {1.9726441186718158, \
1.279074299013813}, {1.7427775945256732, 1.462871819562225}, 
    {1.6119238515688992, 1.289570859044145}, {1.8308237938365033, \
1.0875191232355905}}], 
  Line[{{1.9726441186718158, 1.279074299013813}, {2.16243675857394, \
1.476404966738897}, {1.9178940832636568, 1.6506863454327505}, 
    {1.7427775945256732, 1.462871819562225}, {1.9726441186718158, \
1.279074299013813}}], 
  Line[{{2.16243675857394, 1.476404966738897}, {2.391906864453025, \
1.6555895184432476}, {2.1296198869228578, 1.830268529056038}, 
    {1.9178940832636568, 1.6506863454327505}, {2.16243675857394, \
1.476404966738897}}], 
  Line[{{2.391906864453025, 1.6555895184432476}, {2.6510254915624207, \
1.8022456366013606}, {2.368701571910245, 1.9869545564435847}, 
    {2.1296198869228578, 1.830268529056038}, {2.391906864453025, \
1.6555895184432476}}], 
  Line[{{2.6510254915624207, 1.8022456366013606}, {2.928467912508318, \
1.908454380799519}, {2.6246901213506564, 2.112263515546568}, 
    {2.368701571910245, 1.9869545564435847}, {2.6510254915624207, \
1.8022456366013606}}], 
  Line[{{2.928467912508318, 1.908454380799519}, {3.2121085621789414, \
1.9712852585698495}, {2.8863976072642026, 2.2025704634356607}, 
    {2.6246901213506564, 2.112263515546568}, {2.928467912508318, \
1.908454380799519}}], 
  Line[{{3.2121085621789414, 1.9712852585698495}, {3.489550983124843, \
1.9921691365624086}, {3.1423861567046174, 2.258303983491545}, 
    {2.8863976072642026, 2.2025704634356607}, {3.2121085621789414, \
1.9712852585698495}}], 
  Line[{{3.489550983124843, 1.9921691365624086}, {3.748669610234236, \
1.976615915035449}, {3.381467841692002, 2.283369148915068}, 
    {3.1423861567046174, 2.258303983491545}, {3.489550983124843, \
1.9921691365624086}}], 
  Line[{{3.748669610234236, 1.976615915035449}, {3.978139716113321, \
1.9339672857886046}, {3.5931936453512034, 2.2845436058951534}, 
    {3.381467841692002, 2.283369148915068}, {3.748669610234236, \
1.976615915035449}}], 
  Line[{{3.978139716113321, 1.9339672857886046}, {4.167932356015449, \
1.8768892930626246}, {3.768310134089189, 2.2706462108209013}, 
    {3.5931936453512034, 2.2845436058951534}, {3.978139716113321, \
1.9339672857886046}}], 
  Line[{{4.167932356015449, 1.8768892930626246}, {4.309752680850761, \
1.820205385795918}, {3.8991638770459627, 2.251331326578101}, 
    {3.768310134089189, 2.2706462108209013}, {4.167932356015449, \
1.8768892930626246}}], 
  Line[{{4.309752680850761, 1.820205385795918}, {4.397402461894534, \
1.7786275248098171}, {3.980035937748391, 2.235484296800203}, 
    {3.8991638770459627, 2.251331326578101}, {4.309752680850761, \
1.820205385795918}}], 
  Line[{{4.397402461894534, 1.7786275248098171}, {4.427050983124843, \
1.763355756877417}, {4.007391819076576, 2.2294344764321816}, 
    {3.980035937748391, 2.235484296800203}, {4.397402461894534, \
1.7786275248098171}}], 
  Line[{{4.007391819076576, 2.2294344764321816}, {3.980035937748391, \
2.235484296800203}, {3.4754160508255314, 2.5979598975817524}, 
    {3.500000000000001, 2.598076211353315}, {4.007391819076576, \
2.2294344764321816}}], 
  Line[{{3.980035937748391, 2.235484296800203}, {3.8991638770459636, \
2.2513313265781}, {3.402738639847927, 2.596255039055556}, 
    {3.4754160508255314, 2.5979598975817524}, {3.980035937748391, \
2.235484296800203}}], 
  Line[{{3.8991638770459636, 2.2513313265781}, {3.7683101340891887, \
2.2706462108209022}, {3.2851441186718167, 2.589176886629936}, 
    {3.402738639847927, 2.596255039055556}, {3.8991638770459636, \
2.2513313265781}}], 
  Line[{{3.7683101340891887, 2.2706462108209022}, {3.593193645351205, \
2.284543605895154}, {3.127771932153716, 2.5712732770958864}, 
    {3.2851441186718167, 2.589176886629936}, {3.7683101340891887, \
2.2706462108209022}}], 
  Line[{{3.593193645351205, 2.284543605895154}, {3.3814678416920034, \
2.283369148915068}, {2.937500000000001, 2.536452985962878}, 
    {3.127771932153716, 2.5712732770958864}, {3.593193645351205, \
2.284543605895154}}], 
  Line[{{3.3814678416920034, 2.283369148915068}, {3.1423861567046174, \
2.258303983491545}, {2.7226441186718167, 2.479055835144598}, 
    {2.937500000000001, 2.536452985962878}, {3.3814678416920034, \
2.283369148915068}}], 
  Line[{{3.1423861567046174, 2.258303983491545}, {2.8863976072642052, \
2.202570463435661}, {2.492594521176111, 2.3948140222646956}, 
    {2.7226441186718167, 2.479055835144598}, {3.1423861567046174, \
2.258303983491545}}], 
  Line[{{2.8863976072642052, 2.202570463435661}, {2.6246901213506577, \
2.1122635155465685}, {2.25740547882389, 2.281657041700859}, 
    {2.492594521176111, 2.3948140222646956}, {2.8863976072642052, \
2.202570463435661}}], 
  Line[{{2.6246901213506577, 2.1122635155465685}, {2.368701571910245, \
1.9869545564435855}, {2.0273558813281847, 2.1404016678514597}, 
    {2.25740547882389, 2.281657041700859}, {2.6246901213506577, \
2.1122635155465685}}], 
  Line[{{2.368701571910245, 1.9869545564435855}, {2.12961988692286, \
1.8302685290560392}, {1.8125000000000009, 1.9754350786598884}, 
    {2.0273558813281847, 2.1404016678514597}, {2.368701571910245, \
1.9869545564435855}}], 
  Line[{{2.12961988692286, 1.8302685290560392}, {1.9178940832636582, \
1.6506863454327514}, {1.6222280678462853, 1.7955424168801197}, 
    {1.8125000000000009, 1.9754350786598884}, {2.12961988692286, \
1.8302685290560392}}], 
  Line[{{1.9178940832636582, 1.6506863454327514}, {1.7427775945256736, \
1.4628718195622255}, {1.4648558813281845, 1.6149886737174097}, 
    {1.6222280678462853, 1.7955424168801197}, {1.9178940832636582, \
1.6506863454327514}}], 
  Line[{{1.7427775945256736, 1.4628718195622255}, {1.6119238515689, \
1.2895708590441461}, {1.3472613601520744, 1.454550222063749}, 
    {1.4648558813281845, 1.6149886737174097}, {1.7427775945256736, \
1.4628718195622255}}], 
  Line[{{1.6119238515689, 1.2895708590441461}, {1.5310517908664718, \
1.1623542887261813}, {1.274583949174469, 1.3407174947497684}, 
    {1.3472613601520744, 1.454550222063749}, {1.6119238515689, \
1.2895708590441461}}], 
  Line[{{1.5310517908664718, 1.1623542887261813}, {1.5036959095382878, \
1.114717238216091}, {1.2500000000000004, 1.2990381056766576}, 
    {1.274583949174469, 1.3407174947497684}, {1.5310517908664718, \
1.1623542887261813}}], 
  Line[{{1.5036959095382878, 1.114717238216091}, {1.531051790866472, \
1.1623542887261806}, {1.2745839491744693, 1.3407174947497684}, 
    {1.2500000000000004, 1.2990381056766576}, {1.5036959095382878, \
1.114717238216091}}], 
  Line[{{1.531051790866472, 1.1623542887261806}, {1.6119238515688998, \
1.289570859044146}, {1.3472613601520744, 1.4545502220637483}, 
    {1.2745839491744693, 1.3407174947497684}, {1.531051790866472, \
1.1623542887261806}}], 
  Line[{{1.6119238515688998, 1.289570859044146}, {1.7427775945256734, \
1.4628718195622255}, {1.4648558813281847, 1.6149886737174093}, 
    {1.3472613601520744, 1.4545502220637483}, {1.6119238515688998, \
1.289570859044146}}], 
  Line[{{1.7427775945256734, 1.4628718195622255}, {1.9178940832636575, \
1.650686345432751}, {1.6222280678462848, 1.7955424168801193}, 
    {1.4648558813281847, 1.6149886737174093}, {1.7427775945256734, \
1.4628718195622255}}], 
  Line[{{1.9178940832636575, 1.650686345432751}, {2.129619886922859, \
1.8302685290560388}, {1.8125, 1.9754350786598878}, 
    {1.6222280678462848, 1.7955424168801193}, {1.9178940832636575, \
1.650686345432751}}], 
  Line[{{2.129619886922859, 1.8302685290560388}, {2.368701571910245, \
1.9869545564435847}, {2.0273558813281842, 2.1404016678514597}, 
    {1.8125, 1.9754350786598878}, {2.129619886922859, 1.8302685290560388}}], 
  Line[{{2.368701571910245, 1.9869545564435847}, {2.624690121350657, \
2.112263515546568}, {2.2574054788238893, 2.281657041700858}, 
    {2.0273558813281842, 2.1404016678514597}, {2.368701571910245, \
1.9869545564435847}}], 
  Line[{{2.624690121350657, 2.112263515546568}, {2.886397607264204, \
2.202570463435661}, {2.49259452117611, 2.394814022264695}, 
    {2.2574054788238893, 2.281657041700858}, {2.624690121350657, \
2.112263515546568}}], 
  Line[{{2.886397607264204, 2.202570463435661}, {3.1423861567046174, \
2.258303983491545}, {2.7226441186718158, 2.479055835144599}, 
    {2.49259452117611, 2.394814022264695}, {2.886397607264204, \
2.202570463435661}}], 
  Line[{{3.1423861567046174, 2.258303983491545}, {3.3814678416920025, \
2.283369148915068}, {2.9374999999999996, 2.536452985962878}, 
    {2.7226441186718158, 2.479055835144599}, {3.1423861567046174, \
2.258303983491545}}], 
  Line[{{3.3814678416920025, 2.283369148915068}, {3.593193645351205, \
2.284543605895153}, {3.127771932153715, 2.5712732770958873}, 
    {2.9374999999999996, 2.536452985962878}, {3.3814678416920025, \
2.283369148915068}}], 
  Line[{{3.593193645351205, 2.284543605895153}, {3.7683101340891887, \
2.2706462108209022}, {3.2851441186718167, 2.589176886629936}, 
    {3.127771932153715, 2.5712732770958873}, {3.593193645351205, \
2.284543605895153}}], 
  Line[{{3.7683101340891887, 2.2706462108209022}, {3.8991638770459627, \
2.251331326578101}, {3.4027386398479265, 2.596255039055556}, 
    {3.2851441186718167, 2.589176886629936}, {3.7683101340891887, \
2.2706462108209022}}], 
  Line[{{3.8991638770459627, 2.251331326578101}, {3.980035937748391, \
2.235484296800203}, {3.4754160508255314, 2.5979598975817524}, 
    {3.4027386398479265, 2.596255039055556}, {3.8991638770459627, \
2.251331326578101}}], 
  Line[{{3.980035937748391, 2.235484296800203}, {4.007391819076576, \
2.2294344764321816}, {3.500000000000001, 2.598076211353315}, 
    {3.4754160508255314, 2.5979598975817524}, {3.980035937748391, \
2.235484296800203}}], 
  Line[{{4.007391819076576, 2.2294344764321816}, {3.9800359377483914, \
2.235484296800203}, {3.4754160508255323, 2.597959897581752}, 
    {3.500000000000001, 2.598076211353315}, {4.007391819076576, \
2.2294344764321816}}], 
  Line[{{3.9800359377483914, 2.235484296800203}, {3.899163877045963, \
2.251331326578101}, {3.402738639847927, 2.596255039055556}, 
    {3.4754160508255323, 2.597959897581752}, {3.9800359377483914, \
2.235484296800203}}], 
  Line[{{3.899163877045963, 2.251331326578101}, {3.7683101340891896, \
2.2706462108209013}, {3.285144118671817, 2.589176886629936}, 
    {3.402738639847927, 2.596255039055556}, {3.899163877045963, \
2.251331326578101}}], 
  Line[{{3.7683101340891896, 2.2706462108209013}, {3.593193645351206, \
2.284543605895153}, {3.1277719321537174, 2.5712732770958864}, 
    {3.285144118671817, 2.589176886629936}, {3.7683101340891896, \
2.2706462108209013}}], 
  Line[{{3.593193645351206, 2.284543605895153}, {3.3814678416920043, \
2.2833691489150674}, {2.9375000000000013, 2.5364529859628786}, 
    {3.1277719321537174, 2.5712732770958864}, {3.593193645351206, \
2.284543605895153}}], 
  Line[{{3.3814678416920043, 2.2833691489150674}, {3.1423861567046183, \
2.258303983491545}, {2.722644118671817, 2.479055835144598}, 
    {2.9375000000000013, 2.5364529859628786}, {3.3814678416920043, \
2.2833691489150674}}], 
  Line[{{3.1423861567046183, 2.258303983491545}, {2.886397607264206, \
2.202570463435661}, {2.492594521176112, 2.394814022264695}, 
    {2.722644118671817, 2.479055835144598}, {3.1423861567046183, \
2.258303983491545}}], 
  Line[{{2.886397607264206, 2.202570463435661}, {2.6246901213506586, \
2.1122635155465685}, {2.257405478823891, 2.281657041700859}, 
    {2.492594521176112, 2.394814022264695}, {2.886397607264206, \
2.202570463435661}}], 
  Line[{{2.6246901213506586, 2.1122635155465685}, {2.368701571910246, \
1.9869545564435855}, {2.027355881328185, 2.14040166785146}, 
    {2.257405478823891, 2.281657041700859}, {2.6246901213506586, \
2.1122635155465685}}], 
  Line[{{2.368701571910246, 1.9869545564435855}, {2.1296198869228604, \
1.83026852905604}, {1.8125000000000016, 1.975435078659889}, 
    {2.027355881328185, 2.14040166785146}, {2.368701571910246, \
1.9869545564435855}}], 
  Line[{{2.1296198869228604, 1.83026852905604}, {1.917894083263659, \
1.6506863454327527}, {1.622228067846286, 1.7955424168801213}, 
    {1.8125000000000016, 1.975435078659889}, {2.1296198869228604, \
1.83026852905604}}], 
  Line[{{1.917894083263659, 1.6506863454327527}, {1.7427775945256738, \
1.4628718195622255}, {1.4648558813281847, 1.6149886737174095}, 
    {1.622228067846286, 1.7955424168801213}, {1.917894083263659, \
1.6506863454327527}}], 
  Line[{{1.7427775945256738, 1.4628718195622255}, {1.6119238515689007, \
1.2895708590441464}, {1.3472613601520749, 1.4545502220637494}, 
    {1.4648558813281847, 1.6149886737174095}, {1.7427775945256738, \
1.4628718195622255}}], 
  Line[{{1.6119238515689007, 1.2895708590441464}, {1.5310517908664723, \
1.1623542887261817}, {1.2745839491744695, 1.340717494749769}, 
    {1.3472613601520749, 1.4545502220637494}, {1.6119238515689007, \
1.2895708590441464}}], 
  Line[{{1.5310517908664723, 1.1623542887261817}, {1.5036959095382878, \
1.114717238216091}, {1.2500000000000004, 1.2990381056766576}, 
    {1.2745839491744695, 1.340717494749769}, {1.5310517908664723, \
1.1623542887261817}}], 
  Line[{{1.5036959095382878, 1.114717238216091}, {1.5310517908664716, \
1.1623542887261806}, {1.274583949174469, 1.3407174947497678}, 
    {1.2500000000000004, 1.2990381056766576}, {1.5036959095382878, \
1.114717238216091}}], 
  Line[{{1.5310517908664716, 1.1623542887261806}, {1.6119238515688992, \
1.289570859044145}, {1.3472613601520738, 1.4545502220637476}, 
    {1.274583949174469, 1.3407174947497678}, {1.5310517908664716, \
1.1623542887261806}}], 
  Line[{{1.6119238515688992, 1.289570859044145}, {1.7427775945256732, \
1.462871819562225}, {1.4648558813281845, 1.6149886737174093}, 
    {1.3472613601520738, 1.4545502220637476}, {1.6119238515688992, \
1.289570859044145}}], 
  Line[{{1.7427775945256732, 1.462871819562225}, {1.9178940832636568, \
1.6506863454327505}, {1.622228067846284, 1.795542416880119}, 
    {1.4648558813281845, 1.6149886737174093}, {1.7427775945256732, \
1.462871819562225}}], 
  Line[{{1.9178940832636568, 1.6506863454327505}, {2.1296198869228578, \
1.830268529056038}, {1.812499999999999, 1.9754350786598873}, 
    {1.622228067846284, 1.795542416880119}, {1.9178940832636568, \
1.6506863454327505}}], 
  Line[{{2.1296198869228578, 1.830268529056038}, {2.368701571910245, \
1.9869545564435847}, {2.027355881328184, 2.1404016678514597}, 
    {1.812499999999999, 1.9754350786598873}, {2.1296198869228578, \
1.830268529056038}}], 
  Line[{{2.368701571910245, 1.9869545564435847}, {2.6246901213506564, \
2.112263515546568}, {2.257405478823889, 2.281657041700858}, 
    {2.027355881328184, 2.1404016678514597}, {2.368701571910245, \
1.9869545564435847}}], 
  Line[{{2.6246901213506564, 2.112263515546568}, {2.8863976072642026, \
2.2025704634356607}, {2.492594521176109, 2.3948140222646943}, 
    {2.257405478823889, 2.281657041700858}, {2.6246901213506564, \
2.112263515546568}}], 
  Line[{{2.8863976072642026, 2.2025704634356607}, {3.1423861567046174, \
2.258303983491545}, {2.722644118671816, 2.4790558351445986}, 
    {2.492594521176109, 2.3948140222646943}, {2.8863976072642026, \
2.2025704634356607}}], 
  Line[{{3.1423861567046174, 2.258303983491545}, {3.381467841692002, \
2.283369148915068}, {2.9375, 2.5364529859628773}, 
    {2.722644118671816, 2.4790558351445986}, {3.1423861567046174, \
2.258303983491545}}], 
  Line[{{3.381467841692002, 2.283369148915068}, {3.5931936453512034, \
2.2845436058951534}, {3.1277719321537143, 2.571273277095887}, 
    {2.9375, 2.5364529859628773}, {3.381467841692002, 2.283369148915068}}], 
  Line[{{3.5931936453512034, 2.2845436058951534}, {3.768310134089189, \
2.2706462108209013}, {3.2851441186718167, 2.589176886629936}, 
    {3.1277719321537143, 2.571273277095887}, {3.5931936453512034, \
2.2845436058951534}}], 
  Line[{{3.768310134089189, 2.2706462108209013}, {3.8991638770459627, \
2.251331326578101}, {3.4027386398479265, 2.596255039055556}, 
    {3.2851441186718167, 2.589176886629936}, {3.768310134089189, \
2.2706462108209013}}], 
  Line[{{3.8991638770459627, 2.251331326578101}, {3.980035937748391, \
2.235484296800203}, {3.475416050825532, 2.597959897581752}, 
    {3.4027386398479265, 2.596255039055556}, {3.8991638770459627, \
2.251331326578101}}], 
  Line[{{3.980035937748391, 2.235484296800203}, {4.007391819076576, \
2.2294344764321816}, {3.500000000000001, 2.598076211353315}, 
    {3.475416050825532, 2.597959897581752}, {3.980035937748391, \
2.235484296800203}}], 
  Line[{{3.500000000000001, 2.598076211353315}, {3.4754160508255314, \
2.5979598975817524}, {2.9055971116193557, 2.8487773266631815}, 
    {2.9270509831248424, 2.8531695488854605}, {3.500000000000001, \
2.598076211353315}}], 
  Line[{{3.4754160508255314, 2.5979598975817524}, {3.402738639847927, \
2.596255039055556}, {2.842173134234785, 2.834803496770629}, 
    {2.9055971116193557, 2.8487773266631815}, {3.4754160508255314, \
2.5979598975817524}}], 
  Line[{{3.402738639847927, 2.596255039055556}, {3.2851441186718167, \
2.589176886629936}, {2.739550983124842, 2.809014835019403}, 
    {2.842173134234785, 2.834803496770629}, {3.402738639847927, \
2.596255039055556}}], 
  Line[{{3.2851441186718167, 2.589176886629936}, {3.127771932153716, \
2.5712732770958864}, {2.602215738728751, 2.768181798733441}, 
    {2.739550983124842, 2.809014835019403}, {3.2851441186718167, \
2.589176886629936}}], 
  Line[{{3.127771932153716, 2.5712732770958864}, {2.937500000000001, \
2.536452985962878}, {2.4361696102342374, 2.7087103854853694}, 
    {2.602215738728751, 2.768181798733441}, {3.127771932153716, \
2.5712732770958864}}], 
  Line[{{2.937500000000001, 2.536452985962878}, {2.7226441186718167, \
2.479055835144598}, {2.248669610234237, 2.6273597595826383}, 
    {2.4361696102342374, 2.7087103854853694}, {2.937500000000001, \
2.536452985962878}}], 
  Line[{{2.7226441186718167, 2.479055835144598}, {2.492594521176111, \
2.3948140222646956}, {2.047910388453574, 2.521960112821855}, 
    {2.248669610234237, 2.6273597595826383}, {2.7226441186718167, \
2.479055835144598}}], 
  Line[{{2.492594521176111, 2.3948140222646956}, {2.25740547882389, \
2.281657041700859}, {1.8426660862336899, 2.392089327116677}, 
    {2.047910388453574, 2.521960112821855}, {2.492594521176111, \
2.3948140222646956}}], 
  Line[{{2.25740547882389, 2.281657041700859}, {2.0273558813281847, \
2.1404016678514597}, {1.6419068644530266, 2.239718051509763}, 
    {1.8426660862336899, 2.392089327116677}, {2.25740547882389, \
2.281657041700859}}], 
  Line[{{2.0273558813281847, 2.1404016678514597}, {1.8125000000000009, \
1.9754350786598884}, {1.4544068644530268, 2.069878202800487}, 
    {1.6419068644530266, 2.239718051509763}, {2.0273558813281847, \
2.1404016678514597}}], 
  Line[{{1.8125000000000009, 1.9754350786598884}, {1.6222280678462853, \
1.7955424168801197}, {1.2883607359585132, 1.8914277190459865}, 
    {1.4544068644530268, 2.069878202800487}, {1.8125000000000009, \
1.9754350786598884}}], 
  Line[{{1.6222280678462853, 1.7955424168801197}, {1.4648558813281845, \
1.6149886737174097}, {1.1510254915624212, 1.7178957504272219}, 
    {1.2883607359585132, 1.8914277190459865}, {1.6222280678462853, \
1.7955424168801197}}], 
  Line[{{1.4648558813281845, 1.6149886737174097}, {1.3472613601520744, \
1.454550222063749}, {1.0484033404524795, 1.5679671136605227}, 
    {1.1510254915624212, 1.7178957504272219}, {1.4648558813281845, \
1.6149886737174097}}], 
  Line[{{1.3472613601520744, 1.454550222063749}, {1.274583949174469, \
1.3407174947497684}, {0.9849793630679076, 1.4640759018681937}, 
    {1.0484033404524795, 1.5679671136605227}, {1.3472613601520744, \
1.454550222063749}}], 
  Line[{{1.274583949174469, 1.3407174947497684}, {1.2500000000000004, \
1.2990381056766576}, {0.9635254915624213, 1.4265847744427302}, 
    {0.9849793630679076, 1.4640759018681937}, {1.274583949174469, \
1.3407174947497684}}], 
  Line[{{1.2500000000000004, 1.2990381056766576}, {1.2745839491744693, \
1.3407174947497684}, {0.9849793630679076, 1.4640759018681933}, 
    {0.9635254915624213, 1.4265847744427302}, {1.2500000000000004, \
1.2990381056766576}}], 
  Line[{{1.2745839491744693, 1.3407174947497684}, {1.3472613601520744, \
1.4545502220637483}, {1.0484033404524795, 1.5679671136605224}, 
    {0.9849793630679076, 1.4640759018681933}, {1.2745839491744693, \
1.3407174947497684}}], 
  Line[{{1.3472613601520744, 1.4545502220637483}, {1.4648558813281847, \
1.6149886737174093}, {1.1510254915624214, 1.7178957504272216}, 
    {1.0484033404524795, 1.5679671136605224}, {1.3472613601520744, \
1.4545502220637483}}], 
  Line[{{1.4648558813281847, 1.6149886737174093}, {1.6222280678462848, \
1.7955424168801193}, {1.2883607359585125, 1.8914277190459858}, 
    {1.1510254915624214, 1.7178957504272216}, {1.4648558813281847, \
1.6149886737174093}}], 
  Line[{{1.6222280678462848, 1.7955424168801193}, {1.8125, \
1.9754350786598878}, {1.454406864453026, 2.0698782028004867}, 
    {1.2883607359585125, 1.8914277190459858}, {1.6222280678462848, \
1.7955424168801193}}], 
  Line[{{1.8125, 1.9754350786598878}, {2.0273558813281842, \
2.1404016678514597}, {1.6419068644530261, 2.239718051509763}, 
    {1.454406864453026, 2.0698782028004867}, {1.8125, 1.9754350786598878}}], 
  Line[{{2.0273558813281842, 2.1404016678514597}, {2.2574054788238893, \
2.281657041700858}, {1.8426660862336892, 2.3920893271166763}, 
    {1.6419068644530261, 2.239718051509763}, {2.0273558813281842, \
2.1404016678514597}}], 
  Line[{{2.2574054788238893, 2.281657041700858}, {2.49259452117611, \
2.394814022264695}, {2.0479103884535728, 2.521960112821855}, 
    {1.8426660862336892, 2.3920893271166763}, {2.2574054788238893, \
2.281657041700858}}], 
  Line[{{2.49259452117611, 2.394814022264695}, {2.7226441186718158, \
2.479055835144599}, {2.248669610234237, 2.627359759582638}, 
    {2.0479103884535728, 2.521960112821855}, {2.49259452117611, \
2.394814022264695}}], 
  Line[{{2.7226441186718158, 2.479055835144599}, {2.9374999999999996, \
2.536452985962878}, {2.436169610234236, 2.70871038548537}, 
    {2.248669610234237, 2.627359759582638}, {2.7226441186718158, \
2.479055835144599}}], 
  Line[{{2.9374999999999996, 2.536452985962878}, {3.127771932153715, \
2.5712732770958873}, {2.6022157387287503, 2.7681817987334414}, 
    {2.436169610234236, 2.70871038548537}, {2.9374999999999996, \
2.536452985962878}}], 
  Line[{{3.127771932153715, 2.5712732770958873}, {3.2851441186718167, \
2.589176886629936}, {2.739550983124842, 2.809014835019403}, 
    {2.6022157387287503, 2.7681817987334414}, {3.127771932153715, \
2.5712732770958873}}], 
  Line[{{3.2851441186718167, 2.589176886629936}, {3.4027386398479265, \
2.596255039055556}, {2.842173134234784, 2.834803496770629}, 
    {2.739550983124842, 2.809014835019403}, {3.2851441186718167, \
2.589176886629936}}], 
  Line[{{3.4027386398479265, 2.596255039055556}, {3.4754160508255314, \
2.5979598975817524}, {2.9055971116193557, 2.8487773266631815}, 
    {2.842173134234784, 2.834803496770629}, {3.4027386398479265, \
2.596255039055556}}], 
  Line[{{3.4754160508255314, 2.5979598975817524}, {3.500000000000001, \
2.598076211353315}, {2.9270509831248424, 2.8531695488854605}, 
    {2.9055971116193557, 2.8487773266631815}, {3.4754160508255314, \
2.5979598975817524}}], 
  Line[{{3.500000000000001, 2.598076211353315}, {3.4754160508255323, \
2.597959897581752}, {2.9055971116193566, 2.8487773266631806}, 
    {2.9270509831248424, 2.8531695488854605}, {3.500000000000001, \
2.598076211353315}}], 
  Line[{{3.4754160508255323, 2.597959897581752}, {3.402738639847927, \
2.596255039055556}, {2.8421731342347845, 2.8348034967706295}, 
    {2.9055971116193566, 2.8487773266631806}, {3.4754160508255323, \
2.597959897581752}}], 
  Line[{{3.402738639847927, 2.596255039055556}, {3.285144118671817, \
2.589176886629936}, {2.739550983124843, 2.8090148350194024}, 
    {2.8421731342347845, 2.8348034967706295}, {3.402738639847927, \
2.596255039055556}}], 
  Line[{{3.285144118671817, 2.589176886629936}, {3.1277719321537174, \
2.5712732770958864}, {2.6022157387287517, 2.7681817987334414}, 
    {2.739550983124843, 2.8090148350194024}, {3.285144118671817, \
2.589176886629936}}], 
  Line[{{3.1277719321537174, 2.5712732770958864}, {2.9375000000000013, \
2.5364529859628786}, {2.436169610234238, 2.70871038548537}, 
    {2.6022157387287517, 2.7681817987334414}, {3.1277719321537174, \
2.5712732770958864}}], 
  Line[{{2.9375000000000013, 2.5364529859628786}, {2.722644118671817, \
2.479055835144598}, {2.2486696102342374, 2.6273597595826383}, 
    {2.436169610234238, 2.70871038548537}, {2.9375000000000013, \
2.5364529859628786}}], 
  Line[{{2.722644118671817, 2.479055835144598}, {2.492594521176112, \
2.394814022264695}, {2.047910388453575, 2.521960112821855}, 
    {2.2486696102342374, 2.6273597595826383}, {2.722644118671817, \
2.479055835144598}}], 
  Line[{{2.492594521176112, 2.394814022264695}, {2.257405478823891, \
2.281657041700859}, {1.8426660862336905, 2.3920893271166777}, 
    {2.047910388453575, 2.521960112821855}, {2.492594521176112, \
2.394814022264695}}], 
  Line[{{2.257405478823891, 2.281657041700859}, {2.027355881328185, \
2.14040166785146}, {1.641906864453027, 2.239718051509763}, 
    {1.8426660862336905, 2.3920893271166777}, {2.257405478823891, \
2.281657041700859}}], 
  Line[{{2.027355881328185, 2.14040166785146}, {1.8125000000000016, \
1.975435078659889}, {1.4544068644530275, 2.0698782028004876}, 
    {1.641906864453027, 2.239718051509763}, {2.027355881328185, \
2.14040166785146}}], 
  Line[{{1.8125000000000016, 1.975435078659889}, {1.622228067846286, \
1.7955424168801213}, {1.2883607359585139, 1.8914277190459874}, 
    {1.4544068644530275, 2.0698782028004876}, {1.8125000000000016, \
1.975435078659889}}], 
  Line[{{1.622228067846286, 1.7955424168801213}, {1.4648558813281847, \
1.6149886737174095}, {1.1510254915624214, 1.7178957504272219}, 
    {1.2883607359585139, 1.8914277190459874}, {1.622228067846286, \
1.7955424168801213}}], 
  Line[{{1.4648558813281847, 1.6149886737174095}, {1.3472613601520749, \
1.4545502220637494}, {1.04840334045248, 1.5679671136605233}, 
    {1.1510254915624214, 1.7178957504272219}, {1.4648558813281847, \
1.6149886737174095}}], 
  Line[{{1.3472613601520749, 1.4545502220637494}, {1.2745839491744695, \
1.340717494749769}, {0.984979363067908, 1.464075901868194}, 
    {1.04840334045248, 1.5679671136605233}, {1.3472613601520749, \
1.4545502220637494}}], 
  Line[{{1.2745839491744695, 1.340717494749769}, {1.2500000000000004, \
1.2990381056766576}, {0.9635254915624213, 1.4265847744427302}, 
    {0.984979363067908, 1.464075901868194}, {1.2745839491744695, \
1.340717494749769}}], 
  Line[{{1.2500000000000004, 1.2990381056766576}, {1.274583949174469, \
1.3407174947497678}, {0.9849793630679073, 1.464075901868193}, 
    {0.9635254915624213, 1.4265847744427302}, {1.2500000000000004, \
1.2990381056766576}}], 
  Line[{{1.274583949174469, 1.3407174947497678}, {1.3472613601520738, \
1.4545502220637476}, {1.0484033404524786, 1.5679671136605218}, 
    {0.9849793630679073, 1.464075901868193}, {1.274583949174469, \
1.3407174947497678}}], 
  Line[{{1.3472613601520738, 1.4545502220637476}, {1.4648558813281845, \
1.6149886737174093}, {1.1510254915624212, 1.7178957504272214}, 
    {1.0484033404524786, 1.5679671136605218}, {1.3472613601520738, \
1.4545502220637476}}], 
  Line[{{1.4648558813281845, 1.6149886737174093}, {1.622228067846284, \
1.795542416880119}, {1.2883607359585123, 1.8914277190459852}, 
    {1.1510254915624212, 1.7178957504272214}, {1.4648558813281845, \
1.6149886737174093}}], 
  Line[{{1.622228067846284, 1.795542416880119}, {1.812499999999999, \
1.9754350786598873}, {1.4544068644530252, 2.069878202800486}, 
    {1.2883607359585123, 1.8914277190459852}, {1.622228067846284, \
1.795542416880119}}], 
  Line[{{1.812499999999999, 1.9754350786598873}, {2.027355881328184, \
2.1404016678514597}, {1.6419068644530261, 2.2397180515097626}, 
    {1.4544068644530252, 2.069878202800486}, {1.812499999999999, \
1.9754350786598873}}], 
  Line[{{2.027355881328184, 2.1404016678514597}, {2.257405478823889, \
2.281657041700858}, {1.842666086233689, 2.3920893271166763}, 
    {1.6419068644530261, 2.2397180515097626}, {2.027355881328184, \
2.1404016678514597}}], 
  Line[{{2.257405478823889, 2.281657041700858}, {2.492594521176109, \
2.3948140222646943}, {2.047910388453572, 2.521960112821854}, 
    {1.842666086233689, 2.3920893271166763}, {2.257405478823889, \
2.281657041700858}}], 
  Line[{{2.492594521176109, 2.3948140222646943}, {2.722644118671816, \
2.4790558351445986}, {2.248669610234237, 2.6273597595826383}, 
    {2.047910388453572, 2.521960112821854}, {2.492594521176109, \
2.3948140222646943}}], 
  Line[{{2.722644118671816, 2.4790558351445986}, {2.9375, \
2.5364529859628773}, {2.436169610234236, 2.7087103854853694}, 
    {2.248669610234237, 2.6273597595826383}, {2.722644118671816, \
2.4790558351445986}}], 
  Line[{{2.9375, 2.5364529859628773}, {3.1277719321537143, \
2.571273277095887}, {2.602215738728749, 2.7681817987334414}, 
    {2.436169610234236, 2.7087103854853694}, {2.9375, 2.5364529859628773}}], 
  Line[{{3.1277719321537143, 2.571273277095887}, {3.2851441186718167, \
2.589176886629936}, {2.739550983124842, 2.809014835019403}, 
    {2.602215738728749, 2.7681817987334414}, {3.1277719321537143, \
2.571273277095887}}], 
  Line[{{3.2851441186718167, 2.589176886629936}, {3.4027386398479265, \
2.596255039055556}, {2.842173134234784, 2.834803496770629}, 
    {2.739550983124842, 2.809014835019403}, {3.2851441186718167, \
2.589176886629936}}], 
  Line[{{3.4027386398479265, 2.596255039055556}, {3.475416050825532, \
2.597959897581752}, {2.905597111619356, 2.848777326663181}, 
    {2.842173134234784, 2.834803496770629}, {3.4027386398479265, \
2.596255039055556}}], 
  Line[{{3.475416050825532, 2.597959897581752}, {3.500000000000001, \
2.598076211353315}, {2.9270509831248424, 2.8531695488854605}, 
    {2.905597111619356, 2.848777326663181}, {3.475416050825532, \
2.597959897581752}}], 
  Line[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193557, \
2.8487773266631815}, {2.2954829420678116, 2.976303493889946}, 
    {2.3135853898029626, 2.9835656861048196}, {2.9270509831248424, \
2.8531695488854605}}], 
  Line[{{2.9055971116193557, 2.8487773266631815}, {2.842173134234785, \
2.834803496770629}, {2.2419667626935684, 2.95408127925137}, 
    {2.2954829420678116, 2.976303493889946}, {2.9055971116193557, \
2.8487773266631815}}], 
  Line[{{2.842173134234785, 2.834803496770629}, {2.739550983124842, \
2.809014835019403}, {2.1553757655180044, 2.9156867970745455}, 
    {2.2419667626935684, 2.95408127925137}, {2.842173134234785, \
2.834803496770629}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.602215738728751, \
2.768181798733441}, {2.039494392627399, 2.8593997974092926}, 
    {2.1553757655180044, 2.9156867970745455}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.602215738728751, 2.768181798733441}, {2.4361696102342374, \
2.7087103854853694}, {1.8993872160775924, 2.7833940695732022}, 
    {2.039494392627399, 2.8593997974092926}, {2.602215738728751, \
2.768181798733441}}], 
  Line[{{2.4361696102342374, 2.7087103854853694}, {2.248669610234237, \
2.6273597595826383}, {1.7411775917926342, 2.686221801523239}, 
    {1.8993872160775924, 2.7833940695732022}, {2.4361696102342374, \
2.7087103854853694}}], 
  Line[{{2.248669610234237, 2.6273597595826383}, {2.047910388453574, \
2.521960112821855}, {1.5717800395277852, 2.567335508777075}, 
    {1.7411775917926342, 2.686221801523239}, {2.248669610234237, \
2.6273597595826383}}], 
  Line[{{2.047910388453574, 2.521960112821855}, {1.8426660862336899, \
2.392089327116677}, {1.3985980451766586, 2.427623046285348}, 
    {1.5717800395277852, 2.567335508777075}, {2.047910388453574, \
2.521960112821855}}], 
  Line[{{1.8426660862336899, 2.392089327116677}, {1.6419068644530266, \
2.239718051509763}, {1.2292004929118094, 2.2699589047379565}, 
    {1.3985980451766586, 2.427623046285348}, {1.8426660862336899, \
2.392089327116677}}], 
  Line[{{1.6419068644530266, 2.239718051509763}, {1.4544068644530268, \
2.069878202800487}, {1.0709908686268519, 2.099799626225554}, 
    {1.2292004929118094, 2.2699589047379565}, {1.6419068644530266, \
2.239718051509763}}], 
  Line[{{1.4544068644530268, 2.069878202800487}, {1.2883607359585132, \
1.8914277190459865}, {0.9308836920770447, 1.9258466260207314}, 
    {1.0709908686268519, 2.099799626225554}, {1.4544068644530268, \
2.069878202800487}}], 
  Line[{{1.2883607359585132, 1.8914277190459865}, {1.1510254915624212, \
1.7178957504272219}, {0.8150023191864391, 1.760690570377689}, 
    {0.9308836920770447, 1.9258466260207314}, {1.2883607359585132, \
1.8914277190459865}}], 
  Line[{{1.1510254915624212, 1.7178957504272219}, {1.0484033404524795, \
1.5679671136605227}, {0.7284113220108761, 1.6209688555409116}, 
    {0.8150023191864391, 1.760690570377689}, {1.1510254915624212, \
1.7178957504272219}}], 
  Line[{{1.0484033404524795, 1.5679671136605227}, {0.9849793630679076, \
1.4640759018681937}, {0.674895142636632, 1.5257871330867279}, 
    {0.7284113220108761, 1.6209688555409116}, {1.0484033404524795, \
1.5679671136605227}}], 
  Line[{{0.9849793630679076, 1.4640759018681937}, {0.9635254915624213, \
1.4265847744427302}, {0.6567926949014813, 1.4917828430524098}, 
    {0.674895142636632, 1.5257871330867279}, {0.9849793630679076, \
1.4640759018681937}}], 
  Line[{{0.9635254915624213, 1.4265847744427302}, {0.9849793630679076, \
1.4640759018681933}, {0.674895142636632, 1.5257871330867276}, 
    {0.6567926949014813, 1.4917828430524098}, {0.9635254915624213, \
1.4265847744427302}}], 
  Line[{{0.9849793630679076, 1.4640759018681933}, {1.0484033404524795, \
1.5679671136605224}, {0.7284113220108761, 1.6209688555409112}, 
    {0.674895142636632, 1.5257871330867276}, {0.9849793630679076, \
1.4640759018681933}}], 
  Line[{{1.0484033404524795, 1.5679671136605224}, {1.1510254915624214, \
1.7178957504272216}, {0.8150023191864392, 1.7606905703776887}, 
    {0.7284113220108761, 1.6209688555409112}, {1.0484033404524795, \
1.5679671136605224}}], 
  Line[{{1.1510254915624214, 1.7178957504272216}, {1.2883607359585125, \
1.8914277190459858}, {0.9308836920770442, 1.9258466260207308}, 
    {0.8150023191864392, 1.7606905703776887}, {1.1510254915624214, \
1.7178957504272216}}], 
  Line[{{1.2883607359585125, 1.8914277190459858}, {1.454406864453026, \
2.0698782028004867}, {1.070990868626851, 2.099799626225553}, 
    {0.9308836920770442, 1.9258466260207308}, {1.2883607359585125, \
1.8914277190459858}}], 
  Line[{{1.454406864453026, 2.0698782028004867}, {1.6419068644530261, \
2.239718051509763}, {1.2292004929118092, 2.2699589047379565}, 
    {1.070990868626851, 2.099799626225553}, {1.454406864453026, \
2.0698782028004867}}], 
  Line[{{1.6419068644530261, 2.239718051509763}, {1.8426660862336892, \
2.3920893271166763}, {1.3985980451766582, 2.427623046285347}, 
    {1.2292004929118092, 2.2699589047379565}, {1.6419068644530261, \
2.239718051509763}}], 
  Line[{{1.8426660862336892, 2.3920893271166763}, {2.0479103884535728, \
2.521960112821855}, {1.5717800395277841, 2.567335508777075}, 
    {1.3985980451766582, 2.427623046285347}, {1.8426660862336892, \
2.3920893271166763}}], 
  Line[{{2.0479103884535728, 2.521960112821855}, {2.248669610234237, \
2.627359759582638}, {1.7411775917926342, 2.6862218015232386}, 
    {1.5717800395277841, 2.567335508777075}, {2.0479103884535728, \
2.521960112821855}}], 
  Line[{{2.248669610234237, 2.627359759582638}, {2.436169610234236, \
2.70871038548537}, {1.8993872160775915, 2.783394069573202}, 
    {1.7411775917926342, 2.6862218015232386}, {2.248669610234237, \
2.627359759582638}}], 
  Line[{{2.436169610234236, 2.70871038548537}, {2.6022157387287503, \
2.7681817987334414}, {2.039494392627399, 2.8593997974092926}, 
    {1.8993872160775915, 2.783394069573202}, {2.436169610234236, \
2.70871038548537}}], 
  Line[{{2.6022157387287503, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {2.155375765518005, 2.9156867970745455}, 
    {2.039494392627399, 2.8593997974092926}, {2.6022157387287503, \
2.7681817987334414}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {2.241966762693568, 2.9540812792513695}, 
    {2.155375765518005, 2.9156867970745455}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.842173134234784, 2.834803496770629}, {2.9055971116193557, \
2.8487773266631815}, {2.2954829420678116, 2.976303493889946}, 
    {2.241966762693568, 2.9540812792513695}, {2.842173134234784, \
2.834803496770629}}], 
  Line[{{2.9055971116193557, 2.8487773266631815}, {2.9270509831248424, \
2.8531695488854605}, {2.3135853898029626, 2.9835656861048196}, 
    {2.2954829420678116, 2.976303493889946}, {2.9055971116193557, \
2.8487773266631815}}], 
  Line[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193566, \
2.8487773266631806}, {2.2954829420678124, 2.9763034938899455}, 
    {2.3135853898029626, 2.9835656861048196}, {2.9270509831248424, \
2.8531695488854605}}], 
  Line[{{2.9055971116193566, 2.8487773266631806}, {2.8421731342347845, \
2.8348034967706295}, {2.241966762693568, 2.9540812792513704}, 
    {2.2954829420678124, 2.9763034938899455}, {2.9055971116193566, \
2.8487773266631806}}], 
  Line[{{2.8421731342347845, 2.8348034967706295}, {2.739550983124843, \
2.8090148350194024}, {2.155375765518005, 2.9156867970745455}, 
    {2.241966762693568, 2.9540812792513704}, {2.8421731342347845, \
2.8348034967706295}}], 
  Line[{{2.739550983124843, 2.8090148350194024}, {2.6022157387287517, \
2.7681817987334414}, {2.0394943926274, 2.859399797409293}, 
    {2.155375765518005, 2.9156867970745455}, {2.739550983124843, \
2.8090148350194024}}], 
  Line[{{2.6022157387287517, 2.7681817987334414}, {2.436169610234238, \
2.70871038548537}, {1.8993872160775926, 2.7833940695732027}, 
    {2.0394943926274, 2.859399797409293}, {2.6022157387287517, \
2.7681817987334414}}], 
  Line[{{2.436169610234238, 2.70871038548537}, {2.2486696102342374, \
2.6273597595826383}, {1.7411775917926349, 2.686221801523239}, 
    {1.8993872160775926, 2.7833940695732027}, {2.436169610234238, \
2.70871038548537}}], 
  Line[{{2.2486696102342374, 2.6273597595826383}, {2.047910388453575, \
2.521960112821855}, {1.5717800395277857, 2.5673355087770755}, 
    {1.7411775917926349, 2.686221801523239}, {2.2486696102342374, \
2.6273597595826383}}], 
  Line[{{2.047910388453575, 2.521960112821855}, {1.8426660862336905, \
2.3920893271166777}, {1.3985980451766593, 2.4276230462853485}, 
    {1.5717800395277857, 2.5673355087770755}, {2.047910388453575, \
2.521960112821855}}], 
  Line[{{1.8426660862336905, 2.3920893271166777}, {1.641906864453027, \
2.239718051509763}, {1.2292004929118097, 2.269958904737957}, 
    {1.3985980451766593, 2.4276230462853485}, {1.8426660862336905, \
2.3920893271166777}}], 
  Line[{{1.641906864453027, 2.239718051509763}, {1.4544068644530275, \
2.0698782028004876}, {1.0709908686268523, 2.099799626225555}, 
    {1.2292004929118097, 2.269958904737957}, {1.641906864453027, \
2.239718051509763}}], 
  Line[{{1.4544068644530275, 2.0698782028004876}, {1.2883607359585139, \
1.8914277190459874}, {0.9308836920770454, 1.9258466260207323}, 
    {1.0709908686268523, 2.099799626225555}, {1.4544068644530275, \
2.0698782028004876}}], 
  Line[{{1.2883607359585139, 1.8914277190459874}, {1.1510254915624214, \
1.7178957504272219}, {0.8150023191864393, 1.7606905703776892}, 
    {0.9308836920770454, 1.9258466260207323}, {1.2883607359585139, \
1.8914277190459874}}], 
  Line[{{1.1510254915624214, 1.7178957504272219}, {1.04840334045248, \
1.5679671136605233}, {0.7284113220108764, 1.620968855540912}, 
    {0.8150023191864393, 1.7606905703776892}, {1.1510254915624214, \
1.7178957504272219}}], 
  Line[{{1.04840334045248, 1.5679671136605233}, {0.984979363067908, \
1.464075901868194}, {0.6748951426366323, 1.5257871330867283}, 
    {0.7284113220108764, 1.620968855540912}, {1.04840334045248, \
1.5679671136605233}}], 
  Line[{{0.984979363067908, 1.464075901868194}, {0.9635254915624213, \
1.4265847744427302}, {0.6567926949014813, 1.4917828430524098}, 
    {0.6748951426366323, 1.5257871330867283}, {0.984979363067908, \
1.464075901868194}}], 
  Line[{{0.9635254915624213, 1.4265847744427302}, {0.9849793630679073, \
1.464075901868193}, {0.6748951426366318, 1.5257871330867276}, 
    {0.6567926949014813, 1.4917828430524098}, {0.9635254915624213, \
1.4265847744427302}}], 
  Line[{{0.9849793630679073, 1.464075901868193}, {1.0484033404524786, \
1.5679671136605218}, {0.7284113220108754, 1.6209688555409107}, 
    {0.6748951426366318, 1.5257871330867276}, {0.9849793630679073, \
1.464075901868193}}], 
  Line[{{1.0484033404524786, 1.5679671136605218}, {1.1510254915624212, \
1.7178957504272214}, {0.815002319186439, 1.7606905703776887}, 
    {0.7284113220108754, 1.6209688555409107}, {1.0484033404524786, \
1.5679671136605218}}], 
  Line[{{1.1510254915624212, 1.7178957504272214}, {1.2883607359585123, \
1.8914277190459852}, {0.9308836920770438, 1.9258466260207303}, 
    {0.815002319186439, 1.7606905703776887}, {1.1510254915624212, \
1.7178957504272214}}], 
  Line[{{1.2883607359585123, 1.8914277190459852}, {1.4544068644530252, \
2.069878202800486}, {1.0709908686268506, 2.0997996262255523}, 
    {0.9308836920770438, 1.9258466260207303}, {1.2883607359585123, \
1.8914277190459852}}], 
  Line[{{1.4544068644530252, 2.069878202800486}, {1.6419068644530261, \
2.2397180515097626}, {1.229200492911809, 2.269958904737956}, 
    {1.0709908686268506, 2.0997996262255523}, {1.4544068644530252, \
2.069878202800486}}], 
  Line[{{1.6419068644530261, 2.2397180515097626}, {1.842666086233689, \
2.3920893271166763}, {1.3985980451766578, 2.427623046285347}, 
    {1.229200492911809, 2.269958904737956}, {1.6419068644530261, \
2.2397180515097626}}], 
  Line[{{1.842666086233689, 2.3920893271166763}, {2.047910388453572, \
2.521960112821854}, {1.5717800395277832, 2.5673355087770737}, 
    {1.3985980451766578, 2.427623046285347}, {1.842666086233689, \
2.3920893271166763}}], 
  Line[{{2.047910388453572, 2.521960112821854}, {2.248669610234237, \
2.6273597595826383}, {1.7411775917926344, 2.686221801523239}, 
    {1.5717800395277832, 2.5673355087770737}, {2.047910388453572, \
2.521960112821854}}], 
  Line[{{2.248669610234237, 2.6273597595826383}, {2.436169610234236, \
2.7087103854853694}, {1.8993872160775913, 2.783394069573202}, 
    {1.7411775917926344, 2.686221801523239}, {2.248669610234237, \
2.6273597595826383}}], 
  Line[{{2.436169610234236, 2.7087103854853694}, {2.602215738728749, \
2.7681817987334414}, {2.039494392627398, 2.859399797409292}, 
    {1.8993872160775913, 2.783394069573202}, {2.436169610234236, \
2.7087103854853694}}], 
  Line[{{2.602215738728749, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {2.155375765518005, 2.9156867970745455}, 
    {2.039494392627398, 2.859399797409292}, {2.602215738728749, \
2.7681817987334414}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {2.241966762693568, 2.9540812792513695}, 
    {2.155375765518005, 2.9156867970745455}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.842173134234784, 2.834803496770629}, {2.905597111619356, \
2.848777326663181}, {2.295482942067812, 2.9763034938899455}, 
    {2.241966762693568, 2.9540812792513695}, {2.842173134234784, \
2.834803496770629}}], 
  Line[{{2.905597111619356, 2.848777326663181}, {2.9270509831248424, \
2.8531695488854605}, {2.3135853898029626, 2.9835656861048196}, 
    {2.295482942067812, 2.9763034938899455}, {2.905597111619356, \
2.848777326663181}}], 
  Line[{{2.3135853898029626, 2.9835656861048196}, {2.2954829420678116, \
2.976303493889946}, {1.6717384590329, 2.9745950829027943}, 
    {1.686414610197041, 2.9835656861048196}, {2.3135853898029626, \
2.9835656861048196}}], 
  Line[{{2.2954829420678116, 2.976303493889946}, {2.2419667626935684, \
2.95408127925137}, {1.6283514237703374, 2.947488384456562}, 
    {1.6717384590329, 2.9745950829027943}, {2.2954829420678116, \
2.976303493889946}}], 
  Line[{{2.2419667626935684, 2.95408127925137}, {2.1553757655180044, \
2.9156867970745455}, {1.5581497260444195, 2.9017190909782276}, 
    {1.6283514237703374, 2.947488384456562}, {2.2419667626935684, \
2.95408127925137}}], 
  Line[{{2.1553757655180044, 2.9156867970745455}, {2.039494392627399, \
2.8593997974092926}, {1.464201516910891, 2.8365966765934414}, 
    {1.5581497260444195, 2.9017190909782276}, {2.1553757655180044, \
2.9156867970745455}}], 
  Line[{{2.039494392627399, 2.8593997974092926}, {1.8993872160775924, \
2.7833940695732022}, {1.350612783922411, 2.751525170659194}, 
    {1.464201516910891, 2.8365966765934414}, {2.039494392627399, \
2.8593997974092926}}], 
  Line[{{1.8993872160775924, 2.7833940695732022}, {1.7411775917926342, \
2.686221801523239}, {1.2223478997697899, 2.646328981764321}, 
    {1.350612783922411, 2.751525170659194}, {1.8993872160775924, \
2.7833940695732022}}], 
  Line[{{1.7411775917926342, 2.686221801523239}, {1.5717800395277852, \
2.567335508777075}, {1.0850126553736983, 2.5216249314090464}, 
    {1.2223478997697899, 2.646328981764321}, {1.7411775917926342, \
2.686221801523239}}], 
  Line[{{1.5717800395277852, 2.567335508777075}, {1.3985980451766586, \
2.427623046285348}, {0.9446092599218634, 2.379229777665829}, 
    {1.0850126553736983, 2.5216249314090464}, {1.5717800395277852, \
2.567335508777075}}], 
  Line[{{1.3985980451766586, 2.427623046285348}, {1.2292004929118094, \
2.2699589047379565}, {0.8072740155257718, 2.222607239695348}, 
    {0.9446092599218634, 2.379229777665829}, {1.3985980451766586, \
2.427623046285348}}], 
  Line[{{1.2292004929118094, 2.2699589047379565}, {1.0709908686268519, \
2.099799626225554}, {0.6790091313731508, 2.0573688751735335}, 
    {0.8072740155257718, 2.222607239695348}, {1.2292004929118094, \
2.2699589047379565}}], 
  Line[{{1.0709908686268519, 2.099799626225554}, {0.9308836920770447, \
1.9258466260207314}, {0.5654203983846704, 1.8918241808350191}, 
    {0.6790091313731508, 2.0573688751735335}, {1.0709908686268519, \
2.099799626225554}}], 
  Line[{{0.9308836920770447, 1.9258466260207314}, {0.8150023191864391, \
1.760690570377689}, {0.4714721892511417, 1.7374623647519978}, 
    {0.5654203983846704, 1.8918241808350191}, {0.9308836920770447, \
1.9258466260207314}}], 
  Line[{{0.8150023191864391, 1.760690570377689}, {0.7284113220108761, \
1.6209688555409116}, {0.40127049152522454, 1.6089224974238359}, 
    {0.4714721892511417, 1.7374623647519978}, {0.8150023191864391, \
1.760690570377689}}], 
  Line[{{0.7284113220108761, 1.6209688555409116}, {0.674895142636632, \
1.5257871330867279}, {0.3578834562626614, 1.5224519023538965}, 
    {0.40127049152522454, 1.6089224974238359}, {0.7284113220108761, \
1.6209688555409116}}], 
  Line[{{0.674895142636632, 1.5257871330867279}, {0.6567926949014813, \
1.4917828430524098}, {0.3432073050985205, 1.49178284305241}, 
    {0.3578834562626614, 1.5224519023538965}, {0.674895142636632, \
1.5257871330867279}}], 
  Line[{{0.6567926949014813, 1.4917828430524098}, {0.674895142636632, \
1.5257871330867276}, {0.3578834562626615, 1.5224519023538965}, 
    {0.3432073050985205, 1.49178284305241}, {0.6567926949014813, \
1.4917828430524098}}], 
  Line[{{0.674895142636632, 1.5257871330867276}, {0.7284113220108761, \
1.6209688555409112}, {0.4012704915252243, 1.6089224974238356}, 
    {0.3578834562626615, 1.5224519023538965}, {0.674895142636632, \
1.5257871330867276}}], 
  Line[{{0.7284113220108761, 1.6209688555409112}, {0.8150023191864392, \
1.7606905703776887}, {0.47147218925114165, 1.7374623647519978}, 
    {0.4012704915252243, 1.6089224974238356}, {0.7284113220108761, \
1.6209688555409112}}], 
  Line[{{0.8150023191864392, 1.7606905703776887}, {0.9308836920770442, \
1.9258466260207308}, {0.5654203983846702, 1.8918241808350182}, 
    {0.47147218925114165, 1.7374623647519978}, {0.8150023191864392, \
1.7606905703776887}}], 
  Line[{{0.9308836920770442, 1.9258466260207308}, {1.070990868626851, \
2.099799626225553}, {0.6790091313731502, 2.057368875173533}, 
    {0.5654203983846702, 1.8918241808350182}, {0.9308836920770442, \
1.9258466260207308}}], 
  Line[{{1.070990868626851, 2.099799626225553}, {1.2292004929118092, \
2.2699589047379565}, {0.8072740155257716, 2.222607239695348}, 
    {0.6790091313731502, 2.057368875173533}, {1.070990868626851, \
2.099799626225553}}], 
  Line[{{1.2292004929118092, 2.2699589047379565}, {1.3985980451766582, \
2.427623046285347}, {0.9446092599218627, 2.379229777665828}, 
    {0.8072740155257716, 2.222607239695348}, {1.2292004929118092, \
2.2699589047379565}}], 
  Line[{{1.3985980451766582, 2.427623046285347}, {1.5717800395277841, \
2.567335508777075}, {1.0850126553736974, 2.5216249314090464}, 
    {0.9446092599218627, 2.379229777665828}, {1.3985980451766582, \
2.427623046285347}}], 
  Line[{{1.5717800395277841, 2.567335508777075}, {1.7411775917926342, \
2.6862218015232386}, {1.2223478997697894, 2.646328981764321}, 
    {1.0850126553736974, 2.5216249314090464}, {1.5717800395277841, \
2.567335508777075}}], 
  Line[{{1.7411775917926342, 2.6862218015232386}, {1.8993872160775915, \
2.783394069573202}, {1.3506127839224105, 2.751525170659194}, 
    {1.2223478997697894, 2.646328981764321}, {1.7411775917926342, \
2.6862218015232386}}], 
  Line[{{1.8993872160775915, 2.783394069573202}, {2.039494392627399, \
2.8593997974092926}, {1.4642015169108908, 2.836596676593442}, 
    {1.3506127839224105, 2.751525170659194}, {1.8993872160775915, \
2.783394069573202}}], 
  Line[{{2.039494392627399, 2.8593997974092926}, {2.155375765518005, \
2.9156867970745455}, {1.5581497260444195, 2.901719090978228}, 
    {1.4642015169108908, 2.836596676593442}, {2.039494392627399, \
2.8593997974092926}}], 
  Line[{{2.155375765518005, 2.9156867970745455}, {2.241966762693568, \
2.9540812792513695}, {1.6283514237703371, 2.947488384456561}, 
    {1.5581497260444195, 2.901719090978228}, {2.155375765518005, \
2.9156867970745455}}], 
  Line[{{2.241966762693568, 2.9540812792513695}, {2.2954829420678116, \
2.976303493889946}, {1.6717384590329, 2.9745950829027943}, 
    {1.6283514237703371, 2.947488384456561}, {2.241966762693568, \
2.9540812792513695}}], 
  Line[{{2.2954829420678116, 2.976303493889946}, {2.3135853898029626, \
2.9835656861048196}, {1.686414610197041, 2.9835656861048196}, 
    {1.6717384590329, 2.9745950829027943}, {2.2954829420678116, \
2.976303493889946}}], 
  Line[{{2.3135853898029626, 2.9835656861048196}, {2.2954829420678124, \
2.9763034938899455}, {1.6717384590329005, 2.9745950829027943}, 
    {1.686414610197041, 2.9835656861048196}, {2.3135853898029626, \
2.9835656861048196}}], 
  Line[{{2.2954829420678124, 2.9763034938899455}, {2.241966762693568, \
2.9540812792513704}, {1.6283514237703374, 2.9474883844565616}, 
    {1.6717384590329005, 2.9745950829027943}, {2.2954829420678124, \
2.9763034938899455}}], 
  Line[{{2.241966762693568, 2.9540812792513704}, {2.155375765518005, \
2.9156867970745455}, {1.55814972604442, 2.901719090978228}, 
    {1.6283514237703374, 2.9474883844565616}, {2.241966762693568, \
2.9540812792513704}}], 
  Line[{{2.155375765518005, 2.9156867970745455}, {2.0394943926274, \
2.859399797409293}, {1.4642015169108917, 2.836596676593442}, 
    {1.55814972604442, 2.901719090978228}, {2.155375765518005, \
2.9156867970745455}}], 
  Line[{{2.0394943926274, 2.859399797409293}, {1.8993872160775926, \
2.7833940695732027}, {1.3506127839224114, 2.7515251706591943}, 
    {1.4642015169108917, 2.836596676593442}, {2.0394943926274, \
2.859399797409293}}], 
  Line[{{1.8993872160775926, 2.7833940695732027}, {1.7411775917926349, \
2.686221801523239}, {1.22234789976979, 2.646328981764321}, 
    {1.3506127839224114, 2.7515251706591943}, {1.8993872160775926, \
2.7833940695732027}}], 
  Line[{{1.7411775917926349, 2.686221801523239}, {1.5717800395277857, \
2.5673355087770755}, {1.0850126553736987, 2.5216249314090473}, 
    {1.22234789976979, 2.646328981764321}, {1.7411775917926349, \
2.686221801523239}}], 
  Line[{{1.5717800395277857, 2.5673355087770755}, {1.3985980451766593, \
2.4276230462853485}, {0.9446092599218641, 2.3792297776658295}, 
    {1.0850126553736987, 2.5216249314090473}, {1.5717800395277857, \
2.5673355087770755}}], 
  Line[{{1.3985980451766593, 2.4276230462853485}, {1.2292004929118097, \
2.269958904737957}, {0.807274015525772, 2.2226072396953485}, 
    {0.9446092599218641, 2.3792297776658295}, {1.3985980451766593, \
2.4276230462853485}}], 
  Line[{{1.2292004929118097, 2.269958904737957}, {1.0709908686268523, \
2.099799626225555}, {0.6790091313731512, 2.0573688751735344}, 
    {0.807274015525772, 2.2226072396953485}, {1.2292004929118097, \
2.269958904737957}}], 
  Line[{{1.0709908686268523, 2.099799626225555}, {0.9308836920770454, \
1.9258466260207323}, {0.565420398384671, 1.8918241808350198}, 
    {0.6790091313731512, 2.0573688751735344}, {1.0709908686268523, \
2.099799626225555}}], 
  Line[{{0.9308836920770454, 1.9258466260207323}, {0.8150023191864393, \
1.7606905703776892}, {0.47147218925114187, 1.737462364751998}, 
    {0.565420398384671, 1.8918241808350198}, {0.9308836920770454, \
1.9258466260207323}}], 
  Line[{{0.8150023191864393, 1.7606905703776892}, {0.7284113220108764, \
1.620968855540912}, {0.40127049152522487, 1.6089224974238363}, 
    {0.47147218925114187, 1.737462364751998}, {0.8150023191864393, \
1.7606905703776892}}], 
  Line[{{0.7284113220108764, 1.620968855540912}, {0.6748951426366323, \
1.5257871330867283}, {0.3578834562626616, 1.522451902353897}, 
    {0.40127049152522487, 1.6089224974238363}, {0.7284113220108764, \
1.620968855540912}}], 
  Line[{{0.6748951426366323, 1.5257871330867283}, {0.6567926949014813, \
1.4917828430524098}, {0.3432073050985205, 1.49178284305241}, 
    {0.3578834562626616, 1.522451902353897}, {0.6748951426366323, \
1.5257871330867283}}], 
  Line[{{0.6567926949014813, 1.4917828430524098}, {0.6748951426366318, \
1.5257871330867276}, {0.35788345626266127, 1.5224519023538963}, 
    {0.3432073050985205, 1.49178284305241}, {0.6567926949014813, \
1.4917828430524098}}], 
  Line[{{0.6748951426366318, 1.5257871330867276}, {0.7284113220108754, \
1.6209688555409107}, {0.401270491525224, 1.608922497423835}, 
    {0.35788345626266127, 1.5224519023538963}, {0.6748951426366318, \
1.5257871330867276}}], 
  Line[{{0.7284113220108754, 1.6209688555409107}, {0.815002319186439, \
1.7606905703776887}, {0.47147218925114154, 1.7374623647519976}, 
    {0.401270491525224, 1.608922497423835}, {0.7284113220108754, \
1.6209688555409107}}], 
  Line[{{0.815002319186439, 1.7606905703776887}, {0.9308836920770438, \
1.9258466260207303}, {0.5654203983846697, 1.891824180835018}, 
    {0.47147218925114154, 1.7374623647519976}, {0.815002319186439, \
1.7606905703776887}}], 
  Line[{{0.9308836920770438, 1.9258466260207303}, {1.0709908686268506, \
2.0997996262255523}, {0.6790091313731498, 2.057368875173532}, 
    {0.5654203983846697, 1.891824180835018}, {0.9308836920770438, \
1.9258466260207303}}], 
  Line[{{1.0709908686268506, 2.0997996262255523}, {1.229200492911809, \
2.269958904737956}, {0.8072740155257715, 2.2226072396953476}, 
    {0.6790091313731498, 2.057368875173532}, {1.0709908686268506, \
2.0997996262255523}}], 
  Line[{{1.229200492911809, 2.269958904737956}, {1.3985980451766578, \
2.427623046285347}, {0.9446092599218627, 2.3792297776658278}, 
    {0.8072740155257715, 2.2226072396953476}, {1.229200492911809, \
2.269958904737956}}], 
  Line[{{1.3985980451766578, 2.427623046285347}, {1.5717800395277832, \
2.5673355087770737}, {1.0850126553736967, 2.5216249314090455}, 
    {0.9446092599218627, 2.3792297776658278}, {1.3985980451766578, \
2.427623046285347}}], 
  Line[{{1.5717800395277832, 2.5673355087770737}, {1.7411775917926344, \
2.686221801523239}, {1.2223478997697896, 2.6463289817643205}, 
    {1.0850126553736967, 2.5216249314090455}, {1.5717800395277832, \
2.5673355087770737}}], 
  Line[{{1.7411775917926344, 2.686221801523239}, {1.8993872160775913, \
2.783394069573202}, {1.3506127839224105, 2.7515251706591934}, 
    {1.2223478997697896, 2.6463289817643205}, {1.7411775917926344, \
2.686221801523239}}], 
  Line[{{1.8993872160775913, 2.783394069573202}, {2.039494392627398, \
2.859399797409292}, {1.4642015169108902, 2.8365966765934414}, 
    {1.3506127839224105, 2.7515251706591934}, {1.8993872160775913, \
2.783394069573202}}], 
  Line[{{2.039494392627398, 2.859399797409292}, {2.155375765518005, \
2.9156867970745455}, {1.5581497260444195, 2.901719090978228}, 
    {1.4642015169108902, 2.8365966765934414}, {2.039494392627398, \
2.859399797409292}}], 
  Line[{{2.155375765518005, 2.9156867970745455}, {2.241966762693568, \
2.9540812792513695}, {1.6283514237703371, 2.947488384456561}, 
    {1.5581497260444195, 2.901719090978228}, {2.155375765518005, \
2.9156867970745455}}], 
  Line[{{2.241966762693568, 2.9540812792513695}, {2.295482942067812, \
2.9763034938899455}, {1.6717384590329003, 2.974595082902794}, 
    {1.6283514237703371, 2.947488384456561}, {2.241966762693568, \
2.9540812792513695}}], 
  Line[{{2.295482942067812, 2.9763034938899455}, {2.3135853898029626, \
2.9835656861048196}, {1.686414610197041, 2.9835656861048196}, 
    {1.6717384590329003, 2.974595082902794}, {2.295482942067812, \
2.9763034938899455}}], 
  Line[{{1.686414610197041, 2.9835656861048196}, {1.6717384590329, \
2.9745950829027943}, {1.0616242894813532, 2.843497290965337}, 
    {1.0729490168751585, 2.853169548885461}, {1.686414610197041, \
2.9835656861048196}}], 
  Line[{{1.6717384590329, 2.9745950829027943}, {1.6283514237703374, \
2.947488384456562}, {1.0281450522291185, 2.8144424077524017}, 
    {1.0616242894813532, 2.843497290965337}, {1.6717384590329, \
2.9745950829027943}}], 
  Line[{{1.6283514237703374, 2.947488384456562}, {1.5581497260444195, \
2.9017190909782276}, {0.9739745084375796, 2.7659262761959793}, 
    {1.0281450522291185, 2.8144424077524017}, {1.6283514237703374, \
2.947488384456562}}], 
  Line[{{1.5581497260444195, 2.9017190909782276}, {1.464201516910891, \
2.8365966765934414}, {0.9014801708095374, 2.6979339589171736}, 
    {0.9739745084375796, 2.7659262761959793}, {1.5581497260444195, \
2.9017190909782276}}], 
  Line[{{1.464201516910891, 2.8365966765934414}, {1.350612783922411, \
2.751525170659194}, {0.8138303897657639, 2.6106791787633687}, 
    {0.9014801708095374, 2.6979339589171736}, {1.464201516910891, \
2.8365966765934414}}], 
  Line[{{1.350612783922411, 2.751525170659194}, {1.2223478997697899, \
2.646328981764321}, {0.7148558813281849, 2.504820390287959}, 
    {0.8138303897657639, 2.6106791787633687}, {1.350612783922411, \
2.751525170659194}}], 
  Line[{{1.2223478997697899, 2.646328981764321}, {1.0850126553736983, \
2.5216249314090464}, {0.6088823064479074, 2.3817202672447815}, 
    {0.7148558813281849, 2.504820390287959}, {1.2223478997697899, \
2.646328981764321}}], 
  Line[{{1.0850126553736983, 2.5216249314090464}, {0.9446092599218634, \
2.379229777665829}, {0.5005412188648306, 2.2437468595288657}, 
    {0.6088823064479074, 2.3817202672447815}, {1.0850126553736983, \
2.5216249314090464}}], 
  Line[{{0.9446092599218634, 2.379229777665829}, {0.8072740155257718, \
2.222607239695348}, {0.394567643984553, 2.0946223601372336}, 
    {0.5005412188648306, 2.2437468595288657}, {0.9446092599218634, \
2.379229777665829}}], 
  Line[{{0.8072740155257718, 2.222607239695348}, {0.6790091313731508, \
2.0573688751735335}, {0.29559313554697425, 1.9398272078772512}, 
    {0.394567643984553, 2.0946223601372336}, {0.8072740155257718, \
2.222607239695348}}], 
  Line[{{0.6790091313731508, 2.0573688751735335}, {0.5654203983846704, \
1.8918241808350191}, {0.20794335450320056, 1.7870411277345815}, 
    {0.29559313554697425, 1.9398272078772512}, {0.6790091313731508, \
2.0573688751735335}}], 
  Line[{{0.5654203983846704, 1.8918241808350191}, {0.4714721892511417, \
1.7374623647519978}, {0.13544901687515815, 1.646496168027179}, 
    {0.20794335450320056, 1.7870411277345815}, {0.5654203983846704, \
1.8918241808350191}}], 
  Line[{{0.4714721892511417, 1.7374623647519978}, {0.40127049152522454, \
1.6089224974238359}, {0.0812784730836198, 1.5308481540548229}, 
    {0.13544901687515815, 1.646496168027179}, {0.4714721892511417, \
1.7374623647519978}}], 
  Line[{{0.40127049152522454, 1.6089224974238359}, {0.3578834562626614, \
1.5224519023538965}, {0.04779923583138457, 1.4537753723488893}, 
    {0.0812784730836198, 1.5308481540548229}, {0.40127049152522454, \
1.6089224974238359}}], 
  Line[{{0.3578834562626614, 1.5224519023538965}, {0.3432073050985205, \
1.49178284305241}, {0.03647450843757927, 1.4265847744427305}, 
    {0.04779923583138457, 1.4537753723488893}, {0.3578834562626614, \
1.5224519023538965}}], 
  Line[{{0.3432073050985205, 1.49178284305241}, {0.3578834562626615, \
1.5224519023538965}, {0.04779923583138457, 1.4537753723488893}, 
    {0.03647450843757927, 1.4265847744427305}, {0.3432073050985205, \
1.49178284305241}}], 
  Line[{{0.3578834562626615, 1.5224519023538965}, {0.4012704915252243, \
1.6089224974238356}, {0.0812784730836198, 1.5308481540548227}, 
    {0.04779923583138457, 1.4537753723488893}, {0.3578834562626615, \
1.5224519023538965}}], 
  Line[{{0.4012704915252243, 1.6089224974238356}, {0.47147218925114165, \
1.7374623647519978}, {0.13544901687515815, 1.646496168027179}, 
    {0.0812784730836198, 1.5308481540548227}, {0.4012704915252243, \
1.6089224974238356}}], 
  Line[{{0.47147218925114165, 1.7374623647519978}, {0.5654203983846702, \
1.8918241808350182}, {0.20794335450320034, 1.787041127734581}, 
    {0.13544901687515815, 1.646496168027179}, {0.47147218925114165, \
1.7374623647519978}}], 
  Line[{{0.5654203983846702, 1.8918241808350182}, {0.6790091313731502, \
2.057368875173533}, {0.2955931355469738, 1.9398272078772505}, 
    {0.20794335450320034, 1.787041127734581}, {0.5654203983846702, \
1.8918241808350182}}], 
  Line[{{0.6790091313731502, 2.057368875173533}, {0.8072740155257716, \
2.222607239695348}, {0.3945676439845528, 2.0946223601372336}, 
    {0.2955931355469738, 1.9398272078772505}, {0.6790091313731502, \
2.057368875173533}}], 
  Line[{{0.8072740155257716, 2.222607239695348}, {0.9446092599218627, \
2.379229777665828}, {0.5005412188648302, 2.243746859528865}, 
    {0.3945676439845528, 2.0946223601372336}, {0.8072740155257716, \
2.222607239695348}}], 
  Line[{{0.9446092599218627, 2.379229777665828}, {1.0850126553736974, \
2.5216249314090464}, {0.608882306447907, 2.3817202672447806}, 
    {0.5005412188648302, 2.243746859528865}, {0.9446092599218627, \
2.379229777665828}}], 
  Line[{{1.0850126553736974, 2.5216249314090464}, {1.2223478997697894, \
2.646328981764321}, {0.7148558813281848, 2.5048203902879584}, 
    {0.608882306447907, 2.3817202672447806}, {1.0850126553736974, \
2.5216249314090464}}], 
  Line[{{1.2223478997697894, 2.646328981764321}, {1.3506127839224105, \
2.751525170659194}, {0.8138303897657635, 2.610679178763368}, 
    {0.7148558813281848, 2.5048203902879584}, {1.2223478997697894, \
2.646328981764321}}], 
  Line[{{1.3506127839224105, 2.751525170659194}, {1.4642015169108908, \
2.836596676593442}, {0.9014801708095372, 2.697933958917173}, 
    {0.8138303897657635, 2.610679178763368}, {1.3506127839224105, \
2.751525170659194}}], 
  Line[{{1.4642015169108908, 2.836596676593442}, {1.5581497260444195, \
2.901719090978228}, {0.9739745084375797, 2.7659262761959793}, 
    {0.9014801708095372, 2.697933958917173}, {1.4642015169108908, \
2.836596676593442}}], 
  Line[{{1.5581497260444195, 2.901719090978228}, {1.6283514237703371, \
2.947488384456561}, {1.028145052229118, 2.8144424077524017}, 
    {0.9739745084375797, 2.7659262761959793}, {1.5581497260444195, \
2.901719090978228}}], 
  Line[{{1.6283514237703371, 2.947488384456561}, {1.6717384590329, \
2.9745950829027943}, {1.0616242894813532, 2.843497290965337}, 
    {1.028145052229118, 2.8144424077524017}, {1.6283514237703371, \
2.947488384456561}}], 
  Line[{{1.6717384590329, 2.9745950829027943}, {1.686414610197041, \
2.9835656861048196}, {1.0729490168751585, 2.853169548885461}, 
    {1.0616242894813532, 2.843497290965337}, {1.6717384590329, \
2.9745950829027943}}], 
  Line[{{1.686414610197041, 2.9835656861048196}, {1.6717384590329005, \
2.9745950829027943}, {1.0616242894813537, 2.843497290965337}, 
    {1.0729490168751585, 2.853169548885461}, {1.686414610197041, \
2.9835656861048196}}], 
  Line[{{1.6717384590329005, 2.9745950829027943}, {1.6283514237703374, \
2.9474883844565616}, {1.0281450522291182, 2.8144424077524013}, 
    {1.0616242894813537, 2.843497290965337}, {1.6717384590329005, \
2.9745950829027943}}], 
  Line[{{1.6283514237703374, 2.9474883844565616}, {1.55814972604442, \
2.901719090978228}, {0.9739745084375798, 2.7659262761959797}, 
    {1.0281450522291182, 2.8144424077524013}, {1.6283514237703374, \
2.9474883844565616}}], 
  Line[{{1.55814972604442, 2.901719090978228}, {1.4642015169108917, \
2.836596676593442}, {0.9014801708095378, 2.6979339589171736}, 
    {0.9739745084375798, 2.7659262761959797}, {1.55814972604442, \
2.901719090978228}}], 
  Line[{{1.4642015169108917, 2.836596676593442}, {1.3506127839224114, \
2.7515251706591943}, {0.8138303897657642, 2.6106791787633687}, 
    {0.9014801708095378, 2.6979339589171736}, {1.4642015169108917, \
2.836596676593442}}], 
  Line[{{1.3506127839224114, 2.7515251706591943}, {1.22234789976979, \
2.646328981764321}, {0.7148558813281853, 2.5048203902879593}, 
    {0.8138303897657642, 2.6106791787633687}, {1.3506127839224114, \
2.7515251706591943}}], 
  Line[{{1.22234789976979, 2.646328981764321}, {1.0850126553736987, \
2.5216249314090473}, {0.6088823064479079, 2.381720267244782}, 
    {0.7148558813281853, 2.5048203902879593}, {1.22234789976979, \
2.646328981764321}}], 
  Line[{{1.0850126553736987, 2.5216249314090473}, {0.9446092599218641, \
2.3792297776658295}, {0.5005412188648309, 2.243746859528866}, 
    {0.6088823064479079, 2.381720267244782}, {1.0850126553736987, \
2.5216249314090473}}], 
  Line[{{0.9446092599218641, 2.3792297776658295}, {0.807274015525772, \
2.2226072396953485}, {0.39456764398455324, 2.094622360137234}, 
    {0.5005412188648309, 2.243746859528866}, {0.9446092599218641, \
2.3792297776658295}}], 
  Line[{{0.807274015525772, 2.2226072396953485}, {0.6790091313731512, \
2.0573688751735344}, {0.29559313554697453, 1.9398272078772518}, 
    {0.39456764398455324, 2.094622360137234}, {0.807274015525772, \
2.2226072396953485}}], 
  Line[{{0.6790091313731512, 2.0573688751735344}, {0.565420398384671, \
1.8918241808350198}, {0.20794335450320095, 1.7870411277345821}, 
    {0.29559313554697453, 1.9398272078772518}, {0.6790091313731512, \
2.0573688751735344}}], 
  Line[{{0.565420398384671, 1.8918241808350198}, {0.47147218925114187, \
1.737462364751998}, {0.13544901687515826, 1.6464961680271792}, 
    {0.20794335450320095, 1.7870411277345821}, {0.565420398384671, \
1.8918241808350198}}], 
  Line[{{0.47147218925114187, 1.737462364751998}, {0.40127049152522487, \
1.6089224974238363}, {0.08127847308362002, 1.5308481540548233}, 
    {0.13544901687515826, 1.6464961680271792}, {0.47147218925114187, \
1.737462364751998}}], 
  Line[{{0.40127049152522487, 1.6089224974238363}, {0.3578834562626616, \
1.522451902353897}, {0.04779923583138479, 1.4537753723488898}, 
    {0.08127847308362002, 1.5308481540548233}, {0.40127049152522487, \
1.6089224974238363}}], 
  Line[{{0.3578834562626616, 1.522451902353897}, {0.3432073050985205, \
1.49178284305241}, {0.03647450843757927, 1.4265847744427305}, 
    {0.04779923583138479, 1.4537753723488898}, {0.3578834562626616, \
1.522451902353897}}], 
  Line[{{0.3432073050985205, 1.49178284305241}, {0.35788345626266127, \
1.5224519023538963}, {0.04779923583138446, 1.453775372348889}, 
    {0.03647450843757927, 1.4265847744427305}, {0.3432073050985205, \
1.49178284305241}}], 
  Line[{{0.35788345626266127, 1.5224519023538963}, {0.401270491525224, \
1.608922497423835}, {0.08127847308361935, 1.530848154054822}, 
    {0.04779923583138446, 1.453775372348889}, {0.35788345626266127, \
1.5224519023538963}}], 
  Line[{{0.401270491525224, 1.608922497423835}, {0.47147218925114154, \
1.7374623647519976}, {0.13544901687515803, 1.6464961680271788}, 
    {0.08127847308361935, 1.530848154054822}, {0.401270491525224, \
1.608922497423835}}], 
  Line[{{0.47147218925114154, 1.7374623647519976}, {0.5654203983846697, \
1.891824180835018}, {0.20794335450320006, 1.7870411277345806}, 
    {0.13544901687515803, 1.6464961680271788}, {0.47147218925114154, \
1.7374623647519976}}], 
  Line[{{0.5654203983846697, 1.891824180835018}, {0.6790091313731498, \
2.057368875173532}, {0.29559313554697336, 1.9398272078772498}, 
    {0.20794335450320006, 1.7870411277345806}, {0.5654203983846697, \
1.891824180835018}}], 
  Line[{{0.6790091313731498, 2.057368875173532}, {0.8072740155257715, \
2.2226072396953476}, {0.3945676439845528, 2.094622360137233}, 
    {0.29559313554697336, 1.9398272078772498}, {0.6790091313731498, \
2.057368875173532}}], 
  Line[{{0.8072740155257715, 2.2226072396953476}, {0.9446092599218627, \
2.3792297776658278}, {0.5005412188648299, 2.243746859528865}, 
    {0.3945676439845528, 2.094622360137233}, {0.8072740155257715, \
2.2226072396953476}}], 
  Line[{{0.9446092599218627, 2.3792297776658278}, {1.0850126553736967, \
2.5216249314090455}, {0.6088823064479063, 2.38172026724478}, 
    {0.5005412188648299, 2.243746859528865}, {0.9446092599218627, \
2.3792297776658278}}], 
  Line[{{1.0850126553736967, 2.5216249314090455}, {1.2223478997697896, \
2.6463289817643205}, {0.7148558813281849, 2.5048203902879584}, 
    {0.6088823064479063, 2.38172026724478}, {1.0850126553736967, \
2.5216249314090455}}], 
  Line[{{1.2223478997697896, 2.6463289817643205}, {1.3506127839224105, \
2.7515251706591934}, {0.8138303897657633, 2.610679178763368}, 
    {0.7148558813281849, 2.5048203902879584}, {1.2223478997697896, \
2.6463289817643205}}], 
  Line[{{1.3506127839224105, 2.7515251706591934}, {1.4642015169108902, \
2.8365966765934414}, {0.9014801708095367, 2.6979339589171727}, 
    {0.8138303897657633, 2.610679178763368}, {1.3506127839224105, \
2.7515251706591934}}], 
  Line[{{1.4642015169108902, 2.8365966765934414}, {1.5581497260444195, \
2.901719090978228}, {0.9739745084375797, 2.7659262761959793}, 
    {0.9014801708095367, 2.6979339589171727}, {1.4642015169108902, \
2.8365966765934414}}], 
  Line[{{1.5581497260444195, 2.901719090978228}, {1.6283514237703371, \
2.947488384456561}, {1.028145052229118, 2.8144424077524017}, 
    {0.9739745084375797, 2.7659262761959793}, {1.5581497260444195, \
2.901719090978228}}], 
  Line[{{1.6283514237703371, 2.947488384456561}, {1.6717384590329003, \
2.974595082902794}, {1.0616242894813532, 2.843497290965337}, 
    {1.028145052229118, 2.8144424077524017}, {1.6283514237703371, \
2.947488384456561}}], 
  Line[{{1.6717384590329003, 2.974595082902794}, {1.686414610197041, \
2.9835656861048196}, {1.0729490168751585, 2.853169548885461}, 
    {1.0616242894813532, 2.843497290965337}, {1.6717384590329003, \
2.974595082902794}}], 
  Line[{{1.0729490168751585, 2.853169548885461}, {1.0616242894813532, \
2.843497290965337}, {0.491805350275179, 2.5885835797530192}, 
    {0.5000000000000021, 2.5980762113533173}, {1.0729490168751585, \
2.853169548885461}}], 
  Line[{{1.0616242894813532, 2.843497290965337}, {1.0281450522291185, \
2.8144424077524017}, {0.46757954661597756, 2.56016136091033}, 
    {0.491805350275179, 2.5885835797530192}, {1.0616242894813532, \
2.843497290965337}}], 
  Line[{{1.0281450522291185, 2.8144424077524017}, {0.9739745084375796, \
2.7659262761959793}, {0.4283813728906071, 2.5129980122544073}, 
    {0.46757954661597756, 2.56016136091033}, {1.0281450522291185, \
2.8144424077524017}}], 
  Line[{{0.9739745084375796, 2.7659262761959793}, {0.9014801708095374, \
2.6979339589171736}, {0.3759239773845737, 2.4474780907945575}, 
    {0.4283813728906071, 2.5129980122544073}, {0.9739745084375796, \
2.7659262761959793}}], 
  Line[{{0.9014801708095374, 2.6979339589171736}, {0.8138303897657639, \
2.6106791787633687}, {0.3125000000000019, 2.3642850399222186}, 
    {0.3759239773845737, 2.4474780907945575}, {0.9014801708095374, \
2.6979339589171736}}], 
  Line[{{0.8138303897657639, 2.6106791787633687}, {0.7148558813281849, \
2.504820390287959}, {0.24088137289060696, 2.2645409632922475}, 
    {0.3125000000000019, 2.3642850399222186}, {0.8138303897657639, \
2.6106791787633687}}], 
  Line[{{0.7148558813281849, 2.504820390287959}, {0.6088823064479074, \
2.3817202672447815}, {0.1641981737253718, 2.149982831518161}, 
    {0.24088137289060696, 2.2645409632922475}, {0.7148558813281849, \
2.504820390287959}}], 
  Line[{{0.6088823064479074, 2.3817202672447815}, {0.5005412188648306, \
2.2437468595288657}, {0.0858018262746314, 2.0231783980979907}, 
    {0.1641981737253718, 2.149982831518161}, {0.6088823064479074, \
2.3817202672447815}}], 
  Line[{{0.5005412188648306, 2.2437468595288657}, {0.394567643984553, \
2.0946223601372336}, {0.009118627109396094, 1.8877889819588962}, 
    {0.0858018262746314, 2.0231783980979907}, {0.5005412188648306, \
2.2437468595288657}}], 
  Line[{{0.394567643984553, 2.0946223601372336}, {0.29559313554697425, \
1.9398272078772512}, {-0.06249999999999867, 1.7488835724541536}, 
    {0.009118627109396094, 1.8877889819588962}, {0.394567643984553, \
2.0946223601372336}}], 
  Line[{{0.29559313554697425, 1.9398272078772512}, {0.20794335450320056, \
1.7870411277345815}, {-0.12592397738457056, 1.6132809148526024}, 
    {-0.06249999999999867, 1.7488835724541536}, {0.29559313554697425, \
1.9398272078772512}}], 
  Line[{{0.20794335450320056, 1.7870411277345815}, {0.13544901687515815, \
1.646496168027179}, {-0.17838137289060418, 1.4898021598760784}, 
    {-0.12592397738457056, 1.6132809148526024}, {0.20794335450320056, \
1.7870411277345815}}], 
  Line[{{0.13544901687515815, 1.646496168027179}, {0.0812784730836198, \
1.5308481540548229}, {-0.21757954661597428, 1.3891012614574076}, 
    {-0.17838137289060418, 1.4898021598760784}, {0.13544901687515815, \
1.646496168027179}}], 
  Line[{{0.0812784730836198, 1.5308481540548229}, {0.04779923583138457, \
1.4537753723488893}, {-0.24180535027517608, 1.3224570770547}, 
    {-0.21757954661597428, 1.3891012614574076}, {0.0812784730836198, \
1.5308481540548229}}], 
  Line[{{0.04779923583138457, 1.4537753723488893}, {0.03647450843757927, \
1.4265847744427305}, {-0.249999999999999, 1.2990381056766584}, 
    {-0.24180535027517608, 1.3224570770547}, {0.04779923583138457, \
1.4537753723488893}}], 
  Line[{{0.03647450843757927, 1.4265847744427305}, {0.04779923583138457, \
1.4537753723488893}, {-0.24180535027517608, 1.3224570770547}, 
    {-0.249999999999999, 1.2990381056766584}, {0.03647450843757927, \
1.4265847744427305}}], 
  Line[{{0.04779923583138457, 1.4537753723488893}, {0.0812784730836198, \
1.5308481540548227}, {-0.2175795466159744, 1.3891012614574074}, 
    {-0.24180535027517608, 1.3224570770547}, {0.04779923583138457, \
1.4537753723488893}}], 
  Line[{{0.0812784730836198, 1.5308481540548227}, {0.13544901687515815, \
1.646496168027179}, {-0.17838137289060418, 1.4898021598760782}, 
    {-0.2175795466159744, 1.3891012614574074}, {0.0812784730836198, \
1.5308481540548227}}], 
  Line[{{0.13544901687515815, 1.646496168027179}, {0.20794335450320034, \
1.787041127734581}, {-0.12592397738457067, 1.6132809148526022}, 
    {-0.17838137289060418, 1.4898021598760782}, {0.13544901687515815, \
1.646496168027179}}], 
  Line[{{0.20794335450320034, 1.787041127734581}, {0.2955931355469738, \
1.9398272078772505}, {-0.062499999999998945, 1.7488835724541534}, 
    {-0.12592397738457067, 1.6132809148526022}, {0.20794335450320034, \
1.787041127734581}}], 
  Line[{{0.2955931355469738, 1.9398272078772505}, {0.3945676439845528, \
2.0946223601372336}, {0.009118627109395983, 1.887788981958896}, 
    {-0.062499999999998945, 1.7488835724541534}, {0.2955931355469738, \
1.9398272078772505}}], 
  Line[{{0.3945676439845528, 2.0946223601372336}, {0.5005412188648302, \
2.243746859528865}, {0.08580182627463112, 2.0231783980979903}, 
    {0.009118627109395983, 1.887788981958896}, {0.3945676439845528, \
2.0946223601372336}}], 
  Line[{{0.5005412188648302, 2.243746859528865}, {0.608882306447907, \
2.3817202672447806}, {0.1641981737253714, 2.14998283151816}, 
    {0.08580182627463112, 2.0231783980979903}, {0.5005412188648302, \
2.243746859528865}}], 
  Line[{{0.608882306447907, 2.3817202672447806}, {0.7148558813281848, \
2.5048203902879584}, {0.24088137289060693, 2.264540963292247}, 
    {0.1641981737253714, 2.14998283151816}, {0.608882306447907, \
2.3817202672447806}}], 
  Line[{{0.7148558813281848, 2.5048203902879584}, {0.8138303897657635, \
2.610679178763368}, {0.31250000000000155, 2.3642850399222177}, 
    {0.24088137289060693, 2.264540963292247}, {0.7148558813281848, \
2.5048203902879584}}], 
  Line[{{0.8138303897657635, 2.610679178763368}, {0.9014801708095372, \
2.697933958917173}, {0.3759239773845736, 2.4474780907945575}, 
    {0.31250000000000155, 2.3642850399222177}, {0.8138303897657635, \
2.610679178763368}}], 
  Line[{{0.9014801708095372, 2.697933958917173}, {0.9739745084375797, \
2.7659262761959793}, {0.4283813728906072, 2.5129980122544073}, 
    {0.3759239773845736, 2.4474780907945575}, {0.9014801708095372, \
2.697933958917173}}], 
  Line[{{0.9739745084375797, 2.7659262761959793}, {1.028145052229118, \
2.8144424077524017}, {0.4675795466159774, 2.5601613609103295}, 
    {0.4283813728906072, 2.5129980122544073}, {0.9739745084375797, \
2.7659262761959793}}], 
  Line[{{1.028145052229118, 2.8144424077524017}, {1.0616242894813532, \
2.843497290965337}, {0.4918053502751791, 2.5885835797530192}, 
    {0.4675795466159774, 2.5601613609103295}, {1.028145052229118, \
2.8144424077524017}}], 
  Line[{{1.0616242894813532, 2.843497290965337}, {1.0729490168751585, \
2.853169548885461}, {0.5000000000000021, 2.5980762113533173}, 
    {0.4918053502751791, 2.5885835797530192}, {1.0616242894813532, \
2.843497290965337}}], 
  Line[{{1.0729490168751585, 2.853169548885461}, {1.0616242894813537, \
2.843497290965337}, {0.49180535027517946, 2.5885835797530197}, 
    {0.5000000000000021, 2.5980762113533173}, {1.0729490168751585, \
2.853169548885461}}], 
  Line[{{1.0616242894813537, 2.843497290965337}, {1.0281450522291182, \
2.8144424077524013}, {0.4675795466159775, 2.56016136091033}, 
    {0.49180535027517946, 2.5885835797530197}, {1.0616242894813537, \
2.843497290965337}}], 
  Line[{{1.0281450522291182, 2.8144424077524013}, {0.9739745084375798, \
2.7659262761959797}, {0.4283813728906073, 2.5129980122544078}, 
    {0.4675795466159775, 2.56016136091033}, {1.0281450522291182, \
2.8144424077524013}}], 
  Line[{{0.9739745084375798, 2.7659262761959797}, {0.9014801708095378, \
2.6979339589171736}, {0.375923977384574, 2.4474780907945575}, 
    {0.4283813728906073, 2.5129980122544078}, {0.9739745084375798, \
2.7659262761959797}}], 
  Line[{{0.9014801708095378, 2.6979339589171736}, {0.8138303897657642, \
2.6106791787633687}, {0.3125000000000021, 2.3642850399222186}, 
    {0.375923977384574, 2.4474780907945575}, {0.9014801708095378, \
2.6979339589171736}}], 
  Line[{{0.8138303897657642, 2.6106791787633687}, {0.7148558813281853, \
2.5048203902879593}, {0.24088137289060724, 2.2645409632922475}, 
    {0.3125000000000021, 2.3642850399222186}, {0.8138303897657642, \
2.6106791787633687}}], 
  Line[{{0.7148558813281853, 2.5048203902879593}, {0.6088823064479079, \
2.381720267244782}, {0.1641981737253721, 2.1499828315181615}, 
    {0.24088137289060724, 2.2645409632922475}, {0.7148558813281853, \
2.5048203902879593}}], 
  Line[{{0.6088823064479079, 2.381720267244782}, {0.5005412188648309, \
2.243746859528866}, {0.08580182627463168, 2.023178398097991}, 
    {0.1641981737253721, 2.1499828315181615}, {0.6088823064479079, \
2.381720267244782}}], 
  Line[{{0.5005412188648309, 2.243746859528866}, {0.39456764398455324, \
2.094622360137234}, {0.00911862710939626, 1.8877889819588964}, 
    {0.08580182627463168, 2.023178398097991}, {0.5005412188648309, \
2.243746859528866}}], 
  Line[{{0.39456764398455324, 2.094622360137234}, {0.29559313554697453, \
1.9398272078772518}, {-0.06249999999999839, 1.7488835724541543}, 
    {0.00911862710939626, 1.8877889819588964}, {0.39456764398455324, \
2.094622360137234}}], 
  Line[{{0.29559313554697453, 1.9398272078772518}, {0.20794335450320095, \
1.7870411277345821}, {-0.12592397738457028, 1.613280914852603}, 
    {-0.06249999999999839, 1.7488835724541543}, {0.29559313554697453, \
1.9398272078772518}}], 
  Line[{{0.20794335450320095, 1.7870411277345821}, {0.13544901687515826, \
1.6464961680271792}, {-0.17838137289060407, 1.4898021598760784}, 
    {-0.12592397738457028, 1.613280914852603}, {0.20794335450320095, \
1.7870411277345821}}], 
  Line[{{0.13544901687515826, 1.6464961680271792}, {0.08127847308362002, \
1.5308481540548233}, {-0.21757954661597417, 1.3891012614574079}, 
    {-0.17838137289060407, 1.4898021598760784}, {0.13544901687515826, \
1.6464961680271792}}], 
  Line[{{0.08127847308362002, 1.5308481540548233}, {0.04779923583138479, \
1.4537753723488898}, {-0.24180535027517597, 1.3224570770547004}, 
    {-0.21757954661597417, 1.3891012614574079}, {0.08127847308362002, \
1.5308481540548233}}], 
  Line[{{0.04779923583138479, 1.4537753723488898}, {0.03647450843757927, \
1.4265847744427305}, {-0.249999999999999, 1.2990381056766584}, 
    {-0.24180535027517597, 1.3224570770547004}, {0.04779923583138479, \
1.4537753723488898}}], 
  Line[{{0.03647450843757927, 1.4265847744427305}, {0.04779923583138446, \
1.453775372348889}, {-0.2418053502751762, 1.3224570770547}, 
    {-0.249999999999999, 1.2990381056766584}, {0.03647450843757927, \
1.4265847744427305}}], 
  Line[{{0.04779923583138446, 1.453775372348889}, {0.08127847308361935, \
1.530848154054822}, {-0.21757954661597456, 1.389101261457407}, 
    {-0.2418053502751762, 1.3224570770547}, {0.04779923583138446, \
1.453775372348889}}], 
  Line[{{0.08127847308361935, 1.530848154054822}, {0.13544901687515803, \
1.6464961680271788}, {-0.1783813728906043, 1.489802159876078}, 
    {-0.21757954661597456, 1.389101261457407}, {0.08127847308361935, \
1.530848154054822}}], 
  Line[{{0.13544901687515803, 1.6464961680271788}, {0.20794335450320006, \
1.7870411277345806}, {-0.125923977384571, 1.6132809148526015}, 
    {-0.1783813728906043, 1.489802159876078}, {0.13544901687515803, \
1.6464961680271788}}], 
  Line[{{0.20794335450320006, 1.7870411277345806}, {0.29559313554697336, \
1.9398272078772498}, {-0.06249999999999922, 1.7488835724541525}, 
    {-0.125923977384571, 1.6132809148526015}, {0.20794335450320006, \
1.7870411277345806}}], 
  Line[{{0.29559313554697336, 1.9398272078772498}, {0.3945676439845528, \
2.094622360137233}, {0.009118627109395927, 1.887788981958896}, 
    {-0.06249999999999922, 1.7488835724541525}, {0.29559313554697336, \
1.9398272078772498}}], 
  Line[{{0.3945676439845528, 2.094622360137233}, {0.5005412188648299, \
2.243746859528865}, {0.08580182627463095, 2.02317839809799}, 
    {0.009118627109395927, 1.887788981958896}, {0.3945676439845528, \
2.094622360137233}}], 
  Line[{{0.5005412188648299, 2.243746859528865}, {0.6088823064479063, \
2.38172026724478}, {0.16419817372537102, 2.1499828315181597}, 
    {0.08580182627463095, 2.02317839809799}, {0.5005412188648299, \
2.243746859528865}}], 
  Line[{{0.6088823064479063, 2.38172026724478}, {0.7148558813281849, \
2.5048203902879584}, {0.240881372890607, 2.264540963292247}, 
    {0.16419817372537102, 2.1499828315181597}, {0.6088823064479063, \
2.38172026724478}}], 
  Line[{{0.7148558813281849, 2.5048203902879584}, {0.8138303897657633, \
2.610679178763368}, {0.3125000000000015, 2.3642850399222177}, 
    {0.240881372890607, 2.264540963292247}, {0.7148558813281849, \
2.5048203902879584}}], 
  Line[{{0.8138303897657633, 2.610679178763368}, {0.9014801708095367, \
2.6979339589171727}, {0.37592397738457317, 2.4474780907945566}, 
    {0.3125000000000015, 2.3642850399222177}, {0.8138303897657633, \
2.610679178763368}}], 
  Line[{{0.9014801708095367, 2.6979339589171727}, {0.9739745084375797, \
2.7659262761959793}, {0.4283813728906072, 2.5129980122544073}, 
    {0.37592397738457317, 2.4474780907945566}, {0.9014801708095367, \
2.6979339589171727}}], 
  Line[{{0.9739745084375797, 2.7659262761959793}, {1.028145052229118, \
2.8144424077524017}, {0.46757954661597745, 2.5601613609103295}, 
    {0.4283813728906072, 2.5129980122544073}, {0.9739745084375797, \
2.7659262761959793}}], 
  Line[{{1.028145052229118, 2.8144424077524017}, {1.0616242894813532, \
2.843497290965337}, {0.49180535027517913, 2.5885835797530192}, 
    {0.46757954661597745, 2.5601613609103295}, {1.028145052229118, \
2.8144424077524017}}], 
  Line[{{1.0616242894813532, 2.843497290965337}, {1.0729490168751585, \
2.853169548885461}, {0.5000000000000021, 2.5980762113533173}, 
    {0.49180535027517913, 2.5885835797530192}, {1.0616242894813532, \
2.843497290965337}}], 
  Line[{{0.5000000000000021, 2.5980762113533173}, {0.491805350275179, \
2.5885835797530192}, {-0.012814536647680919, 2.2208803408437965}, 
    {-0.0073918190765734915, 2.2294344764321834}, {0.5000000000000021, \
2.5980762113533173}}], 
  Line[{{0.491805350275179, 2.5885835797530192}, {0.46757954661597756, \
2.56016136091033}, {-0.02884569058205967, 2.1953185530328274}, 
    {-0.012814536647680919, 2.2208803408437965}, {0.491805350275179, \
2.5885835797530192}}], 
  Line[{{0.46757954661597756, 2.56016136091033}, {0.4283813728906071, \
2.5129980122544073}, {-0.05478464252676654, 2.153063306659971}, 
    {-0.02884569058205967, 2.1953185530328274}, {0.46757954661597756, \
2.56016136091033}}], 
  Line[{{0.4283813728906071, 2.5129980122544073}, {0.3759239773845737, \
2.4474780907945575}, {-0.08949773581291628, 2.094679321954477}, 
    {-0.05478464252676654, 2.153063306659971}, {0.4283813728906071, \
2.5129980122544073}}], 
  Line[{{0.3759239773845737, 2.4474780907945575}, {0.3125000000000019, \
2.3642850399222186}, {-0.13146784169200168, 2.0210434859217044}, 
    {-0.08949773581291628, 2.094679321954477}, {0.3759239773845737, \
2.4474780907945575}}], 
  Line[{{0.3125000000000019, 2.3642850399222186}, {0.24088137289060696, \
2.2645409632922475}, {-0.17886066514219484, 1.933432094411192}, 
    {-0.13146784169200168, 2.0210434859217044}, {0.3125000000000019, \
2.3642850399222186}}], 
  Line[{{0.24088137289060696, 2.2645409632922475}, {0.1641981737253718, \
2.149982831518161}, {-0.22960491236272335, 1.8336364565828096}, 
    {-0.17886066514219484, 1.933432094411192}, {0.24088137289060696, \
2.2645409632922475}}], 
  Line[{{0.1641981737253718, 2.149982831518161}, {0.0858018262746314, \
2.0231783980979907}, {-0.28148281625213684, 1.7241122839361502}, 
    {-0.22960491236272335, 1.8336364565828096}, {0.1641981737253718, \
2.149982831518161}}], 
  Line[{{0.0858018262746314, 2.0231783980979907}, {0.009118627109396094, \
1.8877889819588962}, {-0.3322270634726655, 1.6081701375219575}, 
    {-0.28148281625213684, 1.7241122839361502}, {0.0858018262746314, \
2.0231783980979907}}], 
  Line[{{0.009118627109396094, 1.8877889819588962}, {-0.06249999999999867, \
1.7488835724541536}, {-0.3796198869228584, 1.4902097135042398}, 
    {-0.3322270634726655, 1.6081701375219575}, {0.009118627109396094, \
1.8877889819588962}}], 
  Line[{{-0.06249999999999867, 1.7488835724541536}, {-0.12592397738457056, \
1.6132809148526024}, {-0.421589992801944, 1.3759750672106559}, 
    {-0.3796198869228584, 1.4902097135042398}, {-0.06249999999999867, \
1.7488835724541536}}], 
  Line[{{-0.12592397738457056, 1.6132809148526024}, {-0.17838137289060418, \
1.4898021598760784}, {-0.4563030860880937, 1.2727298803122153}, 
    {-0.421589992801944, 1.3759750672106559}, {-0.12592397738457056, \
1.6132809148526024}}], 
  Line[{{-0.17838137289060418, 1.4898021598760784}, {-0.21757954661597428, \
1.3891012614574076}, {-0.48224203803280036, 1.1890852819516726}, 
    {-0.4563030860880937, 1.2727298803122153}, {-0.17838137289060418, \
1.4898021598760784}}], 
  Line[{{-0.21757954661597428, 1.3891012614574076}, {-0.24180535027517608, \
1.3224570770547}, {-0.49827319196717934, 1.1340136417284863}, 
    {-0.48224203803280036, 1.1890852819516726}, {-0.21757954661597428, \
1.3891012614574076}}], 
  Line[{{-0.24180535027517608, 1.3224570770547}, {-0.249999999999999, \
1.2990381056766584}, {-0.5036959095382867, 1.1147172382160917}, 
    {-0.49827319196717934, 1.1340136417284863}, {-0.24180535027517608, \
1.3224570770547}}], 
  Line[{{-0.249999999999999, 1.2990381056766584}, {-0.24180535027517608, \
1.3224570770547}, {-0.4982731919671793, 1.1340136417284863}, 
    {-0.5036959095382867, 1.1147172382160917}, {-0.249999999999999, \
1.2990381056766584}}], 
  Line[{{-0.24180535027517608, 1.3224570770547}, {-0.2175795466159744, \
1.3891012614574074}, {-0.4822420380328004, 1.1890852819516724}, 
    {-0.4982731919671793, 1.1340136417284863}, {-0.24180535027517608, \
1.3224570770547}}], 
  Line[{{-0.2175795466159744, 1.3891012614574074}, {-0.17838137289060418, \
1.4898021598760782}, {-0.4563030860880938, 1.2727298803122153}, 
    {-0.4822420380328004, 1.1890852819516724}, {-0.2175795466159744, \
1.3891012614574074}}], 
  Line[{{-0.17838137289060418, 1.4898021598760782}, {-0.12592397738457067, \
1.6132809148526022}, {-0.42158999280194415, 1.3759750672106557}, 
    {-0.4563030860880938, 1.2727298803122153}, {-0.17838137289060418, \
1.4898021598760782}}], 
  Line[{{-0.12592397738457067, 1.6132809148526022}, {-0.062499999999998945, \
1.7488835724541534}, {-0.37961988692285853, 1.4902097135042391}, 
    {-0.42158999280194415, 1.3759750672106557}, {-0.12592397738457067, \
1.6132809148526022}}], 
  Line[{{-0.062499999999998945, 1.7488835724541534}, {0.009118627109395983, \
1.887788981958896}, {-0.3322270634726655, 1.6081701375219573}, 
    {-0.37961988692285853, 1.4902097135042391}, {-0.062499999999998945, \
1.7488835724541534}}], 
  Line[{{0.009118627109395983, 1.887788981958896}, {0.08580182627463112, \
2.0231783980979903}, {-0.281482816252137, 1.72411228393615}, 
    {-0.3322270634726655, 1.6081701375219573}, {0.009118627109395983, \
1.887788981958896}}], 
  Line[{{0.08580182627463112, 2.0231783980979903}, {0.1641981737253714, \
2.14998283151816}, {-0.22960491236272362, 1.8336364565828094}, 
    {-0.281482816252137, 1.72411228393615}, {0.08580182627463112, \
2.0231783980979903}}], 
  Line[{{0.1641981737253714, 2.14998283151816}, {0.24088137289060693, \
2.264540963292247}, {-0.1788606651421949, 1.9334320944111918}, 
    {-0.22960491236272362, 1.8336364565828094}, {0.1641981737253714, \
2.14998283151816}}], 
  Line[{{0.24088137289060693, 2.264540963292247}, {0.31250000000000155, \
2.3642850399222177}, {-0.13146784169200199, 2.021043485921704}, 
    {-0.1788606651421949, 1.9334320944111918}, {0.24088137289060693, \
2.264540963292247}}], 
  Line[{{0.31250000000000155, 2.3642850399222177}, {0.3759239773845736, \
2.4474780907945575}, {-0.08949773581291631, 2.094679321954477}, 
    {-0.13146784169200199, 2.021043485921704}, {0.31250000000000155, \
2.3642850399222177}}], 
  Line[{{0.3759239773845736, 2.4474780907945575}, {0.4283813728906072, \
2.5129980122544073}, {-0.054784642526766514, 2.153063306659971}, 
    {-0.08949773581291631, 2.094679321954477}, {0.3759239773845736, \
2.4474780907945575}}], 
  Line[{{0.4283813728906072, 2.5129980122544073}, {0.4675795466159774, \
2.5601613609103295}, {-0.028845690582059838, 2.195318553032827}, 
    {-0.054784642526766514, 2.153063306659971}, {0.4283813728906072, \
2.5129980122544073}}], 
  Line[{{0.4675795466159774, 2.5601613609103295}, {0.4918053502751791, \
2.5885835797530192}, {-0.0128145366476809, 2.2208803408437965}, 
    {-0.028845690582059838, 2.195318553032827}, {0.4675795466159774, \
2.5601613609103295}}], 
  Line[{{0.4918053502751791, 2.5885835797530192}, {0.5000000000000021, \
2.5980762113533173}, {-0.0073918190765734915, 2.2294344764321834}, 
    {-0.0128145366476809, 2.2208803408437965}, {0.4918053502751791, \
2.5885835797530192}}], 
  Line[{{0.5000000000000021, 2.5980762113533173}, {0.49180535027517946, \
2.5885835797530197}, {-0.012814536647680836, 2.220880340843797}, 
    {-0.0073918190765734915, 2.2294344764321834}, {0.5000000000000021, \
2.5980762113533173}}], 
  Line[{{0.49180535027517946, 2.5885835797530197}, {0.4675795466159775, \
2.56016136091033}, {-0.028845690582059706, 2.1953185530328274}, 
    {-0.012814536647680836, 2.220880340843797}, {0.49180535027517946, \
2.5885835797530197}}], 
  Line[{{0.4675795466159775, 2.56016136091033}, {0.4283813728906073, \
2.5129980122544078}, {-0.05478464252676645, 2.153063306659971}, 
    {-0.028845690582059706, 2.1953185530328274}, {0.4675795466159775, \
2.56016136091033}}], 
  Line[{{0.4283813728906073, 2.5129980122544078}, {0.375923977384574, \
2.4474780907945575}, {-0.08949773581291603, 2.0946793219544775}, 
    {-0.05478464252676645, 2.153063306659971}, {0.4283813728906073, \
2.5129980122544078}}], 
  Line[{{0.375923977384574, 2.4474780907945575}, {0.3125000000000021, \
2.3642850399222186}, {-0.13146784169200165, 2.0210434859217044}, 
    {-0.08949773581291603, 2.0946793219544775}, {0.375923977384574, \
2.4474780907945575}}], 
  Line[{{0.3125000000000021, 2.3642850399222186}, {0.24088137289060724, \
2.2645409632922475}, {-0.17886066514219465, 1.9334320944111922}, 
    {-0.13146784169200165, 2.0210434859217044}, {0.3125000000000021, \
2.3642850399222186}}], 
  Line[{{0.24088137289060724, 2.2645409632922475}, {0.1641981737253721, \
2.1499828315181615}, {-0.22960491236272318, 1.8336364565828103}, 
    {-0.17886066514219465, 1.9334320944111922}, {0.24088137289060724, \
2.2645409632922475}}], 
  Line[{{0.1641981737253721, 2.1499828315181615}, {0.08580182627463168, \
2.023178398097991}, {-0.28148281625213667, 1.7241122839361507}, 
    {-0.22960491236272318, 1.8336364565828103}, {0.1641981737253721, \
2.1499828315181615}}], 
  Line[{{0.08580182627463168, 2.023178398097991}, {0.00911862710939626, \
1.8877889819588964}, {-0.33222706347266534, 1.6081701375219577}, 
    {-0.28148281625213667, 1.7241122839361507}, {0.08580182627463168, \
2.023178398097991}}], 
  Line[{{0.00911862710939626, 1.8877889819588964}, {-0.06249999999999839, \
1.7488835724541543}, {-0.3796198869228583, 1.49020971350424}, 
    {-0.33222706347266534, 1.6081701375219577}, {0.00911862710939626, \
1.8877889819588964}}], 
  Line[{{-0.06249999999999839, 1.7488835724541543}, {-0.12592397738457028, \
1.613280914852603}, {-0.42158999280194376, 1.3759750672106568}, 
    {-0.3796198869228583, 1.49020971350424}, {-0.06249999999999839, \
1.7488835724541543}}], 
  Line[{{-0.12592397738457028, 1.613280914852603}, {-0.17838137289060407, \
1.4898021598760784}, {-0.4563030860880937, 1.2727298803122153}, 
    {-0.42158999280194376, 1.3759750672106568}, {-0.12592397738457028, \
1.613280914852603}}], 
  Line[{{-0.17838137289060407, 1.4898021598760784}, {-0.21757954661597417, \
1.3891012614574079}, {-0.48224203803280025, 1.1890852819516728}, 
    {-0.4563030860880937, 1.2727298803122153}, {-0.17838137289060407, \
1.4898021598760784}}], 
  Line[{{-0.21757954661597417, 1.3891012614574079}, {-0.24180535027517597, \
1.3224570770547004}, {-0.49827319196717923, 1.1340136417284865}, 
    {-0.48224203803280025, 1.1890852819516728}, {-0.21757954661597417, \
1.3891012614574079}}], 
  Line[{{-0.24180535027517597, 1.3224570770547004}, {-0.249999999999999, \
1.2990381056766584}, {-0.5036959095382867, 1.1147172382160917}, 
    {-0.49827319196717923, 1.1340136417284865}, {-0.24180535027517597, \
1.3224570770547004}}], 
  Line[{{-0.249999999999999, 1.2990381056766584}, {-0.2418053502751762, \
1.3224570770547}, {-0.4982731919671794, 1.134013641728486}, 
    {-0.5036959095382867, 1.1147172382160917}, {-0.249999999999999, \
1.2990381056766584}}], 
  Line[{{-0.2418053502751762, 1.3224570770547}, {-0.21757954661597456, \
1.389101261457407}, {-0.4822420380328006, 1.189085281951672}, 
    {-0.4982731919671794, 1.134013641728486}, {-0.2418053502751762, \
1.3224570770547}}], 
  Line[{{-0.21757954661597456, 1.389101261457407}, {-0.1783813728906043, \
1.489802159876078}, {-0.4563030860880938, 1.2727298803122151}, 
    {-0.4822420380328006, 1.189085281951672}, {-0.21757954661597456, \
1.389101261457407}}], 
  Line[{{-0.1783813728906043, 1.489802159876078}, {-0.125923977384571, \
1.6132809148526015}, {-0.4215899928019442, 1.3759750672106552}, 
    {-0.4563030860880938, 1.2727298803122151}, {-0.1783813728906043, \
1.489802159876078}}], 
  Line[{{-0.125923977384571, 1.6132809148526015}, {-0.06249999999999922, \
1.7488835724541525}, {-0.3796198869228588, 1.4902097135042387}, 
    {-0.4215899928019442, 1.3759750672106552}, {-0.125923977384571, \
1.6132809148526015}}], 
  Line[{{-0.06249999999999922, 1.7488835724541525}, {0.009118627109395927, \
1.887788981958896}, {-0.33222706347266556, 1.6081701375219573}, 
    {-0.3796198869228588, 1.4902097135042387}, {-0.06249999999999922, \
1.7488835724541525}}], 
  Line[{{0.009118627109395927, 1.887788981958896}, {0.08580182627463095, \
2.02317839809799}, {-0.2814828162521371, 1.7241122839361496}, 
    {-0.33222706347266556, 1.6081701375219573}, {0.009118627109395927, \
1.887788981958896}}], 
  Line[{{0.08580182627463095, 2.02317839809799}, {0.16419817372537102, \
2.1499828315181597}, {-0.2296049123627239, 1.833636456582809}, 
    {-0.2814828162521371, 1.7241122839361496}, {0.08580182627463095, \
2.02317839809799}}], 
  Line[{{0.16419817372537102, 2.1499828315181597}, {0.240881372890607, \
2.264540963292247}, {-0.17886066514219484, 1.9334320944111918}, 
    {-0.2296049123627239, 1.833636456582809}, {0.16419817372537102, \
2.1499828315181597}}], 
  Line[{{0.240881372890607, 2.264540963292247}, {0.3125000000000015, \
2.3642850399222177}, {-0.13146784169200207, 2.021043485921704}, 
    {-0.17886066514219484, 1.9334320944111918}, {0.240881372890607, \
2.264540963292247}}], 
  Line[{{0.3125000000000015, 2.3642850399222177}, {0.37592397738457317, \
2.4474780907945566}, {-0.0894977358129165, 2.0946793219544766}, 
    {-0.13146784169200207, 2.021043485921704}, {0.3125000000000015, \
2.3642850399222177}}], 
  Line[{{0.37592397738457317, 2.4474780907945566}, {0.4283813728906072, \
2.5129980122544073}, {-0.05478464252676649, 2.153063306659971}, 
    {-0.0894977358129165, 2.0946793219544766}, {0.37592397738457317, \
2.4474780907945566}}], 
  Line[{{0.4283813728906072, 2.5129980122544073}, {0.46757954661597745, \
2.5601613609103295}, {-0.02884569058205982, 2.195318553032827}, 
    {-0.05478464252676649, 2.153063306659971}, {0.4283813728906072, \
2.5129980122544073}}], 
  Line[{{0.46757954661597745, 2.5601613609103295}, {0.49180535027517913, \
2.5885835797530192}, {-0.01281453664768086, 2.2208803408437965}, 
    {-0.02884569058205982, 2.195318553032827}, {0.46757954661597745, \
2.5601613609103295}}], 
  Line[{{0.49180535027517913, 2.5885835797530192}, {0.5000000000000021, \
2.5980762113533173}, {-0.0073918190765734915, 2.2294344764321834}, 
    {-0.01281453664768086, 2.2208803408437965}, {0.49180535027517913, \
2.5885835797530192}}], 
  Line[{{-0.0073918190765734915, 2.2294344764321834}, {-0.012814536647680919, \
2.2208803408437965}, {-0.43018106079382434, 1.75636834939373}, 
    {-0.4270509831248419, 1.7633557568774199}, {-0.0073918190765734915, \
2.2294344764321834}}], 
  Line[{{-0.012814536647680919, 2.2208803408437965}, {-0.02884569058205967, \
2.1953185530328274}, {-0.4394344943868577, 1.7355139912456736}, 
    {-0.43018106079382434, 1.75636834939373}, {-0.012814536647680919, \
2.2208803408437965}}], 
  Line[{{-0.02884569058205967, 2.1953185530328274}, {-0.05478464252676654, \
2.153063306659971}, {-0.45440686445302614, 1.7011229525643676}, 
    {-0.4394344943868577, 1.7355139912456736}, {-0.02884569058205967, \
2.1953185530328274}}], 
  Line[{{-0.05478464252676654, 2.153063306659971}, {-0.08949773581291628, \
2.094679321954477}, {-0.474443806575035, 1.6537682358032737}, 
    {-0.45440686445302614, 1.7011229525643676}, {-0.05478464252676654, \
2.153063306659971}}], 
  Line[{{-0.08949773581291628, 2.094679321954477}, {-0.13146784169200168, \
2.0210434859217044}, {-0.4986696102342367, 1.594300566883078}, 
    {-0.474443806575035, 1.6537682358032737}, {-0.08949773581291628, \
2.094679321954477}}], 
  Line[{{-0.13146784169200168, 2.0210434859217044}, {-0.17886066514219484, \
1.933432094411192}, {-0.5260254915624208, 1.5239001577085334}, 
    {-0.4986696102342367, 1.594300566883078}, {-0.13146784169200168, \
2.0210434859217044}}], 
  Line[{{-0.17886066514219484, 1.933432094411192}, {-0.22960491236272335, \
1.8336364565828096}, {-0.5553158672774632, 1.4441489417584887}, 
    {-0.5260254915624208, 1.5239001577085334}, {-0.17886066514219484, \
1.933432094411192}}], 
  Line[{{-0.22960491236272335, 1.8336364565828096}, {-0.28148281625213684, \
1.7241122839361502}, {-0.5852606074097998, 1.3571288512592459}, 
    {-0.5553158672774632, 1.4441489417584887}, {-0.22960491236272335, \
1.8336364565828096}}], 
  Line[{{-0.28148281625213684, 1.7241122839361502}, {-0.3322270634726655, \
1.6081701375219575}, {-0.614550983124842, 1.2655525104241712}, 
    {-0.5852606074097998, 1.3571288512592459}, {-0.28148281625213684, \
1.7241122839361502}}], 
  Line[{{-0.3322270634726655, 1.6081701375219575}, {-0.3796198869228584, \
1.4902097135042398}, {-0.6419068644530261, 1.1729281630054873}, 
    {-0.614550983124842, 1.2655525104241712}, {-0.3322270634726655, \
1.6081701375219575}}], 
  Line[{{-0.3796198869228584, 1.4902097135042398}, {-0.421589992801944, \
1.3759750672106559}, {-0.6661326681122279, 1.0837396094369784}, 
    {-0.6419068644530261, 1.1729281630054873}, {-0.3796198869228584, \
1.4902097135042398}}], 
  Line[{{-0.421589992801944, 1.3759750672106559}, {-0.4563030860880937, \
1.2727298803122153}, {-0.6861696102342367, 1.0035621274868158}, 
    {-0.6661326681122279, 1.0837396094369784}, {-0.421589992801944, \
1.3759750672106559}}], 
  Line[{{-0.4563030860880937, 1.2727298803122153}, {-0.48224203803280036, \
1.1890852819516726}, {-0.701141980300405, 0.9389137397717199}, 
    {-0.6861696102342367, 1.0035621274868158}, {-0.4563030860880937, \
1.2727298803122153}}], 
  Line[{{-0.48224203803280036, 1.1890852819516726}, {-0.49827319196717934, \
1.1340136417284863}, {-0.7103954138934385, 0.896506223090295}, 
    {-0.701141980300405, 0.9389137397717199}, {-0.48224203803280036, \
1.1890852819516726}}], 
  Line[{{-0.49827319196717934, 1.1340136417284863}, {-0.5036959095382867, \
1.1147172382160917}, {-0.713525491562421, 0.8816778784387099}, 
    {-0.7103954138934385, 0.896506223090295}, {-0.49827319196717934, \
1.1340136417284863}}], 
  Line[{{-0.5036959095382867, 1.1147172382160917}, {-0.4982731919671793, \
1.1340136417284863}, {-0.7103954138934385, 0.896506223090295}, 
    {-0.713525491562421, 0.8816778784387099}, {-0.5036959095382867, \
1.1147172382160917}}], 
  Line[{{-0.4982731919671793, 1.1340136417284863}, {-0.4822420380328004, \
1.1890852819516724}, {-0.7011419803004051, 0.9389137397717195}, 
    {-0.7103954138934385, 0.896506223090295}, {-0.4982731919671793, \
1.1340136417284863}}], 
  Line[{{-0.4822420380328004, 1.1890852819516724}, {-0.4563030860880938, \
1.2727298803122153}, {-0.6861696102342368, 1.0035621274868156}, 
    {-0.7011419803004051, 0.9389137397717195}, {-0.4822420380328004, \
1.1890852819516724}}], 
  Line[{{-0.4563030860880938, 1.2727298803122153}, {-0.42158999280194415, \
1.3759750672106557}, {-0.6661326681122279, 1.0837396094369782}, 
    {-0.6861696102342368, 1.0035621274868156}, {-0.4563030860880938, \
1.2727298803122153}}], 
  Line[{{-0.42158999280194415, 1.3759750672106557}, {-0.37961988692285853, \
1.4902097135042391}, {-0.6419068644530262, 1.1729281630054869}, 
    {-0.6661326681122279, 1.0837396094369782}, {-0.42158999280194415, \
1.3759750672106557}}], 
  Line[{{-0.37961988692285853, 1.4902097135042391}, {-0.3322270634726655, \
1.6081701375219573}, {-0.614550983124842, 1.265552510424171}, 
    {-0.6419068644530262, 1.1729281630054869}, {-0.37961988692285853, \
1.4902097135042391}}], 
  Line[{{-0.3322270634726655, 1.6081701375219573}, {-0.281482816252137, \
1.72411228393615}, {-0.5852606074097999, 1.3571288512592452}, 
    {-0.614550983124842, 1.265552510424171}, {-0.3322270634726655, \
1.6081701375219573}}], 
  Line[{{-0.281482816252137, 1.72411228393615}, {-0.22960491236272362, \
1.8336364565828094}, {-0.5553158672774632, 1.4441489417584883}, 
    {-0.5852606074097999, 1.3571288512592452}, {-0.281482816252137, \
1.72411228393615}}], 
  Line[{{-0.22960491236272362, 1.8336364565828094}, {-0.1788606651421949, \
1.9334320944111918}, {-0.5260254915624208, 1.5239001577085334}, 
    {-0.5553158672774632, 1.4441489417584883}, {-0.22960491236272362, \
1.8336364565828094}}], 
  Line[{{-0.1788606651421949, 1.9334320944111918}, {-0.13146784169200199, \
2.021043485921704}, {-0.4986696102342367, 1.5943005668830776}, 
    {-0.5260254915624208, 1.5239001577085334}, {-0.1788606651421949, \
1.9334320944111918}}], 
  Line[{{-0.13146784169200199, 2.021043485921704}, {-0.08949773581291631, \
2.094679321954477}, {-0.47444380657503493, 1.6537682358032735}, 
    {-0.4986696102342367, 1.5943005668830776}, {-0.13146784169200199, \
2.021043485921704}}], 
  Line[{{-0.08949773581291631, 2.094679321954477}, {-0.054784642526766514, \
2.153063306659971}, {-0.4544068644530261, 1.7011229525643676}, 
    {-0.47444380657503493, 1.6537682358032735}, {-0.08949773581291631, \
2.094679321954477}}], 
  Line[{{-0.054784642526766514, 2.153063306659971}, {-0.028845690582059838, \
2.195318553032827}, {-0.43943449438685783, 1.7355139912456734}, 
    {-0.4544068644530261, 1.7011229525643676}, {-0.054784642526766514, \
2.153063306659971}}], 
  Line[{{-0.028845690582059838, 2.195318553032827}, {-0.0128145366476809, \
2.2208803408437965}, {-0.43018106079382434, 1.75636834939373}, 
    {-0.43943449438685783, 1.7355139912456734}, {-0.028845690582059838, \
2.195318553032827}}], 
  Line[{{-0.0128145366476809, 2.2208803408437965}, {-0.0073918190765734915, \
2.2294344764321834}, {-0.4270509831248419, 1.7633557568774199}, 
    {-0.43018106079382434, 1.75636834939373}, {-0.0128145366476809, \
2.2208803408437965}}], 
  Line[{{-0.0073918190765734915, 2.2294344764321834}, {-0.012814536647680836, \
2.220880340843797}, {-0.43018106079382423, 1.75636834939373}, 
    {-0.4270509831248419, 1.7633557568774199}, {-0.0073918190765734915, \
2.2294344764321834}}], 
  Line[{{-0.012814536647680836, 2.220880340843797}, {-0.028845690582059706, \
2.1953185530328274}, {-0.4394344943868578, 1.7355139912456736}, 
    {-0.43018106079382423, 1.75636834939373}, {-0.012814536647680836, \
2.220880340843797}}], 
  Line[{{-0.028845690582059706, 2.1953185530328274}, {-0.05478464252676645, \
2.153063306659971}, {-0.454406864453026, 1.7011229525643679}, 
    {-0.4394344943868578, 1.7355139912456736}, {-0.028845690582059706, \
2.1953185530328274}}], 
  Line[{{-0.05478464252676645, 2.153063306659971}, {-0.08949773581291603, \
2.0946793219544775}, {-0.4744438065750348, 1.653768235803274}, 
    {-0.454406864453026, 1.7011229525643679}, {-0.05478464252676645, \
2.153063306659971}}], 
  Line[{{-0.08949773581291603, 2.0946793219544775}, {-0.13146784169200165, \
2.0210434859217044}, {-0.4986696102342365, 1.594300566883078}, 
    {-0.4744438065750348, 1.653768235803274}, {-0.08949773581291603, \
2.0946793219544775}}], 
  Line[{{-0.13146784169200165, 2.0210434859217044}, {-0.17886066514219465, \
1.9334320944111922}, {-0.5260254915624207, 1.5239001577085336}, 
    {-0.4986696102342365, 1.594300566883078}, {-0.13146784169200165, \
2.0210434859217044}}], 
  Line[{{-0.17886066514219465, 1.9334320944111922}, {-0.22960491236272318, \
1.8336364565828103}, {-0.5553158672774631, 1.4441489417584887}, 
    {-0.5260254915624207, 1.5239001577085336}, {-0.17886066514219465, \
1.9334320944111922}}], 
  Line[{{-0.22960491236272318, 1.8336364565828103}, {-0.28148281625213667, \
1.7241122839361507}, {-0.5852606074097996, 1.357128851259246}, 
    {-0.5553158672774631, 1.4441489417584887}, {-0.22960491236272318, \
1.8336364565828103}}], 
  Line[{{-0.28148281625213667, 1.7241122839361507}, {-0.33222706347266534, \
1.6081701375219577}, {-0.6145509831248419, 1.2655525104241714}, 
    {-0.5852606074097996, 1.357128851259246}, {-0.28148281625213667, \
1.7241122839361507}}], 
  Line[{{-0.33222706347266534, 1.6081701375219577}, {-0.3796198869228583, \
1.49020971350424}, {-0.641906864453026, 1.1729281630054875}, 
    {-0.6145509831248419, 1.2655525104241714}, {-0.33222706347266534, \
1.6081701375219577}}], 
  Line[{{-0.3796198869228583, 1.49020971350424}, {-0.42158999280194376, \
1.3759750672106568}, {-0.6661326681122279, 1.0837396094369787}, 
    {-0.641906864453026, 1.1729281630054875}, {-0.3796198869228583, \
1.49020971350424}}], 
  Line[{{-0.42158999280194376, 1.3759750672106568}, {-0.4563030860880937, \
1.2727298803122153}, {-0.6861696102342367, 1.0035621274868158}, 
    {-0.6661326681122279, 1.0837396094369787}, {-0.42158999280194376, \
1.3759750672106568}}], 
  Line[{{-0.4563030860880937, 1.2727298803122153}, {-0.48224203803280025, \
1.1890852819516728}, {-0.701141980300405, 0.93891373977172}, 
    {-0.6861696102342367, 1.0035621274868158}, {-0.4563030860880937, \
1.2727298803122153}}], 
  Line[{{-0.48224203803280025, 1.1890852819516728}, {-0.49827319196717923, \
1.1340136417284865}, {-0.7103954138934385, 0.8965062230902952}, 
    {-0.701141980300405, 0.93891373977172}, {-0.48224203803280025, \
1.1890852819516728}}], 
  Line[{{-0.49827319196717923, 1.1340136417284865}, {-0.5036959095382867, \
1.1147172382160917}, {-0.713525491562421, 0.8816778784387099}, 
    {-0.7103954138934385, 0.8965062230902952}, {-0.49827319196717923, \
1.1340136417284865}}], 
  Line[{{-0.5036959095382867, 1.1147172382160917}, {-0.4982731919671794, \
1.134013641728486}, {-0.7103954138934385, 0.8965062230902949}, 
    {-0.713525491562421, 0.8816778784387099}, {-0.5036959095382867, \
1.1147172382160917}}], 
  Line[{{-0.4982731919671794, 1.134013641728486}, {-0.4822420380328006, \
1.189085281951672}, {-0.7011419803004052, 0.9389137397717192}, 
    {-0.7103954138934385, 0.8965062230902949}, {-0.4982731919671794, \
1.134013641728486}}], 
  Line[{{-0.4822420380328006, 1.189085281951672}, {-0.4563030860880938, \
1.2727298803122151}, {-0.6861696102342368, 1.0035621274868154}, 
    {-0.7011419803004052, 0.9389137397717192}, {-0.4822420380328006, \
1.189085281951672}}], 
  Line[{{-0.4563030860880938, 1.2727298803122151}, {-0.4215899928019442, \
1.3759750672106552}, {-0.6661326681122282, 1.0837396094369776}, 
    {-0.6861696102342368, 1.0035621274868154}, {-0.4563030860880938, \
1.2727298803122151}}], 
  Line[{{-0.4215899928019442, 1.3759750672106552}, {-0.3796198869228588, \
1.4902097135042387}, {-0.6419068644530264, 1.1729281630054864}, 
    {-0.6661326681122282, 1.0837396094369776}, {-0.4215899928019442, \
1.3759750672106552}}], 
  Line[{{-0.3796198869228588, 1.4902097135042387}, {-0.33222706347266556, \
1.6081701375219573}, {-0.614550983124842, 1.2655525104241707}, 
    {-0.6419068644530264, 1.1729281630054864}, {-0.3796198869228588, \
1.4902097135042387}}], 
  Line[{{-0.33222706347266556, 1.6081701375219573}, {-0.2814828162521371, \
1.7241122839361496}, {-0.5852606074097999, 1.3571288512592452}, 
    {-0.614550983124842, 1.2655525104241707}, {-0.33222706347266556, \
1.6081701375219573}}], 
  Line[{{-0.2814828162521371, 1.7241122839361496}, {-0.2296049123627239, \
1.833636456582809}, {-0.5553158672774634, 1.4441489417584878}, 
    {-0.5852606074097999, 1.3571288512592452}, {-0.2814828162521371, \
1.7241122839361496}}], 
  Line[{{-0.2296049123627239, 1.833636456582809}, {-0.17886066514219484, \
1.9334320944111918}, {-0.5260254915624208, 1.5239001577085334}, 
    {-0.5553158672774634, 1.4441489417584878}, {-0.2296049123627239, \
1.833636456582809}}], 
  Line[{{-0.17886066514219484, 1.9334320944111918}, {-0.13146784169200207, \
2.021043485921704}, {-0.49866961023423684, 1.5943005668830776}, 
    {-0.5260254915624208, 1.5239001577085334}, {-0.17886066514219484, \
1.9334320944111918}}], 
  Line[{{-0.13146784169200207, 2.021043485921704}, {-0.0894977358129165, \
2.0946793219544766}, {-0.4744438065750351, 1.6537682358032733}, 
    {-0.49866961023423684, 1.5943005668830776}, {-0.13146784169200207, \
2.021043485921704}}], 
  Line[{{-0.0894977358129165, 2.0946793219544766}, {-0.05478464252676649, \
2.153063306659971}, {-0.4544068644530261, 1.7011229525643676}, 
    {-0.4744438065750351, 1.6537682358032733}, {-0.0894977358129165, \
2.0946793219544766}}], 
  Line[{{-0.05478464252676649, 2.153063306659971}, {-0.02884569058205982, \
2.195318553032827}, {-0.4394344943868578, 1.7355139912456734}, 
    {-0.4544068644530261, 1.7011229525643676}, {-0.05478464252676649, \
2.153063306659971}}], 
  Line[{{-0.02884569058205982, 2.195318553032827}, {-0.01281453664768086, \
2.2208803408437965}, {-0.4301810607938243, 1.75636834939373}, 
    {-0.4394344943868578, 1.7355139912456734}, {-0.02884569058205982, \
2.195318553032827}}], 
  Line[{{-0.01281453664768086, 2.2208803408437965}, {-0.0073918190765734915, \
2.2294344764321834}, {-0.4270509831248419, 1.7633557568774199}, 
    {-0.4301810607938243, 1.75636834939373}, {-0.01281453664768086, \
2.2208803408437965}}], 
  Line[{{-0.4270509831248419, 1.7633557568774199}, {-0.43018106079382434, \
1.75636834939373}, {-0.7420533023112793, 1.2152748245287468}, 
    {-0.7406363729278018, 1.220209929227403}, {-0.4270509831248419, \
1.7633557568774199}}], 
  Line[{{-0.43018106079382434, 1.75636834939373}, {-0.4394344943868577, \
1.7355139912456736}, {-0.7462421638484722, 1.200556789468474}, 
    {-0.7420533023112793, 1.2152748245287468}, {-0.43018106079382434, \
1.75636834939373}}], 
  Line[{{-0.4394344943868577, 1.7355139912456736}, {-0.45440686445302614, \
1.7011229525643676}, {-0.7530198841898177, 1.1763209525760543}, 
    {-0.7462421638484722, 1.200556789468474}, {-0.4394344943868577, \
1.7355139912456736}}], 
  Line[{{-0.45440686445302614, 1.7011229525643676}, {-0.474443806575035, \
1.6537682358032737}, {-0.7620902444332882, 1.1430205016052861}, 
    {-0.7530198841898177, 1.1763209525760543}, {-0.45440686445302614, \
1.7011229525643676}}], 
  Line[{{-0.474443806575035, 1.6537682358032737}, {-0.4986696102342367, \
1.594300566883078}, {-0.7730568263118266, 1.1013148858947228}, 
    {-0.7620902444332882, 1.1430205016052861}, {-0.474443806575035, \
1.6537682358032737}}], 
  Line[{{-0.4986696102342367, 1.594300566883078}, {-0.5260254915624208, \
1.5239001577085334}, {-0.7854403375738425, 1.0520980143876315}, 
    {-0.7730568263118266, 1.1013148858947228}, {-0.4986696102342367, \
1.594300566883078}}], 
  Line[{{-0.5260254915624208, 1.5239001577085334}, {-0.5553158672774632, \
1.4441489417584887}, {-0.7986995593545059, 0.9965396214846565}, 
    {-0.7854403375738425, 1.0520980143876315}, {-0.5260254915624208, \
1.5239001577085334}}], 
  Line[{{-0.5553158672774632, 1.4441489417584887}, {-0.5852606074097998, \
1.3571288512592459}, {-0.8122550000371968, 0.9361441841071289}, 
    {-0.7986995593545059, 0.9965396214846565}, {-0.5553158672774632, \
1.4441489417584887}}], 
  Line[{{-0.5852606074097998, 1.3571288512592459}, {-0.614550983124842, \
1.2655525104241712}, {-0.8255142218178602, 0.8728320775698136}, 
    {-0.8122550000371968, 0.9361441841071289}, {-0.5852606074097998, \
1.3571288512592459}}], 
  Line[{{-0.614550983124842, 1.2655525104241712}, {-0.6419068644530261, \
1.1729281630054873}, {-0.8378977330798761, 0.8090441125945343}, 
    {-0.8255142218178602, 0.8728320775698136}, {-0.614550983124842, \
1.2655525104241712}}], 
  Line[{{-0.6419068644530261, 1.1729281630054873}, {-0.6661326681122279, \
1.0837396094369784}, {-0.8488643149584145, 0.7478557941640124}, 
    {-0.8378977330798761, 0.8090441125945343}, {-0.6419068644530261, \
1.1729281630054873}}], 
  Line[{{-0.6661326681122279, 1.0837396094369784}, {-0.6861696102342367, \
1.0035621274868158}, {-0.857934675201885, 0.6930472461935383}, 
    {-0.8488643149584145, 0.7478557941640124}, {-0.6661326681122279, \
1.0837396094369784}}], 
  Line[{{-0.6861696102342367, 1.0035621274868158}, {-0.701141980300405, \
0.9389137397717199}, {-0.8647123955432304, 0.6489952411032616}, 
    {-0.857934675201885, 0.6930472461935383}, {-0.6861696102342367, \
1.0035621274868158}}], 
  Line[{{-0.701141980300405, 0.9389137397717199}, {-0.7103954138934385, \
0.896506223090295}, {-0.8689012570804234, 0.6201700772082621}, 
    {-0.8647123955432304, 0.6489952411032616}, {-0.701141980300405, \
0.9389137397717199}}], 
  Line[{{-0.7103954138934385, 0.896506223090295}, {-0.713525491562421, \
0.8816778784387099}, {-0.8703181864639009, 0.6101049646137015}, 
    {-0.8689012570804234, 0.6201700772082621}, {-0.7103954138934385, \
0.896506223090295}}], 
  Line[{{-0.713525491562421, 0.8816778784387099}, {-0.7103954138934385, \
0.896506223090295}, {-0.8689012570804234, 0.6201700772082621}, 
    {-0.8703181864639009, 0.6101049646137015}, {-0.713525491562421, \
0.8816778784387099}}], 
  Line[{{-0.7103954138934385, 0.896506223090295}, {-0.7011419803004051, \
0.9389137397717195}, {-0.8647123955432304, 0.6489952411032616}, 
    {-0.8689012570804234, 0.6201700772082621}, {-0.7103954138934385, \
0.896506223090295}}], 
  Line[{{-0.7011419803004051, 0.9389137397717195}, {-0.6861696102342368, \
1.0035621274868156}, {-0.857934675201885, 0.6930472461935381}, 
    {-0.8647123955432304, 0.6489952411032616}, {-0.7011419803004051, \
0.9389137397717195}}], 
  Line[{{-0.6861696102342368, 1.0035621274868156}, {-0.6661326681122279, \
1.0837396094369782}, {-0.8488643149584145, 0.7478557941640123}, 
    {-0.857934675201885, 0.6930472461935381}, {-0.6861696102342368, \
1.0035621274868156}}], 
  Line[{{-0.6661326681122279, 1.0837396094369782}, {-0.6419068644530262, \
1.1729281630054869}, {-0.8378977330798763, 0.809044112594534}, 
    {-0.8488643149584145, 0.7478557941640123}, {-0.6661326681122279, \
1.0837396094369782}}], 
  Line[{{-0.6419068644530262, 1.1729281630054869}, {-0.614550983124842, \
1.265552510424171}, {-0.8255142218178603, 0.8728320775698134}, 
    {-0.8378977330798763, 0.809044112594534}, {-0.6419068644530262, \
1.1729281630054869}}], 
  Line[{{-0.614550983124842, 1.265552510424171}, {-0.5852606074097999, \
1.3571288512592452}, {-0.8122550000371969, 0.9361441841071285}, 
    {-0.8255142218178603, 0.8728320775698134}, {-0.614550983124842, \
1.265552510424171}}], 
  Line[{{-0.5852606074097999, 1.3571288512592452}, {-0.5553158672774632, \
1.4441489417584883}, {-0.798699559354506, 0.9965396214846562}, 
    {-0.8122550000371969, 0.9361441841071285}, {-0.5852606074097999, \
1.3571288512592452}}], 
  Line[{{-0.5553158672774632, 1.4441489417584883}, {-0.5260254915624208, \
1.5239001577085334}, {-0.7854403375738425, 1.0520980143876313}, 
    {-0.798699559354506, 0.9965396214846562}, {-0.5553158672774632, \
1.4441489417584883}}], 
  Line[{{-0.5260254915624208, 1.5239001577085334}, {-0.4986696102342367, \
1.5943005668830776}, {-0.7730568263118266, 1.1013148858947226}, 
    {-0.7854403375738425, 1.0520980143876313}, {-0.5260254915624208, \
1.5239001577085334}}], 
  Line[{{-0.4986696102342367, 1.5943005668830776}, {-0.47444380657503493, \
1.6537682358032735}, {-0.7620902444332882, 1.143020501605286}, 
    {-0.7730568263118266, 1.1013148858947226}, {-0.4986696102342367, \
1.5943005668830776}}], 
  Line[{{-0.47444380657503493, 1.6537682358032735}, {-0.4544068644530261, \
1.7011229525643676}, {-0.7530198841898177, 1.1763209525760543}, 
    {-0.7620902444332882, 1.143020501605286}, {-0.47444380657503493, \
1.6537682358032735}}], 
  Line[{{-0.4544068644530261, 1.7011229525643676}, {-0.43943449438685783, \
1.7355139912456734}, {-0.7462421638484723, 1.200556789468474}, 
    {-0.7530198841898177, 1.1763209525760543}, {-0.4544068644530261, \
1.7011229525643676}}], 
  Line[{{-0.43943449438685783, 1.7355139912456734}, {-0.43018106079382434, \
1.75636834939373}, {-0.7420533023112793, 1.2152748245287468}, 
    {-0.7462421638484723, 1.200556789468474}, {-0.43943449438685783, \
1.7355139912456734}}], 
  Line[{{-0.43018106079382434, 1.75636834939373}, {-0.4270509831248419, \
1.7633557568774199}, {-0.7406363729278018, 1.220209929227403}, 
    {-0.7420533023112793, 1.2152748245287468}, {-0.43018106079382434, \
1.75636834939373}}], 
  Line[{{-0.4270509831248419, 1.7633557568774199}, {-0.43018106079382423, \
1.75636834939373}, {-0.7420533023112793, 1.2152748245287468}, 
    {-0.7406363729278018, 1.220209929227403}, {-0.4270509831248419, \
1.7633557568774199}}], 
  Line[{{-0.43018106079382423, 1.75636834939373}, {-0.4394344943868578, \
1.7355139912456736}, {-0.7462421638484722, 1.200556789468474}, 
    {-0.7420533023112793, 1.2152748245287468}, {-0.43018106079382423, \
1.75636834939373}}], 
  Line[{{-0.4394344943868578, 1.7355139912456736}, {-0.454406864453026, \
1.7011229525643679}, {-0.7530198841898177, 1.1763209525760543}, 
    {-0.7462421638484722, 1.200556789468474}, {-0.4394344943868578, \
1.7355139912456736}}], 
  Line[{{-0.454406864453026, 1.7011229525643679}, {-0.4744438065750348, \
1.653768235803274}, {-0.7620902444332881, 1.1430205016052863}, 
    {-0.7530198841898177, 1.1763209525760543}, {-0.454406864453026, \
1.7011229525643679}}], 
  Line[{{-0.4744438065750348, 1.653768235803274}, {-0.4986696102342365, \
1.594300566883078}, {-0.7730568263118266, 1.1013148858947228}, 
    {-0.7620902444332881, 1.1430205016052863}, {-0.4744438065750348, \
1.653768235803274}}], 
  Line[{{-0.4986696102342365, 1.594300566883078}, {-0.5260254915624207, \
1.5239001577085336}, {-0.7854403375738425, 1.0520980143876315}, 
    {-0.7730568263118266, 1.1013148858947228}, {-0.4986696102342365, \
1.594300566883078}}], 
  Line[{{-0.5260254915624207, 1.5239001577085336}, {-0.5553158672774631, \
1.4441489417584887}, {-0.7986995593545059, 0.9965396214846567}, 
    {-0.7854403375738425, 1.0520980143876315}, {-0.5260254915624207, \
1.5239001577085336}}], 
  Line[{{-0.5553158672774631, 1.4441489417584887}, {-0.5852606074097996, \
1.357128851259246}, {-0.8122550000371966, 0.9361441841071292}, 
    {-0.7986995593545059, 0.9965396214846567}, {-0.5553158672774631, \
1.4441489417584887}}], 
  Line[{{-0.5852606074097996, 1.357128851259246}, {-0.6145509831248419, \
1.2655525104241714}, {-0.8255142218178602, 0.8728320775698137}, 
    {-0.8122550000371966, 0.9361441841071292}, {-0.5852606074097996, \
1.357128851259246}}], 
  Line[{{-0.6145509831248419, 1.2655525104241714}, {-0.641906864453026, \
1.1729281630054875}, {-0.837897733079876, 0.8090441125945347}, 
    {-0.8255142218178602, 0.8728320775698137}, {-0.6145509831248419, \
1.2655525104241714}}], 
  Line[{{-0.641906864453026, 1.1729281630054875}, {-0.6661326681122279, \
1.0837396094369787}, {-0.8488643149584145, 0.7478557941640125}, 
    {-0.837897733079876, 0.8090441125945347}, {-0.641906864453026, \
1.1729281630054875}}], 
  Line[{{-0.6661326681122279, 1.0837396094369787}, {-0.6861696102342367, \
1.0035621274868158}, {-0.857934675201885, 0.6930472461935383}, 
    {-0.8488643149584145, 0.7478557941640125}, {-0.6661326681122279, \
1.0837396094369787}}], 
  Line[{{-0.6861696102342367, 1.0035621274868158}, {-0.701141980300405, \
0.93891373977172}, {-0.8647123955432304, 0.6489952411032617}, 
    {-0.857934675201885, 0.6930472461935383}, {-0.6861696102342367, \
1.0035621274868158}}], 
  Line[{{-0.701141980300405, 0.93891373977172}, {-0.7103954138934385, \
0.8965062230902952}, {-0.8689012570804234, 0.6201700772082622}, 
    {-0.8647123955432304, 0.6489952411032617}, {-0.701141980300405, \
0.93891373977172}}], 
  Line[{{-0.7103954138934385, 0.8965062230902952}, {-0.713525491562421, \
0.8816778784387099}, {-0.8703181864639009, 0.6101049646137015}, 
    {-0.8689012570804234, 0.6201700772082622}, {-0.7103954138934385, \
0.8965062230902952}}], 
  Line[{{-0.713525491562421, 0.8816778784387099}, {-0.7103954138934385, \
0.8965062230902949}, {-0.8689012570804235, 0.6201700772082617}, 
    {-0.8703181864639009, 0.6101049646137015}, {-0.713525491562421, \
0.8816778784387099}}], 
  Line[{{-0.7103954138934385, 0.8965062230902949}, {-0.7011419803004052, \
0.9389137397717192}, {-0.8647123955432305, 0.6489952411032612}, 
    {-0.8689012570804235, 0.6201700772082617}, {-0.7103954138934385, \
0.8965062230902949}}], 
  Line[{{-0.7011419803004052, 0.9389137397717192}, {-0.6861696102342368, \
1.0035621274868154}, {-0.857934675201885, 0.6930472461935381}, 
    {-0.8647123955432305, 0.6489952411032612}, {-0.7011419803004052, \
0.9389137397717192}}], 
  Line[{{-0.6861696102342368, 1.0035621274868154}, {-0.6661326681122282, \
1.0837396094369776}, {-0.8488643149584146, 0.7478557941640119}, 
    {-0.857934675201885, 0.6930472461935381}, {-0.6861696102342368, \
1.0035621274868154}}], 
  Line[{{-0.6661326681122282, 1.0837396094369776}, {-0.6419068644530264, \
1.1729281630054864}, {-0.8378977330798763, 0.8090441125945338}, 
    {-0.8488643149584146, 0.7478557941640119}, {-0.6661326681122282, \
1.0837396094369776}}], 
  Line[{{-0.6419068644530264, 1.1729281630054864}, {-0.614550983124842, \
1.2655525104241707}, {-0.8255142218178603, 0.8728320775698134}, 
    {-0.8378977330798763, 0.8090441125945338}, {-0.6419068644530264, \
1.1729281630054864}}], 
  Line[{{-0.614550983124842, 1.2655525104241707}, {-0.5852606074097999, \
1.3571288512592452}, {-0.8122550000371969, 0.9361441841071284}, 
    {-0.8255142218178603, 0.8728320775698134}, {-0.614550983124842, \
1.2655525104241707}}], 
  Line[{{-0.5852606074097999, 1.3571288512592452}, {-0.5553158672774634, \
1.4441489417584878}, {-0.798699559354506, 0.996539621484656}, 
    {-0.8122550000371969, 0.9361441841071284}, {-0.5852606074097999, \
1.3571288512592452}}], 
  Line[{{-0.5553158672774634, 1.4441489417584878}, {-0.5260254915624208, \
1.5239001577085334}, {-0.7854403375738425, 1.0520980143876313}, 
    {-0.798699559354506, 0.996539621484656}, {-0.5553158672774634, \
1.4441489417584878}}], 
  Line[{{-0.5260254915624208, 1.5239001577085334}, {-0.49866961023423684, \
1.5943005668830776}, {-0.7730568263118266, 1.1013148858947226}, 
    {-0.7854403375738425, 1.0520980143876313}, {-0.5260254915624208, \
1.5239001577085334}}], 
  Line[{{-0.49866961023423684, 1.5943005668830776}, {-0.4744438065750351, \
1.6537682358032733}, {-0.7620902444332882, 1.143020501605286}, 
    {-0.7730568263118266, 1.1013148858947226}, {-0.49866961023423684, \
1.5943005668830776}}], 
  Line[{{-0.4744438065750351, 1.6537682358032733}, {-0.4544068644530261, \
1.7011229525643676}, {-0.7530198841898177, 1.1763209525760543}, 
    {-0.7620902444332882, 1.143020501605286}, {-0.4744438065750351, \
1.6537682358032733}}], 
  Line[{{-0.4544068644530261, 1.7011229525643676}, {-0.4394344943868578, \
1.7355139912456734}, {-0.7462421638484723, 1.200556789468474}, 
    {-0.7530198841898177, 1.1763209525760543}, {-0.4544068644530261, \
1.7011229525643676}}], 
  Line[{{-0.4394344943868578, 1.7355139912456734}, {-0.4301810607938243, \
1.75636834939373}, {-0.7420533023112792, 1.2152748245287468}, 
    {-0.7462421638484723, 1.200556789468474}, {-0.4394344943868578, \
1.7355139912456734}}], 
  Line[{{-0.4301810607938243, 1.75636834939373}, {-0.4270509831248419, \
1.7633557568774199}, {-0.7406363729278018, 1.220209929227403}, 
    {-0.7420533023112792, 1.2152748245287468}, {-0.4301810607938243, \
1.75636834939373}}], 
  Line[{{-0.7406363729278018, 1.220209929227403}, {-0.7420533023112793, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
    {-0.9344428022014165, 0.6237350724532796}, {-0.7406363729278018, \
1.220209929227403}}], 
  Line[{{-0.7420533023112793, 1.2152748245287468}, {-0.7462421638484722, \
1.200556789468474}, {-0.9358597315848941, 0.6135770923916904}, 
    {-0.9348009477166834, 0.6211835161491779}, {-0.7420533023112793, \
1.2152748245287468}}], 
  Line[{{-0.7462421638484722, 1.200556789468474}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
    {-0.9358597315848941, 0.6135770923916904}, {-0.7462421638484722, \
1.200556789468474}}], 
  Line[{{-0.7530198841898177, 1.1763209525760543}, {-0.7620902444332882, \
1.1430205016052861}, {-0.9398655197725241, 0.5838857533279131}, 
    {-0.937572879870399, 0.6010618457721164}, {-0.7530198841898177, \
1.1763209525760543}}], 
  Line[{{-0.7620902444332882, 1.1430205016052861}, {-0.7730568263118266, \
1.1013148858947228}, {-0.9426374519262395, 0.5624063276196131}, 
    {-0.9398655197725241, 0.5838857533279131}, {-0.7620902444332882, \
1.1430205016052861}}], 
  Line[{{-0.7730568263118266, 1.1013148858947228}, {-0.7854403375738425, \
1.0520980143876315}, {-0.9457675295952219, 0.5371028573756125}, 
    {-0.9426374519262395, 0.5624063276196131}, {-0.7730568263118266, \
1.1013148858947228}}], 
  Line[{{-0.7854403375738425, 1.0520980143876315}, {-0.7986995593545059, \
0.9965396214846565}, {-0.9491189533655575, 0.5085950701762803}, 
    {-0.9457675295952219, 0.5371028573756125}, {-0.7854403375738425, \
1.0520980143876315}}], 
  Line[{{-0.7986995593545059, 0.9965396214846565}, {-0.8122550000371968, \
0.9361441841071289}, {-0.9525452499365673, 0.47767060184981125}, 
    {-0.9491189533655575, 0.5085950701762803}, {-0.7986995593545059, \
0.9965396214846565}}], 
  Line[{{-0.8122550000371968, 0.9361441841071289}, {-0.8255142218178602, \
0.8728320775698136}, {-0.955896673706903, 0.44532374723565715}, 
    {-0.9525452499365673, 0.47767060184981125}, {-0.8122550000371968, \
0.9361441841071289}}], 
  Line[{{-0.8255142218178602, 0.8728320775698136}, {-0.8378977330798761, \
0.8090441125945343}, {-0.9590267513758853, 0.41280605266694914}, 
    {-0.955896673706903, 0.44532374723565715}, {-0.8255142218178602, \
0.8728320775698136}}], 
  Line[{{-0.8378977330798761, 0.8090441125945343}, {-0.8488643149584145, \
0.7478557941640124}, {-0.9617986835296009, 0.3816816923272197}, 
    {-0.9590267513758853, 0.41280605266694914}, {-0.8378977330798761, \
0.8090441125945343}}], 
  Line[{{-0.8488643149584145, 0.7478557941640124}, {-0.857934675201885, \
0.6930472461935383}, {-0.9640913234317259, 0.3538602304100192}, 
    {-0.9617986835296009, 0.3816816923272197}, {-0.8488643149584145, \
0.7478557941640124}}], 
  Line[{{-0.857934675201885, 0.6930472461935383}, {-0.8647123955432304, \
0.6489952411032616}, {-0.9658044717172307, 0.33154008354139486}, 
    {-0.9640913234317259, 0.3538602304100192}, {-0.857934675201885, \
0.6930472461935383}}], 
  Line[{{-0.8647123955432304, 0.6489952411032616}, {-0.8689012570804234, \
0.6201700772082621}, {-0.9668632555854414, 0.31695593148714096}, 
    {-0.9658044717172307, 0.33154008354139486}, {-0.8647123955432304, \
0.6489952411032616}}], 
  Line[{{-0.8689012570804234, 0.6201700772082621}, {-0.8703181864639009, \
0.6101049646137015}, {-0.9672214011007083, 0.3118675362266397}, 
    {-0.9668632555854414, 0.31695593148714096}, {-0.8689012570804234, \
0.6201700772082621}}], 
  Line[{{-0.8703181864639009, 0.6101049646137015}, {-0.8689012570804234, \
0.6201700772082621}, {-0.9668632555854414, 0.31695593148714096}, 
    {-0.9672214011007083, 0.3118675362266397}, {-0.8703181864639009, \
0.6101049646137015}}], 
  Line[{{-0.8689012570804234, 0.6201700772082621}, {-0.8647123955432304, \
0.6489952411032616}, {-0.9658044717172307, 0.33154008354139486}, 
    {-0.9668632555854414, 0.31695593148714096}, {-0.8689012570804234, \
0.6201700772082621}}], 
  Line[{{-0.8647123955432304, 0.6489952411032616}, {-0.857934675201885, \
0.6930472461935381}, {-0.9640913234317259, 0.3538602304100192}, 
    {-0.9658044717172307, 0.33154008354139486}, {-0.8647123955432304, \
0.6489952411032616}}], 
  Line[{{-0.857934675201885, 0.6930472461935381}, {-0.8488643149584145, \
0.7478557941640123}, {-0.9617986835296009, 0.3816816923272197}, 
    {-0.9640913234317259, 0.3538602304100192}, {-0.857934675201885, \
0.6930472461935381}}], 
  Line[{{-0.8488643149584145, 0.7478557941640123}, {-0.8378977330798763, \
0.809044112594534}, {-0.9590267513758853, 0.41280605266694914}, 
    {-0.9617986835296009, 0.3816816923272197}, {-0.8488643149584145, \
0.7478557941640123}}], 
  Line[{{-0.8378977330798763, 0.809044112594534}, {-0.8255142218178603, \
0.8728320775698134}, {-0.955896673706903, 0.44532374723565715}, 
    {-0.9590267513758853, 0.41280605266694914}, {-0.8378977330798763, \
0.809044112594534}}], 
  Line[{{-0.8255142218178603, 0.8728320775698134}, {-0.8122550000371969, \
0.9361441841071285}, {-0.9525452499365673, 0.47767060184981125}, 
    {-0.955896673706903, 0.44532374723565715}, {-0.8255142218178603, \
0.8728320775698134}}], 
  Line[{{-0.8122550000371969, 0.9361441841071285}, {-0.798699559354506, \
0.9965396214846562}, {-0.9491189533655575, 0.5085950701762803}, 
    {-0.9525452499365673, 0.47767060184981125}, {-0.8122550000371969, \
0.9361441841071285}}], 
  Line[{{-0.798699559354506, 0.9965396214846562}, {-0.7854403375738425, \
1.0520980143876313}, {-0.9457675295952219, 0.5371028573756125}, 
    {-0.9491189533655575, 0.5085950701762803}, {-0.798699559354506, \
0.9965396214846562}}], 
  Line[{{-0.7854403375738425, 1.0520980143876313}, {-0.7730568263118266, \
1.1013148858947226}, {-0.9426374519262395, 0.5624063276196131}, 
    {-0.9457675295952219, 0.5371028573756125}, {-0.7854403375738425, \
1.0520980143876313}}], 
  Line[{{-0.7730568263118266, 1.1013148858947226}, {-0.7620902444332882, \
1.143020501605286}, {-0.9398655197725241, 0.5838857533279131}, 
    {-0.9426374519262395, 0.5624063276196131}, {-0.7730568263118266, \
1.1013148858947226}}], 
  Line[{{-0.7620902444332882, 1.143020501605286}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
    {-0.9398655197725241, 0.5838857533279131}, {-0.7620902444332882, \
1.143020501605286}}], 
  Line[{{-0.7530198841898177, 1.1763209525760543}, {-0.7462421638484723, \
1.200556789468474}, {-0.9358597315848941, 0.6135770923916904}, 
    {-0.937572879870399, 0.6010618457721164}, {-0.7530198841898177, \
1.1763209525760543}}], 
  Line[{{-0.7462421638484723, 1.200556789468474}, {-0.7420533023112793, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
    {-0.9358597315848941, 0.6135770923916904}, {-0.7462421638484723, \
1.200556789468474}}], 
  Line[{{-0.7420533023112793, 1.2152748245287468}, {-0.7406363729278018, \
1.220209929227403}, {-0.9344428022014165, 0.6237350724532796}, 
    {-0.9348009477166834, 0.6211835161491779}, {-0.7420533023112793, \
1.2152748245287468}}], 
  Line[{{-0.7406363729278018, 1.220209929227403}, {-0.7420533023112793, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
    {-0.9344428022014165, 0.6237350724532796}, {-0.7406363729278018, \
1.220209929227403}}], 
  Line[{{-0.7420533023112793, 1.2152748245287468}, {-0.7462421638484722, \
1.200556789468474}, {-0.9358597315848941, 0.6135770923916904}, 
    {-0.9348009477166834, 0.6211835161491779}, {-0.7420533023112793, \
1.2152748245287468}}], 
  Line[{{-0.7462421638484722, 1.200556789468474}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
    {-0.9358597315848941, 0.6135770923916904}, {-0.7462421638484722, \
1.200556789468474}}], 
  Line[{{-0.7530198841898177, 1.1763209525760543}, {-0.7620902444332881, \
1.1430205016052863}, {-0.939865519772524, 0.5838857533279135}, 
    {-0.937572879870399, 0.6010618457721164}, {-0.7530198841898177, \
1.1763209525760543}}], 
  Line[{{-0.7620902444332881, 1.1430205016052863}, {-0.7730568263118266, \
1.1013148858947228}, {-0.9426374519262395, 0.5624063276196133}, 
    {-0.939865519772524, 0.5838857533279135}, {-0.7620902444332881, \
1.1430205016052863}}], 
  Line[{{-0.7730568263118266, 1.1013148858947228}, {-0.7854403375738425, \
1.0520980143876315}, {-0.9457675295952218, 0.5371028573756126}, 
    {-0.9426374519262395, 0.5624063276196133}, {-0.7730568263118266, \
1.1013148858947228}}], 
  Line[{{-0.7854403375738425, 1.0520980143876315}, {-0.7986995593545059, \
0.9965396214846567}, {-0.9491189533655575, 0.5085950701762803}, 
    {-0.9457675295952218, 0.5371028573756126}, {-0.7854403375738425, \
1.0520980143876315}}], 
  Line[{{-0.7986995593545059, 0.9965396214846567}, {-0.8122550000371966, \
0.9361441841071292}, {-0.9525452499365673, 0.4776706018498115}, 
    {-0.9491189533655575, 0.5085950701762803}, {-0.7986995593545059, \
0.9965396214846567}}], 
  Line[{{-0.8122550000371966, 0.9361441841071292}, {-0.8255142218178602, \
0.8728320775698137}, {-0.955896673706903, 0.44532374723565715}, 
    {-0.9525452499365673, 0.4776706018498115}, {-0.8122550000371966, \
0.9361441841071292}}], 
  Line[{{-0.8255142218178602, 0.8728320775698137}, {-0.837897733079876, \
0.8090441125945347}, {-0.9590267513758853, 0.41280605266694914}, 
    {-0.955896673706903, 0.44532374723565715}, {-0.8255142218178602, \
0.8728320775698137}}], 
  Line[{{-0.837897733079876, 0.8090441125945347}, {-0.8488643149584145, \
0.7478557941640125}, {-0.9617986835296009, 0.3816816923272197}, 
    {-0.9590267513758853, 0.41280605266694914}, {-0.837897733079876, \
0.8090441125945347}}], 
  Line[{{-0.8488643149584145, 0.7478557941640125}, {-0.857934675201885, \
0.6930472461935383}, {-0.9640913234317259, 0.3538602304100192}, 
    {-0.9617986835296009, 0.3816816923272197}, {-0.8488643149584145, \
0.7478557941640125}}], 
  Line[{{-0.857934675201885, 0.6930472461935383}, {-0.8647123955432304, \
0.6489952411032617}, {-0.9658044717172307, 0.33154008354139486}, 
    {-0.9640913234317259, 0.3538602304100192}, {-0.857934675201885, \
0.6930472461935383}}], 
  Line[{{-0.8647123955432304, 0.6489952411032617}, {-0.8689012570804234, \
0.6201700772082622}, {-0.9668632555854413, 0.31695593148714163}, 
    {-0.9658044717172307, 0.33154008354139486}, {-0.8647123955432304, \
0.6489952411032617}}], 
  Line[{{-0.8689012570804234, 0.6201700772082622}, {-0.8703181864639009, \
0.6101049646137015}, {-0.9672214011007083, 0.3118675362266397}, 
    {-0.9668632555854413, 0.31695593148714163}, {-0.8689012570804234, \
0.6201700772082622}}], 
  Line[{{-0.8703181864639009, 0.6101049646137015}, {-0.8689012570804235, \
0.6201700772082617}, {-0.9668632555854414, 0.31695593148714096}, 
    {-0.9672214011007083, 0.3118675362266397}, {-0.8703181864639009, \
0.6101049646137015}}], 
  Line[{{-0.8689012570804235, 0.6201700772082617}, {-0.8647123955432305, \
0.6489952411032612}, {-0.9658044717172307, 0.33154008354139486}, 
    {-0.9668632555854414, 0.31695593148714096}, {-0.8689012570804235, \
0.6201700772082617}}], 
  Line[{{-0.8647123955432305, 0.6489952411032612}, {-0.857934675201885, \
0.6930472461935381}, {-0.9640913234317259, 0.3538602304100192}, 
    {-0.9658044717172307, 0.33154008354139486}, {-0.8647123955432305, \
0.6489952411032612}}], 
  Line[{{-0.857934675201885, 0.6930472461935381}, {-0.8488643149584146, \
0.7478557941640119}, {-0.9617986835296009, 0.38168169232721944}, 
    {-0.9640913234317259, 0.3538602304100192}, {-0.857934675201885, \
0.6930472461935381}}], 
  Line[{{-0.8488643149584146, 0.7478557941640119}, {-0.8378977330798763, \
0.8090441125945338}, {-0.9590267513758853, 0.41280605266694886}, 
    {-0.9617986835296009, 0.38168169232721944}, {-0.8488643149584146, \
0.7478557941640119}}], 
  Line[{{-0.8378977330798763, 0.8090441125945338}, {-0.8255142218178603, \
0.8728320775698134}, {-0.955896673706903, 0.44532374723565715}, 
    {-0.9590267513758853, 0.41280605266694886}, {-0.8378977330798763, \
0.8090441125945338}}], 
  Line[{{-0.8255142218178603, 0.8728320775698134}, {-0.8122550000371969, \
0.9361441841071284}, {-0.9525452499365673, 0.47767060184981125}, 
    {-0.955896673706903, 0.44532374723565715}, {-0.8255142218178603, \
0.8728320775698134}}], 
  Line[{{-0.8122550000371969, 0.9361441841071284}, {-0.798699559354506, \
0.996539621484656}, {-0.9491189533655575, 0.50859507017628}, 
    {-0.9525452499365673, 0.47767060184981125}, {-0.8122550000371969, \
0.9361441841071284}}], 
  Line[{{-0.798699559354506, 0.996539621484656}, {-0.7854403375738425, \
1.0520980143876313}, {-0.9457675295952219, 0.5371028573756125}, 
    {-0.9491189533655575, 0.50859507017628}, {-0.798699559354506, \
0.996539621484656}}], 
  Line[{{-0.7854403375738425, 1.0520980143876313}, {-0.7730568263118266, \
1.1013148858947226}, {-0.9426374519262395, 0.5624063276196131}, 
    {-0.9457675295952219, 0.5371028573756125}, {-0.7854403375738425, \
1.0520980143876313}}], 
  Line[{{-0.7730568263118266, 1.1013148858947226}, {-0.7620902444332882, \
1.143020501605286}, {-0.939865519772524, 0.5838857533279135}, 
    {-0.9426374519262395, 0.5624063276196131}, {-0.7730568263118266, \
1.1013148858947226}}], 
  Line[{{-0.7620902444332882, 1.143020501605286}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
    {-0.939865519772524, 0.5838857533279135}, {-0.7620902444332882, \
1.143020501605286}}], 
  Line[{{-0.7530198841898177, 1.1763209525760543}, {-0.7462421638484723, \
1.200556789468474}, {-0.935859731584894, 0.6135770923916908}, 
    {-0.937572879870399, 0.6010618457721164}, {-0.7530198841898177, \
1.1763209525760543}}], 
  Line[{{-0.7462421638484723, 1.200556789468474}, {-0.7420533023112792, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
    {-0.935859731584894, 0.6135770923916908}, {-0.7462421638484723, \
1.200556789468474}}], 
  Line[{{-0.7420533023112792, 1.2152748245287468}, {-0.7406363729278018, \
1.220209929227403}, {-0.9344428022014165, 0.6237350724532796}, 
    {-0.9348009477166834, 0.6211835161491779}, {-0.7420533023112792, \
1.2152748245287468}}], 
  Line[{{-0.9344428022014165, 0.6237350724532796}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}, 
    {-0.9344428022014165, 0.6237350724532796}}], Line[{{-0.9348009477166834, \
0.6211835161491779}, {-0.9358597315848941, 0.6135770923916904}, 
    {-1., 0.}, {-1., 0.}, {-0.9348009477166834, 0.6211835161491779}}], 
  Line[{{-0.9358597315848941, 0.6135770923916904}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}, 
    {-0.9358597315848941, 0.6135770923916904}}], Line[{{-0.937572879870399, \
0.6010618457721164}, {-0.9398655197725241, 0.5838857533279131}, 
    {-1., 0.}, {-1., 0.}, {-0.937572879870399, 0.6010618457721164}}], 
  Line[{{-0.9398655197725241, 0.5838857533279131}, {-0.9426374519262395, \
0.5624063276196131}, {-1., 0.}, {-1., 0.}, 
    {-0.9398655197725241, 0.5838857533279131}}], Line[{{-0.9426374519262395, \
0.5624063276196131}, {-0.9457675295952219, 0.5371028573756125}, 
    {-1., 0.}, {-1., 0.}, {-0.9426374519262395, 0.5624063276196131}}], 
  Line[{{-0.9457675295952219, 0.5371028573756125}, {-0.9491189533655575, \
0.5085950701762803}, {-1., 0.}, {-1., 0.}, 
    {-0.9457675295952219, 0.5371028573756125}}], Line[{{-0.9491189533655575, \
0.5085950701762803}, {-0.9525452499365673, 0.47767060184981125}, 
    {-1., 0.}, {-1., 0.}, {-0.9491189533655575, 0.5085950701762803}}], 
  Line[{{-0.9525452499365673, 0.47767060184981125}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}, 
    {-0.9525452499365673, 0.47767060184981125}}], Line[{{-0.955896673706903, \
0.44532374723565715}, {-0.9590267513758853, 0.41280605266694914}, 
    {-1., 0.}, {-1., 0.}, {-0.955896673706903, 0.44532374723565715}}], 
  Line[{{-0.9590267513758853, 0.41280605266694914}, {-0.9617986835296009, \
0.3816816923272197}, {-1., 0.}, {-1., 0.}, 
    {-0.9590267513758853, 0.41280605266694914}}], Line[{{-0.9617986835296009, \
0.3816816923272197}, {-0.9640913234317259, 0.3538602304100192}, 
    {-1., 0.}, {-1., 0.}, {-0.9617986835296009, 0.3816816923272197}}], 
  Line[{{-0.9640913234317259, 0.3538602304100192}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}, 
    {-0.9640913234317259, 0.3538602304100192}}], Line[{{-0.9658044717172307, \
0.33154008354139486}, {-0.9668632555854414, 0.31695593148714096}, 
    {-1., 0.}, {-1., 0.}, {-0.9658044717172307, 0.33154008354139486}}], 
  Line[{{-0.9668632555854414, 0.31695593148714096}, {-0.9672214011007083, \
0.3118675362266397}, {-1., 0.}, {-1., 0.}, 
    {-0.9668632555854414, 0.31695593148714096}}], Line[{{-0.9672214011007083, \
0.3118675362266397}, {-0.9668632555854414, 0.31695593148714096}, 
    {-1., 0.}, {-1., 0.}, {-0.9672214011007083, 0.3118675362266397}}], 
  Line[{{-0.9668632555854414, 0.31695593148714096}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}, 
    {-0.9668632555854414, 0.31695593148714096}}], Line[{{-0.9658044717172307, \
0.33154008354139486}, {-0.9640913234317259, 0.3538602304100192}, 
    {-1., 0.}, {-1., 0.}, {-0.9658044717172307, 0.33154008354139486}}], 
  Line[{{-0.9640913234317259, 0.3538602304100192}, {-0.9617986835296009, \
0.3816816923272197}, {-1., 0.}, {-1., 0.}, 
    {-0.9640913234317259, 0.3538602304100192}}], Line[{{-0.9617986835296009, \
0.3816816923272197}, {-0.9590267513758853, 0.41280605266694914}, 
    {-1., 0.}, {-1., 0.}, {-0.9617986835296009, 0.3816816923272197}}], 
  Line[{{-0.9590267513758853, 0.41280605266694914}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}, 
    {-0.9590267513758853, 0.41280605266694914}}], Line[{{-0.955896673706903, \
0.44532374723565715}, {-0.9525452499365673, 0.47767060184981125}, 
    {-1., 0.}, {-1., 0.}, {-0.955896673706903, 0.44532374723565715}}], 
  Line[{{-0.9525452499365673, 0.47767060184981125}, {-0.9491189533655575, \
0.5085950701762803}, {-1., 0.}, {-1., 0.}, 
    {-0.9525452499365673, 0.47767060184981125}}], Line[{{-0.9491189533655575, \
0.5085950701762803}, {-0.9457675295952219, 0.5371028573756125}, 
    {-1., 0.}, {-1., 0.}, {-0.9491189533655575, 0.5085950701762803}}], 
  Line[{{-0.9457675295952219, 0.5371028573756125}, {-0.9426374519262395, \
0.5624063276196131}, {-1., 0.}, {-1., 0.}, 
    {-0.9457675295952219, 0.5371028573756125}}], Line[{{-0.9426374519262395, \
0.5624063276196131}, {-0.9398655197725241, 0.5838857533279131}, 
    {-1., 0.}, {-1., 0.}, {-0.9426374519262395, 0.5624063276196131}}], 
  Line[{{-0.9398655197725241, 0.5838857533279131}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}, 
    {-0.9398655197725241, 0.5838857533279131}}], Line[{{-0.937572879870399, \
0.6010618457721164}, {-0.9358597315848941, 0.6135770923916904}, 
    {-1., 0.}, {-1., 0.}, {-0.937572879870399, 0.6010618457721164}}], 
  Line[{{-0.9358597315848941, 0.6135770923916904}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}, 
    {-0.9358597315848941, 0.6135770923916904}}], Line[{{-0.9348009477166834, \
0.6211835161491779}, {-0.9344428022014165, 0.6237350724532796}, 
    {-1., 0.}, {-1., 0.}, {-0.9348009477166834, 0.6211835161491779}}], 
  Line[{{-0.9344428022014165, 0.6237350724532796}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}, 
    {-0.9344428022014165, 0.6237350724532796}}], Line[{{-0.9348009477166834, \
0.6211835161491779}, {-0.9358597315848941, 0.6135770923916904}, 
    {-1., 0.}, {-1., 0.}, {-0.9348009477166834, 0.6211835161491779}}], 
  Line[{{-0.9358597315848941, 0.6135770923916904}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}, 
    {-0.9358597315848941, 0.6135770923916904}}], Line[{{-0.937572879870399, \
0.6010618457721164}, {-0.939865519772524, 0.5838857533279135}, 
    {-1., 0.}, {-1., 0.}, {-0.937572879870399, 0.6010618457721164}}], 
  Line[{{-0.939865519772524, 0.5838857533279135}, {-0.9426374519262395, \
0.5624063276196133}, {-1., 0.}, {-1., 0.}, 
    {-0.939865519772524, 0.5838857533279135}}], Line[{{-0.9426374519262395, \
0.5624063276196133}, {-0.9457675295952218, 0.5371028573756126}, 
    {-1., 0.}, {-1., 0.}, {-0.9426374519262395, 0.5624063276196133}}], 
  Line[{{-0.9457675295952218, 0.5371028573756126}, {-0.9491189533655575, \
0.5085950701762803}, {-1., 0.}, {-1., 0.}, 
    {-0.9457675295952218, 0.5371028573756126}}], Line[{{-0.9491189533655575, \
0.5085950701762803}, {-0.9525452499365673, 0.4776706018498115}, 
    {-1., 0.}, {-1., 0.}, {-0.9491189533655575, 0.5085950701762803}}], 
  Line[{{-0.9525452499365673, 0.4776706018498115}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}, 
    {-0.9525452499365673, 0.4776706018498115}}], Line[{{-0.955896673706903, \
0.44532374723565715}, {-0.9590267513758853, 0.41280605266694914}, 
    {-1., 0.}, {-1., 0.}, {-0.955896673706903, 0.44532374723565715}}], 
  Line[{{-0.9590267513758853, 0.41280605266694914}, {-0.9617986835296009, \
0.3816816923272197}, {-1., 0.}, {-1., 0.}, 
    {-0.9590267513758853, 0.41280605266694914}}], Line[{{-0.9617986835296009, \
0.3816816923272197}, {-0.9640913234317259, 0.3538602304100192}, 
    {-1., 0.}, {-1., 0.}, {-0.9617986835296009, 0.3816816923272197}}], 
  Line[{{-0.9640913234317259, 0.3538602304100192}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}, 
    {-0.9640913234317259, 0.3538602304100192}}], Line[{{-0.9658044717172307, \
0.33154008354139486}, {-0.9668632555854413, 0.31695593148714163}, 
    {-1., 0.}, {-1., 0.}, {-0.9658044717172307, 0.33154008354139486}}], 
  Line[{{-0.9668632555854413, 0.31695593148714163}, {-0.9672214011007083, \
0.3118675362266397}, {-1., 0.}, {-1., 0.}, 
    {-0.9668632555854413, 0.31695593148714163}}], Line[{{-0.9672214011007083, \
0.3118675362266397}, {-0.9668632555854414, 0.31695593148714096}, 
    {-1., 0.}, {-1., 0.}, {-0.9672214011007083, 0.3118675362266397}}], 
  Line[{{-0.9668632555854414, 0.31695593148714096}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}, 
    {-0.9668632555854414, 0.31695593148714096}}], Line[{{-0.9658044717172307, \
0.33154008354139486}, {-0.9640913234317259, 0.3538602304100192}, 
    {-1., 0.}, {-1., 0.}, {-0.9658044717172307, 0.33154008354139486}}], 
  Line[{{-0.9640913234317259, 0.3538602304100192}, {-0.9617986835296009, \
0.38168169232721944}, {-1., 0.}, {-1., 0.}, 
    {-0.9640913234317259, 0.3538602304100192}}], Line[{{-0.9617986835296009, \
0.38168169232721944}, {-0.9590267513758853, 0.41280605266694886}, 
    {-1., 0.}, {-1., 0.}, {-0.9617986835296009, 0.38168169232721944}}], 
  Line[{{-0.9590267513758853, 0.41280605266694886}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}, 
    {-0.9590267513758853, 0.41280605266694886}}], Line[{{-0.955896673706903, \
0.44532374723565715}, {-0.9525452499365673, 0.47767060184981125}, 
    {-1., 0.}, {-1., 0.}, {-0.955896673706903, 0.44532374723565715}}], 
  Line[{{-0.9525452499365673, 0.47767060184981125}, {-0.9491189533655575, \
0.50859507017628}, {-1., 0.}, {-1., 0.}, 
    {-0.9525452499365673, 0.47767060184981125}}], Line[{{-0.9491189533655575, \
0.50859507017628}, {-0.9457675295952219, 0.5371028573756125}, 
    {-1., 0.}, {-1., 0.}, {-0.9491189533655575, 0.50859507017628}}], 
  Line[{{-0.9457675295952219, 0.5371028573756125}, {-0.9426374519262395, \
0.5624063276196131}, {-1., 0.}, {-1., 0.}, 
    {-0.9457675295952219, 0.5371028573756125}}], Line[{{-0.9426374519262395, \
0.5624063276196131}, {-0.939865519772524, 0.5838857533279135}, 
    {-1., 0.}, {-1., 0.}, {-0.9426374519262395, 0.5624063276196131}}], 
  Line[{{-0.939865519772524, 0.5838857533279135}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}, 
    {-0.939865519772524, 0.5838857533279135}}], Line[{{-0.937572879870399, \
0.6010618457721164}, {-0.935859731584894, 0.6135770923916908}, 
    {-1., 0.}, {-1., 0.}, {-0.937572879870399, 0.6010618457721164}}], 
  Line[{{-0.935859731584894, 0.6135770923916908}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}, 
    {-0.935859731584894, 0.6135770923916908}}], Line[{{-0.9348009477166834, \
0.6211835161491779}, {-0.9344428022014165, 0.6237350724532796}, 
    {-1., 0.}, {-1., 0.}, {-0.9348009477166834, 0.6211835161491779}}]}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell["\<\
quads = Map[   Flatten[#,1][[{1,2,4,3}]]  & ,Flatten[ Partition[ thenodes, \
{2,2}, {1,1}], 1]];
thefill = Map[ { RGBColor @@ Append[ MeanNode[#], 0.5] , Polygon[#]} &, quads \
];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
midp = Range[ 0.5/ npp , 1 , N[1/ npp] ];
midt = Range[ 0.5/ ntt , 1 , N[1/ ntt] ];
colorlist = Map[ CMYKColor[ #[[1]] , 0.5  , #[[2]] , 0.1 ] &, Flatten[ Outer[ \
List, midt,midp], 1] ]; \
\>", "Input"],

Cell["\<\
General::spell1: Possible spelling error: new symbol name \"midt\" is similar \
to existing symbol \"midp\". More\[Ellipsis]\
\>", "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
initialfill = ( Graphics /@ Transpose[ {colorlist,  Polygon /@ quads } ]);
initialmesh = Graphics /@ ( ClosedLine /@ quads) ;
Show[ initialfill, initialmesh ]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.303152 0.0147151 0.0936792 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.017 .5 .008 .1 k
.02381 .01472 m
.02381 .02453 L
.05556 .02453 L
.05556 .01472 L
F
.017 .5 .025 .1 k
.02381 .02453 m
.02381 .03434 L
.05556 .03434 L
.05556 .02453 L
F
.017 .5 .042 .1 k
.02381 .03434 m
.02381 .04415 L
.05556 .04415 L
.05556 .03434 L
F
.017 .5 .058 .1 k
.02381 .04415 m
.02381 .05396 L
.05556 .05396 L
.05556 .04415 L
F
.017 .5 .075 .1 k
.02381 .05396 m
.02381 .06377 L
.05556 .06377 L
.05556 .05396 L
F
.017 .5 .092 .1 k
.02381 .06377 m
.02381 .07358 L
.05556 .07358 L
.05556 .06377 L
F
.017 .5 .108 .1 k
.02381 .07358 m
.02381 .08339 L
.05556 .08339 L
.05556 .07358 L
F
.017 .5 .125 .1 k
.02381 .08339 m
.02381 .0932 L
.05556 .0932 L
.05556 .08339 L
F
.017 .5 .142 .1 k
.02381 .0932 m
.02381 .10301 L
.05556 .10301 L
.05556 .0932 L
F
.017 .5 .158 .1 k
.02381 .10301 m
.02381 .11282 L
.05556 .11282 L
.05556 .10301 L
F
.017 .5 .175 .1 k
.02381 .11282 m
.02381 .12263 L
.05556 .12263 L
.05556 .11282 L
F
.017 .5 .192 .1 k
.02381 .12263 m
.02381 .13244 L
.05556 .13244 L
.05556 .12263 L
F
.017 .5 .208 .1 k
.02381 .13244 m
.02381 .14225 L
.05556 .14225 L
.05556 .13244 L
F
.017 .5 .225 .1 k
.02381 .14225 m
.02381 .15206 L
.05556 .15206 L
.05556 .14225 L
F
.017 .5 .242 .1 k
.02381 .15206 m
.02381 .16187 L
.05556 .16187 L
.05556 .15206 L
F
.017 .5 .258 .1 k
.02381 .16187 m
.02381 .17168 L
.05556 .17168 L
.05556 .16187 L
F
.017 .5 .275 .1 k
.02381 .17168 m
.02381 .18149 L
.05556 .18149 L
.05556 .17168 L
F
.017 .5 .292 .1 k
.02381 .18149 m
.02381 .1913 L
.05556 .1913 L
.05556 .18149 L
F
.017 .5 .308 .1 k
.02381 .1913 m
.02381 .20111 L
.05556 .20111 L
.05556 .1913 L
F
.017 .5 .325 .1 k
.02381 .20111 m
.02381 .21092 L
.05556 .21092 L
.05556 .20111 L
F
.017 .5 .342 .1 k
.02381 .21092 m
.02381 .22073 L
.05556 .22073 L
.05556 .21092 L
F
.017 .5 .358 .1 k
.02381 .22073 m
.02381 .23054 L
.05556 .23054 L
.05556 .22073 L
F
.017 .5 .375 .1 k
.02381 .23054 m
.02381 .24035 L
.05556 .24035 L
.05556 .23054 L
F
.017 .5 .392 .1 k
.02381 .24035 m
.02381 .25016 L
.05556 .25016 L
.05556 .24035 L
F
.017 .5 .408 .1 k
.02381 .25016 m
.02381 .25997 L
.05556 .25997 L
.05556 .25016 L
F
.017 .5 .425 .1 k
.02381 .25997 m
.02381 .26978 L
.05556 .26978 L
.05556 .25997 L
F
.017 .5 .442 .1 k
.02381 .26978 m
.02381 .27959 L
.05556 .27959 L
.05556 .26978 L
F
.017 .5 .458 .1 k
.02381 .27959 m
.02381 .2894 L
.05556 .2894 L
.05556 .27959 L
F
.017 .5 .475 .1 k
.02381 .2894 m
.02381 .29921 L
.05556 .29921 L
.05556 .2894 L
F
.017 .5 .492 .1 k
.02381 .29921 m
.02381 .30902 L
.05556 .30902 L
.05556 .29921 L
F
.017 .5 .508 .1 k
.02381 .30902 m
.02381 .31883 L
.05556 .31883 L
.05556 .30902 L
F
.017 .5 .525 .1 k
.02381 .31883 m
.02381 .32864 L
.05556 .32864 L
.05556 .31883 L
F
.017 .5 .542 .1 k
.02381 .32864 m
.02381 .33845 L
.05556 .33845 L
.05556 .32864 L
F
.017 .5 .558 .1 k
.02381 .33845 m
.02381 .34826 L
.05556 .34826 L
.05556 .33845 L
F
.017 .5 .575 .1 k
.02381 .34826 m
.02381 .35807 L
.05556 .35807 L
.05556 .34826 L
F
.017 .5 .592 .1 k
.02381 .35807 m
.02381 .36788 L
.05556 .36788 L
.05556 .35807 L
F
.017 .5 .608 .1 k
.02381 .36788 m
.02381 .37769 L
.05556 .37769 L
.05556 .36788 L
F
.017 .5 .625 .1 k
.02381 .37769 m
.02381 .3875 L
.05556 .3875 L
.05556 .37769 L
F
.017 .5 .642 .1 k
.02381 .3875 m
.02381 .39731 L
.05556 .39731 L
.05556 .3875 L
F
.017 .5 .658 .1 k
.02381 .39731 m
.02381 .40712 L
.05556 .40712 L
.05556 .39731 L
F
.017 .5 .675 .1 k
.02381 .40712 m
.02381 .41693 L
.05556 .41693 L
.05556 .40712 L
F
.017 .5 .692 .1 k
.02381 .41693 m
.02381 .42674 L
.05556 .42674 L
.05556 .41693 L
F
.017 .5 .708 .1 k
.02381 .42674 m
.02381 .43655 L
.05556 .43655 L
.05556 .42674 L
F
.017 .5 .725 .1 k
.02381 .43655 m
.02381 .44636 L
.05556 .44636 L
.05556 .43655 L
F
.017 .5 .742 .1 k
.02381 .44636 m
.02381 .45617 L
.05556 .45617 L
.05556 .44636 L
F
.017 .5 .758 .1 k
.02381 .45617 m
.02381 .46598 L
.05556 .46598 L
.05556 .45617 L
F
.017 .5 .775 .1 k
.02381 .46598 m
.02381 .47579 L
.05556 .47579 L
.05556 .46598 L
F
.017 .5 .792 .1 k
.02381 .47579 m
.02381 .4856 L
.05556 .4856 L
.05556 .47579 L
F
.017 .5 .808 .1 k
.02381 .4856 m
.02381 .49541 L
.05556 .49541 L
.05556 .4856 L
F
.017 .5 .825 .1 k
.02381 .49541 m
.02381 .50522 L
.05556 .50522 L
.05556 .49541 L
F
.017 .5 .842 .1 k
.02381 .50522 m
.02381 .51503 L
.05556 .51503 L
.05556 .50522 L
F
.017 .5 .858 .1 k
.02381 .51503 m
.02381 .52484 L
.05556 .52484 L
.05556 .51503 L
F
.017 .5 .875 .1 k
.02381 .52484 m
.02381 .53465 L
.05556 .53465 L
.05556 .52484 L
F
.017 .5 .892 .1 k
.02381 .53465 m
.02381 .54446 L
.05556 .54446 L
.05556 .53465 L
F
.017 .5 .908 .1 k
.02381 .54446 m
.02381 .55427 L
.05556 .55427 L
.05556 .54446 L
F
.017 .5 .925 .1 k
.02381 .55427 m
.02381 .56408 L
.05556 .56408 L
.05556 .55427 L
F
.017 .5 .942 .1 k
.02381 .56408 m
.02381 .57389 L
.05556 .57389 L
.05556 .56408 L
F
.017 .5 .958 .1 k
.02381 .57389 m
.02381 .5837 L
.05556 .5837 L
.05556 .57389 L
F
.017 .5 .975 .1 k
.02381 .5837 m
.02381 .59351 L
.05556 .59351 L
.05556 .5837 L
F
.017 .5 .992 .1 k
.02381 .59351 m
.02381 .60332 L
.05556 .60332 L
.05556 .59351 L
F
.05 .5 .008 .1 k
.05556 .01472 m
.05556 .02453 L
.0873 .02453 L
.0873 .01472 L
F
.05 .5 .025 .1 k
.05556 .02453 m
.05556 .03434 L
.0873 .03434 L
.0873 .02453 L
F
.05 .5 .042 .1 k
.05556 .03434 m
.05556 .04415 L
.0873 .04415 L
.0873 .03434 L
F
.05 .5 .058 .1 k
.05556 .04415 m
.05556 .05396 L
.0873 .05396 L
.0873 .04415 L
F
.05 .5 .075 .1 k
.05556 .05396 m
.05556 .06377 L
.0873 .06377 L
.0873 .05396 L
F
.05 .5 .092 .1 k
.05556 .06377 m
.05556 .07358 L
.0873 .07358 L
.0873 .06377 L
F
.05 .5 .108 .1 k
.05556 .07358 m
.05556 .08339 L
.0873 .08339 L
.0873 .07358 L
F
.05 .5 .125 .1 k
.05556 .08339 m
.05556 .0932 L
.0873 .0932 L
.0873 .08339 L
F
.05 .5 .142 .1 k
.05556 .0932 m
.05556 .10301 L
.0873 .10301 L
.0873 .0932 L
F
.05 .5 .158 .1 k
.05556 .10301 m
.05556 .11282 L
.0873 .11282 L
.0873 .10301 L
F
.05 .5 .175 .1 k
.05556 .11282 m
.05556 .12263 L
.0873 .12263 L
.0873 .11282 L
F
.05 .5 .192 .1 k
.05556 .12263 m
.05556 .13244 L
.0873 .13244 L
.0873 .12263 L
F
.05 .5 .208 .1 k
.05556 .13244 m
.05556 .14225 L
.0873 .14225 L
.0873 .13244 L
F
.05 .5 .225 .1 k
.05556 .14225 m
.05556 .15206 L
.0873 .15206 L
.0873 .14225 L
F
.05 .5 .242 .1 k
.05556 .15206 m
.05556 .16187 L
.0873 .16187 L
.0873 .15206 L
F
.05 .5 .258 .1 k
.05556 .16187 m
.05556 .17168 L
.0873 .17168 L
.0873 .16187 L
F
.05 .5 .275 .1 k
.05556 .17168 m
.05556 .18149 L
.0873 .18149 L
.0873 .17168 L
F
.05 .5 .292 .1 k
.05556 .18149 m
.05556 .1913 L
.0873 .1913 L
.0873 .18149 L
F
.05 .5 .308 .1 k
.05556 .1913 m
.05556 .20111 L
.0873 .20111 L
.0873 .1913 L
F
.05 .5 .325 .1 k
.05556 .20111 m
.05556 .21092 L
.0873 .21092 L
.0873 .20111 L
F
.05 .5 .342 .1 k
.05556 .21092 m
.05556 .22073 L
.0873 .22073 L
.0873 .21092 L
F
.05 .5 .358 .1 k
.05556 .22073 m
.05556 .23054 L
.0873 .23054 L
.0873 .22073 L
F
.05 .5 .375 .1 k
.05556 .23054 m
.05556 .24035 L
.0873 .24035 L
.0873 .23054 L
F
.05 .5 .392 .1 k
.05556 .24035 m
.05556 .25016 L
.0873 .25016 L
.0873 .24035 L
F
.05 .5 .408 .1 k
.05556 .25016 m
.05556 .25997 L
.0873 .25997 L
.0873 .25016 L
F
.05 .5 .425 .1 k
.05556 .25997 m
.05556 .26978 L
.0873 .26978 L
.0873 .25997 L
F
.05 .5 .442 .1 k
.05556 .26978 m
.05556 .27959 L
.0873 .27959 L
.0873 .26978 L
F
.05 .5 .458 .1 k
.05556 .27959 m
.05556 .2894 L
.0873 .2894 L
.0873 .27959 L
F
.05 .5 .475 .1 k
.05556 .2894 m
.05556 .29921 L
.0873 .29921 L
.0873 .2894 L
F
.05 .5 .492 .1 k
.05556 .29921 m
.05556 .30902 L
.0873 .30902 L
.0873 .29921 L
F
.05 .5 .508 .1 k
.05556 .30902 m
.05556 .31883 L
.0873 .31883 L
.0873 .30902 L
F
.05 .5 .525 .1 k
.05556 .31883 m
.05556 .32864 L
.0873 .32864 L
.0873 .31883 L
F
.05 .5 .542 .1 k
.05556 .32864 m
.05556 .33845 L
.0873 .33845 L
.0873 .32864 L
F
.05 .5 .558 .1 k
.05556 .33845 m
.05556 .34826 L
.0873 .34826 L
.0873 .33845 L
F
.05 .5 .575 .1 k
.05556 .34826 m
.05556 .35807 L
.0873 .35807 L
.0873 .34826 L
F
.05 .5 .592 .1 k
.05556 .35807 m
.05556 .36788 L
.0873 .36788 L
.0873 .35807 L
F
.05 .5 .608 .1 k
.05556 .36788 m
.05556 .37769 L
.0873 .37769 L
.0873 .36788 L
F
.05 .5 .625 .1 k
.05556 .37769 m
.05556 .3875 L
.0873 .3875 L
.0873 .37769 L
F
.05 .5 .642 .1 k
.05556 .3875 m
.05556 .39731 L
.0873 .39731 L
.0873 .3875 L
F
.05 .5 .658 .1 k
.05556 .39731 m
.05556 .40712 L
.0873 .40712 L
.0873 .39731 L
F
.05 .5 .675 .1 k
.05556 .40712 m
.05556 .41693 L
.0873 .41693 L
.0873 .40712 L
F
.05 .5 .692 .1 k
.05556 .41693 m
.05556 .42674 L
.0873 .42674 L
.0873 .41693 L
F
.05 .5 .708 .1 k
.05556 .42674 m
.05556 .43655 L
.0873 .43655 L
.0873 .42674 L
F
.05 .5 .725 .1 k
.05556 .43655 m
.05556 .44636 L
.0873 .44636 L
.0873 .43655 L
F
.05 .5 .742 .1 k
.05556 .44636 m
.05556 .45617 L
.0873 .45617 L
.0873 .44636 L
F
.05 .5 .758 .1 k
.05556 .45617 m
.05556 .46598 L
.0873 .46598 L
.0873 .45617 L
F
.05 .5 .775 .1 k
.05556 .46598 m
.05556 .47579 L
.0873 .47579 L
.0873 .46598 L
F
.05 .5 .792 .1 k
.05556 .47579 m
.05556 .4856 L
.0873 .4856 L
.0873 .47579 L
F
.05 .5 .808 .1 k
.05556 .4856 m
.05556 .49541 L
.0873 .49541 L
.0873 .4856 L
F
.05 .5 .825 .1 k
.05556 .49541 m
.05556 .50522 L
.0873 .50522 L
.0873 .49541 L
F
.05 .5 .842 .1 k
.05556 .50522 m
.05556 .51503 L
.0873 .51503 L
.0873 .50522 L
F
.05 .5 .858 .1 k
.05556 .51503 m
.05556 .52484 L
.0873 .52484 L
.0873 .51503 L
F
.05 .5 .875 .1 k
.05556 .52484 m
.05556 .53465 L
.0873 .53465 L
.0873 .52484 L
F
.05 .5 .892 .1 k
.05556 .53465 m
.05556 .54446 L
.0873 .54446 L
.0873 .53465 L
F
.05 .5 .908 .1 k
.05556 .54446 m
.05556 .55427 L
.0873 .55427 L
.0873 .54446 L
F
.05 .5 .925 .1 k
.05556 .55427 m
.05556 .56408 L
.0873 .56408 L
.0873 .55427 L
F
.05 .5 .942 .1 k
.05556 .56408 m
.05556 .57389 L
.0873 .57389 L
.0873 .56408 L
F
.05 .5 .958 .1 k
.05556 .57389 m
.05556 .5837 L
.0873 .5837 L
.0873 .57389 L
F
.05 .5 .975 .1 k
.05556 .5837 m
.05556 .59351 L
.0873 .59351 L
.0873 .5837 L
F
.05 .5 .992 .1 k
.05556 .59351 m
.05556 .60332 L
.0873 .60332 L
.0873 .59351 L
F
.083 .5 .008 .1 k
.0873 .01472 m
.0873 .02453 L
.11905 .02453 L
.11905 .01472 L
F
.083 .5 .025 .1 k
.0873 .02453 m
.0873 .03434 L
.11905 .03434 L
.11905 .02453 L
F
.083 .5 .042 .1 k
.0873 .03434 m
.0873 .04415 L
.11905 .04415 L
.11905 .03434 L
F
.083 .5 .058 .1 k
.0873 .04415 m
.0873 .05396 L
.11905 .05396 L
.11905 .04415 L
F
.083 .5 .075 .1 k
.0873 .05396 m
.0873 .06377 L
.11905 .06377 L
.11905 .05396 L
F
.083 .5 .092 .1 k
.0873 .06377 m
.0873 .07358 L
.11905 .07358 L
.11905 .06377 L
F
.083 .5 .108 .1 k
.0873 .07358 m
.0873 .08339 L
.11905 .08339 L
.11905 .07358 L
F
.083 .5 .125 .1 k
.0873 .08339 m
.0873 .0932 L
.11905 .0932 L
.11905 .08339 L
F
.083 .5 .142 .1 k
.0873 .0932 m
.0873 .10301 L
.11905 .10301 L
.11905 .0932 L
F
.083 .5 .158 .1 k
.0873 .10301 m
.0873 .11282 L
.11905 .11282 L
.11905 .10301 L
F
.083 .5 .175 .1 k
.0873 .11282 m
.0873 .12263 L
.11905 .12263 L
.11905 .11282 L
F
.083 .5 .192 .1 k
.0873 .12263 m
.0873 .13244 L
.11905 .13244 L
.11905 .12263 L
F
.083 .5 .208 .1 k
.0873 .13244 m
.0873 .14225 L
.11905 .14225 L
.11905 .13244 L
F
.083 .5 .225 .1 k
.0873 .14225 m
.0873 .15206 L
.11905 .15206 L
.11905 .14225 L
F
.083 .5 .242 .1 k
.0873 .15206 m
.0873 .16187 L
.11905 .16187 L
.11905 .15206 L
F
.083 .5 .258 .1 k
.0873 .16187 m
.0873 .17168 L
.11905 .17168 L
.11905 .16187 L
F
.083 .5 .275 .1 k
.0873 .17168 m
.0873 .18149 L
.11905 .18149 L
.11905 .17168 L
F
.083 .5 .292 .1 k
.0873 .18149 m
.0873 .1913 L
.11905 .1913 L
.11905 .18149 L
F
.083 .5 .308 .1 k
.0873 .1913 m
.0873 .20111 L
.11905 .20111 L
.11905 .1913 L
F
.083 .5 .325 .1 k
.0873 .20111 m
.0873 .21092 L
.11905 .21092 L
.11905 .20111 L
F
.083 .5 .342 .1 k
.0873 .21092 m
.0873 .22073 L
.11905 .22073 L
.11905 .21092 L
F
.083 .5 .358 .1 k
.0873 .22073 m
.0873 .23054 L
.11905 .23054 L
.11905 .22073 L
F
.083 .5 .375 .1 k
.0873 .23054 m
.0873 .24035 L
.11905 .24035 L
.11905 .23054 L
F
.083 .5 .392 .1 k
.0873 .24035 m
.0873 .25016 L
.11905 .25016 L
.11905 .24035 L
F
.083 .5 .408 .1 k
.0873 .25016 m
.0873 .25997 L
.11905 .25997 L
.11905 .25016 L
F
.083 .5 .425 .1 k
.0873 .25997 m
.0873 .26978 L
.11905 .26978 L
.11905 .25997 L
F
.083 .5 .442 .1 k
.0873 .26978 m
.0873 .27959 L
.11905 .27959 L
.11905 .26978 L
F
.083 .5 .458 .1 k
.0873 .27959 m
.0873 .2894 L
.11905 .2894 L
.11905 .27959 L
F
.083 .5 .475 .1 k
.0873 .2894 m
.0873 .29921 L
.11905 .29921 L
.11905 .2894 L
F
.083 .5 .492 .1 k
.0873 .29921 m
.0873 .30902 L
.11905 .30902 L
.11905 .29921 L
F
.083 .5 .508 .1 k
.0873 .30902 m
.0873 .31883 L
.11905 .31883 L
.11905 .30902 L
F
.083 .5 .525 .1 k
.0873 .31883 m
.0873 .32864 L
.11905 .32864 L
.11905 .31883 L
F
.083 .5 .542 .1 k
.0873 .32864 m
.0873 .33845 L
.11905 .33845 L
.11905 .32864 L
F
.083 .5 .558 .1 k
.0873 .33845 m
.0873 .34826 L
.11905 .34826 L
.11905 .33845 L
F
.083 .5 .575 .1 k
.0873 .34826 m
.0873 .35807 L
.11905 .35807 L
.11905 .34826 L
F
.083 .5 .592 .1 k
.0873 .35807 m
.0873 .36788 L
.11905 .36788 L
.11905 .35807 L
F
.083 .5 .608 .1 k
.0873 .36788 m
.0873 .37769 L
.11905 .37769 L
.11905 .36788 L
F
.083 .5 .625 .1 k
.0873 .37769 m
.0873 .3875 L
.11905 .3875 L
.11905 .37769 L
F
.083 .5 .642 .1 k
.0873 .3875 m
.0873 .39731 L
.11905 .39731 L
.11905 .3875 L
F
.083 .5 .658 .1 k
.0873 .39731 m
.0873 .40712 L
.11905 .40712 L
.11905 .39731 L
F
.083 .5 .675 .1 k
.0873 .40712 m
.0873 .41693 L
.11905 .41693 L
.11905 .40712 L
F
.083 .5 .692 .1 k
.0873 .41693 m
.0873 .42674 L
.11905 .42674 L
.11905 .41693 L
F
.083 .5 .708 .1 k
.0873 .42674 m
.0873 .43655 L
.11905 .43655 L
.11905 .42674 L
F
.083 .5 .725 .1 k
.0873 .43655 m
.0873 .44636 L
.11905 .44636 L
.11905 .43655 L
F
.083 .5 .742 .1 k
.0873 .44636 m
.0873 .45617 L
.11905 .45617 L
.11905 .44636 L
F
.083 .5 .758 .1 k
.0873 .45617 m
.0873 .46598 L
.11905 .46598 L
.11905 .45617 L
F
.083 .5 .775 .1 k
.0873 .46598 m
.0873 .47579 L
.11905 .47579 L
.11905 .46598 L
F
.083 .5 .792 .1 k
.0873 .47579 m
.0873 .4856 L
.11905 .4856 L
.11905 .47579 L
F
.083 .5 .808 .1 k
.0873 .4856 m
.0873 .49541 L
.11905 .49541 L
.11905 .4856 L
F
.083 .5 .825 .1 k
.0873 .49541 m
.0873 .50522 L
.11905 .50522 L
.11905 .49541 L
F
.083 .5 .842 .1 k
.0873 .50522 m
.0873 .51503 L
.11905 .51503 L
.11905 .50522 L
F
.083 .5 .858 .1 k
.0873 .51503 m
.0873 .52484 L
.11905 .52484 L
.11905 .51503 L
F
.083 .5 .875 .1 k
.0873 .52484 m
.0873 .53465 L
.11905 .53465 L
.11905 .52484 L
F
.083 .5 .892 .1 k
.0873 .53465 m
.0873 .54446 L
.11905 .54446 L
.11905 .53465 L
F
.083 .5 .908 .1 k
.0873 .54446 m
.0873 .55427 L
.11905 .55427 L
.11905 .54446 L
F
.083 .5 .925 .1 k
.0873 .55427 m
.0873 .56408 L
.11905 .56408 L
.11905 .55427 L
F
.083 .5 .942 .1 k
.0873 .56408 m
.0873 .57389 L
.11905 .57389 L
.11905 .56408 L
F
.083 .5 .958 .1 k
.0873 .57389 m
.0873 .5837 L
.11905 .5837 L
.11905 .57389 L
F
.083 .5 .975 .1 k
.0873 .5837 m
.0873 .59351 L
.11905 .59351 L
.11905 .5837 L
F
.083 .5 .992 .1 k
.0873 .59351 m
.0873 .60332 L
.11905 .60332 L
.11905 .59351 L
F
.117 .5 .008 .1 k
.11905 .01472 m
.11905 .02453 L
.15079 .02453 L
.15079 .01472 L
F
.117 .5 .025 .1 k
.11905 .02453 m
.11905 .03434 L
.15079 .03434 L
.15079 .02453 L
F
.117 .5 .042 .1 k
.11905 .03434 m
.11905 .04415 L
.15079 .04415 L
.15079 .03434 L
F
.117 .5 .058 .1 k
.11905 .04415 m
.11905 .05396 L
.15079 .05396 L
.15079 .04415 L
F
.117 .5 .075 .1 k
.11905 .05396 m
.11905 .06377 L
.15079 .06377 L
.15079 .05396 L
F
.117 .5 .092 .1 k
.11905 .06377 m
.11905 .07358 L
.15079 .07358 L
.15079 .06377 L
F
.117 .5 .108 .1 k
.11905 .07358 m
.11905 .08339 L
.15079 .08339 L
.15079 .07358 L
F
.117 .5 .125 .1 k
.11905 .08339 m
.11905 .0932 L
.15079 .0932 L
.15079 .08339 L
F
.117 .5 .142 .1 k
.11905 .0932 m
.11905 .10301 L
.15079 .10301 L
.15079 .0932 L
F
.117 .5 .158 .1 k
.11905 .10301 m
.11905 .11282 L
.15079 .11282 L
.15079 .10301 L
F
.117 .5 .175 .1 k
.11905 .11282 m
.11905 .12263 L
.15079 .12263 L
.15079 .11282 L
F
.117 .5 .192 .1 k
.11905 .12263 m
.11905 .13244 L
.15079 .13244 L
.15079 .12263 L
F
.117 .5 .208 .1 k
.11905 .13244 m
.11905 .14225 L
.15079 .14225 L
.15079 .13244 L
F
.117 .5 .225 .1 k
.11905 .14225 m
.11905 .15206 L
.15079 .15206 L
.15079 .14225 L
F
.117 .5 .242 .1 k
.11905 .15206 m
.11905 .16187 L
.15079 .16187 L
.15079 .15206 L
F
.117 .5 .258 .1 k
.11905 .16187 m
.11905 .17168 L
.15079 .17168 L
.15079 .16187 L
F
.117 .5 .275 .1 k
.11905 .17168 m
.11905 .18149 L
.15079 .18149 L
.15079 .17168 L
F
.117 .5 .292 .1 k
.11905 .18149 m
.11905 .1913 L
.15079 .1913 L
.15079 .18149 L
F
.117 .5 .308 .1 k
.11905 .1913 m
.11905 .20111 L
.15079 .20111 L
.15079 .1913 L
F
.117 .5 .325 .1 k
.11905 .20111 m
.11905 .21092 L
.15079 .21092 L
.15079 .20111 L
F
.117 .5 .342 .1 k
.11905 .21092 m
.11905 .22073 L
.15079 .22073 L
.15079 .21092 L
F
.117 .5 .358 .1 k
.11905 .22073 m
.11905 .23054 L
.15079 .23054 L
.15079 .22073 L
F
.117 .5 .375 .1 k
.11905 .23054 m
.11905 .24035 L
.15079 .24035 L
.15079 .23054 L
F
.117 .5 .392 .1 k
.11905 .24035 m
.11905 .25016 L
.15079 .25016 L
.15079 .24035 L
F
.117 .5 .408 .1 k
.11905 .25016 m
.11905 .25997 L
.15079 .25997 L
.15079 .25016 L
F
.117 .5 .425 .1 k
.11905 .25997 m
.11905 .26978 L
.15079 .26978 L
.15079 .25997 L
F
.117 .5 .442 .1 k
.11905 .26978 m
.11905 .27959 L
.15079 .27959 L
.15079 .26978 L
F
.117 .5 .458 .1 k
.11905 .27959 m
.11905 .2894 L
.15079 .2894 L
.15079 .27959 L
F
.117 .5 .475 .1 k
.11905 .2894 m
.11905 .29921 L
.15079 .29921 L
.15079 .2894 L
F
.117 .5 .492 .1 k
.11905 .29921 m
.11905 .30902 L
.15079 .30902 L
.15079 .29921 L
F
.117 .5 .508 .1 k
.11905 .30902 m
.11905 .31883 L
.15079 .31883 L
.15079 .30902 L
F
.117 .5 .525 .1 k
.11905 .31883 m
.11905 .32864 L
.15079 .32864 L
.15079 .31883 L
F
.117 .5 .542 .1 k
.11905 .32864 m
.11905 .33845 L
.15079 .33845 L
.15079 .32864 L
F
.117 .5 .558 .1 k
.11905 .33845 m
.11905 .34826 L
.15079 .34826 L
.15079 .33845 L
F
.117 .5 .575 .1 k
.11905 .34826 m
.11905 .35807 L
.15079 .35807 L
.15079 .34826 L
F
.117 .5 .592 .1 k
.11905 .35807 m
.11905 .36788 L
.15079 .36788 L
.15079 .35807 L
F
.117 .5 .608 .1 k
.11905 .36788 m
.11905 .37769 L
.15079 .37769 L
.15079 .36788 L
F
.117 .5 .625 .1 k
.11905 .37769 m
.11905 .3875 L
.15079 .3875 L
.15079 .37769 L
F
.117 .5 .642 .1 k
.11905 .3875 m
.11905 .39731 L
.15079 .39731 L
.15079 .3875 L
F
.117 .5 .658 .1 k
.11905 .39731 m
.11905 .40712 L
.15079 .40712 L
.15079 .39731 L
F
.117 .5 .675 .1 k
.11905 .40712 m
.11905 .41693 L
.15079 .41693 L
.15079 .40712 L
F
.117 .5 .692 .1 k
.11905 .41693 m
.11905 .42674 L
.15079 .42674 L
.15079 .41693 L
F
.117 .5 .708 .1 k
.11905 .42674 m
.11905 .43655 L
.15079 .43655 L
.15079 .42674 L
F
.117 .5 .725 .1 k
.11905 .43655 m
.11905 .44636 L
.15079 .44636 L
.15079 .43655 L
F
.117 .5 .742 .1 k
.11905 .44636 m
.11905 .45617 L
.15079 .45617 L
.15079 .44636 L
F
.117 .5 .758 .1 k
.11905 .45617 m
.11905 .46598 L
.15079 .46598 L
.15079 .45617 L
F
.117 .5 .775 .1 k
.11905 .46598 m
.11905 .47579 L
.15079 .47579 L
.15079 .46598 L
F
.117 .5 .792 .1 k
.11905 .47579 m
.11905 .4856 L
.15079 .4856 L
.15079 .47579 L
F
.117 .5 .808 .1 k
.11905 .4856 m
.11905 .49541 L
.15079 .49541 L
.15079 .4856 L
F
.117 .5 .825 .1 k
.11905 .49541 m
.11905 .50522 L
.15079 .50522 L
.15079 .49541 L
F
.117 .5 .842 .1 k
.11905 .50522 m
.11905 .51503 L
.15079 .51503 L
.15079 .50522 L
F
.117 .5 .858 .1 k
.11905 .51503 m
.11905 .52484 L
.15079 .52484 L
.15079 .51503 L
F
.117 .5 .875 .1 k
.11905 .52484 m
.11905 .53465 L
.15079 .53465 L
.15079 .52484 L
F
.117 .5 .892 .1 k
.11905 .53465 m
.11905 .54446 L
.15079 .54446 L
.15079 .53465 L
F
.117 .5 .908 .1 k
.11905 .54446 m
.11905 .55427 L
.15079 .55427 L
.15079 .54446 L
F
.117 .5 .925 .1 k
.11905 .55427 m
.11905 .56408 L
.15079 .56408 L
.15079 .55427 L
F
.117 .5 .942 .1 k
.11905 .56408 m
.11905 .57389 L
.15079 .57389 L
.15079 .56408 L
F
.117 .5 .958 .1 k
.11905 .57389 m
.11905 .5837 L
.15079 .5837 L
.15079 .57389 L
F
.117 .5 .975 .1 k
.11905 .5837 m
.11905 .59351 L
.15079 .59351 L
.15079 .5837 L
F
.117 .5 .992 .1 k
.11905 .59351 m
.11905 .60332 L
.15079 .60332 L
.15079 .59351 L
F
.15 .5 .008 .1 k
.15079 .01472 m
.15079 .02453 L
.18254 .02453 L
.18254 .01472 L
F
.15 .5 .025 .1 k
.15079 .02453 m
.15079 .03434 L
.18254 .03434 L
.18254 .02453 L
F
.15 .5 .042 .1 k
.15079 .03434 m
.15079 .04415 L
.18254 .04415 L
.18254 .03434 L
F
.15 .5 .058 .1 k
.15079 .04415 m
.15079 .05396 L
.18254 .05396 L
.18254 .04415 L
F
.15 .5 .075 .1 k
.15079 .05396 m
.15079 .06377 L
.18254 .06377 L
.18254 .05396 L
F
.15 .5 .092 .1 k
.15079 .06377 m
.15079 .07358 L
.18254 .07358 L
.18254 .06377 L
F
.15 .5 .108 .1 k
.15079 .07358 m
.15079 .08339 L
.18254 .08339 L
.18254 .07358 L
F
.15 .5 .125 .1 k
.15079 .08339 m
.15079 .0932 L
.18254 .0932 L
.18254 .08339 L
F
.15 .5 .142 .1 k
.15079 .0932 m
.15079 .10301 L
.18254 .10301 L
.18254 .0932 L
F
.15 .5 .158 .1 k
.15079 .10301 m
.15079 .11282 L
.18254 .11282 L
.18254 .10301 L
F
.15 .5 .175 .1 k
.15079 .11282 m
.15079 .12263 L
.18254 .12263 L
.18254 .11282 L
F
.15 .5 .192 .1 k
.15079 .12263 m
.15079 .13244 L
.18254 .13244 L
.18254 .12263 L
F
.15 .5 .208 .1 k
.15079 .13244 m
.15079 .14225 L
.18254 .14225 L
.18254 .13244 L
F
.15 .5 .225 .1 k
.15079 .14225 m
.15079 .15206 L
.18254 .15206 L
.18254 .14225 L
F
.15 .5 .242 .1 k
.15079 .15206 m
.15079 .16187 L
.18254 .16187 L
.18254 .15206 L
F
.15 .5 .258 .1 k
.15079 .16187 m
.15079 .17168 L
.18254 .17168 L
.18254 .16187 L
F
.15 .5 .275 .1 k
.15079 .17168 m
.15079 .18149 L
.18254 .18149 L
.18254 .17168 L
F
.15 .5 .292 .1 k
.15079 .18149 m
.15079 .1913 L
.18254 .1913 L
.18254 .18149 L
F
.15 .5 .308 .1 k
.15079 .1913 m
.15079 .20111 L
.18254 .20111 L
.18254 .1913 L
F
.15 .5 .325 .1 k
.15079 .20111 m
.15079 .21092 L
.18254 .21092 L
.18254 .20111 L
F
.15 .5 .342 .1 k
.15079 .21092 m
.15079 .22073 L
.18254 .22073 L
.18254 .21092 L
F
.15 .5 .358 .1 k
.15079 .22073 m
.15079 .23054 L
.18254 .23054 L
.18254 .22073 L
F
.15 .5 .375 .1 k
.15079 .23054 m
.15079 .24035 L
.18254 .24035 L
.18254 .23054 L
F
.15 .5 .392 .1 k
.15079 .24035 m
.15079 .25016 L
.18254 .25016 L
.18254 .24035 L
F
.15 .5 .408 .1 k
.15079 .25016 m
.15079 .25997 L
.18254 .25997 L
.18254 .25016 L
F
.15 .5 .425 .1 k
.15079 .25997 m
.15079 .26978 L
.18254 .26978 L
.18254 .25997 L
F
.15 .5 .442 .1 k
.15079 .26978 m
.15079 .27959 L
.18254 .27959 L
.18254 .26978 L
F
.15 .5 .458 .1 k
.15079 .27959 m
.15079 .2894 L
.18254 .2894 L
.18254 .27959 L
F
.15 .5 .475 .1 k
.15079 .2894 m
.15079 .29921 L
.18254 .29921 L
.18254 .2894 L
F
.15 .5 .492 .1 k
.15079 .29921 m
.15079 .30902 L
.18254 .30902 L
.18254 .29921 L
F
.15 .5 .508 .1 k
.15079 .30902 m
.15079 .31883 L
.18254 .31883 L
.18254 .30902 L
F
.15 .5 .525 .1 k
.15079 .31883 m
.15079 .32864 L
.18254 .32864 L
.18254 .31883 L
F
.15 .5 .542 .1 k
.15079 .32864 m
.15079 .33845 L
.18254 .33845 L
.18254 .32864 L
F
.15 .5 .558 .1 k
.15079 .33845 m
.15079 .34826 L
.18254 .34826 L
.18254 .33845 L
F
.15 .5 .575 .1 k
.15079 .34826 m
.15079 .35807 L
.18254 .35807 L
.18254 .34826 L
F
.15 .5 .592 .1 k
.15079 .35807 m
.15079 .36788 L
.18254 .36788 L
.18254 .35807 L
F
.15 .5 .608 .1 k
.15079 .36788 m
.15079 .37769 L
.18254 .37769 L
.18254 .36788 L
F
.15 .5 .625 .1 k
.15079 .37769 m
.15079 .3875 L
.18254 .3875 L
.18254 .37769 L
F
.15 .5 .642 .1 k
.15079 .3875 m
.15079 .39731 L
.18254 .39731 L
.18254 .3875 L
F
.15 .5 .658 .1 k
.15079 .39731 m
.15079 .40712 L
.18254 .40712 L
.18254 .39731 L
F
.15 .5 .675 .1 k
.15079 .40712 m
.15079 .41693 L
.18254 .41693 L
.18254 .40712 L
F
.15 .5 .692 .1 k
.15079 .41693 m
.15079 .42674 L
.18254 .42674 L
.18254 .41693 L
F
.15 .5 .708 .1 k
.15079 .42674 m
.15079 .43655 L
.18254 .43655 L
.18254 .42674 L
F
.15 .5 .725 .1 k
.15079 .43655 m
.15079 .44636 L
.18254 .44636 L
.18254 .43655 L
F
.15 .5 .742 .1 k
.15079 .44636 m
.15079 .45617 L
.18254 .45617 L
.18254 .44636 L
F
.15 .5 .758 .1 k
.15079 .45617 m
.15079 .46598 L
.18254 .46598 L
.18254 .45617 L
F
.15 .5 .775 .1 k
.15079 .46598 m
.15079 .47579 L
.18254 .47579 L
.18254 .46598 L
F
.15 .5 .792 .1 k
.15079 .47579 m
.15079 .4856 L
.18254 .4856 L
.18254 .47579 L
F
.15 .5 .808 .1 k
.15079 .4856 m
.15079 .49541 L
.18254 .49541 L
.18254 .4856 L
F
.15 .5 .825 .1 k
.15079 .49541 m
.15079 .50522 L
.18254 .50522 L
.18254 .49541 L
F
.15 .5 .842 .1 k
.15079 .50522 m
.15079 .51503 L
.18254 .51503 L
.18254 .50522 L
F
.15 .5 .858 .1 k
.15079 .51503 m
.15079 .52484 L
.18254 .52484 L
.18254 .51503 L
F
.15 .5 .875 .1 k
.15079 .52484 m
.15079 .53465 L
.18254 .53465 L
.18254 .52484 L
F
.15 .5 .892 .1 k
.15079 .53465 m
.15079 .54446 L
.18254 .54446 L
.18254 .53465 L
F
.15 .5 .908 .1 k
.15079 .54446 m
.15079 .55427 L
.18254 .55427 L
.18254 .54446 L
F
.15 .5 .925 .1 k
.15079 .55427 m
.15079 .56408 L
.18254 .56408 L
.18254 .55427 L
F
.15 .5 .942 .1 k
.15079 .56408 m
.15079 .57389 L
.18254 .57389 L
.18254 .56408 L
F
.15 .5 .958 .1 k
.15079 .57389 m
.15079 .5837 L
.18254 .5837 L
.18254 .57389 L
F
.15 .5 .975 .1 k
.15079 .5837 m
.15079 .59351 L
.18254 .59351 L
.18254 .5837 L
F
.15 .5 .992 .1 k
.15079 .59351 m
.15079 .60332 L
.18254 .60332 L
.18254 .59351 L
F
.183 .5 .008 .1 k
.18254 .01472 m
.18254 .02453 L
.21429 .02453 L
.21429 .01472 L
F
.183 .5 .025 .1 k
.18254 .02453 m
.18254 .03434 L
.21429 .03434 L
.21429 .02453 L
F
.183 .5 .042 .1 k
.18254 .03434 m
.18254 .04415 L
.21429 .04415 L
.21429 .03434 L
F
.183 .5 .058 .1 k
.18254 .04415 m
.18254 .05396 L
.21429 .05396 L
.21429 .04415 L
F
.183 .5 .075 .1 k
.18254 .05396 m
.18254 .06377 L
.21429 .06377 L
.21429 .05396 L
F
.183 .5 .092 .1 k
.18254 .06377 m
.18254 .07358 L
.21429 .07358 L
.21429 .06377 L
F
.183 .5 .108 .1 k
.18254 .07358 m
.18254 .08339 L
.21429 .08339 L
.21429 .07358 L
F
.183 .5 .125 .1 k
.18254 .08339 m
.18254 .0932 L
.21429 .0932 L
.21429 .08339 L
F
.183 .5 .142 .1 k
.18254 .0932 m
.18254 .10301 L
.21429 .10301 L
.21429 .0932 L
F
.183 .5 .158 .1 k
.18254 .10301 m
.18254 .11282 L
.21429 .11282 L
.21429 .10301 L
F
.183 .5 .175 .1 k
.18254 .11282 m
.18254 .12263 L
.21429 .12263 L
.21429 .11282 L
F
.183 .5 .192 .1 k
.18254 .12263 m
.18254 .13244 L
.21429 .13244 L
.21429 .12263 L
F
.183 .5 .208 .1 k
.18254 .13244 m
.18254 .14225 L
.21429 .14225 L
.21429 .13244 L
F
.183 .5 .225 .1 k
.18254 .14225 m
.18254 .15206 L
.21429 .15206 L
.21429 .14225 L
F
.183 .5 .242 .1 k
.18254 .15206 m
.18254 .16187 L
.21429 .16187 L
.21429 .15206 L
F
.183 .5 .258 .1 k
.18254 .16187 m
.18254 .17168 L
.21429 .17168 L
.21429 .16187 L
F
.183 .5 .275 .1 k
.18254 .17168 m
.18254 .18149 L
.21429 .18149 L
.21429 .17168 L
F
.183 .5 .292 .1 k
.18254 .18149 m
.18254 .1913 L
.21429 .1913 L
.21429 .18149 L
F
.183 .5 .308 .1 k
.18254 .1913 m
.18254 .20111 L
.21429 .20111 L
.21429 .1913 L
F
.183 .5 .325 .1 k
.18254 .20111 m
.18254 .21092 L
.21429 .21092 L
.21429 .20111 L
F
.183 .5 .342 .1 k
.18254 .21092 m
.18254 .22073 L
.21429 .22073 L
.21429 .21092 L
F
.183 .5 .358 .1 k
.18254 .22073 m
.18254 .23054 L
.21429 .23054 L
.21429 .22073 L
F
.183 .5 .375 .1 k
.18254 .23054 m
.18254 .24035 L
.21429 .24035 L
.21429 .23054 L
F
.183 .5 .392 .1 k
.18254 .24035 m
.18254 .25016 L
.21429 .25016 L
.21429 .24035 L
F
.183 .5 .408 .1 k
.18254 .25016 m
.18254 .25997 L
.21429 .25997 L
.21429 .25016 L
F
.183 .5 .425 .1 k
.18254 .25997 m
.18254 .26978 L
.21429 .26978 L
.21429 .25997 L
F
.183 .5 .442 .1 k
.18254 .26978 m
.18254 .27959 L
.21429 .27959 L
.21429 .26978 L
F
.183 .5 .458 .1 k
.18254 .27959 m
.18254 .2894 L
.21429 .2894 L
.21429 .27959 L
F
.183 .5 .475 .1 k
.18254 .2894 m
.18254 .29921 L
.21429 .29921 L
.21429 .2894 L
F
.183 .5 .492 .1 k
.18254 .29921 m
.18254 .30902 L
.21429 .30902 L
.21429 .29921 L
F
.183 .5 .508 .1 k
.18254 .30902 m
.18254 .31883 L
.21429 .31883 L
.21429 .30902 L
F
.183 .5 .525 .1 k
.18254 .31883 m
.18254 .32864 L
.21429 .32864 L
.21429 .31883 L
F
.183 .5 .542 .1 k
.18254 .32864 m
.18254 .33845 L
.21429 .33845 L
.21429 .32864 L
F
.183 .5 .558 .1 k
.18254 .33845 m
.18254 .34826 L
.21429 .34826 L
.21429 .33845 L
F
.183 .5 .575 .1 k
.18254 .34826 m
.18254 .35807 L
.21429 .35807 L
.21429 .34826 L
F
.183 .5 .592 .1 k
.18254 .35807 m
.18254 .36788 L
.21429 .36788 L
.21429 .35807 L
F
.183 .5 .608 .1 k
.18254 .36788 m
.18254 .37769 L
.21429 .37769 L
.21429 .36788 L
F
.183 .5 .625 .1 k
.18254 .37769 m
.18254 .3875 L
.21429 .3875 L
.21429 .37769 L
F
.183 .5 .642 .1 k
.18254 .3875 m
.18254 .39731 L
.21429 .39731 L
.21429 .3875 L
F
.183 .5 .658 .1 k
.18254 .39731 m
.18254 .40712 L
.21429 .40712 L
.21429 .39731 L
F
.183 .5 .675 .1 k
.18254 .40712 m
.18254 .41693 L
.21429 .41693 L
.21429 .40712 L
F
.183 .5 .692 .1 k
.18254 .41693 m
.18254 .42674 L
.21429 .42674 L
.21429 .41693 L
F
.183 .5 .708 .1 k
.18254 .42674 m
.18254 .43655 L
.21429 .43655 L
.21429 .42674 L
F
.183 .5 .725 .1 k
.18254 .43655 m
.18254 .44636 L
.21429 .44636 L
.21429 .43655 L
F
.183 .5 .742 .1 k
.18254 .44636 m
.18254 .45617 L
.21429 .45617 L
.21429 .44636 L
F
.183 .5 .758 .1 k
.18254 .45617 m
.18254 .46598 L
.21429 .46598 L
.21429 .45617 L
F
.183 .5 .775 .1 k
.18254 .46598 m
.18254 .47579 L
.21429 .47579 L
.21429 .46598 L
F
.183 .5 .792 .1 k
.18254 .47579 m
.18254 .4856 L
.21429 .4856 L
.21429 .47579 L
F
.183 .5 .808 .1 k
.18254 .4856 m
.18254 .49541 L
.21429 .49541 L
.21429 .4856 L
F
.183 .5 .825 .1 k
.18254 .49541 m
.18254 .50522 L
.21429 .50522 L
.21429 .49541 L
F
.183 .5 .842 .1 k
.18254 .50522 m
.18254 .51503 L
.21429 .51503 L
.21429 .50522 L
F
.183 .5 .858 .1 k
.18254 .51503 m
.18254 .52484 L
.21429 .52484 L
.21429 .51503 L
F
.183 .5 .875 .1 k
.18254 .52484 m
.18254 .53465 L
.21429 .53465 L
.21429 .52484 L
F
.183 .5 .892 .1 k
.18254 .53465 m
.18254 .54446 L
.21429 .54446 L
.21429 .53465 L
F
.183 .5 .908 .1 k
.18254 .54446 m
.18254 .55427 L
.21429 .55427 L
.21429 .54446 L
F
.183 .5 .925 .1 k
.18254 .55427 m
.18254 .56408 L
.21429 .56408 L
.21429 .55427 L
F
.183 .5 .942 .1 k
.18254 .56408 m
.18254 .57389 L
.21429 .57389 L
.21429 .56408 L
F
.183 .5 .958 .1 k
.18254 .57389 m
.18254 .5837 L
.21429 .5837 L
.21429 .57389 L
F
.183 .5 .975 .1 k
.18254 .5837 m
.18254 .59351 L
.21429 .59351 L
.21429 .5837 L
F
.183 .5 .992 .1 k
.18254 .59351 m
.18254 .60332 L
.21429 .60332 L
.21429 .59351 L
F
.217 .5 .008 .1 k
.21429 .01472 m
.21429 .02453 L
.24603 .02453 L
.24603 .01472 L
F
.217 .5 .025 .1 k
.21429 .02453 m
.21429 .03434 L
.24603 .03434 L
.24603 .02453 L
F
.217 .5 .042 .1 k
.21429 .03434 m
.21429 .04415 L
.24603 .04415 L
.24603 .03434 L
F
.217 .5 .058 .1 k
.21429 .04415 m
.21429 .05396 L
.24603 .05396 L
.24603 .04415 L
F
.217 .5 .075 .1 k
.21429 .05396 m
.21429 .06377 L
.24603 .06377 L
.24603 .05396 L
F
.217 .5 .092 .1 k
.21429 .06377 m
.21429 .07358 L
.24603 .07358 L
.24603 .06377 L
F
.217 .5 .108 .1 k
.21429 .07358 m
.21429 .08339 L
.24603 .08339 L
.24603 .07358 L
F
.217 .5 .125 .1 k
.21429 .08339 m
.21429 .0932 L
.24603 .0932 L
.24603 .08339 L
F
.217 .5 .142 .1 k
.21429 .0932 m
.21429 .10301 L
.24603 .10301 L
.24603 .0932 L
F
.217 .5 .158 .1 k
.21429 .10301 m
.21429 .11282 L
.24603 .11282 L
.24603 .10301 L
F
.217 .5 .175 .1 k
.21429 .11282 m
.21429 .12263 L
.24603 .12263 L
.24603 .11282 L
F
.217 .5 .192 .1 k
.21429 .12263 m
.21429 .13244 L
.24603 .13244 L
.24603 .12263 L
F
.217 .5 .208 .1 k
.21429 .13244 m
.21429 .14225 L
.24603 .14225 L
.24603 .13244 L
F
.217 .5 .225 .1 k
.21429 .14225 m
.21429 .15206 L
.24603 .15206 L
.24603 .14225 L
F
.217 .5 .242 .1 k
.21429 .15206 m
.21429 .16187 L
.24603 .16187 L
.24603 .15206 L
F
.217 .5 .258 .1 k
.21429 .16187 m
.21429 .17168 L
.24603 .17168 L
.24603 .16187 L
F
.217 .5 .275 .1 k
.21429 .17168 m
.21429 .18149 L
.24603 .18149 L
.24603 .17168 L
F
.217 .5 .292 .1 k
.21429 .18149 m
.21429 .1913 L
.24603 .1913 L
.24603 .18149 L
F
.217 .5 .308 .1 k
.21429 .1913 m
.21429 .20111 L
.24603 .20111 L
.24603 .1913 L
F
.217 .5 .325 .1 k
.21429 .20111 m
.21429 .21092 L
.24603 .21092 L
.24603 .20111 L
F
.217 .5 .342 .1 k
.21429 .21092 m
.21429 .22073 L
.24603 .22073 L
.24603 .21092 L
F
.217 .5 .358 .1 k
.21429 .22073 m
.21429 .23054 L
.24603 .23054 L
.24603 .22073 L
F
.217 .5 .375 .1 k
.21429 .23054 m
.21429 .24035 L
.24603 .24035 L
.24603 .23054 L
F
.217 .5 .392 .1 k
.21429 .24035 m
.21429 .25016 L
.24603 .25016 L
.24603 .24035 L
F
.217 .5 .408 .1 k
.21429 .25016 m
.21429 .25997 L
.24603 .25997 L
.24603 .25016 L
F
.217 .5 .425 .1 k
.21429 .25997 m
.21429 .26978 L
.24603 .26978 L
.24603 .25997 L
F
.217 .5 .442 .1 k
.21429 .26978 m
.21429 .27959 L
.24603 .27959 L
.24603 .26978 L
F
.217 .5 .458 .1 k
.21429 .27959 m
.21429 .2894 L
.24603 .2894 L
.24603 .27959 L
F
.217 .5 .475 .1 k
.21429 .2894 m
.21429 .29921 L
.24603 .29921 L
.24603 .2894 L
F
.217 .5 .492 .1 k
.21429 .29921 m
.21429 .30902 L
.24603 .30902 L
.24603 .29921 L
F
.217 .5 .508 .1 k
.21429 .30902 m
.21429 .31883 L
.24603 .31883 L
.24603 .30902 L
F
.217 .5 .525 .1 k
.21429 .31883 m
.21429 .32864 L
.24603 .32864 L
.24603 .31883 L
F
.217 .5 .542 .1 k
.21429 .32864 m
.21429 .33845 L
.24603 .33845 L
.24603 .32864 L
F
.217 .5 .558 .1 k
.21429 .33845 m
.21429 .34826 L
.24603 .34826 L
.24603 .33845 L
F
.217 .5 .575 .1 k
.21429 .34826 m
.21429 .35807 L
.24603 .35807 L
.24603 .34826 L
F
.217 .5 .592 .1 k
.21429 .35807 m
.21429 .36788 L
.24603 .36788 L
.24603 .35807 L
F
.217 .5 .608 .1 k
.21429 .36788 m
.21429 .37769 L
.24603 .37769 L
.24603 .36788 L
F
.217 .5 .625 .1 k
.21429 .37769 m
.21429 .3875 L
.24603 .3875 L
.24603 .37769 L
F
.217 .5 .642 .1 k
.21429 .3875 m
.21429 .39731 L
.24603 .39731 L
.24603 .3875 L
F
.217 .5 .658 .1 k
.21429 .39731 m
.21429 .40712 L
.24603 .40712 L
.24603 .39731 L
F
.217 .5 .675 .1 k
.21429 .40712 m
.21429 .41693 L
.24603 .41693 L
.24603 .40712 L
F
.217 .5 .692 .1 k
.21429 .41693 m
.21429 .42674 L
.24603 .42674 L
.24603 .41693 L
F
.217 .5 .708 .1 k
.21429 .42674 m
.21429 .43655 L
.24603 .43655 L
.24603 .42674 L
F
.217 .5 .725 .1 k
.21429 .43655 m
.21429 .44636 L
.24603 .44636 L
.24603 .43655 L
F
.217 .5 .742 .1 k
.21429 .44636 m
.21429 .45617 L
.24603 .45617 L
.24603 .44636 L
F
.217 .5 .758 .1 k
.21429 .45617 m
.21429 .46598 L
.24603 .46598 L
.24603 .45617 L
F
.217 .5 .775 .1 k
.21429 .46598 m
.21429 .47579 L
.24603 .47579 L
.24603 .46598 L
F
.217 .5 .792 .1 k
.21429 .47579 m
.21429 .4856 L
.24603 .4856 L
.24603 .47579 L
F
.217 .5 .808 .1 k
.21429 .4856 m
.21429 .49541 L
.24603 .49541 L
.24603 .4856 L
F
.217 .5 .825 .1 k
.21429 .49541 m
.21429 .50522 L
.24603 .50522 L
.24603 .49541 L
F
.217 .5 .842 .1 k
.21429 .50522 m
.21429 .51503 L
.24603 .51503 L
.24603 .50522 L
F
.217 .5 .858 .1 k
.21429 .51503 m
.21429 .52484 L
.24603 .52484 L
.24603 .51503 L
F
.217 .5 .875 .1 k
.21429 .52484 m
.21429 .53465 L
.24603 .53465 L
.24603 .52484 L
F
.217 .5 .892 .1 k
.21429 .53465 m
.21429 .54446 L
.24603 .54446 L
.24603 .53465 L
F
.217 .5 .908 .1 k
.21429 .54446 m
.21429 .55427 L
.24603 .55427 L
.24603 .54446 L
F
.217 .5 .925 .1 k
.21429 .55427 m
.21429 .56408 L
.24603 .56408 L
.24603 .55427 L
F
.217 .5 .942 .1 k
.21429 .56408 m
.21429 .57389 L
.24603 .57389 L
.24603 .56408 L
F
.217 .5 .958 .1 k
.21429 .57389 m
.21429 .5837 L
.24603 .5837 L
.24603 .57389 L
F
.217 .5 .975 .1 k
.21429 .5837 m
.21429 .59351 L
.24603 .59351 L
.24603 .5837 L
F
.217 .5 .992 .1 k
.21429 .59351 m
.21429 .60332 L
.24603 .60332 L
.24603 .59351 L
F
.25 .5 .008 .1 k
.24603 .01472 m
.24603 .02453 L
.27778 .02453 L
.27778 .01472 L
F
.25 .5 .025 .1 k
.24603 .02453 m
.24603 .03434 L
.27778 .03434 L
.27778 .02453 L
F
.25 .5 .042 .1 k
.24603 .03434 m
.24603 .04415 L
.27778 .04415 L
.27778 .03434 L
F
.25 .5 .058 .1 k
.24603 .04415 m
.24603 .05396 L
.27778 .05396 L
.27778 .04415 L
F
.25 .5 .075 .1 k
.24603 .05396 m
.24603 .06377 L
.27778 .06377 L
.27778 .05396 L
F
.25 .5 .092 .1 k
.24603 .06377 m
.24603 .07358 L
.27778 .07358 L
.27778 .06377 L
F
.25 .5 .108 .1 k
.24603 .07358 m
.24603 .08339 L
.27778 .08339 L
.27778 .07358 L
F
.25 .5 .125 .1 k
.24603 .08339 m
.24603 .0932 L
.27778 .0932 L
.27778 .08339 L
F
.25 .5 .142 .1 k
.24603 .0932 m
.24603 .10301 L
.27778 .10301 L
.27778 .0932 L
F
.25 .5 .158 .1 k
.24603 .10301 m
.24603 .11282 L
.27778 .11282 L
.27778 .10301 L
F
.25 .5 .175 .1 k
.24603 .11282 m
.24603 .12263 L
.27778 .12263 L
.27778 .11282 L
F
.25 .5 .192 .1 k
.24603 .12263 m
.24603 .13244 L
.27778 .13244 L
.27778 .12263 L
F
.25 .5 .208 .1 k
.24603 .13244 m
.24603 .14225 L
.27778 .14225 L
.27778 .13244 L
F
.25 .5 .225 .1 k
.24603 .14225 m
.24603 .15206 L
.27778 .15206 L
.27778 .14225 L
F
.25 .5 .242 .1 k
.24603 .15206 m
.24603 .16187 L
.27778 .16187 L
.27778 .15206 L
F
.25 .5 .258 .1 k
.24603 .16187 m
.24603 .17168 L
.27778 .17168 L
.27778 .16187 L
F
.25 .5 .275 .1 k
.24603 .17168 m
.24603 .18149 L
.27778 .18149 L
.27778 .17168 L
F
.25 .5 .292 .1 k
.24603 .18149 m
.24603 .1913 L
.27778 .1913 L
.27778 .18149 L
F
.25 .5 .308 .1 k
.24603 .1913 m
.24603 .20111 L
.27778 .20111 L
.27778 .1913 L
F
.25 .5 .325 .1 k
.24603 .20111 m
.24603 .21092 L
.27778 .21092 L
.27778 .20111 L
F
.25 .5 .342 .1 k
.24603 .21092 m
.24603 .22073 L
.27778 .22073 L
.27778 .21092 L
F
.25 .5 .358 .1 k
.24603 .22073 m
.24603 .23054 L
.27778 .23054 L
.27778 .22073 L
F
.25 .5 .375 .1 k
.24603 .23054 m
.24603 .24035 L
.27778 .24035 L
.27778 .23054 L
F
.25 .5 .392 .1 k
.24603 .24035 m
.24603 .25016 L
.27778 .25016 L
.27778 .24035 L
F
.25 .5 .408 .1 k
.24603 .25016 m
.24603 .25997 L
.27778 .25997 L
.27778 .25016 L
F
.25 .5 .425 .1 k
.24603 .25997 m
.24603 .26978 L
.27778 .26978 L
.27778 .25997 L
F
.25 .5 .442 .1 k
.24603 .26978 m
.24603 .27959 L
.27778 .27959 L
.27778 .26978 L
F
.25 .5 .458 .1 k
.24603 .27959 m
.24603 .2894 L
.27778 .2894 L
.27778 .27959 L
F
.25 .5 .475 .1 k
.24603 .2894 m
.24603 .29921 L
.27778 .29921 L
.27778 .2894 L
F
.25 .5 .492 .1 k
.24603 .29921 m
.24603 .30902 L
.27778 .30902 L
.27778 .29921 L
F
.25 .5 .508 .1 k
.24603 .30902 m
.24603 .31883 L
.27778 .31883 L
.27778 .30902 L
F
.25 .5 .525 .1 k
.24603 .31883 m
.24603 .32864 L
.27778 .32864 L
.27778 .31883 L
F
.25 .5 .542 .1 k
.24603 .32864 m
.24603 .33845 L
.27778 .33845 L
.27778 .32864 L
F
.25 .5 .558 .1 k
.24603 .33845 m
.24603 .34826 L
.27778 .34826 L
.27778 .33845 L
F
.25 .5 .575 .1 k
.24603 .34826 m
.24603 .35807 L
.27778 .35807 L
.27778 .34826 L
F
.25 .5 .592 .1 k
.24603 .35807 m
.24603 .36788 L
.27778 .36788 L
.27778 .35807 L
F
.25 .5 .608 .1 k
.24603 .36788 m
.24603 .37769 L
.27778 .37769 L
.27778 .36788 L
F
.25 .5 .625 .1 k
.24603 .37769 m
.24603 .3875 L
.27778 .3875 L
.27778 .37769 L
F
.25 .5 .642 .1 k
.24603 .3875 m
.24603 .39731 L
.27778 .39731 L
.27778 .3875 L
F
.25 .5 .658 .1 k
.24603 .39731 m
.24603 .40712 L
.27778 .40712 L
.27778 .39731 L
F
.25 .5 .675 .1 k
.24603 .40712 m
.24603 .41693 L
.27778 .41693 L
.27778 .40712 L
F
.25 .5 .692 .1 k
.24603 .41693 m
.24603 .42674 L
.27778 .42674 L
.27778 .41693 L
F
.25 .5 .708 .1 k
.24603 .42674 m
.24603 .43655 L
.27778 .43655 L
.27778 .42674 L
F
.25 .5 .725 .1 k
.24603 .43655 m
.24603 .44636 L
.27778 .44636 L
.27778 .43655 L
F
.25 .5 .742 .1 k
.24603 .44636 m
.24603 .45617 L
.27778 .45617 L
.27778 .44636 L
F
.25 .5 .758 .1 k
.24603 .45617 m
.24603 .46598 L
.27778 .46598 L
.27778 .45617 L
F
.25 .5 .775 .1 k
.24603 .46598 m
.24603 .47579 L
.27778 .47579 L
.27778 .46598 L
F
.25 .5 .792 .1 k
.24603 .47579 m
.24603 .4856 L
.27778 .4856 L
.27778 .47579 L
F
.25 .5 .808 .1 k
.24603 .4856 m
.24603 .49541 L
.27778 .49541 L
.27778 .4856 L
F
.25 .5 .825 .1 k
.24603 .49541 m
.24603 .50522 L
.27778 .50522 L
.27778 .49541 L
F
.25 .5 .842 .1 k
.24603 .50522 m
.24603 .51503 L
.27778 .51503 L
.27778 .50522 L
F
.25 .5 .858 .1 k
.24603 .51503 m
.24603 .52484 L
.27778 .52484 L
.27778 .51503 L
F
.25 .5 .875 .1 k
.24603 .52484 m
.24603 .53465 L
.27778 .53465 L
.27778 .52484 L
F
.25 .5 .892 .1 k
.24603 .53465 m
.24603 .54446 L
.27778 .54446 L
.27778 .53465 L
F
.25 .5 .908 .1 k
.24603 .54446 m
.24603 .55427 L
.27778 .55427 L
.27778 .54446 L
F
.25 .5 .925 .1 k
.24603 .55427 m
.24603 .56408 L
.27778 .56408 L
.27778 .55427 L
F
.25 .5 .942 .1 k
.24603 .56408 m
.24603 .57389 L
.27778 .57389 L
.27778 .56408 L
F
.25 .5 .958 .1 k
.24603 .57389 m
.24603 .5837 L
.27778 .5837 L
.27778 .57389 L
F
.25 .5 .975 .1 k
.24603 .5837 m
.24603 .59351 L
.27778 .59351 L
.27778 .5837 L
F
.25 .5 .992 .1 k
.24603 .59351 m
.24603 .60332 L
.27778 .60332 L
.27778 .59351 L
F
.283 .5 .008 .1 k
.27778 .01472 m
.27778 .02453 L
.30952 .02453 L
.30952 .01472 L
F
.283 .5 .025 .1 k
.27778 .02453 m
.27778 .03434 L
.30952 .03434 L
.30952 .02453 L
F
.283 .5 .042 .1 k
.27778 .03434 m
.27778 .04415 L
.30952 .04415 L
.30952 .03434 L
F
.283 .5 .058 .1 k
.27778 .04415 m
.27778 .05396 L
.30952 .05396 L
.30952 .04415 L
F
.283 .5 .075 .1 k
.27778 .05396 m
.27778 .06377 L
.30952 .06377 L
.30952 .05396 L
F
.283 .5 .092 .1 k
.27778 .06377 m
.27778 .07358 L
.30952 .07358 L
.30952 .06377 L
F
.283 .5 .108 .1 k
.27778 .07358 m
.27778 .08339 L
.30952 .08339 L
.30952 .07358 L
F
.283 .5 .125 .1 k
.27778 .08339 m
.27778 .0932 L
.30952 .0932 L
.30952 .08339 L
F
.283 .5 .142 .1 k
.27778 .0932 m
.27778 .10301 L
.30952 .10301 L
.30952 .0932 L
F
.283 .5 .158 .1 k
.27778 .10301 m
.27778 .11282 L
.30952 .11282 L
.30952 .10301 L
F
.283 .5 .175 .1 k
.27778 .11282 m
.27778 .12263 L
.30952 .12263 L
.30952 .11282 L
F
.283 .5 .192 .1 k
.27778 .12263 m
.27778 .13244 L
.30952 .13244 L
.30952 .12263 L
F
.283 .5 .208 .1 k
.27778 .13244 m
.27778 .14225 L
.30952 .14225 L
.30952 .13244 L
F
.283 .5 .225 .1 k
.27778 .14225 m
.27778 .15206 L
.30952 .15206 L
.30952 .14225 L
F
.283 .5 .242 .1 k
.27778 .15206 m
.27778 .16187 L
.30952 .16187 L
.30952 .15206 L
F
.283 .5 .258 .1 k
.27778 .16187 m
.27778 .17168 L
.30952 .17168 L
.30952 .16187 L
F
.283 .5 .275 .1 k
.27778 .17168 m
.27778 .18149 L
.30952 .18149 L
.30952 .17168 L
F
.283 .5 .292 .1 k
.27778 .18149 m
.27778 .1913 L
.30952 .1913 L
.30952 .18149 L
F
.283 .5 .308 .1 k
.27778 .1913 m
.27778 .20111 L
.30952 .20111 L
.30952 .1913 L
F
.283 .5 .325 .1 k
.27778 .20111 m
.27778 .21092 L
.30952 .21092 L
.30952 .20111 L
F
.283 .5 .342 .1 k
.27778 .21092 m
.27778 .22073 L
.30952 .22073 L
.30952 .21092 L
F
.283 .5 .358 .1 k
.27778 .22073 m
.27778 .23054 L
.30952 .23054 L
.30952 .22073 L
F
.283 .5 .375 .1 k
.27778 .23054 m
.27778 .24035 L
.30952 .24035 L
.30952 .23054 L
F
.283 .5 .392 .1 k
.27778 .24035 m
.27778 .25016 L
.30952 .25016 L
.30952 .24035 L
F
.283 .5 .408 .1 k
.27778 .25016 m
.27778 .25997 L
.30952 .25997 L
.30952 .25016 L
F
.283 .5 .425 .1 k
.27778 .25997 m
.27778 .26978 L
.30952 .26978 L
.30952 .25997 L
F
.283 .5 .442 .1 k
.27778 .26978 m
.27778 .27959 L
.30952 .27959 L
.30952 .26978 L
F
.283 .5 .458 .1 k
.27778 .27959 m
.27778 .2894 L
.30952 .2894 L
.30952 .27959 L
F
.283 .5 .475 .1 k
.27778 .2894 m
.27778 .29921 L
.30952 .29921 L
.30952 .2894 L
F
.283 .5 .492 .1 k
.27778 .29921 m
.27778 .30902 L
.30952 .30902 L
.30952 .29921 L
F
.283 .5 .508 .1 k
.27778 .30902 m
.27778 .31883 L
.30952 .31883 L
.30952 .30902 L
F
.283 .5 .525 .1 k
.27778 .31883 m
.27778 .32864 L
.30952 .32864 L
.30952 .31883 L
F
.283 .5 .542 .1 k
.27778 .32864 m
.27778 .33845 L
.30952 .33845 L
.30952 .32864 L
F
.283 .5 .558 .1 k
.27778 .33845 m
.27778 .34826 L
.30952 .34826 L
.30952 .33845 L
F
.283 .5 .575 .1 k
.27778 .34826 m
.27778 .35807 L
.30952 .35807 L
.30952 .34826 L
F
.283 .5 .592 .1 k
.27778 .35807 m
.27778 .36788 L
.30952 .36788 L
.30952 .35807 L
F
.283 .5 .608 .1 k
.27778 .36788 m
.27778 .37769 L
.30952 .37769 L
.30952 .36788 L
F
.283 .5 .625 .1 k
.27778 .37769 m
.27778 .3875 L
.30952 .3875 L
.30952 .37769 L
F
.283 .5 .642 .1 k
.27778 .3875 m
.27778 .39731 L
.30952 .39731 L
.30952 .3875 L
F
.283 .5 .658 .1 k
.27778 .39731 m
.27778 .40712 L
.30952 .40712 L
.30952 .39731 L
F
.283 .5 .675 .1 k
.27778 .40712 m
.27778 .41693 L
.30952 .41693 L
.30952 .40712 L
F
.283 .5 .692 .1 k
.27778 .41693 m
.27778 .42674 L
.30952 .42674 L
.30952 .41693 L
F
.283 .5 .708 .1 k
.27778 .42674 m
.27778 .43655 L
.30952 .43655 L
.30952 .42674 L
F
.283 .5 .725 .1 k
.27778 .43655 m
.27778 .44636 L
.30952 .44636 L
.30952 .43655 L
F
.283 .5 .742 .1 k
.27778 .44636 m
.27778 .45617 L
.30952 .45617 L
.30952 .44636 L
F
.283 .5 .758 .1 k
.27778 .45617 m
.27778 .46598 L
.30952 .46598 L
.30952 .45617 L
F
.283 .5 .775 .1 k
.27778 .46598 m
.27778 .47579 L
.30952 .47579 L
.30952 .46598 L
F
.283 .5 .792 .1 k
.27778 .47579 m
.27778 .4856 L
.30952 .4856 L
.30952 .47579 L
F
.283 .5 .808 .1 k
.27778 .4856 m
.27778 .49541 L
.30952 .49541 L
.30952 .4856 L
F
.283 .5 .825 .1 k
.27778 .49541 m
.27778 .50522 L
.30952 .50522 L
.30952 .49541 L
F
.283 .5 .842 .1 k
.27778 .50522 m
.27778 .51503 L
.30952 .51503 L
.30952 .50522 L
F
.283 .5 .858 .1 k
.27778 .51503 m
.27778 .52484 L
.30952 .52484 L
.30952 .51503 L
F
.283 .5 .875 .1 k
.27778 .52484 m
.27778 .53465 L
.30952 .53465 L
.30952 .52484 L
F
.283 .5 .892 .1 k
.27778 .53465 m
.27778 .54446 L
.30952 .54446 L
.30952 .53465 L
F
.283 .5 .908 .1 k
.27778 .54446 m
.27778 .55427 L
.30952 .55427 L
.30952 .54446 L
F
.283 .5 .925 .1 k
.27778 .55427 m
.27778 .56408 L
.30952 .56408 L
.30952 .55427 L
F
.283 .5 .942 .1 k
.27778 .56408 m
.27778 .57389 L
.30952 .57389 L
.30952 .56408 L
F
.283 .5 .958 .1 k
.27778 .57389 m
.27778 .5837 L
.30952 .5837 L
.30952 .57389 L
F
.283 .5 .975 .1 k
.27778 .5837 m
.27778 .59351 L
.30952 .59351 L
.30952 .5837 L
F
.283 .5 .992 .1 k
.27778 .59351 m
.27778 .60332 L
.30952 .60332 L
.30952 .59351 L
F
.317 .5 .008 .1 k
.30952 .01472 m
.30952 .02453 L
.34127 .02453 L
.34127 .01472 L
F
.317 .5 .025 .1 k
.30952 .02453 m
.30952 .03434 L
.34127 .03434 L
.34127 .02453 L
F
.317 .5 .042 .1 k
.30952 .03434 m
.30952 .04415 L
.34127 .04415 L
.34127 .03434 L
F
.317 .5 .058 .1 k
.30952 .04415 m
.30952 .05396 L
.34127 .05396 L
.34127 .04415 L
F
.317 .5 .075 .1 k
.30952 .05396 m
.30952 .06377 L
.34127 .06377 L
.34127 .05396 L
F
.317 .5 .092 .1 k
.30952 .06377 m
.30952 .07358 L
.34127 .07358 L
.34127 .06377 L
F
.317 .5 .108 .1 k
.30952 .07358 m
.30952 .08339 L
.34127 .08339 L
.34127 .07358 L
F
.317 .5 .125 .1 k
.30952 .08339 m
.30952 .0932 L
.34127 .0932 L
.34127 .08339 L
F
.317 .5 .142 .1 k
.30952 .0932 m
.30952 .10301 L
.34127 .10301 L
.34127 .0932 L
F
.317 .5 .158 .1 k
.30952 .10301 m
.30952 .11282 L
.34127 .11282 L
.34127 .10301 L
F
.317 .5 .175 .1 k
.30952 .11282 m
.30952 .12263 L
.34127 .12263 L
.34127 .11282 L
F
.317 .5 .192 .1 k
.30952 .12263 m
.30952 .13244 L
.34127 .13244 L
.34127 .12263 L
F
.317 .5 .208 .1 k
.30952 .13244 m
.30952 .14225 L
.34127 .14225 L
.34127 .13244 L
F
.317 .5 .225 .1 k
.30952 .14225 m
.30952 .15206 L
.34127 .15206 L
.34127 .14225 L
F
.317 .5 .242 .1 k
.30952 .15206 m
.30952 .16187 L
.34127 .16187 L
.34127 .15206 L
F
.317 .5 .258 .1 k
.30952 .16187 m
.30952 .17168 L
.34127 .17168 L
.34127 .16187 L
F
.317 .5 .275 .1 k
.30952 .17168 m
.30952 .18149 L
.34127 .18149 L
.34127 .17168 L
F
.317 .5 .292 .1 k
.30952 .18149 m
.30952 .1913 L
.34127 .1913 L
.34127 .18149 L
F
.317 .5 .308 .1 k
.30952 .1913 m
.30952 .20111 L
.34127 .20111 L
.34127 .1913 L
F
.317 .5 .325 .1 k
.30952 .20111 m
.30952 .21092 L
.34127 .21092 L
.34127 .20111 L
F
.317 .5 .342 .1 k
.30952 .21092 m
.30952 .22073 L
.34127 .22073 L
.34127 .21092 L
F
.317 .5 .358 .1 k
.30952 .22073 m
.30952 .23054 L
.34127 .23054 L
.34127 .22073 L
F
.317 .5 .375 .1 k
.30952 .23054 m
.30952 .24035 L
.34127 .24035 L
.34127 .23054 L
F
.317 .5 .392 .1 k
.30952 .24035 m
.30952 .25016 L
.34127 .25016 L
.34127 .24035 L
F
.317 .5 .408 .1 k
.30952 .25016 m
.30952 .25997 L
.34127 .25997 L
.34127 .25016 L
F
.317 .5 .425 .1 k
.30952 .25997 m
.30952 .26978 L
.34127 .26978 L
.34127 .25997 L
F
.317 .5 .442 .1 k
.30952 .26978 m
.30952 .27959 L
.34127 .27959 L
.34127 .26978 L
F
.317 .5 .458 .1 k
.30952 .27959 m
.30952 .2894 L
.34127 .2894 L
.34127 .27959 L
F
.317 .5 .475 .1 k
.30952 .2894 m
.30952 .29921 L
.34127 .29921 L
.34127 .2894 L
F
.317 .5 .492 .1 k
.30952 .29921 m
.30952 .30902 L
.34127 .30902 L
.34127 .29921 L
F
.317 .5 .508 .1 k
.30952 .30902 m
.30952 .31883 L
.34127 .31883 L
.34127 .30902 L
F
.317 .5 .525 .1 k
.30952 .31883 m
.30952 .32864 L
.34127 .32864 L
.34127 .31883 L
F
.317 .5 .542 .1 k
.30952 .32864 m
.30952 .33845 L
.34127 .33845 L
.34127 .32864 L
F
.317 .5 .558 .1 k
.30952 .33845 m
.30952 .34826 L
.34127 .34826 L
.34127 .33845 L
F
.317 .5 .575 .1 k
.30952 .34826 m
.30952 .35807 L
.34127 .35807 L
.34127 .34826 L
F
.317 .5 .592 .1 k
.30952 .35807 m
.30952 .36788 L
.34127 .36788 L
.34127 .35807 L
F
.317 .5 .608 .1 k
.30952 .36788 m
.30952 .37769 L
.34127 .37769 L
.34127 .36788 L
F
.317 .5 .625 .1 k
.30952 .37769 m
.30952 .3875 L
.34127 .3875 L
.34127 .37769 L
F
.317 .5 .642 .1 k
.30952 .3875 m
.30952 .39731 L
.34127 .39731 L
.34127 .3875 L
F
.317 .5 .658 .1 k
.30952 .39731 m
.30952 .40712 L
.34127 .40712 L
.34127 .39731 L
F
.317 .5 .675 .1 k
.30952 .40712 m
.30952 .41693 L
.34127 .41693 L
.34127 .40712 L
F
.317 .5 .692 .1 k
.30952 .41693 m
.30952 .42674 L
.34127 .42674 L
.34127 .41693 L
F
.317 .5 .708 .1 k
.30952 .42674 m
.30952 .43655 L
.34127 .43655 L
.34127 .42674 L
F
.317 .5 .725 .1 k
.30952 .43655 m
.30952 .44636 L
.34127 .44636 L
.34127 .43655 L
F
.317 .5 .742 .1 k
.30952 .44636 m
.30952 .45617 L
.34127 .45617 L
.34127 .44636 L
F
.317 .5 .758 .1 k
.30952 .45617 m
.30952 .46598 L
.34127 .46598 L
.34127 .45617 L
F
.317 .5 .775 .1 k
.30952 .46598 m
.30952 .47579 L
.34127 .47579 L
.34127 .46598 L
F
.317 .5 .792 .1 k
.30952 .47579 m
.30952 .4856 L
.34127 .4856 L
.34127 .47579 L
F
.317 .5 .808 .1 k
.30952 .4856 m
.30952 .49541 L
.34127 .49541 L
.34127 .4856 L
F
.317 .5 .825 .1 k
.30952 .49541 m
.30952 .50522 L
.34127 .50522 L
.34127 .49541 L
F
.317 .5 .842 .1 k
.30952 .50522 m
.30952 .51503 L
.34127 .51503 L
.34127 .50522 L
F
.317 .5 .858 .1 k
.30952 .51503 m
.30952 .52484 L
.34127 .52484 L
.34127 .51503 L
F
.317 .5 .875 .1 k
.30952 .52484 m
.30952 .53465 L
.34127 .53465 L
.34127 .52484 L
F
.317 .5 .892 .1 k
.30952 .53465 m
.30952 .54446 L
.34127 .54446 L
.34127 .53465 L
F
.317 .5 .908 .1 k
.30952 .54446 m
.30952 .55427 L
.34127 .55427 L
.34127 .54446 L
F
.317 .5 .925 .1 k
.30952 .55427 m
.30952 .56408 L
.34127 .56408 L
.34127 .55427 L
F
.317 .5 .942 .1 k
.30952 .56408 m
.30952 .57389 L
.34127 .57389 L
.34127 .56408 L
F
.317 .5 .958 .1 k
.30952 .57389 m
.30952 .5837 L
.34127 .5837 L
.34127 .57389 L
F
.317 .5 .975 .1 k
.30952 .5837 m
.30952 .59351 L
.34127 .59351 L
.34127 .5837 L
F
.317 .5 .992 .1 k
.30952 .59351 m
.30952 .60332 L
.34127 .60332 L
.34127 .59351 L
F
.35 .5 .008 .1 k
.34127 .01472 m
.34127 .02453 L
.37302 .02453 L
.37302 .01472 L
F
.35 .5 .025 .1 k
.34127 .02453 m
.34127 .03434 L
.37302 .03434 L
.37302 .02453 L
F
.35 .5 .042 .1 k
.34127 .03434 m
.34127 .04415 L
.37302 .04415 L
.37302 .03434 L
F
.35 .5 .058 .1 k
.34127 .04415 m
.34127 .05396 L
.37302 .05396 L
.37302 .04415 L
F
.35 .5 .075 .1 k
.34127 .05396 m
.34127 .06377 L
.37302 .06377 L
.37302 .05396 L
F
.35 .5 .092 .1 k
.34127 .06377 m
.34127 .07358 L
.37302 .07358 L
.37302 .06377 L
F
.35 .5 .108 .1 k
.34127 .07358 m
.34127 .08339 L
.37302 .08339 L
.37302 .07358 L
F
.35 .5 .125 .1 k
.34127 .08339 m
.34127 .0932 L
.37302 .0932 L
.37302 .08339 L
F
.35 .5 .142 .1 k
.34127 .0932 m
.34127 .10301 L
.37302 .10301 L
.37302 .0932 L
F
.35 .5 .158 .1 k
.34127 .10301 m
.34127 .11282 L
.37302 .11282 L
.37302 .10301 L
F
.35 .5 .175 .1 k
.34127 .11282 m
.34127 .12263 L
.37302 .12263 L
.37302 .11282 L
F
.35 .5 .192 .1 k
.34127 .12263 m
.34127 .13244 L
.37302 .13244 L
.37302 .12263 L
F
.35 .5 .208 .1 k
.34127 .13244 m
.34127 .14225 L
.37302 .14225 L
.37302 .13244 L
F
.35 .5 .225 .1 k
.34127 .14225 m
.34127 .15206 L
.37302 .15206 L
.37302 .14225 L
F
.35 .5 .242 .1 k
.34127 .15206 m
.34127 .16187 L
.37302 .16187 L
.37302 .15206 L
F
.35 .5 .258 .1 k
.34127 .16187 m
.34127 .17168 L
.37302 .17168 L
.37302 .16187 L
F
.35 .5 .275 .1 k
.34127 .17168 m
.34127 .18149 L
.37302 .18149 L
.37302 .17168 L
F
.35 .5 .292 .1 k
.34127 .18149 m
.34127 .1913 L
.37302 .1913 L
.37302 .18149 L
F
.35 .5 .308 .1 k
.34127 .1913 m
.34127 .20111 L
.37302 .20111 L
.37302 .1913 L
F
.35 .5 .325 .1 k
.34127 .20111 m
.34127 .21092 L
.37302 .21092 L
.37302 .20111 L
F
.35 .5 .342 .1 k
.34127 .21092 m
.34127 .22073 L
.37302 .22073 L
.37302 .21092 L
F
.35 .5 .358 .1 k
.34127 .22073 m
.34127 .23054 L
.37302 .23054 L
.37302 .22073 L
F
.35 .5 .375 .1 k
.34127 .23054 m
.34127 .24035 L
.37302 .24035 L
.37302 .23054 L
F
.35 .5 .392 .1 k
.34127 .24035 m
.34127 .25016 L
.37302 .25016 L
.37302 .24035 L
F
.35 .5 .408 .1 k
.34127 .25016 m
.34127 .25997 L
.37302 .25997 L
.37302 .25016 L
F
.35 .5 .425 .1 k
.34127 .25997 m
.34127 .26978 L
.37302 .26978 L
.37302 .25997 L
F
.35 .5 .442 .1 k
.34127 .26978 m
.34127 .27959 L
.37302 .27959 L
.37302 .26978 L
F
.35 .5 .458 .1 k
.34127 .27959 m
.34127 .2894 L
.37302 .2894 L
.37302 .27959 L
F
.35 .5 .475 .1 k
.34127 .2894 m
.34127 .29921 L
.37302 .29921 L
.37302 .2894 L
F
.35 .5 .492 .1 k
.34127 .29921 m
.34127 .30902 L
.37302 .30902 L
.37302 .29921 L
F
.35 .5 .508 .1 k
.34127 .30902 m
.34127 .31883 L
.37302 .31883 L
.37302 .30902 L
F
.35 .5 .525 .1 k
.34127 .31883 m
.34127 .32864 L
.37302 .32864 L
.37302 .31883 L
F
.35 .5 .542 .1 k
.34127 .32864 m
.34127 .33845 L
.37302 .33845 L
.37302 .32864 L
F
.35 .5 .558 .1 k
.34127 .33845 m
.34127 .34826 L
.37302 .34826 L
.37302 .33845 L
F
.35 .5 .575 .1 k
.34127 .34826 m
.34127 .35807 L
.37302 .35807 L
.37302 .34826 L
F
.35 .5 .592 .1 k
.34127 .35807 m
.34127 .36788 L
.37302 .36788 L
.37302 .35807 L
F
.35 .5 .608 .1 k
.34127 .36788 m
.34127 .37769 L
.37302 .37769 L
.37302 .36788 L
F
.35 .5 .625 .1 k
.34127 .37769 m
.34127 .3875 L
.37302 .3875 L
.37302 .37769 L
F
.35 .5 .642 .1 k
.34127 .3875 m
.34127 .39731 L
.37302 .39731 L
.37302 .3875 L
F
.35 .5 .658 .1 k
.34127 .39731 m
.34127 .40712 L
.37302 .40712 L
.37302 .39731 L
F
.35 .5 .675 .1 k
.34127 .40712 m
.34127 .41693 L
.37302 .41693 L
.37302 .40712 L
F
.35 .5 .692 .1 k
.34127 .41693 m
.34127 .42674 L
.37302 .42674 L
.37302 .41693 L
F
.35 .5 .708 .1 k
.34127 .42674 m
.34127 .43655 L
.37302 .43655 L
.37302 .42674 L
F
.35 .5 .725 .1 k
.34127 .43655 m
.34127 .44636 L
.37302 .44636 L
.37302 .43655 L
F
.35 .5 .742 .1 k
.34127 .44636 m
.34127 .45617 L
.37302 .45617 L
.37302 .44636 L
F
.35 .5 .758 .1 k
.34127 .45617 m
.34127 .46598 L
.37302 .46598 L
.37302 .45617 L
F
.35 .5 .775 .1 k
.34127 .46598 m
.34127 .47579 L
.37302 .47579 L
.37302 .46598 L
F
.35 .5 .792 .1 k
.34127 .47579 m
.34127 .4856 L
.37302 .4856 L
.37302 .47579 L
F
.35 .5 .808 .1 k
.34127 .4856 m
.34127 .49541 L
.37302 .49541 L
.37302 .4856 L
F
.35 .5 .825 .1 k
.34127 .49541 m
.34127 .50522 L
.37302 .50522 L
.37302 .49541 L
F
.35 .5 .842 .1 k
.34127 .50522 m
.34127 .51503 L
.37302 .51503 L
.37302 .50522 L
F
.35 .5 .858 .1 k
.34127 .51503 m
.34127 .52484 L
.37302 .52484 L
.37302 .51503 L
F
.35 .5 .875 .1 k
.34127 .52484 m
.34127 .53465 L
.37302 .53465 L
.37302 .52484 L
F
.35 .5 .892 .1 k
.34127 .53465 m
.34127 .54446 L
.37302 .54446 L
.37302 .53465 L
F
.35 .5 .908 .1 k
.34127 .54446 m
.34127 .55427 L
.37302 .55427 L
.37302 .54446 L
F
.35 .5 .925 .1 k
.34127 .55427 m
.34127 .56408 L
.37302 .56408 L
.37302 .55427 L
F
.35 .5 .942 .1 k
.34127 .56408 m
.34127 .57389 L
.37302 .57389 L
.37302 .56408 L
F
.35 .5 .958 .1 k
.34127 .57389 m
.34127 .5837 L
.37302 .5837 L
.37302 .57389 L
F
.35 .5 .975 .1 k
.34127 .5837 m
.34127 .59351 L
.37302 .59351 L
.37302 .5837 L
F
.35 .5 .992 .1 k
.34127 .59351 m
.34127 .60332 L
.37302 .60332 L
.37302 .59351 L
F
.383 .5 .008 .1 k
.37302 .01472 m
.37302 .02453 L
.40476 .02453 L
.40476 .01472 L
F
.383 .5 .025 .1 k
.37302 .02453 m
.37302 .03434 L
.40476 .03434 L
.40476 .02453 L
F
.383 .5 .042 .1 k
.37302 .03434 m
.37302 .04415 L
.40476 .04415 L
.40476 .03434 L
F
.383 .5 .058 .1 k
.37302 .04415 m
.37302 .05396 L
.40476 .05396 L
.40476 .04415 L
F
.383 .5 .075 .1 k
.37302 .05396 m
.37302 .06377 L
.40476 .06377 L
.40476 .05396 L
F
.383 .5 .092 .1 k
.37302 .06377 m
.37302 .07358 L
.40476 .07358 L
.40476 .06377 L
F
.383 .5 .108 .1 k
.37302 .07358 m
.37302 .08339 L
.40476 .08339 L
.40476 .07358 L
F
.383 .5 .125 .1 k
.37302 .08339 m
.37302 .0932 L
.40476 .0932 L
.40476 .08339 L
F
.383 .5 .142 .1 k
.37302 .0932 m
.37302 .10301 L
.40476 .10301 L
.40476 .0932 L
F
.383 .5 .158 .1 k
.37302 .10301 m
.37302 .11282 L
.40476 .11282 L
.40476 .10301 L
F
.383 .5 .175 .1 k
.37302 .11282 m
.37302 .12263 L
.40476 .12263 L
.40476 .11282 L
F
.383 .5 .192 .1 k
.37302 .12263 m
.37302 .13244 L
.40476 .13244 L
.40476 .12263 L
F
.383 .5 .208 .1 k
.37302 .13244 m
.37302 .14225 L
.40476 .14225 L
.40476 .13244 L
F
.383 .5 .225 .1 k
.37302 .14225 m
.37302 .15206 L
.40476 .15206 L
.40476 .14225 L
F
.383 .5 .242 .1 k
.37302 .15206 m
.37302 .16187 L
.40476 .16187 L
.40476 .15206 L
F
.383 .5 .258 .1 k
.37302 .16187 m
.37302 .17168 L
.40476 .17168 L
.40476 .16187 L
F
.383 .5 .275 .1 k
.37302 .17168 m
.37302 .18149 L
.40476 .18149 L
.40476 .17168 L
F
.383 .5 .292 .1 k
.37302 .18149 m
.37302 .1913 L
.40476 .1913 L
.40476 .18149 L
F
.383 .5 .308 .1 k
.37302 .1913 m
.37302 .20111 L
.40476 .20111 L
.40476 .1913 L
F
.383 .5 .325 .1 k
.37302 .20111 m
.37302 .21092 L
.40476 .21092 L
.40476 .20111 L
F
.383 .5 .342 .1 k
.37302 .21092 m
.37302 .22073 L
.40476 .22073 L
.40476 .21092 L
F
.383 .5 .358 .1 k
.37302 .22073 m
.37302 .23054 L
.40476 .23054 L
.40476 .22073 L
F
.383 .5 .375 .1 k
.37302 .23054 m
.37302 .24035 L
.40476 .24035 L
.40476 .23054 L
F
.383 .5 .392 .1 k
.37302 .24035 m
.37302 .25016 L
.40476 .25016 L
.40476 .24035 L
F
.383 .5 .408 .1 k
.37302 .25016 m
.37302 .25997 L
.40476 .25997 L
.40476 .25016 L
F
.383 .5 .425 .1 k
.37302 .25997 m
.37302 .26978 L
.40476 .26978 L
.40476 .25997 L
F
.383 .5 .442 .1 k
.37302 .26978 m
.37302 .27959 L
.40476 .27959 L
.40476 .26978 L
F
.383 .5 .458 .1 k
.37302 .27959 m
.37302 .2894 L
.40476 .2894 L
.40476 .27959 L
F
.383 .5 .475 .1 k
.37302 .2894 m
.37302 .29921 L
.40476 .29921 L
.40476 .2894 L
F
.383 .5 .492 .1 k
.37302 .29921 m
.37302 .30902 L
.40476 .30902 L
.40476 .29921 L
F
.383 .5 .508 .1 k
.37302 .30902 m
.37302 .31883 L
.40476 .31883 L
.40476 .30902 L
F
.383 .5 .525 .1 k
.37302 .31883 m
.37302 .32864 L
.40476 .32864 L
.40476 .31883 L
F
.383 .5 .542 .1 k
.37302 .32864 m
.37302 .33845 L
.40476 .33845 L
.40476 .32864 L
F
.383 .5 .558 .1 k
.37302 .33845 m
.37302 .34826 L
.40476 .34826 L
.40476 .33845 L
F
.383 .5 .575 .1 k
.37302 .34826 m
.37302 .35807 L
.40476 .35807 L
.40476 .34826 L
F
.383 .5 .592 .1 k
.37302 .35807 m
.37302 .36788 L
.40476 .36788 L
.40476 .35807 L
F
.383 .5 .608 .1 k
.37302 .36788 m
.37302 .37769 L
.40476 .37769 L
.40476 .36788 L
F
.383 .5 .625 .1 k
.37302 .37769 m
.37302 .3875 L
.40476 .3875 L
.40476 .37769 L
F
.383 .5 .642 .1 k
.37302 .3875 m
.37302 .39731 L
.40476 .39731 L
.40476 .3875 L
F
.383 .5 .658 .1 k
.37302 .39731 m
.37302 .40712 L
.40476 .40712 L
.40476 .39731 L
F
.383 .5 .675 .1 k
.37302 .40712 m
.37302 .41693 L
.40476 .41693 L
.40476 .40712 L
F
.383 .5 .692 .1 k
.37302 .41693 m
.37302 .42674 L
.40476 .42674 L
.40476 .41693 L
F
.383 .5 .708 .1 k
.37302 .42674 m
.37302 .43655 L
.40476 .43655 L
.40476 .42674 L
F
.383 .5 .725 .1 k
.37302 .43655 m
.37302 .44636 L
.40476 .44636 L
.40476 .43655 L
F
.383 .5 .742 .1 k
.37302 .44636 m
.37302 .45617 L
.40476 .45617 L
.40476 .44636 L
F
.383 .5 .758 .1 k
.37302 .45617 m
.37302 .46598 L
.40476 .46598 L
.40476 .45617 L
F
.383 .5 .775 .1 k
.37302 .46598 m
.37302 .47579 L
.40476 .47579 L
.40476 .46598 L
F
.383 .5 .792 .1 k
.37302 .47579 m
.37302 .4856 L
.40476 .4856 L
.40476 .47579 L
F
.383 .5 .808 .1 k
.37302 .4856 m
.37302 .49541 L
.40476 .49541 L
.40476 .4856 L
F
.383 .5 .825 .1 k
.37302 .49541 m
.37302 .50522 L
.40476 .50522 L
.40476 .49541 L
F
.383 .5 .842 .1 k
.37302 .50522 m
.37302 .51503 L
.40476 .51503 L
.40476 .50522 L
F
.383 .5 .858 .1 k
.37302 .51503 m
.37302 .52484 L
.40476 .52484 L
.40476 .51503 L
F
.383 .5 .875 .1 k
.37302 .52484 m
.37302 .53465 L
.40476 .53465 L
.40476 .52484 L
F
.383 .5 .892 .1 k
.37302 .53465 m
.37302 .54446 L
.40476 .54446 L
.40476 .53465 L
F
.383 .5 .908 .1 k
.37302 .54446 m
.37302 .55427 L
.40476 .55427 L
.40476 .54446 L
F
.383 .5 .925 .1 k
.37302 .55427 m
.37302 .56408 L
.40476 .56408 L
.40476 .55427 L
F
.383 .5 .942 .1 k
.37302 .56408 m
.37302 .57389 L
.40476 .57389 L
.40476 .56408 L
F
.383 .5 .958 .1 k
.37302 .57389 m
.37302 .5837 L
.40476 .5837 L
.40476 .57389 L
F
.383 .5 .975 .1 k
.37302 .5837 m
.37302 .59351 L
.40476 .59351 L
.40476 .5837 L
F
.383 .5 .992 .1 k
.37302 .59351 m
.37302 .60332 L
.40476 .60332 L
.40476 .59351 L
F
.417 .5 .008 .1 k
.40476 .01472 m
.40476 .02453 L
.43651 .02453 L
.43651 .01472 L
F
.417 .5 .025 .1 k
.40476 .02453 m
.40476 .03434 L
.43651 .03434 L
.43651 .02453 L
F
.417 .5 .042 .1 k
.40476 .03434 m
.40476 .04415 L
.43651 .04415 L
.43651 .03434 L
F
.417 .5 .058 .1 k
.40476 .04415 m
.40476 .05396 L
.43651 .05396 L
.43651 .04415 L
F
.417 .5 .075 .1 k
.40476 .05396 m
.40476 .06377 L
.43651 .06377 L
.43651 .05396 L
F
.417 .5 .092 .1 k
.40476 .06377 m
.40476 .07358 L
.43651 .07358 L
.43651 .06377 L
F
.417 .5 .108 .1 k
.40476 .07358 m
.40476 .08339 L
.43651 .08339 L
.43651 .07358 L
F
.417 .5 .125 .1 k
.40476 .08339 m
.40476 .0932 L
.43651 .0932 L
.43651 .08339 L
F
.417 .5 .142 .1 k
.40476 .0932 m
.40476 .10301 L
.43651 .10301 L
.43651 .0932 L
F
.417 .5 .158 .1 k
.40476 .10301 m
.40476 .11282 L
.43651 .11282 L
.43651 .10301 L
F
.417 .5 .175 .1 k
.40476 .11282 m
.40476 .12263 L
.43651 .12263 L
.43651 .11282 L
F
.417 .5 .192 .1 k
.40476 .12263 m
.40476 .13244 L
.43651 .13244 L
.43651 .12263 L
F
.417 .5 .208 .1 k
.40476 .13244 m
.40476 .14225 L
.43651 .14225 L
.43651 .13244 L
F
.417 .5 .225 .1 k
.40476 .14225 m
.40476 .15206 L
.43651 .15206 L
.43651 .14225 L
F
.417 .5 .242 .1 k
.40476 .15206 m
.40476 .16187 L
.43651 .16187 L
.43651 .15206 L
F
.417 .5 .258 .1 k
.40476 .16187 m
.40476 .17168 L
.43651 .17168 L
.43651 .16187 L
F
.417 .5 .275 .1 k
.40476 .17168 m
.40476 .18149 L
.43651 .18149 L
.43651 .17168 L
F
.417 .5 .292 .1 k
.40476 .18149 m
.40476 .1913 L
.43651 .1913 L
.43651 .18149 L
F
.417 .5 .308 .1 k
.40476 .1913 m
.40476 .20111 L
.43651 .20111 L
.43651 .1913 L
F
.417 .5 .325 .1 k
.40476 .20111 m
.40476 .21092 L
.43651 .21092 L
.43651 .20111 L
F
.417 .5 .342 .1 k
.40476 .21092 m
.40476 .22073 L
.43651 .22073 L
.43651 .21092 L
F
.417 .5 .358 .1 k
.40476 .22073 m
.40476 .23054 L
.43651 .23054 L
.43651 .22073 L
F
.417 .5 .375 .1 k
.40476 .23054 m
.40476 .24035 L
.43651 .24035 L
.43651 .23054 L
F
.417 .5 .392 .1 k
.40476 .24035 m
.40476 .25016 L
.43651 .25016 L
.43651 .24035 L
F
.417 .5 .408 .1 k
.40476 .25016 m
.40476 .25997 L
.43651 .25997 L
.43651 .25016 L
F
.417 .5 .425 .1 k
.40476 .25997 m
.40476 .26978 L
.43651 .26978 L
.43651 .25997 L
F
.417 .5 .442 .1 k
.40476 .26978 m
.40476 .27959 L
.43651 .27959 L
.43651 .26978 L
F
.417 .5 .458 .1 k
.40476 .27959 m
.40476 .2894 L
.43651 .2894 L
.43651 .27959 L
F
.417 .5 .475 .1 k
.40476 .2894 m
.40476 .29921 L
.43651 .29921 L
.43651 .2894 L
F
.417 .5 .492 .1 k
.40476 .29921 m
.40476 .30902 L
.43651 .30902 L
.43651 .29921 L
F
.417 .5 .508 .1 k
.40476 .30902 m
.40476 .31883 L
.43651 .31883 L
.43651 .30902 L
F
.417 .5 .525 .1 k
.40476 .31883 m
.40476 .32864 L
.43651 .32864 L
.43651 .31883 L
F
.417 .5 .542 .1 k
.40476 .32864 m
.40476 .33845 L
.43651 .33845 L
.43651 .32864 L
F
.417 .5 .558 .1 k
.40476 .33845 m
.40476 .34826 L
.43651 .34826 L
.43651 .33845 L
F
.417 .5 .575 .1 k
.40476 .34826 m
.40476 .35807 L
.43651 .35807 L
.43651 .34826 L
F
.417 .5 .592 .1 k
.40476 .35807 m
.40476 .36788 L
.43651 .36788 L
.43651 .35807 L
F
.417 .5 .608 .1 k
.40476 .36788 m
.40476 .37769 L
.43651 .37769 L
.43651 .36788 L
F
.417 .5 .625 .1 k
.40476 .37769 m
.40476 .3875 L
.43651 .3875 L
.43651 .37769 L
F
.417 .5 .642 .1 k
.40476 .3875 m
.40476 .39731 L
.43651 .39731 L
.43651 .3875 L
F
.417 .5 .658 .1 k
.40476 .39731 m
.40476 .40712 L
.43651 .40712 L
.43651 .39731 L
F
.417 .5 .675 .1 k
.40476 .40712 m
.40476 .41693 L
.43651 .41693 L
.43651 .40712 L
F
.417 .5 .692 .1 k
.40476 .41693 m
.40476 .42674 L
.43651 .42674 L
.43651 .41693 L
F
.417 .5 .708 .1 k
.40476 .42674 m
.40476 .43655 L
.43651 .43655 L
.43651 .42674 L
F
.417 .5 .725 .1 k
.40476 .43655 m
.40476 .44636 L
.43651 .44636 L
.43651 .43655 L
F
.417 .5 .742 .1 k
.40476 .44636 m
.40476 .45617 L
.43651 .45617 L
.43651 .44636 L
F
.417 .5 .758 .1 k
.40476 .45617 m
.40476 .46598 L
.43651 .46598 L
.43651 .45617 L
F
.417 .5 .775 .1 k
.40476 .46598 m
.40476 .47579 L
.43651 .47579 L
.43651 .46598 L
F
.417 .5 .792 .1 k
.40476 .47579 m
.40476 .4856 L
.43651 .4856 L
.43651 .47579 L
F
.417 .5 .808 .1 k
.40476 .4856 m
.40476 .49541 L
.43651 .49541 L
.43651 .4856 L
F
.417 .5 .825 .1 k
.40476 .49541 m
.40476 .50522 L
.43651 .50522 L
.43651 .49541 L
F
.417 .5 .842 .1 k
.40476 .50522 m
.40476 .51503 L
.43651 .51503 L
.43651 .50522 L
F
.417 .5 .858 .1 k
.40476 .51503 m
.40476 .52484 L
.43651 .52484 L
.43651 .51503 L
F
.417 .5 .875 .1 k
.40476 .52484 m
.40476 .53465 L
.43651 .53465 L
.43651 .52484 L
F
.417 .5 .892 .1 k
.40476 .53465 m
.40476 .54446 L
.43651 .54446 L
.43651 .53465 L
F
.417 .5 .908 .1 k
.40476 .54446 m
.40476 .55427 L
.43651 .55427 L
.43651 .54446 L
F
.417 .5 .925 .1 k
.40476 .55427 m
.40476 .56408 L
.43651 .56408 L
.43651 .55427 L
F
.417 .5 .942 .1 k
.40476 .56408 m
.40476 .57389 L
.43651 .57389 L
.43651 .56408 L
F
.417 .5 .958 .1 k
.40476 .57389 m
.40476 .5837 L
.43651 .5837 L
.43651 .57389 L
F
.417 .5 .975 .1 k
.40476 .5837 m
.40476 .59351 L
.43651 .59351 L
.43651 .5837 L
F
.417 .5 .992 .1 k
.40476 .59351 m
.40476 .60332 L
.43651 .60332 L
.43651 .59351 L
F
.45 .5 .008 .1 k
.43651 .01472 m
.43651 .02453 L
.46825 .02453 L
.46825 .01472 L
F
.45 .5 .025 .1 k
.43651 .02453 m
.43651 .03434 L
.46825 .03434 L
.46825 .02453 L
F
.45 .5 .042 .1 k
.43651 .03434 m
.43651 .04415 L
.46825 .04415 L
.46825 .03434 L
F
.45 .5 .058 .1 k
.43651 .04415 m
.43651 .05396 L
.46825 .05396 L
.46825 .04415 L
F
.45 .5 .075 .1 k
.43651 .05396 m
.43651 .06377 L
.46825 .06377 L
.46825 .05396 L
F
.45 .5 .092 .1 k
.43651 .06377 m
.43651 .07358 L
.46825 .07358 L
.46825 .06377 L
F
.45 .5 .108 .1 k
.43651 .07358 m
.43651 .08339 L
.46825 .08339 L
.46825 .07358 L
F
.45 .5 .125 .1 k
.43651 .08339 m
.43651 .0932 L
.46825 .0932 L
.46825 .08339 L
F
.45 .5 .142 .1 k
.43651 .0932 m
.43651 .10301 L
.46825 .10301 L
.46825 .0932 L
F
.45 .5 .158 .1 k
.43651 .10301 m
.43651 .11282 L
.46825 .11282 L
.46825 .10301 L
F
.45 .5 .175 .1 k
.43651 .11282 m
.43651 .12263 L
.46825 .12263 L
.46825 .11282 L
F
.45 .5 .192 .1 k
.43651 .12263 m
.43651 .13244 L
.46825 .13244 L
.46825 .12263 L
F
.45 .5 .208 .1 k
.43651 .13244 m
.43651 .14225 L
.46825 .14225 L
.46825 .13244 L
F
.45 .5 .225 .1 k
.43651 .14225 m
.43651 .15206 L
.46825 .15206 L
.46825 .14225 L
F
.45 .5 .242 .1 k
.43651 .15206 m
.43651 .16187 L
.46825 .16187 L
.46825 .15206 L
F
.45 .5 .258 .1 k
.43651 .16187 m
.43651 .17168 L
.46825 .17168 L
.46825 .16187 L
F
.45 .5 .275 .1 k
.43651 .17168 m
.43651 .18149 L
.46825 .18149 L
.46825 .17168 L
F
.45 .5 .292 .1 k
.43651 .18149 m
.43651 .1913 L
.46825 .1913 L
.46825 .18149 L
F
.45 .5 .308 .1 k
.43651 .1913 m
.43651 .20111 L
.46825 .20111 L
.46825 .1913 L
F
.45 .5 .325 .1 k
.43651 .20111 m
.43651 .21092 L
.46825 .21092 L
.46825 .20111 L
F
.45 .5 .342 .1 k
.43651 .21092 m
.43651 .22073 L
.46825 .22073 L
.46825 .21092 L
F
.45 .5 .358 .1 k
.43651 .22073 m
.43651 .23054 L
.46825 .23054 L
.46825 .22073 L
F
.45 .5 .375 .1 k
.43651 .23054 m
.43651 .24035 L
.46825 .24035 L
.46825 .23054 L
F
.45 .5 .392 .1 k
.43651 .24035 m
.43651 .25016 L
.46825 .25016 L
.46825 .24035 L
F
.45 .5 .408 .1 k
.43651 .25016 m
.43651 .25997 L
.46825 .25997 L
.46825 .25016 L
F
.45 .5 .425 .1 k
.43651 .25997 m
.43651 .26978 L
.46825 .26978 L
.46825 .25997 L
F
.45 .5 .442 .1 k
.43651 .26978 m
.43651 .27959 L
.46825 .27959 L
.46825 .26978 L
F
.45 .5 .458 .1 k
.43651 .27959 m
.43651 .2894 L
.46825 .2894 L
.46825 .27959 L
F
.45 .5 .475 .1 k
.43651 .2894 m
.43651 .29921 L
.46825 .29921 L
.46825 .2894 L
F
.45 .5 .492 .1 k
.43651 .29921 m
.43651 .30902 L
.46825 .30902 L
.46825 .29921 L
F
.45 .5 .508 .1 k
.43651 .30902 m
.43651 .31883 L
.46825 .31883 L
.46825 .30902 L
F
.45 .5 .525 .1 k
.43651 .31883 m
.43651 .32864 L
.46825 .32864 L
.46825 .31883 L
F
.45 .5 .542 .1 k
.43651 .32864 m
.43651 .33845 L
.46825 .33845 L
.46825 .32864 L
F
.45 .5 .558 .1 k
.43651 .33845 m
.43651 .34826 L
.46825 .34826 L
.46825 .33845 L
F
.45 .5 .575 .1 k
.43651 .34826 m
.43651 .35807 L
.46825 .35807 L
.46825 .34826 L
F
.45 .5 .592 .1 k
.43651 .35807 m
.43651 .36788 L
.46825 .36788 L
.46825 .35807 L
F
.45 .5 .608 .1 k
.43651 .36788 m
.43651 .37769 L
.46825 .37769 L
.46825 .36788 L
F
.45 .5 .625 .1 k
.43651 .37769 m
.43651 .3875 L
.46825 .3875 L
.46825 .37769 L
F
.45 .5 .642 .1 k
.43651 .3875 m
.43651 .39731 L
.46825 .39731 L
.46825 .3875 L
F
.45 .5 .658 .1 k
.43651 .39731 m
.43651 .40712 L
.46825 .40712 L
.46825 .39731 L
F
.45 .5 .675 .1 k
.43651 .40712 m
.43651 .41693 L
.46825 .41693 L
.46825 .40712 L
F
.45 .5 .692 .1 k
.43651 .41693 m
.43651 .42674 L
.46825 .42674 L
.46825 .41693 L
F
.45 .5 .708 .1 k
.43651 .42674 m
.43651 .43655 L
.46825 .43655 L
.46825 .42674 L
F
.45 .5 .725 .1 k
.43651 .43655 m
.43651 .44636 L
.46825 .44636 L
.46825 .43655 L
F
.45 .5 .742 .1 k
.43651 .44636 m
.43651 .45617 L
.46825 .45617 L
.46825 .44636 L
F
.45 .5 .758 .1 k
.43651 .45617 m
.43651 .46598 L
.46825 .46598 L
.46825 .45617 L
F
.45 .5 .775 .1 k
.43651 .46598 m
.43651 .47579 L
.46825 .47579 L
.46825 .46598 L
F
.45 .5 .792 .1 k
.43651 .47579 m
.43651 .4856 L
.46825 .4856 L
.46825 .47579 L
F
.45 .5 .808 .1 k
.43651 .4856 m
.43651 .49541 L
.46825 .49541 L
.46825 .4856 L
F
.45 .5 .825 .1 k
.43651 .49541 m
.43651 .50522 L
.46825 .50522 L
.46825 .49541 L
F
.45 .5 .842 .1 k
.43651 .50522 m
.43651 .51503 L
.46825 .51503 L
.46825 .50522 L
F
.45 .5 .858 .1 k
.43651 .51503 m
.43651 .52484 L
.46825 .52484 L
.46825 .51503 L
F
.45 .5 .875 .1 k
.43651 .52484 m
.43651 .53465 L
.46825 .53465 L
.46825 .52484 L
F
.45 .5 .892 .1 k
.43651 .53465 m
.43651 .54446 L
.46825 .54446 L
.46825 .53465 L
F
.45 .5 .908 .1 k
.43651 .54446 m
.43651 .55427 L
.46825 .55427 L
.46825 .54446 L
F
.45 .5 .925 .1 k
.43651 .55427 m
.43651 .56408 L
.46825 .56408 L
.46825 .55427 L
F
.45 .5 .942 .1 k
.43651 .56408 m
.43651 .57389 L
.46825 .57389 L
.46825 .56408 L
F
.45 .5 .958 .1 k
.43651 .57389 m
.43651 .5837 L
.46825 .5837 L
.46825 .57389 L
F
.45 .5 .975 .1 k
.43651 .5837 m
.43651 .59351 L
.46825 .59351 L
.46825 .5837 L
F
.45 .5 .992 .1 k
.43651 .59351 m
.43651 .60332 L
.46825 .60332 L
.46825 .59351 L
F
.483 .5 .008 .1 k
.46825 .01472 m
.46825 .02453 L
.5 .02453 L
.5 .01472 L
F
.483 .5 .025 .1 k
.46825 .02453 m
.46825 .03434 L
.5 .03434 L
.5 .02453 L
F
.483 .5 .042 .1 k
.46825 .03434 m
.46825 .04415 L
.5 .04415 L
.5 .03434 L
F
.483 .5 .058 .1 k
.46825 .04415 m
.46825 .05396 L
.5 .05396 L
.5 .04415 L
F
.483 .5 .075 .1 k
.46825 .05396 m
.46825 .06377 L
.5 .06377 L
.5 .05396 L
F
.483 .5 .092 .1 k
.46825 .06377 m
.46825 .07358 L
.5 .07358 L
.5 .06377 L
F
.483 .5 .108 .1 k
.46825 .07358 m
.46825 .08339 L
.5 .08339 L
.5 .07358 L
F
.483 .5 .125 .1 k
.46825 .08339 m
.46825 .0932 L
.5 .0932 L
.5 .08339 L
F
.483 .5 .142 .1 k
.46825 .0932 m
.46825 .10301 L
.5 .10301 L
.5 .0932 L
F
.483 .5 .158 .1 k
.46825 .10301 m
.46825 .11282 L
.5 .11282 L
.5 .10301 L
F
.483 .5 .175 .1 k
.46825 .11282 m
.46825 .12263 L
.5 .12263 L
.5 .11282 L
F
.483 .5 .192 .1 k
.46825 .12263 m
.46825 .13244 L
.5 .13244 L
.5 .12263 L
F
.483 .5 .208 .1 k
.46825 .13244 m
.46825 .14225 L
.5 .14225 L
.5 .13244 L
F
.483 .5 .225 .1 k
.46825 .14225 m
.46825 .15206 L
.5 .15206 L
.5 .14225 L
F
.483 .5 .242 .1 k
.46825 .15206 m
.46825 .16187 L
.5 .16187 L
.5 .15206 L
F
.483 .5 .258 .1 k
.46825 .16187 m
.46825 .17168 L
.5 .17168 L
.5 .16187 L
F
.483 .5 .275 .1 k
.46825 .17168 m
.46825 .18149 L
.5 .18149 L
.5 .17168 L
F
.483 .5 .292 .1 k
.46825 .18149 m
.46825 .1913 L
.5 .1913 L
.5 .18149 L
F
.483 .5 .308 .1 k
.46825 .1913 m
.46825 .20111 L
.5 .20111 L
.5 .1913 L
F
.483 .5 .325 .1 k
.46825 .20111 m
.46825 .21092 L
.5 .21092 L
.5 .20111 L
F
.483 .5 .342 .1 k
.46825 .21092 m
.46825 .22073 L
.5 .22073 L
.5 .21092 L
F
.483 .5 .358 .1 k
.46825 .22073 m
.46825 .23054 L
.5 .23054 L
.5 .22073 L
F
.483 .5 .375 .1 k
.46825 .23054 m
.46825 .24035 L
.5 .24035 L
.5 .23054 L
F
.483 .5 .392 .1 k
.46825 .24035 m
.46825 .25016 L
.5 .25016 L
.5 .24035 L
F
.483 .5 .408 .1 k
.46825 .25016 m
.46825 .25997 L
.5 .25997 L
.5 .25016 L
F
.483 .5 .425 .1 k
.46825 .25997 m
.46825 .26978 L
.5 .26978 L
.5 .25997 L
F
.483 .5 .442 .1 k
.46825 .26978 m
.46825 .27959 L
.5 .27959 L
.5 .26978 L
F
.483 .5 .458 .1 k
.46825 .27959 m
.46825 .2894 L
.5 .2894 L
.5 .27959 L
F
.483 .5 .475 .1 k
.46825 .2894 m
.46825 .29921 L
.5 .29921 L
.5 .2894 L
F
.483 .5 .492 .1 k
.46825 .29921 m
.46825 .30902 L
.5 .30902 L
.5 .29921 L
F
.483 .5 .508 .1 k
.46825 .30902 m
.46825 .31883 L
.5 .31883 L
.5 .30902 L
F
.483 .5 .525 .1 k
.46825 .31883 m
.46825 .32864 L
.5 .32864 L
.5 .31883 L
F
.483 .5 .542 .1 k
.46825 .32864 m
.46825 .33845 L
.5 .33845 L
.5 .32864 L
F
.483 .5 .558 .1 k
.46825 .33845 m
.46825 .34826 L
.5 .34826 L
.5 .33845 L
F
.483 .5 .575 .1 k
.46825 .34826 m
.46825 .35807 L
.5 .35807 L
.5 .34826 L
F
.483 .5 .592 .1 k
.46825 .35807 m
.46825 .36788 L
.5 .36788 L
.5 .35807 L
F
.483 .5 .608 .1 k
.46825 .36788 m
.46825 .37769 L
.5 .37769 L
.5 .36788 L
F
.483 .5 .625 .1 k
.46825 .37769 m
.46825 .3875 L
.5 .3875 L
.5 .37769 L
F
.483 .5 .642 .1 k
.46825 .3875 m
.46825 .39731 L
.5 .39731 L
.5 .3875 L
F
.483 .5 .658 .1 k
.46825 .39731 m
.46825 .40712 L
.5 .40712 L
.5 .39731 L
F
.483 .5 .675 .1 k
.46825 .40712 m
.46825 .41693 L
.5 .41693 L
.5 .40712 L
F
.483 .5 .692 .1 k
.46825 .41693 m
.46825 .42674 L
.5 .42674 L
.5 .41693 L
F
.483 .5 .708 .1 k
.46825 .42674 m
.46825 .43655 L
.5 .43655 L
.5 .42674 L
F
.483 .5 .725 .1 k
.46825 .43655 m
.46825 .44636 L
.5 .44636 L
.5 .43655 L
F
.483 .5 .742 .1 k
.46825 .44636 m
.46825 .45617 L
.5 .45617 L
.5 .44636 L
F
.483 .5 .758 .1 k
.46825 .45617 m
.46825 .46598 L
.5 .46598 L
.5 .45617 L
F
.483 .5 .775 .1 k
.46825 .46598 m
.46825 .47579 L
.5 .47579 L
.5 .46598 L
F
.483 .5 .792 .1 k
.46825 .47579 m
.46825 .4856 L
.5 .4856 L
.5 .47579 L
F
.483 .5 .808 .1 k
.46825 .4856 m
.46825 .49541 L
.5 .49541 L
.5 .4856 L
F
.483 .5 .825 .1 k
.46825 .49541 m
.46825 .50522 L
.5 .50522 L
.5 .49541 L
F
.483 .5 .842 .1 k
.46825 .50522 m
.46825 .51503 L
.5 .51503 L
.5 .50522 L
F
.483 .5 .858 .1 k
.46825 .51503 m
.46825 .52484 L
.5 .52484 L
.5 .51503 L
F
.483 .5 .875 .1 k
.46825 .52484 m
.46825 .53465 L
.5 .53465 L
.5 .52484 L
F
.483 .5 .892 .1 k
.46825 .53465 m
.46825 .54446 L
.5 .54446 L
.5 .53465 L
F
.483 .5 .908 .1 k
.46825 .54446 m
.46825 .55427 L
.5 .55427 L
.5 .54446 L
F
.483 .5 .925 .1 k
.46825 .55427 m
.46825 .56408 L
.5 .56408 L
.5 .55427 L
F
.483 .5 .942 .1 k
.46825 .56408 m
.46825 .57389 L
.5 .57389 L
.5 .56408 L
F
.483 .5 .958 .1 k
.46825 .57389 m
.46825 .5837 L
.5 .5837 L
.5 .57389 L
F
.483 .5 .975 .1 k
.46825 .5837 m
.46825 .59351 L
.5 .59351 L
.5 .5837 L
F
.483 .5 .992 .1 k
.46825 .59351 m
.46825 .60332 L
.5 .60332 L
.5 .59351 L
F
.517 .5 .008 .1 k
.5 .01472 m
.5 .02453 L
.53175 .02453 L
.53175 .01472 L
F
.517 .5 .025 .1 k
.5 .02453 m
.5 .03434 L
.53175 .03434 L
.53175 .02453 L
F
.517 .5 .042 .1 k
.5 .03434 m
.5 .04415 L
.53175 .04415 L
.53175 .03434 L
F
.517 .5 .058 .1 k
.5 .04415 m
.5 .05396 L
.53175 .05396 L
.53175 .04415 L
F
.517 .5 .075 .1 k
.5 .05396 m
.5 .06377 L
.53175 .06377 L
.53175 .05396 L
F
.517 .5 .092 .1 k
.5 .06377 m
.5 .07358 L
.53175 .07358 L
.53175 .06377 L
F
.517 .5 .108 .1 k
.5 .07358 m
.5 .08339 L
.53175 .08339 L
.53175 .07358 L
F
.517 .5 .125 .1 k
.5 .08339 m
.5 .0932 L
.53175 .0932 L
.53175 .08339 L
F
.517 .5 .142 .1 k
.5 .0932 m
.5 .10301 L
.53175 .10301 L
.53175 .0932 L
F
.517 .5 .158 .1 k
.5 .10301 m
.5 .11282 L
.53175 .11282 L
.53175 .10301 L
F
.517 .5 .175 .1 k
.5 .11282 m
.5 .12263 L
.53175 .12263 L
.53175 .11282 L
F
.517 .5 .192 .1 k
.5 .12263 m
.5 .13244 L
.53175 .13244 L
.53175 .12263 L
F
.517 .5 .208 .1 k
.5 .13244 m
.5 .14225 L
.53175 .14225 L
.53175 .13244 L
F
.517 .5 .225 .1 k
.5 .14225 m
.5 .15206 L
.53175 .15206 L
.53175 .14225 L
F
.517 .5 .242 .1 k
.5 .15206 m
.5 .16187 L
.53175 .16187 L
.53175 .15206 L
F
.517 .5 .258 .1 k
.5 .16187 m
.5 .17168 L
.53175 .17168 L
.53175 .16187 L
F
.517 .5 .275 .1 k
.5 .17168 m
.5 .18149 L
.53175 .18149 L
.53175 .17168 L
F
.517 .5 .292 .1 k
.5 .18149 m
.5 .1913 L
.53175 .1913 L
.53175 .18149 L
F
.517 .5 .308 .1 k
.5 .1913 m
.5 .20111 L
.53175 .20111 L
.53175 .1913 L
F
.517 .5 .325 .1 k
.5 .20111 m
.5 .21092 L
.53175 .21092 L
.53175 .20111 L
F
.517 .5 .342 .1 k
.5 .21092 m
.5 .22073 L
.53175 .22073 L
.53175 .21092 L
F
.517 .5 .358 .1 k
.5 .22073 m
.5 .23054 L
.53175 .23054 L
.53175 .22073 L
F
.517 .5 .375 .1 k
.5 .23054 m
.5 .24035 L
.53175 .24035 L
.53175 .23054 L
F
.517 .5 .392 .1 k
.5 .24035 m
.5 .25016 L
.53175 .25016 L
.53175 .24035 L
F
.517 .5 .408 .1 k
.5 .25016 m
.5 .25997 L
.53175 .25997 L
.53175 .25016 L
F
.517 .5 .425 .1 k
.5 .25997 m
.5 .26978 L
.53175 .26978 L
.53175 .25997 L
F
.517 .5 .442 .1 k
.5 .26978 m
.5 .27959 L
.53175 .27959 L
.53175 .26978 L
F
.517 .5 .458 .1 k
.5 .27959 m
.5 .2894 L
.53175 .2894 L
.53175 .27959 L
F
.517 .5 .475 .1 k
.5 .2894 m
.5 .29921 L
.53175 .29921 L
.53175 .2894 L
F
.517 .5 .492 .1 k
.5 .29921 m
.5 .30902 L
.53175 .30902 L
.53175 .29921 L
F
.517 .5 .508 .1 k
.5 .30902 m
.5 .31883 L
.53175 .31883 L
.53175 .30902 L
F
.517 .5 .525 .1 k
.5 .31883 m
.5 .32864 L
.53175 .32864 L
.53175 .31883 L
F
.517 .5 .542 .1 k
.5 .32864 m
.5 .33845 L
.53175 .33845 L
.53175 .32864 L
F
.517 .5 .558 .1 k
.5 .33845 m
.5 .34826 L
.53175 .34826 L
.53175 .33845 L
F
.517 .5 .575 .1 k
.5 .34826 m
.5 .35807 L
.53175 .35807 L
.53175 .34826 L
F
.517 .5 .592 .1 k
.5 .35807 m
.5 .36788 L
.53175 .36788 L
.53175 .35807 L
F
.517 .5 .608 .1 k
.5 .36788 m
.5 .37769 L
.53175 .37769 L
.53175 .36788 L
F
.517 .5 .625 .1 k
.5 .37769 m
.5 .3875 L
.53175 .3875 L
.53175 .37769 L
F
.517 .5 .642 .1 k
.5 .3875 m
.5 .39731 L
.53175 .39731 L
.53175 .3875 L
F
.517 .5 .658 .1 k
.5 .39731 m
.5 .40712 L
.53175 .40712 L
.53175 .39731 L
F
.517 .5 .675 .1 k
.5 .40712 m
.5 .41693 L
.53175 .41693 L
.53175 .40712 L
F
.517 .5 .692 .1 k
.5 .41693 m
.5 .42674 L
.53175 .42674 L
.53175 .41693 L
F
.517 .5 .708 .1 k
.5 .42674 m
.5 .43655 L
.53175 .43655 L
.53175 .42674 L
F
.517 .5 .725 .1 k
.5 .43655 m
.5 .44636 L
.53175 .44636 L
.53175 .43655 L
F
.517 .5 .742 .1 k
.5 .44636 m
.5 .45617 L
.53175 .45617 L
.53175 .44636 L
F
.517 .5 .758 .1 k
.5 .45617 m
.5 .46598 L
.53175 .46598 L
.53175 .45617 L
F
.517 .5 .775 .1 k
.5 .46598 m
.5 .47579 L
.53175 .47579 L
.53175 .46598 L
F
.517 .5 .792 .1 k
.5 .47579 m
.5 .4856 L
.53175 .4856 L
.53175 .47579 L
F
.517 .5 .808 .1 k
.5 .4856 m
.5 .49541 L
.53175 .49541 L
.53175 .4856 L
F
.517 .5 .825 .1 k
.5 .49541 m
.5 .50522 L
.53175 .50522 L
.53175 .49541 L
F
.517 .5 .842 .1 k
.5 .50522 m
.5 .51503 L
.53175 .51503 L
.53175 .50522 L
F
.517 .5 .858 .1 k
.5 .51503 m
.5 .52484 L
.53175 .52484 L
.53175 .51503 L
F
.517 .5 .875 .1 k
.5 .52484 m
.5 .53465 L
.53175 .53465 L
.53175 .52484 L
F
.517 .5 .892 .1 k
.5 .53465 m
.5 .54446 L
.53175 .54446 L
.53175 .53465 L
F
.517 .5 .908 .1 k
.5 .54446 m
.5 .55427 L
.53175 .55427 L
.53175 .54446 L
F
.517 .5 .925 .1 k
.5 .55427 m
.5 .56408 L
.53175 .56408 L
.53175 .55427 L
F
.517 .5 .942 .1 k
.5 .56408 m
.5 .57389 L
.53175 .57389 L
.53175 .56408 L
F
.517 .5 .958 .1 k
.5 .57389 m
.5 .5837 L
.53175 .5837 L
.53175 .57389 L
F
.517 .5 .975 .1 k
.5 .5837 m
.5 .59351 L
.53175 .59351 L
.53175 .5837 L
F
.517 .5 .992 .1 k
.5 .59351 m
.5 .60332 L
.53175 .60332 L
.53175 .59351 L
F
.55 .5 .008 .1 k
.53175 .01472 m
.53175 .02453 L
.56349 .02453 L
.56349 .01472 L
F
.55 .5 .025 .1 k
.53175 .02453 m
.53175 .03434 L
.56349 .03434 L
.56349 .02453 L
F
.55 .5 .042 .1 k
.53175 .03434 m
.53175 .04415 L
.56349 .04415 L
.56349 .03434 L
F
.55 .5 .058 .1 k
.53175 .04415 m
.53175 .05396 L
.56349 .05396 L
.56349 .04415 L
F
.55 .5 .075 .1 k
.53175 .05396 m
.53175 .06377 L
.56349 .06377 L
.56349 .05396 L
F
.55 .5 .092 .1 k
.53175 .06377 m
.53175 .07358 L
.56349 .07358 L
.56349 .06377 L
F
.55 .5 .108 .1 k
.53175 .07358 m
.53175 .08339 L
.56349 .08339 L
.56349 .07358 L
F
.55 .5 .125 .1 k
.53175 .08339 m
.53175 .0932 L
.56349 .0932 L
.56349 .08339 L
F
.55 .5 .142 .1 k
.53175 .0932 m
.53175 .10301 L
.56349 .10301 L
.56349 .0932 L
F
.55 .5 .158 .1 k
.53175 .10301 m
.53175 .11282 L
.56349 .11282 L
.56349 .10301 L
F
.55 .5 .175 .1 k
.53175 .11282 m
.53175 .12263 L
.56349 .12263 L
.56349 .11282 L
F
.55 .5 .192 .1 k
.53175 .12263 m
.53175 .13244 L
.56349 .13244 L
.56349 .12263 L
F
.55 .5 .208 .1 k
.53175 .13244 m
.53175 .14225 L
.56349 .14225 L
.56349 .13244 L
F
.55 .5 .225 .1 k
.53175 .14225 m
.53175 .15206 L
.56349 .15206 L
.56349 .14225 L
F
.55 .5 .242 .1 k
.53175 .15206 m
.53175 .16187 L
.56349 .16187 L
.56349 .15206 L
F
.55 .5 .258 .1 k
.53175 .16187 m
.53175 .17168 L
.56349 .17168 L
.56349 .16187 L
F
.55 .5 .275 .1 k
.53175 .17168 m
.53175 .18149 L
.56349 .18149 L
.56349 .17168 L
F
.55 .5 .292 .1 k
.53175 .18149 m
.53175 .1913 L
.56349 .1913 L
.56349 .18149 L
F
.55 .5 .308 .1 k
.53175 .1913 m
.53175 .20111 L
.56349 .20111 L
.56349 .1913 L
F
.55 .5 .325 .1 k
.53175 .20111 m
.53175 .21092 L
.56349 .21092 L
.56349 .20111 L
F
.55 .5 .342 .1 k
.53175 .21092 m
.53175 .22073 L
.56349 .22073 L
.56349 .21092 L
F
.55 .5 .358 .1 k
.53175 .22073 m
.53175 .23054 L
.56349 .23054 L
.56349 .22073 L
F
.55 .5 .375 .1 k
.53175 .23054 m
.53175 .24035 L
.56349 .24035 L
.56349 .23054 L
F
.55 .5 .392 .1 k
.53175 .24035 m
.53175 .25016 L
.56349 .25016 L
.56349 .24035 L
F
.55 .5 .408 .1 k
.53175 .25016 m
.53175 .25997 L
.56349 .25997 L
.56349 .25016 L
F
.55 .5 .425 .1 k
.53175 .25997 m
.53175 .26978 L
.56349 .26978 L
.56349 .25997 L
F
.55 .5 .442 .1 k
.53175 .26978 m
.53175 .27959 L
.56349 .27959 L
.56349 .26978 L
F
.55 .5 .458 .1 k
.53175 .27959 m
.53175 .2894 L
.56349 .2894 L
.56349 .27959 L
F
.55 .5 .475 .1 k
.53175 .2894 m
.53175 .29921 L
.56349 .29921 L
.56349 .2894 L
F
.55 .5 .492 .1 k
.53175 .29921 m
.53175 .30902 L
.56349 .30902 L
.56349 .29921 L
F
.55 .5 .508 .1 k
.53175 .30902 m
.53175 .31883 L
.56349 .31883 L
.56349 .30902 L
F
.55 .5 .525 .1 k
.53175 .31883 m
.53175 .32864 L
.56349 .32864 L
.56349 .31883 L
F
.55 .5 .542 .1 k
.53175 .32864 m
.53175 .33845 L
.56349 .33845 L
.56349 .32864 L
F
.55 .5 .558 .1 k
.53175 .33845 m
.53175 .34826 L
.56349 .34826 L
.56349 .33845 L
F
.55 .5 .575 .1 k
.53175 .34826 m
.53175 .35807 L
.56349 .35807 L
.56349 .34826 L
F
.55 .5 .592 .1 k
.53175 .35807 m
.53175 .36788 L
.56349 .36788 L
.56349 .35807 L
F
.55 .5 .608 .1 k
.53175 .36788 m
.53175 .37769 L
.56349 .37769 L
.56349 .36788 L
F
.55 .5 .625 .1 k
.53175 .37769 m
.53175 .3875 L
.56349 .3875 L
.56349 .37769 L
F
.55 .5 .642 .1 k
.53175 .3875 m
.53175 .39731 L
.56349 .39731 L
.56349 .3875 L
F
.55 .5 .658 .1 k
.53175 .39731 m
.53175 .40712 L
.56349 .40712 L
.56349 .39731 L
F
.55 .5 .675 .1 k
.53175 .40712 m
.53175 .41693 L
.56349 .41693 L
.56349 .40712 L
F
.55 .5 .692 .1 k
.53175 .41693 m
.53175 .42674 L
.56349 .42674 L
.56349 .41693 L
F
.55 .5 .708 .1 k
.53175 .42674 m
.53175 .43655 L
.56349 .43655 L
.56349 .42674 L
F
.55 .5 .725 .1 k
.53175 .43655 m
.53175 .44636 L
.56349 .44636 L
.56349 .43655 L
F
.55 .5 .742 .1 k
.53175 .44636 m
.53175 .45617 L
.56349 .45617 L
.56349 .44636 L
F
.55 .5 .758 .1 k
.53175 .45617 m
.53175 .46598 L
.56349 .46598 L
.56349 .45617 L
F
.55 .5 .775 .1 k
.53175 .46598 m
.53175 .47579 L
.56349 .47579 L
.56349 .46598 L
F
.55 .5 .792 .1 k
.53175 .47579 m
.53175 .4856 L
.56349 .4856 L
.56349 .47579 L
F
.55 .5 .808 .1 k
.53175 .4856 m
.53175 .49541 L
.56349 .49541 L
.56349 .4856 L
F
.55 .5 .825 .1 k
.53175 .49541 m
.53175 .50522 L
.56349 .50522 L
.56349 .49541 L
F
.55 .5 .842 .1 k
.53175 .50522 m
.53175 .51503 L
.56349 .51503 L
.56349 .50522 L
F
.55 .5 .858 .1 k
.53175 .51503 m
.53175 .52484 L
.56349 .52484 L
.56349 .51503 L
F
.55 .5 .875 .1 k
.53175 .52484 m
.53175 .53465 L
.56349 .53465 L
.56349 .52484 L
F
.55 .5 .892 .1 k
.53175 .53465 m
.53175 .54446 L
.56349 .54446 L
.56349 .53465 L
F
.55 .5 .908 .1 k
.53175 .54446 m
.53175 .55427 L
.56349 .55427 L
.56349 .54446 L
F
.55 .5 .925 .1 k
.53175 .55427 m
.53175 .56408 L
.56349 .56408 L
.56349 .55427 L
F
.55 .5 .942 .1 k
.53175 .56408 m
.53175 .57389 L
.56349 .57389 L
.56349 .56408 L
F
.55 .5 .958 .1 k
.53175 .57389 m
.53175 .5837 L
.56349 .5837 L
.56349 .57389 L
F
.55 .5 .975 .1 k
.53175 .5837 m
.53175 .59351 L
.56349 .59351 L
.56349 .5837 L
F
.55 .5 .992 .1 k
.53175 .59351 m
.53175 .60332 L
.56349 .60332 L
.56349 .59351 L
F
.583 .5 .008 .1 k
.56349 .01472 m
.56349 .02453 L
.59524 .02453 L
.59524 .01472 L
F
.583 .5 .025 .1 k
.56349 .02453 m
.56349 .03434 L
.59524 .03434 L
.59524 .02453 L
F
.583 .5 .042 .1 k
.56349 .03434 m
.56349 .04415 L
.59524 .04415 L
.59524 .03434 L
F
.583 .5 .058 .1 k
.56349 .04415 m
.56349 .05396 L
.59524 .05396 L
.59524 .04415 L
F
.583 .5 .075 .1 k
.56349 .05396 m
.56349 .06377 L
.59524 .06377 L
.59524 .05396 L
F
.583 .5 .092 .1 k
.56349 .06377 m
.56349 .07358 L
.59524 .07358 L
.59524 .06377 L
F
.583 .5 .108 .1 k
.56349 .07358 m
.56349 .08339 L
.59524 .08339 L
.59524 .07358 L
F
.583 .5 .125 .1 k
.56349 .08339 m
.56349 .0932 L
.59524 .0932 L
.59524 .08339 L
F
.583 .5 .142 .1 k
.56349 .0932 m
.56349 .10301 L
.59524 .10301 L
.59524 .0932 L
F
.583 .5 .158 .1 k
.56349 .10301 m
.56349 .11282 L
.59524 .11282 L
.59524 .10301 L
F
.583 .5 .175 .1 k
.56349 .11282 m
.56349 .12263 L
.59524 .12263 L
.59524 .11282 L
F
.583 .5 .192 .1 k
.56349 .12263 m
.56349 .13244 L
.59524 .13244 L
.59524 .12263 L
F
.583 .5 .208 .1 k
.56349 .13244 m
.56349 .14225 L
.59524 .14225 L
.59524 .13244 L
F
.583 .5 .225 .1 k
.56349 .14225 m
.56349 .15206 L
.59524 .15206 L
.59524 .14225 L
F
.583 .5 .242 .1 k
.56349 .15206 m
.56349 .16187 L
.59524 .16187 L
.59524 .15206 L
F
.583 .5 .258 .1 k
.56349 .16187 m
.56349 .17168 L
.59524 .17168 L
.59524 .16187 L
F
.583 .5 .275 .1 k
.56349 .17168 m
.56349 .18149 L
.59524 .18149 L
.59524 .17168 L
F
.583 .5 .292 .1 k
.56349 .18149 m
.56349 .1913 L
.59524 .1913 L
.59524 .18149 L
F
.583 .5 .308 .1 k
.56349 .1913 m
.56349 .20111 L
.59524 .20111 L
.59524 .1913 L
F
.583 .5 .325 .1 k
.56349 .20111 m
.56349 .21092 L
.59524 .21092 L
.59524 .20111 L
F
.583 .5 .342 .1 k
.56349 .21092 m
.56349 .22073 L
.59524 .22073 L
.59524 .21092 L
F
.583 .5 .358 .1 k
.56349 .22073 m
.56349 .23054 L
.59524 .23054 L
.59524 .22073 L
F
.583 .5 .375 .1 k
.56349 .23054 m
.56349 .24035 L
.59524 .24035 L
.59524 .23054 L
F
.583 .5 .392 .1 k
.56349 .24035 m
.56349 .25016 L
.59524 .25016 L
.59524 .24035 L
F
.583 .5 .408 .1 k
.56349 .25016 m
.56349 .25997 L
.59524 .25997 L
.59524 .25016 L
F
.583 .5 .425 .1 k
.56349 .25997 m
.56349 .26978 L
.59524 .26978 L
.59524 .25997 L
F
.583 .5 .442 .1 k
.56349 .26978 m
.56349 .27959 L
.59524 .27959 L
.59524 .26978 L
F
.583 .5 .458 .1 k
.56349 .27959 m
.56349 .2894 L
.59524 .2894 L
.59524 .27959 L
F
.583 .5 .475 .1 k
.56349 .2894 m
.56349 .29921 L
.59524 .29921 L
.59524 .2894 L
F
.583 .5 .492 .1 k
.56349 .29921 m
.56349 .30902 L
.59524 .30902 L
.59524 .29921 L
F
.583 .5 .508 .1 k
.56349 .30902 m
.56349 .31883 L
.59524 .31883 L
.59524 .30902 L
F
.583 .5 .525 .1 k
.56349 .31883 m
.56349 .32864 L
.59524 .32864 L
.59524 .31883 L
F
.583 .5 .542 .1 k
.56349 .32864 m
.56349 .33845 L
.59524 .33845 L
.59524 .32864 L
F
.583 .5 .558 .1 k
.56349 .33845 m
.56349 .34826 L
.59524 .34826 L
.59524 .33845 L
F
.583 .5 .575 .1 k
.56349 .34826 m
.56349 .35807 L
.59524 .35807 L
.59524 .34826 L
F
.583 .5 .592 .1 k
.56349 .35807 m
.56349 .36788 L
.59524 .36788 L
.59524 .35807 L
F
.583 .5 .608 .1 k
.56349 .36788 m
.56349 .37769 L
.59524 .37769 L
.59524 .36788 L
F
.583 .5 .625 .1 k
.56349 .37769 m
.56349 .3875 L
.59524 .3875 L
.59524 .37769 L
F
.583 .5 .642 .1 k
.56349 .3875 m
.56349 .39731 L
.59524 .39731 L
.59524 .3875 L
F
.583 .5 .658 .1 k
.56349 .39731 m
.56349 .40712 L
.59524 .40712 L
.59524 .39731 L
F
.583 .5 .675 .1 k
.56349 .40712 m
.56349 .41693 L
.59524 .41693 L
.59524 .40712 L
F
.583 .5 .692 .1 k
.56349 .41693 m
.56349 .42674 L
.59524 .42674 L
.59524 .41693 L
F
.583 .5 .708 .1 k
.56349 .42674 m
.56349 .43655 L
.59524 .43655 L
.59524 .42674 L
F
.583 .5 .725 .1 k
.56349 .43655 m
.56349 .44636 L
.59524 .44636 L
.59524 .43655 L
F
.583 .5 .742 .1 k
.56349 .44636 m
.56349 .45617 L
.59524 .45617 L
.59524 .44636 L
F
.583 .5 .758 .1 k
.56349 .45617 m
.56349 .46598 L
.59524 .46598 L
.59524 .45617 L
F
.583 .5 .775 .1 k
.56349 .46598 m
.56349 .47579 L
.59524 .47579 L
.59524 .46598 L
F
.583 .5 .792 .1 k
.56349 .47579 m
.56349 .4856 L
.59524 .4856 L
.59524 .47579 L
F
.583 .5 .808 .1 k
.56349 .4856 m
.56349 .49541 L
.59524 .49541 L
.59524 .4856 L
F
.583 .5 .825 .1 k
.56349 .49541 m
.56349 .50522 L
.59524 .50522 L
.59524 .49541 L
F
.583 .5 .842 .1 k
.56349 .50522 m
.56349 .51503 L
.59524 .51503 L
.59524 .50522 L
F
.583 .5 .858 .1 k
.56349 .51503 m
.56349 .52484 L
.59524 .52484 L
.59524 .51503 L
F
.583 .5 .875 .1 k
.56349 .52484 m
.56349 .53465 L
.59524 .53465 L
.59524 .52484 L
F
.583 .5 .892 .1 k
.56349 .53465 m
.56349 .54446 L
.59524 .54446 L
.59524 .53465 L
F
.583 .5 .908 .1 k
.56349 .54446 m
.56349 .55427 L
.59524 .55427 L
.59524 .54446 L
F
.583 .5 .925 .1 k
.56349 .55427 m
.56349 .56408 L
.59524 .56408 L
.59524 .55427 L
F
.583 .5 .942 .1 k
.56349 .56408 m
.56349 .57389 L
.59524 .57389 L
.59524 .56408 L
F
.583 .5 .958 .1 k
.56349 .57389 m
.56349 .5837 L
.59524 .5837 L
.59524 .57389 L
F
.583 .5 .975 .1 k
.56349 .5837 m
.56349 .59351 L
.59524 .59351 L
.59524 .5837 L
F
.583 .5 .992 .1 k
.56349 .59351 m
.56349 .60332 L
.59524 .60332 L
.59524 .59351 L
F
.617 .5 .008 .1 k
.59524 .01472 m
.59524 .02453 L
.62698 .02453 L
.62698 .01472 L
F
.617 .5 .025 .1 k
.59524 .02453 m
.59524 .03434 L
.62698 .03434 L
.62698 .02453 L
F
.617 .5 .042 .1 k
.59524 .03434 m
.59524 .04415 L
.62698 .04415 L
.62698 .03434 L
F
.617 .5 .058 .1 k
.59524 .04415 m
.59524 .05396 L
.62698 .05396 L
.62698 .04415 L
F
.617 .5 .075 .1 k
.59524 .05396 m
.59524 .06377 L
.62698 .06377 L
.62698 .05396 L
F
.617 .5 .092 .1 k
.59524 .06377 m
.59524 .07358 L
.62698 .07358 L
.62698 .06377 L
F
.617 .5 .108 .1 k
.59524 .07358 m
.59524 .08339 L
.62698 .08339 L
.62698 .07358 L
F
.617 .5 .125 .1 k
.59524 .08339 m
.59524 .0932 L
.62698 .0932 L
.62698 .08339 L
F
.617 .5 .142 .1 k
.59524 .0932 m
.59524 .10301 L
.62698 .10301 L
.62698 .0932 L
F
.617 .5 .158 .1 k
.59524 .10301 m
.59524 .11282 L
.62698 .11282 L
.62698 .10301 L
F
.617 .5 .175 .1 k
.59524 .11282 m
.59524 .12263 L
.62698 .12263 L
.62698 .11282 L
F
.617 .5 .192 .1 k
.59524 .12263 m
.59524 .13244 L
.62698 .13244 L
.62698 .12263 L
F
.617 .5 .208 .1 k
.59524 .13244 m
.59524 .14225 L
.62698 .14225 L
.62698 .13244 L
F
.617 .5 .225 .1 k
.59524 .14225 m
.59524 .15206 L
.62698 .15206 L
.62698 .14225 L
F
.617 .5 .242 .1 k
.59524 .15206 m
.59524 .16187 L
.62698 .16187 L
.62698 .15206 L
F
.617 .5 .258 .1 k
.59524 .16187 m
.59524 .17168 L
.62698 .17168 L
.62698 .16187 L
F
.617 .5 .275 .1 k
.59524 .17168 m
.59524 .18149 L
.62698 .18149 L
.62698 .17168 L
F
.617 .5 .292 .1 k
.59524 .18149 m
.59524 .1913 L
.62698 .1913 L
.62698 .18149 L
F
.617 .5 .308 .1 k
.59524 .1913 m
.59524 .20111 L
.62698 .20111 L
.62698 .1913 L
F
.617 .5 .325 .1 k
.59524 .20111 m
.59524 .21092 L
.62698 .21092 L
.62698 .20111 L
F
.617 .5 .342 .1 k
.59524 .21092 m
.59524 .22073 L
.62698 .22073 L
.62698 .21092 L
F
.617 .5 .358 .1 k
.59524 .22073 m
.59524 .23054 L
.62698 .23054 L
.62698 .22073 L
F
.617 .5 .375 .1 k
.59524 .23054 m
.59524 .24035 L
.62698 .24035 L
.62698 .23054 L
F
.617 .5 .392 .1 k
.59524 .24035 m
.59524 .25016 L
.62698 .25016 L
.62698 .24035 L
F
.617 .5 .408 .1 k
.59524 .25016 m
.59524 .25997 L
.62698 .25997 L
.62698 .25016 L
F
.617 .5 .425 .1 k
.59524 .25997 m
.59524 .26978 L
.62698 .26978 L
.62698 .25997 L
F
.617 .5 .442 .1 k
.59524 .26978 m
.59524 .27959 L
.62698 .27959 L
.62698 .26978 L
F
.617 .5 .458 .1 k
.59524 .27959 m
.59524 .2894 L
.62698 .2894 L
.62698 .27959 L
F
.617 .5 .475 .1 k
.59524 .2894 m
.59524 .29921 L
.62698 .29921 L
.62698 .2894 L
F
.617 .5 .492 .1 k
.59524 .29921 m
.59524 .30902 L
.62698 .30902 L
.62698 .29921 L
F
.617 .5 .508 .1 k
.59524 .30902 m
.59524 .31883 L
.62698 .31883 L
.62698 .30902 L
F
.617 .5 .525 .1 k
.59524 .31883 m
.59524 .32864 L
.62698 .32864 L
.62698 .31883 L
F
.617 .5 .542 .1 k
.59524 .32864 m
.59524 .33845 L
.62698 .33845 L
.62698 .32864 L
F
.617 .5 .558 .1 k
.59524 .33845 m
.59524 .34826 L
.62698 .34826 L
.62698 .33845 L
F
.617 .5 .575 .1 k
.59524 .34826 m
.59524 .35807 L
.62698 .35807 L
.62698 .34826 L
F
.617 .5 .592 .1 k
.59524 .35807 m
.59524 .36788 L
.62698 .36788 L
.62698 .35807 L
F
.617 .5 .608 .1 k
.59524 .36788 m
.59524 .37769 L
.62698 .37769 L
.62698 .36788 L
F
.617 .5 .625 .1 k
.59524 .37769 m
.59524 .3875 L
.62698 .3875 L
.62698 .37769 L
F
.617 .5 .642 .1 k
.59524 .3875 m
.59524 .39731 L
.62698 .39731 L
.62698 .3875 L
F
.617 .5 .658 .1 k
.59524 .39731 m
.59524 .40712 L
.62698 .40712 L
.62698 .39731 L
F
.617 .5 .675 .1 k
.59524 .40712 m
.59524 .41693 L
.62698 .41693 L
.62698 .40712 L
F
.617 .5 .692 .1 k
.59524 .41693 m
.59524 .42674 L
.62698 .42674 L
.62698 .41693 L
F
.617 .5 .708 .1 k
.59524 .42674 m
.59524 .43655 L
.62698 .43655 L
.62698 .42674 L
F
.617 .5 .725 .1 k
.59524 .43655 m
.59524 .44636 L
.62698 .44636 L
.62698 .43655 L
F
.617 .5 .742 .1 k
.59524 .44636 m
.59524 .45617 L
.62698 .45617 L
.62698 .44636 L
F
.617 .5 .758 .1 k
.59524 .45617 m
.59524 .46598 L
.62698 .46598 L
.62698 .45617 L
F
.617 .5 .775 .1 k
.59524 .46598 m
.59524 .47579 L
.62698 .47579 L
.62698 .46598 L
F
.617 .5 .792 .1 k
.59524 .47579 m
.59524 .4856 L
.62698 .4856 L
.62698 .47579 L
F
.617 .5 .808 .1 k
.59524 .4856 m
.59524 .49541 L
.62698 .49541 L
.62698 .4856 L
F
.617 .5 .825 .1 k
.59524 .49541 m
.59524 .50522 L
.62698 .50522 L
.62698 .49541 L
F
.617 .5 .842 .1 k
.59524 .50522 m
.59524 .51503 L
.62698 .51503 L
.62698 .50522 L
F
.617 .5 .858 .1 k
.59524 .51503 m
.59524 .52484 L
.62698 .52484 L
.62698 .51503 L
F
.617 .5 .875 .1 k
.59524 .52484 m
.59524 .53465 L
.62698 .53465 L
.62698 .52484 L
F
.617 .5 .892 .1 k
.59524 .53465 m
.59524 .54446 L
.62698 .54446 L
.62698 .53465 L
F
.617 .5 .908 .1 k
.59524 .54446 m
.59524 .55427 L
.62698 .55427 L
.62698 .54446 L
F
.617 .5 .925 .1 k
.59524 .55427 m
.59524 .56408 L
.62698 .56408 L
.62698 .55427 L
F
.617 .5 .942 .1 k
.59524 .56408 m
.59524 .57389 L
.62698 .57389 L
.62698 .56408 L
F
.617 .5 .958 .1 k
.59524 .57389 m
.59524 .5837 L
.62698 .5837 L
.62698 .57389 L
F
.617 .5 .975 .1 k
.59524 .5837 m
.59524 .59351 L
.62698 .59351 L
.62698 .5837 L
F
.617 .5 .992 .1 k
.59524 .59351 m
.59524 .60332 L
.62698 .60332 L
.62698 .59351 L
F
.65 .5 .008 .1 k
.62698 .01472 m
.62698 .02453 L
.65873 .02453 L
.65873 .01472 L
F
.65 .5 .025 .1 k
.62698 .02453 m
.62698 .03434 L
.65873 .03434 L
.65873 .02453 L
F
.65 .5 .042 .1 k
.62698 .03434 m
.62698 .04415 L
.65873 .04415 L
.65873 .03434 L
F
.65 .5 .058 .1 k
.62698 .04415 m
.62698 .05396 L
.65873 .05396 L
.65873 .04415 L
F
.65 .5 .075 .1 k
.62698 .05396 m
.62698 .06377 L
.65873 .06377 L
.65873 .05396 L
F
.65 .5 .092 .1 k
.62698 .06377 m
.62698 .07358 L
.65873 .07358 L
.65873 .06377 L
F
.65 .5 .108 .1 k
.62698 .07358 m
.62698 .08339 L
.65873 .08339 L
.65873 .07358 L
F
.65 .5 .125 .1 k
.62698 .08339 m
.62698 .0932 L
.65873 .0932 L
.65873 .08339 L
F
.65 .5 .142 .1 k
.62698 .0932 m
.62698 .10301 L
.65873 .10301 L
.65873 .0932 L
F
.65 .5 .158 .1 k
.62698 .10301 m
.62698 .11282 L
.65873 .11282 L
.65873 .10301 L
F
.65 .5 .175 .1 k
.62698 .11282 m
.62698 .12263 L
.65873 .12263 L
.65873 .11282 L
F
.65 .5 .192 .1 k
.62698 .12263 m
.62698 .13244 L
.65873 .13244 L
.65873 .12263 L
F
.65 .5 .208 .1 k
.62698 .13244 m
.62698 .14225 L
.65873 .14225 L
.65873 .13244 L
F
.65 .5 .225 .1 k
.62698 .14225 m
.62698 .15206 L
.65873 .15206 L
.65873 .14225 L
F
.65 .5 .242 .1 k
.62698 .15206 m
.62698 .16187 L
.65873 .16187 L
.65873 .15206 L
F
.65 .5 .258 .1 k
.62698 .16187 m
.62698 .17168 L
.65873 .17168 L
.65873 .16187 L
F
.65 .5 .275 .1 k
.62698 .17168 m
.62698 .18149 L
.65873 .18149 L
.65873 .17168 L
F
.65 .5 .292 .1 k
.62698 .18149 m
.62698 .1913 L
.65873 .1913 L
.65873 .18149 L
F
.65 .5 .308 .1 k
.62698 .1913 m
.62698 .20111 L
.65873 .20111 L
.65873 .1913 L
F
.65 .5 .325 .1 k
.62698 .20111 m
.62698 .21092 L
.65873 .21092 L
.65873 .20111 L
F
.65 .5 .342 .1 k
.62698 .21092 m
.62698 .22073 L
.65873 .22073 L
.65873 .21092 L
F
.65 .5 .358 .1 k
.62698 .22073 m
.62698 .23054 L
.65873 .23054 L
.65873 .22073 L
F
.65 .5 .375 .1 k
.62698 .23054 m
.62698 .24035 L
.65873 .24035 L
.65873 .23054 L
F
.65 .5 .392 .1 k
.62698 .24035 m
.62698 .25016 L
.65873 .25016 L
.65873 .24035 L
F
.65 .5 .408 .1 k
.62698 .25016 m
.62698 .25997 L
.65873 .25997 L
.65873 .25016 L
F
.65 .5 .425 .1 k
.62698 .25997 m
.62698 .26978 L
.65873 .26978 L
.65873 .25997 L
F
.65 .5 .442 .1 k
.62698 .26978 m
.62698 .27959 L
.65873 .27959 L
.65873 .26978 L
F
.65 .5 .458 .1 k
.62698 .27959 m
.62698 .2894 L
.65873 .2894 L
.65873 .27959 L
F
.65 .5 .475 .1 k
.62698 .2894 m
.62698 .29921 L
.65873 .29921 L
.65873 .2894 L
F
.65 .5 .492 .1 k
.62698 .29921 m
.62698 .30902 L
.65873 .30902 L
.65873 .29921 L
F
.65 .5 .508 .1 k
.62698 .30902 m
.62698 .31883 L
.65873 .31883 L
.65873 .30902 L
F
.65 .5 .525 .1 k
.62698 .31883 m
.62698 .32864 L
.65873 .32864 L
.65873 .31883 L
F
.65 .5 .542 .1 k
.62698 .32864 m
.62698 .33845 L
.65873 .33845 L
.65873 .32864 L
F
.65 .5 .558 .1 k
.62698 .33845 m
.62698 .34826 L
.65873 .34826 L
.65873 .33845 L
F
.65 .5 .575 .1 k
.62698 .34826 m
.62698 .35807 L
.65873 .35807 L
.65873 .34826 L
F
.65 .5 .592 .1 k
.62698 .35807 m
.62698 .36788 L
.65873 .36788 L
.65873 .35807 L
F
.65 .5 .608 .1 k
.62698 .36788 m
.62698 .37769 L
.65873 .37769 L
.65873 .36788 L
F
.65 .5 .625 .1 k
.62698 .37769 m
.62698 .3875 L
.65873 .3875 L
.65873 .37769 L
F
.65 .5 .642 .1 k
.62698 .3875 m
.62698 .39731 L
.65873 .39731 L
.65873 .3875 L
F
.65 .5 .658 .1 k
.62698 .39731 m
.62698 .40712 L
.65873 .40712 L
.65873 .39731 L
F
.65 .5 .675 .1 k
.62698 .40712 m
.62698 .41693 L
.65873 .41693 L
.65873 .40712 L
F
.65 .5 .692 .1 k
.62698 .41693 m
.62698 .42674 L
.65873 .42674 L
.65873 .41693 L
F
.65 .5 .708 .1 k
.62698 .42674 m
.62698 .43655 L
.65873 .43655 L
.65873 .42674 L
F
.65 .5 .725 .1 k
.62698 .43655 m
.62698 .44636 L
.65873 .44636 L
.65873 .43655 L
F
.65 .5 .742 .1 k
.62698 .44636 m
.62698 .45617 L
.65873 .45617 L
.65873 .44636 L
F
.65 .5 .758 .1 k
.62698 .45617 m
.62698 .46598 L
.65873 .46598 L
.65873 .45617 L
F
.65 .5 .775 .1 k
.62698 .46598 m
.62698 .47579 L
.65873 .47579 L
.65873 .46598 L
F
.65 .5 .792 .1 k
.62698 .47579 m
.62698 .4856 L
.65873 .4856 L
.65873 .47579 L
F
.65 .5 .808 .1 k
.62698 .4856 m
.62698 .49541 L
.65873 .49541 L
.65873 .4856 L
F
.65 .5 .825 .1 k
.62698 .49541 m
.62698 .50522 L
.65873 .50522 L
.65873 .49541 L
F
.65 .5 .842 .1 k
.62698 .50522 m
.62698 .51503 L
.65873 .51503 L
.65873 .50522 L
F
.65 .5 .858 .1 k
.62698 .51503 m
.62698 .52484 L
.65873 .52484 L
.65873 .51503 L
F
.65 .5 .875 .1 k
.62698 .52484 m
.62698 .53465 L
.65873 .53465 L
.65873 .52484 L
F
.65 .5 .892 .1 k
.62698 .53465 m
.62698 .54446 L
.65873 .54446 L
.65873 .53465 L
F
.65 .5 .908 .1 k
.62698 .54446 m
.62698 .55427 L
.65873 .55427 L
.65873 .54446 L
F
.65 .5 .925 .1 k
.62698 .55427 m
.62698 .56408 L
.65873 .56408 L
.65873 .55427 L
F
.65 .5 .942 .1 k
.62698 .56408 m
.62698 .57389 L
.65873 .57389 L
.65873 .56408 L
F
.65 .5 .958 .1 k
.62698 .57389 m
.62698 .5837 L
.65873 .5837 L
.65873 .57389 L
F
.65 .5 .975 .1 k
.62698 .5837 m
.62698 .59351 L
.65873 .59351 L
.65873 .5837 L
F
.65 .5 .992 .1 k
.62698 .59351 m
.62698 .60332 L
.65873 .60332 L
.65873 .59351 L
F
.683 .5 .008 .1 k
.65873 .01472 m
.65873 .02453 L
.69048 .02453 L
.69048 .01472 L
F
.683 .5 .025 .1 k
.65873 .02453 m
.65873 .03434 L
.69048 .03434 L
.69048 .02453 L
F
.683 .5 .042 .1 k
.65873 .03434 m
.65873 .04415 L
.69048 .04415 L
.69048 .03434 L
F
.683 .5 .058 .1 k
.65873 .04415 m
.65873 .05396 L
.69048 .05396 L
.69048 .04415 L
F
.683 .5 .075 .1 k
.65873 .05396 m
.65873 .06377 L
.69048 .06377 L
.69048 .05396 L
F
.683 .5 .092 .1 k
.65873 .06377 m
.65873 .07358 L
.69048 .07358 L
.69048 .06377 L
F
.683 .5 .108 .1 k
.65873 .07358 m
.65873 .08339 L
.69048 .08339 L
.69048 .07358 L
F
.683 .5 .125 .1 k
.65873 .08339 m
.65873 .0932 L
.69048 .0932 L
.69048 .08339 L
F
.683 .5 .142 .1 k
.65873 .0932 m
.65873 .10301 L
.69048 .10301 L
.69048 .0932 L
F
.683 .5 .158 .1 k
.65873 .10301 m
.65873 .11282 L
.69048 .11282 L
.69048 .10301 L
F
.683 .5 .175 .1 k
.65873 .11282 m
.65873 .12263 L
.69048 .12263 L
.69048 .11282 L
F
.683 .5 .192 .1 k
.65873 .12263 m
.65873 .13244 L
.69048 .13244 L
.69048 .12263 L
F
.683 .5 .208 .1 k
.65873 .13244 m
.65873 .14225 L
.69048 .14225 L
.69048 .13244 L
F
.683 .5 .225 .1 k
.65873 .14225 m
.65873 .15206 L
.69048 .15206 L
.69048 .14225 L
F
.683 .5 .242 .1 k
.65873 .15206 m
.65873 .16187 L
.69048 .16187 L
.69048 .15206 L
F
.683 .5 .258 .1 k
.65873 .16187 m
.65873 .17168 L
.69048 .17168 L
.69048 .16187 L
F
.683 .5 .275 .1 k
.65873 .17168 m
.65873 .18149 L
.69048 .18149 L
.69048 .17168 L
F
.683 .5 .292 .1 k
.65873 .18149 m
.65873 .1913 L
.69048 .1913 L
.69048 .18149 L
F
.683 .5 .308 .1 k
.65873 .1913 m
.65873 .20111 L
.69048 .20111 L
.69048 .1913 L
F
.683 .5 .325 .1 k
.65873 .20111 m
.65873 .21092 L
.69048 .21092 L
.69048 .20111 L
F
.683 .5 .342 .1 k
.65873 .21092 m
.65873 .22073 L
.69048 .22073 L
.69048 .21092 L
F
.683 .5 .358 .1 k
.65873 .22073 m
.65873 .23054 L
.69048 .23054 L
.69048 .22073 L
F
.683 .5 .375 .1 k
.65873 .23054 m
.65873 .24035 L
.69048 .24035 L
.69048 .23054 L
F
.683 .5 .392 .1 k
.65873 .24035 m
.65873 .25016 L
.69048 .25016 L
.69048 .24035 L
F
.683 .5 .408 .1 k
.65873 .25016 m
.65873 .25997 L
.69048 .25997 L
.69048 .25016 L
F
.683 .5 .425 .1 k
.65873 .25997 m
.65873 .26978 L
.69048 .26978 L
.69048 .25997 L
F
.683 .5 .442 .1 k
.65873 .26978 m
.65873 .27959 L
.69048 .27959 L
.69048 .26978 L
F
.683 .5 .458 .1 k
.65873 .27959 m
.65873 .2894 L
.69048 .2894 L
.69048 .27959 L
F
.683 .5 .475 .1 k
.65873 .2894 m
.65873 .29921 L
.69048 .29921 L
.69048 .2894 L
F
.683 .5 .492 .1 k
.65873 .29921 m
.65873 .30902 L
.69048 .30902 L
.69048 .29921 L
F
.683 .5 .508 .1 k
.65873 .30902 m
.65873 .31883 L
.69048 .31883 L
.69048 .30902 L
F
.683 .5 .525 .1 k
.65873 .31883 m
.65873 .32864 L
.69048 .32864 L
.69048 .31883 L
F
.683 .5 .542 .1 k
.65873 .32864 m
.65873 .33845 L
.69048 .33845 L
.69048 .32864 L
F
.683 .5 .558 .1 k
.65873 .33845 m
.65873 .34826 L
.69048 .34826 L
.69048 .33845 L
F
.683 .5 .575 .1 k
.65873 .34826 m
.65873 .35807 L
.69048 .35807 L
.69048 .34826 L
F
.683 .5 .592 .1 k
.65873 .35807 m
.65873 .36788 L
.69048 .36788 L
.69048 .35807 L
F
.683 .5 .608 .1 k
.65873 .36788 m
.65873 .37769 L
.69048 .37769 L
.69048 .36788 L
F
.683 .5 .625 .1 k
.65873 .37769 m
.65873 .3875 L
.69048 .3875 L
.69048 .37769 L
F
.683 .5 .642 .1 k
.65873 .3875 m
.65873 .39731 L
.69048 .39731 L
.69048 .3875 L
F
.683 .5 .658 .1 k
.65873 .39731 m
.65873 .40712 L
.69048 .40712 L
.69048 .39731 L
F
.683 .5 .675 .1 k
.65873 .40712 m
.65873 .41693 L
.69048 .41693 L
.69048 .40712 L
F
.683 .5 .692 .1 k
.65873 .41693 m
.65873 .42674 L
.69048 .42674 L
.69048 .41693 L
F
.683 .5 .708 .1 k
.65873 .42674 m
.65873 .43655 L
.69048 .43655 L
.69048 .42674 L
F
.683 .5 .725 .1 k
.65873 .43655 m
.65873 .44636 L
.69048 .44636 L
.69048 .43655 L
F
.683 .5 .742 .1 k
.65873 .44636 m
.65873 .45617 L
.69048 .45617 L
.69048 .44636 L
F
.683 .5 .758 .1 k
.65873 .45617 m
.65873 .46598 L
.69048 .46598 L
.69048 .45617 L
F
.683 .5 .775 .1 k
.65873 .46598 m
.65873 .47579 L
.69048 .47579 L
.69048 .46598 L
F
.683 .5 .792 .1 k
.65873 .47579 m
.65873 .4856 L
.69048 .4856 L
.69048 .47579 L
F
.683 .5 .808 .1 k
.65873 .4856 m
.65873 .49541 L
.69048 .49541 L
.69048 .4856 L
F
.683 .5 .825 .1 k
.65873 .49541 m
.65873 .50522 L
.69048 .50522 L
.69048 .49541 L
F
.683 .5 .842 .1 k
.65873 .50522 m
.65873 .51503 L
.69048 .51503 L
.69048 .50522 L
F
.683 .5 .858 .1 k
.65873 .51503 m
.65873 .52484 L
.69048 .52484 L
.69048 .51503 L
F
.683 .5 .875 .1 k
.65873 .52484 m
.65873 .53465 L
.69048 .53465 L
.69048 .52484 L
F
.683 .5 .892 .1 k
.65873 .53465 m
.65873 .54446 L
.69048 .54446 L
.69048 .53465 L
F
.683 .5 .908 .1 k
.65873 .54446 m
.65873 .55427 L
.69048 .55427 L
.69048 .54446 L
F
.683 .5 .925 .1 k
.65873 .55427 m
.65873 .56408 L
.69048 .56408 L
.69048 .55427 L
F
.683 .5 .942 .1 k
.65873 .56408 m
.65873 .57389 L
.69048 .57389 L
.69048 .56408 L
F
.683 .5 .958 .1 k
.65873 .57389 m
.65873 .5837 L
.69048 .5837 L
.69048 .57389 L
F
.683 .5 .975 .1 k
.65873 .5837 m
.65873 .59351 L
.69048 .59351 L
.69048 .5837 L
F
.683 .5 .992 .1 k
.65873 .59351 m
.65873 .60332 L
.69048 .60332 L
.69048 .59351 L
F
.717 .5 .008 .1 k
.69048 .01472 m
.69048 .02453 L
.72222 .02453 L
.72222 .01472 L
F
.717 .5 .025 .1 k
.69048 .02453 m
.69048 .03434 L
.72222 .03434 L
.72222 .02453 L
F
.717 .5 .042 .1 k
.69048 .03434 m
.69048 .04415 L
.72222 .04415 L
.72222 .03434 L
F
.717 .5 .058 .1 k
.69048 .04415 m
.69048 .05396 L
.72222 .05396 L
.72222 .04415 L
F
.717 .5 .075 .1 k
.69048 .05396 m
.69048 .06377 L
.72222 .06377 L
.72222 .05396 L
F
.717 .5 .092 .1 k
.69048 .06377 m
.69048 .07358 L
.72222 .07358 L
.72222 .06377 L
F
.717 .5 .108 .1 k
.69048 .07358 m
.69048 .08339 L
.72222 .08339 L
.72222 .07358 L
F
.717 .5 .125 .1 k
.69048 .08339 m
.69048 .0932 L
.72222 .0932 L
.72222 .08339 L
F
.717 .5 .142 .1 k
.69048 .0932 m
.69048 .10301 L
.72222 .10301 L
.72222 .0932 L
F
.717 .5 .158 .1 k
.69048 .10301 m
.69048 .11282 L
.72222 .11282 L
.72222 .10301 L
F
.717 .5 .175 .1 k
.69048 .11282 m
.69048 .12263 L
.72222 .12263 L
.72222 .11282 L
F
.717 .5 .192 .1 k
.69048 .12263 m
.69048 .13244 L
.72222 .13244 L
.72222 .12263 L
F
.717 .5 .208 .1 k
.69048 .13244 m
.69048 .14225 L
.72222 .14225 L
.72222 .13244 L
F
.717 .5 .225 .1 k
.69048 .14225 m
.69048 .15206 L
.72222 .15206 L
.72222 .14225 L
F
.717 .5 .242 .1 k
.69048 .15206 m
.69048 .16187 L
.72222 .16187 L
.72222 .15206 L
F
.717 .5 .258 .1 k
.69048 .16187 m
.69048 .17168 L
.72222 .17168 L
.72222 .16187 L
F
.717 .5 .275 .1 k
.69048 .17168 m
.69048 .18149 L
.72222 .18149 L
.72222 .17168 L
F
.717 .5 .292 .1 k
.69048 .18149 m
.69048 .1913 L
.72222 .1913 L
.72222 .18149 L
F
.717 .5 .308 .1 k
.69048 .1913 m
.69048 .20111 L
.72222 .20111 L
.72222 .1913 L
F
.717 .5 .325 .1 k
.69048 .20111 m
.69048 .21092 L
.72222 .21092 L
.72222 .20111 L
F
.717 .5 .342 .1 k
.69048 .21092 m
.69048 .22073 L
.72222 .22073 L
.72222 .21092 L
F
.717 .5 .358 .1 k
.69048 .22073 m
.69048 .23054 L
.72222 .23054 L
.72222 .22073 L
F
.717 .5 .375 .1 k
.69048 .23054 m
.69048 .24035 L
.72222 .24035 L
.72222 .23054 L
F
.717 .5 .392 .1 k
.69048 .24035 m
.69048 .25016 L
.72222 .25016 L
.72222 .24035 L
F
.717 .5 .408 .1 k
.69048 .25016 m
.69048 .25997 L
.72222 .25997 L
.72222 .25016 L
F
.717 .5 .425 .1 k
.69048 .25997 m
.69048 .26978 L
.72222 .26978 L
.72222 .25997 L
F
.717 .5 .442 .1 k
.69048 .26978 m
.69048 .27959 L
.72222 .27959 L
.72222 .26978 L
F
.717 .5 .458 .1 k
.69048 .27959 m
.69048 .2894 L
.72222 .2894 L
.72222 .27959 L
F
.717 .5 .475 .1 k
.69048 .2894 m
.69048 .29921 L
.72222 .29921 L
.72222 .2894 L
F
.717 .5 .492 .1 k
.69048 .29921 m
.69048 .30902 L
.72222 .30902 L
.72222 .29921 L
F
.717 .5 .508 .1 k
.69048 .30902 m
.69048 .31883 L
.72222 .31883 L
.72222 .30902 L
F
.717 .5 .525 .1 k
.69048 .31883 m
.69048 .32864 L
.72222 .32864 L
.72222 .31883 L
F
.717 .5 .542 .1 k
.69048 .32864 m
.69048 .33845 L
.72222 .33845 L
.72222 .32864 L
F
.717 .5 .558 .1 k
.69048 .33845 m
.69048 .34826 L
.72222 .34826 L
.72222 .33845 L
F
.717 .5 .575 .1 k
.69048 .34826 m
.69048 .35807 L
.72222 .35807 L
.72222 .34826 L
F
.717 .5 .592 .1 k
.69048 .35807 m
.69048 .36788 L
.72222 .36788 L
.72222 .35807 L
F
.717 .5 .608 .1 k
.69048 .36788 m
.69048 .37769 L
.72222 .37769 L
.72222 .36788 L
F
.717 .5 .625 .1 k
.69048 .37769 m
.69048 .3875 L
.72222 .3875 L
.72222 .37769 L
F
.717 .5 .642 .1 k
.69048 .3875 m
.69048 .39731 L
.72222 .39731 L
.72222 .3875 L
F
.717 .5 .658 .1 k
.69048 .39731 m
.69048 .40712 L
.72222 .40712 L
.72222 .39731 L
F
.717 .5 .675 .1 k
.69048 .40712 m
.69048 .41693 L
.72222 .41693 L
.72222 .40712 L
F
.717 .5 .692 .1 k
.69048 .41693 m
.69048 .42674 L
.72222 .42674 L
.72222 .41693 L
F
.717 .5 .708 .1 k
.69048 .42674 m
.69048 .43655 L
.72222 .43655 L
.72222 .42674 L
F
.717 .5 .725 .1 k
.69048 .43655 m
.69048 .44636 L
.72222 .44636 L
.72222 .43655 L
F
.717 .5 .742 .1 k
.69048 .44636 m
.69048 .45617 L
.72222 .45617 L
.72222 .44636 L
F
.717 .5 .758 .1 k
.69048 .45617 m
.69048 .46598 L
.72222 .46598 L
.72222 .45617 L
F
.717 .5 .775 .1 k
.69048 .46598 m
.69048 .47579 L
.72222 .47579 L
.72222 .46598 L
F
.717 .5 .792 .1 k
.69048 .47579 m
.69048 .4856 L
.72222 .4856 L
.72222 .47579 L
F
.717 .5 .808 .1 k
.69048 .4856 m
.69048 .49541 L
.72222 .49541 L
.72222 .4856 L
F
.717 .5 .825 .1 k
.69048 .49541 m
.69048 .50522 L
.72222 .50522 L
.72222 .49541 L
F
.717 .5 .842 .1 k
.69048 .50522 m
.69048 .51503 L
.72222 .51503 L
.72222 .50522 L
F
.717 .5 .858 .1 k
.69048 .51503 m
.69048 .52484 L
.72222 .52484 L
.72222 .51503 L
F
.717 .5 .875 .1 k
.69048 .52484 m
.69048 .53465 L
.72222 .53465 L
.72222 .52484 L
F
.717 .5 .892 .1 k
.69048 .53465 m
.69048 .54446 L
.72222 .54446 L
.72222 .53465 L
F
.717 .5 .908 .1 k
.69048 .54446 m
.69048 .55427 L
.72222 .55427 L
.72222 .54446 L
F
.717 .5 .925 .1 k
.69048 .55427 m
.69048 .56408 L
.72222 .56408 L
.72222 .55427 L
F
.717 .5 .942 .1 k
.69048 .56408 m
.69048 .57389 L
.72222 .57389 L
.72222 .56408 L
F
.717 .5 .958 .1 k
.69048 .57389 m
.69048 .5837 L
.72222 .5837 L
.72222 .57389 L
F
.717 .5 .975 .1 k
.69048 .5837 m
.69048 .59351 L
.72222 .59351 L
.72222 .5837 L
F
.717 .5 .992 .1 k
.69048 .59351 m
.69048 .60332 L
.72222 .60332 L
.72222 .59351 L
F
.75 .5 .008 .1 k
.72222 .01472 m
.72222 .02453 L
.75397 .02453 L
.75397 .01472 L
F
.75 .5 .025 .1 k
.72222 .02453 m
.72222 .03434 L
.75397 .03434 L
.75397 .02453 L
F
.75 .5 .042 .1 k
.72222 .03434 m
.72222 .04415 L
.75397 .04415 L
.75397 .03434 L
F
.75 .5 .058 .1 k
.72222 .04415 m
.72222 .05396 L
.75397 .05396 L
.75397 .04415 L
F
.75 .5 .075 .1 k
.72222 .05396 m
.72222 .06377 L
.75397 .06377 L
.75397 .05396 L
F
.75 .5 .092 .1 k
.72222 .06377 m
.72222 .07358 L
.75397 .07358 L
.75397 .06377 L
F
.75 .5 .108 .1 k
.72222 .07358 m
.72222 .08339 L
.75397 .08339 L
.75397 .07358 L
F
.75 .5 .125 .1 k
.72222 .08339 m
.72222 .0932 L
.75397 .0932 L
.75397 .08339 L
F
.75 .5 .142 .1 k
.72222 .0932 m
.72222 .10301 L
.75397 .10301 L
.75397 .0932 L
F
.75 .5 .158 .1 k
.72222 .10301 m
.72222 .11282 L
.75397 .11282 L
.75397 .10301 L
F
.75 .5 .175 .1 k
.72222 .11282 m
.72222 .12263 L
.75397 .12263 L
.75397 .11282 L
F
.75 .5 .192 .1 k
.72222 .12263 m
.72222 .13244 L
.75397 .13244 L
.75397 .12263 L
F
.75 .5 .208 .1 k
.72222 .13244 m
.72222 .14225 L
.75397 .14225 L
.75397 .13244 L
F
.75 .5 .225 .1 k
.72222 .14225 m
.72222 .15206 L
.75397 .15206 L
.75397 .14225 L
F
.75 .5 .242 .1 k
.72222 .15206 m
.72222 .16187 L
.75397 .16187 L
.75397 .15206 L
F
.75 .5 .258 .1 k
.72222 .16187 m
.72222 .17168 L
.75397 .17168 L
.75397 .16187 L
F
.75 .5 .275 .1 k
.72222 .17168 m
.72222 .18149 L
.75397 .18149 L
.75397 .17168 L
F
.75 .5 .292 .1 k
.72222 .18149 m
.72222 .1913 L
.75397 .1913 L
.75397 .18149 L
F
.75 .5 .308 .1 k
.72222 .1913 m
.72222 .20111 L
.75397 .20111 L
.75397 .1913 L
F
.75 .5 .325 .1 k
.72222 .20111 m
.72222 .21092 L
.75397 .21092 L
.75397 .20111 L
F
.75 .5 .342 .1 k
.72222 .21092 m
.72222 .22073 L
.75397 .22073 L
.75397 .21092 L
F
.75 .5 .358 .1 k
.72222 .22073 m
.72222 .23054 L
.75397 .23054 L
.75397 .22073 L
F
.75 .5 .375 .1 k
.72222 .23054 m
.72222 .24035 L
.75397 .24035 L
.75397 .23054 L
F
.75 .5 .392 .1 k
.72222 .24035 m
.72222 .25016 L
.75397 .25016 L
.75397 .24035 L
F
.75 .5 .408 .1 k
.72222 .25016 m
.72222 .25997 L
.75397 .25997 L
.75397 .25016 L
F
.75 .5 .425 .1 k
.72222 .25997 m
.72222 .26978 L
.75397 .26978 L
.75397 .25997 L
F
.75 .5 .442 .1 k
.72222 .26978 m
.72222 .27959 L
.75397 .27959 L
.75397 .26978 L
F
.75 .5 .458 .1 k
.72222 .27959 m
.72222 .2894 L
.75397 .2894 L
.75397 .27959 L
F
.75 .5 .475 .1 k
.72222 .2894 m
.72222 .29921 L
.75397 .29921 L
.75397 .2894 L
F
.75 .5 .492 .1 k
.72222 .29921 m
.72222 .30902 L
.75397 .30902 L
.75397 .29921 L
F
.75 .5 .508 .1 k
.72222 .30902 m
.72222 .31883 L
.75397 .31883 L
.75397 .30902 L
F
.75 .5 .525 .1 k
.72222 .31883 m
.72222 .32864 L
.75397 .32864 L
.75397 .31883 L
F
.75 .5 .542 .1 k
.72222 .32864 m
.72222 .33845 L
.75397 .33845 L
.75397 .32864 L
F
.75 .5 .558 .1 k
.72222 .33845 m
.72222 .34826 L
.75397 .34826 L
.75397 .33845 L
F
.75 .5 .575 .1 k
.72222 .34826 m
.72222 .35807 L
.75397 .35807 L
.75397 .34826 L
F
.75 .5 .592 .1 k
.72222 .35807 m
.72222 .36788 L
.75397 .36788 L
.75397 .35807 L
F
.75 .5 .608 .1 k
.72222 .36788 m
.72222 .37769 L
.75397 .37769 L
.75397 .36788 L
F
.75 .5 .625 .1 k
.72222 .37769 m
.72222 .3875 L
.75397 .3875 L
.75397 .37769 L
F
.75 .5 .642 .1 k
.72222 .3875 m
.72222 .39731 L
.75397 .39731 L
.75397 .3875 L
F
.75 .5 .658 .1 k
.72222 .39731 m
.72222 .40712 L
.75397 .40712 L
.75397 .39731 L
F
.75 .5 .675 .1 k
.72222 .40712 m
.72222 .41693 L
.75397 .41693 L
.75397 .40712 L
F
.75 .5 .692 .1 k
.72222 .41693 m
.72222 .42674 L
.75397 .42674 L
.75397 .41693 L
F
.75 .5 .708 .1 k
.72222 .42674 m
.72222 .43655 L
.75397 .43655 L
.75397 .42674 L
F
.75 .5 .725 .1 k
.72222 .43655 m
.72222 .44636 L
.75397 .44636 L
.75397 .43655 L
F
.75 .5 .742 .1 k
.72222 .44636 m
.72222 .45617 L
.75397 .45617 L
.75397 .44636 L
F
.75 .5 .758 .1 k
.72222 .45617 m
.72222 .46598 L
.75397 .46598 L
.75397 .45617 L
F
.75 .5 .775 .1 k
.72222 .46598 m
.72222 .47579 L
.75397 .47579 L
.75397 .46598 L
F
.75 .5 .792 .1 k
.72222 .47579 m
.72222 .4856 L
.75397 .4856 L
.75397 .47579 L
F
.75 .5 .808 .1 k
.72222 .4856 m
.72222 .49541 L
.75397 .49541 L
.75397 .4856 L
F
.75 .5 .825 .1 k
.72222 .49541 m
.72222 .50522 L
.75397 .50522 L
.75397 .49541 L
F
.75 .5 .842 .1 k
.72222 .50522 m
.72222 .51503 L
.75397 .51503 L
.75397 .50522 L
F
.75 .5 .858 .1 k
.72222 .51503 m
.72222 .52484 L
.75397 .52484 L
.75397 .51503 L
F
.75 .5 .875 .1 k
.72222 .52484 m
.72222 .53465 L
.75397 .53465 L
.75397 .52484 L
F
.75 .5 .892 .1 k
.72222 .53465 m
.72222 .54446 L
.75397 .54446 L
.75397 .53465 L
F
.75 .5 .908 .1 k
.72222 .54446 m
.72222 .55427 L
.75397 .55427 L
.75397 .54446 L
F
.75 .5 .925 .1 k
.72222 .55427 m
.72222 .56408 L
.75397 .56408 L
.75397 .55427 L
F
.75 .5 .942 .1 k
.72222 .56408 m
.72222 .57389 L
.75397 .57389 L
.75397 .56408 L
F
.75 .5 .958 .1 k
.72222 .57389 m
.72222 .5837 L
.75397 .5837 L
.75397 .57389 L
F
.75 .5 .975 .1 k
.72222 .5837 m
.72222 .59351 L
.75397 .59351 L
.75397 .5837 L
F
.75 .5 .992 .1 k
.72222 .59351 m
.72222 .60332 L
.75397 .60332 L
.75397 .59351 L
F
.783 .5 .008 .1 k
.75397 .01472 m
.75397 .02453 L
.78571 .02453 L
.78571 .01472 L
F
.783 .5 .025 .1 k
.75397 .02453 m
.75397 .03434 L
.78571 .03434 L
.78571 .02453 L
F
.783 .5 .042 .1 k
.75397 .03434 m
.75397 .04415 L
.78571 .04415 L
.78571 .03434 L
F
.783 .5 .058 .1 k
.75397 .04415 m
.75397 .05396 L
.78571 .05396 L
.78571 .04415 L
F
.783 .5 .075 .1 k
.75397 .05396 m
.75397 .06377 L
.78571 .06377 L
.78571 .05396 L
F
.783 .5 .092 .1 k
.75397 .06377 m
.75397 .07358 L
.78571 .07358 L
.78571 .06377 L
F
.783 .5 .108 .1 k
.75397 .07358 m
.75397 .08339 L
.78571 .08339 L
.78571 .07358 L
F
.783 .5 .125 .1 k
.75397 .08339 m
.75397 .0932 L
.78571 .0932 L
.78571 .08339 L
F
.783 .5 .142 .1 k
.75397 .0932 m
.75397 .10301 L
.78571 .10301 L
.78571 .0932 L
F
.783 .5 .158 .1 k
.75397 .10301 m
.75397 .11282 L
.78571 .11282 L
.78571 .10301 L
F
.783 .5 .175 .1 k
.75397 .11282 m
.75397 .12263 L
.78571 .12263 L
.78571 .11282 L
F
.783 .5 .192 .1 k
.75397 .12263 m
.75397 .13244 L
.78571 .13244 L
.78571 .12263 L
F
.783 .5 .208 .1 k
.75397 .13244 m
.75397 .14225 L
.78571 .14225 L
.78571 .13244 L
F
.783 .5 .225 .1 k
.75397 .14225 m
.75397 .15206 L
.78571 .15206 L
.78571 .14225 L
F
.783 .5 .242 .1 k
.75397 .15206 m
.75397 .16187 L
.78571 .16187 L
.78571 .15206 L
F
.783 .5 .258 .1 k
.75397 .16187 m
.75397 .17168 L
.78571 .17168 L
.78571 .16187 L
F
.783 .5 .275 .1 k
.75397 .17168 m
.75397 .18149 L
.78571 .18149 L
.78571 .17168 L
F
.783 .5 .292 .1 k
.75397 .18149 m
.75397 .1913 L
.78571 .1913 L
.78571 .18149 L
F
.783 .5 .308 .1 k
.75397 .1913 m
.75397 .20111 L
.78571 .20111 L
.78571 .1913 L
F
.783 .5 .325 .1 k
.75397 .20111 m
.75397 .21092 L
.78571 .21092 L
.78571 .20111 L
F
.783 .5 .342 .1 k
.75397 .21092 m
.75397 .22073 L
.78571 .22073 L
.78571 .21092 L
F
.783 .5 .358 .1 k
.75397 .22073 m
.75397 .23054 L
.78571 .23054 L
.78571 .22073 L
F
.783 .5 .375 .1 k
.75397 .23054 m
.75397 .24035 L
.78571 .24035 L
.78571 .23054 L
F
.783 .5 .392 .1 k
.75397 .24035 m
.75397 .25016 L
.78571 .25016 L
.78571 .24035 L
F
.783 .5 .408 .1 k
.75397 .25016 m
.75397 .25997 L
.78571 .25997 L
.78571 .25016 L
F
.783 .5 .425 .1 k
.75397 .25997 m
.75397 .26978 L
.78571 .26978 L
.78571 .25997 L
F
.783 .5 .442 .1 k
.75397 .26978 m
.75397 .27959 L
.78571 .27959 L
.78571 .26978 L
F
.783 .5 .458 .1 k
.75397 .27959 m
.75397 .2894 L
.78571 .2894 L
.78571 .27959 L
F
.783 .5 .475 .1 k
.75397 .2894 m
.75397 .29921 L
.78571 .29921 L
.78571 .2894 L
F
.783 .5 .492 .1 k
.75397 .29921 m
.75397 .30902 L
.78571 .30902 L
.78571 .29921 L
F
.783 .5 .508 .1 k
.75397 .30902 m
.75397 .31883 L
.78571 .31883 L
.78571 .30902 L
F
.783 .5 .525 .1 k
.75397 .31883 m
.75397 .32864 L
.78571 .32864 L
.78571 .31883 L
F
.783 .5 .542 .1 k
.75397 .32864 m
.75397 .33845 L
.78571 .33845 L
.78571 .32864 L
F
.783 .5 .558 .1 k
.75397 .33845 m
.75397 .34826 L
.78571 .34826 L
.78571 .33845 L
F
.783 .5 .575 .1 k
.75397 .34826 m
.75397 .35807 L
.78571 .35807 L
.78571 .34826 L
F
.783 .5 .592 .1 k
.75397 .35807 m
.75397 .36788 L
.78571 .36788 L
.78571 .35807 L
F
.783 .5 .608 .1 k
.75397 .36788 m
.75397 .37769 L
.78571 .37769 L
.78571 .36788 L
F
.783 .5 .625 .1 k
.75397 .37769 m
.75397 .3875 L
.78571 .3875 L
.78571 .37769 L
F
.783 .5 .642 .1 k
.75397 .3875 m
.75397 .39731 L
.78571 .39731 L
.78571 .3875 L
F
.783 .5 .658 .1 k
.75397 .39731 m
.75397 .40712 L
.78571 .40712 L
.78571 .39731 L
F
.783 .5 .675 .1 k
.75397 .40712 m
.75397 .41693 L
.78571 .41693 L
.78571 .40712 L
F
.783 .5 .692 .1 k
.75397 .41693 m
.75397 .42674 L
.78571 .42674 L
.78571 .41693 L
F
.783 .5 .708 .1 k
.75397 .42674 m
.75397 .43655 L
.78571 .43655 L
.78571 .42674 L
F
.783 .5 .725 .1 k
.75397 .43655 m
.75397 .44636 L
.78571 .44636 L
.78571 .43655 L
F
.783 .5 .742 .1 k
.75397 .44636 m
.75397 .45617 L
.78571 .45617 L
.78571 .44636 L
F
.783 .5 .758 .1 k
.75397 .45617 m
.75397 .46598 L
.78571 .46598 L
.78571 .45617 L
F
.783 .5 .775 .1 k
.75397 .46598 m
.75397 .47579 L
.78571 .47579 L
.78571 .46598 L
F
.783 .5 .792 .1 k
.75397 .47579 m
.75397 .4856 L
.78571 .4856 L
.78571 .47579 L
F
.783 .5 .808 .1 k
.75397 .4856 m
.75397 .49541 L
.78571 .49541 L
.78571 .4856 L
F
.783 .5 .825 .1 k
.75397 .49541 m
.75397 .50522 L
.78571 .50522 L
.78571 .49541 L
F
.783 .5 .842 .1 k
.75397 .50522 m
.75397 .51503 L
.78571 .51503 L
.78571 .50522 L
F
.783 .5 .858 .1 k
.75397 .51503 m
.75397 .52484 L
.78571 .52484 L
.78571 .51503 L
F
.783 .5 .875 .1 k
.75397 .52484 m
.75397 .53465 L
.78571 .53465 L
.78571 .52484 L
F
.783 .5 .892 .1 k
.75397 .53465 m
.75397 .54446 L
.78571 .54446 L
.78571 .53465 L
F
.783 .5 .908 .1 k
.75397 .54446 m
.75397 .55427 L
.78571 .55427 L
.78571 .54446 L
F
.783 .5 .925 .1 k
.75397 .55427 m
.75397 .56408 L
.78571 .56408 L
.78571 .55427 L
F
.783 .5 .942 .1 k
.75397 .56408 m
.75397 .57389 L
.78571 .57389 L
.78571 .56408 L
F
.783 .5 .958 .1 k
.75397 .57389 m
.75397 .5837 L
.78571 .5837 L
.78571 .57389 L
F
.783 .5 .975 .1 k
.75397 .5837 m
.75397 .59351 L
.78571 .59351 L
.78571 .5837 L
F
.783 .5 .992 .1 k
.75397 .59351 m
.75397 .60332 L
.78571 .60332 L
.78571 .59351 L
F
.817 .5 .008 .1 k
.78571 .01472 m
.78571 .02453 L
.81746 .02453 L
.81746 .01472 L
F
.817 .5 .025 .1 k
.78571 .02453 m
.78571 .03434 L
.81746 .03434 L
.81746 .02453 L
F
.817 .5 .042 .1 k
.78571 .03434 m
.78571 .04415 L
.81746 .04415 L
.81746 .03434 L
F
.817 .5 .058 .1 k
.78571 .04415 m
.78571 .05396 L
.81746 .05396 L
.81746 .04415 L
F
.817 .5 .075 .1 k
.78571 .05396 m
.78571 .06377 L
.81746 .06377 L
.81746 .05396 L
F
.817 .5 .092 .1 k
.78571 .06377 m
.78571 .07358 L
.81746 .07358 L
.81746 .06377 L
F
.817 .5 .108 .1 k
.78571 .07358 m
.78571 .08339 L
.81746 .08339 L
.81746 .07358 L
F
.817 .5 .125 .1 k
.78571 .08339 m
.78571 .0932 L
.81746 .0932 L
.81746 .08339 L
F
.817 .5 .142 .1 k
.78571 .0932 m
.78571 .10301 L
.81746 .10301 L
.81746 .0932 L
F
.817 .5 .158 .1 k
.78571 .10301 m
.78571 .11282 L
.81746 .11282 L
.81746 .10301 L
F
.817 .5 .175 .1 k
.78571 .11282 m
.78571 .12263 L
.81746 .12263 L
.81746 .11282 L
F
.817 .5 .192 .1 k
.78571 .12263 m
.78571 .13244 L
.81746 .13244 L
.81746 .12263 L
F
.817 .5 .208 .1 k
.78571 .13244 m
.78571 .14225 L
.81746 .14225 L
.81746 .13244 L
F
.817 .5 .225 .1 k
.78571 .14225 m
.78571 .15206 L
.81746 .15206 L
.81746 .14225 L
F
.817 .5 .242 .1 k
.78571 .15206 m
.78571 .16187 L
.81746 .16187 L
.81746 .15206 L
F
.817 .5 .258 .1 k
.78571 .16187 m
.78571 .17168 L
.81746 .17168 L
.81746 .16187 L
F
.817 .5 .275 .1 k
.78571 .17168 m
.78571 .18149 L
.81746 .18149 L
.81746 .17168 L
F
.817 .5 .292 .1 k
.78571 .18149 m
.78571 .1913 L
.81746 .1913 L
.81746 .18149 L
F
.817 .5 .308 .1 k
.78571 .1913 m
.78571 .20111 L
.81746 .20111 L
.81746 .1913 L
F
.817 .5 .325 .1 k
.78571 .20111 m
.78571 .21092 L
.81746 .21092 L
.81746 .20111 L
F
.817 .5 .342 .1 k
.78571 .21092 m
.78571 .22073 L
.81746 .22073 L
.81746 .21092 L
F
.817 .5 .358 .1 k
.78571 .22073 m
.78571 .23054 L
.81746 .23054 L
.81746 .22073 L
F
.817 .5 .375 .1 k
.78571 .23054 m
.78571 .24035 L
.81746 .24035 L
.81746 .23054 L
F
.817 .5 .392 .1 k
.78571 .24035 m
.78571 .25016 L
.81746 .25016 L
.81746 .24035 L
F
.817 .5 .408 .1 k
.78571 .25016 m
.78571 .25997 L
.81746 .25997 L
.81746 .25016 L
F
.817 .5 .425 .1 k
.78571 .25997 m
.78571 .26978 L
.81746 .26978 L
.81746 .25997 L
F
.817 .5 .442 .1 k
.78571 .26978 m
.78571 .27959 L
.81746 .27959 L
.81746 .26978 L
F
.817 .5 .458 .1 k
.78571 .27959 m
.78571 .2894 L
.81746 .2894 L
.81746 .27959 L
F
.817 .5 .475 .1 k
.78571 .2894 m
.78571 .29921 L
.81746 .29921 L
.81746 .2894 L
F
.817 .5 .492 .1 k
.78571 .29921 m
.78571 .30902 L
.81746 .30902 L
.81746 .29921 L
F
.817 .5 .508 .1 k
.78571 .30902 m
.78571 .31883 L
.81746 .31883 L
.81746 .30902 L
F
.817 .5 .525 .1 k
.78571 .31883 m
.78571 .32864 L
.81746 .32864 L
.81746 .31883 L
F
.817 .5 .542 .1 k
.78571 .32864 m
.78571 .33845 L
.81746 .33845 L
.81746 .32864 L
F
.817 .5 .558 .1 k
.78571 .33845 m
.78571 .34826 L
.81746 .34826 L
.81746 .33845 L
F
.817 .5 .575 .1 k
.78571 .34826 m
.78571 .35807 L
.81746 .35807 L
.81746 .34826 L
F
.817 .5 .592 .1 k
.78571 .35807 m
.78571 .36788 L
.81746 .36788 L
.81746 .35807 L
F
.817 .5 .608 .1 k
.78571 .36788 m
.78571 .37769 L
.81746 .37769 L
.81746 .36788 L
F
.817 .5 .625 .1 k
.78571 .37769 m
.78571 .3875 L
.81746 .3875 L
.81746 .37769 L
F
.817 .5 .642 .1 k
.78571 .3875 m
.78571 .39731 L
.81746 .39731 L
.81746 .3875 L
F
.817 .5 .658 .1 k
.78571 .39731 m
.78571 .40712 L
.81746 .40712 L
.81746 .39731 L
F
.817 .5 .675 .1 k
.78571 .40712 m
.78571 .41693 L
.81746 .41693 L
.81746 .40712 L
F
.817 .5 .692 .1 k
.78571 .41693 m
.78571 .42674 L
.81746 .42674 L
.81746 .41693 L
F
.817 .5 .708 .1 k
.78571 .42674 m
.78571 .43655 L
.81746 .43655 L
.81746 .42674 L
F
.817 .5 .725 .1 k
.78571 .43655 m
.78571 .44636 L
.81746 .44636 L
.81746 .43655 L
F
.817 .5 .742 .1 k
.78571 .44636 m
.78571 .45617 L
.81746 .45617 L
.81746 .44636 L
F
.817 .5 .758 .1 k
.78571 .45617 m
.78571 .46598 L
.81746 .46598 L
.81746 .45617 L
F
.817 .5 .775 .1 k
.78571 .46598 m
.78571 .47579 L
.81746 .47579 L
.81746 .46598 L
F
.817 .5 .792 .1 k
.78571 .47579 m
.78571 .4856 L
.81746 .4856 L
.81746 .47579 L
F
.817 .5 .808 .1 k
.78571 .4856 m
.78571 .49541 L
.81746 .49541 L
.81746 .4856 L
F
.817 .5 .825 .1 k
.78571 .49541 m
.78571 .50522 L
.81746 .50522 L
.81746 .49541 L
F
.817 .5 .842 .1 k
.78571 .50522 m
.78571 .51503 L
.81746 .51503 L
.81746 .50522 L
F
.817 .5 .858 .1 k
.78571 .51503 m
.78571 .52484 L
.81746 .52484 L
.81746 .51503 L
F
.817 .5 .875 .1 k
.78571 .52484 m
.78571 .53465 L
.81746 .53465 L
.81746 .52484 L
F
.817 .5 .892 .1 k
.78571 .53465 m
.78571 .54446 L
.81746 .54446 L
.81746 .53465 L
F
.817 .5 .908 .1 k
.78571 .54446 m
.78571 .55427 L
.81746 .55427 L
.81746 .54446 L
F
.817 .5 .925 .1 k
.78571 .55427 m
.78571 .56408 L
.81746 .56408 L
.81746 .55427 L
F
.817 .5 .942 .1 k
.78571 .56408 m
.78571 .57389 L
.81746 .57389 L
.81746 .56408 L
F
.817 .5 .958 .1 k
.78571 .57389 m
.78571 .5837 L
.81746 .5837 L
.81746 .57389 L
F
.817 .5 .975 .1 k
.78571 .5837 m
.78571 .59351 L
.81746 .59351 L
.81746 .5837 L
F
.817 .5 .992 .1 k
.78571 .59351 m
.78571 .60332 L
.81746 .60332 L
.81746 .59351 L
F
.85 .5 .008 .1 k
.81746 .01472 m
.81746 .02453 L
.84921 .02453 L
.84921 .01472 L
F
.85 .5 .025 .1 k
.81746 .02453 m
.81746 .03434 L
.84921 .03434 L
.84921 .02453 L
F
.85 .5 .042 .1 k
.81746 .03434 m
.81746 .04415 L
.84921 .04415 L
.84921 .03434 L
F
.85 .5 .058 .1 k
.81746 .04415 m
.81746 .05396 L
.84921 .05396 L
.84921 .04415 L
F
.85 .5 .075 .1 k
.81746 .05396 m
.81746 .06377 L
.84921 .06377 L
.84921 .05396 L
F
.85 .5 .092 .1 k
.81746 .06377 m
.81746 .07358 L
.84921 .07358 L
.84921 .06377 L
F
.85 .5 .108 .1 k
.81746 .07358 m
.81746 .08339 L
.84921 .08339 L
.84921 .07358 L
F
.85 .5 .125 .1 k
.81746 .08339 m
.81746 .0932 L
.84921 .0932 L
.84921 .08339 L
F
.85 .5 .142 .1 k
.81746 .0932 m
.81746 .10301 L
.84921 .10301 L
.84921 .0932 L
F
.85 .5 .158 .1 k
.81746 .10301 m
.81746 .11282 L
.84921 .11282 L
.84921 .10301 L
F
.85 .5 .175 .1 k
.81746 .11282 m
.81746 .12263 L
.84921 .12263 L
.84921 .11282 L
F
.85 .5 .192 .1 k
.81746 .12263 m
.81746 .13244 L
.84921 .13244 L
.84921 .12263 L
F
.85 .5 .208 .1 k
.81746 .13244 m
.81746 .14225 L
.84921 .14225 L
.84921 .13244 L
F
.85 .5 .225 .1 k
.81746 .14225 m
.81746 .15206 L
.84921 .15206 L
.84921 .14225 L
F
.85 .5 .242 .1 k
.81746 .15206 m
.81746 .16187 L
.84921 .16187 L
.84921 .15206 L
F
.85 .5 .258 .1 k
.81746 .16187 m
.81746 .17168 L
.84921 .17168 L
.84921 .16187 L
F
.85 .5 .275 .1 k
.81746 .17168 m
.81746 .18149 L
.84921 .18149 L
.84921 .17168 L
F
.85 .5 .292 .1 k
.81746 .18149 m
.81746 .1913 L
.84921 .1913 L
.84921 .18149 L
F
.85 .5 .308 .1 k
.81746 .1913 m
.81746 .20111 L
.84921 .20111 L
.84921 .1913 L
F
.85 .5 .325 .1 k
.81746 .20111 m
.81746 .21092 L
.84921 .21092 L
.84921 .20111 L
F
.85 .5 .342 .1 k
.81746 .21092 m
.81746 .22073 L
.84921 .22073 L
.84921 .21092 L
F
.85 .5 .358 .1 k
.81746 .22073 m
.81746 .23054 L
.84921 .23054 L
.84921 .22073 L
F
.85 .5 .375 .1 k
.81746 .23054 m
.81746 .24035 L
.84921 .24035 L
.84921 .23054 L
F
.85 .5 .392 .1 k
.81746 .24035 m
.81746 .25016 L
.84921 .25016 L
.84921 .24035 L
F
.85 .5 .408 .1 k
.81746 .25016 m
.81746 .25997 L
.84921 .25997 L
.84921 .25016 L
F
.85 .5 .425 .1 k
.81746 .25997 m
.81746 .26978 L
.84921 .26978 L
.84921 .25997 L
F
.85 .5 .442 .1 k
.81746 .26978 m
.81746 .27959 L
.84921 .27959 L
.84921 .26978 L
F
.85 .5 .458 .1 k
.81746 .27959 m
.81746 .2894 L
.84921 .2894 L
.84921 .27959 L
F
.85 .5 .475 .1 k
.81746 .2894 m
.81746 .29921 L
.84921 .29921 L
.84921 .2894 L
F
.85 .5 .492 .1 k
.81746 .29921 m
.81746 .30902 L
.84921 .30902 L
.84921 .29921 L
F
.85 .5 .508 .1 k
.81746 .30902 m
.81746 .31883 L
.84921 .31883 L
.84921 .30902 L
F
.85 .5 .525 .1 k
.81746 .31883 m
.81746 .32864 L
.84921 .32864 L
.84921 .31883 L
F
.85 .5 .542 .1 k
.81746 .32864 m
.81746 .33845 L
.84921 .33845 L
.84921 .32864 L
F
.85 .5 .558 .1 k
.81746 .33845 m
.81746 .34826 L
.84921 .34826 L
.84921 .33845 L
F
.85 .5 .575 .1 k
.81746 .34826 m
.81746 .35807 L
.84921 .35807 L
.84921 .34826 L
F
.85 .5 .592 .1 k
.81746 .35807 m
.81746 .36788 L
.84921 .36788 L
.84921 .35807 L
F
.85 .5 .608 .1 k
.81746 .36788 m
.81746 .37769 L
.84921 .37769 L
.84921 .36788 L
F
.85 .5 .625 .1 k
.81746 .37769 m
.81746 .3875 L
.84921 .3875 L
.84921 .37769 L
F
.85 .5 .642 .1 k
.81746 .3875 m
.81746 .39731 L
.84921 .39731 L
.84921 .3875 L
F
.85 .5 .658 .1 k
.81746 .39731 m
.81746 .40712 L
.84921 .40712 L
.84921 .39731 L
F
.85 .5 .675 .1 k
.81746 .40712 m
.81746 .41693 L
.84921 .41693 L
.84921 .40712 L
F
.85 .5 .692 .1 k
.81746 .41693 m
.81746 .42674 L
.84921 .42674 L
.84921 .41693 L
F
.85 .5 .708 .1 k
.81746 .42674 m
.81746 .43655 L
.84921 .43655 L
.84921 .42674 L
F
.85 .5 .725 .1 k
.81746 .43655 m
.81746 .44636 L
.84921 .44636 L
.84921 .43655 L
F
.85 .5 .742 .1 k
.81746 .44636 m
.81746 .45617 L
.84921 .45617 L
.84921 .44636 L
F
.85 .5 .758 .1 k
.81746 .45617 m
.81746 .46598 L
.84921 .46598 L
.84921 .45617 L
F
.85 .5 .775 .1 k
.81746 .46598 m
.81746 .47579 L
.84921 .47579 L
.84921 .46598 L
F
.85 .5 .792 .1 k
.81746 .47579 m
.81746 .4856 L
.84921 .4856 L
.84921 .47579 L
F
.85 .5 .808 .1 k
.81746 .4856 m
.81746 .49541 L
.84921 .49541 L
.84921 .4856 L
F
.85 .5 .825 .1 k
.81746 .49541 m
.81746 .50522 L
.84921 .50522 L
.84921 .49541 L
F
.85 .5 .842 .1 k
.81746 .50522 m
.81746 .51503 L
.84921 .51503 L
.84921 .50522 L
F
.85 .5 .858 .1 k
.81746 .51503 m
.81746 .52484 L
.84921 .52484 L
.84921 .51503 L
F
.85 .5 .875 .1 k
.81746 .52484 m
.81746 .53465 L
.84921 .53465 L
.84921 .52484 L
F
.85 .5 .892 .1 k
.81746 .53465 m
.81746 .54446 L
.84921 .54446 L
.84921 .53465 L
F
.85 .5 .908 .1 k
.81746 .54446 m
.81746 .55427 L
.84921 .55427 L
.84921 .54446 L
F
.85 .5 .925 .1 k
.81746 .55427 m
.81746 .56408 L
.84921 .56408 L
.84921 .55427 L
F
.85 .5 .942 .1 k
.81746 .56408 m
.81746 .57389 L
.84921 .57389 L
.84921 .56408 L
F
.85 .5 .958 .1 k
.81746 .57389 m
.81746 .5837 L
.84921 .5837 L
.84921 .57389 L
F
.85 .5 .975 .1 k
.81746 .5837 m
.81746 .59351 L
.84921 .59351 L
.84921 .5837 L
F
.85 .5 .992 .1 k
.81746 .59351 m
.81746 .60332 L
.84921 .60332 L
.84921 .59351 L
F
.883 .5 .008 .1 k
.84921 .01472 m
.84921 .02453 L
.88095 .02453 L
.88095 .01472 L
F
.883 .5 .025 .1 k
.84921 .02453 m
.84921 .03434 L
.88095 .03434 L
.88095 .02453 L
F
.883 .5 .042 .1 k
.84921 .03434 m
.84921 .04415 L
.88095 .04415 L
.88095 .03434 L
F
.883 .5 .058 .1 k
.84921 .04415 m
.84921 .05396 L
.88095 .05396 L
.88095 .04415 L
F
.883 .5 .075 .1 k
.84921 .05396 m
.84921 .06377 L
.88095 .06377 L
.88095 .05396 L
F
.883 .5 .092 .1 k
.84921 .06377 m
.84921 .07358 L
.88095 .07358 L
.88095 .06377 L
F
.883 .5 .108 .1 k
.84921 .07358 m
.84921 .08339 L
.88095 .08339 L
.88095 .07358 L
F
.883 .5 .125 .1 k
.84921 .08339 m
.84921 .0932 L
.88095 .0932 L
.88095 .08339 L
F
.883 .5 .142 .1 k
.84921 .0932 m
.84921 .10301 L
.88095 .10301 L
.88095 .0932 L
F
.883 .5 .158 .1 k
.84921 .10301 m
.84921 .11282 L
.88095 .11282 L
.88095 .10301 L
F
.883 .5 .175 .1 k
.84921 .11282 m
.84921 .12263 L
.88095 .12263 L
.88095 .11282 L
F
.883 .5 .192 .1 k
.84921 .12263 m
.84921 .13244 L
.88095 .13244 L
.88095 .12263 L
F
.883 .5 .208 .1 k
.84921 .13244 m
.84921 .14225 L
.88095 .14225 L
.88095 .13244 L
F
.883 .5 .225 .1 k
.84921 .14225 m
.84921 .15206 L
.88095 .15206 L
.88095 .14225 L
F
.883 .5 .242 .1 k
.84921 .15206 m
.84921 .16187 L
.88095 .16187 L
.88095 .15206 L
F
.883 .5 .258 .1 k
.84921 .16187 m
.84921 .17168 L
.88095 .17168 L
.88095 .16187 L
F
.883 .5 .275 .1 k
.84921 .17168 m
.84921 .18149 L
.88095 .18149 L
.88095 .17168 L
F
.883 .5 .292 .1 k
.84921 .18149 m
.84921 .1913 L
.88095 .1913 L
.88095 .18149 L
F
.883 .5 .308 .1 k
.84921 .1913 m
.84921 .20111 L
.88095 .20111 L
.88095 .1913 L
F
.883 .5 .325 .1 k
.84921 .20111 m
.84921 .21092 L
.88095 .21092 L
.88095 .20111 L
F
.883 .5 .342 .1 k
.84921 .21092 m
.84921 .22073 L
.88095 .22073 L
.88095 .21092 L
F
.883 .5 .358 .1 k
.84921 .22073 m
.84921 .23054 L
.88095 .23054 L
.88095 .22073 L
F
.883 .5 .375 .1 k
.84921 .23054 m
.84921 .24035 L
.88095 .24035 L
.88095 .23054 L
F
.883 .5 .392 .1 k
.84921 .24035 m
.84921 .25016 L
.88095 .25016 L
.88095 .24035 L
F
.883 .5 .408 .1 k
.84921 .25016 m
.84921 .25997 L
.88095 .25997 L
.88095 .25016 L
F
.883 .5 .425 .1 k
.84921 .25997 m
.84921 .26978 L
.88095 .26978 L
.88095 .25997 L
F
.883 .5 .442 .1 k
.84921 .26978 m
.84921 .27959 L
.88095 .27959 L
.88095 .26978 L
F
.883 .5 .458 .1 k
.84921 .27959 m
.84921 .2894 L
.88095 .2894 L
.88095 .27959 L
F
.883 .5 .475 .1 k
.84921 .2894 m
.84921 .29921 L
.88095 .29921 L
.88095 .2894 L
F
.883 .5 .492 .1 k
.84921 .29921 m
.84921 .30902 L
.88095 .30902 L
.88095 .29921 L
F
.883 .5 .508 .1 k
.84921 .30902 m
.84921 .31883 L
.88095 .31883 L
.88095 .30902 L
F
.883 .5 .525 .1 k
.84921 .31883 m
.84921 .32864 L
.88095 .32864 L
.88095 .31883 L
F
.883 .5 .542 .1 k
.84921 .32864 m
.84921 .33845 L
.88095 .33845 L
.88095 .32864 L
F
.883 .5 .558 .1 k
.84921 .33845 m
.84921 .34826 L
.88095 .34826 L
.88095 .33845 L
F
.883 .5 .575 .1 k
.84921 .34826 m
.84921 .35807 L
.88095 .35807 L
.88095 .34826 L
F
.883 .5 .592 .1 k
.84921 .35807 m
.84921 .36788 L
.88095 .36788 L
.88095 .35807 L
F
.883 .5 .608 .1 k
.84921 .36788 m
.84921 .37769 L
.88095 .37769 L
.88095 .36788 L
F
.883 .5 .625 .1 k
.84921 .37769 m
.84921 .3875 L
.88095 .3875 L
.88095 .37769 L
F
.883 .5 .642 .1 k
.84921 .3875 m
.84921 .39731 L
.88095 .39731 L
.88095 .3875 L
F
.883 .5 .658 .1 k
.84921 .39731 m
.84921 .40712 L
.88095 .40712 L
.88095 .39731 L
F
.883 .5 .675 .1 k
.84921 .40712 m
.84921 .41693 L
.88095 .41693 L
.88095 .40712 L
F
.883 .5 .692 .1 k
.84921 .41693 m
.84921 .42674 L
.88095 .42674 L
.88095 .41693 L
F
.883 .5 .708 .1 k
.84921 .42674 m
.84921 .43655 L
.88095 .43655 L
.88095 .42674 L
F
.883 .5 .725 .1 k
.84921 .43655 m
.84921 .44636 L
.88095 .44636 L
.88095 .43655 L
F
.883 .5 .742 .1 k
.84921 .44636 m
.84921 .45617 L
.88095 .45617 L
.88095 .44636 L
F
.883 .5 .758 .1 k
.84921 .45617 m
.84921 .46598 L
.88095 .46598 L
.88095 .45617 L
F
.883 .5 .775 .1 k
.84921 .46598 m
.84921 .47579 L
.88095 .47579 L
.88095 .46598 L
F
.883 .5 .792 .1 k
.84921 .47579 m
.84921 .4856 L
.88095 .4856 L
.88095 .47579 L
F
.883 .5 .808 .1 k
.84921 .4856 m
.84921 .49541 L
.88095 .49541 L
.88095 .4856 L
F
.883 .5 .825 .1 k
.84921 .49541 m
.84921 .50522 L
.88095 .50522 L
.88095 .49541 L
F
.883 .5 .842 .1 k
.84921 .50522 m
.84921 .51503 L
.88095 .51503 L
.88095 .50522 L
F
.883 .5 .858 .1 k
.84921 .51503 m
.84921 .52484 L
.88095 .52484 L
.88095 .51503 L
F
.883 .5 .875 .1 k
.84921 .52484 m
.84921 .53465 L
.88095 .53465 L
.88095 .52484 L
F
.883 .5 .892 .1 k
.84921 .53465 m
.84921 .54446 L
.88095 .54446 L
.88095 .53465 L
F
.883 .5 .908 .1 k
.84921 .54446 m
.84921 .55427 L
.88095 .55427 L
.88095 .54446 L
F
.883 .5 .925 .1 k
.84921 .55427 m
.84921 .56408 L
.88095 .56408 L
.88095 .55427 L
F
.883 .5 .942 .1 k
.84921 .56408 m
.84921 .57389 L
.88095 .57389 L
.88095 .56408 L
F
.883 .5 .958 .1 k
.84921 .57389 m
.84921 .5837 L
.88095 .5837 L
.88095 .57389 L
F
.883 .5 .975 .1 k
.84921 .5837 m
.84921 .59351 L
.88095 .59351 L
.88095 .5837 L
F
.883 .5 .992 .1 k
.84921 .59351 m
.84921 .60332 L
.88095 .60332 L
.88095 .59351 L
F
.917 .5 .008 .1 k
.88095 .01472 m
.88095 .02453 L
.9127 .02453 L
.9127 .01472 L
F
.917 .5 .025 .1 k
.88095 .02453 m
.88095 .03434 L
.9127 .03434 L
.9127 .02453 L
F
.917 .5 .042 .1 k
.88095 .03434 m
.88095 .04415 L
.9127 .04415 L
.9127 .03434 L
F
.917 .5 .058 .1 k
.88095 .04415 m
.88095 .05396 L
.9127 .05396 L
.9127 .04415 L
F
.917 .5 .075 .1 k
.88095 .05396 m
.88095 .06377 L
.9127 .06377 L
.9127 .05396 L
F
.917 .5 .092 .1 k
.88095 .06377 m
.88095 .07358 L
.9127 .07358 L
.9127 .06377 L
F
.917 .5 .108 .1 k
.88095 .07358 m
.88095 .08339 L
.9127 .08339 L
.9127 .07358 L
F
.917 .5 .125 .1 k
.88095 .08339 m
.88095 .0932 L
.9127 .0932 L
.9127 .08339 L
F
.917 .5 .142 .1 k
.88095 .0932 m
.88095 .10301 L
.9127 .10301 L
.9127 .0932 L
F
.917 .5 .158 .1 k
.88095 .10301 m
.88095 .11282 L
.9127 .11282 L
.9127 .10301 L
F
.917 .5 .175 .1 k
.88095 .11282 m
.88095 .12263 L
.9127 .12263 L
.9127 .11282 L
F
.917 .5 .192 .1 k
.88095 .12263 m
.88095 .13244 L
.9127 .13244 L
.9127 .12263 L
F
.917 .5 .208 .1 k
.88095 .13244 m
.88095 .14225 L
.9127 .14225 L
.9127 .13244 L
F
.917 .5 .225 .1 k
.88095 .14225 m
.88095 .15206 L
.9127 .15206 L
.9127 .14225 L
F
.917 .5 .242 .1 k
.88095 .15206 m
.88095 .16187 L
.9127 .16187 L
.9127 .15206 L
F
.917 .5 .258 .1 k
.88095 .16187 m
.88095 .17168 L
.9127 .17168 L
.9127 .16187 L
F
.917 .5 .275 .1 k
.88095 .17168 m
.88095 .18149 L
.9127 .18149 L
.9127 .17168 L
F
.917 .5 .292 .1 k
.88095 .18149 m
.88095 .1913 L
.9127 .1913 L
.9127 .18149 L
F
.917 .5 .308 .1 k
.88095 .1913 m
.88095 .20111 L
.9127 .20111 L
.9127 .1913 L
F
.917 .5 .325 .1 k
.88095 .20111 m
.88095 .21092 L
.9127 .21092 L
.9127 .20111 L
F
.917 .5 .342 .1 k
.88095 .21092 m
.88095 .22073 L
.9127 .22073 L
.9127 .21092 L
F
.917 .5 .358 .1 k
.88095 .22073 m
.88095 .23054 L
.9127 .23054 L
.9127 .22073 L
F
.917 .5 .375 .1 k
.88095 .23054 m
.88095 .24035 L
.9127 .24035 L
.9127 .23054 L
F
.917 .5 .392 .1 k
.88095 .24035 m
.88095 .25016 L
.9127 .25016 L
.9127 .24035 L
F
.917 .5 .408 .1 k
.88095 .25016 m
.88095 .25997 L
.9127 .25997 L
.9127 .25016 L
F
.917 .5 .425 .1 k
.88095 .25997 m
.88095 .26978 L
.9127 .26978 L
.9127 .25997 L
F
.917 .5 .442 .1 k
.88095 .26978 m
.88095 .27959 L
.9127 .27959 L
.9127 .26978 L
F
.917 .5 .458 .1 k
.88095 .27959 m
.88095 .2894 L
.9127 .2894 L
.9127 .27959 L
F
.917 .5 .475 .1 k
.88095 .2894 m
.88095 .29921 L
.9127 .29921 L
.9127 .2894 L
F
.917 .5 .492 .1 k
.88095 .29921 m
.88095 .30902 L
.9127 .30902 L
.9127 .29921 L
F
.917 .5 .508 .1 k
.88095 .30902 m
.88095 .31883 L
.9127 .31883 L
.9127 .30902 L
F
.917 .5 .525 .1 k
.88095 .31883 m
.88095 .32864 L
.9127 .32864 L
.9127 .31883 L
F
.917 .5 .542 .1 k
.88095 .32864 m
.88095 .33845 L
.9127 .33845 L
.9127 .32864 L
F
.917 .5 .558 .1 k
.88095 .33845 m
.88095 .34826 L
.9127 .34826 L
.9127 .33845 L
F
.917 .5 .575 .1 k
.88095 .34826 m
.88095 .35807 L
.9127 .35807 L
.9127 .34826 L
F
.917 .5 .592 .1 k
.88095 .35807 m
.88095 .36788 L
.9127 .36788 L
.9127 .35807 L
F
.917 .5 .608 .1 k
.88095 .36788 m
.88095 .37769 L
.9127 .37769 L
.9127 .36788 L
F
.917 .5 .625 .1 k
.88095 .37769 m
.88095 .3875 L
.9127 .3875 L
.9127 .37769 L
F
.917 .5 .642 .1 k
.88095 .3875 m
.88095 .39731 L
.9127 .39731 L
.9127 .3875 L
F
.917 .5 .658 .1 k
.88095 .39731 m
.88095 .40712 L
.9127 .40712 L
.9127 .39731 L
F
.917 .5 .675 .1 k
.88095 .40712 m
.88095 .41693 L
.9127 .41693 L
.9127 .40712 L
F
.917 .5 .692 .1 k
.88095 .41693 m
.88095 .42674 L
.9127 .42674 L
.9127 .41693 L
F
.917 .5 .708 .1 k
.88095 .42674 m
.88095 .43655 L
.9127 .43655 L
.9127 .42674 L
F
.917 .5 .725 .1 k
.88095 .43655 m
.88095 .44636 L
.9127 .44636 L
.9127 .43655 L
F
.917 .5 .742 .1 k
.88095 .44636 m
.88095 .45617 L
.9127 .45617 L
.9127 .44636 L
F
.917 .5 .758 .1 k
.88095 .45617 m
.88095 .46598 L
.9127 .46598 L
.9127 .45617 L
F
.917 .5 .775 .1 k
.88095 .46598 m
.88095 .47579 L
.9127 .47579 L
.9127 .46598 L
F
.917 .5 .792 .1 k
.88095 .47579 m
.88095 .4856 L
.9127 .4856 L
.9127 .47579 L
F
.917 .5 .808 .1 k
.88095 .4856 m
.88095 .49541 L
.9127 .49541 L
.9127 .4856 L
F
.917 .5 .825 .1 k
.88095 .49541 m
.88095 .50522 L
.9127 .50522 L
.9127 .49541 L
F
.917 .5 .842 .1 k
.88095 .50522 m
.88095 .51503 L
.9127 .51503 L
.9127 .50522 L
F
.917 .5 .858 .1 k
.88095 .51503 m
.88095 .52484 L
.9127 .52484 L
.9127 .51503 L
F
.917 .5 .875 .1 k
.88095 .52484 m
.88095 .53465 L
.9127 .53465 L
.9127 .52484 L
F
.917 .5 .892 .1 k
.88095 .53465 m
.88095 .54446 L
.9127 .54446 L
.9127 .53465 L
F
.917 .5 .908 .1 k
.88095 .54446 m
.88095 .55427 L
.9127 .55427 L
.9127 .54446 L
F
.917 .5 .925 .1 k
.88095 .55427 m
.88095 .56408 L
.9127 .56408 L
.9127 .55427 L
F
.917 .5 .942 .1 k
.88095 .56408 m
.88095 .57389 L
.9127 .57389 L
.9127 .56408 L
F
.917 .5 .958 .1 k
.88095 .57389 m
.88095 .5837 L
.9127 .5837 L
.9127 .57389 L
F
.917 .5 .975 .1 k
.88095 .5837 m
.88095 .59351 L
.9127 .59351 L
.9127 .5837 L
F
.917 .5 .992 .1 k
.88095 .59351 m
.88095 .60332 L
.9127 .60332 L
.9127 .59351 L
F
.95 .5 .008 .1 k
.9127 .01472 m
.9127 .02453 L
.94444 .02453 L
.94444 .01472 L
F
.95 .5 .025 .1 k
.9127 .02453 m
.9127 .03434 L
.94444 .03434 L
.94444 .02453 L
F
.95 .5 .042 .1 k
.9127 .03434 m
.9127 .04415 L
.94444 .04415 L
.94444 .03434 L
F
.95 .5 .058 .1 k
.9127 .04415 m
.9127 .05396 L
.94444 .05396 L
.94444 .04415 L
F
.95 .5 .075 .1 k
.9127 .05396 m
.9127 .06377 L
.94444 .06377 L
.94444 .05396 L
F
.95 .5 .092 .1 k
.9127 .06377 m
.9127 .07358 L
.94444 .07358 L
.94444 .06377 L
F
.95 .5 .108 .1 k
.9127 .07358 m
.9127 .08339 L
.94444 .08339 L
.94444 .07358 L
F
.95 .5 .125 .1 k
.9127 .08339 m
.9127 .0932 L
.94444 .0932 L
.94444 .08339 L
F
.95 .5 .142 .1 k
.9127 .0932 m
.9127 .10301 L
.94444 .10301 L
.94444 .0932 L
F
.95 .5 .158 .1 k
.9127 .10301 m
.9127 .11282 L
.94444 .11282 L
.94444 .10301 L
F
.95 .5 .175 .1 k
.9127 .11282 m
.9127 .12263 L
.94444 .12263 L
.94444 .11282 L
F
.95 .5 .192 .1 k
.9127 .12263 m
.9127 .13244 L
.94444 .13244 L
.94444 .12263 L
F
.95 .5 .208 .1 k
.9127 .13244 m
.9127 .14225 L
.94444 .14225 L
.94444 .13244 L
F
.95 .5 .225 .1 k
.9127 .14225 m
.9127 .15206 L
.94444 .15206 L
.94444 .14225 L
F
.95 .5 .242 .1 k
.9127 .15206 m
.9127 .16187 L
.94444 .16187 L
.94444 .15206 L
F
.95 .5 .258 .1 k
.9127 .16187 m
.9127 .17168 L
.94444 .17168 L
.94444 .16187 L
F
.95 .5 .275 .1 k
.9127 .17168 m
.9127 .18149 L
.94444 .18149 L
.94444 .17168 L
F
.95 .5 .292 .1 k
.9127 .18149 m
.9127 .1913 L
.94444 .1913 L
.94444 .18149 L
F
.95 .5 .308 .1 k
.9127 .1913 m
.9127 .20111 L
.94444 .20111 L
.94444 .1913 L
F
.95 .5 .325 .1 k
.9127 .20111 m
.9127 .21092 L
.94444 .21092 L
.94444 .20111 L
F
.95 .5 .342 .1 k
.9127 .21092 m
.9127 .22073 L
.94444 .22073 L
.94444 .21092 L
F
.95 .5 .358 .1 k
.9127 .22073 m
.9127 .23054 L
.94444 .23054 L
.94444 .22073 L
F
.95 .5 .375 .1 k
.9127 .23054 m
.9127 .24035 L
.94444 .24035 L
.94444 .23054 L
F
.95 .5 .392 .1 k
.9127 .24035 m
.9127 .25016 L
.94444 .25016 L
.94444 .24035 L
F
.95 .5 .408 .1 k
.9127 .25016 m
.9127 .25997 L
.94444 .25997 L
.94444 .25016 L
F
.95 .5 .425 .1 k
.9127 .25997 m
.9127 .26978 L
.94444 .26978 L
.94444 .25997 L
F
.95 .5 .442 .1 k
.9127 .26978 m
.9127 .27959 L
.94444 .27959 L
.94444 .26978 L
F
.95 .5 .458 .1 k
.9127 .27959 m
.9127 .2894 L
.94444 .2894 L
.94444 .27959 L
F
.95 .5 .475 .1 k
.9127 .2894 m
.9127 .29921 L
.94444 .29921 L
.94444 .2894 L
F
.95 .5 .492 .1 k
.9127 .29921 m
.9127 .30902 L
.94444 .30902 L
.94444 .29921 L
F
.95 .5 .508 .1 k
.9127 .30902 m
.9127 .31883 L
.94444 .31883 L
.94444 .30902 L
F
.95 .5 .525 .1 k
.9127 .31883 m
.9127 .32864 L
.94444 .32864 L
.94444 .31883 L
F
.95 .5 .542 .1 k
.9127 .32864 m
.9127 .33845 L
.94444 .33845 L
.94444 .32864 L
F
.95 .5 .558 .1 k
.9127 .33845 m
.9127 .34826 L
.94444 .34826 L
.94444 .33845 L
F
.95 .5 .575 .1 k
.9127 .34826 m
.9127 .35807 L
.94444 .35807 L
.94444 .34826 L
F
.95 .5 .592 .1 k
.9127 .35807 m
.9127 .36788 L
.94444 .36788 L
.94444 .35807 L
F
.95 .5 .608 .1 k
.9127 .36788 m
.9127 .37769 L
.94444 .37769 L
.94444 .36788 L
F
.95 .5 .625 .1 k
.9127 .37769 m
.9127 .3875 L
.94444 .3875 L
.94444 .37769 L
F
.95 .5 .642 .1 k
.9127 .3875 m
.9127 .39731 L
.94444 .39731 L
.94444 .3875 L
F
.95 .5 .658 .1 k
.9127 .39731 m
.9127 .40712 L
.94444 .40712 L
.94444 .39731 L
F
.95 .5 .675 .1 k
.9127 .40712 m
.9127 .41693 L
.94444 .41693 L
.94444 .40712 L
F
.95 .5 .692 .1 k
.9127 .41693 m
.9127 .42674 L
.94444 .42674 L
.94444 .41693 L
F
.95 .5 .708 .1 k
.9127 .42674 m
.9127 .43655 L
.94444 .43655 L
.94444 .42674 L
F
.95 .5 .725 .1 k
.9127 .43655 m
.9127 .44636 L
.94444 .44636 L
.94444 .43655 L
F
.95 .5 .742 .1 k
.9127 .44636 m
.9127 .45617 L
.94444 .45617 L
.94444 .44636 L
F
.95 .5 .758 .1 k
.9127 .45617 m
.9127 .46598 L
.94444 .46598 L
.94444 .45617 L
F
.95 .5 .775 .1 k
.9127 .46598 m
.9127 .47579 L
.94444 .47579 L
.94444 .46598 L
F
.95 .5 .792 .1 k
.9127 .47579 m
.9127 .4856 L
.94444 .4856 L
.94444 .47579 L
F
.95 .5 .808 .1 k
.9127 .4856 m
.9127 .49541 L
.94444 .49541 L
.94444 .4856 L
F
.95 .5 .825 .1 k
.9127 .49541 m
.9127 .50522 L
.94444 .50522 L
.94444 .49541 L
F
.95 .5 .842 .1 k
.9127 .50522 m
.9127 .51503 L
.94444 .51503 L
.94444 .50522 L
F
.95 .5 .858 .1 k
.9127 .51503 m
.9127 .52484 L
.94444 .52484 L
.94444 .51503 L
F
.95 .5 .875 .1 k
.9127 .52484 m
.9127 .53465 L
.94444 .53465 L
.94444 .52484 L
F
.95 .5 .892 .1 k
.9127 .53465 m
.9127 .54446 L
.94444 .54446 L
.94444 .53465 L
F
.95 .5 .908 .1 k
.9127 .54446 m
.9127 .55427 L
.94444 .55427 L
.94444 .54446 L
F
.95 .5 .925 .1 k
.9127 .55427 m
.9127 .56408 L
.94444 .56408 L
.94444 .55427 L
F
.95 .5 .942 .1 k
.9127 .56408 m
.9127 .57389 L
.94444 .57389 L
.94444 .56408 L
F
.95 .5 .958 .1 k
.9127 .57389 m
.9127 .5837 L
.94444 .5837 L
.94444 .57389 L
F
.95 .5 .975 .1 k
.9127 .5837 m
.9127 .59351 L
.94444 .59351 L
.94444 .5837 L
F
.95 .5 .992 .1 k
.9127 .59351 m
.9127 .60332 L
.94444 .60332 L
.94444 .59351 L
F
.983 .5 .008 .1 k
.94444 .01472 m
.94444 .02453 L
.97619 .02453 L
.97619 .01472 L
F
.983 .5 .025 .1 k
.94444 .02453 m
.94444 .03434 L
.97619 .03434 L
.97619 .02453 L
F
.983 .5 .042 .1 k
.94444 .03434 m
.94444 .04415 L
.97619 .04415 L
.97619 .03434 L
F
.983 .5 .058 .1 k
.94444 .04415 m
.94444 .05396 L
.97619 .05396 L
.97619 .04415 L
F
.983 .5 .075 .1 k
.94444 .05396 m
.94444 .06377 L
.97619 .06377 L
.97619 .05396 L
F
.983 .5 .092 .1 k
.94444 .06377 m
.94444 .07358 L
.97619 .07358 L
.97619 .06377 L
F
.983 .5 .108 .1 k
.94444 .07358 m
.94444 .08339 L
.97619 .08339 L
.97619 .07358 L
F
.983 .5 .125 .1 k
.94444 .08339 m
.94444 .0932 L
.97619 .0932 L
.97619 .08339 L
F
.983 .5 .142 .1 k
.94444 .0932 m
.94444 .10301 L
.97619 .10301 L
.97619 .0932 L
F
.983 .5 .158 .1 k
.94444 .10301 m
.94444 .11282 L
.97619 .11282 L
.97619 .10301 L
F
.983 .5 .175 .1 k
.94444 .11282 m
.94444 .12263 L
.97619 .12263 L
.97619 .11282 L
F
.983 .5 .192 .1 k
.94444 .12263 m
.94444 .13244 L
.97619 .13244 L
.97619 .12263 L
F
.983 .5 .208 .1 k
.94444 .13244 m
.94444 .14225 L
.97619 .14225 L
.97619 .13244 L
F
.983 .5 .225 .1 k
.94444 .14225 m
.94444 .15206 L
.97619 .15206 L
.97619 .14225 L
F
.983 .5 .242 .1 k
.94444 .15206 m
.94444 .16187 L
.97619 .16187 L
.97619 .15206 L
F
.983 .5 .258 .1 k
.94444 .16187 m
.94444 .17168 L
.97619 .17168 L
.97619 .16187 L
F
.983 .5 .275 .1 k
.94444 .17168 m
.94444 .18149 L
.97619 .18149 L
.97619 .17168 L
F
.983 .5 .292 .1 k
.94444 .18149 m
.94444 .1913 L
.97619 .1913 L
.97619 .18149 L
F
.983 .5 .308 .1 k
.94444 .1913 m
.94444 .20111 L
.97619 .20111 L
.97619 .1913 L
F
.983 .5 .325 .1 k
.94444 .20111 m
.94444 .21092 L
.97619 .21092 L
.97619 .20111 L
F
.983 .5 .342 .1 k
.94444 .21092 m
.94444 .22073 L
.97619 .22073 L
.97619 .21092 L
F
.983 .5 .358 .1 k
.94444 .22073 m
.94444 .23054 L
.97619 .23054 L
.97619 .22073 L
F
.983 .5 .375 .1 k
.94444 .23054 m
.94444 .24035 L
.97619 .24035 L
.97619 .23054 L
F
.983 .5 .392 .1 k
.94444 .24035 m
.94444 .25016 L
.97619 .25016 L
.97619 .24035 L
F
.983 .5 .408 .1 k
.94444 .25016 m
.94444 .25997 L
.97619 .25997 L
.97619 .25016 L
F
.983 .5 .425 .1 k
.94444 .25997 m
.94444 .26978 L
.97619 .26978 L
.97619 .25997 L
F
.983 .5 .442 .1 k
.94444 .26978 m
.94444 .27959 L
.97619 .27959 L
.97619 .26978 L
F
.983 .5 .458 .1 k
.94444 .27959 m
.94444 .2894 L
.97619 .2894 L
.97619 .27959 L
F
.983 .5 .475 .1 k
.94444 .2894 m
.94444 .29921 L
.97619 .29921 L
.97619 .2894 L
F
.983 .5 .492 .1 k
.94444 .29921 m
.94444 .30902 L
.97619 .30902 L
.97619 .29921 L
F
.983 .5 .508 .1 k
.94444 .30902 m
.94444 .31883 L
.97619 .31883 L
.97619 .30902 L
F
.983 .5 .525 .1 k
.94444 .31883 m
.94444 .32864 L
.97619 .32864 L
.97619 .31883 L
F
.983 .5 .542 .1 k
.94444 .32864 m
.94444 .33845 L
.97619 .33845 L
.97619 .32864 L
F
.983 .5 .558 .1 k
.94444 .33845 m
.94444 .34826 L
.97619 .34826 L
.97619 .33845 L
F
.983 .5 .575 .1 k
.94444 .34826 m
.94444 .35807 L
.97619 .35807 L
.97619 .34826 L
F
.983 .5 .592 .1 k
.94444 .35807 m
.94444 .36788 L
.97619 .36788 L
.97619 .35807 L
F
.983 .5 .608 .1 k
.94444 .36788 m
.94444 .37769 L
.97619 .37769 L
.97619 .36788 L
F
.983 .5 .625 .1 k
.94444 .37769 m
.94444 .3875 L
.97619 .3875 L
.97619 .37769 L
F
.983 .5 .642 .1 k
.94444 .3875 m
.94444 .39731 L
.97619 .39731 L
.97619 .3875 L
F
.983 .5 .658 .1 k
.94444 .39731 m
.94444 .40712 L
.97619 .40712 L
.97619 .39731 L
F
.983 .5 .675 .1 k
.94444 .40712 m
.94444 .41693 L
.97619 .41693 L
.97619 .40712 L
F
.983 .5 .692 .1 k
.94444 .41693 m
.94444 .42674 L
.97619 .42674 L
.97619 .41693 L
F
.983 .5 .708 .1 k
.94444 .42674 m
.94444 .43655 L
.97619 .43655 L
.97619 .42674 L
F
.983 .5 .725 .1 k
.94444 .43655 m
.94444 .44636 L
.97619 .44636 L
.97619 .43655 L
F
.983 .5 .742 .1 k
.94444 .44636 m
.94444 .45617 L
.97619 .45617 L
.97619 .44636 L
F
.983 .5 .758 .1 k
.94444 .45617 m
.94444 .46598 L
.97619 .46598 L
.97619 .45617 L
F
.983 .5 .775 .1 k
.94444 .46598 m
.94444 .47579 L
.97619 .47579 L
.97619 .46598 L
F
.983 .5 .792 .1 k
.94444 .47579 m
.94444 .4856 L
.97619 .4856 L
.97619 .47579 L
F
.983 .5 .808 .1 k
.94444 .4856 m
.94444 .49541 L
.97619 .49541 L
.97619 .4856 L
F
.983 .5 .825 .1 k
.94444 .49541 m
.94444 .50522 L
.97619 .50522 L
.97619 .49541 L
F
.983 .5 .842 .1 k
.94444 .50522 m
.94444 .51503 L
.97619 .51503 L
.97619 .50522 L
F
.983 .5 .858 .1 k
.94444 .51503 m
.94444 .52484 L
.97619 .52484 L
.97619 .51503 L
F
.983 .5 .875 .1 k
.94444 .52484 m
.94444 .53465 L
.97619 .53465 L
.97619 .52484 L
F
.983 .5 .892 .1 k
.94444 .53465 m
.94444 .54446 L
.97619 .54446 L
.97619 .53465 L
F
.983 .5 .908 .1 k
.94444 .54446 m
.94444 .55427 L
.97619 .55427 L
.97619 .54446 L
F
.983 .5 .925 .1 k
.94444 .55427 m
.94444 .56408 L
.97619 .56408 L
.97619 .55427 L
F
.983 .5 .942 .1 k
.94444 .56408 m
.94444 .57389 L
.97619 .57389 L
.97619 .56408 L
F
.983 .5 .958 .1 k
.94444 .57389 m
.94444 .5837 L
.97619 .5837 L
.97619 .57389 L
F
.983 .5 .975 .1 k
.94444 .5837 m
.94444 .59351 L
.97619 .59351 L
.97619 .5837 L
F
.983 .5 .992 .1 k
.94444 .59351 m
.94444 .60332 L
.97619 .60332 L
.97619 .59351 L
F
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02453 L
.05556 .02453 L
.05556 .01472 L
.02381 .01472 L
s
.02381 .02453 m
.02381 .03434 L
.05556 .03434 L
.05556 .02453 L
.02381 .02453 L
s
.02381 .03434 m
.02381 .04415 L
.05556 .04415 L
.05556 .03434 L
.02381 .03434 L
s
.02381 .04415 m
.02381 .05396 L
.05556 .05396 L
.05556 .04415 L
.02381 .04415 L
s
.02381 .05396 m
.02381 .06377 L
.05556 .06377 L
.05556 .05396 L
.02381 .05396 L
s
.02381 .06377 m
.02381 .07358 L
.05556 .07358 L
.05556 .06377 L
.02381 .06377 L
s
.02381 .07358 m
.02381 .08339 L
.05556 .08339 L
.05556 .07358 L
.02381 .07358 L
s
.02381 .08339 m
.02381 .0932 L
.05556 .0932 L
.05556 .08339 L
.02381 .08339 L
s
.02381 .0932 m
.02381 .10301 L
.05556 .10301 L
.05556 .0932 L
.02381 .0932 L
s
.02381 .10301 m
.02381 .11282 L
.05556 .11282 L
.05556 .10301 L
.02381 .10301 L
s
.02381 .11282 m
.02381 .12263 L
.05556 .12263 L
.05556 .11282 L
.02381 .11282 L
s
.02381 .12263 m
.02381 .13244 L
.05556 .13244 L
.05556 .12263 L
.02381 .12263 L
s
.02381 .13244 m
.02381 .14225 L
.05556 .14225 L
.05556 .13244 L
.02381 .13244 L
s
.02381 .14225 m
.02381 .15206 L
.05556 .15206 L
.05556 .14225 L
.02381 .14225 L
s
.02381 .15206 m
.02381 .16187 L
.05556 .16187 L
.05556 .15206 L
.02381 .15206 L
s
.02381 .16187 m
.02381 .17168 L
.05556 .17168 L
.05556 .16187 L
.02381 .16187 L
s
.02381 .17168 m
.02381 .18149 L
.05556 .18149 L
.05556 .17168 L
.02381 .17168 L
s
.02381 .18149 m
.02381 .1913 L
.05556 .1913 L
.05556 .18149 L
.02381 .18149 L
s
.02381 .1913 m
.02381 .20111 L
.05556 .20111 L
.05556 .1913 L
.02381 .1913 L
s
.02381 .20111 m
.02381 .21092 L
.05556 .21092 L
.05556 .20111 L
.02381 .20111 L
s
.02381 .21092 m
.02381 .22073 L
.05556 .22073 L
.05556 .21092 L
.02381 .21092 L
s
.02381 .22073 m
.02381 .23054 L
.05556 .23054 L
.05556 .22073 L
.02381 .22073 L
s
.02381 .23054 m
.02381 .24035 L
.05556 .24035 L
.05556 .23054 L
.02381 .23054 L
s
.02381 .24035 m
.02381 .25016 L
.05556 .25016 L
.05556 .24035 L
.02381 .24035 L
s
.02381 .25016 m
.02381 .25997 L
.05556 .25997 L
.05556 .25016 L
.02381 .25016 L
s
.02381 .25997 m
.02381 .26978 L
.05556 .26978 L
.05556 .25997 L
.02381 .25997 L
s
.02381 .26978 m
.02381 .27959 L
.05556 .27959 L
.05556 .26978 L
.02381 .26978 L
s
.02381 .27959 m
.02381 .2894 L
.05556 .2894 L
.05556 .27959 L
.02381 .27959 L
s
.02381 .2894 m
.02381 .29921 L
.05556 .29921 L
.05556 .2894 L
.02381 .2894 L
s
.02381 .29921 m
.02381 .30902 L
.05556 .30902 L
.05556 .29921 L
.02381 .29921 L
s
.02381 .30902 m
.02381 .31883 L
.05556 .31883 L
.05556 .30902 L
.02381 .30902 L
s
.02381 .31883 m
.02381 .32864 L
.05556 .32864 L
.05556 .31883 L
.02381 .31883 L
s
.02381 .32864 m
.02381 .33845 L
.05556 .33845 L
.05556 .32864 L
.02381 .32864 L
s
.02381 .33845 m
.02381 .34826 L
.05556 .34826 L
.05556 .33845 L
.02381 .33845 L
s
.02381 .34826 m
.02381 .35807 L
.05556 .35807 L
.05556 .34826 L
.02381 .34826 L
s
.02381 .35807 m
.02381 .36788 L
.05556 .36788 L
.05556 .35807 L
.02381 .35807 L
s
.02381 .36788 m
.02381 .37769 L
.05556 .37769 L
.05556 .36788 L
.02381 .36788 L
s
.02381 .37769 m
.02381 .3875 L
.05556 .3875 L
.05556 .37769 L
.02381 .37769 L
s
.02381 .3875 m
.02381 .39731 L
.05556 .39731 L
.05556 .3875 L
.02381 .3875 L
s
.02381 .39731 m
.02381 .40712 L
.05556 .40712 L
.05556 .39731 L
.02381 .39731 L
s
.02381 .40712 m
.02381 .41693 L
.05556 .41693 L
.05556 .40712 L
.02381 .40712 L
s
.02381 .41693 m
.02381 .42674 L
.05556 .42674 L
.05556 .41693 L
.02381 .41693 L
s
.02381 .42674 m
.02381 .43655 L
.05556 .43655 L
.05556 .42674 L
.02381 .42674 L
s
.02381 .43655 m
.02381 .44636 L
.05556 .44636 L
.05556 .43655 L
.02381 .43655 L
s
.02381 .44636 m
.02381 .45617 L
.05556 .45617 L
.05556 .44636 L
.02381 .44636 L
s
.02381 .45617 m
.02381 .46598 L
.05556 .46598 L
.05556 .45617 L
.02381 .45617 L
s
.02381 .46598 m
.02381 .47579 L
.05556 .47579 L
.05556 .46598 L
.02381 .46598 L
s
.02381 .47579 m
.02381 .4856 L
.05556 .4856 L
.05556 .47579 L
.02381 .47579 L
s
.02381 .4856 m
.02381 .49541 L
.05556 .49541 L
.05556 .4856 L
.02381 .4856 L
s
.02381 .49541 m
.02381 .50522 L
.05556 .50522 L
.05556 .49541 L
.02381 .49541 L
s
.02381 .50522 m
.02381 .51503 L
.05556 .51503 L
.05556 .50522 L
.02381 .50522 L
s
.02381 .51503 m
.02381 .52484 L
.05556 .52484 L
.05556 .51503 L
.02381 .51503 L
s
.02381 .52484 m
.02381 .53465 L
.05556 .53465 L
.05556 .52484 L
.02381 .52484 L
s
.02381 .53465 m
.02381 .54446 L
.05556 .54446 L
.05556 .53465 L
.02381 .53465 L
s
.02381 .54446 m
.02381 .55427 L
.05556 .55427 L
.05556 .54446 L
.02381 .54446 L
s
.02381 .55427 m
.02381 .56408 L
.05556 .56408 L
.05556 .55427 L
.02381 .55427 L
s
.02381 .56408 m
.02381 .57389 L
.05556 .57389 L
.05556 .56408 L
.02381 .56408 L
s
.02381 .57389 m
.02381 .5837 L
.05556 .5837 L
.05556 .57389 L
.02381 .57389 L
s
.02381 .5837 m
.02381 .59351 L
.05556 .59351 L
.05556 .5837 L
.02381 .5837 L
s
.02381 .59351 m
.02381 .60332 L
.05556 .60332 L
.05556 .59351 L
.02381 .59351 L
s
.05556 .01472 m
.05556 .02453 L
.0873 .02453 L
.0873 .01472 L
.05556 .01472 L
s
.05556 .02453 m
.05556 .03434 L
.0873 .03434 L
.0873 .02453 L
.05556 .02453 L
s
.05556 .03434 m
.05556 .04415 L
.0873 .04415 L
.0873 .03434 L
.05556 .03434 L
s
.05556 .04415 m
.05556 .05396 L
.0873 .05396 L
.0873 .04415 L
.05556 .04415 L
s
.05556 .05396 m
.05556 .06377 L
.0873 .06377 L
.0873 .05396 L
.05556 .05396 L
s
.05556 .06377 m
.05556 .07358 L
.0873 .07358 L
.0873 .06377 L
.05556 .06377 L
s
.05556 .07358 m
.05556 .08339 L
.0873 .08339 L
.0873 .07358 L
.05556 .07358 L
s
.05556 .08339 m
.05556 .0932 L
.0873 .0932 L
.0873 .08339 L
.05556 .08339 L
s
.05556 .0932 m
.05556 .10301 L
.0873 .10301 L
.0873 .0932 L
.05556 .0932 L
s
.05556 .10301 m
.05556 .11282 L
.0873 .11282 L
.0873 .10301 L
.05556 .10301 L
s
.05556 .11282 m
.05556 .12263 L
.0873 .12263 L
.0873 .11282 L
.05556 .11282 L
s
.05556 .12263 m
.05556 .13244 L
.0873 .13244 L
.0873 .12263 L
.05556 .12263 L
s
.05556 .13244 m
.05556 .14225 L
.0873 .14225 L
.0873 .13244 L
.05556 .13244 L
s
.05556 .14225 m
.05556 .15206 L
.0873 .15206 L
.0873 .14225 L
.05556 .14225 L
s
.05556 .15206 m
.05556 .16187 L
.0873 .16187 L
.0873 .15206 L
.05556 .15206 L
s
.05556 .16187 m
.05556 .17168 L
.0873 .17168 L
.0873 .16187 L
.05556 .16187 L
s
.05556 .17168 m
.05556 .18149 L
.0873 .18149 L
.0873 .17168 L
.05556 .17168 L
s
.05556 .18149 m
.05556 .1913 L
.0873 .1913 L
.0873 .18149 L
.05556 .18149 L
s
.05556 .1913 m
.05556 .20111 L
.0873 .20111 L
.0873 .1913 L
.05556 .1913 L
s
.05556 .20111 m
.05556 .21092 L
.0873 .21092 L
.0873 .20111 L
.05556 .20111 L
s
.05556 .21092 m
.05556 .22073 L
.0873 .22073 L
.0873 .21092 L
.05556 .21092 L
s
.05556 .22073 m
.05556 .23054 L
.0873 .23054 L
.0873 .22073 L
.05556 .22073 L
s
.05556 .23054 m
.05556 .24035 L
.0873 .24035 L
.0873 .23054 L
.05556 .23054 L
s
.05556 .24035 m
.05556 .25016 L
.0873 .25016 L
.0873 .24035 L
.05556 .24035 L
s
.05556 .25016 m
.05556 .25997 L
.0873 .25997 L
.0873 .25016 L
.05556 .25016 L
s
.05556 .25997 m
.05556 .26978 L
.0873 .26978 L
.0873 .25997 L
.05556 .25997 L
s
.05556 .26978 m
.05556 .27959 L
.0873 .27959 L
.0873 .26978 L
.05556 .26978 L
s
.05556 .27959 m
.05556 .2894 L
.0873 .2894 L
.0873 .27959 L
.05556 .27959 L
s
.05556 .2894 m
.05556 .29921 L
.0873 .29921 L
.0873 .2894 L
.05556 .2894 L
s
.05556 .29921 m
.05556 .30902 L
.0873 .30902 L
.0873 .29921 L
.05556 .29921 L
s
.05556 .30902 m
.05556 .31883 L
.0873 .31883 L
.0873 .30902 L
.05556 .30902 L
s
.05556 .31883 m
.05556 .32864 L
.0873 .32864 L
.0873 .31883 L
.05556 .31883 L
s
.05556 .32864 m
.05556 .33845 L
.0873 .33845 L
.0873 .32864 L
.05556 .32864 L
s
.05556 .33845 m
.05556 .34826 L
.0873 .34826 L
.0873 .33845 L
.05556 .33845 L
s
.05556 .34826 m
.05556 .35807 L
.0873 .35807 L
.0873 .34826 L
.05556 .34826 L
s
.05556 .35807 m
.05556 .36788 L
.0873 .36788 L
.0873 .35807 L
.05556 .35807 L
s
.05556 .36788 m
.05556 .37769 L
.0873 .37769 L
.0873 .36788 L
.05556 .36788 L
s
.05556 .37769 m
.05556 .3875 L
.0873 .3875 L
.0873 .37769 L
.05556 .37769 L
s
.05556 .3875 m
.05556 .39731 L
.0873 .39731 L
.0873 .3875 L
.05556 .3875 L
s
.05556 .39731 m
.05556 .40712 L
.0873 .40712 L
.0873 .39731 L
.05556 .39731 L
s
.05556 .40712 m
.05556 .41693 L
.0873 .41693 L
.0873 .40712 L
.05556 .40712 L
s
.05556 .41693 m
.05556 .42674 L
.0873 .42674 L
.0873 .41693 L
.05556 .41693 L
s
.05556 .42674 m
.05556 .43655 L
.0873 .43655 L
.0873 .42674 L
.05556 .42674 L
s
.05556 .43655 m
.05556 .44636 L
.0873 .44636 L
.0873 .43655 L
.05556 .43655 L
s
.05556 .44636 m
.05556 .45617 L
.0873 .45617 L
.0873 .44636 L
.05556 .44636 L
s
.05556 .45617 m
.05556 .46598 L
.0873 .46598 L
.0873 .45617 L
.05556 .45617 L
s
.05556 .46598 m
.05556 .47579 L
.0873 .47579 L
.0873 .46598 L
.05556 .46598 L
s
.05556 .47579 m
.05556 .4856 L
.0873 .4856 L
.0873 .47579 L
.05556 .47579 L
s
.05556 .4856 m
.05556 .49541 L
.0873 .49541 L
.0873 .4856 L
.05556 .4856 L
s
.05556 .49541 m
.05556 .50522 L
.0873 .50522 L
.0873 .49541 L
.05556 .49541 L
s
.05556 .50522 m
.05556 .51503 L
.0873 .51503 L
.0873 .50522 L
.05556 .50522 L
s
.05556 .51503 m
.05556 .52484 L
.0873 .52484 L
.0873 .51503 L
.05556 .51503 L
s
.05556 .52484 m
.05556 .53465 L
.0873 .53465 L
.0873 .52484 L
.05556 .52484 L
s
.05556 .53465 m
.05556 .54446 L
.0873 .54446 L
.0873 .53465 L
.05556 .53465 L
s
.05556 .54446 m
.05556 .55427 L
.0873 .55427 L
.0873 .54446 L
.05556 .54446 L
s
.05556 .55427 m
.05556 .56408 L
.0873 .56408 L
.0873 .55427 L
.05556 .55427 L
s
.05556 .56408 m
.05556 .57389 L
.0873 .57389 L
.0873 .56408 L
.05556 .56408 L
s
.05556 .57389 m
.05556 .5837 L
.0873 .5837 L
.0873 .57389 L
.05556 .57389 L
s
.05556 .5837 m
.05556 .59351 L
.0873 .59351 L
.0873 .5837 L
.05556 .5837 L
s
.05556 .59351 m
.05556 .60332 L
.0873 .60332 L
.0873 .59351 L
.05556 .59351 L
s
.0873 .01472 m
.0873 .02453 L
.11905 .02453 L
.11905 .01472 L
.0873 .01472 L
s
.0873 .02453 m
.0873 .03434 L
.11905 .03434 L
.11905 .02453 L
.0873 .02453 L
s
.0873 .03434 m
.0873 .04415 L
.11905 .04415 L
.11905 .03434 L
.0873 .03434 L
s
.0873 .04415 m
.0873 .05396 L
.11905 .05396 L
.11905 .04415 L
.0873 .04415 L
s
.0873 .05396 m
.0873 .06377 L
.11905 .06377 L
.11905 .05396 L
.0873 .05396 L
s
.0873 .06377 m
.0873 .07358 L
.11905 .07358 L
.11905 .06377 L
.0873 .06377 L
s
.0873 .07358 m
.0873 .08339 L
.11905 .08339 L
.11905 .07358 L
.0873 .07358 L
s
.0873 .08339 m
.0873 .0932 L
.11905 .0932 L
.11905 .08339 L
.0873 .08339 L
s
.0873 .0932 m
.0873 .10301 L
.11905 .10301 L
.11905 .0932 L
.0873 .0932 L
s
.0873 .10301 m
.0873 .11282 L
.11905 .11282 L
.11905 .10301 L
.0873 .10301 L
s
.0873 .11282 m
.0873 .12263 L
.11905 .12263 L
.11905 .11282 L
.0873 .11282 L
s
.0873 .12263 m
.0873 .13244 L
.11905 .13244 L
.11905 .12263 L
.0873 .12263 L
s
.0873 .13244 m
.0873 .14225 L
.11905 .14225 L
.11905 .13244 L
.0873 .13244 L
s
.0873 .14225 m
.0873 .15206 L
.11905 .15206 L
.11905 .14225 L
.0873 .14225 L
s
.0873 .15206 m
.0873 .16187 L
.11905 .16187 L
.11905 .15206 L
.0873 .15206 L
s
.0873 .16187 m
.0873 .17168 L
.11905 .17168 L
.11905 .16187 L
.0873 .16187 L
s
.0873 .17168 m
.0873 .18149 L
.11905 .18149 L
.11905 .17168 L
.0873 .17168 L
s
.0873 .18149 m
.0873 .1913 L
.11905 .1913 L
.11905 .18149 L
.0873 .18149 L
s
.0873 .1913 m
.0873 .20111 L
.11905 .20111 L
.11905 .1913 L
.0873 .1913 L
s
.0873 .20111 m
.0873 .21092 L
.11905 .21092 L
.11905 .20111 L
.0873 .20111 L
s
.0873 .21092 m
.0873 .22073 L
.11905 .22073 L
.11905 .21092 L
.0873 .21092 L
s
.0873 .22073 m
.0873 .23054 L
.11905 .23054 L
.11905 .22073 L
.0873 .22073 L
s
.0873 .23054 m
.0873 .24035 L
.11905 .24035 L
.11905 .23054 L
.0873 .23054 L
s
.0873 .24035 m
.0873 .25016 L
.11905 .25016 L
.11905 .24035 L
.0873 .24035 L
s
.0873 .25016 m
.0873 .25997 L
.11905 .25997 L
.11905 .25016 L
.0873 .25016 L
s
.0873 .25997 m
.0873 .26978 L
.11905 .26978 L
.11905 .25997 L
.0873 .25997 L
s
.0873 .26978 m
.0873 .27959 L
.11905 .27959 L
.11905 .26978 L
.0873 .26978 L
s
.0873 .27959 m
.0873 .2894 L
.11905 .2894 L
.11905 .27959 L
.0873 .27959 L
s
.0873 .2894 m
.0873 .29921 L
.11905 .29921 L
.11905 .2894 L
.0873 .2894 L
s
.0873 .29921 m
.0873 .30902 L
.11905 .30902 L
.11905 .29921 L
.0873 .29921 L
s
.0873 .30902 m
.0873 .31883 L
.11905 .31883 L
.11905 .30902 L
.0873 .30902 L
s
.0873 .31883 m
.0873 .32864 L
.11905 .32864 L
.11905 .31883 L
.0873 .31883 L
s
.0873 .32864 m
.0873 .33845 L
.11905 .33845 L
.11905 .32864 L
.0873 .32864 L
s
.0873 .33845 m
.0873 .34826 L
.11905 .34826 L
.11905 .33845 L
.0873 .33845 L
s
.0873 .34826 m
.0873 .35807 L
.11905 .35807 L
.11905 .34826 L
.0873 .34826 L
s
.0873 .35807 m
.0873 .36788 L
.11905 .36788 L
.11905 .35807 L
.0873 .35807 L
s
.0873 .36788 m
.0873 .37769 L
.11905 .37769 L
.11905 .36788 L
.0873 .36788 L
s
.0873 .37769 m
.0873 .3875 L
.11905 .3875 L
.11905 .37769 L
.0873 .37769 L
s
.0873 .3875 m
.0873 .39731 L
.11905 .39731 L
.11905 .3875 L
.0873 .3875 L
s
.0873 .39731 m
.0873 .40712 L
.11905 .40712 L
.11905 .39731 L
.0873 .39731 L
s
.0873 .40712 m
.0873 .41693 L
.11905 .41693 L
.11905 .40712 L
.0873 .40712 L
s
.0873 .41693 m
.0873 .42674 L
.11905 .42674 L
.11905 .41693 L
.0873 .41693 L
s
.0873 .42674 m
.0873 .43655 L
.11905 .43655 L
.11905 .42674 L
.0873 .42674 L
s
.0873 .43655 m
.0873 .44636 L
.11905 .44636 L
.11905 .43655 L
.0873 .43655 L
s
.0873 .44636 m
.0873 .45617 L
.11905 .45617 L
.11905 .44636 L
.0873 .44636 L
s
.0873 .45617 m
.0873 .46598 L
.11905 .46598 L
.11905 .45617 L
.0873 .45617 L
s
.0873 .46598 m
.0873 .47579 L
.11905 .47579 L
.11905 .46598 L
.0873 .46598 L
s
.0873 .47579 m
.0873 .4856 L
.11905 .4856 L
.11905 .47579 L
.0873 .47579 L
s
.0873 .4856 m
.0873 .49541 L
.11905 .49541 L
.11905 .4856 L
.0873 .4856 L
s
.0873 .49541 m
.0873 .50522 L
.11905 .50522 L
.11905 .49541 L
.0873 .49541 L
s
.0873 .50522 m
.0873 .51503 L
.11905 .51503 L
.11905 .50522 L
.0873 .50522 L
s
.0873 .51503 m
.0873 .52484 L
.11905 .52484 L
.11905 .51503 L
.0873 .51503 L
s
.0873 .52484 m
.0873 .53465 L
.11905 .53465 L
.11905 .52484 L
.0873 .52484 L
s
.0873 .53465 m
.0873 .54446 L
.11905 .54446 L
.11905 .53465 L
.0873 .53465 L
s
.0873 .54446 m
.0873 .55427 L
.11905 .55427 L
.11905 .54446 L
.0873 .54446 L
s
.0873 .55427 m
.0873 .56408 L
.11905 .56408 L
.11905 .55427 L
.0873 .55427 L
s
.0873 .56408 m
.0873 .57389 L
.11905 .57389 L
.11905 .56408 L
.0873 .56408 L
s
.0873 .57389 m
.0873 .5837 L
.11905 .5837 L
.11905 .57389 L
.0873 .57389 L
s
.0873 .5837 m
.0873 .59351 L
.11905 .59351 L
.11905 .5837 L
.0873 .5837 L
s
.0873 .59351 m
.0873 .60332 L
.11905 .60332 L
.11905 .59351 L
.0873 .59351 L
s
.11905 .01472 m
.11905 .02453 L
.15079 .02453 L
.15079 .01472 L
.11905 .01472 L
s
.11905 .02453 m
.11905 .03434 L
.15079 .03434 L
.15079 .02453 L
.11905 .02453 L
s
.11905 .03434 m
.11905 .04415 L
.15079 .04415 L
.15079 .03434 L
.11905 .03434 L
s
.11905 .04415 m
.11905 .05396 L
.15079 .05396 L
.15079 .04415 L
.11905 .04415 L
s
.11905 .05396 m
.11905 .06377 L
.15079 .06377 L
.15079 .05396 L
.11905 .05396 L
s
.11905 .06377 m
.11905 .07358 L
.15079 .07358 L
.15079 .06377 L
.11905 .06377 L
s
.11905 .07358 m
.11905 .08339 L
.15079 .08339 L
.15079 .07358 L
.11905 .07358 L
s
.11905 .08339 m
.11905 .0932 L
.15079 .0932 L
.15079 .08339 L
.11905 .08339 L
s
.11905 .0932 m
.11905 .10301 L
.15079 .10301 L
.15079 .0932 L
.11905 .0932 L
s
.11905 .10301 m
.11905 .11282 L
.15079 .11282 L
.15079 .10301 L
.11905 .10301 L
s
.11905 .11282 m
.11905 .12263 L
.15079 .12263 L
.15079 .11282 L
.11905 .11282 L
s
.11905 .12263 m
.11905 .13244 L
.15079 .13244 L
.15079 .12263 L
.11905 .12263 L
s
.11905 .13244 m
.11905 .14225 L
.15079 .14225 L
.15079 .13244 L
.11905 .13244 L
s
.11905 .14225 m
.11905 .15206 L
.15079 .15206 L
.15079 .14225 L
.11905 .14225 L
s
.11905 .15206 m
.11905 .16187 L
.15079 .16187 L
.15079 .15206 L
.11905 .15206 L
s
.11905 .16187 m
.11905 .17168 L
.15079 .17168 L
.15079 .16187 L
.11905 .16187 L
s
.11905 .17168 m
.11905 .18149 L
.15079 .18149 L
.15079 .17168 L
.11905 .17168 L
s
.11905 .18149 m
.11905 .1913 L
.15079 .1913 L
.15079 .18149 L
.11905 .18149 L
s
.11905 .1913 m
.11905 .20111 L
.15079 .20111 L
.15079 .1913 L
.11905 .1913 L
s
.11905 .20111 m
.11905 .21092 L
.15079 .21092 L
.15079 .20111 L
.11905 .20111 L
s
.11905 .21092 m
.11905 .22073 L
.15079 .22073 L
.15079 .21092 L
.11905 .21092 L
s
.11905 .22073 m
.11905 .23054 L
.15079 .23054 L
.15079 .22073 L
.11905 .22073 L
s
.11905 .23054 m
.11905 .24035 L
.15079 .24035 L
.15079 .23054 L
.11905 .23054 L
s
.11905 .24035 m
.11905 .25016 L
.15079 .25016 L
.15079 .24035 L
.11905 .24035 L
s
.11905 .25016 m
.11905 .25997 L
.15079 .25997 L
.15079 .25016 L
.11905 .25016 L
s
.11905 .25997 m
.11905 .26978 L
.15079 .26978 L
.15079 .25997 L
.11905 .25997 L
s
.11905 .26978 m
.11905 .27959 L
.15079 .27959 L
.15079 .26978 L
.11905 .26978 L
s
.11905 .27959 m
.11905 .2894 L
.15079 .2894 L
.15079 .27959 L
.11905 .27959 L
s
.11905 .2894 m
.11905 .29921 L
.15079 .29921 L
.15079 .2894 L
.11905 .2894 L
s
.11905 .29921 m
.11905 .30902 L
.15079 .30902 L
.15079 .29921 L
.11905 .29921 L
s
.11905 .30902 m
.11905 .31883 L
.15079 .31883 L
.15079 .30902 L
.11905 .30902 L
s
.11905 .31883 m
.11905 .32864 L
.15079 .32864 L
.15079 .31883 L
.11905 .31883 L
s
.11905 .32864 m
.11905 .33845 L
.15079 .33845 L
.15079 .32864 L
.11905 .32864 L
s
.11905 .33845 m
.11905 .34826 L
.15079 .34826 L
.15079 .33845 L
.11905 .33845 L
s
.11905 .34826 m
.11905 .35807 L
.15079 .35807 L
.15079 .34826 L
.11905 .34826 L
s
.11905 .35807 m
.11905 .36788 L
.15079 .36788 L
.15079 .35807 L
.11905 .35807 L
s
.11905 .36788 m
.11905 .37769 L
.15079 .37769 L
.15079 .36788 L
.11905 .36788 L
s
.11905 .37769 m
.11905 .3875 L
.15079 .3875 L
.15079 .37769 L
.11905 .37769 L
s
.11905 .3875 m
.11905 .39731 L
.15079 .39731 L
.15079 .3875 L
.11905 .3875 L
s
.11905 .39731 m
.11905 .40712 L
.15079 .40712 L
.15079 .39731 L
.11905 .39731 L
s
.11905 .40712 m
.11905 .41693 L
.15079 .41693 L
.15079 .40712 L
.11905 .40712 L
s
.11905 .41693 m
.11905 .42674 L
.15079 .42674 L
.15079 .41693 L
.11905 .41693 L
s
.11905 .42674 m
.11905 .43655 L
.15079 .43655 L
.15079 .42674 L
.11905 .42674 L
s
.11905 .43655 m
.11905 .44636 L
.15079 .44636 L
.15079 .43655 L
.11905 .43655 L
s
.11905 .44636 m
.11905 .45617 L
.15079 .45617 L
.15079 .44636 L
.11905 .44636 L
s
.11905 .45617 m
.11905 .46598 L
.15079 .46598 L
.15079 .45617 L
.11905 .45617 L
s
.11905 .46598 m
.11905 .47579 L
.15079 .47579 L
.15079 .46598 L
.11905 .46598 L
s
.11905 .47579 m
.11905 .4856 L
.15079 .4856 L
.15079 .47579 L
.11905 .47579 L
s
.11905 .4856 m
.11905 .49541 L
.15079 .49541 L
.15079 .4856 L
.11905 .4856 L
s
.11905 .49541 m
.11905 .50522 L
.15079 .50522 L
.15079 .49541 L
.11905 .49541 L
s
.11905 .50522 m
.11905 .51503 L
.15079 .51503 L
.15079 .50522 L
.11905 .50522 L
s
.11905 .51503 m
.11905 .52484 L
.15079 .52484 L
.15079 .51503 L
.11905 .51503 L
s
.11905 .52484 m
.11905 .53465 L
.15079 .53465 L
.15079 .52484 L
.11905 .52484 L
s
.11905 .53465 m
.11905 .54446 L
.15079 .54446 L
.15079 .53465 L
.11905 .53465 L
s
.11905 .54446 m
.11905 .55427 L
.15079 .55427 L
.15079 .54446 L
.11905 .54446 L
s
.11905 .55427 m
.11905 .56408 L
.15079 .56408 L
.15079 .55427 L
.11905 .55427 L
s
.11905 .56408 m
.11905 .57389 L
.15079 .57389 L
.15079 .56408 L
.11905 .56408 L
s
.11905 .57389 m
.11905 .5837 L
.15079 .5837 L
.15079 .57389 L
.11905 .57389 L
s
.11905 .5837 m
.11905 .59351 L
.15079 .59351 L
.15079 .5837 L
.11905 .5837 L
s
.11905 .59351 m
.11905 .60332 L
.15079 .60332 L
.15079 .59351 L
.11905 .59351 L
s
.15079 .01472 m
.15079 .02453 L
.18254 .02453 L
.18254 .01472 L
.15079 .01472 L
s
.15079 .02453 m
.15079 .03434 L
.18254 .03434 L
.18254 .02453 L
.15079 .02453 L
s
.15079 .03434 m
.15079 .04415 L
.18254 .04415 L
.18254 .03434 L
.15079 .03434 L
s
.15079 .04415 m
.15079 .05396 L
.18254 .05396 L
.18254 .04415 L
.15079 .04415 L
s
.15079 .05396 m
.15079 .06377 L
.18254 .06377 L
.18254 .05396 L
.15079 .05396 L
s
.15079 .06377 m
.15079 .07358 L
.18254 .07358 L
.18254 .06377 L
.15079 .06377 L
s
.15079 .07358 m
.15079 .08339 L
.18254 .08339 L
.18254 .07358 L
.15079 .07358 L
s
.15079 .08339 m
.15079 .0932 L
.18254 .0932 L
.18254 .08339 L
.15079 .08339 L
s
.15079 .0932 m
.15079 .10301 L
.18254 .10301 L
.18254 .0932 L
.15079 .0932 L
s
.15079 .10301 m
.15079 .11282 L
.18254 .11282 L
.18254 .10301 L
.15079 .10301 L
s
.15079 .11282 m
.15079 .12263 L
.18254 .12263 L
.18254 .11282 L
.15079 .11282 L
s
.15079 .12263 m
.15079 .13244 L
.18254 .13244 L
.18254 .12263 L
.15079 .12263 L
s
.15079 .13244 m
.15079 .14225 L
.18254 .14225 L
.18254 .13244 L
.15079 .13244 L
s
.15079 .14225 m
.15079 .15206 L
.18254 .15206 L
.18254 .14225 L
.15079 .14225 L
s
.15079 .15206 m
.15079 .16187 L
.18254 .16187 L
.18254 .15206 L
.15079 .15206 L
s
.15079 .16187 m
.15079 .17168 L
.18254 .17168 L
.18254 .16187 L
.15079 .16187 L
s
.15079 .17168 m
.15079 .18149 L
.18254 .18149 L
.18254 .17168 L
.15079 .17168 L
s
.15079 .18149 m
.15079 .1913 L
.18254 .1913 L
.18254 .18149 L
.15079 .18149 L
s
.15079 .1913 m
.15079 .20111 L
.18254 .20111 L
.18254 .1913 L
.15079 .1913 L
s
.15079 .20111 m
.15079 .21092 L
.18254 .21092 L
.18254 .20111 L
.15079 .20111 L
s
.15079 .21092 m
.15079 .22073 L
.18254 .22073 L
.18254 .21092 L
.15079 .21092 L
s
.15079 .22073 m
.15079 .23054 L
.18254 .23054 L
.18254 .22073 L
.15079 .22073 L
s
.15079 .23054 m
.15079 .24035 L
.18254 .24035 L
.18254 .23054 L
.15079 .23054 L
s
.15079 .24035 m
.15079 .25016 L
.18254 .25016 L
.18254 .24035 L
.15079 .24035 L
s
.15079 .25016 m
.15079 .25997 L
.18254 .25997 L
.18254 .25016 L
.15079 .25016 L
s
.15079 .25997 m
.15079 .26978 L
.18254 .26978 L
.18254 .25997 L
.15079 .25997 L
s
.15079 .26978 m
.15079 .27959 L
.18254 .27959 L
.18254 .26978 L
.15079 .26978 L
s
.15079 .27959 m
.15079 .2894 L
.18254 .2894 L
.18254 .27959 L
.15079 .27959 L
s
.15079 .2894 m
.15079 .29921 L
.18254 .29921 L
.18254 .2894 L
.15079 .2894 L
s
.15079 .29921 m
.15079 .30902 L
.18254 .30902 L
.18254 .29921 L
.15079 .29921 L
s
.15079 .30902 m
.15079 .31883 L
.18254 .31883 L
.18254 .30902 L
.15079 .30902 L
s
.15079 .31883 m
.15079 .32864 L
.18254 .32864 L
.18254 .31883 L
.15079 .31883 L
s
.15079 .32864 m
.15079 .33845 L
.18254 .33845 L
.18254 .32864 L
.15079 .32864 L
s
.15079 .33845 m
.15079 .34826 L
.18254 .34826 L
.18254 .33845 L
.15079 .33845 L
s
.15079 .34826 m
.15079 .35807 L
.18254 .35807 L
.18254 .34826 L
.15079 .34826 L
s
.15079 .35807 m
.15079 .36788 L
.18254 .36788 L
.18254 .35807 L
.15079 .35807 L
s
.15079 .36788 m
.15079 .37769 L
.18254 .37769 L
.18254 .36788 L
.15079 .36788 L
s
.15079 .37769 m
.15079 .3875 L
.18254 .3875 L
.18254 .37769 L
.15079 .37769 L
s
.15079 .3875 m
.15079 .39731 L
.18254 .39731 L
.18254 .3875 L
.15079 .3875 L
s
.15079 .39731 m
.15079 .40712 L
.18254 .40712 L
.18254 .39731 L
.15079 .39731 L
s
.15079 .40712 m
.15079 .41693 L
.18254 .41693 L
.18254 .40712 L
.15079 .40712 L
s
.15079 .41693 m
.15079 .42674 L
.18254 .42674 L
.18254 .41693 L
.15079 .41693 L
s
.15079 .42674 m
.15079 .43655 L
.18254 .43655 L
.18254 .42674 L
.15079 .42674 L
s
.15079 .43655 m
.15079 .44636 L
.18254 .44636 L
.18254 .43655 L
.15079 .43655 L
s
.15079 .44636 m
.15079 .45617 L
.18254 .45617 L
.18254 .44636 L
.15079 .44636 L
s
.15079 .45617 m
.15079 .46598 L
.18254 .46598 L
.18254 .45617 L
.15079 .45617 L
s
.15079 .46598 m
.15079 .47579 L
.18254 .47579 L
.18254 .46598 L
.15079 .46598 L
s
.15079 .47579 m
.15079 .4856 L
.18254 .4856 L
.18254 .47579 L
.15079 .47579 L
s
.15079 .4856 m
.15079 .49541 L
.18254 .49541 L
.18254 .4856 L
.15079 .4856 L
s
.15079 .49541 m
.15079 .50522 L
.18254 .50522 L
.18254 .49541 L
.15079 .49541 L
s
.15079 .50522 m
.15079 .51503 L
.18254 .51503 L
.18254 .50522 L
.15079 .50522 L
s
.15079 .51503 m
.15079 .52484 L
.18254 .52484 L
.18254 .51503 L
.15079 .51503 L
s
.15079 .52484 m
.15079 .53465 L
.18254 .53465 L
.18254 .52484 L
.15079 .52484 L
s
.15079 .53465 m
.15079 .54446 L
.18254 .54446 L
.18254 .53465 L
.15079 .53465 L
s
.15079 .54446 m
.15079 .55427 L
.18254 .55427 L
.18254 .54446 L
.15079 .54446 L
s
.15079 .55427 m
.15079 .56408 L
.18254 .56408 L
.18254 .55427 L
.15079 .55427 L
s
.15079 .56408 m
.15079 .57389 L
.18254 .57389 L
.18254 .56408 L
.15079 .56408 L
s
.15079 .57389 m
.15079 .5837 L
.18254 .5837 L
.18254 .57389 L
.15079 .57389 L
s
.15079 .5837 m
.15079 .59351 L
.18254 .59351 L
.18254 .5837 L
.15079 .5837 L
s
.15079 .59351 m
.15079 .60332 L
.18254 .60332 L
.18254 .59351 L
.15079 .59351 L
s
.18254 .01472 m
.18254 .02453 L
.21429 .02453 L
.21429 .01472 L
.18254 .01472 L
s
.18254 .02453 m
.18254 .03434 L
.21429 .03434 L
.21429 .02453 L
.18254 .02453 L
s
.18254 .03434 m
.18254 .04415 L
.21429 .04415 L
.21429 .03434 L
.18254 .03434 L
s
.18254 .04415 m
.18254 .05396 L
.21429 .05396 L
.21429 .04415 L
.18254 .04415 L
s
.18254 .05396 m
.18254 .06377 L
.21429 .06377 L
.21429 .05396 L
.18254 .05396 L
s
.18254 .06377 m
.18254 .07358 L
.21429 .07358 L
.21429 .06377 L
.18254 .06377 L
s
.18254 .07358 m
.18254 .08339 L
.21429 .08339 L
.21429 .07358 L
.18254 .07358 L
s
.18254 .08339 m
.18254 .0932 L
.21429 .0932 L
.21429 .08339 L
.18254 .08339 L
s
.18254 .0932 m
.18254 .10301 L
.21429 .10301 L
.21429 .0932 L
.18254 .0932 L
s
.18254 .10301 m
.18254 .11282 L
.21429 .11282 L
.21429 .10301 L
.18254 .10301 L
s
.18254 .11282 m
.18254 .12263 L
.21429 .12263 L
.21429 .11282 L
.18254 .11282 L
s
.18254 .12263 m
.18254 .13244 L
.21429 .13244 L
.21429 .12263 L
.18254 .12263 L
s
.18254 .13244 m
.18254 .14225 L
.21429 .14225 L
.21429 .13244 L
.18254 .13244 L
s
.18254 .14225 m
.18254 .15206 L
.21429 .15206 L
.21429 .14225 L
.18254 .14225 L
s
.18254 .15206 m
.18254 .16187 L
.21429 .16187 L
.21429 .15206 L
.18254 .15206 L
s
.18254 .16187 m
.18254 .17168 L
.21429 .17168 L
.21429 .16187 L
.18254 .16187 L
s
.18254 .17168 m
.18254 .18149 L
.21429 .18149 L
.21429 .17168 L
.18254 .17168 L
s
.18254 .18149 m
.18254 .1913 L
.21429 .1913 L
.21429 .18149 L
.18254 .18149 L
s
.18254 .1913 m
.18254 .20111 L
.21429 .20111 L
.21429 .1913 L
.18254 .1913 L
s
.18254 .20111 m
.18254 .21092 L
.21429 .21092 L
.21429 .20111 L
.18254 .20111 L
s
.18254 .21092 m
.18254 .22073 L
.21429 .22073 L
.21429 .21092 L
.18254 .21092 L
s
.18254 .22073 m
.18254 .23054 L
.21429 .23054 L
.21429 .22073 L
.18254 .22073 L
s
.18254 .23054 m
.18254 .24035 L
.21429 .24035 L
.21429 .23054 L
.18254 .23054 L
s
.18254 .24035 m
.18254 .25016 L
.21429 .25016 L
.21429 .24035 L
.18254 .24035 L
s
.18254 .25016 m
.18254 .25997 L
.21429 .25997 L
.21429 .25016 L
.18254 .25016 L
s
.18254 .25997 m
.18254 .26978 L
.21429 .26978 L
.21429 .25997 L
.18254 .25997 L
s
.18254 .26978 m
.18254 .27959 L
.21429 .27959 L
.21429 .26978 L
.18254 .26978 L
s
.18254 .27959 m
.18254 .2894 L
.21429 .2894 L
.21429 .27959 L
.18254 .27959 L
s
.18254 .2894 m
.18254 .29921 L
.21429 .29921 L
.21429 .2894 L
.18254 .2894 L
s
.18254 .29921 m
.18254 .30902 L
.21429 .30902 L
.21429 .29921 L
.18254 .29921 L
s
.18254 .30902 m
.18254 .31883 L
.21429 .31883 L
.21429 .30902 L
.18254 .30902 L
s
.18254 .31883 m
.18254 .32864 L
.21429 .32864 L
.21429 .31883 L
.18254 .31883 L
s
.18254 .32864 m
.18254 .33845 L
.21429 .33845 L
.21429 .32864 L
.18254 .32864 L
s
.18254 .33845 m
.18254 .34826 L
.21429 .34826 L
.21429 .33845 L
.18254 .33845 L
s
.18254 .34826 m
.18254 .35807 L
.21429 .35807 L
.21429 .34826 L
.18254 .34826 L
s
.18254 .35807 m
.18254 .36788 L
.21429 .36788 L
.21429 .35807 L
.18254 .35807 L
s
.18254 .36788 m
.18254 .37769 L
.21429 .37769 L
.21429 .36788 L
.18254 .36788 L
s
.18254 .37769 m
.18254 .3875 L
.21429 .3875 L
.21429 .37769 L
.18254 .37769 L
s
.18254 .3875 m
.18254 .39731 L
.21429 .39731 L
.21429 .3875 L
.18254 .3875 L
s
.18254 .39731 m
.18254 .40712 L
.21429 .40712 L
.21429 .39731 L
.18254 .39731 L
s
.18254 .40712 m
.18254 .41693 L
.21429 .41693 L
.21429 .40712 L
.18254 .40712 L
s
.18254 .41693 m
.18254 .42674 L
.21429 .42674 L
.21429 .41693 L
.18254 .41693 L
s
.18254 .42674 m
.18254 .43655 L
.21429 .43655 L
.21429 .42674 L
.18254 .42674 L
s
.18254 .43655 m
.18254 .44636 L
.21429 .44636 L
.21429 .43655 L
.18254 .43655 L
s
.18254 .44636 m
.18254 .45617 L
.21429 .45617 L
.21429 .44636 L
.18254 .44636 L
s
.18254 .45617 m
.18254 .46598 L
.21429 .46598 L
.21429 .45617 L
.18254 .45617 L
s
.18254 .46598 m
.18254 .47579 L
.21429 .47579 L
.21429 .46598 L
.18254 .46598 L
s
.18254 .47579 m
.18254 .4856 L
.21429 .4856 L
.21429 .47579 L
.18254 .47579 L
s
.18254 .4856 m
.18254 .49541 L
.21429 .49541 L
.21429 .4856 L
.18254 .4856 L
s
.18254 .49541 m
.18254 .50522 L
.21429 .50522 L
.21429 .49541 L
.18254 .49541 L
s
.18254 .50522 m
.18254 .51503 L
.21429 .51503 L
.21429 .50522 L
.18254 .50522 L
s
.18254 .51503 m
.18254 .52484 L
.21429 .52484 L
.21429 .51503 L
.18254 .51503 L
s
.18254 .52484 m
.18254 .53465 L
.21429 .53465 L
.21429 .52484 L
.18254 .52484 L
s
.18254 .53465 m
.18254 .54446 L
.21429 .54446 L
.21429 .53465 L
.18254 .53465 L
s
.18254 .54446 m
.18254 .55427 L
.21429 .55427 L
.21429 .54446 L
.18254 .54446 L
s
.18254 .55427 m
.18254 .56408 L
.21429 .56408 L
.21429 .55427 L
.18254 .55427 L
s
.18254 .56408 m
.18254 .57389 L
.21429 .57389 L
.21429 .56408 L
.18254 .56408 L
s
.18254 .57389 m
.18254 .5837 L
.21429 .5837 L
.21429 .57389 L
.18254 .57389 L
s
.18254 .5837 m
.18254 .59351 L
.21429 .59351 L
.21429 .5837 L
.18254 .5837 L
s
.18254 .59351 m
.18254 .60332 L
.21429 .60332 L
.21429 .59351 L
.18254 .59351 L
s
.21429 .01472 m
.21429 .02453 L
.24603 .02453 L
.24603 .01472 L
.21429 .01472 L
s
.21429 .02453 m
.21429 .03434 L
.24603 .03434 L
.24603 .02453 L
.21429 .02453 L
s
.21429 .03434 m
.21429 .04415 L
.24603 .04415 L
.24603 .03434 L
.21429 .03434 L
s
.21429 .04415 m
.21429 .05396 L
.24603 .05396 L
.24603 .04415 L
.21429 .04415 L
s
.21429 .05396 m
.21429 .06377 L
.24603 .06377 L
.24603 .05396 L
.21429 .05396 L
s
.21429 .06377 m
.21429 .07358 L
.24603 .07358 L
.24603 .06377 L
.21429 .06377 L
s
.21429 .07358 m
.21429 .08339 L
.24603 .08339 L
.24603 .07358 L
.21429 .07358 L
s
.21429 .08339 m
.21429 .0932 L
.24603 .0932 L
.24603 .08339 L
.21429 .08339 L
s
.21429 .0932 m
.21429 .10301 L
.24603 .10301 L
.24603 .0932 L
.21429 .0932 L
s
.21429 .10301 m
.21429 .11282 L
.24603 .11282 L
.24603 .10301 L
.21429 .10301 L
s
.21429 .11282 m
.21429 .12263 L
.24603 .12263 L
.24603 .11282 L
.21429 .11282 L
s
.21429 .12263 m
.21429 .13244 L
.24603 .13244 L
.24603 .12263 L
.21429 .12263 L
s
.21429 .13244 m
.21429 .14225 L
.24603 .14225 L
.24603 .13244 L
.21429 .13244 L
s
.21429 .14225 m
.21429 .15206 L
.24603 .15206 L
.24603 .14225 L
.21429 .14225 L
s
.21429 .15206 m
.21429 .16187 L
.24603 .16187 L
.24603 .15206 L
.21429 .15206 L
s
.21429 .16187 m
.21429 .17168 L
.24603 .17168 L
.24603 .16187 L
.21429 .16187 L
s
.21429 .17168 m
.21429 .18149 L
.24603 .18149 L
.24603 .17168 L
.21429 .17168 L
s
.21429 .18149 m
.21429 .1913 L
.24603 .1913 L
.24603 .18149 L
.21429 .18149 L
s
.21429 .1913 m
.21429 .20111 L
.24603 .20111 L
.24603 .1913 L
.21429 .1913 L
s
.21429 .20111 m
.21429 .21092 L
.24603 .21092 L
.24603 .20111 L
.21429 .20111 L
s
.21429 .21092 m
.21429 .22073 L
.24603 .22073 L
.24603 .21092 L
.21429 .21092 L
s
.21429 .22073 m
.21429 .23054 L
.24603 .23054 L
.24603 .22073 L
.21429 .22073 L
s
.21429 .23054 m
.21429 .24035 L
.24603 .24035 L
.24603 .23054 L
.21429 .23054 L
s
.21429 .24035 m
.21429 .25016 L
.24603 .25016 L
.24603 .24035 L
.21429 .24035 L
s
.21429 .25016 m
.21429 .25997 L
.24603 .25997 L
.24603 .25016 L
.21429 .25016 L
s
.21429 .25997 m
.21429 .26978 L
.24603 .26978 L
.24603 .25997 L
.21429 .25997 L
s
.21429 .26978 m
.21429 .27959 L
.24603 .27959 L
.24603 .26978 L
.21429 .26978 L
s
.21429 .27959 m
.21429 .2894 L
.24603 .2894 L
.24603 .27959 L
.21429 .27959 L
s
.21429 .2894 m
.21429 .29921 L
.24603 .29921 L
.24603 .2894 L
.21429 .2894 L
s
.21429 .29921 m
.21429 .30902 L
.24603 .30902 L
.24603 .29921 L
.21429 .29921 L
s
.21429 .30902 m
.21429 .31883 L
.24603 .31883 L
.24603 .30902 L
.21429 .30902 L
s
.21429 .31883 m
.21429 .32864 L
.24603 .32864 L
.24603 .31883 L
.21429 .31883 L
s
.21429 .32864 m
.21429 .33845 L
.24603 .33845 L
.24603 .32864 L
.21429 .32864 L
s
.21429 .33845 m
.21429 .34826 L
.24603 .34826 L
.24603 .33845 L
.21429 .33845 L
s
.21429 .34826 m
.21429 .35807 L
.24603 .35807 L
.24603 .34826 L
.21429 .34826 L
s
.21429 .35807 m
.21429 .36788 L
.24603 .36788 L
.24603 .35807 L
.21429 .35807 L
s
.21429 .36788 m
.21429 .37769 L
.24603 .37769 L
.24603 .36788 L
.21429 .36788 L
s
.21429 .37769 m
.21429 .3875 L
.24603 .3875 L
.24603 .37769 L
.21429 .37769 L
s
.21429 .3875 m
.21429 .39731 L
.24603 .39731 L
.24603 .3875 L
.21429 .3875 L
s
.21429 .39731 m
.21429 .40712 L
.24603 .40712 L
.24603 .39731 L
.21429 .39731 L
s
.21429 .40712 m
.21429 .41693 L
.24603 .41693 L
.24603 .40712 L
.21429 .40712 L
s
.21429 .41693 m
.21429 .42674 L
.24603 .42674 L
.24603 .41693 L
.21429 .41693 L
s
.21429 .42674 m
.21429 .43655 L
.24603 .43655 L
.24603 .42674 L
.21429 .42674 L
s
.21429 .43655 m
.21429 .44636 L
.24603 .44636 L
.24603 .43655 L
.21429 .43655 L
s
.21429 .44636 m
.21429 .45617 L
.24603 .45617 L
.24603 .44636 L
.21429 .44636 L
s
.21429 .45617 m
.21429 .46598 L
.24603 .46598 L
.24603 .45617 L
.21429 .45617 L
s
.21429 .46598 m
.21429 .47579 L
.24603 .47579 L
.24603 .46598 L
.21429 .46598 L
s
.21429 .47579 m
.21429 .4856 L
.24603 .4856 L
.24603 .47579 L
.21429 .47579 L
s
.21429 .4856 m
.21429 .49541 L
.24603 .49541 L
.24603 .4856 L
.21429 .4856 L
s
.21429 .49541 m
.21429 .50522 L
.24603 .50522 L
.24603 .49541 L
.21429 .49541 L
s
.21429 .50522 m
.21429 .51503 L
.24603 .51503 L
.24603 .50522 L
.21429 .50522 L
s
.21429 .51503 m
.21429 .52484 L
.24603 .52484 L
.24603 .51503 L
.21429 .51503 L
s
.21429 .52484 m
.21429 .53465 L
.24603 .53465 L
.24603 .52484 L
.21429 .52484 L
s
.21429 .53465 m
.21429 .54446 L
.24603 .54446 L
.24603 .53465 L
.21429 .53465 L
s
.21429 .54446 m
.21429 .55427 L
.24603 .55427 L
.24603 .54446 L
.21429 .54446 L
s
.21429 .55427 m
.21429 .56408 L
.24603 .56408 L
.24603 .55427 L
.21429 .55427 L
s
.21429 .56408 m
.21429 .57389 L
.24603 .57389 L
.24603 .56408 L
.21429 .56408 L
s
.21429 .57389 m
.21429 .5837 L
.24603 .5837 L
.24603 .57389 L
.21429 .57389 L
s
.21429 .5837 m
.21429 .59351 L
.24603 .59351 L
.24603 .5837 L
.21429 .5837 L
s
.21429 .59351 m
.21429 .60332 L
.24603 .60332 L
.24603 .59351 L
.21429 .59351 L
s
.24603 .01472 m
.24603 .02453 L
.27778 .02453 L
.27778 .01472 L
.24603 .01472 L
s
.24603 .02453 m
.24603 .03434 L
.27778 .03434 L
.27778 .02453 L
.24603 .02453 L
s
.24603 .03434 m
.24603 .04415 L
.27778 .04415 L
.27778 .03434 L
.24603 .03434 L
s
.24603 .04415 m
.24603 .05396 L
.27778 .05396 L
.27778 .04415 L
.24603 .04415 L
s
.24603 .05396 m
.24603 .06377 L
.27778 .06377 L
.27778 .05396 L
.24603 .05396 L
s
.24603 .06377 m
.24603 .07358 L
.27778 .07358 L
.27778 .06377 L
.24603 .06377 L
s
.24603 .07358 m
.24603 .08339 L
.27778 .08339 L
.27778 .07358 L
.24603 .07358 L
s
.24603 .08339 m
.24603 .0932 L
.27778 .0932 L
.27778 .08339 L
.24603 .08339 L
s
.24603 .0932 m
.24603 .10301 L
.27778 .10301 L
.27778 .0932 L
.24603 .0932 L
s
.24603 .10301 m
.24603 .11282 L
.27778 .11282 L
.27778 .10301 L
.24603 .10301 L
s
.24603 .11282 m
.24603 .12263 L
.27778 .12263 L
.27778 .11282 L
.24603 .11282 L
s
.24603 .12263 m
.24603 .13244 L
.27778 .13244 L
.27778 .12263 L
.24603 .12263 L
s
.24603 .13244 m
.24603 .14225 L
.27778 .14225 L
.27778 .13244 L
.24603 .13244 L
s
.24603 .14225 m
.24603 .15206 L
.27778 .15206 L
.27778 .14225 L
.24603 .14225 L
s
.24603 .15206 m
.24603 .16187 L
.27778 .16187 L
.27778 .15206 L
.24603 .15206 L
s
.24603 .16187 m
.24603 .17168 L
.27778 .17168 L
.27778 .16187 L
.24603 .16187 L
s
.24603 .17168 m
.24603 .18149 L
.27778 .18149 L
.27778 .17168 L
.24603 .17168 L
s
.24603 .18149 m
.24603 .1913 L
.27778 .1913 L
.27778 .18149 L
.24603 .18149 L
s
.24603 .1913 m
.24603 .20111 L
.27778 .20111 L
.27778 .1913 L
.24603 .1913 L
s
.24603 .20111 m
.24603 .21092 L
.27778 .21092 L
.27778 .20111 L
.24603 .20111 L
s
.24603 .21092 m
.24603 .22073 L
.27778 .22073 L
.27778 .21092 L
.24603 .21092 L
s
.24603 .22073 m
.24603 .23054 L
.27778 .23054 L
.27778 .22073 L
.24603 .22073 L
s
.24603 .23054 m
.24603 .24035 L
.27778 .24035 L
.27778 .23054 L
.24603 .23054 L
s
.24603 .24035 m
.24603 .25016 L
.27778 .25016 L
.27778 .24035 L
.24603 .24035 L
s
.24603 .25016 m
.24603 .25997 L
.27778 .25997 L
.27778 .25016 L
.24603 .25016 L
s
.24603 .25997 m
.24603 .26978 L
.27778 .26978 L
.27778 .25997 L
.24603 .25997 L
s
.24603 .26978 m
.24603 .27959 L
.27778 .27959 L
.27778 .26978 L
.24603 .26978 L
s
.24603 .27959 m
.24603 .2894 L
.27778 .2894 L
.27778 .27959 L
.24603 .27959 L
s
.24603 .2894 m
.24603 .29921 L
.27778 .29921 L
.27778 .2894 L
.24603 .2894 L
s
.24603 .29921 m
.24603 .30902 L
.27778 .30902 L
.27778 .29921 L
.24603 .29921 L
s
.24603 .30902 m
.24603 .31883 L
.27778 .31883 L
.27778 .30902 L
.24603 .30902 L
s
.24603 .31883 m
.24603 .32864 L
.27778 .32864 L
.27778 .31883 L
.24603 .31883 L
s
.24603 .32864 m
.24603 .33845 L
.27778 .33845 L
.27778 .32864 L
.24603 .32864 L
s
.24603 .33845 m
.24603 .34826 L
.27778 .34826 L
.27778 .33845 L
.24603 .33845 L
s
.24603 .34826 m
.24603 .35807 L
.27778 .35807 L
.27778 .34826 L
.24603 .34826 L
s
.24603 .35807 m
.24603 .36788 L
.27778 .36788 L
.27778 .35807 L
.24603 .35807 L
s
.24603 .36788 m
.24603 .37769 L
.27778 .37769 L
.27778 .36788 L
.24603 .36788 L
s
.24603 .37769 m
.24603 .3875 L
.27778 .3875 L
.27778 .37769 L
.24603 .37769 L
s
.24603 .3875 m
.24603 .39731 L
.27778 .39731 L
.27778 .3875 L
.24603 .3875 L
s
.24603 .39731 m
.24603 .40712 L
.27778 .40712 L
.27778 .39731 L
.24603 .39731 L
s
.24603 .40712 m
.24603 .41693 L
.27778 .41693 L
.27778 .40712 L
.24603 .40712 L
s
.24603 .41693 m
.24603 .42674 L
.27778 .42674 L
.27778 .41693 L
.24603 .41693 L
s
.24603 .42674 m
.24603 .43655 L
.27778 .43655 L
.27778 .42674 L
.24603 .42674 L
s
.24603 .43655 m
.24603 .44636 L
.27778 .44636 L
.27778 .43655 L
.24603 .43655 L
s
.24603 .44636 m
.24603 .45617 L
.27778 .45617 L
.27778 .44636 L
.24603 .44636 L
s
.24603 .45617 m
.24603 .46598 L
.27778 .46598 L
.27778 .45617 L
.24603 .45617 L
s
.24603 .46598 m
.24603 .47579 L
.27778 .47579 L
.27778 .46598 L
.24603 .46598 L
s
.24603 .47579 m
.24603 .4856 L
.27778 .4856 L
.27778 .47579 L
.24603 .47579 L
s
.24603 .4856 m
.24603 .49541 L
.27778 .49541 L
.27778 .4856 L
.24603 .4856 L
s
.24603 .49541 m
.24603 .50522 L
.27778 .50522 L
.27778 .49541 L
.24603 .49541 L
s
.24603 .50522 m
.24603 .51503 L
.27778 .51503 L
.27778 .50522 L
.24603 .50522 L
s
.24603 .51503 m
.24603 .52484 L
.27778 .52484 L
.27778 .51503 L
.24603 .51503 L
s
.24603 .52484 m
.24603 .53465 L
.27778 .53465 L
.27778 .52484 L
.24603 .52484 L
s
.24603 .53465 m
.24603 .54446 L
.27778 .54446 L
.27778 .53465 L
.24603 .53465 L
s
.24603 .54446 m
.24603 .55427 L
.27778 .55427 L
.27778 .54446 L
.24603 .54446 L
s
.24603 .55427 m
.24603 .56408 L
.27778 .56408 L
.27778 .55427 L
.24603 .55427 L
s
.24603 .56408 m
.24603 .57389 L
.27778 .57389 L
.27778 .56408 L
.24603 .56408 L
s
.24603 .57389 m
.24603 .5837 L
.27778 .5837 L
.27778 .57389 L
.24603 .57389 L
s
.24603 .5837 m
.24603 .59351 L
.27778 .59351 L
.27778 .5837 L
.24603 .5837 L
s
.24603 .59351 m
.24603 .60332 L
.27778 .60332 L
.27778 .59351 L
.24603 .59351 L
s
.27778 .01472 m
.27778 .02453 L
.30952 .02453 L
.30952 .01472 L
.27778 .01472 L
s
.27778 .02453 m
.27778 .03434 L
.30952 .03434 L
.30952 .02453 L
.27778 .02453 L
s
.27778 .03434 m
.27778 .04415 L
.30952 .04415 L
.30952 .03434 L
.27778 .03434 L
s
.27778 .04415 m
.27778 .05396 L
.30952 .05396 L
.30952 .04415 L
.27778 .04415 L
s
.27778 .05396 m
.27778 .06377 L
.30952 .06377 L
.30952 .05396 L
.27778 .05396 L
s
.27778 .06377 m
.27778 .07358 L
.30952 .07358 L
.30952 .06377 L
.27778 .06377 L
s
.27778 .07358 m
.27778 .08339 L
.30952 .08339 L
.30952 .07358 L
.27778 .07358 L
s
.27778 .08339 m
.27778 .0932 L
.30952 .0932 L
.30952 .08339 L
.27778 .08339 L
s
.27778 .0932 m
.27778 .10301 L
.30952 .10301 L
.30952 .0932 L
.27778 .0932 L
s
.27778 .10301 m
.27778 .11282 L
.30952 .11282 L
.30952 .10301 L
.27778 .10301 L
s
.27778 .11282 m
.27778 .12263 L
.30952 .12263 L
.30952 .11282 L
.27778 .11282 L
s
.27778 .12263 m
.27778 .13244 L
.30952 .13244 L
.30952 .12263 L
.27778 .12263 L
s
.27778 .13244 m
.27778 .14225 L
.30952 .14225 L
.30952 .13244 L
.27778 .13244 L
s
.27778 .14225 m
.27778 .15206 L
.30952 .15206 L
.30952 .14225 L
.27778 .14225 L
s
.27778 .15206 m
.27778 .16187 L
.30952 .16187 L
.30952 .15206 L
.27778 .15206 L
s
.27778 .16187 m
.27778 .17168 L
.30952 .17168 L
.30952 .16187 L
.27778 .16187 L
s
.27778 .17168 m
.27778 .18149 L
.30952 .18149 L
.30952 .17168 L
.27778 .17168 L
s
.27778 .18149 m
.27778 .1913 L
.30952 .1913 L
.30952 .18149 L
.27778 .18149 L
s
.27778 .1913 m
.27778 .20111 L
.30952 .20111 L
.30952 .1913 L
.27778 .1913 L
s
.27778 .20111 m
.27778 .21092 L
.30952 .21092 L
.30952 .20111 L
.27778 .20111 L
s
.27778 .21092 m
.27778 .22073 L
.30952 .22073 L
.30952 .21092 L
.27778 .21092 L
s
.27778 .22073 m
.27778 .23054 L
.30952 .23054 L
.30952 .22073 L
.27778 .22073 L
s
.27778 .23054 m
.27778 .24035 L
.30952 .24035 L
.30952 .23054 L
.27778 .23054 L
s
.27778 .24035 m
.27778 .25016 L
.30952 .25016 L
.30952 .24035 L
.27778 .24035 L
s
.27778 .25016 m
.27778 .25997 L
.30952 .25997 L
.30952 .25016 L
.27778 .25016 L
s
.27778 .25997 m
.27778 .26978 L
.30952 .26978 L
.30952 .25997 L
.27778 .25997 L
s
.27778 .26978 m
.27778 .27959 L
.30952 .27959 L
.30952 .26978 L
.27778 .26978 L
s
.27778 .27959 m
.27778 .2894 L
.30952 .2894 L
.30952 .27959 L
.27778 .27959 L
s
.27778 .2894 m
.27778 .29921 L
.30952 .29921 L
.30952 .2894 L
.27778 .2894 L
s
.27778 .29921 m
.27778 .30902 L
.30952 .30902 L
.30952 .29921 L
.27778 .29921 L
s
.27778 .30902 m
.27778 .31883 L
.30952 .31883 L
.30952 .30902 L
.27778 .30902 L
s
.27778 .31883 m
.27778 .32864 L
.30952 .32864 L
.30952 .31883 L
.27778 .31883 L
s
.27778 .32864 m
.27778 .33845 L
.30952 .33845 L
.30952 .32864 L
.27778 .32864 L
s
.27778 .33845 m
.27778 .34826 L
.30952 .34826 L
.30952 .33845 L
.27778 .33845 L
s
.27778 .34826 m
.27778 .35807 L
.30952 .35807 L
.30952 .34826 L
.27778 .34826 L
s
.27778 .35807 m
.27778 .36788 L
.30952 .36788 L
.30952 .35807 L
.27778 .35807 L
s
.27778 .36788 m
.27778 .37769 L
.30952 .37769 L
.30952 .36788 L
.27778 .36788 L
s
.27778 .37769 m
.27778 .3875 L
.30952 .3875 L
.30952 .37769 L
.27778 .37769 L
s
.27778 .3875 m
.27778 .39731 L
.30952 .39731 L
.30952 .3875 L
.27778 .3875 L
s
.27778 .39731 m
.27778 .40712 L
.30952 .40712 L
.30952 .39731 L
.27778 .39731 L
s
.27778 .40712 m
.27778 .41693 L
.30952 .41693 L
.30952 .40712 L
.27778 .40712 L
s
.27778 .41693 m
.27778 .42674 L
.30952 .42674 L
.30952 .41693 L
.27778 .41693 L
s
.27778 .42674 m
.27778 .43655 L
.30952 .43655 L
.30952 .42674 L
.27778 .42674 L
s
.27778 .43655 m
.27778 .44636 L
.30952 .44636 L
.30952 .43655 L
.27778 .43655 L
s
.27778 .44636 m
.27778 .45617 L
.30952 .45617 L
.30952 .44636 L
.27778 .44636 L
s
.27778 .45617 m
.27778 .46598 L
.30952 .46598 L
.30952 .45617 L
.27778 .45617 L
s
.27778 .46598 m
.27778 .47579 L
.30952 .47579 L
.30952 .46598 L
.27778 .46598 L
s
.27778 .47579 m
.27778 .4856 L
.30952 .4856 L
.30952 .47579 L
.27778 .47579 L
s
.27778 .4856 m
.27778 .49541 L
.30952 .49541 L
.30952 .4856 L
.27778 .4856 L
s
.27778 .49541 m
.27778 .50522 L
.30952 .50522 L
.30952 .49541 L
.27778 .49541 L
s
.27778 .50522 m
.27778 .51503 L
.30952 .51503 L
.30952 .50522 L
.27778 .50522 L
s
.27778 .51503 m
.27778 .52484 L
.30952 .52484 L
.30952 .51503 L
.27778 .51503 L
s
.27778 .52484 m
.27778 .53465 L
.30952 .53465 L
.30952 .52484 L
.27778 .52484 L
s
.27778 .53465 m
.27778 .54446 L
.30952 .54446 L
.30952 .53465 L
.27778 .53465 L
s
.27778 .54446 m
.27778 .55427 L
.30952 .55427 L
.30952 .54446 L
.27778 .54446 L
s
.27778 .55427 m
.27778 .56408 L
.30952 .56408 L
.30952 .55427 L
.27778 .55427 L
s
.27778 .56408 m
.27778 .57389 L
.30952 .57389 L
.30952 .56408 L
.27778 .56408 L
s
.27778 .57389 m
.27778 .5837 L
.30952 .5837 L
.30952 .57389 L
.27778 .57389 L
s
.27778 .5837 m
.27778 .59351 L
.30952 .59351 L
.30952 .5837 L
.27778 .5837 L
s
.27778 .59351 m
.27778 .60332 L
.30952 .60332 L
.30952 .59351 L
.27778 .59351 L
s
.30952 .01472 m
.30952 .02453 L
.34127 .02453 L
.34127 .01472 L
.30952 .01472 L
s
.30952 .02453 m
.30952 .03434 L
.34127 .03434 L
.34127 .02453 L
.30952 .02453 L
s
.30952 .03434 m
.30952 .04415 L
.34127 .04415 L
.34127 .03434 L
.30952 .03434 L
s
.30952 .04415 m
.30952 .05396 L
.34127 .05396 L
.34127 .04415 L
.30952 .04415 L
s
.30952 .05396 m
.30952 .06377 L
.34127 .06377 L
.34127 .05396 L
.30952 .05396 L
s
.30952 .06377 m
.30952 .07358 L
.34127 .07358 L
.34127 .06377 L
.30952 .06377 L
s
.30952 .07358 m
.30952 .08339 L
.34127 .08339 L
.34127 .07358 L
.30952 .07358 L
s
.30952 .08339 m
.30952 .0932 L
.34127 .0932 L
.34127 .08339 L
.30952 .08339 L
s
.30952 .0932 m
.30952 .10301 L
.34127 .10301 L
.34127 .0932 L
.30952 .0932 L
s
.30952 .10301 m
.30952 .11282 L
.34127 .11282 L
.34127 .10301 L
.30952 .10301 L
s
.30952 .11282 m
.30952 .12263 L
.34127 .12263 L
.34127 .11282 L
.30952 .11282 L
s
.30952 .12263 m
.30952 .13244 L
.34127 .13244 L
.34127 .12263 L
.30952 .12263 L
s
.30952 .13244 m
.30952 .14225 L
.34127 .14225 L
.34127 .13244 L
.30952 .13244 L
s
.30952 .14225 m
.30952 .15206 L
.34127 .15206 L
.34127 .14225 L
.30952 .14225 L
s
.30952 .15206 m
.30952 .16187 L
.34127 .16187 L
.34127 .15206 L
.30952 .15206 L
s
.30952 .16187 m
.30952 .17168 L
.34127 .17168 L
.34127 .16187 L
.30952 .16187 L
s
.30952 .17168 m
.30952 .18149 L
.34127 .18149 L
.34127 .17168 L
.30952 .17168 L
s
.30952 .18149 m
.30952 .1913 L
.34127 .1913 L
.34127 .18149 L
.30952 .18149 L
s
.30952 .1913 m
.30952 .20111 L
.34127 .20111 L
.34127 .1913 L
.30952 .1913 L
s
.30952 .20111 m
.30952 .21092 L
.34127 .21092 L
.34127 .20111 L
.30952 .20111 L
s
.30952 .21092 m
.30952 .22073 L
.34127 .22073 L
.34127 .21092 L
.30952 .21092 L
s
.30952 .22073 m
.30952 .23054 L
.34127 .23054 L
.34127 .22073 L
.30952 .22073 L
s
.30952 .23054 m
.30952 .24035 L
.34127 .24035 L
.34127 .23054 L
.30952 .23054 L
s
.30952 .24035 m
.30952 .25016 L
.34127 .25016 L
.34127 .24035 L
.30952 .24035 L
s
.30952 .25016 m
.30952 .25997 L
.34127 .25997 L
.34127 .25016 L
.30952 .25016 L
s
.30952 .25997 m
.30952 .26978 L
.34127 .26978 L
.34127 .25997 L
.30952 .25997 L
s
.30952 .26978 m
.30952 .27959 L
.34127 .27959 L
.34127 .26978 L
.30952 .26978 L
s
.30952 .27959 m
.30952 .2894 L
.34127 .2894 L
.34127 .27959 L
.30952 .27959 L
s
.30952 .2894 m
.30952 .29921 L
.34127 .29921 L
.34127 .2894 L
.30952 .2894 L
s
.30952 .29921 m
.30952 .30902 L
.34127 .30902 L
.34127 .29921 L
.30952 .29921 L
s
.30952 .30902 m
.30952 .31883 L
.34127 .31883 L
.34127 .30902 L
.30952 .30902 L
s
.30952 .31883 m
.30952 .32864 L
.34127 .32864 L
.34127 .31883 L
.30952 .31883 L
s
.30952 .32864 m
.30952 .33845 L
.34127 .33845 L
.34127 .32864 L
.30952 .32864 L
s
.30952 .33845 m
.30952 .34826 L
.34127 .34826 L
.34127 .33845 L
.30952 .33845 L
s
.30952 .34826 m
.30952 .35807 L
.34127 .35807 L
.34127 .34826 L
.30952 .34826 L
s
.30952 .35807 m
.30952 .36788 L
.34127 .36788 L
.34127 .35807 L
.30952 .35807 L
s
.30952 .36788 m
.30952 .37769 L
.34127 .37769 L
.34127 .36788 L
.30952 .36788 L
s
.30952 .37769 m
.30952 .3875 L
.34127 .3875 L
.34127 .37769 L
.30952 .37769 L
s
.30952 .3875 m
.30952 .39731 L
.34127 .39731 L
.34127 .3875 L
.30952 .3875 L
s
.30952 .39731 m
.30952 .40712 L
.34127 .40712 L
.34127 .39731 L
.30952 .39731 L
s
.30952 .40712 m
.30952 .41693 L
.34127 .41693 L
.34127 .40712 L
.30952 .40712 L
s
.30952 .41693 m
.30952 .42674 L
.34127 .42674 L
.34127 .41693 L
.30952 .41693 L
s
.30952 .42674 m
.30952 .43655 L
.34127 .43655 L
.34127 .42674 L
.30952 .42674 L
s
.30952 .43655 m
.30952 .44636 L
.34127 .44636 L
.34127 .43655 L
.30952 .43655 L
s
.30952 .44636 m
.30952 .45617 L
.34127 .45617 L
.34127 .44636 L
.30952 .44636 L
s
.30952 .45617 m
.30952 .46598 L
.34127 .46598 L
.34127 .45617 L
.30952 .45617 L
s
.30952 .46598 m
.30952 .47579 L
.34127 .47579 L
.34127 .46598 L
.30952 .46598 L
s
.30952 .47579 m
.30952 .4856 L
.34127 .4856 L
.34127 .47579 L
.30952 .47579 L
s
.30952 .4856 m
.30952 .49541 L
.34127 .49541 L
.34127 .4856 L
.30952 .4856 L
s
.30952 .49541 m
.30952 .50522 L
.34127 .50522 L
.34127 .49541 L
.30952 .49541 L
s
.30952 .50522 m
.30952 .51503 L
.34127 .51503 L
.34127 .50522 L
.30952 .50522 L
s
.30952 .51503 m
.30952 .52484 L
.34127 .52484 L
.34127 .51503 L
.30952 .51503 L
s
.30952 .52484 m
.30952 .53465 L
.34127 .53465 L
.34127 .52484 L
.30952 .52484 L
s
.30952 .53465 m
.30952 .54446 L
.34127 .54446 L
.34127 .53465 L
.30952 .53465 L
s
.30952 .54446 m
.30952 .55427 L
.34127 .55427 L
.34127 .54446 L
.30952 .54446 L
s
.30952 .55427 m
.30952 .56408 L
.34127 .56408 L
.34127 .55427 L
.30952 .55427 L
s
.30952 .56408 m
.30952 .57389 L
.34127 .57389 L
.34127 .56408 L
.30952 .56408 L
s
.30952 .57389 m
.30952 .5837 L
.34127 .5837 L
.34127 .57389 L
.30952 .57389 L
s
.30952 .5837 m
.30952 .59351 L
.34127 .59351 L
.34127 .5837 L
.30952 .5837 L
s
.30952 .59351 m
.30952 .60332 L
.34127 .60332 L
.34127 .59351 L
.30952 .59351 L
s
.34127 .01472 m
.34127 .02453 L
.37302 .02453 L
.37302 .01472 L
.34127 .01472 L
s
.34127 .02453 m
.34127 .03434 L
.37302 .03434 L
.37302 .02453 L
.34127 .02453 L
s
.34127 .03434 m
.34127 .04415 L
.37302 .04415 L
.37302 .03434 L
.34127 .03434 L
s
.34127 .04415 m
.34127 .05396 L
.37302 .05396 L
.37302 .04415 L
.34127 .04415 L
s
.34127 .05396 m
.34127 .06377 L
.37302 .06377 L
.37302 .05396 L
.34127 .05396 L
s
.34127 .06377 m
.34127 .07358 L
.37302 .07358 L
.37302 .06377 L
.34127 .06377 L
s
.34127 .07358 m
.34127 .08339 L
.37302 .08339 L
.37302 .07358 L
.34127 .07358 L
s
.34127 .08339 m
.34127 .0932 L
.37302 .0932 L
.37302 .08339 L
.34127 .08339 L
s
.34127 .0932 m
.34127 .10301 L
.37302 .10301 L
.37302 .0932 L
.34127 .0932 L
s
.34127 .10301 m
.34127 .11282 L
.37302 .11282 L
.37302 .10301 L
.34127 .10301 L
s
.34127 .11282 m
.34127 .12263 L
.37302 .12263 L
.37302 .11282 L
.34127 .11282 L
s
.34127 .12263 m
.34127 .13244 L
.37302 .13244 L
.37302 .12263 L
.34127 .12263 L
s
.34127 .13244 m
.34127 .14225 L
.37302 .14225 L
.37302 .13244 L
.34127 .13244 L
s
.34127 .14225 m
.34127 .15206 L
.37302 .15206 L
.37302 .14225 L
.34127 .14225 L
s
.34127 .15206 m
.34127 .16187 L
.37302 .16187 L
.37302 .15206 L
.34127 .15206 L
s
.34127 .16187 m
.34127 .17168 L
.37302 .17168 L
.37302 .16187 L
.34127 .16187 L
s
.34127 .17168 m
.34127 .18149 L
.37302 .18149 L
.37302 .17168 L
.34127 .17168 L
s
.34127 .18149 m
.34127 .1913 L
.37302 .1913 L
.37302 .18149 L
.34127 .18149 L
s
.34127 .1913 m
.34127 .20111 L
.37302 .20111 L
.37302 .1913 L
.34127 .1913 L
s
.34127 .20111 m
.34127 .21092 L
.37302 .21092 L
.37302 .20111 L
.34127 .20111 L
s
.34127 .21092 m
.34127 .22073 L
.37302 .22073 L
.37302 .21092 L
.34127 .21092 L
s
.34127 .22073 m
.34127 .23054 L
.37302 .23054 L
.37302 .22073 L
.34127 .22073 L
s
.34127 .23054 m
.34127 .24035 L
.37302 .24035 L
.37302 .23054 L
.34127 .23054 L
s
.34127 .24035 m
.34127 .25016 L
.37302 .25016 L
.37302 .24035 L
.34127 .24035 L
s
.34127 .25016 m
.34127 .25997 L
.37302 .25997 L
.37302 .25016 L
.34127 .25016 L
s
.34127 .25997 m
.34127 .26978 L
.37302 .26978 L
.37302 .25997 L
.34127 .25997 L
s
.34127 .26978 m
.34127 .27959 L
.37302 .27959 L
.37302 .26978 L
.34127 .26978 L
s
.34127 .27959 m
.34127 .2894 L
.37302 .2894 L
.37302 .27959 L
.34127 .27959 L
s
.34127 .2894 m
.34127 .29921 L
.37302 .29921 L
.37302 .2894 L
.34127 .2894 L
s
.34127 .29921 m
.34127 .30902 L
.37302 .30902 L
.37302 .29921 L
.34127 .29921 L
s
.34127 .30902 m
.34127 .31883 L
.37302 .31883 L
.37302 .30902 L
.34127 .30902 L
s
.34127 .31883 m
.34127 .32864 L
.37302 .32864 L
.37302 .31883 L
.34127 .31883 L
s
.34127 .32864 m
.34127 .33845 L
.37302 .33845 L
.37302 .32864 L
.34127 .32864 L
s
.34127 .33845 m
.34127 .34826 L
.37302 .34826 L
.37302 .33845 L
.34127 .33845 L
s
.34127 .34826 m
.34127 .35807 L
.37302 .35807 L
.37302 .34826 L
.34127 .34826 L
s
.34127 .35807 m
.34127 .36788 L
.37302 .36788 L
.37302 .35807 L
.34127 .35807 L
s
.34127 .36788 m
.34127 .37769 L
.37302 .37769 L
.37302 .36788 L
.34127 .36788 L
s
.34127 .37769 m
.34127 .3875 L
.37302 .3875 L
.37302 .37769 L
.34127 .37769 L
s
.34127 .3875 m
.34127 .39731 L
.37302 .39731 L
.37302 .3875 L
.34127 .3875 L
s
.34127 .39731 m
.34127 .40712 L
.37302 .40712 L
.37302 .39731 L
.34127 .39731 L
s
.34127 .40712 m
.34127 .41693 L
.37302 .41693 L
.37302 .40712 L
.34127 .40712 L
s
.34127 .41693 m
.34127 .42674 L
.37302 .42674 L
.37302 .41693 L
.34127 .41693 L
s
.34127 .42674 m
.34127 .43655 L
.37302 .43655 L
.37302 .42674 L
.34127 .42674 L
s
.34127 .43655 m
.34127 .44636 L
.37302 .44636 L
.37302 .43655 L
.34127 .43655 L
s
.34127 .44636 m
.34127 .45617 L
.37302 .45617 L
.37302 .44636 L
.34127 .44636 L
s
.34127 .45617 m
.34127 .46598 L
.37302 .46598 L
.37302 .45617 L
.34127 .45617 L
s
.34127 .46598 m
.34127 .47579 L
.37302 .47579 L
.37302 .46598 L
.34127 .46598 L
s
.34127 .47579 m
.34127 .4856 L
.37302 .4856 L
.37302 .47579 L
.34127 .47579 L
s
.34127 .4856 m
.34127 .49541 L
.37302 .49541 L
.37302 .4856 L
.34127 .4856 L
s
.34127 .49541 m
.34127 .50522 L
.37302 .50522 L
.37302 .49541 L
.34127 .49541 L
s
.34127 .50522 m
.34127 .51503 L
.37302 .51503 L
.37302 .50522 L
.34127 .50522 L
s
.34127 .51503 m
.34127 .52484 L
.37302 .52484 L
.37302 .51503 L
.34127 .51503 L
s
.34127 .52484 m
.34127 .53465 L
.37302 .53465 L
.37302 .52484 L
.34127 .52484 L
s
.34127 .53465 m
.34127 .54446 L
.37302 .54446 L
.37302 .53465 L
.34127 .53465 L
s
.34127 .54446 m
.34127 .55427 L
.37302 .55427 L
.37302 .54446 L
.34127 .54446 L
s
.34127 .55427 m
.34127 .56408 L
.37302 .56408 L
.37302 .55427 L
.34127 .55427 L
s
.34127 .56408 m
.34127 .57389 L
.37302 .57389 L
.37302 .56408 L
.34127 .56408 L
s
.34127 .57389 m
.34127 .5837 L
.37302 .5837 L
.37302 .57389 L
.34127 .57389 L
s
.34127 .5837 m
.34127 .59351 L
.37302 .59351 L
.37302 .5837 L
.34127 .5837 L
s
.34127 .59351 m
.34127 .60332 L
.37302 .60332 L
.37302 .59351 L
.34127 .59351 L
s
.37302 .01472 m
.37302 .02453 L
.40476 .02453 L
.40476 .01472 L
.37302 .01472 L
s
.37302 .02453 m
.37302 .03434 L
.40476 .03434 L
.40476 .02453 L
.37302 .02453 L
s
.37302 .03434 m
.37302 .04415 L
.40476 .04415 L
.40476 .03434 L
.37302 .03434 L
s
.37302 .04415 m
.37302 .05396 L
.40476 .05396 L
.40476 .04415 L
.37302 .04415 L
s
.37302 .05396 m
.37302 .06377 L
.40476 .06377 L
.40476 .05396 L
.37302 .05396 L
s
.37302 .06377 m
.37302 .07358 L
.40476 .07358 L
.40476 .06377 L
.37302 .06377 L
s
.37302 .07358 m
.37302 .08339 L
.40476 .08339 L
.40476 .07358 L
.37302 .07358 L
s
.37302 .08339 m
.37302 .0932 L
.40476 .0932 L
.40476 .08339 L
.37302 .08339 L
s
.37302 .0932 m
.37302 .10301 L
.40476 .10301 L
.40476 .0932 L
.37302 .0932 L
s
.37302 .10301 m
.37302 .11282 L
.40476 .11282 L
.40476 .10301 L
.37302 .10301 L
s
.37302 .11282 m
.37302 .12263 L
.40476 .12263 L
.40476 .11282 L
.37302 .11282 L
s
.37302 .12263 m
.37302 .13244 L
.40476 .13244 L
.40476 .12263 L
.37302 .12263 L
s
.37302 .13244 m
.37302 .14225 L
.40476 .14225 L
.40476 .13244 L
.37302 .13244 L
s
.37302 .14225 m
.37302 .15206 L
.40476 .15206 L
.40476 .14225 L
.37302 .14225 L
s
.37302 .15206 m
.37302 .16187 L
.40476 .16187 L
.40476 .15206 L
.37302 .15206 L
s
.37302 .16187 m
.37302 .17168 L
.40476 .17168 L
.40476 .16187 L
.37302 .16187 L
s
.37302 .17168 m
.37302 .18149 L
.40476 .18149 L
.40476 .17168 L
.37302 .17168 L
s
.37302 .18149 m
.37302 .1913 L
.40476 .1913 L
.40476 .18149 L
.37302 .18149 L
s
.37302 .1913 m
.37302 .20111 L
.40476 .20111 L
.40476 .1913 L
.37302 .1913 L
s
.37302 .20111 m
.37302 .21092 L
.40476 .21092 L
.40476 .20111 L
.37302 .20111 L
s
.37302 .21092 m
.37302 .22073 L
.40476 .22073 L
.40476 .21092 L
.37302 .21092 L
s
.37302 .22073 m
.37302 .23054 L
.40476 .23054 L
.40476 .22073 L
.37302 .22073 L
s
.37302 .23054 m
.37302 .24035 L
.40476 .24035 L
.40476 .23054 L
.37302 .23054 L
s
.37302 .24035 m
.37302 .25016 L
.40476 .25016 L
.40476 .24035 L
.37302 .24035 L
s
.37302 .25016 m
.37302 .25997 L
.40476 .25997 L
.40476 .25016 L
.37302 .25016 L
s
.37302 .25997 m
.37302 .26978 L
.40476 .26978 L
.40476 .25997 L
.37302 .25997 L
s
.37302 .26978 m
.37302 .27959 L
.40476 .27959 L
.40476 .26978 L
.37302 .26978 L
s
.37302 .27959 m
.37302 .2894 L
.40476 .2894 L
.40476 .27959 L
.37302 .27959 L
s
.37302 .2894 m
.37302 .29921 L
.40476 .29921 L
.40476 .2894 L
.37302 .2894 L
s
.37302 .29921 m
.37302 .30902 L
.40476 .30902 L
.40476 .29921 L
.37302 .29921 L
s
.37302 .30902 m
.37302 .31883 L
.40476 .31883 L
.40476 .30902 L
.37302 .30902 L
s
.37302 .31883 m
.37302 .32864 L
.40476 .32864 L
.40476 .31883 L
.37302 .31883 L
s
.37302 .32864 m
.37302 .33845 L
.40476 .33845 L
.40476 .32864 L
.37302 .32864 L
s
.37302 .33845 m
.37302 .34826 L
.40476 .34826 L
.40476 .33845 L
.37302 .33845 L
s
.37302 .34826 m
.37302 .35807 L
.40476 .35807 L
.40476 .34826 L
.37302 .34826 L
s
.37302 .35807 m
.37302 .36788 L
.40476 .36788 L
.40476 .35807 L
.37302 .35807 L
s
.37302 .36788 m
.37302 .37769 L
.40476 .37769 L
.40476 .36788 L
.37302 .36788 L
s
.37302 .37769 m
.37302 .3875 L
.40476 .3875 L
.40476 .37769 L
.37302 .37769 L
s
.37302 .3875 m
.37302 .39731 L
.40476 .39731 L
.40476 .3875 L
.37302 .3875 L
s
.37302 .39731 m
.37302 .40712 L
.40476 .40712 L
.40476 .39731 L
.37302 .39731 L
s
.37302 .40712 m
.37302 .41693 L
.40476 .41693 L
.40476 .40712 L
.37302 .40712 L
s
.37302 .41693 m
.37302 .42674 L
.40476 .42674 L
.40476 .41693 L
.37302 .41693 L
s
.37302 .42674 m
.37302 .43655 L
.40476 .43655 L
.40476 .42674 L
.37302 .42674 L
s
.37302 .43655 m
.37302 .44636 L
.40476 .44636 L
.40476 .43655 L
.37302 .43655 L
s
.37302 .44636 m
.37302 .45617 L
.40476 .45617 L
.40476 .44636 L
.37302 .44636 L
s
.37302 .45617 m
.37302 .46598 L
.40476 .46598 L
.40476 .45617 L
.37302 .45617 L
s
.37302 .46598 m
.37302 .47579 L
.40476 .47579 L
.40476 .46598 L
.37302 .46598 L
s
.37302 .47579 m
.37302 .4856 L
.40476 .4856 L
.40476 .47579 L
.37302 .47579 L
s
.37302 .4856 m
.37302 .49541 L
.40476 .49541 L
.40476 .4856 L
.37302 .4856 L
s
.37302 .49541 m
.37302 .50522 L
.40476 .50522 L
.40476 .49541 L
.37302 .49541 L
s
.37302 .50522 m
.37302 .51503 L
.40476 .51503 L
.40476 .50522 L
.37302 .50522 L
s
.37302 .51503 m
.37302 .52484 L
.40476 .52484 L
.40476 .51503 L
.37302 .51503 L
s
.37302 .52484 m
.37302 .53465 L
.40476 .53465 L
.40476 .52484 L
.37302 .52484 L
s
.37302 .53465 m
.37302 .54446 L
.40476 .54446 L
.40476 .53465 L
.37302 .53465 L
s
.37302 .54446 m
.37302 .55427 L
.40476 .55427 L
.40476 .54446 L
.37302 .54446 L
s
.37302 .55427 m
.37302 .56408 L
.40476 .56408 L
.40476 .55427 L
.37302 .55427 L
s
.37302 .56408 m
.37302 .57389 L
.40476 .57389 L
.40476 .56408 L
.37302 .56408 L
s
.37302 .57389 m
.37302 .5837 L
.40476 .5837 L
.40476 .57389 L
.37302 .57389 L
s
.37302 .5837 m
.37302 .59351 L
.40476 .59351 L
.40476 .5837 L
.37302 .5837 L
s
.37302 .59351 m
.37302 .60332 L
.40476 .60332 L
.40476 .59351 L
.37302 .59351 L
s
.40476 .01472 m
.40476 .02453 L
.43651 .02453 L
.43651 .01472 L
.40476 .01472 L
s
.40476 .02453 m
.40476 .03434 L
.43651 .03434 L
.43651 .02453 L
.40476 .02453 L
s
.40476 .03434 m
.40476 .04415 L
.43651 .04415 L
.43651 .03434 L
.40476 .03434 L
s
.40476 .04415 m
.40476 .05396 L
.43651 .05396 L
.43651 .04415 L
.40476 .04415 L
s
.40476 .05396 m
.40476 .06377 L
.43651 .06377 L
.43651 .05396 L
.40476 .05396 L
s
.40476 .06377 m
.40476 .07358 L
.43651 .07358 L
.43651 .06377 L
.40476 .06377 L
s
.40476 .07358 m
.40476 .08339 L
.43651 .08339 L
.43651 .07358 L
.40476 .07358 L
s
.40476 .08339 m
.40476 .0932 L
.43651 .0932 L
.43651 .08339 L
.40476 .08339 L
s
.40476 .0932 m
.40476 .10301 L
.43651 .10301 L
.43651 .0932 L
.40476 .0932 L
s
.40476 .10301 m
.40476 .11282 L
.43651 .11282 L
.43651 .10301 L
.40476 .10301 L
s
.40476 .11282 m
.40476 .12263 L
.43651 .12263 L
.43651 .11282 L
.40476 .11282 L
s
.40476 .12263 m
.40476 .13244 L
.43651 .13244 L
.43651 .12263 L
.40476 .12263 L
s
.40476 .13244 m
.40476 .14225 L
.43651 .14225 L
.43651 .13244 L
.40476 .13244 L
s
.40476 .14225 m
.40476 .15206 L
.43651 .15206 L
.43651 .14225 L
.40476 .14225 L
s
.40476 .15206 m
.40476 .16187 L
.43651 .16187 L
.43651 .15206 L
.40476 .15206 L
s
.40476 .16187 m
.40476 .17168 L
.43651 .17168 L
.43651 .16187 L
.40476 .16187 L
s
.40476 .17168 m
.40476 .18149 L
.43651 .18149 L
.43651 .17168 L
.40476 .17168 L
s
.40476 .18149 m
.40476 .1913 L
.43651 .1913 L
.43651 .18149 L
.40476 .18149 L
s
.40476 .1913 m
.40476 .20111 L
.43651 .20111 L
.43651 .1913 L
.40476 .1913 L
s
.40476 .20111 m
.40476 .21092 L
.43651 .21092 L
.43651 .20111 L
.40476 .20111 L
s
.40476 .21092 m
.40476 .22073 L
.43651 .22073 L
.43651 .21092 L
.40476 .21092 L
s
.40476 .22073 m
.40476 .23054 L
.43651 .23054 L
.43651 .22073 L
.40476 .22073 L
s
.40476 .23054 m
.40476 .24035 L
.43651 .24035 L
.43651 .23054 L
.40476 .23054 L
s
.40476 .24035 m
.40476 .25016 L
.43651 .25016 L
.43651 .24035 L
.40476 .24035 L
s
.40476 .25016 m
.40476 .25997 L
.43651 .25997 L
.43651 .25016 L
.40476 .25016 L
s
.40476 .25997 m
.40476 .26978 L
.43651 .26978 L
.43651 .25997 L
.40476 .25997 L
s
.40476 .26978 m
.40476 .27959 L
.43651 .27959 L
.43651 .26978 L
.40476 .26978 L
s
.40476 .27959 m
.40476 .2894 L
.43651 .2894 L
.43651 .27959 L
.40476 .27959 L
s
.40476 .2894 m
.40476 .29921 L
.43651 .29921 L
.43651 .2894 L
.40476 .2894 L
s
.40476 .29921 m
.40476 .30902 L
.43651 .30902 L
.43651 .29921 L
.40476 .29921 L
s
.40476 .30902 m
.40476 .31883 L
.43651 .31883 L
.43651 .30902 L
.40476 .30902 L
s
.40476 .31883 m
.40476 .32864 L
.43651 .32864 L
.43651 .31883 L
.40476 .31883 L
s
.40476 .32864 m
.40476 .33845 L
.43651 .33845 L
.43651 .32864 L
.40476 .32864 L
s
.40476 .33845 m
.40476 .34826 L
.43651 .34826 L
.43651 .33845 L
.40476 .33845 L
s
.40476 .34826 m
.40476 .35807 L
.43651 .35807 L
.43651 .34826 L
.40476 .34826 L
s
.40476 .35807 m
.40476 .36788 L
.43651 .36788 L
.43651 .35807 L
.40476 .35807 L
s
.40476 .36788 m
.40476 .37769 L
.43651 .37769 L
.43651 .36788 L
.40476 .36788 L
s
.40476 .37769 m
.40476 .3875 L
.43651 .3875 L
.43651 .37769 L
.40476 .37769 L
s
.40476 .3875 m
.40476 .39731 L
.43651 .39731 L
.43651 .3875 L
.40476 .3875 L
s
.40476 .39731 m
.40476 .40712 L
.43651 .40712 L
.43651 .39731 L
.40476 .39731 L
s
.40476 .40712 m
.40476 .41693 L
.43651 .41693 L
.43651 .40712 L
.40476 .40712 L
s
.40476 .41693 m
.40476 .42674 L
.43651 .42674 L
.43651 .41693 L
.40476 .41693 L
s
.40476 .42674 m
.40476 .43655 L
.43651 .43655 L
.43651 .42674 L
.40476 .42674 L
s
.40476 .43655 m
.40476 .44636 L
.43651 .44636 L
.43651 .43655 L
.40476 .43655 L
s
.40476 .44636 m
.40476 .45617 L
.43651 .45617 L
.43651 .44636 L
.40476 .44636 L
s
.40476 .45617 m
.40476 .46598 L
.43651 .46598 L
.43651 .45617 L
.40476 .45617 L
s
.40476 .46598 m
.40476 .47579 L
.43651 .47579 L
.43651 .46598 L
.40476 .46598 L
s
.40476 .47579 m
.40476 .4856 L
.43651 .4856 L
.43651 .47579 L
.40476 .47579 L
s
.40476 .4856 m
.40476 .49541 L
.43651 .49541 L
.43651 .4856 L
.40476 .4856 L
s
.40476 .49541 m
.40476 .50522 L
.43651 .50522 L
.43651 .49541 L
.40476 .49541 L
s
.40476 .50522 m
.40476 .51503 L
.43651 .51503 L
.43651 .50522 L
.40476 .50522 L
s
.40476 .51503 m
.40476 .52484 L
.43651 .52484 L
.43651 .51503 L
.40476 .51503 L
s
.40476 .52484 m
.40476 .53465 L
.43651 .53465 L
.43651 .52484 L
.40476 .52484 L
s
.40476 .53465 m
.40476 .54446 L
.43651 .54446 L
.43651 .53465 L
.40476 .53465 L
s
.40476 .54446 m
.40476 .55427 L
.43651 .55427 L
.43651 .54446 L
.40476 .54446 L
s
.40476 .55427 m
.40476 .56408 L
.43651 .56408 L
.43651 .55427 L
.40476 .55427 L
s
.40476 .56408 m
.40476 .57389 L
.43651 .57389 L
.43651 .56408 L
.40476 .56408 L
s
.40476 .57389 m
.40476 .5837 L
.43651 .5837 L
.43651 .57389 L
.40476 .57389 L
s
.40476 .5837 m
.40476 .59351 L
.43651 .59351 L
.43651 .5837 L
.40476 .5837 L
s
.40476 .59351 m
.40476 .60332 L
.43651 .60332 L
.43651 .59351 L
.40476 .59351 L
s
.43651 .01472 m
.43651 .02453 L
.46825 .02453 L
.46825 .01472 L
.43651 .01472 L
s
.43651 .02453 m
.43651 .03434 L
.46825 .03434 L
.46825 .02453 L
.43651 .02453 L
s
.43651 .03434 m
.43651 .04415 L
.46825 .04415 L
.46825 .03434 L
.43651 .03434 L
s
.43651 .04415 m
.43651 .05396 L
.46825 .05396 L
.46825 .04415 L
.43651 .04415 L
s
.43651 .05396 m
.43651 .06377 L
.46825 .06377 L
.46825 .05396 L
.43651 .05396 L
s
.43651 .06377 m
.43651 .07358 L
.46825 .07358 L
.46825 .06377 L
.43651 .06377 L
s
.43651 .07358 m
.43651 .08339 L
.46825 .08339 L
.46825 .07358 L
.43651 .07358 L
s
.43651 .08339 m
.43651 .0932 L
.46825 .0932 L
.46825 .08339 L
.43651 .08339 L
s
.43651 .0932 m
.43651 .10301 L
.46825 .10301 L
.46825 .0932 L
.43651 .0932 L
s
.43651 .10301 m
.43651 .11282 L
.46825 .11282 L
.46825 .10301 L
.43651 .10301 L
s
.43651 .11282 m
.43651 .12263 L
.46825 .12263 L
.46825 .11282 L
.43651 .11282 L
s
.43651 .12263 m
.43651 .13244 L
.46825 .13244 L
.46825 .12263 L
.43651 .12263 L
s
.43651 .13244 m
.43651 .14225 L
.46825 .14225 L
.46825 .13244 L
.43651 .13244 L
s
.43651 .14225 m
.43651 .15206 L
.46825 .15206 L
.46825 .14225 L
.43651 .14225 L
s
.43651 .15206 m
.43651 .16187 L
.46825 .16187 L
.46825 .15206 L
.43651 .15206 L
s
.43651 .16187 m
.43651 .17168 L
.46825 .17168 L
.46825 .16187 L
.43651 .16187 L
s
.43651 .17168 m
.43651 .18149 L
.46825 .18149 L
.46825 .17168 L
.43651 .17168 L
s
.43651 .18149 m
.43651 .1913 L
.46825 .1913 L
.46825 .18149 L
.43651 .18149 L
s
.43651 .1913 m
.43651 .20111 L
.46825 .20111 L
.46825 .1913 L
.43651 .1913 L
s
.43651 .20111 m
.43651 .21092 L
.46825 .21092 L
.46825 .20111 L
.43651 .20111 L
s
.43651 .21092 m
.43651 .22073 L
.46825 .22073 L
.46825 .21092 L
.43651 .21092 L
s
.43651 .22073 m
.43651 .23054 L
.46825 .23054 L
.46825 .22073 L
.43651 .22073 L
s
.43651 .23054 m
.43651 .24035 L
.46825 .24035 L
.46825 .23054 L
.43651 .23054 L
s
.43651 .24035 m
.43651 .25016 L
.46825 .25016 L
.46825 .24035 L
.43651 .24035 L
s
.43651 .25016 m
.43651 .25997 L
.46825 .25997 L
.46825 .25016 L
.43651 .25016 L
s
.43651 .25997 m
.43651 .26978 L
.46825 .26978 L
.46825 .25997 L
.43651 .25997 L
s
.43651 .26978 m
.43651 .27959 L
.46825 .27959 L
.46825 .26978 L
.43651 .26978 L
s
.43651 .27959 m
.43651 .2894 L
.46825 .2894 L
.46825 .27959 L
.43651 .27959 L
s
.43651 .2894 m
.43651 .29921 L
.46825 .29921 L
.46825 .2894 L
.43651 .2894 L
s
.43651 .29921 m
.43651 .30902 L
.46825 .30902 L
.46825 .29921 L
.43651 .29921 L
s
.43651 .30902 m
.43651 .31883 L
.46825 .31883 L
.46825 .30902 L
.43651 .30902 L
s
.43651 .31883 m
.43651 .32864 L
.46825 .32864 L
.46825 .31883 L
.43651 .31883 L
s
.43651 .32864 m
.43651 .33845 L
.46825 .33845 L
.46825 .32864 L
.43651 .32864 L
s
.43651 .33845 m
.43651 .34826 L
.46825 .34826 L
.46825 .33845 L
.43651 .33845 L
s
.43651 .34826 m
.43651 .35807 L
.46825 .35807 L
.46825 .34826 L
.43651 .34826 L
s
.43651 .35807 m
.43651 .36788 L
.46825 .36788 L
.46825 .35807 L
.43651 .35807 L
s
.43651 .36788 m
.43651 .37769 L
.46825 .37769 L
.46825 .36788 L
.43651 .36788 L
s
.43651 .37769 m
.43651 .3875 L
.46825 .3875 L
.46825 .37769 L
.43651 .37769 L
s
.43651 .3875 m
.43651 .39731 L
.46825 .39731 L
.46825 .3875 L
.43651 .3875 L
s
.43651 .39731 m
.43651 .40712 L
.46825 .40712 L
.46825 .39731 L
.43651 .39731 L
s
.43651 .40712 m
.43651 .41693 L
.46825 .41693 L
.46825 .40712 L
.43651 .40712 L
s
.43651 .41693 m
.43651 .42674 L
.46825 .42674 L
.46825 .41693 L
.43651 .41693 L
s
.43651 .42674 m
.43651 .43655 L
.46825 .43655 L
.46825 .42674 L
.43651 .42674 L
s
.43651 .43655 m
.43651 .44636 L
.46825 .44636 L
.46825 .43655 L
.43651 .43655 L
s
.43651 .44636 m
.43651 .45617 L
.46825 .45617 L
.46825 .44636 L
.43651 .44636 L
s
.43651 .45617 m
.43651 .46598 L
.46825 .46598 L
.46825 .45617 L
.43651 .45617 L
s
.43651 .46598 m
.43651 .47579 L
.46825 .47579 L
.46825 .46598 L
.43651 .46598 L
s
.43651 .47579 m
.43651 .4856 L
.46825 .4856 L
.46825 .47579 L
.43651 .47579 L
s
.43651 .4856 m
.43651 .49541 L
.46825 .49541 L
.46825 .4856 L
.43651 .4856 L
s
.43651 .49541 m
.43651 .50522 L
.46825 .50522 L
.46825 .49541 L
.43651 .49541 L
s
.43651 .50522 m
.43651 .51503 L
.46825 .51503 L
.46825 .50522 L
.43651 .50522 L
s
.43651 .51503 m
.43651 .52484 L
.46825 .52484 L
.46825 .51503 L
.43651 .51503 L
s
.43651 .52484 m
.43651 .53465 L
.46825 .53465 L
.46825 .52484 L
.43651 .52484 L
s
.43651 .53465 m
.43651 .54446 L
.46825 .54446 L
.46825 .53465 L
.43651 .53465 L
s
.43651 .54446 m
.43651 .55427 L
.46825 .55427 L
.46825 .54446 L
.43651 .54446 L
s
.43651 .55427 m
.43651 .56408 L
.46825 .56408 L
.46825 .55427 L
.43651 .55427 L
s
.43651 .56408 m
.43651 .57389 L
.46825 .57389 L
.46825 .56408 L
.43651 .56408 L
s
.43651 .57389 m
.43651 .5837 L
.46825 .5837 L
.46825 .57389 L
.43651 .57389 L
s
.43651 .5837 m
.43651 .59351 L
.46825 .59351 L
.46825 .5837 L
.43651 .5837 L
s
.43651 .59351 m
.43651 .60332 L
.46825 .60332 L
.46825 .59351 L
.43651 .59351 L
s
.46825 .01472 m
.46825 .02453 L
.5 .02453 L
.5 .01472 L
.46825 .01472 L
s
.46825 .02453 m
.46825 .03434 L
.5 .03434 L
.5 .02453 L
.46825 .02453 L
s
.46825 .03434 m
.46825 .04415 L
.5 .04415 L
.5 .03434 L
.46825 .03434 L
s
.46825 .04415 m
.46825 .05396 L
.5 .05396 L
.5 .04415 L
.46825 .04415 L
s
.46825 .05396 m
.46825 .06377 L
.5 .06377 L
.5 .05396 L
.46825 .05396 L
s
.46825 .06377 m
.46825 .07358 L
.5 .07358 L
.5 .06377 L
.46825 .06377 L
s
.46825 .07358 m
.46825 .08339 L
.5 .08339 L
.5 .07358 L
.46825 .07358 L
s
.46825 .08339 m
.46825 .0932 L
.5 .0932 L
.5 .08339 L
.46825 .08339 L
s
.46825 .0932 m
.46825 .10301 L
.5 .10301 L
.5 .0932 L
.46825 .0932 L
s
.46825 .10301 m
.46825 .11282 L
.5 .11282 L
.5 .10301 L
.46825 .10301 L
s
.46825 .11282 m
.46825 .12263 L
.5 .12263 L
.5 .11282 L
.46825 .11282 L
s
.46825 .12263 m
.46825 .13244 L
.5 .13244 L
.5 .12263 L
.46825 .12263 L
s
.46825 .13244 m
.46825 .14225 L
.5 .14225 L
.5 .13244 L
.46825 .13244 L
s
.46825 .14225 m
.46825 .15206 L
.5 .15206 L
.5 .14225 L
.46825 .14225 L
s
.46825 .15206 m
.46825 .16187 L
.5 .16187 L
.5 .15206 L
.46825 .15206 L
s
.46825 .16187 m
.46825 .17168 L
.5 .17168 L
.5 .16187 L
.46825 .16187 L
s
.46825 .17168 m
.46825 .18149 L
.5 .18149 L
.5 .17168 L
.46825 .17168 L
s
.46825 .18149 m
.46825 .1913 L
.5 .1913 L
.5 .18149 L
.46825 .18149 L
s
.46825 .1913 m
.46825 .20111 L
.5 .20111 L
.5 .1913 L
.46825 .1913 L
s
.46825 .20111 m
.46825 .21092 L
.5 .21092 L
.5 .20111 L
.46825 .20111 L
s
.46825 .21092 m
.46825 .22073 L
.5 .22073 L
.5 .21092 L
.46825 .21092 L
s
.46825 .22073 m
.46825 .23054 L
.5 .23054 L
.5 .22073 L
.46825 .22073 L
s
.46825 .23054 m
.46825 .24035 L
.5 .24035 L
.5 .23054 L
.46825 .23054 L
s
.46825 .24035 m
.46825 .25016 L
.5 .25016 L
.5 .24035 L
.46825 .24035 L
s
.46825 .25016 m
.46825 .25997 L
.5 .25997 L
.5 .25016 L
.46825 .25016 L
s
.46825 .25997 m
.46825 .26978 L
.5 .26978 L
.5 .25997 L
.46825 .25997 L
s
.46825 .26978 m
.46825 .27959 L
.5 .27959 L
.5 .26978 L
.46825 .26978 L
s
.46825 .27959 m
.46825 .2894 L
.5 .2894 L
.5 .27959 L
.46825 .27959 L
s
.46825 .2894 m
.46825 .29921 L
.5 .29921 L
.5 .2894 L
.46825 .2894 L
s
.46825 .29921 m
.46825 .30902 L
.5 .30902 L
.5 .29921 L
.46825 .29921 L
s
.46825 .30902 m
.46825 .31883 L
.5 .31883 L
.5 .30902 L
.46825 .30902 L
s
.46825 .31883 m
.46825 .32864 L
.5 .32864 L
.5 .31883 L
.46825 .31883 L
s
.46825 .32864 m
.46825 .33845 L
.5 .33845 L
.5 .32864 L
.46825 .32864 L
s
.46825 .33845 m
.46825 .34826 L
.5 .34826 L
.5 .33845 L
.46825 .33845 L
s
.46825 .34826 m
.46825 .35807 L
.5 .35807 L
.5 .34826 L
.46825 .34826 L
s
.46825 .35807 m
.46825 .36788 L
.5 .36788 L
.5 .35807 L
.46825 .35807 L
s
.46825 .36788 m
.46825 .37769 L
.5 .37769 L
.5 .36788 L
.46825 .36788 L
s
.46825 .37769 m
.46825 .3875 L
.5 .3875 L
.5 .37769 L
.46825 .37769 L
s
.46825 .3875 m
.46825 .39731 L
.5 .39731 L
.5 .3875 L
.46825 .3875 L
s
.46825 .39731 m
.46825 .40712 L
.5 .40712 L
.5 .39731 L
.46825 .39731 L
s
.46825 .40712 m
.46825 .41693 L
.5 .41693 L
.5 .40712 L
.46825 .40712 L
s
.46825 .41693 m
.46825 .42674 L
.5 .42674 L
.5 .41693 L
.46825 .41693 L
s
.46825 .42674 m
.46825 .43655 L
.5 .43655 L
.5 .42674 L
.46825 .42674 L
s
.46825 .43655 m
.46825 .44636 L
.5 .44636 L
.5 .43655 L
.46825 .43655 L
s
.46825 .44636 m
.46825 .45617 L
.5 .45617 L
.5 .44636 L
.46825 .44636 L
s
.46825 .45617 m
.46825 .46598 L
.5 .46598 L
.5 .45617 L
.46825 .45617 L
s
.46825 .46598 m
.46825 .47579 L
.5 .47579 L
.5 .46598 L
.46825 .46598 L
s
.46825 .47579 m
.46825 .4856 L
.5 .4856 L
.5 .47579 L
.46825 .47579 L
s
.46825 .4856 m
.46825 .49541 L
.5 .49541 L
.5 .4856 L
.46825 .4856 L
s
.46825 .49541 m
.46825 .50522 L
.5 .50522 L
.5 .49541 L
.46825 .49541 L
s
.46825 .50522 m
.46825 .51503 L
.5 .51503 L
.5 .50522 L
.46825 .50522 L
s
.46825 .51503 m
.46825 .52484 L
.5 .52484 L
.5 .51503 L
.46825 .51503 L
s
.46825 .52484 m
.46825 .53465 L
.5 .53465 L
.5 .52484 L
.46825 .52484 L
s
.46825 .53465 m
.46825 .54446 L
.5 .54446 L
.5 .53465 L
.46825 .53465 L
s
.46825 .54446 m
.46825 .55427 L
.5 .55427 L
.5 .54446 L
.46825 .54446 L
s
.46825 .55427 m
.46825 .56408 L
.5 .56408 L
.5 .55427 L
.46825 .55427 L
s
.46825 .56408 m
.46825 .57389 L
.5 .57389 L
.5 .56408 L
.46825 .56408 L
s
.46825 .57389 m
.46825 .5837 L
.5 .5837 L
.5 .57389 L
.46825 .57389 L
s
.46825 .5837 m
.46825 .59351 L
.5 .59351 L
.5 .5837 L
.46825 .5837 L
s
.46825 .59351 m
.46825 .60332 L
.5 .60332 L
.5 .59351 L
.46825 .59351 L
s
.5 .01472 m
.5 .02453 L
.53175 .02453 L
.53175 .01472 L
.5 .01472 L
s
.5 .02453 m
.5 .03434 L
.53175 .03434 L
.53175 .02453 L
.5 .02453 L
s
.5 .03434 m
.5 .04415 L
.53175 .04415 L
.53175 .03434 L
.5 .03434 L
s
.5 .04415 m
.5 .05396 L
.53175 .05396 L
.53175 .04415 L
.5 .04415 L
s
.5 .05396 m
.5 .06377 L
.53175 .06377 L
.53175 .05396 L
.5 .05396 L
s
.5 .06377 m
.5 .07358 L
.53175 .07358 L
.53175 .06377 L
.5 .06377 L
s
.5 .07358 m
.5 .08339 L
.53175 .08339 L
.53175 .07358 L
.5 .07358 L
s
.5 .08339 m
.5 .0932 L
.53175 .0932 L
.53175 .08339 L
.5 .08339 L
s
.5 .0932 m
.5 .10301 L
.53175 .10301 L
.53175 .0932 L
.5 .0932 L
s
.5 .10301 m
.5 .11282 L
.53175 .11282 L
.53175 .10301 L
.5 .10301 L
s
.5 .11282 m
.5 .12263 L
.53175 .12263 L
.53175 .11282 L
.5 .11282 L
s
.5 .12263 m
.5 .13244 L
.53175 .13244 L
.53175 .12263 L
.5 .12263 L
s
.5 .13244 m
.5 .14225 L
.53175 .14225 L
.53175 .13244 L
.5 .13244 L
s
.5 .14225 m
.5 .15206 L
.53175 .15206 L
.53175 .14225 L
.5 .14225 L
s
.5 .15206 m
.5 .16187 L
.53175 .16187 L
.53175 .15206 L
.5 .15206 L
s
.5 .16187 m
.5 .17168 L
.53175 .17168 L
.53175 .16187 L
.5 .16187 L
s
.5 .17168 m
.5 .18149 L
.53175 .18149 L
.53175 .17168 L
.5 .17168 L
s
.5 .18149 m
.5 .1913 L
.53175 .1913 L
.53175 .18149 L
.5 .18149 L
s
.5 .1913 m
.5 .20111 L
.53175 .20111 L
.53175 .1913 L
.5 .1913 L
s
.5 .20111 m
.5 .21092 L
.53175 .21092 L
.53175 .20111 L
.5 .20111 L
s
.5 .21092 m
.5 .22073 L
.53175 .22073 L
.53175 .21092 L
.5 .21092 L
s
.5 .22073 m
.5 .23054 L
.53175 .23054 L
.53175 .22073 L
.5 .22073 L
s
.5 .23054 m
.5 .24035 L
.53175 .24035 L
.53175 .23054 L
.5 .23054 L
s
.5 .24035 m
.5 .25016 L
.53175 .25016 L
.53175 .24035 L
.5 .24035 L
s
.5 .25016 m
.5 .25997 L
.53175 .25997 L
.53175 .25016 L
.5 .25016 L
s
.5 .25997 m
.5 .26978 L
.53175 .26978 L
.53175 .25997 L
.5 .25997 L
s
.5 .26978 m
.5 .27959 L
.53175 .27959 L
.53175 .26978 L
.5 .26978 L
s
.5 .27959 m
.5 .2894 L
.53175 .2894 L
.53175 .27959 L
.5 .27959 L
s
.5 .2894 m
.5 .29921 L
.53175 .29921 L
.53175 .2894 L
.5 .2894 L
s
.5 .29921 m
.5 .30902 L
.53175 .30902 L
.53175 .29921 L
.5 .29921 L
s
.5 .30902 m
.5 .31883 L
.53175 .31883 L
.53175 .30902 L
.5 .30902 L
s
.5 .31883 m
.5 .32864 L
.53175 .32864 L
.53175 .31883 L
.5 .31883 L
s
.5 .32864 m
.5 .33845 L
.53175 .33845 L
.53175 .32864 L
.5 .32864 L
s
.5 .33845 m
.5 .34826 L
.53175 .34826 L
.53175 .33845 L
.5 .33845 L
s
.5 .34826 m
.5 .35807 L
.53175 .35807 L
.53175 .34826 L
.5 .34826 L
s
.5 .35807 m
.5 .36788 L
.53175 .36788 L
.53175 .35807 L
.5 .35807 L
s
.5 .36788 m
.5 .37769 L
.53175 .37769 L
.53175 .36788 L
.5 .36788 L
s
.5 .37769 m
.5 .3875 L
.53175 .3875 L
.53175 .37769 L
.5 .37769 L
s
.5 .3875 m
.5 .39731 L
.53175 .39731 L
.53175 .3875 L
.5 .3875 L
s
.5 .39731 m
.5 .40712 L
.53175 .40712 L
.53175 .39731 L
.5 .39731 L
s
.5 .40712 m
.5 .41693 L
.53175 .41693 L
.53175 .40712 L
.5 .40712 L
s
.5 .41693 m
.5 .42674 L
.53175 .42674 L
.53175 .41693 L
.5 .41693 L
s
.5 .42674 m
.5 .43655 L
.53175 .43655 L
.53175 .42674 L
.5 .42674 L
s
.5 .43655 m
.5 .44636 L
.53175 .44636 L
.53175 .43655 L
.5 .43655 L
s
.5 .44636 m
.5 .45617 L
.53175 .45617 L
.53175 .44636 L
.5 .44636 L
s
.5 .45617 m
.5 .46598 L
.53175 .46598 L
.53175 .45617 L
.5 .45617 L
s
.5 .46598 m
.5 .47579 L
.53175 .47579 L
.53175 .46598 L
.5 .46598 L
s
.5 .47579 m
.5 .4856 L
.53175 .4856 L
.53175 .47579 L
.5 .47579 L
s
.5 .4856 m
.5 .49541 L
.53175 .49541 L
.53175 .4856 L
.5 .4856 L
s
.5 .49541 m
.5 .50522 L
.53175 .50522 L
.53175 .49541 L
.5 .49541 L
s
.5 .50522 m
.5 .51503 L
.53175 .51503 L
.53175 .50522 L
.5 .50522 L
s
.5 .51503 m
.5 .52484 L
.53175 .52484 L
.53175 .51503 L
.5 .51503 L
s
.5 .52484 m
.5 .53465 L
.53175 .53465 L
.53175 .52484 L
.5 .52484 L
s
.5 .53465 m
.5 .54446 L
.53175 .54446 L
.53175 .53465 L
.5 .53465 L
s
.5 .54446 m
.5 .55427 L
.53175 .55427 L
.53175 .54446 L
.5 .54446 L
s
.5 .55427 m
.5 .56408 L
.53175 .56408 L
.53175 .55427 L
.5 .55427 L
s
.5 .56408 m
.5 .57389 L
.53175 .57389 L
.53175 .56408 L
.5 .56408 L
s
.5 .57389 m
.5 .5837 L
.53175 .5837 L
.53175 .57389 L
.5 .57389 L
s
.5 .5837 m
.5 .59351 L
.53175 .59351 L
.53175 .5837 L
.5 .5837 L
s
.5 .59351 m
.5 .60332 L
.53175 .60332 L
.53175 .59351 L
.5 .59351 L
s
.53175 .01472 m
.53175 .02453 L
.56349 .02453 L
.56349 .01472 L
.53175 .01472 L
s
.53175 .02453 m
.53175 .03434 L
.56349 .03434 L
.56349 .02453 L
.53175 .02453 L
s
.53175 .03434 m
.53175 .04415 L
.56349 .04415 L
.56349 .03434 L
.53175 .03434 L
s
.53175 .04415 m
.53175 .05396 L
.56349 .05396 L
.56349 .04415 L
.53175 .04415 L
s
.53175 .05396 m
.53175 .06377 L
.56349 .06377 L
.56349 .05396 L
.53175 .05396 L
s
.53175 .06377 m
.53175 .07358 L
.56349 .07358 L
.56349 .06377 L
.53175 .06377 L
s
.53175 .07358 m
.53175 .08339 L
.56349 .08339 L
.56349 .07358 L
.53175 .07358 L
s
.53175 .08339 m
.53175 .0932 L
.56349 .0932 L
.56349 .08339 L
.53175 .08339 L
s
.53175 .0932 m
.53175 .10301 L
.56349 .10301 L
.56349 .0932 L
.53175 .0932 L
s
.53175 .10301 m
.53175 .11282 L
.56349 .11282 L
.56349 .10301 L
.53175 .10301 L
s
.53175 .11282 m
.53175 .12263 L
.56349 .12263 L
.56349 .11282 L
.53175 .11282 L
s
.53175 .12263 m
.53175 .13244 L
.56349 .13244 L
.56349 .12263 L
.53175 .12263 L
s
.53175 .13244 m
.53175 .14225 L
.56349 .14225 L
.56349 .13244 L
.53175 .13244 L
s
.53175 .14225 m
.53175 .15206 L
.56349 .15206 L
.56349 .14225 L
.53175 .14225 L
s
.53175 .15206 m
.53175 .16187 L
.56349 .16187 L
.56349 .15206 L
.53175 .15206 L
s
.53175 .16187 m
.53175 .17168 L
.56349 .17168 L
.56349 .16187 L
.53175 .16187 L
s
.53175 .17168 m
.53175 .18149 L
.56349 .18149 L
.56349 .17168 L
.53175 .17168 L
s
.53175 .18149 m
.53175 .1913 L
.56349 .1913 L
.56349 .18149 L
.53175 .18149 L
s
.53175 .1913 m
.53175 .20111 L
.56349 .20111 L
.56349 .1913 L
.53175 .1913 L
s
.53175 .20111 m
.53175 .21092 L
.56349 .21092 L
.56349 .20111 L
.53175 .20111 L
s
.53175 .21092 m
.53175 .22073 L
.56349 .22073 L
.56349 .21092 L
.53175 .21092 L
s
.53175 .22073 m
.53175 .23054 L
.56349 .23054 L
.56349 .22073 L
.53175 .22073 L
s
.53175 .23054 m
.53175 .24035 L
.56349 .24035 L
.56349 .23054 L
.53175 .23054 L
s
.53175 .24035 m
.53175 .25016 L
.56349 .25016 L
.56349 .24035 L
.53175 .24035 L
s
.53175 .25016 m
.53175 .25997 L
.56349 .25997 L
.56349 .25016 L
.53175 .25016 L
s
.53175 .25997 m
.53175 .26978 L
.56349 .26978 L
.56349 .25997 L
.53175 .25997 L
s
.53175 .26978 m
.53175 .27959 L
.56349 .27959 L
.56349 .26978 L
.53175 .26978 L
s
.53175 .27959 m
.53175 .2894 L
.56349 .2894 L
.56349 .27959 L
.53175 .27959 L
s
.53175 .2894 m
.53175 .29921 L
.56349 .29921 L
.56349 .2894 L
.53175 .2894 L
s
.53175 .29921 m
.53175 .30902 L
.56349 .30902 L
.56349 .29921 L
.53175 .29921 L
s
.53175 .30902 m
.53175 .31883 L
.56349 .31883 L
.56349 .30902 L
.53175 .30902 L
s
.53175 .31883 m
.53175 .32864 L
.56349 .32864 L
.56349 .31883 L
.53175 .31883 L
s
.53175 .32864 m
.53175 .33845 L
.56349 .33845 L
.56349 .32864 L
.53175 .32864 L
s
.53175 .33845 m
.53175 .34826 L
.56349 .34826 L
.56349 .33845 L
.53175 .33845 L
s
.53175 .34826 m
.53175 .35807 L
.56349 .35807 L
.56349 .34826 L
.53175 .34826 L
s
.53175 .35807 m
.53175 .36788 L
.56349 .36788 L
.56349 .35807 L
.53175 .35807 L
s
.53175 .36788 m
.53175 .37769 L
.56349 .37769 L
.56349 .36788 L
.53175 .36788 L
s
.53175 .37769 m
.53175 .3875 L
.56349 .3875 L
.56349 .37769 L
.53175 .37769 L
s
.53175 .3875 m
.53175 .39731 L
.56349 .39731 L
.56349 .3875 L
.53175 .3875 L
s
.53175 .39731 m
.53175 .40712 L
.56349 .40712 L
.56349 .39731 L
.53175 .39731 L
s
.53175 .40712 m
.53175 .41693 L
.56349 .41693 L
.56349 .40712 L
.53175 .40712 L
s
.53175 .41693 m
.53175 .42674 L
.56349 .42674 L
.56349 .41693 L
.53175 .41693 L
s
.53175 .42674 m
.53175 .43655 L
.56349 .43655 L
.56349 .42674 L
.53175 .42674 L
s
.53175 .43655 m
.53175 .44636 L
.56349 .44636 L
.56349 .43655 L
.53175 .43655 L
s
.53175 .44636 m
.53175 .45617 L
.56349 .45617 L
.56349 .44636 L
.53175 .44636 L
s
.53175 .45617 m
.53175 .46598 L
.56349 .46598 L
.56349 .45617 L
.53175 .45617 L
s
.53175 .46598 m
.53175 .47579 L
.56349 .47579 L
.56349 .46598 L
.53175 .46598 L
s
.53175 .47579 m
.53175 .4856 L
.56349 .4856 L
.56349 .47579 L
.53175 .47579 L
s
.53175 .4856 m
.53175 .49541 L
.56349 .49541 L
.56349 .4856 L
.53175 .4856 L
s
.53175 .49541 m
.53175 .50522 L
.56349 .50522 L
.56349 .49541 L
.53175 .49541 L
s
.53175 .50522 m
.53175 .51503 L
.56349 .51503 L
.56349 .50522 L
.53175 .50522 L
s
.53175 .51503 m
.53175 .52484 L
.56349 .52484 L
.56349 .51503 L
.53175 .51503 L
s
.53175 .52484 m
.53175 .53465 L
.56349 .53465 L
.56349 .52484 L
.53175 .52484 L
s
.53175 .53465 m
.53175 .54446 L
.56349 .54446 L
.56349 .53465 L
.53175 .53465 L
s
.53175 .54446 m
.53175 .55427 L
.56349 .55427 L
.56349 .54446 L
.53175 .54446 L
s
.53175 .55427 m
.53175 .56408 L
.56349 .56408 L
.56349 .55427 L
.53175 .55427 L
s
.53175 .56408 m
.53175 .57389 L
.56349 .57389 L
.56349 .56408 L
.53175 .56408 L
s
.53175 .57389 m
.53175 .5837 L
.56349 .5837 L
.56349 .57389 L
.53175 .57389 L
s
.53175 .5837 m
.53175 .59351 L
.56349 .59351 L
.56349 .5837 L
.53175 .5837 L
s
.53175 .59351 m
.53175 .60332 L
.56349 .60332 L
.56349 .59351 L
.53175 .59351 L
s
.56349 .01472 m
.56349 .02453 L
.59524 .02453 L
.59524 .01472 L
.56349 .01472 L
s
.56349 .02453 m
.56349 .03434 L
.59524 .03434 L
.59524 .02453 L
.56349 .02453 L
s
.56349 .03434 m
.56349 .04415 L
.59524 .04415 L
.59524 .03434 L
.56349 .03434 L
s
.56349 .04415 m
.56349 .05396 L
.59524 .05396 L
.59524 .04415 L
.56349 .04415 L
s
.56349 .05396 m
.56349 .06377 L
.59524 .06377 L
.59524 .05396 L
.56349 .05396 L
s
.56349 .06377 m
.56349 .07358 L
.59524 .07358 L
.59524 .06377 L
.56349 .06377 L
s
.56349 .07358 m
.56349 .08339 L
.59524 .08339 L
.59524 .07358 L
.56349 .07358 L
s
.56349 .08339 m
.56349 .0932 L
.59524 .0932 L
.59524 .08339 L
.56349 .08339 L
s
.56349 .0932 m
.56349 .10301 L
.59524 .10301 L
.59524 .0932 L
.56349 .0932 L
s
.56349 .10301 m
.56349 .11282 L
.59524 .11282 L
.59524 .10301 L
.56349 .10301 L
s
.56349 .11282 m
.56349 .12263 L
.59524 .12263 L
.59524 .11282 L
.56349 .11282 L
s
.56349 .12263 m
.56349 .13244 L
.59524 .13244 L
.59524 .12263 L
.56349 .12263 L
s
.56349 .13244 m
.56349 .14225 L
.59524 .14225 L
.59524 .13244 L
.56349 .13244 L
s
.56349 .14225 m
.56349 .15206 L
.59524 .15206 L
.59524 .14225 L
.56349 .14225 L
s
.56349 .15206 m
.56349 .16187 L
.59524 .16187 L
.59524 .15206 L
.56349 .15206 L
s
.56349 .16187 m
.56349 .17168 L
.59524 .17168 L
.59524 .16187 L
.56349 .16187 L
s
.56349 .17168 m
.56349 .18149 L
.59524 .18149 L
.59524 .17168 L
.56349 .17168 L
s
.56349 .18149 m
.56349 .1913 L
.59524 .1913 L
.59524 .18149 L
.56349 .18149 L
s
.56349 .1913 m
.56349 .20111 L
.59524 .20111 L
.59524 .1913 L
.56349 .1913 L
s
.56349 .20111 m
.56349 .21092 L
.59524 .21092 L
.59524 .20111 L
.56349 .20111 L
s
.56349 .21092 m
.56349 .22073 L
.59524 .22073 L
.59524 .21092 L
.56349 .21092 L
s
.56349 .22073 m
.56349 .23054 L
.59524 .23054 L
.59524 .22073 L
.56349 .22073 L
s
.56349 .23054 m
.56349 .24035 L
.59524 .24035 L
.59524 .23054 L
.56349 .23054 L
s
.56349 .24035 m
.56349 .25016 L
.59524 .25016 L
.59524 .24035 L
.56349 .24035 L
s
.56349 .25016 m
.56349 .25997 L
.59524 .25997 L
.59524 .25016 L
.56349 .25016 L
s
.56349 .25997 m
.56349 .26978 L
.59524 .26978 L
.59524 .25997 L
.56349 .25997 L
s
.56349 .26978 m
.56349 .27959 L
.59524 .27959 L
.59524 .26978 L
.56349 .26978 L
s
.56349 .27959 m
.56349 .2894 L
.59524 .2894 L
.59524 .27959 L
.56349 .27959 L
s
.56349 .2894 m
.56349 .29921 L
.59524 .29921 L
.59524 .2894 L
.56349 .2894 L
s
.56349 .29921 m
.56349 .30902 L
.59524 .30902 L
.59524 .29921 L
.56349 .29921 L
s
.56349 .30902 m
.56349 .31883 L
.59524 .31883 L
.59524 .30902 L
.56349 .30902 L
s
.56349 .31883 m
.56349 .32864 L
.59524 .32864 L
.59524 .31883 L
.56349 .31883 L
s
.56349 .32864 m
.56349 .33845 L
.59524 .33845 L
.59524 .32864 L
.56349 .32864 L
s
.56349 .33845 m
.56349 .34826 L
.59524 .34826 L
.59524 .33845 L
.56349 .33845 L
s
.56349 .34826 m
.56349 .35807 L
.59524 .35807 L
.59524 .34826 L
.56349 .34826 L
s
.56349 .35807 m
.56349 .36788 L
.59524 .36788 L
.59524 .35807 L
.56349 .35807 L
s
.56349 .36788 m
.56349 .37769 L
.59524 .37769 L
.59524 .36788 L
.56349 .36788 L
s
.56349 .37769 m
.56349 .3875 L
.59524 .3875 L
.59524 .37769 L
.56349 .37769 L
s
.56349 .3875 m
.56349 .39731 L
.59524 .39731 L
.59524 .3875 L
.56349 .3875 L
s
.56349 .39731 m
.56349 .40712 L
.59524 .40712 L
.59524 .39731 L
.56349 .39731 L
s
.56349 .40712 m
.56349 .41693 L
.59524 .41693 L
.59524 .40712 L
.56349 .40712 L
s
.56349 .41693 m
.56349 .42674 L
.59524 .42674 L
.59524 .41693 L
.56349 .41693 L
s
.56349 .42674 m
.56349 .43655 L
.59524 .43655 L
.59524 .42674 L
.56349 .42674 L
s
.56349 .43655 m
.56349 .44636 L
.59524 .44636 L
.59524 .43655 L
.56349 .43655 L
s
.56349 .44636 m
.56349 .45617 L
.59524 .45617 L
.59524 .44636 L
.56349 .44636 L
s
.56349 .45617 m
.56349 .46598 L
.59524 .46598 L
.59524 .45617 L
.56349 .45617 L
s
.56349 .46598 m
.56349 .47579 L
.59524 .47579 L
.59524 .46598 L
.56349 .46598 L
s
.56349 .47579 m
.56349 .4856 L
.59524 .4856 L
.59524 .47579 L
.56349 .47579 L
s
.56349 .4856 m
.56349 .49541 L
.59524 .49541 L
.59524 .4856 L
.56349 .4856 L
s
.56349 .49541 m
.56349 .50522 L
.59524 .50522 L
.59524 .49541 L
.56349 .49541 L
s
.56349 .50522 m
.56349 .51503 L
.59524 .51503 L
.59524 .50522 L
.56349 .50522 L
s
.56349 .51503 m
.56349 .52484 L
.59524 .52484 L
.59524 .51503 L
.56349 .51503 L
s
.56349 .52484 m
.56349 .53465 L
.59524 .53465 L
.59524 .52484 L
.56349 .52484 L
s
.56349 .53465 m
.56349 .54446 L
.59524 .54446 L
.59524 .53465 L
.56349 .53465 L
s
.56349 .54446 m
.56349 .55427 L
.59524 .55427 L
.59524 .54446 L
.56349 .54446 L
s
.56349 .55427 m
.56349 .56408 L
.59524 .56408 L
.59524 .55427 L
.56349 .55427 L
s
.56349 .56408 m
.56349 .57389 L
.59524 .57389 L
.59524 .56408 L
.56349 .56408 L
s
.56349 .57389 m
.56349 .5837 L
.59524 .5837 L
.59524 .57389 L
.56349 .57389 L
s
.56349 .5837 m
.56349 .59351 L
.59524 .59351 L
.59524 .5837 L
.56349 .5837 L
s
.56349 .59351 m
.56349 .60332 L
.59524 .60332 L
.59524 .59351 L
.56349 .59351 L
s
.59524 .01472 m
.59524 .02453 L
.62698 .02453 L
.62698 .01472 L
.59524 .01472 L
s
.59524 .02453 m
.59524 .03434 L
.62698 .03434 L
.62698 .02453 L
.59524 .02453 L
s
.59524 .03434 m
.59524 .04415 L
.62698 .04415 L
.62698 .03434 L
.59524 .03434 L
s
.59524 .04415 m
.59524 .05396 L
.62698 .05396 L
.62698 .04415 L
.59524 .04415 L
s
.59524 .05396 m
.59524 .06377 L
.62698 .06377 L
.62698 .05396 L
.59524 .05396 L
s
.59524 .06377 m
.59524 .07358 L
.62698 .07358 L
.62698 .06377 L
.59524 .06377 L
s
.59524 .07358 m
.59524 .08339 L
.62698 .08339 L
.62698 .07358 L
.59524 .07358 L
s
.59524 .08339 m
.59524 .0932 L
.62698 .0932 L
.62698 .08339 L
.59524 .08339 L
s
.59524 .0932 m
.59524 .10301 L
.62698 .10301 L
.62698 .0932 L
.59524 .0932 L
s
.59524 .10301 m
.59524 .11282 L
.62698 .11282 L
.62698 .10301 L
.59524 .10301 L
s
.59524 .11282 m
.59524 .12263 L
.62698 .12263 L
.62698 .11282 L
.59524 .11282 L
s
.59524 .12263 m
.59524 .13244 L
.62698 .13244 L
.62698 .12263 L
.59524 .12263 L
s
.59524 .13244 m
.59524 .14225 L
.62698 .14225 L
.62698 .13244 L
.59524 .13244 L
s
.59524 .14225 m
.59524 .15206 L
.62698 .15206 L
.62698 .14225 L
.59524 .14225 L
s
.59524 .15206 m
.59524 .16187 L
.62698 .16187 L
.62698 .15206 L
.59524 .15206 L
s
.59524 .16187 m
.59524 .17168 L
.62698 .17168 L
.62698 .16187 L
.59524 .16187 L
s
.59524 .17168 m
.59524 .18149 L
.62698 .18149 L
.62698 .17168 L
.59524 .17168 L
s
.59524 .18149 m
.59524 .1913 L
.62698 .1913 L
.62698 .18149 L
.59524 .18149 L
s
.59524 .1913 m
.59524 .20111 L
.62698 .20111 L
.62698 .1913 L
.59524 .1913 L
s
.59524 .20111 m
.59524 .21092 L
.62698 .21092 L
.62698 .20111 L
.59524 .20111 L
s
.59524 .21092 m
.59524 .22073 L
.62698 .22073 L
.62698 .21092 L
.59524 .21092 L
s
.59524 .22073 m
.59524 .23054 L
.62698 .23054 L
.62698 .22073 L
.59524 .22073 L
s
.59524 .23054 m
.59524 .24035 L
.62698 .24035 L
.62698 .23054 L
.59524 .23054 L
s
.59524 .24035 m
.59524 .25016 L
.62698 .25016 L
.62698 .24035 L
.59524 .24035 L
s
.59524 .25016 m
.59524 .25997 L
.62698 .25997 L
.62698 .25016 L
.59524 .25016 L
s
.59524 .25997 m
.59524 .26978 L
.62698 .26978 L
.62698 .25997 L
.59524 .25997 L
s
.59524 .26978 m
.59524 .27959 L
.62698 .27959 L
.62698 .26978 L
.59524 .26978 L
s
.59524 .27959 m
.59524 .2894 L
.62698 .2894 L
.62698 .27959 L
.59524 .27959 L
s
.59524 .2894 m
.59524 .29921 L
.62698 .29921 L
.62698 .2894 L
.59524 .2894 L
s
.59524 .29921 m
.59524 .30902 L
.62698 .30902 L
.62698 .29921 L
.59524 .29921 L
s
.59524 .30902 m
.59524 .31883 L
.62698 .31883 L
.62698 .30902 L
.59524 .30902 L
s
.59524 .31883 m
.59524 .32864 L
.62698 .32864 L
.62698 .31883 L
.59524 .31883 L
s
.59524 .32864 m
.59524 .33845 L
.62698 .33845 L
.62698 .32864 L
.59524 .32864 L
s
.59524 .33845 m
.59524 .34826 L
.62698 .34826 L
.62698 .33845 L
.59524 .33845 L
s
.59524 .34826 m
.59524 .35807 L
.62698 .35807 L
.62698 .34826 L
.59524 .34826 L
s
.59524 .35807 m
.59524 .36788 L
.62698 .36788 L
.62698 .35807 L
.59524 .35807 L
s
.59524 .36788 m
.59524 .37769 L
.62698 .37769 L
.62698 .36788 L
.59524 .36788 L
s
.59524 .37769 m
.59524 .3875 L
.62698 .3875 L
.62698 .37769 L
.59524 .37769 L
s
.59524 .3875 m
.59524 .39731 L
.62698 .39731 L
.62698 .3875 L
.59524 .3875 L
s
.59524 .39731 m
.59524 .40712 L
.62698 .40712 L
.62698 .39731 L
.59524 .39731 L
s
.59524 .40712 m
.59524 .41693 L
.62698 .41693 L
.62698 .40712 L
.59524 .40712 L
s
.59524 .41693 m
.59524 .42674 L
.62698 .42674 L
.62698 .41693 L
.59524 .41693 L
s
.59524 .42674 m
.59524 .43655 L
.62698 .43655 L
.62698 .42674 L
.59524 .42674 L
s
.59524 .43655 m
.59524 .44636 L
.62698 .44636 L
.62698 .43655 L
.59524 .43655 L
s
.59524 .44636 m
.59524 .45617 L
.62698 .45617 L
.62698 .44636 L
.59524 .44636 L
s
.59524 .45617 m
.59524 .46598 L
.62698 .46598 L
.62698 .45617 L
.59524 .45617 L
s
.59524 .46598 m
.59524 .47579 L
.62698 .47579 L
.62698 .46598 L
.59524 .46598 L
s
.59524 .47579 m
.59524 .4856 L
.62698 .4856 L
.62698 .47579 L
.59524 .47579 L
s
.59524 .4856 m
.59524 .49541 L
.62698 .49541 L
.62698 .4856 L
.59524 .4856 L
s
.59524 .49541 m
.59524 .50522 L
.62698 .50522 L
.62698 .49541 L
.59524 .49541 L
s
.59524 .50522 m
.59524 .51503 L
.62698 .51503 L
.62698 .50522 L
.59524 .50522 L
s
.59524 .51503 m
.59524 .52484 L
.62698 .52484 L
.62698 .51503 L
.59524 .51503 L
s
.59524 .52484 m
.59524 .53465 L
.62698 .53465 L
.62698 .52484 L
.59524 .52484 L
s
.59524 .53465 m
.59524 .54446 L
.62698 .54446 L
.62698 .53465 L
.59524 .53465 L
s
.59524 .54446 m
.59524 .55427 L
.62698 .55427 L
.62698 .54446 L
.59524 .54446 L
s
.59524 .55427 m
.59524 .56408 L
.62698 .56408 L
.62698 .55427 L
.59524 .55427 L
s
.59524 .56408 m
.59524 .57389 L
.62698 .57389 L
.62698 .56408 L
.59524 .56408 L
s
.59524 .57389 m
.59524 .5837 L
.62698 .5837 L
.62698 .57389 L
.59524 .57389 L
s
.59524 .5837 m
.59524 .59351 L
.62698 .59351 L
.62698 .5837 L
.59524 .5837 L
s
.59524 .59351 m
.59524 .60332 L
.62698 .60332 L
.62698 .59351 L
.59524 .59351 L
s
.62698 .01472 m
.62698 .02453 L
.65873 .02453 L
.65873 .01472 L
.62698 .01472 L
s
.62698 .02453 m
.62698 .03434 L
.65873 .03434 L
.65873 .02453 L
.62698 .02453 L
s
.62698 .03434 m
.62698 .04415 L
.65873 .04415 L
.65873 .03434 L
.62698 .03434 L
s
.62698 .04415 m
.62698 .05396 L
.65873 .05396 L
.65873 .04415 L
.62698 .04415 L
s
.62698 .05396 m
.62698 .06377 L
.65873 .06377 L
.65873 .05396 L
.62698 .05396 L
s
.62698 .06377 m
.62698 .07358 L
.65873 .07358 L
.65873 .06377 L
.62698 .06377 L
s
.62698 .07358 m
.62698 .08339 L
.65873 .08339 L
.65873 .07358 L
.62698 .07358 L
s
.62698 .08339 m
.62698 .0932 L
.65873 .0932 L
.65873 .08339 L
.62698 .08339 L
s
.62698 .0932 m
.62698 .10301 L
.65873 .10301 L
.65873 .0932 L
.62698 .0932 L
s
.62698 .10301 m
.62698 .11282 L
.65873 .11282 L
.65873 .10301 L
.62698 .10301 L
s
.62698 .11282 m
.62698 .12263 L
.65873 .12263 L
.65873 .11282 L
.62698 .11282 L
s
.62698 .12263 m
.62698 .13244 L
.65873 .13244 L
.65873 .12263 L
.62698 .12263 L
s
.62698 .13244 m
.62698 .14225 L
.65873 .14225 L
.65873 .13244 L
.62698 .13244 L
s
.62698 .14225 m
.62698 .15206 L
.65873 .15206 L
.65873 .14225 L
.62698 .14225 L
s
.62698 .15206 m
.62698 .16187 L
.65873 .16187 L
.65873 .15206 L
.62698 .15206 L
s
.62698 .16187 m
.62698 .17168 L
.65873 .17168 L
.65873 .16187 L
.62698 .16187 L
s
.62698 .17168 m
.62698 .18149 L
.65873 .18149 L
.65873 .17168 L
.62698 .17168 L
s
.62698 .18149 m
.62698 .1913 L
.65873 .1913 L
.65873 .18149 L
.62698 .18149 L
s
.62698 .1913 m
.62698 .20111 L
.65873 .20111 L
.65873 .1913 L
.62698 .1913 L
s
.62698 .20111 m
.62698 .21092 L
.65873 .21092 L
.65873 .20111 L
.62698 .20111 L
s
.62698 .21092 m
.62698 .22073 L
.65873 .22073 L
.65873 .21092 L
.62698 .21092 L
s
.62698 .22073 m
.62698 .23054 L
.65873 .23054 L
.65873 .22073 L
.62698 .22073 L
s
.62698 .23054 m
.62698 .24035 L
.65873 .24035 L
.65873 .23054 L
.62698 .23054 L
s
.62698 .24035 m
.62698 .25016 L
.65873 .25016 L
.65873 .24035 L
.62698 .24035 L
s
.62698 .25016 m
.62698 .25997 L
.65873 .25997 L
.65873 .25016 L
.62698 .25016 L
s
.62698 .25997 m
.62698 .26978 L
.65873 .26978 L
.65873 .25997 L
.62698 .25997 L
s
.62698 .26978 m
.62698 .27959 L
.65873 .27959 L
.65873 .26978 L
.62698 .26978 L
s
.62698 .27959 m
.62698 .2894 L
.65873 .2894 L
.65873 .27959 L
.62698 .27959 L
s
.62698 .2894 m
.62698 .29921 L
.65873 .29921 L
.65873 .2894 L
.62698 .2894 L
s
.62698 .29921 m
.62698 .30902 L
.65873 .30902 L
.65873 .29921 L
.62698 .29921 L
s
.62698 .30902 m
.62698 .31883 L
.65873 .31883 L
.65873 .30902 L
.62698 .30902 L
s
.62698 .31883 m
.62698 .32864 L
.65873 .32864 L
.65873 .31883 L
.62698 .31883 L
s
.62698 .32864 m
.62698 .33845 L
.65873 .33845 L
.65873 .32864 L
.62698 .32864 L
s
.62698 .33845 m
.62698 .34826 L
.65873 .34826 L
.65873 .33845 L
.62698 .33845 L
s
.62698 .34826 m
.62698 .35807 L
.65873 .35807 L
.65873 .34826 L
.62698 .34826 L
s
.62698 .35807 m
.62698 .36788 L
.65873 .36788 L
.65873 .35807 L
.62698 .35807 L
s
.62698 .36788 m
.62698 .37769 L
.65873 .37769 L
.65873 .36788 L
.62698 .36788 L
s
.62698 .37769 m
.62698 .3875 L
.65873 .3875 L
.65873 .37769 L
.62698 .37769 L
s
.62698 .3875 m
.62698 .39731 L
.65873 .39731 L
.65873 .3875 L
.62698 .3875 L
s
.62698 .39731 m
.62698 .40712 L
.65873 .40712 L
.65873 .39731 L
.62698 .39731 L
s
.62698 .40712 m
.62698 .41693 L
.65873 .41693 L
.65873 .40712 L
.62698 .40712 L
s
.62698 .41693 m
.62698 .42674 L
.65873 .42674 L
.65873 .41693 L
.62698 .41693 L
s
.62698 .42674 m
.62698 .43655 L
.65873 .43655 L
.65873 .42674 L
.62698 .42674 L
s
.62698 .43655 m
.62698 .44636 L
.65873 .44636 L
.65873 .43655 L
.62698 .43655 L
s
.62698 .44636 m
.62698 .45617 L
.65873 .45617 L
.65873 .44636 L
.62698 .44636 L
s
.62698 .45617 m
.62698 .46598 L
.65873 .46598 L
.65873 .45617 L
.62698 .45617 L
s
.62698 .46598 m
.62698 .47579 L
.65873 .47579 L
.65873 .46598 L
.62698 .46598 L
s
.62698 .47579 m
.62698 .4856 L
.65873 .4856 L
.65873 .47579 L
.62698 .47579 L
s
.62698 .4856 m
.62698 .49541 L
.65873 .49541 L
.65873 .4856 L
.62698 .4856 L
s
.62698 .49541 m
.62698 .50522 L
.65873 .50522 L
.65873 .49541 L
.62698 .49541 L
s
.62698 .50522 m
.62698 .51503 L
.65873 .51503 L
.65873 .50522 L
.62698 .50522 L
s
.62698 .51503 m
.62698 .52484 L
.65873 .52484 L
.65873 .51503 L
.62698 .51503 L
s
.62698 .52484 m
.62698 .53465 L
.65873 .53465 L
.65873 .52484 L
.62698 .52484 L
s
.62698 .53465 m
.62698 .54446 L
.65873 .54446 L
.65873 .53465 L
.62698 .53465 L
s
.62698 .54446 m
.62698 .55427 L
.65873 .55427 L
.65873 .54446 L
.62698 .54446 L
s
.62698 .55427 m
.62698 .56408 L
.65873 .56408 L
.65873 .55427 L
.62698 .55427 L
s
.62698 .56408 m
.62698 .57389 L
.65873 .57389 L
.65873 .56408 L
.62698 .56408 L
s
.62698 .57389 m
.62698 .5837 L
.65873 .5837 L
.65873 .57389 L
.62698 .57389 L
s
.62698 .5837 m
.62698 .59351 L
.65873 .59351 L
.65873 .5837 L
.62698 .5837 L
s
.62698 .59351 m
.62698 .60332 L
.65873 .60332 L
.65873 .59351 L
.62698 .59351 L
s
.65873 .01472 m
.65873 .02453 L
.69048 .02453 L
.69048 .01472 L
.65873 .01472 L
s
.65873 .02453 m
.65873 .03434 L
.69048 .03434 L
.69048 .02453 L
.65873 .02453 L
s
.65873 .03434 m
.65873 .04415 L
.69048 .04415 L
.69048 .03434 L
.65873 .03434 L
s
.65873 .04415 m
.65873 .05396 L
.69048 .05396 L
.69048 .04415 L
.65873 .04415 L
s
.65873 .05396 m
.65873 .06377 L
.69048 .06377 L
.69048 .05396 L
.65873 .05396 L
s
.65873 .06377 m
.65873 .07358 L
.69048 .07358 L
.69048 .06377 L
.65873 .06377 L
s
.65873 .07358 m
.65873 .08339 L
.69048 .08339 L
.69048 .07358 L
.65873 .07358 L
s
.65873 .08339 m
.65873 .0932 L
.69048 .0932 L
.69048 .08339 L
.65873 .08339 L
s
.65873 .0932 m
.65873 .10301 L
.69048 .10301 L
.69048 .0932 L
.65873 .0932 L
s
.65873 .10301 m
.65873 .11282 L
.69048 .11282 L
.69048 .10301 L
.65873 .10301 L
s
.65873 .11282 m
.65873 .12263 L
.69048 .12263 L
.69048 .11282 L
.65873 .11282 L
s
.65873 .12263 m
.65873 .13244 L
.69048 .13244 L
.69048 .12263 L
.65873 .12263 L
s
.65873 .13244 m
.65873 .14225 L
.69048 .14225 L
.69048 .13244 L
.65873 .13244 L
s
.65873 .14225 m
.65873 .15206 L
.69048 .15206 L
.69048 .14225 L
.65873 .14225 L
s
.65873 .15206 m
.65873 .16187 L
.69048 .16187 L
.69048 .15206 L
.65873 .15206 L
s
.65873 .16187 m
.65873 .17168 L
.69048 .17168 L
.69048 .16187 L
.65873 .16187 L
s
.65873 .17168 m
.65873 .18149 L
.69048 .18149 L
.69048 .17168 L
.65873 .17168 L
s
.65873 .18149 m
.65873 .1913 L
.69048 .1913 L
.69048 .18149 L
.65873 .18149 L
s
.65873 .1913 m
.65873 .20111 L
.69048 .20111 L
.69048 .1913 L
.65873 .1913 L
s
.65873 .20111 m
.65873 .21092 L
.69048 .21092 L
.69048 .20111 L
.65873 .20111 L
s
.65873 .21092 m
.65873 .22073 L
.69048 .22073 L
.69048 .21092 L
.65873 .21092 L
s
.65873 .22073 m
.65873 .23054 L
.69048 .23054 L
.69048 .22073 L
.65873 .22073 L
s
.65873 .23054 m
.65873 .24035 L
.69048 .24035 L
.69048 .23054 L
.65873 .23054 L
s
.65873 .24035 m
.65873 .25016 L
.69048 .25016 L
.69048 .24035 L
.65873 .24035 L
s
.65873 .25016 m
.65873 .25997 L
.69048 .25997 L
.69048 .25016 L
.65873 .25016 L
s
.65873 .25997 m
.65873 .26978 L
.69048 .26978 L
.69048 .25997 L
.65873 .25997 L
s
.65873 .26978 m
.65873 .27959 L
.69048 .27959 L
.69048 .26978 L
.65873 .26978 L
s
.65873 .27959 m
.65873 .2894 L
.69048 .2894 L
.69048 .27959 L
.65873 .27959 L
s
.65873 .2894 m
.65873 .29921 L
.69048 .29921 L
.69048 .2894 L
.65873 .2894 L
s
.65873 .29921 m
.65873 .30902 L
.69048 .30902 L
.69048 .29921 L
.65873 .29921 L
s
.65873 .30902 m
.65873 .31883 L
.69048 .31883 L
.69048 .30902 L
.65873 .30902 L
s
.65873 .31883 m
.65873 .32864 L
.69048 .32864 L
.69048 .31883 L
.65873 .31883 L
s
.65873 .32864 m
.65873 .33845 L
.69048 .33845 L
.69048 .32864 L
.65873 .32864 L
s
.65873 .33845 m
.65873 .34826 L
.69048 .34826 L
.69048 .33845 L
.65873 .33845 L
s
.65873 .34826 m
.65873 .35807 L
.69048 .35807 L
.69048 .34826 L
.65873 .34826 L
s
.65873 .35807 m
.65873 .36788 L
.69048 .36788 L
.69048 .35807 L
.65873 .35807 L
s
.65873 .36788 m
.65873 .37769 L
.69048 .37769 L
.69048 .36788 L
.65873 .36788 L
s
.65873 .37769 m
.65873 .3875 L
.69048 .3875 L
.69048 .37769 L
.65873 .37769 L
s
.65873 .3875 m
.65873 .39731 L
.69048 .39731 L
.69048 .3875 L
.65873 .3875 L
s
.65873 .39731 m
.65873 .40712 L
.69048 .40712 L
.69048 .39731 L
.65873 .39731 L
s
.65873 .40712 m
.65873 .41693 L
.69048 .41693 L
.69048 .40712 L
.65873 .40712 L
s
.65873 .41693 m
.65873 .42674 L
.69048 .42674 L
.69048 .41693 L
.65873 .41693 L
s
.65873 .42674 m
.65873 .43655 L
.69048 .43655 L
.69048 .42674 L
.65873 .42674 L
s
.65873 .43655 m
.65873 .44636 L
.69048 .44636 L
.69048 .43655 L
.65873 .43655 L
s
.65873 .44636 m
.65873 .45617 L
.69048 .45617 L
.69048 .44636 L
.65873 .44636 L
s
.65873 .45617 m
.65873 .46598 L
.69048 .46598 L
.69048 .45617 L
.65873 .45617 L
s
.65873 .46598 m
.65873 .47579 L
.69048 .47579 L
.69048 .46598 L
.65873 .46598 L
s
.65873 .47579 m
.65873 .4856 L
.69048 .4856 L
.69048 .47579 L
.65873 .47579 L
s
.65873 .4856 m
.65873 .49541 L
.69048 .49541 L
.69048 .4856 L
.65873 .4856 L
s
.65873 .49541 m
.65873 .50522 L
.69048 .50522 L
.69048 .49541 L
.65873 .49541 L
s
.65873 .50522 m
.65873 .51503 L
.69048 .51503 L
.69048 .50522 L
.65873 .50522 L
s
.65873 .51503 m
.65873 .52484 L
.69048 .52484 L
.69048 .51503 L
.65873 .51503 L
s
.65873 .52484 m
.65873 .53465 L
.69048 .53465 L
.69048 .52484 L
.65873 .52484 L
s
.65873 .53465 m
.65873 .54446 L
.69048 .54446 L
.69048 .53465 L
.65873 .53465 L
s
.65873 .54446 m
.65873 .55427 L
.69048 .55427 L
.69048 .54446 L
.65873 .54446 L
s
.65873 .55427 m
.65873 .56408 L
.69048 .56408 L
.69048 .55427 L
.65873 .55427 L
s
.65873 .56408 m
.65873 .57389 L
.69048 .57389 L
.69048 .56408 L
.65873 .56408 L
s
.65873 .57389 m
.65873 .5837 L
.69048 .5837 L
.69048 .57389 L
.65873 .57389 L
s
.65873 .5837 m
.65873 .59351 L
.69048 .59351 L
.69048 .5837 L
.65873 .5837 L
s
.65873 .59351 m
.65873 .60332 L
.69048 .60332 L
.69048 .59351 L
.65873 .59351 L
s
.69048 .01472 m
.69048 .02453 L
.72222 .02453 L
.72222 .01472 L
.69048 .01472 L
s
.69048 .02453 m
.69048 .03434 L
.72222 .03434 L
.72222 .02453 L
.69048 .02453 L
s
.69048 .03434 m
.69048 .04415 L
.72222 .04415 L
.72222 .03434 L
.69048 .03434 L
s
.69048 .04415 m
.69048 .05396 L
.72222 .05396 L
.72222 .04415 L
.69048 .04415 L
s
.69048 .05396 m
.69048 .06377 L
.72222 .06377 L
.72222 .05396 L
.69048 .05396 L
s
.69048 .06377 m
.69048 .07358 L
.72222 .07358 L
.72222 .06377 L
.69048 .06377 L
s
.69048 .07358 m
.69048 .08339 L
.72222 .08339 L
.72222 .07358 L
.69048 .07358 L
s
.69048 .08339 m
.69048 .0932 L
.72222 .0932 L
.72222 .08339 L
.69048 .08339 L
s
.69048 .0932 m
.69048 .10301 L
.72222 .10301 L
.72222 .0932 L
.69048 .0932 L
s
.69048 .10301 m
.69048 .11282 L
.72222 .11282 L
.72222 .10301 L
.69048 .10301 L
s
.69048 .11282 m
.69048 .12263 L
.72222 .12263 L
.72222 .11282 L
.69048 .11282 L
s
.69048 .12263 m
.69048 .13244 L
.72222 .13244 L
.72222 .12263 L
.69048 .12263 L
s
.69048 .13244 m
.69048 .14225 L
.72222 .14225 L
.72222 .13244 L
.69048 .13244 L
s
.69048 .14225 m
.69048 .15206 L
.72222 .15206 L
.72222 .14225 L
.69048 .14225 L
s
.69048 .15206 m
.69048 .16187 L
.72222 .16187 L
.72222 .15206 L
.69048 .15206 L
s
.69048 .16187 m
.69048 .17168 L
.72222 .17168 L
.72222 .16187 L
.69048 .16187 L
s
.69048 .17168 m
.69048 .18149 L
.72222 .18149 L
.72222 .17168 L
.69048 .17168 L
s
.69048 .18149 m
.69048 .1913 L
.72222 .1913 L
.72222 .18149 L
.69048 .18149 L
s
.69048 .1913 m
.69048 .20111 L
.72222 .20111 L
.72222 .1913 L
.69048 .1913 L
s
.69048 .20111 m
.69048 .21092 L
.72222 .21092 L
.72222 .20111 L
.69048 .20111 L
s
.69048 .21092 m
.69048 .22073 L
.72222 .22073 L
.72222 .21092 L
.69048 .21092 L
s
.69048 .22073 m
.69048 .23054 L
.72222 .23054 L
.72222 .22073 L
.69048 .22073 L
s
.69048 .23054 m
.69048 .24035 L
.72222 .24035 L
.72222 .23054 L
.69048 .23054 L
s
.69048 .24035 m
.69048 .25016 L
.72222 .25016 L
.72222 .24035 L
.69048 .24035 L
s
.69048 .25016 m
.69048 .25997 L
.72222 .25997 L
.72222 .25016 L
.69048 .25016 L
s
.69048 .25997 m
.69048 .26978 L
.72222 .26978 L
.72222 .25997 L
.69048 .25997 L
s
.69048 .26978 m
.69048 .27959 L
.72222 .27959 L
.72222 .26978 L
.69048 .26978 L
s
.69048 .27959 m
.69048 .2894 L
.72222 .2894 L
.72222 .27959 L
.69048 .27959 L
s
.69048 .2894 m
.69048 .29921 L
.72222 .29921 L
.72222 .2894 L
.69048 .2894 L
s
.69048 .29921 m
.69048 .30902 L
.72222 .30902 L
.72222 .29921 L
.69048 .29921 L
s
.69048 .30902 m
.69048 .31883 L
.72222 .31883 L
.72222 .30902 L
.69048 .30902 L
s
.69048 .31883 m
.69048 .32864 L
.72222 .32864 L
.72222 .31883 L
.69048 .31883 L
s
.69048 .32864 m
.69048 .33845 L
.72222 .33845 L
.72222 .32864 L
.69048 .32864 L
s
.69048 .33845 m
.69048 .34826 L
.72222 .34826 L
.72222 .33845 L
.69048 .33845 L
s
.69048 .34826 m
.69048 .35807 L
.72222 .35807 L
.72222 .34826 L
.69048 .34826 L
s
.69048 .35807 m
.69048 .36788 L
.72222 .36788 L
.72222 .35807 L
.69048 .35807 L
s
.69048 .36788 m
.69048 .37769 L
.72222 .37769 L
.72222 .36788 L
.69048 .36788 L
s
.69048 .37769 m
.69048 .3875 L
.72222 .3875 L
.72222 .37769 L
.69048 .37769 L
s
.69048 .3875 m
.69048 .39731 L
.72222 .39731 L
.72222 .3875 L
.69048 .3875 L
s
.69048 .39731 m
.69048 .40712 L
.72222 .40712 L
.72222 .39731 L
.69048 .39731 L
s
.69048 .40712 m
.69048 .41693 L
.72222 .41693 L
.72222 .40712 L
.69048 .40712 L
s
.69048 .41693 m
.69048 .42674 L
.72222 .42674 L
.72222 .41693 L
.69048 .41693 L
s
.69048 .42674 m
.69048 .43655 L
.72222 .43655 L
.72222 .42674 L
.69048 .42674 L
s
.69048 .43655 m
.69048 .44636 L
.72222 .44636 L
.72222 .43655 L
.69048 .43655 L
s
.69048 .44636 m
.69048 .45617 L
.72222 .45617 L
.72222 .44636 L
.69048 .44636 L
s
.69048 .45617 m
.69048 .46598 L
.72222 .46598 L
.72222 .45617 L
.69048 .45617 L
s
.69048 .46598 m
.69048 .47579 L
.72222 .47579 L
.72222 .46598 L
.69048 .46598 L
s
.69048 .47579 m
.69048 .4856 L
.72222 .4856 L
.72222 .47579 L
.69048 .47579 L
s
.69048 .4856 m
.69048 .49541 L
.72222 .49541 L
.72222 .4856 L
.69048 .4856 L
s
.69048 .49541 m
.69048 .50522 L
.72222 .50522 L
.72222 .49541 L
.69048 .49541 L
s
.69048 .50522 m
.69048 .51503 L
.72222 .51503 L
.72222 .50522 L
.69048 .50522 L
s
.69048 .51503 m
.69048 .52484 L
.72222 .52484 L
.72222 .51503 L
.69048 .51503 L
s
.69048 .52484 m
.69048 .53465 L
.72222 .53465 L
.72222 .52484 L
.69048 .52484 L
s
.69048 .53465 m
.69048 .54446 L
.72222 .54446 L
.72222 .53465 L
.69048 .53465 L
s
.69048 .54446 m
.69048 .55427 L
.72222 .55427 L
.72222 .54446 L
.69048 .54446 L
s
.69048 .55427 m
.69048 .56408 L
.72222 .56408 L
.72222 .55427 L
.69048 .55427 L
s
.69048 .56408 m
.69048 .57389 L
.72222 .57389 L
.72222 .56408 L
.69048 .56408 L
s
.69048 .57389 m
.69048 .5837 L
.72222 .5837 L
.72222 .57389 L
.69048 .57389 L
s
.69048 .5837 m
.69048 .59351 L
.72222 .59351 L
.72222 .5837 L
.69048 .5837 L
s
.69048 .59351 m
.69048 .60332 L
.72222 .60332 L
.72222 .59351 L
.69048 .59351 L
s
.72222 .01472 m
.72222 .02453 L
.75397 .02453 L
.75397 .01472 L
.72222 .01472 L
s
.72222 .02453 m
.72222 .03434 L
.75397 .03434 L
.75397 .02453 L
.72222 .02453 L
s
.72222 .03434 m
.72222 .04415 L
.75397 .04415 L
.75397 .03434 L
.72222 .03434 L
s
.72222 .04415 m
.72222 .05396 L
.75397 .05396 L
.75397 .04415 L
.72222 .04415 L
s
.72222 .05396 m
.72222 .06377 L
.75397 .06377 L
.75397 .05396 L
.72222 .05396 L
s
.72222 .06377 m
.72222 .07358 L
.75397 .07358 L
.75397 .06377 L
.72222 .06377 L
s
.72222 .07358 m
.72222 .08339 L
.75397 .08339 L
.75397 .07358 L
.72222 .07358 L
s
.72222 .08339 m
.72222 .0932 L
.75397 .0932 L
.75397 .08339 L
.72222 .08339 L
s
.72222 .0932 m
.72222 .10301 L
.75397 .10301 L
.75397 .0932 L
.72222 .0932 L
s
.72222 .10301 m
.72222 .11282 L
.75397 .11282 L
.75397 .10301 L
.72222 .10301 L
s
.72222 .11282 m
.72222 .12263 L
.75397 .12263 L
.75397 .11282 L
.72222 .11282 L
s
.72222 .12263 m
.72222 .13244 L
.75397 .13244 L
.75397 .12263 L
.72222 .12263 L
s
.72222 .13244 m
.72222 .14225 L
.75397 .14225 L
.75397 .13244 L
.72222 .13244 L
s
.72222 .14225 m
.72222 .15206 L
.75397 .15206 L
.75397 .14225 L
.72222 .14225 L
s
.72222 .15206 m
.72222 .16187 L
.75397 .16187 L
.75397 .15206 L
.72222 .15206 L
s
.72222 .16187 m
.72222 .17168 L
.75397 .17168 L
.75397 .16187 L
.72222 .16187 L
s
.72222 .17168 m
.72222 .18149 L
.75397 .18149 L
.75397 .17168 L
.72222 .17168 L
s
.72222 .18149 m
.72222 .1913 L
.75397 .1913 L
.75397 .18149 L
.72222 .18149 L
s
.72222 .1913 m
.72222 .20111 L
.75397 .20111 L
.75397 .1913 L
.72222 .1913 L
s
.72222 .20111 m
.72222 .21092 L
.75397 .21092 L
.75397 .20111 L
.72222 .20111 L
s
.72222 .21092 m
.72222 .22073 L
.75397 .22073 L
.75397 .21092 L
.72222 .21092 L
s
.72222 .22073 m
.72222 .23054 L
.75397 .23054 L
.75397 .22073 L
.72222 .22073 L
s
.72222 .23054 m
.72222 .24035 L
.75397 .24035 L
.75397 .23054 L
.72222 .23054 L
s
.72222 .24035 m
.72222 .25016 L
.75397 .25016 L
.75397 .24035 L
.72222 .24035 L
s
.72222 .25016 m
.72222 .25997 L
.75397 .25997 L
.75397 .25016 L
.72222 .25016 L
s
.72222 .25997 m
.72222 .26978 L
.75397 .26978 L
.75397 .25997 L
.72222 .25997 L
s
.72222 .26978 m
.72222 .27959 L
.75397 .27959 L
.75397 .26978 L
.72222 .26978 L
s
.72222 .27959 m
.72222 .2894 L
.75397 .2894 L
.75397 .27959 L
.72222 .27959 L
s
.72222 .2894 m
.72222 .29921 L
.75397 .29921 L
.75397 .2894 L
.72222 .2894 L
s
.72222 .29921 m
.72222 .30902 L
.75397 .30902 L
.75397 .29921 L
.72222 .29921 L
s
.72222 .30902 m
.72222 .31883 L
.75397 .31883 L
.75397 .30902 L
.72222 .30902 L
s
.72222 .31883 m
.72222 .32864 L
.75397 .32864 L
.75397 .31883 L
.72222 .31883 L
s
.72222 .32864 m
.72222 .33845 L
.75397 .33845 L
.75397 .32864 L
.72222 .32864 L
s
.72222 .33845 m
.72222 .34826 L
.75397 .34826 L
.75397 .33845 L
.72222 .33845 L
s
.72222 .34826 m
.72222 .35807 L
.75397 .35807 L
.75397 .34826 L
.72222 .34826 L
s
.72222 .35807 m
.72222 .36788 L
.75397 .36788 L
.75397 .35807 L
.72222 .35807 L
s
.72222 .36788 m
.72222 .37769 L
.75397 .37769 L
.75397 .36788 L
.72222 .36788 L
s
.72222 .37769 m
.72222 .3875 L
.75397 .3875 L
.75397 .37769 L
.72222 .37769 L
s
.72222 .3875 m
.72222 .39731 L
.75397 .39731 L
.75397 .3875 L
.72222 .3875 L
s
.72222 .39731 m
.72222 .40712 L
.75397 .40712 L
.75397 .39731 L
.72222 .39731 L
s
.72222 .40712 m
.72222 .41693 L
.75397 .41693 L
.75397 .40712 L
.72222 .40712 L
s
.72222 .41693 m
.72222 .42674 L
.75397 .42674 L
.75397 .41693 L
.72222 .41693 L
s
.72222 .42674 m
.72222 .43655 L
.75397 .43655 L
.75397 .42674 L
.72222 .42674 L
s
.72222 .43655 m
.72222 .44636 L
.75397 .44636 L
.75397 .43655 L
.72222 .43655 L
s
.72222 .44636 m
.72222 .45617 L
.75397 .45617 L
.75397 .44636 L
.72222 .44636 L
s
.72222 .45617 m
.72222 .46598 L
.75397 .46598 L
.75397 .45617 L
.72222 .45617 L
s
.72222 .46598 m
.72222 .47579 L
.75397 .47579 L
.75397 .46598 L
.72222 .46598 L
s
.72222 .47579 m
.72222 .4856 L
.75397 .4856 L
.75397 .47579 L
.72222 .47579 L
s
.72222 .4856 m
.72222 .49541 L
.75397 .49541 L
.75397 .4856 L
.72222 .4856 L
s
.72222 .49541 m
.72222 .50522 L
.75397 .50522 L
.75397 .49541 L
.72222 .49541 L
s
.72222 .50522 m
.72222 .51503 L
.75397 .51503 L
.75397 .50522 L
.72222 .50522 L
s
.72222 .51503 m
.72222 .52484 L
.75397 .52484 L
.75397 .51503 L
.72222 .51503 L
s
.72222 .52484 m
.72222 .53465 L
.75397 .53465 L
.75397 .52484 L
.72222 .52484 L
s
.72222 .53465 m
.72222 .54446 L
.75397 .54446 L
.75397 .53465 L
.72222 .53465 L
s
.72222 .54446 m
.72222 .55427 L
.75397 .55427 L
.75397 .54446 L
.72222 .54446 L
s
.72222 .55427 m
.72222 .56408 L
.75397 .56408 L
.75397 .55427 L
.72222 .55427 L
s
.72222 .56408 m
.72222 .57389 L
.75397 .57389 L
.75397 .56408 L
.72222 .56408 L
s
.72222 .57389 m
.72222 .5837 L
.75397 .5837 L
.75397 .57389 L
.72222 .57389 L
s
.72222 .5837 m
.72222 .59351 L
.75397 .59351 L
.75397 .5837 L
.72222 .5837 L
s
.72222 .59351 m
.72222 .60332 L
.75397 .60332 L
.75397 .59351 L
.72222 .59351 L
s
.75397 .01472 m
.75397 .02453 L
.78571 .02453 L
.78571 .01472 L
.75397 .01472 L
s
.75397 .02453 m
.75397 .03434 L
.78571 .03434 L
.78571 .02453 L
.75397 .02453 L
s
.75397 .03434 m
.75397 .04415 L
.78571 .04415 L
.78571 .03434 L
.75397 .03434 L
s
.75397 .04415 m
.75397 .05396 L
.78571 .05396 L
.78571 .04415 L
.75397 .04415 L
s
.75397 .05396 m
.75397 .06377 L
.78571 .06377 L
.78571 .05396 L
.75397 .05396 L
s
.75397 .06377 m
.75397 .07358 L
.78571 .07358 L
.78571 .06377 L
.75397 .06377 L
s
.75397 .07358 m
.75397 .08339 L
.78571 .08339 L
.78571 .07358 L
.75397 .07358 L
s
.75397 .08339 m
.75397 .0932 L
.78571 .0932 L
.78571 .08339 L
.75397 .08339 L
s
.75397 .0932 m
.75397 .10301 L
.78571 .10301 L
.78571 .0932 L
.75397 .0932 L
s
.75397 .10301 m
.75397 .11282 L
.78571 .11282 L
.78571 .10301 L
.75397 .10301 L
s
.75397 .11282 m
.75397 .12263 L
.78571 .12263 L
.78571 .11282 L
.75397 .11282 L
s
.75397 .12263 m
.75397 .13244 L
.78571 .13244 L
.78571 .12263 L
.75397 .12263 L
s
.75397 .13244 m
.75397 .14225 L
.78571 .14225 L
.78571 .13244 L
.75397 .13244 L
s
.75397 .14225 m
.75397 .15206 L
.78571 .15206 L
.78571 .14225 L
.75397 .14225 L
s
.75397 .15206 m
.75397 .16187 L
.78571 .16187 L
.78571 .15206 L
.75397 .15206 L
s
.75397 .16187 m
.75397 .17168 L
.78571 .17168 L
.78571 .16187 L
.75397 .16187 L
s
.75397 .17168 m
.75397 .18149 L
.78571 .18149 L
.78571 .17168 L
.75397 .17168 L
s
.75397 .18149 m
.75397 .1913 L
.78571 .1913 L
.78571 .18149 L
.75397 .18149 L
s
.75397 .1913 m
.75397 .20111 L
.78571 .20111 L
.78571 .1913 L
.75397 .1913 L
s
.75397 .20111 m
.75397 .21092 L
.78571 .21092 L
.78571 .20111 L
.75397 .20111 L
s
.75397 .21092 m
.75397 .22073 L
.78571 .22073 L
.78571 .21092 L
.75397 .21092 L
s
.75397 .22073 m
.75397 .23054 L
.78571 .23054 L
.78571 .22073 L
.75397 .22073 L
s
.75397 .23054 m
.75397 .24035 L
.78571 .24035 L
.78571 .23054 L
.75397 .23054 L
s
.75397 .24035 m
.75397 .25016 L
.78571 .25016 L
.78571 .24035 L
.75397 .24035 L
s
.75397 .25016 m
.75397 .25997 L
.78571 .25997 L
.78571 .25016 L
.75397 .25016 L
s
.75397 .25997 m
.75397 .26978 L
.78571 .26978 L
.78571 .25997 L
.75397 .25997 L
s
.75397 .26978 m
.75397 .27959 L
.78571 .27959 L
.78571 .26978 L
.75397 .26978 L
s
.75397 .27959 m
.75397 .2894 L
.78571 .2894 L
.78571 .27959 L
.75397 .27959 L
s
.75397 .2894 m
.75397 .29921 L
.78571 .29921 L
.78571 .2894 L
.75397 .2894 L
s
.75397 .29921 m
.75397 .30902 L
.78571 .30902 L
.78571 .29921 L
.75397 .29921 L
s
.75397 .30902 m
.75397 .31883 L
.78571 .31883 L
.78571 .30902 L
.75397 .30902 L
s
.75397 .31883 m
.75397 .32864 L
.78571 .32864 L
.78571 .31883 L
.75397 .31883 L
s
.75397 .32864 m
.75397 .33845 L
.78571 .33845 L
.78571 .32864 L
.75397 .32864 L
s
.75397 .33845 m
.75397 .34826 L
.78571 .34826 L
.78571 .33845 L
.75397 .33845 L
s
.75397 .34826 m
.75397 .35807 L
.78571 .35807 L
.78571 .34826 L
.75397 .34826 L
s
.75397 .35807 m
.75397 .36788 L
.78571 .36788 L
.78571 .35807 L
.75397 .35807 L
s
.75397 .36788 m
.75397 .37769 L
.78571 .37769 L
.78571 .36788 L
.75397 .36788 L
s
.75397 .37769 m
.75397 .3875 L
.78571 .3875 L
.78571 .37769 L
.75397 .37769 L
s
.75397 .3875 m
.75397 .39731 L
.78571 .39731 L
.78571 .3875 L
.75397 .3875 L
s
.75397 .39731 m
.75397 .40712 L
.78571 .40712 L
.78571 .39731 L
.75397 .39731 L
s
.75397 .40712 m
.75397 .41693 L
.78571 .41693 L
.78571 .40712 L
.75397 .40712 L
s
.75397 .41693 m
.75397 .42674 L
.78571 .42674 L
.78571 .41693 L
.75397 .41693 L
s
.75397 .42674 m
.75397 .43655 L
.78571 .43655 L
.78571 .42674 L
.75397 .42674 L
s
.75397 .43655 m
.75397 .44636 L
.78571 .44636 L
.78571 .43655 L
.75397 .43655 L
s
.75397 .44636 m
.75397 .45617 L
.78571 .45617 L
.78571 .44636 L
.75397 .44636 L
s
.75397 .45617 m
.75397 .46598 L
.78571 .46598 L
.78571 .45617 L
.75397 .45617 L
s
.75397 .46598 m
.75397 .47579 L
.78571 .47579 L
.78571 .46598 L
.75397 .46598 L
s
.75397 .47579 m
.75397 .4856 L
.78571 .4856 L
.78571 .47579 L
.75397 .47579 L
s
.75397 .4856 m
.75397 .49541 L
.78571 .49541 L
.78571 .4856 L
.75397 .4856 L
s
.75397 .49541 m
.75397 .50522 L
.78571 .50522 L
.78571 .49541 L
.75397 .49541 L
s
.75397 .50522 m
.75397 .51503 L
.78571 .51503 L
.78571 .50522 L
.75397 .50522 L
s
.75397 .51503 m
.75397 .52484 L
.78571 .52484 L
.78571 .51503 L
.75397 .51503 L
s
.75397 .52484 m
.75397 .53465 L
.78571 .53465 L
.78571 .52484 L
.75397 .52484 L
s
.75397 .53465 m
.75397 .54446 L
.78571 .54446 L
.78571 .53465 L
.75397 .53465 L
s
.75397 .54446 m
.75397 .55427 L
.78571 .55427 L
.78571 .54446 L
.75397 .54446 L
s
.75397 .55427 m
.75397 .56408 L
.78571 .56408 L
.78571 .55427 L
.75397 .55427 L
s
.75397 .56408 m
.75397 .57389 L
.78571 .57389 L
.78571 .56408 L
.75397 .56408 L
s
.75397 .57389 m
.75397 .5837 L
.78571 .5837 L
.78571 .57389 L
.75397 .57389 L
s
.75397 .5837 m
.75397 .59351 L
.78571 .59351 L
.78571 .5837 L
.75397 .5837 L
s
.75397 .59351 m
.75397 .60332 L
.78571 .60332 L
.78571 .59351 L
.75397 .59351 L
s
.78571 .01472 m
.78571 .02453 L
.81746 .02453 L
.81746 .01472 L
.78571 .01472 L
s
.78571 .02453 m
.78571 .03434 L
.81746 .03434 L
.81746 .02453 L
.78571 .02453 L
s
.78571 .03434 m
.78571 .04415 L
.81746 .04415 L
.81746 .03434 L
.78571 .03434 L
s
.78571 .04415 m
.78571 .05396 L
.81746 .05396 L
.81746 .04415 L
.78571 .04415 L
s
.78571 .05396 m
.78571 .06377 L
.81746 .06377 L
.81746 .05396 L
.78571 .05396 L
s
.78571 .06377 m
.78571 .07358 L
.81746 .07358 L
.81746 .06377 L
.78571 .06377 L
s
.78571 .07358 m
.78571 .08339 L
.81746 .08339 L
.81746 .07358 L
.78571 .07358 L
s
.78571 .08339 m
.78571 .0932 L
.81746 .0932 L
.81746 .08339 L
.78571 .08339 L
s
.78571 .0932 m
.78571 .10301 L
.81746 .10301 L
.81746 .0932 L
.78571 .0932 L
s
.78571 .10301 m
.78571 .11282 L
.81746 .11282 L
.81746 .10301 L
.78571 .10301 L
s
.78571 .11282 m
.78571 .12263 L
.81746 .12263 L
.81746 .11282 L
.78571 .11282 L
s
.78571 .12263 m
.78571 .13244 L
.81746 .13244 L
.81746 .12263 L
.78571 .12263 L
s
.78571 .13244 m
.78571 .14225 L
.81746 .14225 L
.81746 .13244 L
.78571 .13244 L
s
.78571 .14225 m
.78571 .15206 L
.81746 .15206 L
.81746 .14225 L
.78571 .14225 L
s
.78571 .15206 m
.78571 .16187 L
.81746 .16187 L
.81746 .15206 L
.78571 .15206 L
s
.78571 .16187 m
.78571 .17168 L
.81746 .17168 L
.81746 .16187 L
.78571 .16187 L
s
.78571 .17168 m
.78571 .18149 L
.81746 .18149 L
.81746 .17168 L
.78571 .17168 L
s
.78571 .18149 m
.78571 .1913 L
.81746 .1913 L
.81746 .18149 L
.78571 .18149 L
s
.78571 .1913 m
.78571 .20111 L
.81746 .20111 L
.81746 .1913 L
.78571 .1913 L
s
.78571 .20111 m
.78571 .21092 L
.81746 .21092 L
.81746 .20111 L
.78571 .20111 L
s
.78571 .21092 m
.78571 .22073 L
.81746 .22073 L
.81746 .21092 L
.78571 .21092 L
s
.78571 .22073 m
.78571 .23054 L
.81746 .23054 L
.81746 .22073 L
.78571 .22073 L
s
.78571 .23054 m
.78571 .24035 L
.81746 .24035 L
.81746 .23054 L
.78571 .23054 L
s
.78571 .24035 m
.78571 .25016 L
.81746 .25016 L
.81746 .24035 L
.78571 .24035 L
s
.78571 .25016 m
.78571 .25997 L
.81746 .25997 L
.81746 .25016 L
.78571 .25016 L
s
.78571 .25997 m
.78571 .26978 L
.81746 .26978 L
.81746 .25997 L
.78571 .25997 L
s
.78571 .26978 m
.78571 .27959 L
.81746 .27959 L
.81746 .26978 L
.78571 .26978 L
s
.78571 .27959 m
.78571 .2894 L
.81746 .2894 L
.81746 .27959 L
.78571 .27959 L
s
.78571 .2894 m
.78571 .29921 L
.81746 .29921 L
.81746 .2894 L
.78571 .2894 L
s
.78571 .29921 m
.78571 .30902 L
.81746 .30902 L
.81746 .29921 L
.78571 .29921 L
s
.78571 .30902 m
.78571 .31883 L
.81746 .31883 L
.81746 .30902 L
.78571 .30902 L
s
.78571 .31883 m
.78571 .32864 L
.81746 .32864 L
.81746 .31883 L
.78571 .31883 L
s
.78571 .32864 m
.78571 .33845 L
.81746 .33845 L
.81746 .32864 L
.78571 .32864 L
s
.78571 .33845 m
.78571 .34826 L
.81746 .34826 L
.81746 .33845 L
.78571 .33845 L
s
.78571 .34826 m
.78571 .35807 L
.81746 .35807 L
.81746 .34826 L
.78571 .34826 L
s
.78571 .35807 m
.78571 .36788 L
.81746 .36788 L
.81746 .35807 L
.78571 .35807 L
s
.78571 .36788 m
.78571 .37769 L
.81746 .37769 L
.81746 .36788 L
.78571 .36788 L
s
.78571 .37769 m
.78571 .3875 L
.81746 .3875 L
.81746 .37769 L
.78571 .37769 L
s
.78571 .3875 m
.78571 .39731 L
.81746 .39731 L
.81746 .3875 L
.78571 .3875 L
s
.78571 .39731 m
.78571 .40712 L
.81746 .40712 L
.81746 .39731 L
.78571 .39731 L
s
.78571 .40712 m
.78571 .41693 L
.81746 .41693 L
.81746 .40712 L
.78571 .40712 L
s
.78571 .41693 m
.78571 .42674 L
.81746 .42674 L
.81746 .41693 L
.78571 .41693 L
s
.78571 .42674 m
.78571 .43655 L
.81746 .43655 L
.81746 .42674 L
.78571 .42674 L
s
.78571 .43655 m
.78571 .44636 L
.81746 .44636 L
.81746 .43655 L
.78571 .43655 L
s
.78571 .44636 m
.78571 .45617 L
.81746 .45617 L
.81746 .44636 L
.78571 .44636 L
s
.78571 .45617 m
.78571 .46598 L
.81746 .46598 L
.81746 .45617 L
.78571 .45617 L
s
.78571 .46598 m
.78571 .47579 L
.81746 .47579 L
.81746 .46598 L
.78571 .46598 L
s
.78571 .47579 m
.78571 .4856 L
.81746 .4856 L
.81746 .47579 L
.78571 .47579 L
s
.78571 .4856 m
.78571 .49541 L
.81746 .49541 L
.81746 .4856 L
.78571 .4856 L
s
.78571 .49541 m
.78571 .50522 L
.81746 .50522 L
.81746 .49541 L
.78571 .49541 L
s
.78571 .50522 m
.78571 .51503 L
.81746 .51503 L
.81746 .50522 L
.78571 .50522 L
s
.78571 .51503 m
.78571 .52484 L
.81746 .52484 L
.81746 .51503 L
.78571 .51503 L
s
.78571 .52484 m
.78571 .53465 L
.81746 .53465 L
.81746 .52484 L
.78571 .52484 L
s
.78571 .53465 m
.78571 .54446 L
.81746 .54446 L
.81746 .53465 L
.78571 .53465 L
s
.78571 .54446 m
.78571 .55427 L
.81746 .55427 L
.81746 .54446 L
.78571 .54446 L
s
.78571 .55427 m
.78571 .56408 L
.81746 .56408 L
.81746 .55427 L
.78571 .55427 L
s
.78571 .56408 m
.78571 .57389 L
.81746 .57389 L
.81746 .56408 L
.78571 .56408 L
s
.78571 .57389 m
.78571 .5837 L
.81746 .5837 L
.81746 .57389 L
.78571 .57389 L
s
.78571 .5837 m
.78571 .59351 L
.81746 .59351 L
.81746 .5837 L
.78571 .5837 L
s
.78571 .59351 m
.78571 .60332 L
.81746 .60332 L
.81746 .59351 L
.78571 .59351 L
s
.81746 .01472 m
.81746 .02453 L
.84921 .02453 L
.84921 .01472 L
.81746 .01472 L
s
.81746 .02453 m
.81746 .03434 L
.84921 .03434 L
.84921 .02453 L
.81746 .02453 L
s
.81746 .03434 m
.81746 .04415 L
.84921 .04415 L
.84921 .03434 L
.81746 .03434 L
s
.81746 .04415 m
.81746 .05396 L
.84921 .05396 L
.84921 .04415 L
.81746 .04415 L
s
.81746 .05396 m
.81746 .06377 L
.84921 .06377 L
.84921 .05396 L
.81746 .05396 L
s
.81746 .06377 m
.81746 .07358 L
.84921 .07358 L
.84921 .06377 L
.81746 .06377 L
s
.81746 .07358 m
.81746 .08339 L
.84921 .08339 L
.84921 .07358 L
.81746 .07358 L
s
.81746 .08339 m
.81746 .0932 L
.84921 .0932 L
.84921 .08339 L
.81746 .08339 L
s
.81746 .0932 m
.81746 .10301 L
.84921 .10301 L
.84921 .0932 L
.81746 .0932 L
s
.81746 .10301 m
.81746 .11282 L
.84921 .11282 L
.84921 .10301 L
.81746 .10301 L
s
.81746 .11282 m
.81746 .12263 L
.84921 .12263 L
.84921 .11282 L
.81746 .11282 L
s
.81746 .12263 m
.81746 .13244 L
.84921 .13244 L
.84921 .12263 L
.81746 .12263 L
s
.81746 .13244 m
.81746 .14225 L
.84921 .14225 L
.84921 .13244 L
.81746 .13244 L
s
.81746 .14225 m
.81746 .15206 L
.84921 .15206 L
.84921 .14225 L
.81746 .14225 L
s
.81746 .15206 m
.81746 .16187 L
.84921 .16187 L
.84921 .15206 L
.81746 .15206 L
s
.81746 .16187 m
.81746 .17168 L
.84921 .17168 L
.84921 .16187 L
.81746 .16187 L
s
.81746 .17168 m
.81746 .18149 L
.84921 .18149 L
.84921 .17168 L
.81746 .17168 L
s
.81746 .18149 m
.81746 .1913 L
.84921 .1913 L
.84921 .18149 L
.81746 .18149 L
s
.81746 .1913 m
.81746 .20111 L
.84921 .20111 L
.84921 .1913 L
.81746 .1913 L
s
.81746 .20111 m
.81746 .21092 L
.84921 .21092 L
.84921 .20111 L
.81746 .20111 L
s
.81746 .21092 m
.81746 .22073 L
.84921 .22073 L
.84921 .21092 L
.81746 .21092 L
s
.81746 .22073 m
.81746 .23054 L
.84921 .23054 L
.84921 .22073 L
.81746 .22073 L
s
.81746 .23054 m
.81746 .24035 L
.84921 .24035 L
.84921 .23054 L
.81746 .23054 L
s
.81746 .24035 m
.81746 .25016 L
.84921 .25016 L
.84921 .24035 L
.81746 .24035 L
s
.81746 .25016 m
.81746 .25997 L
.84921 .25997 L
.84921 .25016 L
.81746 .25016 L
s
.81746 .25997 m
.81746 .26978 L
.84921 .26978 L
.84921 .25997 L
.81746 .25997 L
s
.81746 .26978 m
.81746 .27959 L
.84921 .27959 L
.84921 .26978 L
.81746 .26978 L
s
.81746 .27959 m
.81746 .2894 L
.84921 .2894 L
.84921 .27959 L
.81746 .27959 L
s
.81746 .2894 m
.81746 .29921 L
.84921 .29921 L
.84921 .2894 L
.81746 .2894 L
s
.81746 .29921 m
.81746 .30902 L
.84921 .30902 L
.84921 .29921 L
.81746 .29921 L
s
.81746 .30902 m
.81746 .31883 L
.84921 .31883 L
.84921 .30902 L
.81746 .30902 L
s
.81746 .31883 m
.81746 .32864 L
.84921 .32864 L
.84921 .31883 L
.81746 .31883 L
s
.81746 .32864 m
.81746 .33845 L
.84921 .33845 L
.84921 .32864 L
.81746 .32864 L
s
.81746 .33845 m
.81746 .34826 L
.84921 .34826 L
.84921 .33845 L
.81746 .33845 L
s
.81746 .34826 m
.81746 .35807 L
.84921 .35807 L
.84921 .34826 L
.81746 .34826 L
s
.81746 .35807 m
.81746 .36788 L
.84921 .36788 L
.84921 .35807 L
.81746 .35807 L
s
.81746 .36788 m
.81746 .37769 L
.84921 .37769 L
.84921 .36788 L
.81746 .36788 L
s
.81746 .37769 m
.81746 .3875 L
.84921 .3875 L
.84921 .37769 L
.81746 .37769 L
s
.81746 .3875 m
.81746 .39731 L
.84921 .39731 L
.84921 .3875 L
.81746 .3875 L
s
.81746 .39731 m
.81746 .40712 L
.84921 .40712 L
.84921 .39731 L
.81746 .39731 L
s
.81746 .40712 m
.81746 .41693 L
.84921 .41693 L
.84921 .40712 L
.81746 .40712 L
s
.81746 .41693 m
.81746 .42674 L
.84921 .42674 L
.84921 .41693 L
.81746 .41693 L
s
.81746 .42674 m
.81746 .43655 L
.84921 .43655 L
.84921 .42674 L
.81746 .42674 L
s
.81746 .43655 m
.81746 .44636 L
.84921 .44636 L
.84921 .43655 L
.81746 .43655 L
s
.81746 .44636 m
.81746 .45617 L
.84921 .45617 L
.84921 .44636 L
.81746 .44636 L
s
.81746 .45617 m
.81746 .46598 L
.84921 .46598 L
.84921 .45617 L
.81746 .45617 L
s
.81746 .46598 m
.81746 .47579 L
.84921 .47579 L
.84921 .46598 L
.81746 .46598 L
s
.81746 .47579 m
.81746 .4856 L
.84921 .4856 L
.84921 .47579 L
.81746 .47579 L
s
.81746 .4856 m
.81746 .49541 L
.84921 .49541 L
.84921 .4856 L
.81746 .4856 L
s
.81746 .49541 m
.81746 .50522 L
.84921 .50522 L
.84921 .49541 L
.81746 .49541 L
s
.81746 .50522 m
.81746 .51503 L
.84921 .51503 L
.84921 .50522 L
.81746 .50522 L
s
.81746 .51503 m
.81746 .52484 L
.84921 .52484 L
.84921 .51503 L
.81746 .51503 L
s
.81746 .52484 m
.81746 .53465 L
.84921 .53465 L
.84921 .52484 L
.81746 .52484 L
s
.81746 .53465 m
.81746 .54446 L
.84921 .54446 L
.84921 .53465 L
.81746 .53465 L
s
.81746 .54446 m
.81746 .55427 L
.84921 .55427 L
.84921 .54446 L
.81746 .54446 L
s
.81746 .55427 m
.81746 .56408 L
.84921 .56408 L
.84921 .55427 L
.81746 .55427 L
s
.81746 .56408 m
.81746 .57389 L
.84921 .57389 L
.84921 .56408 L
.81746 .56408 L
s
.81746 .57389 m
.81746 .5837 L
.84921 .5837 L
.84921 .57389 L
.81746 .57389 L
s
.81746 .5837 m
.81746 .59351 L
.84921 .59351 L
.84921 .5837 L
.81746 .5837 L
s
.81746 .59351 m
.81746 .60332 L
.84921 .60332 L
.84921 .59351 L
.81746 .59351 L
s
.84921 .01472 m
.84921 .02453 L
.88095 .02453 L
.88095 .01472 L
.84921 .01472 L
s
.84921 .02453 m
.84921 .03434 L
.88095 .03434 L
.88095 .02453 L
.84921 .02453 L
s
.84921 .03434 m
.84921 .04415 L
.88095 .04415 L
.88095 .03434 L
.84921 .03434 L
s
.84921 .04415 m
.84921 .05396 L
.88095 .05396 L
.88095 .04415 L
.84921 .04415 L
s
.84921 .05396 m
.84921 .06377 L
.88095 .06377 L
.88095 .05396 L
.84921 .05396 L
s
.84921 .06377 m
.84921 .07358 L
.88095 .07358 L
.88095 .06377 L
.84921 .06377 L
s
.84921 .07358 m
.84921 .08339 L
.88095 .08339 L
.88095 .07358 L
.84921 .07358 L
s
.84921 .08339 m
.84921 .0932 L
.88095 .0932 L
.88095 .08339 L
.84921 .08339 L
s
.84921 .0932 m
.84921 .10301 L
.88095 .10301 L
.88095 .0932 L
.84921 .0932 L
s
.84921 .10301 m
.84921 .11282 L
.88095 .11282 L
.88095 .10301 L
.84921 .10301 L
s
.84921 .11282 m
.84921 .12263 L
.88095 .12263 L
.88095 .11282 L
.84921 .11282 L
s
.84921 .12263 m
.84921 .13244 L
.88095 .13244 L
.88095 .12263 L
.84921 .12263 L
s
.84921 .13244 m
.84921 .14225 L
.88095 .14225 L
.88095 .13244 L
.84921 .13244 L
s
.84921 .14225 m
.84921 .15206 L
.88095 .15206 L
.88095 .14225 L
.84921 .14225 L
s
.84921 .15206 m
.84921 .16187 L
.88095 .16187 L
.88095 .15206 L
.84921 .15206 L
s
.84921 .16187 m
.84921 .17168 L
.88095 .17168 L
.88095 .16187 L
.84921 .16187 L
s
.84921 .17168 m
.84921 .18149 L
.88095 .18149 L
.88095 .17168 L
.84921 .17168 L
s
.84921 .18149 m
.84921 .1913 L
.88095 .1913 L
.88095 .18149 L
.84921 .18149 L
s
.84921 .1913 m
.84921 .20111 L
.88095 .20111 L
.88095 .1913 L
.84921 .1913 L
s
.84921 .20111 m
.84921 .21092 L
.88095 .21092 L
.88095 .20111 L
.84921 .20111 L
s
.84921 .21092 m
.84921 .22073 L
.88095 .22073 L
.88095 .21092 L
.84921 .21092 L
s
.84921 .22073 m
.84921 .23054 L
.88095 .23054 L
.88095 .22073 L
.84921 .22073 L
s
.84921 .23054 m
.84921 .24035 L
.88095 .24035 L
.88095 .23054 L
.84921 .23054 L
s
.84921 .24035 m
.84921 .25016 L
.88095 .25016 L
.88095 .24035 L
.84921 .24035 L
s
.84921 .25016 m
.84921 .25997 L
.88095 .25997 L
.88095 .25016 L
.84921 .25016 L
s
.84921 .25997 m
.84921 .26978 L
.88095 .26978 L
.88095 .25997 L
.84921 .25997 L
s
.84921 .26978 m
.84921 .27959 L
.88095 .27959 L
.88095 .26978 L
.84921 .26978 L
s
.84921 .27959 m
.84921 .2894 L
.88095 .2894 L
.88095 .27959 L
.84921 .27959 L
s
.84921 .2894 m
.84921 .29921 L
.88095 .29921 L
.88095 .2894 L
.84921 .2894 L
s
.84921 .29921 m
.84921 .30902 L
.88095 .30902 L
.88095 .29921 L
.84921 .29921 L
s
.84921 .30902 m
.84921 .31883 L
.88095 .31883 L
.88095 .30902 L
.84921 .30902 L
s
.84921 .31883 m
.84921 .32864 L
.88095 .32864 L
.88095 .31883 L
.84921 .31883 L
s
.84921 .32864 m
.84921 .33845 L
.88095 .33845 L
.88095 .32864 L
.84921 .32864 L
s
.84921 .33845 m
.84921 .34826 L
.88095 .34826 L
.88095 .33845 L
.84921 .33845 L
s
.84921 .34826 m
.84921 .35807 L
.88095 .35807 L
.88095 .34826 L
.84921 .34826 L
s
.84921 .35807 m
.84921 .36788 L
.88095 .36788 L
.88095 .35807 L
.84921 .35807 L
s
.84921 .36788 m
.84921 .37769 L
.88095 .37769 L
.88095 .36788 L
.84921 .36788 L
s
.84921 .37769 m
.84921 .3875 L
.88095 .3875 L
.88095 .37769 L
.84921 .37769 L
s
.84921 .3875 m
.84921 .39731 L
.88095 .39731 L
.88095 .3875 L
.84921 .3875 L
s
.84921 .39731 m
.84921 .40712 L
.88095 .40712 L
.88095 .39731 L
.84921 .39731 L
s
.84921 .40712 m
.84921 .41693 L
.88095 .41693 L
.88095 .40712 L
.84921 .40712 L
s
.84921 .41693 m
.84921 .42674 L
.88095 .42674 L
.88095 .41693 L
.84921 .41693 L
s
.84921 .42674 m
.84921 .43655 L
.88095 .43655 L
.88095 .42674 L
.84921 .42674 L
s
.84921 .43655 m
.84921 .44636 L
.88095 .44636 L
.88095 .43655 L
.84921 .43655 L
s
.84921 .44636 m
.84921 .45617 L
.88095 .45617 L
.88095 .44636 L
.84921 .44636 L
s
.84921 .45617 m
.84921 .46598 L
.88095 .46598 L
.88095 .45617 L
.84921 .45617 L
s
.84921 .46598 m
.84921 .47579 L
.88095 .47579 L
.88095 .46598 L
.84921 .46598 L
s
.84921 .47579 m
.84921 .4856 L
.88095 .4856 L
.88095 .47579 L
.84921 .47579 L
s
.84921 .4856 m
.84921 .49541 L
.88095 .49541 L
.88095 .4856 L
.84921 .4856 L
s
.84921 .49541 m
.84921 .50522 L
.88095 .50522 L
.88095 .49541 L
.84921 .49541 L
s
.84921 .50522 m
.84921 .51503 L
.88095 .51503 L
.88095 .50522 L
.84921 .50522 L
s
.84921 .51503 m
.84921 .52484 L
.88095 .52484 L
.88095 .51503 L
.84921 .51503 L
s
.84921 .52484 m
.84921 .53465 L
.88095 .53465 L
.88095 .52484 L
.84921 .52484 L
s
.84921 .53465 m
.84921 .54446 L
.88095 .54446 L
.88095 .53465 L
.84921 .53465 L
s
.84921 .54446 m
.84921 .55427 L
.88095 .55427 L
.88095 .54446 L
.84921 .54446 L
s
.84921 .55427 m
.84921 .56408 L
.88095 .56408 L
.88095 .55427 L
.84921 .55427 L
s
.84921 .56408 m
.84921 .57389 L
.88095 .57389 L
.88095 .56408 L
.84921 .56408 L
s
.84921 .57389 m
.84921 .5837 L
.88095 .5837 L
.88095 .57389 L
.84921 .57389 L
s
.84921 .5837 m
.84921 .59351 L
.88095 .59351 L
.88095 .5837 L
.84921 .5837 L
s
.84921 .59351 m
.84921 .60332 L
.88095 .60332 L
.88095 .59351 L
.84921 .59351 L
s
.88095 .01472 m
.88095 .02453 L
.9127 .02453 L
.9127 .01472 L
.88095 .01472 L
s
.88095 .02453 m
.88095 .03434 L
.9127 .03434 L
.9127 .02453 L
.88095 .02453 L
s
.88095 .03434 m
.88095 .04415 L
.9127 .04415 L
.9127 .03434 L
.88095 .03434 L
s
.88095 .04415 m
.88095 .05396 L
.9127 .05396 L
.9127 .04415 L
.88095 .04415 L
s
.88095 .05396 m
.88095 .06377 L
.9127 .06377 L
.9127 .05396 L
.88095 .05396 L
s
.88095 .06377 m
.88095 .07358 L
.9127 .07358 L
.9127 .06377 L
.88095 .06377 L
s
.88095 .07358 m
.88095 .08339 L
.9127 .08339 L
.9127 .07358 L
.88095 .07358 L
s
.88095 .08339 m
.88095 .0932 L
.9127 .0932 L
.9127 .08339 L
.88095 .08339 L
s
.88095 .0932 m
.88095 .10301 L
.9127 .10301 L
.9127 .0932 L
.88095 .0932 L
s
.88095 .10301 m
.88095 .11282 L
.9127 .11282 L
.9127 .10301 L
.88095 .10301 L
s
.88095 .11282 m
.88095 .12263 L
.9127 .12263 L
.9127 .11282 L
.88095 .11282 L
s
.88095 .12263 m
.88095 .13244 L
.9127 .13244 L
.9127 .12263 L
.88095 .12263 L
s
.88095 .13244 m
.88095 .14225 L
.9127 .14225 L
.9127 .13244 L
.88095 .13244 L
s
.88095 .14225 m
.88095 .15206 L
.9127 .15206 L
.9127 .14225 L
.88095 .14225 L
s
.88095 .15206 m
.88095 .16187 L
.9127 .16187 L
.9127 .15206 L
.88095 .15206 L
s
.88095 .16187 m
.88095 .17168 L
.9127 .17168 L
.9127 .16187 L
.88095 .16187 L
s
.88095 .17168 m
.88095 .18149 L
.9127 .18149 L
.9127 .17168 L
.88095 .17168 L
s
.88095 .18149 m
.88095 .1913 L
.9127 .1913 L
.9127 .18149 L
.88095 .18149 L
s
.88095 .1913 m
.88095 .20111 L
.9127 .20111 L
.9127 .1913 L
.88095 .1913 L
s
.88095 .20111 m
.88095 .21092 L
.9127 .21092 L
.9127 .20111 L
.88095 .20111 L
s
.88095 .21092 m
.88095 .22073 L
.9127 .22073 L
.9127 .21092 L
.88095 .21092 L
s
.88095 .22073 m
.88095 .23054 L
.9127 .23054 L
.9127 .22073 L
.88095 .22073 L
s
.88095 .23054 m
.88095 .24035 L
.9127 .24035 L
.9127 .23054 L
.88095 .23054 L
s
.88095 .24035 m
.88095 .25016 L
.9127 .25016 L
.9127 .24035 L
.88095 .24035 L
s
.88095 .25016 m
.88095 .25997 L
.9127 .25997 L
.9127 .25016 L
.88095 .25016 L
s
.88095 .25997 m
.88095 .26978 L
.9127 .26978 L
.9127 .25997 L
.88095 .25997 L
s
.88095 .26978 m
.88095 .27959 L
.9127 .27959 L
.9127 .26978 L
.88095 .26978 L
s
.88095 .27959 m
.88095 .2894 L
.9127 .2894 L
.9127 .27959 L
.88095 .27959 L
s
.88095 .2894 m
.88095 .29921 L
.9127 .29921 L
.9127 .2894 L
.88095 .2894 L
s
.88095 .29921 m
.88095 .30902 L
.9127 .30902 L
.9127 .29921 L
.88095 .29921 L
s
.88095 .30902 m
.88095 .31883 L
.9127 .31883 L
.9127 .30902 L
.88095 .30902 L
s
.88095 .31883 m
.88095 .32864 L
.9127 .32864 L
.9127 .31883 L
.88095 .31883 L
s
.88095 .32864 m
.88095 .33845 L
.9127 .33845 L
.9127 .32864 L
.88095 .32864 L
s
.88095 .33845 m
.88095 .34826 L
.9127 .34826 L
.9127 .33845 L
.88095 .33845 L
s
.88095 .34826 m
.88095 .35807 L
.9127 .35807 L
.9127 .34826 L
.88095 .34826 L
s
.88095 .35807 m
.88095 .36788 L
.9127 .36788 L
.9127 .35807 L
.88095 .35807 L
s
.88095 .36788 m
.88095 .37769 L
.9127 .37769 L
.9127 .36788 L
.88095 .36788 L
s
.88095 .37769 m
.88095 .3875 L
.9127 .3875 L
.9127 .37769 L
.88095 .37769 L
s
.88095 .3875 m
.88095 .39731 L
.9127 .39731 L
.9127 .3875 L
.88095 .3875 L
s
.88095 .39731 m
.88095 .40712 L
.9127 .40712 L
.9127 .39731 L
.88095 .39731 L
s
.88095 .40712 m
.88095 .41693 L
.9127 .41693 L
.9127 .40712 L
.88095 .40712 L
s
.88095 .41693 m
.88095 .42674 L
.9127 .42674 L
.9127 .41693 L
.88095 .41693 L
s
.88095 .42674 m
.88095 .43655 L
.9127 .43655 L
.9127 .42674 L
.88095 .42674 L
s
.88095 .43655 m
.88095 .44636 L
.9127 .44636 L
.9127 .43655 L
.88095 .43655 L
s
.88095 .44636 m
.88095 .45617 L
.9127 .45617 L
.9127 .44636 L
.88095 .44636 L
s
.88095 .45617 m
.88095 .46598 L
.9127 .46598 L
.9127 .45617 L
.88095 .45617 L
s
.88095 .46598 m
.88095 .47579 L
.9127 .47579 L
.9127 .46598 L
.88095 .46598 L
s
.88095 .47579 m
.88095 .4856 L
.9127 .4856 L
.9127 .47579 L
.88095 .47579 L
s
.88095 .4856 m
.88095 .49541 L
.9127 .49541 L
.9127 .4856 L
.88095 .4856 L
s
.88095 .49541 m
.88095 .50522 L
.9127 .50522 L
.9127 .49541 L
.88095 .49541 L
s
.88095 .50522 m
.88095 .51503 L
.9127 .51503 L
.9127 .50522 L
.88095 .50522 L
s
.88095 .51503 m
.88095 .52484 L
.9127 .52484 L
.9127 .51503 L
.88095 .51503 L
s
.88095 .52484 m
.88095 .53465 L
.9127 .53465 L
.9127 .52484 L
.88095 .52484 L
s
.88095 .53465 m
.88095 .54446 L
.9127 .54446 L
.9127 .53465 L
.88095 .53465 L
s
.88095 .54446 m
.88095 .55427 L
.9127 .55427 L
.9127 .54446 L
.88095 .54446 L
s
.88095 .55427 m
.88095 .56408 L
.9127 .56408 L
.9127 .55427 L
.88095 .55427 L
s
.88095 .56408 m
.88095 .57389 L
.9127 .57389 L
.9127 .56408 L
.88095 .56408 L
s
.88095 .57389 m
.88095 .5837 L
.9127 .5837 L
.9127 .57389 L
.88095 .57389 L
s
.88095 .5837 m
.88095 .59351 L
.9127 .59351 L
.9127 .5837 L
.88095 .5837 L
s
.88095 .59351 m
.88095 .60332 L
.9127 .60332 L
.9127 .59351 L
.88095 .59351 L
s
.9127 .01472 m
.9127 .02453 L
.94444 .02453 L
.94444 .01472 L
.9127 .01472 L
s
.9127 .02453 m
.9127 .03434 L
.94444 .03434 L
.94444 .02453 L
.9127 .02453 L
s
.9127 .03434 m
.9127 .04415 L
.94444 .04415 L
.94444 .03434 L
.9127 .03434 L
s
.9127 .04415 m
.9127 .05396 L
.94444 .05396 L
.94444 .04415 L
.9127 .04415 L
s
.9127 .05396 m
.9127 .06377 L
.94444 .06377 L
.94444 .05396 L
.9127 .05396 L
s
.9127 .06377 m
.9127 .07358 L
.94444 .07358 L
.94444 .06377 L
.9127 .06377 L
s
.9127 .07358 m
.9127 .08339 L
.94444 .08339 L
.94444 .07358 L
.9127 .07358 L
s
.9127 .08339 m
.9127 .0932 L
.94444 .0932 L
.94444 .08339 L
.9127 .08339 L
s
.9127 .0932 m
.9127 .10301 L
.94444 .10301 L
.94444 .0932 L
.9127 .0932 L
s
.9127 .10301 m
.9127 .11282 L
.94444 .11282 L
.94444 .10301 L
.9127 .10301 L
s
.9127 .11282 m
.9127 .12263 L
.94444 .12263 L
.94444 .11282 L
.9127 .11282 L
s
.9127 .12263 m
.9127 .13244 L
.94444 .13244 L
.94444 .12263 L
.9127 .12263 L
s
.9127 .13244 m
.9127 .14225 L
.94444 .14225 L
.94444 .13244 L
.9127 .13244 L
s
.9127 .14225 m
.9127 .15206 L
.94444 .15206 L
.94444 .14225 L
.9127 .14225 L
s
.9127 .15206 m
.9127 .16187 L
.94444 .16187 L
.94444 .15206 L
.9127 .15206 L
s
.9127 .16187 m
.9127 .17168 L
.94444 .17168 L
.94444 .16187 L
.9127 .16187 L
s
.9127 .17168 m
.9127 .18149 L
.94444 .18149 L
.94444 .17168 L
.9127 .17168 L
s
.9127 .18149 m
.9127 .1913 L
.94444 .1913 L
.94444 .18149 L
.9127 .18149 L
s
.9127 .1913 m
.9127 .20111 L
.94444 .20111 L
.94444 .1913 L
.9127 .1913 L
s
.9127 .20111 m
.9127 .21092 L
.94444 .21092 L
.94444 .20111 L
.9127 .20111 L
s
.9127 .21092 m
.9127 .22073 L
.94444 .22073 L
.94444 .21092 L
.9127 .21092 L
s
.9127 .22073 m
.9127 .23054 L
.94444 .23054 L
.94444 .22073 L
.9127 .22073 L
s
.9127 .23054 m
.9127 .24035 L
.94444 .24035 L
.94444 .23054 L
.9127 .23054 L
s
.9127 .24035 m
.9127 .25016 L
.94444 .25016 L
.94444 .24035 L
.9127 .24035 L
s
.9127 .25016 m
.9127 .25997 L
.94444 .25997 L
.94444 .25016 L
.9127 .25016 L
s
.9127 .25997 m
.9127 .26978 L
.94444 .26978 L
.94444 .25997 L
.9127 .25997 L
s
.9127 .26978 m
.9127 .27959 L
.94444 .27959 L
.94444 .26978 L
.9127 .26978 L
s
.9127 .27959 m
.9127 .2894 L
.94444 .2894 L
.94444 .27959 L
.9127 .27959 L
s
.9127 .2894 m
.9127 .29921 L
.94444 .29921 L
.94444 .2894 L
.9127 .2894 L
s
.9127 .29921 m
.9127 .30902 L
.94444 .30902 L
.94444 .29921 L
.9127 .29921 L
s
.9127 .30902 m
.9127 .31883 L
.94444 .31883 L
.94444 .30902 L
.9127 .30902 L
s
.9127 .31883 m
.9127 .32864 L
.94444 .32864 L
.94444 .31883 L
.9127 .31883 L
s
.9127 .32864 m
.9127 .33845 L
.94444 .33845 L
.94444 .32864 L
.9127 .32864 L
s
.9127 .33845 m
.9127 .34826 L
.94444 .34826 L
.94444 .33845 L
.9127 .33845 L
s
.9127 .34826 m
.9127 .35807 L
.94444 .35807 L
.94444 .34826 L
.9127 .34826 L
s
.9127 .35807 m
.9127 .36788 L
.94444 .36788 L
.94444 .35807 L
.9127 .35807 L
s
.9127 .36788 m
.9127 .37769 L
.94444 .37769 L
.94444 .36788 L
.9127 .36788 L
s
.9127 .37769 m
.9127 .3875 L
.94444 .3875 L
.94444 .37769 L
.9127 .37769 L
s
.9127 .3875 m
.9127 .39731 L
.94444 .39731 L
.94444 .3875 L
.9127 .3875 L
s
.9127 .39731 m
.9127 .40712 L
.94444 .40712 L
.94444 .39731 L
.9127 .39731 L
s
.9127 .40712 m
.9127 .41693 L
.94444 .41693 L
.94444 .40712 L
.9127 .40712 L
s
.9127 .41693 m
.9127 .42674 L
.94444 .42674 L
.94444 .41693 L
.9127 .41693 L
s
.9127 .42674 m
.9127 .43655 L
.94444 .43655 L
.94444 .42674 L
.9127 .42674 L
s
.9127 .43655 m
.9127 .44636 L
.94444 .44636 L
.94444 .43655 L
.9127 .43655 L
s
.9127 .44636 m
.9127 .45617 L
.94444 .45617 L
.94444 .44636 L
.9127 .44636 L
s
.9127 .45617 m
.9127 .46598 L
.94444 .46598 L
.94444 .45617 L
.9127 .45617 L
s
.9127 .46598 m
.9127 .47579 L
.94444 .47579 L
.94444 .46598 L
.9127 .46598 L
s
.9127 .47579 m
.9127 .4856 L
.94444 .4856 L
.94444 .47579 L
.9127 .47579 L
s
.9127 .4856 m
.9127 .49541 L
.94444 .49541 L
.94444 .4856 L
.9127 .4856 L
s
.9127 .49541 m
.9127 .50522 L
.94444 .50522 L
.94444 .49541 L
.9127 .49541 L
s
.9127 .50522 m
.9127 .51503 L
.94444 .51503 L
.94444 .50522 L
.9127 .50522 L
s
.9127 .51503 m
.9127 .52484 L
.94444 .52484 L
.94444 .51503 L
.9127 .51503 L
s
.9127 .52484 m
.9127 .53465 L
.94444 .53465 L
.94444 .52484 L
.9127 .52484 L
s
.9127 .53465 m
.9127 .54446 L
.94444 .54446 L
.94444 .53465 L
.9127 .53465 L
s
.9127 .54446 m
.9127 .55427 L
.94444 .55427 L
.94444 .54446 L
.9127 .54446 L
s
.9127 .55427 m
.9127 .56408 L
.94444 .56408 L
.94444 .55427 L
.9127 .55427 L
s
.9127 .56408 m
.9127 .57389 L
.94444 .57389 L
.94444 .56408 L
.9127 .56408 L
s
.9127 .57389 m
.9127 .5837 L
.94444 .5837 L
.94444 .57389 L
.9127 .57389 L
s
.9127 .5837 m
.9127 .59351 L
.94444 .59351 L
.94444 .5837 L
.9127 .5837 L
s
.9127 .59351 m
.9127 .60332 L
.94444 .60332 L
.94444 .59351 L
.9127 .59351 L
s
.94444 .01472 m
.94444 .02453 L
.97619 .02453 L
.97619 .01472 L
.94444 .01472 L
s
.94444 .02453 m
.94444 .03434 L
.97619 .03434 L
.97619 .02453 L
.94444 .02453 L
s
.94444 .03434 m
.94444 .04415 L
.97619 .04415 L
.97619 .03434 L
.94444 .03434 L
s
.94444 .04415 m
.94444 .05396 L
.97619 .05396 L
.97619 .04415 L
.94444 .04415 L
s
.94444 .05396 m
.94444 .06377 L
.97619 .06377 L
.97619 .05396 L
.94444 .05396 L
s
.94444 .06377 m
.94444 .07358 L
.97619 .07358 L
.97619 .06377 L
.94444 .06377 L
s
.94444 .07358 m
.94444 .08339 L
.97619 .08339 L
.97619 .07358 L
.94444 .07358 L
s
.94444 .08339 m
.94444 .0932 L
.97619 .0932 L
.97619 .08339 L
.94444 .08339 L
s
.94444 .0932 m
.94444 .10301 L
.97619 .10301 L
.97619 .0932 L
.94444 .0932 L
s
.94444 .10301 m
.94444 .11282 L
.97619 .11282 L
.97619 .10301 L
.94444 .10301 L
s
.94444 .11282 m
.94444 .12263 L
.97619 .12263 L
.97619 .11282 L
.94444 .11282 L
s
.94444 .12263 m
.94444 .13244 L
.97619 .13244 L
.97619 .12263 L
.94444 .12263 L
s
.94444 .13244 m
.94444 .14225 L
.97619 .14225 L
.97619 .13244 L
.94444 .13244 L
s
.94444 .14225 m
.94444 .15206 L
.97619 .15206 L
.97619 .14225 L
.94444 .14225 L
s
.94444 .15206 m
.94444 .16187 L
.97619 .16187 L
.97619 .15206 L
.94444 .15206 L
s
.94444 .16187 m
.94444 .17168 L
.97619 .17168 L
.97619 .16187 L
.94444 .16187 L
s
.94444 .17168 m
.94444 .18149 L
.97619 .18149 L
.97619 .17168 L
.94444 .17168 L
s
.94444 .18149 m
.94444 .1913 L
.97619 .1913 L
.97619 .18149 L
.94444 .18149 L
s
.94444 .1913 m
.94444 .20111 L
.97619 .20111 L
.97619 .1913 L
.94444 .1913 L
s
.94444 .20111 m
.94444 .21092 L
.97619 .21092 L
.97619 .20111 L
.94444 .20111 L
s
.94444 .21092 m
.94444 .22073 L
.97619 .22073 L
.97619 .21092 L
.94444 .21092 L
s
.94444 .22073 m
.94444 .23054 L
.97619 .23054 L
.97619 .22073 L
.94444 .22073 L
s
.94444 .23054 m
.94444 .24035 L
.97619 .24035 L
.97619 .23054 L
.94444 .23054 L
s
.94444 .24035 m
.94444 .25016 L
.97619 .25016 L
.97619 .24035 L
.94444 .24035 L
s
.94444 .25016 m
.94444 .25997 L
.97619 .25997 L
.97619 .25016 L
.94444 .25016 L
s
.94444 .25997 m
.94444 .26978 L
.97619 .26978 L
.97619 .25997 L
.94444 .25997 L
s
.94444 .26978 m
.94444 .27959 L
.97619 .27959 L
.97619 .26978 L
.94444 .26978 L
s
.94444 .27959 m
.94444 .2894 L
.97619 .2894 L
.97619 .27959 L
.94444 .27959 L
s
.94444 .2894 m
.94444 .29921 L
.97619 .29921 L
.97619 .2894 L
.94444 .2894 L
s
.94444 .29921 m
.94444 .30902 L
.97619 .30902 L
.97619 .29921 L
.94444 .29921 L
s
.94444 .30902 m
.94444 .31883 L
.97619 .31883 L
.97619 .30902 L
.94444 .30902 L
s
.94444 .31883 m
.94444 .32864 L
.97619 .32864 L
.97619 .31883 L
.94444 .31883 L
s
.94444 .32864 m
.94444 .33845 L
.97619 .33845 L
.97619 .32864 L
.94444 .32864 L
s
.94444 .33845 m
.94444 .34826 L
.97619 .34826 L
.97619 .33845 L
.94444 .33845 L
s
.94444 .34826 m
.94444 .35807 L
.97619 .35807 L
.97619 .34826 L
.94444 .34826 L
s
.94444 .35807 m
.94444 .36788 L
.97619 .36788 L
.97619 .35807 L
.94444 .35807 L
s
.94444 .36788 m
.94444 .37769 L
.97619 .37769 L
.97619 .36788 L
.94444 .36788 L
s
.94444 .37769 m
.94444 .3875 L
.97619 .3875 L
.97619 .37769 L
.94444 .37769 L
s
.94444 .3875 m
.94444 .39731 L
.97619 .39731 L
.97619 .3875 L
.94444 .3875 L
s
.94444 .39731 m
.94444 .40712 L
.97619 .40712 L
.97619 .39731 L
.94444 .39731 L
s
.94444 .40712 m
.94444 .41693 L
.97619 .41693 L
.97619 .40712 L
.94444 .40712 L
s
.94444 .41693 m
.94444 .42674 L
.97619 .42674 L
.97619 .41693 L
.94444 .41693 L
s
.94444 .42674 m
.94444 .43655 L
.97619 .43655 L
.97619 .42674 L
.94444 .42674 L
s
.94444 .43655 m
.94444 .44636 L
.97619 .44636 L
.97619 .43655 L
.94444 .43655 L
s
.94444 .44636 m
.94444 .45617 L
.97619 .45617 L
.97619 .44636 L
.94444 .44636 L
s
.94444 .45617 m
.94444 .46598 L
.97619 .46598 L
.97619 .45617 L
.94444 .45617 L
s
.94444 .46598 m
.94444 .47579 L
.97619 .47579 L
.97619 .46598 L
.94444 .46598 L
s
.94444 .47579 m
.94444 .4856 L
.97619 .4856 L
.97619 .47579 L
.94444 .47579 L
s
.94444 .4856 m
.94444 .49541 L
.97619 .49541 L
.97619 .4856 L
.94444 .4856 L
s
.94444 .49541 m
.94444 .50522 L
.97619 .50522 L
.97619 .49541 L
.94444 .49541 L
s
.94444 .50522 m
.94444 .51503 L
.97619 .51503 L
.97619 .50522 L
.94444 .50522 L
s
.94444 .51503 m
.94444 .52484 L
.97619 .52484 L
.97619 .51503 L
.94444 .51503 L
s
.94444 .52484 m
.94444 .53465 L
.97619 .53465 L
.97619 .52484 L
.94444 .52484 L
s
.94444 .53465 m
.94444 .54446 L
.97619 .54446 L
.97619 .53465 L
.94444 .53465 L
s
.94444 .54446 m
.94444 .55427 L
.97619 .55427 L
.97619 .54446 L
.94444 .54446 L
s
.94444 .55427 m
.94444 .56408 L
.97619 .56408 L
.97619 .55427 L
.94444 .55427 L
s
.94444 .56408 m
.94444 .57389 L
.97619 .57389 L
.97619 .56408 L
.94444 .56408 L
s
.94444 .57389 m
.94444 .5837 L
.97619 .5837 L
.97619 .57389 L
.94444 .57389 L
s
.94444 .5837 m
.94444 .59351 L
.97619 .59351 L
.97619 .5837 L
.94444 .5837 L
s
.94444 .59351 m
.94444 .60332 L
.97619 .60332 L
.97619 .59351 L
.94444 .59351 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0826309, -0.157113, \
0.0115222, 0.0372864}}],

Cell[OutputFormData["\<\
Graphics[{{CMYKColor[0.016666666666666666, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0., 0.}, {0., 0.10471975511965977}, {0.10471975511965977, \
0.10471975511965977}, {0.10471975511965977, 0.}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.025, 0.1], Polygon[{{0., \
0.10471975511965977}, {0., 0.20943951023931953}, 
     {0.10471975511965977, 0.20943951023931953}, {0.10471975511965977, \
0.10471975511965977}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0., 0.20943951023931953}, {0., 0.3141592653589793}, 
     {0.10471975511965977, 0.3141592653589793}, {0.10471975511965977, \
0.20943951023931953}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.058333333333333334, 0.1], \
Polygon[{{0., 0.3141592653589793}, {0., 0.41887902047863906}, 
     {0.10471975511965977, 0.41887902047863906}, {0.10471975511965977, \
0.3141592653589793}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.075, 0.1], Polygon[{{0., \
0.41887902047863906}, {0., 0.5235987755982988}, 
     {0.10471975511965977, 0.5235987755982988}, {0.10471975511965977, \
0.41887902047863906}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.09166666666666666, 0.1], \
Polygon[{{0., 0.5235987755982988}, {0., 0.6283185307179586}, 
     {0.10471975511965977, 0.6283185307179586}, {0.10471975511965977, \
0.5235987755982988}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0., 0.6283185307179586}, {0., 0.7330382858376183}, 
     {0.10471975511965977, 0.7330382858376183}, {0.10471975511965977, \
0.6283185307179586}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.125, 0.1], Polygon[{{0., \
0.7330382858376183}, {0., 0.8377580409572781}, 
     {0.10471975511965977, 0.8377580409572781}, {0.10471975511965977, \
0.7330382858376183}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0., 0.8377580409572781}, {0., 0.9424777960769379}, 
     {0.10471975511965977, 0.9424777960769379}, {0.10471975511965977, \
0.8377580409572781}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.15833333333333333, 0.1], \
Polygon[{{0., 0.9424777960769379}, {0., 1.0471975511965976}, 
     {0.10471975511965977, 1.0471975511965976}, {0.10471975511965977, \
0.9424777960769379}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.175, 0.1], Polygon[{{0., \
1.0471975511965976}, {0., 1.1519173063162573}, 
     {0.10471975511965977, 1.1519173063162573}, {0.10471975511965977, \
1.0471975511965976}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.19166666666666665, 0.1], \
Polygon[{{0., 1.1519173063162573}, {0., 1.2566370614359172}, 
     {0.10471975511965977, 1.2566370614359172}, {0.10471975511965977, \
1.1519173063162573}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0., 1.2566370614359172}, {0., 1.361356816555577}, 
     {0.10471975511965977, 1.361356816555577}, {0.10471975511965977, \
1.2566370614359172}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.225, 0.1], Polygon[{{0., \
1.361356816555577}, {0., 1.4660765716752366}, 
     {0.10471975511965977, 1.4660765716752366}, {0.10471975511965977, \
1.361356816555577}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0., 1.4660765716752366}, {0., 1.5707963267948966}, 
     {0.10471975511965977, 1.5707963267948966}, {0.10471975511965977, \
1.4660765716752366}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.2583333333333333, 0.1], \
Polygon[{{0., 1.5707963267948966}, {0., 1.6755160819145563}, 
     {0.10471975511965977, 1.6755160819145563}, {0.10471975511965977, \
1.5707963267948966}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.275, 0.1], Polygon[{{0., \
1.6755160819145563}, {0., 1.780235837034216}, 
     {0.10471975511965977, 1.780235837034216}, {0.10471975511965977, \
1.6755160819145563}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.2916666666666667, 0.1], \
Polygon[{{0., 1.780235837034216}, {0., 1.8849555921538759}, 
     {0.10471975511965977, 1.8849555921538759}, {0.10471975511965977, \
1.780235837034216}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{0., 1.8849555921538759}, {0., 1.9896753472735356}, 
     {0.10471975511965977, 1.9896753472735356}, {0.10471975511965977, \
1.8849555921538759}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.325, 0.1], Polygon[{{0., \
1.9896753472735356}, {0., 2.0943951023931953}, 
     {0.10471975511965977, 2.0943951023931953}, {0.10471975511965977, \
1.9896753472735356}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{0., 2.0943951023931953}, {0., 2.199114857512855}, 
     {0.10471975511965977, 2.199114857512855}, {0.10471975511965977, \
2.0943951023931953}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.35833333333333334, 0.1], \
Polygon[{{0., 2.199114857512855}, {0., 2.3038346126325147}, 
     {0.10471975511965977, 2.3038346126325147}, {0.10471975511965977, \
2.199114857512855}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.375, 0.1], Polygon[{{0., \
2.3038346126325147}, {0., 2.4085543677521746}, 
     {0.10471975511965977, 2.4085543677521746}, {0.10471975511965977, \
2.3038346126325147}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.39166666666666666, 0.1], \
Polygon[{{0., 2.4085543677521746}, {0., 2.5132741228718345}, 
     {0.10471975511965977, 2.5132741228718345}, {0.10471975511965977, \
2.4085543677521746}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{0., 2.5132741228718345}, {0., 2.617993877991494}, 
     {0.10471975511965977, 2.617993877991494}, {0.10471975511965977, \
2.5132741228718345}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.425, 0.1], Polygon[{{0., \
2.617993877991494}, {0., 2.722713633111154}, 
     {0.10471975511965977, 2.722713633111154}, {0.10471975511965977, \
2.617993877991494}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{0., 2.722713633111154}, {0., 2.827433388230814}, 
     {0.10471975511965977, 2.827433388230814}, {0.10471975511965977, \
2.722713633111154}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.4583333333333333, 0.1], \
Polygon[{{0., 2.827433388230814}, {0., 2.9321531433504733}, 
     {0.10471975511965977, 2.9321531433504733}, {0.10471975511965977, \
2.827433388230814}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.475, 0.1], Polygon[{{0., \
2.9321531433504733}, {0., 3.036872898470133}, 
     {0.10471975511965977, 3.036872898470133}, {0.10471975511965977, \
2.9321531433504733}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.49166666666666664, 0.1], \
Polygon[{{0., 3.036872898470133}, {0., 3.141592653589793}, 
     {0.10471975511965977, 3.141592653589793}, {0.10471975511965977, \
3.036872898470133}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{0., 3.141592653589793}, {0., 3.2463124087094526}, 
     {0.10471975511965977, 3.2463124087094526}, {0.10471975511965977, \
3.141592653589793}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.525, 0.1], Polygon[{{0., \
3.2463124087094526}, {0., 3.3510321638291125}, 
     {0.10471975511965977, 3.3510321638291125}, {0.10471975511965977, \
3.2463124087094526}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{0., 3.3510321638291125}, {0., 3.4557519189487724}, 
     {0.10471975511965977, 3.4557519189487724}, {0.10471975511965977, \
3.3510321638291125}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.5583333333333333, 0.1], \
Polygon[{{0., 3.4557519189487724}, {0., 3.560471674068432}, 
     {0.10471975511965977, 3.560471674068432}, {0.10471975511965977, \
3.4557519189487724}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.575, 0.1], Polygon[{{0., \
3.560471674068432}, {0., 3.665191429188092}, 
     {0.10471975511965977, 3.665191429188092}, {0.10471975511965977, \
3.560471674068432}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.5916666666666667, 0.1], \
Polygon[{{0., 3.665191429188092}, {0., 3.7699111843077517}, 
     {0.10471975511965977, 3.7699111843077517}, {0.10471975511965977, \
3.665191429188092}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{0., 3.7699111843077517}, {0., 3.874630939427411}, 
     {0.10471975511965977, 3.874630939427411}, {0.10471975511965977, \
3.7699111843077517}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.625, 0.1], Polygon[{{0., \
3.874630939427411}, {0., 3.979350694547071}, 
     {0.10471975511965977, 3.979350694547071}, {0.10471975511965977, \
3.874630939427411}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{0., 3.979350694547071}, {0., 4.084070449666731}, 
     {0.10471975511965977, 4.084070449666731}, {0.10471975511965977, \
3.979350694547071}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.6583333333333333, 0.1], \
Polygon[{{0., 4.084070449666731}, {0., 4.1887902047863905}, 
     {0.10471975511965977, 4.1887902047863905}, {0.10471975511965977, \
4.084070449666731}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.675, 0.1], Polygon[{{0., \
4.1887902047863905}, {0., 4.29350995990605}, 
     {0.10471975511965977, 4.29350995990605}, {0.10471975511965977, \
4.1887902047863905}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.6916666666666667, 0.1], \
Polygon[{{0., 4.29350995990605}, {0., 4.39822971502571}, 
     {0.10471975511965977, 4.39822971502571}, {0.10471975511965977, \
4.29350995990605}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{0., 4.39822971502571}, {0., 4.50294947014537}, 
     {0.10471975511965977, 4.50294947014537}, {0.10471975511965977, \
4.39822971502571}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.725, 0.1], Polygon[{{0., \
4.50294947014537}, {0., 4.607669225265029}, 
     {0.10471975511965977, 4.607669225265029}, {0.10471975511965977, \
4.50294947014537}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{0., 4.607669225265029}, {0., 4.71238898038469}, 
     {0.10471975511965977, 4.71238898038469}, {0.10471975511965977, \
4.607669225265029}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.7583333333333333, 0.1], \
Polygon[{{0., 4.71238898038469}, {0., 4.817108735504349}, 
     {0.10471975511965977, 4.817108735504349}, {0.10471975511965977, \
4.71238898038469}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.775, 0.1], Polygon[{{0., \
4.817108735504349}, {0., 4.921828490624009}, 
     {0.10471975511965977, 4.921828490624009}, {0.10471975511965977, \
4.817108735504349}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.7916666666666666, 0.1], \
Polygon[{{0., 4.921828490624009}, {0., 5.026548245743669}, 
     {0.10471975511965977, 5.026548245743669}, {0.10471975511965977, \
4.921828490624009}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0., 5.026548245743669}, {0., 5.1312680008633285}, 
     {0.10471975511965977, 5.1312680008633285}, {0.10471975511965977, \
5.026548245743669}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.825, 0.1], Polygon[{{0., \
5.1312680008633285}, {0., 5.235987755982988}, 
     {0.10471975511965977, 5.235987755982988}, {0.10471975511965977, \
5.1312680008633285}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0., 5.235987755982988}, {0., 5.340707511102648}, 
     {0.10471975511965977, 5.340707511102648}, {0.10471975511965977, \
5.235987755982988}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.8583333333333333, 0.1], \
Polygon[{{0., 5.340707511102648}, {0., 5.445427266222308}, 
     {0.10471975511965977, 5.445427266222308}, {0.10471975511965977, \
5.340707511102648}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.875, 0.1], Polygon[{{0., \
5.445427266222308}, {0., 5.550147021341967}, 
     {0.10471975511965977, 5.550147021341967}, {0.10471975511965977, \
5.445427266222308}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.8916666666666666, 0.1], \
Polygon[{{0., 5.550147021341967}, {0., 5.654866776461628}, 
     {0.10471975511965977, 5.654866776461628}, {0.10471975511965977, \
5.550147021341967}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0., 5.654866776461628}, {0., 5.759586531581287}, 
     {0.10471975511965977, 5.759586531581287}, {0.10471975511965977, \
5.654866776461628}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.9249999999999999, 0.1], \
Polygon[{{0., 5.759586531581287}, {0., 5.864306286700947}, 
     {0.10471975511965977, 5.864306286700947}, {0.10471975511965977, \
5.759586531581287}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0., 5.864306286700947}, {0., 5.969026041820607}, 
     {0.10471975511965977, 5.969026041820607}, {0.10471975511965977, \
5.864306286700947}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.9583333333333334, 0.1], \
Polygon[{{0., 5.969026041820607}, {0., 6.073745796940266}, 
     {0.10471975511965977, 6.073745796940266}, {0.10471975511965977, \
5.969026041820607}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.975, 0.1], Polygon[{{0., \
6.073745796940266}, {0., 6.178465552059926}, 
     {0.10471975511965977, 6.178465552059926}, {0.10471975511965977, \
6.073745796940266}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.9916666666666667, 0.1], \
Polygon[{{0., 6.178465552059926}, {0., 6.283185307179586}, 
     {0.10471975511965977, 6.283185307179586}, {0.10471975511965977, \
6.178465552059926}}]}, 
  {CMYKColor[0.05, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.10471975511965977, 0.}, {0.10471975511965977, \
0.10471975511965977}, 
     {0.20943951023931953, 0.10471975511965977}, {0.20943951023931953, \
0.}}]}, {CMYKColor[0.05, 0.5, 0.025, 0.1], 
   Polygon[{{0.10471975511965977, 0.10471975511965977}, {0.10471975511965977, \
0.20943951023931953}, {0.20943951023931953, 0.20943951023931953}, 
     {0.20943951023931953, 0.10471975511965977}}]}, {CMYKColor[0.05, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{0.10471975511965977, 0.20943951023931953}, {0.10471975511965977, \
0.3141592653589793}, {0.20943951023931953, 0.3141592653589793}, 
     {0.20943951023931953, 0.20943951023931953}}]}, {CMYKColor[0.05, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{0.10471975511965977, 0.3141592653589793}, {0.10471975511965977, \
0.41887902047863906}, {0.20943951023931953, 0.41887902047863906}, 
     {0.20943951023931953, 0.3141592653589793}}]}, {CMYKColor[0.05, 0.5, \
0.075, 0.1], 
   Polygon[{{0.10471975511965977, 0.41887902047863906}, {0.10471975511965977, \
0.5235987755982988}, {0.20943951023931953, 0.5235987755982988}, 
     {0.20943951023931953, 0.41887902047863906}}]}, {CMYKColor[0.05, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{0.10471975511965977, 0.5235987755982988}, {0.10471975511965977, \
0.6283185307179586}, {0.20943951023931953, 0.6283185307179586}, 
     {0.20943951023931953, 0.5235987755982988}}]}, {CMYKColor[0.05, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{0.10471975511965977, 0.6283185307179586}, {0.10471975511965977, \
0.7330382858376183}, {0.20943951023931953, 0.7330382858376183}, 
     {0.20943951023931953, 0.6283185307179586}}]}, {CMYKColor[0.05, 0.5, \
0.125, 0.1], 
   Polygon[{{0.10471975511965977, 0.7330382858376183}, {0.10471975511965977, \
0.8377580409572781}, {0.20943951023931953, 0.8377580409572781}, 
     {0.20943951023931953, 0.7330382858376183}}]}, {CMYKColor[0.05, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{0.10471975511965977, 0.8377580409572781}, {0.10471975511965977, \
0.9424777960769379}, {0.20943951023931953, 0.9424777960769379}, 
     {0.20943951023931953, 0.8377580409572781}}]}, {CMYKColor[0.05, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 0.9424777960769379}, {0.10471975511965977, \
1.0471975511965976}, {0.20943951023931953, 1.0471975511965976}, 
     {0.20943951023931953, 0.9424777960769379}}]}, {CMYKColor[0.05, 0.5, \
0.175, 0.1], 
   Polygon[{{0.10471975511965977, 1.0471975511965976}, {0.10471975511965977, \
1.1519173063162573}, {0.20943951023931953, 1.1519173063162573}, 
     {0.20943951023931953, 1.0471975511965976}}]}, {CMYKColor[0.05, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{0.10471975511965977, 1.1519173063162573}, {0.10471975511965977, \
1.2566370614359172}, {0.20943951023931953, 1.2566370614359172}, 
     {0.20943951023931953, 1.1519173063162573}}]}, {CMYKColor[0.05, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{0.10471975511965977, 1.2566370614359172}, {0.10471975511965977, \
1.361356816555577}, {0.20943951023931953, 1.361356816555577}, 
     {0.20943951023931953, 1.2566370614359172}}]}, {CMYKColor[0.05, 0.5, \
0.225, 0.1], 
   Polygon[{{0.10471975511965977, 1.361356816555577}, {0.10471975511965977, \
1.4660765716752366}, {0.20943951023931953, 1.4660765716752366}, 
     {0.20943951023931953, 1.361356816555577}}]}, {CMYKColor[0.05, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{0.10471975511965977, 1.4660765716752366}, {0.10471975511965977, \
1.5707963267948966}, {0.20943951023931953, 1.5707963267948966}, 
     {0.20943951023931953, 1.4660765716752366}}]}, {CMYKColor[0.05, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 1.5707963267948966}, {0.10471975511965977, \
1.6755160819145563}, {0.20943951023931953, 1.6755160819145563}, 
     {0.20943951023931953, 1.5707963267948966}}]}, {CMYKColor[0.05, 0.5, \
0.275, 0.1], 
   Polygon[{{0.10471975511965977, 1.6755160819145563}, {0.10471975511965977, \
1.780235837034216}, {0.20943951023931953, 1.780235837034216}, 
     {0.20943951023931953, 1.6755160819145563}}]}, {CMYKColor[0.05, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{0.10471975511965977, 1.780235837034216}, {0.10471975511965977, \
1.8849555921538759}, {0.20943951023931953, 1.8849555921538759}, 
     {0.20943951023931953, 1.780235837034216}}]}, {CMYKColor[0.05, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{0.10471975511965977, 1.8849555921538759}, {0.10471975511965977, \
1.9896753472735356}, {0.20943951023931953, 1.9896753472735356}, 
     {0.20943951023931953, 1.8849555921538759}}]}, {CMYKColor[0.05, 0.5, \
0.325, 0.1], 
   Polygon[{{0.10471975511965977, 1.9896753472735356}, {0.10471975511965977, \
2.0943951023931953}, {0.20943951023931953, 2.0943951023931953}, 
     {0.20943951023931953, 1.9896753472735356}}]}, {CMYKColor[0.05, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{0.10471975511965977, 2.0943951023931953}, {0.10471975511965977, \
2.199114857512855}, {0.20943951023931953, 2.199114857512855}, 
     {0.20943951023931953, 2.0943951023931953}}]}, {CMYKColor[0.05, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{0.10471975511965977, 2.199114857512855}, {0.10471975511965977, \
2.3038346126325147}, {0.20943951023931953, 2.3038346126325147}, 
     {0.20943951023931953, 2.199114857512855}}]}, {CMYKColor[0.05, 0.5, \
0.375, 0.1], 
   Polygon[{{0.10471975511965977, 2.3038346126325147}, {0.10471975511965977, \
2.4085543677521746}, {0.20943951023931953, 2.4085543677521746}, 
     {0.20943951023931953, 2.3038346126325147}}]}, {CMYKColor[0.05, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{0.10471975511965977, 2.4085543677521746}, {0.10471975511965977, \
2.5132741228718345}, {0.20943951023931953, 2.5132741228718345}, 
     {0.20943951023931953, 2.4085543677521746}}]}, {CMYKColor[0.05, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 2.5132741228718345}, {0.10471975511965977, \
2.617993877991494}, {0.20943951023931953, 2.617993877991494}, 
     {0.20943951023931953, 2.5132741228718345}}]}, {CMYKColor[0.05, 0.5, \
0.425, 0.1], 
   Polygon[{{0.10471975511965977, 2.617993877991494}, {0.10471975511965977, \
2.722713633111154}, {0.20943951023931953, 2.722713633111154}, 
     {0.20943951023931953, 2.617993877991494}}]}, {CMYKColor[0.05, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{0.10471975511965977, 2.722713633111154}, {0.10471975511965977, \
2.827433388230814}, {0.20943951023931953, 2.827433388230814}, 
     {0.20943951023931953, 2.722713633111154}}]}, {CMYKColor[0.05, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 2.827433388230814}, {0.10471975511965977, \
2.9321531433504733}, {0.20943951023931953, 2.9321531433504733}, 
     {0.20943951023931953, 2.827433388230814}}]}, {CMYKColor[0.05, 0.5, \
0.475, 0.1], 
   Polygon[{{0.10471975511965977, 2.9321531433504733}, {0.10471975511965977, \
3.036872898470133}, {0.20943951023931953, 3.036872898470133}, 
     {0.20943951023931953, 2.9321531433504733}}]}, {CMYKColor[0.05, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{0.10471975511965977, 3.036872898470133}, {0.10471975511965977, \
3.141592653589793}, {0.20943951023931953, 3.141592653589793}, 
     {0.20943951023931953, 3.036872898470133}}]}, {CMYKColor[0.05, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 3.141592653589793}, {0.10471975511965977, \
3.2463124087094526}, {0.20943951023931953, 3.2463124087094526}, 
     {0.20943951023931953, 3.141592653589793}}]}, {CMYKColor[0.05, 0.5, \
0.525, 0.1], 
   Polygon[{{0.10471975511965977, 3.2463124087094526}, {0.10471975511965977, \
3.3510321638291125}, {0.20943951023931953, 3.3510321638291125}, 
     {0.20943951023931953, 3.2463124087094526}}]}, {CMYKColor[0.05, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{0.10471975511965977, 3.3510321638291125}, {0.10471975511965977, \
3.4557519189487724}, {0.20943951023931953, 3.4557519189487724}, 
     {0.20943951023931953, 3.3510321638291125}}]}, {CMYKColor[0.05, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 3.4557519189487724}, {0.10471975511965977, \
3.560471674068432}, {0.20943951023931953, 3.560471674068432}, 
     {0.20943951023931953, 3.4557519189487724}}]}, {CMYKColor[0.05, 0.5, \
0.575, 0.1], 
   Polygon[{{0.10471975511965977, 3.560471674068432}, {0.10471975511965977, \
3.665191429188092}, {0.20943951023931953, 3.665191429188092}, 
     {0.20943951023931953, 3.560471674068432}}]}, {CMYKColor[0.05, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{0.10471975511965977, 3.665191429188092}, {0.10471975511965977, \
3.7699111843077517}, {0.20943951023931953, 3.7699111843077517}, 
     {0.20943951023931953, 3.665191429188092}}]}, {CMYKColor[0.05, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 3.7699111843077517}, {0.10471975511965977, \
3.874630939427411}, {0.20943951023931953, 3.874630939427411}, 
     {0.20943951023931953, 3.7699111843077517}}]}, {CMYKColor[0.05, 0.5, \
0.625, 0.1], 
   Polygon[{{0.10471975511965977, 3.874630939427411}, {0.10471975511965977, \
3.979350694547071}, {0.20943951023931953, 3.979350694547071}, 
     {0.20943951023931953, 3.874630939427411}}]}, {CMYKColor[0.05, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{0.10471975511965977, 3.979350694547071}, {0.10471975511965977, \
4.084070449666731}, {0.20943951023931953, 4.084070449666731}, 
     {0.20943951023931953, 3.979350694547071}}]}, {CMYKColor[0.05, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 4.084070449666731}, {0.10471975511965977, \
4.1887902047863905}, {0.20943951023931953, 4.1887902047863905}, 
     {0.20943951023931953, 4.084070449666731}}]}, {CMYKColor[0.05, 0.5, \
0.675, 0.1], 
   Polygon[{{0.10471975511965977, 4.1887902047863905}, {0.10471975511965977, \
4.29350995990605}, {0.20943951023931953, 4.29350995990605}, 
     {0.20943951023931953, 4.1887902047863905}}]}, {CMYKColor[0.05, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{0.10471975511965977, 4.29350995990605}, {0.10471975511965977, \
4.39822971502571}, {0.20943951023931953, 4.39822971502571}, 
     {0.20943951023931953, 4.29350995990605}}]}, {CMYKColor[0.05, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{0.10471975511965977, 4.39822971502571}, {0.10471975511965977, \
4.50294947014537}, {0.20943951023931953, 4.50294947014537}, 
     {0.20943951023931953, 4.39822971502571}}]}, {CMYKColor[0.05, 0.5, 0.725, \
0.1], 
   Polygon[{{0.10471975511965977, 4.50294947014537}, {0.10471975511965977, \
4.607669225265029}, {0.20943951023931953, 4.607669225265029}, 
     {0.20943951023931953, 4.50294947014537}}]}, {CMYKColor[0.05, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{0.10471975511965977, 4.607669225265029}, {0.10471975511965977, \
4.71238898038469}, {0.20943951023931953, 4.71238898038469}, 
     {0.20943951023931953, 4.607669225265029}}]}, {CMYKColor[0.05, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 4.71238898038469}, {0.10471975511965977, \
4.817108735504349}, {0.20943951023931953, 4.817108735504349}, 
     {0.20943951023931953, 4.71238898038469}}]}, {CMYKColor[0.05, 0.5, 0.775, \
0.1], 
   Polygon[{{0.10471975511965977, 4.817108735504349}, {0.10471975511965977, \
4.921828490624009}, {0.20943951023931953, 4.921828490624009}, 
     {0.20943951023931953, 4.817108735504349}}]}, {CMYKColor[0.05, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{0.10471975511965977, 4.921828490624009}, {0.10471975511965977, \
5.026548245743669}, {0.20943951023931953, 5.026548245743669}, 
     {0.20943951023931953, 4.921828490624009}}]}, {CMYKColor[0.05, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 5.026548245743669}, {0.10471975511965977, \
5.1312680008633285}, {0.20943951023931953, 5.1312680008633285}, 
     {0.20943951023931953, 5.026548245743669}}]}, {CMYKColor[0.05, 0.5, \
0.825, 0.1], 
   Polygon[{{0.10471975511965977, 5.1312680008633285}, {0.10471975511965977, \
5.235987755982988}, {0.20943951023931953, 5.235987755982988}, 
     {0.20943951023931953, 5.1312680008633285}}]}, {CMYKColor[0.05, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{0.10471975511965977, 5.235987755982988}, {0.10471975511965977, \
5.340707511102648}, {0.20943951023931953, 5.340707511102648}, 
     {0.20943951023931953, 5.235987755982988}}]}, {CMYKColor[0.05, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 5.340707511102648}, {0.10471975511965977, \
5.445427266222308}, {0.20943951023931953, 5.445427266222308}, 
     {0.20943951023931953, 5.340707511102648}}]}, {CMYKColor[0.05, 0.5, \
0.875, 0.1], 
   Polygon[{{0.10471975511965977, 5.445427266222308}, {0.10471975511965977, \
5.550147021341967}, {0.20943951023931953, 5.550147021341967}, 
     {0.20943951023931953, 5.445427266222308}}]}, {CMYKColor[0.05, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{0.10471975511965977, 5.550147021341967}, {0.10471975511965977, \
5.654866776461628}, {0.20943951023931953, 5.654866776461628}, 
     {0.20943951023931953, 5.550147021341967}}]}, {CMYKColor[0.05, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{0.10471975511965977, 5.654866776461628}, {0.10471975511965977, \
5.759586531581287}, {0.20943951023931953, 5.759586531581287}, 
     {0.20943951023931953, 5.654866776461628}}]}, {CMYKColor[0.05, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{0.10471975511965977, 5.759586531581287}, {0.10471975511965977, \
5.864306286700947}, {0.20943951023931953, 5.864306286700947}, 
     {0.20943951023931953, 5.759586531581287}}]}, {CMYKColor[0.05, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{0.10471975511965977, 5.864306286700947}, {0.10471975511965977, \
5.969026041820607}, {0.20943951023931953, 5.969026041820607}, 
     {0.20943951023931953, 5.864306286700947}}]}, {CMYKColor[0.05, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{0.10471975511965977, 5.969026041820607}, {0.10471975511965977, \
6.073745796940266}, {0.20943951023931953, 6.073745796940266}, 
     {0.20943951023931953, 5.969026041820607}}]}, {CMYKColor[0.05, 0.5, \
0.975, 0.1], 
   Polygon[{{0.10471975511965977, 6.073745796940266}, {0.10471975511965977, \
6.178465552059926}, {0.20943951023931953, 6.178465552059926}, 
     {0.20943951023931953, 6.073745796940266}}]}, {CMYKColor[0.05, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{0.10471975511965977, 6.178465552059926}, {0.10471975511965977, \
6.283185307179586}, {0.20943951023931953, 6.283185307179586}, 
     {0.20943951023931953, 6.178465552059926}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 0.}, {0.20943951023931953, \
0.10471975511965977}, {0.3141592653589793, 0.10471975511965977}, 
     {0.3141592653589793, 0.}}]}, {CMYKColor[0.08333333333333333, 0.5, 0.025, \
0.1], 
   Polygon[{{0.20943951023931953, 0.10471975511965977}, {0.20943951023931953, \
0.20943951023931953}, {0.3141592653589793, 0.20943951023931953}, 
     {0.3141592653589793, 0.10471975511965977}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.20943951023931953, 0.20943951023931953}, {0.20943951023931953, \
0.3141592653589793}, {0.3141592653589793, 0.3141592653589793}, 
     {0.3141592653589793, 0.20943951023931953}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.20943951023931953, 0.3141592653589793}, {0.20943951023931953, \
0.41887902047863906}, {0.3141592653589793, 0.41887902047863906}, 
     {0.3141592653589793, 0.3141592653589793}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{0.20943951023931953, 0.41887902047863906}, {0.20943951023931953, \
0.5235987755982988}, {0.3141592653589793, 0.5235987755982988}, 
     {0.3141592653589793, 0.41887902047863906}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.20943951023931953, 0.5235987755982988}, {0.20943951023931953, \
0.6283185307179586}, {0.3141592653589793, 0.6283185307179586}, 
     {0.3141592653589793, 0.5235987755982988}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.20943951023931953, 0.6283185307179586}, {0.20943951023931953, \
0.7330382858376183}, {0.3141592653589793, 0.7330382858376183}, 
     {0.3141592653589793, 0.6283185307179586}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{0.20943951023931953, 0.7330382858376183}, {0.20943951023931953, \
0.8377580409572781}, {0.3141592653589793, 0.8377580409572781}, 
     {0.3141592653589793, 0.7330382858376183}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.20943951023931953, 0.8377580409572781}, {0.20943951023931953, \
0.9424777960769379}, {0.3141592653589793, 0.9424777960769379}, 
     {0.3141592653589793, 0.8377580409572781}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 0.9424777960769379}, {0.20943951023931953, \
1.0471975511965976}, {0.3141592653589793, 1.0471975511965976}, 
     {0.3141592653589793, 0.9424777960769379}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{0.20943951023931953, 1.0471975511965976}, {0.20943951023931953, \
1.1519173063162573}, {0.3141592653589793, 1.1519173063162573}, 
     {0.3141592653589793, 1.0471975511965976}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.20943951023931953, 1.1519173063162573}, {0.20943951023931953, \
1.2566370614359172}, {0.3141592653589793, 1.2566370614359172}, 
     {0.3141592653589793, 1.1519173063162573}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.20943951023931953, 1.2566370614359172}, {0.20943951023931953, \
1.361356816555577}, {0.3141592653589793, 1.361356816555577}, 
     {0.3141592653589793, 1.2566370614359172}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{0.20943951023931953, 1.361356816555577}, {0.20943951023931953, \
1.4660765716752366}, {0.3141592653589793, 1.4660765716752366}, 
     {0.3141592653589793, 1.361356816555577}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.20943951023931953, 1.4660765716752366}, {0.20943951023931953, \
1.5707963267948966}, {0.3141592653589793, 1.5707963267948966}, 
     {0.3141592653589793, 1.4660765716752366}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 1.5707963267948966}, {0.20943951023931953, \
1.6755160819145563}, {0.3141592653589793, 1.6755160819145563}, 
     {0.3141592653589793, 1.5707963267948966}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{0.20943951023931953, 1.6755160819145563}, {0.20943951023931953, \
1.780235837034216}, {0.3141592653589793, 1.780235837034216}, 
     {0.3141592653589793, 1.6755160819145563}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0.20943951023931953, 1.780235837034216}, {0.20943951023931953, \
1.8849555921538759}, {0.3141592653589793, 1.8849555921538759}, 
     {0.3141592653589793, 1.780235837034216}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0.20943951023931953, 1.8849555921538759}, {0.20943951023931953, \
1.9896753472735356}, {0.3141592653589793, 1.9896753472735356}, 
     {0.3141592653589793, 1.8849555921538759}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{0.20943951023931953, 1.9896753472735356}, {0.20943951023931953, \
2.0943951023931953}, {0.3141592653589793, 2.0943951023931953}, 
     {0.3141592653589793, 1.9896753472735356}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{0.20943951023931953, 2.0943951023931953}, {0.20943951023931953, \
2.199114857512855}, {0.3141592653589793, 2.199114857512855}, 
     {0.3141592653589793, 2.0943951023931953}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0.20943951023931953, 2.199114857512855}, {0.20943951023931953, \
2.3038346126325147}, {0.3141592653589793, 2.3038346126325147}, 
     {0.3141592653589793, 2.199114857512855}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{0.20943951023931953, 2.3038346126325147}, {0.20943951023931953, \
2.4085543677521746}, {0.3141592653589793, 2.4085543677521746}, 
     {0.3141592653589793, 2.3038346126325147}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{0.20943951023931953, 2.4085543677521746}, {0.20943951023931953, \
2.5132741228718345}, {0.3141592653589793, 2.5132741228718345}, 
     {0.3141592653589793, 2.4085543677521746}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 2.5132741228718345}, {0.20943951023931953, \
2.617993877991494}, {0.3141592653589793, 2.617993877991494}, 
     {0.3141592653589793, 2.5132741228718345}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{0.20943951023931953, 2.617993877991494}, {0.20943951023931953, \
2.722713633111154}, {0.3141592653589793, 2.722713633111154}, 
     {0.3141592653589793, 2.617993877991494}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{0.20943951023931953, 2.722713633111154}, {0.20943951023931953, \
2.827433388230814}, {0.3141592653589793, 2.827433388230814}, 
     {0.3141592653589793, 2.722713633111154}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 2.827433388230814}, {0.20943951023931953, \
2.9321531433504733}, {0.3141592653589793, 2.9321531433504733}, 
     {0.3141592653589793, 2.827433388230814}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{0.20943951023931953, 2.9321531433504733}, {0.20943951023931953, \
3.036872898470133}, {0.3141592653589793, 3.036872898470133}, 
     {0.3141592653589793, 2.9321531433504733}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{0.20943951023931953, 3.036872898470133}, {0.20943951023931953, \
3.141592653589793}, {0.3141592653589793, 3.141592653589793}, 
     {0.3141592653589793, 3.036872898470133}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 3.141592653589793}, {0.20943951023931953, \
3.2463124087094526}, {0.3141592653589793, 3.2463124087094526}, 
     {0.3141592653589793, 3.141592653589793}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{0.20943951023931953, 3.2463124087094526}, {0.20943951023931953, \
3.3510321638291125}, {0.3141592653589793, 3.3510321638291125}, 
     {0.3141592653589793, 3.2463124087094526}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{0.20943951023931953, 3.3510321638291125}, {0.20943951023931953, \
3.4557519189487724}, {0.3141592653589793, 3.4557519189487724}, 
     {0.3141592653589793, 3.3510321638291125}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 3.4557519189487724}, {0.20943951023931953, \
3.560471674068432}, {0.3141592653589793, 3.560471674068432}, 
     {0.3141592653589793, 3.4557519189487724}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{0.20943951023931953, 3.560471674068432}, {0.20943951023931953, \
3.665191429188092}, {0.3141592653589793, 3.665191429188092}, 
     {0.3141592653589793, 3.560471674068432}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{0.20943951023931953, 3.665191429188092}, {0.20943951023931953, \
3.7699111843077517}, {0.3141592653589793, 3.7699111843077517}, 
     {0.3141592653589793, 3.665191429188092}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 3.7699111843077517}, {0.20943951023931953, \
3.874630939427411}, {0.3141592653589793, 3.874630939427411}, 
     {0.3141592653589793, 3.7699111843077517}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{0.20943951023931953, 3.874630939427411}, {0.20943951023931953, \
3.979350694547071}, {0.3141592653589793, 3.979350694547071}, 
     {0.3141592653589793, 3.874630939427411}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0.20943951023931953, 3.979350694547071}, {0.20943951023931953, \
4.084070449666731}, {0.3141592653589793, 4.084070449666731}, 
     {0.3141592653589793, 3.979350694547071}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 4.084070449666731}, {0.20943951023931953, \
4.1887902047863905}, {0.3141592653589793, 4.1887902047863905}, 
     {0.3141592653589793, 4.084070449666731}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{0.20943951023931953, 4.1887902047863905}, {0.20943951023931953, \
4.29350995990605}, {0.3141592653589793, 4.29350995990605}, 
     {0.3141592653589793, 4.1887902047863905}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0.20943951023931953, 4.29350995990605}, {0.20943951023931953, \
4.39822971502571}, {0.3141592653589793, 4.39822971502571}, 
     {0.3141592653589793, 4.29350995990605}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0.20943951023931953, 4.39822971502571}, {0.20943951023931953, \
4.50294947014537}, {0.3141592653589793, 4.50294947014537}, 
     {0.3141592653589793, 4.39822971502571}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{0.20943951023931953, 4.50294947014537}, {0.20943951023931953, \
4.607669225265029}, {0.3141592653589793, 4.607669225265029}, 
     {0.3141592653589793, 4.50294947014537}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.20943951023931953, 4.607669225265029}, {0.20943951023931953, \
4.71238898038469}, {0.3141592653589793, 4.71238898038469}, 
     {0.3141592653589793, 4.607669225265029}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 4.71238898038469}, {0.20943951023931953, \
4.817108735504349}, {0.3141592653589793, 4.817108735504349}, 
     {0.3141592653589793, 4.71238898038469}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{0.20943951023931953, 4.817108735504349}, {0.20943951023931953, \
4.921828490624009}, {0.3141592653589793, 4.921828490624009}, 
     {0.3141592653589793, 4.817108735504349}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.20943951023931953, 4.921828490624009}, {0.20943951023931953, \
5.026548245743669}, {0.3141592653589793, 5.026548245743669}, 
     {0.3141592653589793, 4.921828490624009}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 5.026548245743669}, {0.20943951023931953, \
5.1312680008633285}, {0.3141592653589793, 5.1312680008633285}, 
     {0.3141592653589793, 5.026548245743669}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{0.20943951023931953, 5.1312680008633285}, {0.20943951023931953, \
5.235987755982988}, {0.3141592653589793, 5.235987755982988}, 
     {0.3141592653589793, 5.1312680008633285}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.20943951023931953, 5.235987755982988}, {0.20943951023931953, \
5.340707511102648}, {0.3141592653589793, 5.340707511102648}, 
     {0.3141592653589793, 5.235987755982988}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 5.340707511102648}, {0.20943951023931953, \
5.445427266222308}, {0.3141592653589793, 5.445427266222308}, 
     {0.3141592653589793, 5.340707511102648}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{0.20943951023931953, 5.445427266222308}, {0.20943951023931953, \
5.550147021341967}, {0.3141592653589793, 5.550147021341967}, 
     {0.3141592653589793, 5.445427266222308}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.20943951023931953, 5.550147021341967}, {0.20943951023931953, \
5.654866776461628}, {0.3141592653589793, 5.654866776461628}, 
     {0.3141592653589793, 5.550147021341967}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.20943951023931953, 5.654866776461628}, {0.20943951023931953, \
5.759586531581287}, {0.3141592653589793, 5.759586531581287}, 
     {0.3141592653589793, 5.654866776461628}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.20943951023931953, 5.759586531581287}, {0.20943951023931953, \
5.864306286700947}, {0.3141592653589793, 5.864306286700947}, 
     {0.3141592653589793, 5.759586531581287}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.20943951023931953, 5.864306286700947}, {0.20943951023931953, \
5.969026041820607}, {0.3141592653589793, 5.969026041820607}, 
     {0.3141592653589793, 5.864306286700947}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.20943951023931953, 5.969026041820607}, {0.20943951023931953, \
6.073745796940266}, {0.3141592653589793, 6.073745796940266}, 
     {0.3141592653589793, 5.969026041820607}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{0.20943951023931953, 6.073745796940266}, {0.20943951023931953, \
6.178465552059926}, {0.3141592653589793, 6.178465552059926}, 
     {0.3141592653589793, 6.073745796940266}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.20943951023931953, 6.178465552059926}, {0.20943951023931953, \
6.283185307179586}, {0.3141592653589793, 6.283185307179586}, 
     {0.3141592653589793, 6.178465552059926}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 0.}, {0.3141592653589793, \
0.10471975511965977}, {0.41887902047863906, 0.10471975511965977}, 
     {0.41887902047863906, 0.}}]}, {CMYKColor[0.11666666666666667, 0.5, \
0.025, 0.1], 
   Polygon[{{0.3141592653589793, 0.10471975511965977}, {0.3141592653589793, \
0.20943951023931953}, {0.41887902047863906, 0.20943951023931953}, 
     {0.41887902047863906, 0.10471975511965977}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.3141592653589793, 0.20943951023931953}, {0.3141592653589793, \
0.3141592653589793}, {0.41887902047863906, 0.3141592653589793}, 
     {0.41887902047863906, 0.20943951023931953}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.3141592653589793, 0.3141592653589793}, {0.3141592653589793, \
0.41887902047863906}, {0.41887902047863906, 0.41887902047863906}, 
     {0.41887902047863906, 0.3141592653589793}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{0.3141592653589793, 0.41887902047863906}, {0.3141592653589793, \
0.5235987755982988}, {0.41887902047863906, 0.5235987755982988}, 
     {0.41887902047863906, 0.41887902047863906}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.3141592653589793, 0.5235987755982988}, {0.3141592653589793, \
0.6283185307179586}, {0.41887902047863906, 0.6283185307179586}, 
     {0.41887902047863906, 0.5235987755982988}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.3141592653589793, 0.6283185307179586}, {0.3141592653589793, \
0.7330382858376183}, {0.41887902047863906, 0.7330382858376183}, 
     {0.41887902047863906, 0.6283185307179586}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{0.3141592653589793, 0.7330382858376183}, {0.3141592653589793, \
0.8377580409572781}, {0.41887902047863906, 0.8377580409572781}, 
     {0.41887902047863906, 0.7330382858376183}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.3141592653589793, 0.8377580409572781}, {0.3141592653589793, \
0.9424777960769379}, {0.41887902047863906, 0.9424777960769379}, 
     {0.41887902047863906, 0.8377580409572781}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 0.9424777960769379}, {0.3141592653589793, \
1.0471975511965976}, {0.41887902047863906, 1.0471975511965976}, 
     {0.41887902047863906, 0.9424777960769379}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{0.3141592653589793, 1.0471975511965976}, {0.3141592653589793, \
1.1519173063162573}, {0.41887902047863906, 1.1519173063162573}, 
     {0.41887902047863906, 1.0471975511965976}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.3141592653589793, 1.1519173063162573}, {0.3141592653589793, \
1.2566370614359172}, {0.41887902047863906, 1.2566370614359172}, 
     {0.41887902047863906, 1.1519173063162573}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.3141592653589793, 1.2566370614359172}, {0.3141592653589793, \
1.361356816555577}, {0.41887902047863906, 1.361356816555577}, 
     {0.41887902047863906, 1.2566370614359172}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{0.3141592653589793, 1.361356816555577}, {0.3141592653589793, \
1.4660765716752366}, {0.41887902047863906, 1.4660765716752366}, 
     {0.41887902047863906, 1.361356816555577}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.3141592653589793, 1.4660765716752366}, {0.3141592653589793, \
1.5707963267948966}, {0.41887902047863906, 1.5707963267948966}, 
     {0.41887902047863906, 1.4660765716752366}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 1.5707963267948966}, {0.3141592653589793, \
1.6755160819145563}, {0.41887902047863906, 1.6755160819145563}, 
     {0.41887902047863906, 1.5707963267948966}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{0.3141592653589793, 1.6755160819145563}, {0.3141592653589793, \
1.780235837034216}, {0.41887902047863906, 1.780235837034216}, 
     {0.41887902047863906, 1.6755160819145563}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0.3141592653589793, 1.780235837034216}, {0.3141592653589793, \
1.8849555921538759}, {0.41887902047863906, 1.8849555921538759}, 
     {0.41887902047863906, 1.780235837034216}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0.3141592653589793, 1.8849555921538759}, {0.3141592653589793, \
1.9896753472735356}, {0.41887902047863906, 1.9896753472735356}, 
     {0.41887902047863906, 1.8849555921538759}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{0.3141592653589793, 1.9896753472735356}, {0.3141592653589793, \
2.0943951023931953}, {0.41887902047863906, 2.0943951023931953}, 
     {0.41887902047863906, 1.9896753472735356}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{0.3141592653589793, 2.0943951023931953}, {0.3141592653589793, \
2.199114857512855}, {0.41887902047863906, 2.199114857512855}, 
     {0.41887902047863906, 2.0943951023931953}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0.3141592653589793, 2.199114857512855}, {0.3141592653589793, \
2.3038346126325147}, {0.41887902047863906, 2.3038346126325147}, 
     {0.41887902047863906, 2.199114857512855}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{0.3141592653589793, 2.3038346126325147}, {0.3141592653589793, \
2.4085543677521746}, {0.41887902047863906, 2.4085543677521746}, 
     {0.41887902047863906, 2.3038346126325147}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{0.3141592653589793, 2.4085543677521746}, {0.3141592653589793, \
2.5132741228718345}, {0.41887902047863906, 2.5132741228718345}, 
     {0.41887902047863906, 2.4085543677521746}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 2.5132741228718345}, {0.3141592653589793, \
2.617993877991494}, {0.41887902047863906, 2.617993877991494}, 
     {0.41887902047863906, 2.5132741228718345}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{0.3141592653589793, 2.617993877991494}, {0.3141592653589793, \
2.722713633111154}, {0.41887902047863906, 2.722713633111154}, 
     {0.41887902047863906, 2.617993877991494}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{0.3141592653589793, 2.722713633111154}, {0.3141592653589793, \
2.827433388230814}, {0.41887902047863906, 2.827433388230814}, 
     {0.41887902047863906, 2.722713633111154}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 2.827433388230814}, {0.3141592653589793, \
2.9321531433504733}, {0.41887902047863906, 2.9321531433504733}, 
     {0.41887902047863906, 2.827433388230814}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{0.3141592653589793, 2.9321531433504733}, {0.3141592653589793, \
3.036872898470133}, {0.41887902047863906, 3.036872898470133}, 
     {0.41887902047863906, 2.9321531433504733}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{0.3141592653589793, 3.036872898470133}, {0.3141592653589793, \
3.141592653589793}, {0.41887902047863906, 3.141592653589793}, 
     {0.41887902047863906, 3.036872898470133}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 3.141592653589793}, {0.3141592653589793, \
3.2463124087094526}, {0.41887902047863906, 3.2463124087094526}, 
     {0.41887902047863906, 3.141592653589793}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{0.3141592653589793, 3.2463124087094526}, {0.3141592653589793, \
3.3510321638291125}, {0.41887902047863906, 3.3510321638291125}, 
     {0.41887902047863906, 3.2463124087094526}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{0.3141592653589793, 3.3510321638291125}, {0.3141592653589793, \
3.4557519189487724}, {0.41887902047863906, 3.4557519189487724}, 
     {0.41887902047863906, 3.3510321638291125}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 3.4557519189487724}, {0.3141592653589793, \
3.560471674068432}, {0.41887902047863906, 3.560471674068432}, 
     {0.41887902047863906, 3.4557519189487724}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{0.3141592653589793, 3.560471674068432}, {0.3141592653589793, \
3.665191429188092}, {0.41887902047863906, 3.665191429188092}, 
     {0.41887902047863906, 3.560471674068432}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{0.3141592653589793, 3.665191429188092}, {0.3141592653589793, \
3.7699111843077517}, {0.41887902047863906, 3.7699111843077517}, 
     {0.41887902047863906, 3.665191429188092}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 3.7699111843077517}, {0.3141592653589793, \
3.874630939427411}, {0.41887902047863906, 3.874630939427411}, 
     {0.41887902047863906, 3.7699111843077517}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{0.3141592653589793, 3.874630939427411}, {0.3141592653589793, \
3.979350694547071}, {0.41887902047863906, 3.979350694547071}, 
     {0.41887902047863906, 3.874630939427411}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0.3141592653589793, 3.979350694547071}, {0.3141592653589793, \
4.084070449666731}, {0.41887902047863906, 4.084070449666731}, 
     {0.41887902047863906, 3.979350694547071}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 4.084070449666731}, {0.3141592653589793, \
4.1887902047863905}, {0.41887902047863906, 4.1887902047863905}, 
     {0.41887902047863906, 4.084070449666731}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{0.3141592653589793, 4.1887902047863905}, {0.3141592653589793, \
4.29350995990605}, {0.41887902047863906, 4.29350995990605}, 
     {0.41887902047863906, 4.1887902047863905}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0.3141592653589793, 4.29350995990605}, {0.3141592653589793, \
4.39822971502571}, {0.41887902047863906, 4.39822971502571}, 
     {0.41887902047863906, 4.29350995990605}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0.3141592653589793, 4.39822971502571}, {0.3141592653589793, \
4.50294947014537}, {0.41887902047863906, 4.50294947014537}, 
     {0.41887902047863906, 4.39822971502571}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{0.3141592653589793, 4.50294947014537}, {0.3141592653589793, \
4.607669225265029}, {0.41887902047863906, 4.607669225265029}, 
     {0.41887902047863906, 4.50294947014537}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.3141592653589793, 4.607669225265029}, {0.3141592653589793, \
4.71238898038469}, {0.41887902047863906, 4.71238898038469}, 
     {0.41887902047863906, 4.607669225265029}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 4.71238898038469}, {0.3141592653589793, \
4.817108735504349}, {0.41887902047863906, 4.817108735504349}, 
     {0.41887902047863906, 4.71238898038469}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.775, 0.1], 
   Polygon[{{0.3141592653589793, 4.817108735504349}, {0.3141592653589793, \
4.921828490624009}, {0.41887902047863906, 4.921828490624009}, 
     {0.41887902047863906, 4.817108735504349}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.3141592653589793, 4.921828490624009}, {0.3141592653589793, \
5.026548245743669}, {0.41887902047863906, 5.026548245743669}, 
     {0.41887902047863906, 4.921828490624009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 5.026548245743669}, {0.3141592653589793, \
5.1312680008633285}, {0.41887902047863906, 5.1312680008633285}, 
     {0.41887902047863906, 5.026548245743669}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{0.3141592653589793, 5.1312680008633285}, {0.3141592653589793, \
5.235987755982988}, {0.41887902047863906, 5.235987755982988}, 
     {0.41887902047863906, 5.1312680008633285}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.3141592653589793, 5.235987755982988}, {0.3141592653589793, \
5.340707511102648}, {0.41887902047863906, 5.340707511102648}, 
     {0.41887902047863906, 5.235987755982988}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 5.340707511102648}, {0.3141592653589793, \
5.445427266222308}, {0.41887902047863906, 5.445427266222308}, 
     {0.41887902047863906, 5.340707511102648}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{0.3141592653589793, 5.445427266222308}, {0.3141592653589793, \
5.550147021341967}, {0.41887902047863906, 5.550147021341967}, 
     {0.41887902047863906, 5.445427266222308}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.3141592653589793, 5.550147021341967}, {0.3141592653589793, \
5.654866776461628}, {0.41887902047863906, 5.654866776461628}, 
     {0.41887902047863906, 5.550147021341967}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.3141592653589793, 5.654866776461628}, {0.3141592653589793, \
5.759586531581287}, {0.41887902047863906, 5.759586531581287}, 
     {0.41887902047863906, 5.654866776461628}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.3141592653589793, 5.759586531581287}, {0.3141592653589793, \
5.864306286700947}, {0.41887902047863906, 5.864306286700947}, 
     {0.41887902047863906, 5.759586531581287}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.3141592653589793, 5.864306286700947}, {0.3141592653589793, \
5.969026041820607}, {0.41887902047863906, 5.969026041820607}, 
     {0.41887902047863906, 5.864306286700947}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.3141592653589793, 5.969026041820607}, {0.3141592653589793, \
6.073745796940266}, {0.41887902047863906, 6.073745796940266}, 
     {0.41887902047863906, 5.969026041820607}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{0.3141592653589793, 6.073745796940266}, {0.3141592653589793, \
6.178465552059926}, {0.41887902047863906, 6.178465552059926}, 
     {0.41887902047863906, 6.073745796940266}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.3141592653589793, 6.178465552059926}, {0.3141592653589793, \
6.283185307179586}, {0.41887902047863906, 6.283185307179586}, 
     {0.41887902047863906, 6.178465552059926}}]}, {CMYKColor[0.15, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 0.}, {0.41887902047863906, \
0.10471975511965977}, {0.5235987755982988, 0.10471975511965977}, 
     {0.5235987755982988, 0.}}]}, {CMYKColor[0.15, 0.5, 0.025, 0.1], 
   Polygon[{{0.41887902047863906, 0.10471975511965977}, {0.41887902047863906, \
0.20943951023931953}, {0.5235987755982988, 0.20943951023931953}, 
     {0.5235987755982988, 0.10471975511965977}}]}, {CMYKColor[0.15, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{0.41887902047863906, 0.20943951023931953}, {0.41887902047863906, \
0.3141592653589793}, {0.5235987755982988, 0.3141592653589793}, 
     {0.5235987755982988, 0.20943951023931953}}]}, {CMYKColor[0.15, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{0.41887902047863906, 0.3141592653589793}, {0.41887902047863906, \
0.41887902047863906}, {0.5235987755982988, 0.41887902047863906}, 
     {0.5235987755982988, 0.3141592653589793}}]}, {CMYKColor[0.15, 0.5, \
0.075, 0.1], 
   Polygon[{{0.41887902047863906, 0.41887902047863906}, {0.41887902047863906, \
0.5235987755982988}, {0.5235987755982988, 0.5235987755982988}, 
     {0.5235987755982988, 0.41887902047863906}}]}, {CMYKColor[0.15, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{0.41887902047863906, 0.5235987755982988}, {0.41887902047863906, \
0.6283185307179586}, {0.5235987755982988, 0.6283185307179586}, 
     {0.5235987755982988, 0.5235987755982988}}]}, {CMYKColor[0.15, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{0.41887902047863906, 0.6283185307179586}, {0.41887902047863906, \
0.7330382858376183}, {0.5235987755982988, 0.7330382858376183}, 
     {0.5235987755982988, 0.6283185307179586}}]}, {CMYKColor[0.15, 0.5, \
0.125, 0.1], 
   Polygon[{{0.41887902047863906, 0.7330382858376183}, {0.41887902047863906, \
0.8377580409572781}, {0.5235987755982988, 0.8377580409572781}, 
     {0.5235987755982988, 0.7330382858376183}}]}, {CMYKColor[0.15, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{0.41887902047863906, 0.8377580409572781}, {0.41887902047863906, \
0.9424777960769379}, {0.5235987755982988, 0.9424777960769379}, 
     {0.5235987755982988, 0.8377580409572781}}]}, {CMYKColor[0.15, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 0.9424777960769379}, {0.41887902047863906, \
1.0471975511965976}, {0.5235987755982988, 1.0471975511965976}, 
     {0.5235987755982988, 0.9424777960769379}}]}, {CMYKColor[0.15, 0.5, \
0.175, 0.1], 
   Polygon[{{0.41887902047863906, 1.0471975511965976}, {0.41887902047863906, \
1.1519173063162573}, {0.5235987755982988, 1.1519173063162573}, 
     {0.5235987755982988, 1.0471975511965976}}]}, {CMYKColor[0.15, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{0.41887902047863906, 1.1519173063162573}, {0.41887902047863906, \
1.2566370614359172}, {0.5235987755982988, 1.2566370614359172}, 
     {0.5235987755982988, 1.1519173063162573}}]}, {CMYKColor[0.15, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{0.41887902047863906, 1.2566370614359172}, {0.41887902047863906, \
1.361356816555577}, {0.5235987755982988, 1.361356816555577}, 
     {0.5235987755982988, 1.2566370614359172}}]}, {CMYKColor[0.15, 0.5, \
0.225, 0.1], 
   Polygon[{{0.41887902047863906, 1.361356816555577}, {0.41887902047863906, \
1.4660765716752366}, {0.5235987755982988, 1.4660765716752366}, 
     {0.5235987755982988, 1.361356816555577}}]}, {CMYKColor[0.15, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{0.41887902047863906, 1.4660765716752366}, {0.41887902047863906, \
1.5707963267948966}, {0.5235987755982988, 1.5707963267948966}, 
     {0.5235987755982988, 1.4660765716752366}}]}, {CMYKColor[0.15, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 1.5707963267948966}, {0.41887902047863906, \
1.6755160819145563}, {0.5235987755982988, 1.6755160819145563}, 
     {0.5235987755982988, 1.5707963267948966}}]}, {CMYKColor[0.15, 0.5, \
0.275, 0.1], 
   Polygon[{{0.41887902047863906, 1.6755160819145563}, {0.41887902047863906, \
1.780235837034216}, {0.5235987755982988, 1.780235837034216}, 
     {0.5235987755982988, 1.6755160819145563}}]}, {CMYKColor[0.15, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{0.41887902047863906, 1.780235837034216}, {0.41887902047863906, \
1.8849555921538759}, {0.5235987755982988, 1.8849555921538759}, 
     {0.5235987755982988, 1.780235837034216}}]}, {CMYKColor[0.15, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{0.41887902047863906, 1.8849555921538759}, {0.41887902047863906, \
1.9896753472735356}, {0.5235987755982988, 1.9896753472735356}, 
     {0.5235987755982988, 1.8849555921538759}}]}, {CMYKColor[0.15, 0.5, \
0.325, 0.1], 
   Polygon[{{0.41887902047863906, 1.9896753472735356}, {0.41887902047863906, \
2.0943951023931953}, {0.5235987755982988, 2.0943951023931953}, 
     {0.5235987755982988, 1.9896753472735356}}]}, {CMYKColor[0.15, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{0.41887902047863906, 2.0943951023931953}, {0.41887902047863906, \
2.199114857512855}, {0.5235987755982988, 2.199114857512855}, 
     {0.5235987755982988, 2.0943951023931953}}]}, {CMYKColor[0.15, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{0.41887902047863906, 2.199114857512855}, {0.41887902047863906, \
2.3038346126325147}, {0.5235987755982988, 2.3038346126325147}, 
     {0.5235987755982988, 2.199114857512855}}]}, {CMYKColor[0.15, 0.5, 0.375, \
0.1], 
   Polygon[{{0.41887902047863906, 2.3038346126325147}, {0.41887902047863906, \
2.4085543677521746}, {0.5235987755982988, 2.4085543677521746}, 
     {0.5235987755982988, 2.3038346126325147}}]}, {CMYKColor[0.15, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{0.41887902047863906, 2.4085543677521746}, {0.41887902047863906, \
2.5132741228718345}, {0.5235987755982988, 2.5132741228718345}, 
     {0.5235987755982988, 2.4085543677521746}}]}, {CMYKColor[0.15, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 2.5132741228718345}, {0.41887902047863906, \
2.617993877991494}, {0.5235987755982988, 2.617993877991494}, 
     {0.5235987755982988, 2.5132741228718345}}]}, {CMYKColor[0.15, 0.5, \
0.425, 0.1], 
   Polygon[{{0.41887902047863906, 2.617993877991494}, {0.41887902047863906, \
2.722713633111154}, {0.5235987755982988, 2.722713633111154}, 
     {0.5235987755982988, 2.617993877991494}}]}, {CMYKColor[0.15, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{0.41887902047863906, 2.722713633111154}, {0.41887902047863906, \
2.827433388230814}, {0.5235987755982988, 2.827433388230814}, 
     {0.5235987755982988, 2.722713633111154}}]}, {CMYKColor[0.15, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 2.827433388230814}, {0.41887902047863906, \
2.9321531433504733}, {0.5235987755982988, 2.9321531433504733}, 
     {0.5235987755982988, 2.827433388230814}}]}, {CMYKColor[0.15, 0.5, 0.475, \
0.1], 
   Polygon[{{0.41887902047863906, 2.9321531433504733}, {0.41887902047863906, \
3.036872898470133}, {0.5235987755982988, 3.036872898470133}, 
     {0.5235987755982988, 2.9321531433504733}}]}, {CMYKColor[0.15, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{0.41887902047863906, 3.036872898470133}, {0.41887902047863906, \
3.141592653589793}, {0.5235987755982988, 3.141592653589793}, 
     {0.5235987755982988, 3.036872898470133}}]}, {CMYKColor[0.15, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 3.141592653589793}, {0.41887902047863906, \
3.2463124087094526}, {0.5235987755982988, 3.2463124087094526}, 
     {0.5235987755982988, 3.141592653589793}}]}, {CMYKColor[0.15, 0.5, 0.525, \
0.1], 
   Polygon[{{0.41887902047863906, 3.2463124087094526}, {0.41887902047863906, \
3.3510321638291125}, {0.5235987755982988, 3.3510321638291125}, 
     {0.5235987755982988, 3.2463124087094526}}]}, {CMYKColor[0.15, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{0.41887902047863906, 3.3510321638291125}, {0.41887902047863906, \
3.4557519189487724}, {0.5235987755982988, 3.4557519189487724}, 
     {0.5235987755982988, 3.3510321638291125}}]}, {CMYKColor[0.15, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 3.4557519189487724}, {0.41887902047863906, \
3.560471674068432}, {0.5235987755982988, 3.560471674068432}, 
     {0.5235987755982988, 3.4557519189487724}}]}, {CMYKColor[0.15, 0.5, \
0.575, 0.1], 
   Polygon[{{0.41887902047863906, 3.560471674068432}, {0.41887902047863906, \
3.665191429188092}, {0.5235987755982988, 3.665191429188092}, 
     {0.5235987755982988, 3.560471674068432}}]}, {CMYKColor[0.15, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{0.41887902047863906, 3.665191429188092}, {0.41887902047863906, \
3.7699111843077517}, {0.5235987755982988, 3.7699111843077517}, 
     {0.5235987755982988, 3.665191429188092}}]}, {CMYKColor[0.15, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 3.7699111843077517}, {0.41887902047863906, \
3.874630939427411}, {0.5235987755982988, 3.874630939427411}, 
     {0.5235987755982988, 3.7699111843077517}}]}, {CMYKColor[0.15, 0.5, \
0.625, 0.1], 
   Polygon[{{0.41887902047863906, 3.874630939427411}, {0.41887902047863906, \
3.979350694547071}, {0.5235987755982988, 3.979350694547071}, 
     {0.5235987755982988, 3.874630939427411}}]}, {CMYKColor[0.15, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{0.41887902047863906, 3.979350694547071}, {0.41887902047863906, \
4.084070449666731}, {0.5235987755982988, 4.084070449666731}, 
     {0.5235987755982988, 3.979350694547071}}]}, {CMYKColor[0.15, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 4.084070449666731}, {0.41887902047863906, \
4.1887902047863905}, {0.5235987755982988, 4.1887902047863905}, 
     {0.5235987755982988, 4.084070449666731}}]}, {CMYKColor[0.15, 0.5, 0.675, \
0.1], 
   Polygon[{{0.41887902047863906, 4.1887902047863905}, {0.41887902047863906, \
4.29350995990605}, {0.5235987755982988, 4.29350995990605}, 
     {0.5235987755982988, 4.1887902047863905}}]}, {CMYKColor[0.15, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{0.41887902047863906, 4.29350995990605}, {0.41887902047863906, \
4.39822971502571}, {0.5235987755982988, 4.39822971502571}, 
     {0.5235987755982988, 4.29350995990605}}]}, {CMYKColor[0.15, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{0.41887902047863906, 4.39822971502571}, {0.41887902047863906, \
4.50294947014537}, {0.5235987755982988, 4.50294947014537}, 
     {0.5235987755982988, 4.39822971502571}}]}, {CMYKColor[0.15, 0.5, 0.725, \
0.1], 
   Polygon[{{0.41887902047863906, 4.50294947014537}, {0.41887902047863906, \
4.607669225265029}, {0.5235987755982988, 4.607669225265029}, 
     {0.5235987755982988, 4.50294947014537}}]}, {CMYKColor[0.15, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{0.41887902047863906, 4.607669225265029}, {0.41887902047863906, \
4.71238898038469}, {0.5235987755982988, 4.71238898038469}, 
     {0.5235987755982988, 4.607669225265029}}]}, {CMYKColor[0.15, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 4.71238898038469}, {0.41887902047863906, \
4.817108735504349}, {0.5235987755982988, 4.817108735504349}, 
     {0.5235987755982988, 4.71238898038469}}]}, {CMYKColor[0.15, 0.5, 0.775, \
0.1], 
   Polygon[{{0.41887902047863906, 4.817108735504349}, {0.41887902047863906, \
4.921828490624009}, {0.5235987755982988, 4.921828490624009}, 
     {0.5235987755982988, 4.817108735504349}}]}, {CMYKColor[0.15, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{0.41887902047863906, 4.921828490624009}, {0.41887902047863906, \
5.026548245743669}, {0.5235987755982988, 5.026548245743669}, 
     {0.5235987755982988, 4.921828490624009}}]}, {CMYKColor[0.15, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 5.026548245743669}, {0.41887902047863906, \
5.1312680008633285}, {0.5235987755982988, 5.1312680008633285}, 
     {0.5235987755982988, 5.026548245743669}}]}, {CMYKColor[0.15, 0.5, 0.825, \
0.1], 
   Polygon[{{0.41887902047863906, 5.1312680008633285}, {0.41887902047863906, \
5.235987755982988}, {0.5235987755982988, 5.235987755982988}, 
     {0.5235987755982988, 5.1312680008633285}}]}, {CMYKColor[0.15, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{0.41887902047863906, 5.235987755982988}, {0.41887902047863906, \
5.340707511102648}, {0.5235987755982988, 5.340707511102648}, 
     {0.5235987755982988, 5.235987755982988}}]}, {CMYKColor[0.15, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 5.340707511102648}, {0.41887902047863906, \
5.445427266222308}, {0.5235987755982988, 5.445427266222308}, 
     {0.5235987755982988, 5.340707511102648}}]}, {CMYKColor[0.15, 0.5, 0.875, \
0.1], 
   Polygon[{{0.41887902047863906, 5.445427266222308}, {0.41887902047863906, \
5.550147021341967}, {0.5235987755982988, 5.550147021341967}, 
     {0.5235987755982988, 5.445427266222308}}]}, {CMYKColor[0.15, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{0.41887902047863906, 5.550147021341967}, {0.41887902047863906, \
5.654866776461628}, {0.5235987755982988, 5.654866776461628}, 
     {0.5235987755982988, 5.550147021341967}}]}, {CMYKColor[0.15, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{0.41887902047863906, 5.654866776461628}, {0.41887902047863906, \
5.759586531581287}, {0.5235987755982988, 5.759586531581287}, 
     {0.5235987755982988, 5.654866776461628}}]}, {CMYKColor[0.15, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{0.41887902047863906, 5.759586531581287}, {0.41887902047863906, \
5.864306286700947}, {0.5235987755982988, 5.864306286700947}, 
     {0.5235987755982988, 5.759586531581287}}]}, {CMYKColor[0.15, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{0.41887902047863906, 5.864306286700947}, {0.41887902047863906, \
5.969026041820607}, {0.5235987755982988, 5.969026041820607}, 
     {0.5235987755982988, 5.864306286700947}}]}, {CMYKColor[0.15, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{0.41887902047863906, 5.969026041820607}, {0.41887902047863906, \
6.073745796940266}, {0.5235987755982988, 6.073745796940266}, 
     {0.5235987755982988, 5.969026041820607}}]}, {CMYKColor[0.15, 0.5, 0.975, \
0.1], 
   Polygon[{{0.41887902047863906, 6.073745796940266}, {0.41887902047863906, \
6.178465552059926}, {0.5235987755982988, 6.178465552059926}, 
     {0.5235987755982988, 6.073745796940266}}]}, {CMYKColor[0.15, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{0.41887902047863906, 6.178465552059926}, {0.41887902047863906, \
6.283185307179586}, {0.5235987755982988, 6.283185307179586}, 
     {0.5235987755982988, 6.178465552059926}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 0.}, {0.5235987755982988, \
0.10471975511965977}, {0.6283185307179586, 0.10471975511965977}, 
     {0.6283185307179586, 0.}}]}, {CMYKColor[0.18333333333333332, 0.5, 0.025, \
0.1], 
   Polygon[{{0.5235987755982988, 0.10471975511965977}, {0.5235987755982988, \
0.20943951023931953}, {0.6283185307179586, 0.20943951023931953}, 
     {0.6283185307179586, 0.10471975511965977}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.5235987755982988, 0.20943951023931953}, {0.5235987755982988, \
0.3141592653589793}, {0.6283185307179586, 0.3141592653589793}, 
     {0.6283185307179586, 0.20943951023931953}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.5235987755982988, 0.3141592653589793}, {0.5235987755982988, \
0.41887902047863906}, {0.6283185307179586, 0.41887902047863906}, 
     {0.6283185307179586, 0.3141592653589793}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.075, 0.1], 
   Polygon[{{0.5235987755982988, 0.41887902047863906}, {0.5235987755982988, \
0.5235987755982988}, {0.6283185307179586, 0.5235987755982988}, 
     {0.6283185307179586, 0.41887902047863906}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.5235987755982988, 0.5235987755982988}, {0.5235987755982988, \
0.6283185307179586}, {0.6283185307179586, 0.6283185307179586}, 
     {0.6283185307179586, 0.5235987755982988}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.5235987755982988, 0.6283185307179586}, {0.5235987755982988, \
0.7330382858376183}, {0.6283185307179586, 0.7330382858376183}, 
     {0.6283185307179586, 0.6283185307179586}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.125, 0.1], 
   Polygon[{{0.5235987755982988, 0.7330382858376183}, {0.5235987755982988, \
0.8377580409572781}, {0.6283185307179586, 0.8377580409572781}, 
     {0.6283185307179586, 0.7330382858376183}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.5235987755982988, 0.8377580409572781}, {0.5235987755982988, \
0.9424777960769379}, {0.6283185307179586, 0.9424777960769379}, 
     {0.6283185307179586, 0.8377580409572781}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 0.9424777960769379}, {0.5235987755982988, \
1.0471975511965976}, {0.6283185307179586, 1.0471975511965976}, 
     {0.6283185307179586, 0.9424777960769379}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.175, 0.1], 
   Polygon[{{0.5235987755982988, 1.0471975511965976}, {0.5235987755982988, \
1.1519173063162573}, {0.6283185307179586, 1.1519173063162573}, 
     {0.6283185307179586, 1.0471975511965976}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.5235987755982988, 1.1519173063162573}, {0.5235987755982988, \
1.2566370614359172}, {0.6283185307179586, 1.2566370614359172}, 
     {0.6283185307179586, 1.1519173063162573}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.5235987755982988, 1.2566370614359172}, {0.5235987755982988, \
1.361356816555577}, {0.6283185307179586, 1.361356816555577}, 
     {0.6283185307179586, 1.2566370614359172}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.225, 0.1], 
   Polygon[{{0.5235987755982988, 1.361356816555577}, {0.5235987755982988, \
1.4660765716752366}, {0.6283185307179586, 1.4660765716752366}, 
     {0.6283185307179586, 1.361356816555577}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.5235987755982988, 1.4660765716752366}, {0.5235987755982988, \
1.5707963267948966}, {0.6283185307179586, 1.5707963267948966}, 
     {0.6283185307179586, 1.4660765716752366}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 1.5707963267948966}, {0.5235987755982988, \
1.6755160819145563}, {0.6283185307179586, 1.6755160819145563}, 
     {0.6283185307179586, 1.5707963267948966}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.275, 0.1], 
   Polygon[{{0.5235987755982988, 1.6755160819145563}, {0.5235987755982988, \
1.780235837034216}, {0.6283185307179586, 1.780235837034216}, 
     {0.6283185307179586, 1.6755160819145563}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0.5235987755982988, 1.780235837034216}, {0.5235987755982988, \
1.8849555921538759}, {0.6283185307179586, 1.8849555921538759}, 
     {0.6283185307179586, 1.780235837034216}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0.5235987755982988, 1.8849555921538759}, {0.5235987755982988, \
1.9896753472735356}, {0.6283185307179586, 1.9896753472735356}, 
     {0.6283185307179586, 1.8849555921538759}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.325, 0.1], 
   Polygon[{{0.5235987755982988, 1.9896753472735356}, {0.5235987755982988, \
2.0943951023931953}, {0.6283185307179586, 2.0943951023931953}, 
     {0.6283185307179586, 1.9896753472735356}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{0.5235987755982988, 2.0943951023931953}, {0.5235987755982988, \
2.199114857512855}, {0.6283185307179586, 2.199114857512855}, 
     {0.6283185307179586, 2.0943951023931953}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0.5235987755982988, 2.199114857512855}, {0.5235987755982988, \
2.3038346126325147}, {0.6283185307179586, 2.3038346126325147}, 
     {0.6283185307179586, 2.199114857512855}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.375, 0.1], 
   Polygon[{{0.5235987755982988, 2.3038346126325147}, {0.5235987755982988, \
2.4085543677521746}, {0.6283185307179586, 2.4085543677521746}, 
     {0.6283185307179586, 2.3038346126325147}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{0.5235987755982988, 2.4085543677521746}, {0.5235987755982988, \
2.5132741228718345}, {0.6283185307179586, 2.5132741228718345}, 
     {0.6283185307179586, 2.4085543677521746}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 2.5132741228718345}, {0.5235987755982988, \
2.617993877991494}, {0.6283185307179586, 2.617993877991494}, 
     {0.6283185307179586, 2.5132741228718345}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.425, 0.1], 
   Polygon[{{0.5235987755982988, 2.617993877991494}, {0.5235987755982988, \
2.722713633111154}, {0.6283185307179586, 2.722713633111154}, 
     {0.6283185307179586, 2.617993877991494}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{0.5235987755982988, 2.722713633111154}, {0.5235987755982988, \
2.827433388230814}, {0.6283185307179586, 2.827433388230814}, 
     {0.6283185307179586, 2.722713633111154}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 2.827433388230814}, {0.5235987755982988, \
2.9321531433504733}, {0.6283185307179586, 2.9321531433504733}, 
     {0.6283185307179586, 2.827433388230814}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.475, 0.1], 
   Polygon[{{0.5235987755982988, 2.9321531433504733}, {0.5235987755982988, \
3.036872898470133}, {0.6283185307179586, 3.036872898470133}, 
     {0.6283185307179586, 2.9321531433504733}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{0.5235987755982988, 3.036872898470133}, {0.5235987755982988, \
3.141592653589793}, {0.6283185307179586, 3.141592653589793}, 
     {0.6283185307179586, 3.036872898470133}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 3.141592653589793}, {0.5235987755982988, \
3.2463124087094526}, {0.6283185307179586, 3.2463124087094526}, 
     {0.6283185307179586, 3.141592653589793}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.525, 0.1], 
   Polygon[{{0.5235987755982988, 3.2463124087094526}, {0.5235987755982988, \
3.3510321638291125}, {0.6283185307179586, 3.3510321638291125}, 
     {0.6283185307179586, 3.2463124087094526}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{0.5235987755982988, 3.3510321638291125}, {0.5235987755982988, \
3.4557519189487724}, {0.6283185307179586, 3.4557519189487724}, 
     {0.6283185307179586, 3.3510321638291125}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 3.4557519189487724}, {0.5235987755982988, \
3.560471674068432}, {0.6283185307179586, 3.560471674068432}, 
     {0.6283185307179586, 3.4557519189487724}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.575, 0.1], 
   Polygon[{{0.5235987755982988, 3.560471674068432}, {0.5235987755982988, \
3.665191429188092}, {0.6283185307179586, 3.665191429188092}, 
     {0.6283185307179586, 3.560471674068432}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{0.5235987755982988, 3.665191429188092}, {0.5235987755982988, \
3.7699111843077517}, {0.6283185307179586, 3.7699111843077517}, 
     {0.6283185307179586, 3.665191429188092}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 3.7699111843077517}, {0.5235987755982988, \
3.874630939427411}, {0.6283185307179586, 3.874630939427411}, 
     {0.6283185307179586, 3.7699111843077517}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.625, 0.1], 
   Polygon[{{0.5235987755982988, 3.874630939427411}, {0.5235987755982988, \
3.979350694547071}, {0.6283185307179586, 3.979350694547071}, 
     {0.6283185307179586, 3.874630939427411}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0.5235987755982988, 3.979350694547071}, {0.5235987755982988, \
4.084070449666731}, {0.6283185307179586, 4.084070449666731}, 
     {0.6283185307179586, 3.979350694547071}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 4.084070449666731}, {0.5235987755982988, \
4.1887902047863905}, {0.6283185307179586, 4.1887902047863905}, 
     {0.6283185307179586, 4.084070449666731}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.675, 0.1], 
   Polygon[{{0.5235987755982988, 4.1887902047863905}, {0.5235987755982988, \
4.29350995990605}, {0.6283185307179586, 4.29350995990605}, 
     {0.6283185307179586, 4.1887902047863905}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0.5235987755982988, 4.29350995990605}, {0.5235987755982988, \
4.39822971502571}, {0.6283185307179586, 4.39822971502571}, 
     {0.6283185307179586, 4.29350995990605}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0.5235987755982988, 4.39822971502571}, {0.5235987755982988, \
4.50294947014537}, {0.6283185307179586, 4.50294947014537}, 
     {0.6283185307179586, 4.39822971502571}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.725, 0.1], 
   Polygon[{{0.5235987755982988, 4.50294947014537}, {0.5235987755982988, \
4.607669225265029}, {0.6283185307179586, 4.607669225265029}, 
     {0.6283185307179586, 4.50294947014537}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.5235987755982988, 4.607669225265029}, {0.5235987755982988, \
4.71238898038469}, {0.6283185307179586, 4.71238898038469}, 
     {0.6283185307179586, 4.607669225265029}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 4.71238898038469}, {0.5235987755982988, \
4.817108735504349}, {0.6283185307179586, 4.817108735504349}, 
     {0.6283185307179586, 4.71238898038469}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.775, 0.1], 
   Polygon[{{0.5235987755982988, 4.817108735504349}, {0.5235987755982988, \
4.921828490624009}, {0.6283185307179586, 4.921828490624009}, 
     {0.6283185307179586, 4.817108735504349}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.5235987755982988, 4.921828490624009}, {0.5235987755982988, \
5.026548245743669}, {0.6283185307179586, 5.026548245743669}, 
     {0.6283185307179586, 4.921828490624009}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 5.026548245743669}, {0.5235987755982988, \
5.1312680008633285}, {0.6283185307179586, 5.1312680008633285}, 
     {0.6283185307179586, 5.026548245743669}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.825, 0.1], 
   Polygon[{{0.5235987755982988, 5.1312680008633285}, {0.5235987755982988, \
5.235987755982988}, {0.6283185307179586, 5.235987755982988}, 
     {0.6283185307179586, 5.1312680008633285}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.5235987755982988, 5.235987755982988}, {0.5235987755982988, \
5.340707511102648}, {0.6283185307179586, 5.340707511102648}, 
     {0.6283185307179586, 5.235987755982988}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 5.340707511102648}, {0.5235987755982988, \
5.445427266222308}, {0.6283185307179586, 5.445427266222308}, 
     {0.6283185307179586, 5.340707511102648}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.875, 0.1], 
   Polygon[{{0.5235987755982988, 5.445427266222308}, {0.5235987755982988, \
5.550147021341967}, {0.6283185307179586, 5.550147021341967}, 
     {0.6283185307179586, 5.445427266222308}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.5235987755982988, 5.550147021341967}, {0.5235987755982988, \
5.654866776461628}, {0.6283185307179586, 5.654866776461628}, 
     {0.6283185307179586, 5.550147021341967}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.5235987755982988, 5.654866776461628}, {0.5235987755982988, \
5.759586531581287}, {0.6283185307179586, 5.759586531581287}, 
     {0.6283185307179586, 5.654866776461628}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.5235987755982988, 5.759586531581287}, {0.5235987755982988, \
5.864306286700947}, {0.6283185307179586, 5.864306286700947}, 
     {0.6283185307179586, 5.759586531581287}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.5235987755982988, 5.864306286700947}, {0.5235987755982988, \
5.969026041820607}, {0.6283185307179586, 5.969026041820607}, 
     {0.6283185307179586, 5.864306286700947}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.5235987755982988, 5.969026041820607}, {0.5235987755982988, \
6.073745796940266}, {0.6283185307179586, 6.073745796940266}, 
     {0.6283185307179586, 5.969026041820607}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.975, 0.1], 
   Polygon[{{0.5235987755982988, 6.073745796940266}, {0.5235987755982988, \
6.178465552059926}, {0.6283185307179586, 6.178465552059926}, 
     {0.6283185307179586, 6.073745796940266}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.5235987755982988, 6.178465552059926}, {0.5235987755982988, \
6.283185307179586}, {0.6283185307179586, 6.283185307179586}, 
     {0.6283185307179586, 6.178465552059926}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 0.}, {0.6283185307179586, \
0.10471975511965977}, {0.7330382858376183, 0.10471975511965977}, 
     {0.7330382858376183, 0.}}]}, {CMYKColor[0.21666666666666667, 0.5, 0.025, \
0.1], 
   Polygon[{{0.6283185307179586, 0.10471975511965977}, {0.6283185307179586, \
0.20943951023931953}, {0.7330382858376183, 0.20943951023931953}, 
     {0.7330382858376183, 0.10471975511965977}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.6283185307179586, 0.20943951023931953}, {0.6283185307179586, \
0.3141592653589793}, {0.7330382858376183, 0.3141592653589793}, 
     {0.7330382858376183, 0.20943951023931953}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.6283185307179586, 0.3141592653589793}, {0.6283185307179586, \
0.41887902047863906}, {0.7330382858376183, 0.41887902047863906}, 
     {0.7330382858376183, 0.3141592653589793}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{0.6283185307179586, 0.41887902047863906}, {0.6283185307179586, \
0.5235987755982988}, {0.7330382858376183, 0.5235987755982988}, 
     {0.7330382858376183, 0.41887902047863906}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.6283185307179586, 0.5235987755982988}, {0.6283185307179586, \
0.6283185307179586}, {0.7330382858376183, 0.6283185307179586}, 
     {0.7330382858376183, 0.5235987755982988}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.6283185307179586, 0.6283185307179586}, {0.6283185307179586, \
0.7330382858376183}, {0.7330382858376183, 0.7330382858376183}, 
     {0.7330382858376183, 0.6283185307179586}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{0.6283185307179586, 0.7330382858376183}, {0.6283185307179586, \
0.8377580409572781}, {0.7330382858376183, 0.8377580409572781}, 
     {0.7330382858376183, 0.7330382858376183}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.6283185307179586, 0.8377580409572781}, {0.6283185307179586, \
0.9424777960769379}, {0.7330382858376183, 0.9424777960769379}, 
     {0.7330382858376183, 0.8377580409572781}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 0.9424777960769379}, {0.6283185307179586, \
1.0471975511965976}, {0.7330382858376183, 1.0471975511965976}, 
     {0.7330382858376183, 0.9424777960769379}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{0.6283185307179586, 1.0471975511965976}, {0.6283185307179586, \
1.1519173063162573}, {0.7330382858376183, 1.1519173063162573}, 
     {0.7330382858376183, 1.0471975511965976}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.6283185307179586, 1.1519173063162573}, {0.6283185307179586, \
1.2566370614359172}, {0.7330382858376183, 1.2566370614359172}, 
     {0.7330382858376183, 1.1519173063162573}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.6283185307179586, 1.2566370614359172}, {0.6283185307179586, \
1.361356816555577}, {0.7330382858376183, 1.361356816555577}, 
     {0.7330382858376183, 1.2566370614359172}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{0.6283185307179586, 1.361356816555577}, {0.6283185307179586, \
1.4660765716752366}, {0.7330382858376183, 1.4660765716752366}, 
     {0.7330382858376183, 1.361356816555577}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.6283185307179586, 1.4660765716752366}, {0.6283185307179586, \
1.5707963267948966}, {0.7330382858376183, 1.5707963267948966}, 
     {0.7330382858376183, 1.4660765716752366}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 1.5707963267948966}, {0.6283185307179586, \
1.6755160819145563}, {0.7330382858376183, 1.6755160819145563}, 
     {0.7330382858376183, 1.5707963267948966}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{0.6283185307179586, 1.6755160819145563}, {0.6283185307179586, \
1.780235837034216}, {0.7330382858376183, 1.780235837034216}, 
     {0.7330382858376183, 1.6755160819145563}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0.6283185307179586, 1.780235837034216}, {0.6283185307179586, \
1.8849555921538759}, {0.7330382858376183, 1.8849555921538759}, 
     {0.7330382858376183, 1.780235837034216}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0.6283185307179586, 1.8849555921538759}, {0.6283185307179586, \
1.9896753472735356}, {0.7330382858376183, 1.9896753472735356}, 
     {0.7330382858376183, 1.8849555921538759}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{0.6283185307179586, 1.9896753472735356}, {0.6283185307179586, \
2.0943951023931953}, {0.7330382858376183, 2.0943951023931953}, 
     {0.7330382858376183, 1.9896753472735356}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{0.6283185307179586, 2.0943951023931953}, {0.6283185307179586, \
2.199114857512855}, {0.7330382858376183, 2.199114857512855}, 
     {0.7330382858376183, 2.0943951023931953}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0.6283185307179586, 2.199114857512855}, {0.6283185307179586, \
2.3038346126325147}, {0.7330382858376183, 2.3038346126325147}, 
     {0.7330382858376183, 2.199114857512855}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{0.6283185307179586, 2.3038346126325147}, {0.6283185307179586, \
2.4085543677521746}, {0.7330382858376183, 2.4085543677521746}, 
     {0.7330382858376183, 2.3038346126325147}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{0.6283185307179586, 2.4085543677521746}, {0.6283185307179586, \
2.5132741228718345}, {0.7330382858376183, 2.5132741228718345}, 
     {0.7330382858376183, 2.4085543677521746}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 2.5132741228718345}, {0.6283185307179586, \
2.617993877991494}, {0.7330382858376183, 2.617993877991494}, 
     {0.7330382858376183, 2.5132741228718345}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{0.6283185307179586, 2.617993877991494}, {0.6283185307179586, \
2.722713633111154}, {0.7330382858376183, 2.722713633111154}, 
     {0.7330382858376183, 2.617993877991494}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{0.6283185307179586, 2.722713633111154}, {0.6283185307179586, \
2.827433388230814}, {0.7330382858376183, 2.827433388230814}, 
     {0.7330382858376183, 2.722713633111154}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 2.827433388230814}, {0.6283185307179586, \
2.9321531433504733}, {0.7330382858376183, 2.9321531433504733}, 
     {0.7330382858376183, 2.827433388230814}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{0.6283185307179586, 2.9321531433504733}, {0.6283185307179586, \
3.036872898470133}, {0.7330382858376183, 3.036872898470133}, 
     {0.7330382858376183, 2.9321531433504733}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{0.6283185307179586, 3.036872898470133}, {0.6283185307179586, \
3.141592653589793}, {0.7330382858376183, 3.141592653589793}, 
     {0.7330382858376183, 3.036872898470133}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 3.141592653589793}, {0.6283185307179586, \
3.2463124087094526}, {0.7330382858376183, 3.2463124087094526}, 
     {0.7330382858376183, 3.141592653589793}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{0.6283185307179586, 3.2463124087094526}, {0.6283185307179586, \
3.3510321638291125}, {0.7330382858376183, 3.3510321638291125}, 
     {0.7330382858376183, 3.2463124087094526}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{0.6283185307179586, 3.3510321638291125}, {0.6283185307179586, \
3.4557519189487724}, {0.7330382858376183, 3.4557519189487724}, 
     {0.7330382858376183, 3.3510321638291125}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 3.4557519189487724}, {0.6283185307179586, \
3.560471674068432}, {0.7330382858376183, 3.560471674068432}, 
     {0.7330382858376183, 3.4557519189487724}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{0.6283185307179586, 3.560471674068432}, {0.6283185307179586, \
3.665191429188092}, {0.7330382858376183, 3.665191429188092}, 
     {0.7330382858376183, 3.560471674068432}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{0.6283185307179586, 3.665191429188092}, {0.6283185307179586, \
3.7699111843077517}, {0.7330382858376183, 3.7699111843077517}, 
     {0.7330382858376183, 3.665191429188092}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 3.7699111843077517}, {0.6283185307179586, \
3.874630939427411}, {0.7330382858376183, 3.874630939427411}, 
     {0.7330382858376183, 3.7699111843077517}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{0.6283185307179586, 3.874630939427411}, {0.6283185307179586, \
3.979350694547071}, {0.7330382858376183, 3.979350694547071}, 
     {0.7330382858376183, 3.874630939427411}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0.6283185307179586, 3.979350694547071}, {0.6283185307179586, \
4.084070449666731}, {0.7330382858376183, 4.084070449666731}, 
     {0.7330382858376183, 3.979350694547071}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 4.084070449666731}, {0.6283185307179586, \
4.1887902047863905}, {0.7330382858376183, 4.1887902047863905}, 
     {0.7330382858376183, 4.084070449666731}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{0.6283185307179586, 4.1887902047863905}, {0.6283185307179586, \
4.29350995990605}, {0.7330382858376183, 4.29350995990605}, 
     {0.7330382858376183, 4.1887902047863905}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0.6283185307179586, 4.29350995990605}, {0.6283185307179586, \
4.39822971502571}, {0.7330382858376183, 4.39822971502571}, 
     {0.7330382858376183, 4.29350995990605}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0.6283185307179586, 4.39822971502571}, {0.6283185307179586, \
4.50294947014537}, {0.7330382858376183, 4.50294947014537}, 
     {0.7330382858376183, 4.39822971502571}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{0.6283185307179586, 4.50294947014537}, {0.6283185307179586, \
4.607669225265029}, {0.7330382858376183, 4.607669225265029}, 
     {0.7330382858376183, 4.50294947014537}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.6283185307179586, 4.607669225265029}, {0.6283185307179586, \
4.71238898038469}, {0.7330382858376183, 4.71238898038469}, 
     {0.7330382858376183, 4.607669225265029}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 4.71238898038469}, {0.6283185307179586, \
4.817108735504349}, {0.7330382858376183, 4.817108735504349}, 
     {0.7330382858376183, 4.71238898038469}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.775, 0.1], 
   Polygon[{{0.6283185307179586, 4.817108735504349}, {0.6283185307179586, \
4.921828490624009}, {0.7330382858376183, 4.921828490624009}, 
     {0.7330382858376183, 4.817108735504349}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.6283185307179586, 4.921828490624009}, {0.6283185307179586, \
5.026548245743669}, {0.7330382858376183, 5.026548245743669}, 
     {0.7330382858376183, 4.921828490624009}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 5.026548245743669}, {0.6283185307179586, \
5.1312680008633285}, {0.7330382858376183, 5.1312680008633285}, 
     {0.7330382858376183, 5.026548245743669}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{0.6283185307179586, 5.1312680008633285}, {0.6283185307179586, \
5.235987755982988}, {0.7330382858376183, 5.235987755982988}, 
     {0.7330382858376183, 5.1312680008633285}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.6283185307179586, 5.235987755982988}, {0.6283185307179586, \
5.340707511102648}, {0.7330382858376183, 5.340707511102648}, 
     {0.7330382858376183, 5.235987755982988}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 5.340707511102648}, {0.6283185307179586, \
5.445427266222308}, {0.7330382858376183, 5.445427266222308}, 
     {0.7330382858376183, 5.340707511102648}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{0.6283185307179586, 5.445427266222308}, {0.6283185307179586, \
5.550147021341967}, {0.7330382858376183, 5.550147021341967}, 
     {0.7330382858376183, 5.445427266222308}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.6283185307179586, 5.550147021341967}, {0.6283185307179586, \
5.654866776461628}, {0.7330382858376183, 5.654866776461628}, 
     {0.7330382858376183, 5.550147021341967}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.6283185307179586, 5.654866776461628}, {0.6283185307179586, \
5.759586531581287}, {0.7330382858376183, 5.759586531581287}, 
     {0.7330382858376183, 5.654866776461628}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.6283185307179586, 5.759586531581287}, {0.6283185307179586, \
5.864306286700947}, {0.7330382858376183, 5.864306286700947}, 
     {0.7330382858376183, 5.759586531581287}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.6283185307179586, 5.864306286700947}, {0.6283185307179586, \
5.969026041820607}, {0.7330382858376183, 5.969026041820607}, 
     {0.7330382858376183, 5.864306286700947}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.6283185307179586, 5.969026041820607}, {0.6283185307179586, \
6.073745796940266}, {0.7330382858376183, 6.073745796940266}, 
     {0.7330382858376183, 5.969026041820607}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{0.6283185307179586, 6.073745796940266}, {0.6283185307179586, \
6.178465552059926}, {0.7330382858376183, 6.178465552059926}, 
     {0.7330382858376183, 6.073745796940266}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.6283185307179586, 6.178465552059926}, {0.6283185307179586, \
6.283185307179586}, {0.7330382858376183, 6.283185307179586}, 
     {0.7330382858376183, 6.178465552059926}}]}, {CMYKColor[0.25, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 0.}, {0.7330382858376183, \
0.10471975511965977}, {0.8377580409572781, 0.10471975511965977}, 
     {0.8377580409572781, 0.}}]}, {CMYKColor[0.25, 0.5, 0.025, 0.1], 
   Polygon[{{0.7330382858376183, 0.10471975511965977}, {0.7330382858376183, \
0.20943951023931953}, {0.8377580409572781, 0.20943951023931953}, 
     {0.8377580409572781, 0.10471975511965977}}]}, {CMYKColor[0.25, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{0.7330382858376183, 0.20943951023931953}, {0.7330382858376183, \
0.3141592653589793}, {0.8377580409572781, 0.3141592653589793}, 
     {0.8377580409572781, 0.20943951023931953}}]}, {CMYKColor[0.25, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{0.7330382858376183, 0.3141592653589793}, {0.7330382858376183, \
0.41887902047863906}, {0.8377580409572781, 0.41887902047863906}, 
     {0.8377580409572781, 0.3141592653589793}}]}, {CMYKColor[0.25, 0.5, \
0.075, 0.1], 
   Polygon[{{0.7330382858376183, 0.41887902047863906}, {0.7330382858376183, \
0.5235987755982988}, {0.8377580409572781, 0.5235987755982988}, 
     {0.8377580409572781, 0.41887902047863906}}]}, {CMYKColor[0.25, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{0.7330382858376183, 0.5235987755982988}, {0.7330382858376183, \
0.6283185307179586}, {0.8377580409572781, 0.6283185307179586}, 
     {0.8377580409572781, 0.5235987755982988}}]}, {CMYKColor[0.25, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{0.7330382858376183, 0.6283185307179586}, {0.7330382858376183, \
0.7330382858376183}, {0.8377580409572781, 0.7330382858376183}, 
     {0.8377580409572781, 0.6283185307179586}}]}, {CMYKColor[0.25, 0.5, \
0.125, 0.1], 
   Polygon[{{0.7330382858376183, 0.7330382858376183}, {0.7330382858376183, \
0.8377580409572781}, {0.8377580409572781, 0.8377580409572781}, 
     {0.8377580409572781, 0.7330382858376183}}]}, {CMYKColor[0.25, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{0.7330382858376183, 0.8377580409572781}, {0.7330382858376183, \
0.9424777960769379}, {0.8377580409572781, 0.9424777960769379}, 
     {0.8377580409572781, 0.8377580409572781}}]}, {CMYKColor[0.25, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 0.9424777960769379}, {0.7330382858376183, \
1.0471975511965976}, {0.8377580409572781, 1.0471975511965976}, 
     {0.8377580409572781, 0.9424777960769379}}]}, {CMYKColor[0.25, 0.5, \
0.175, 0.1], 
   Polygon[{{0.7330382858376183, 1.0471975511965976}, {0.7330382858376183, \
1.1519173063162573}, {0.8377580409572781, 1.1519173063162573}, 
     {0.8377580409572781, 1.0471975511965976}}]}, {CMYKColor[0.25, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{0.7330382858376183, 1.1519173063162573}, {0.7330382858376183, \
1.2566370614359172}, {0.8377580409572781, 1.2566370614359172}, 
     {0.8377580409572781, 1.1519173063162573}}]}, {CMYKColor[0.25, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{0.7330382858376183, 1.2566370614359172}, {0.7330382858376183, \
1.361356816555577}, {0.8377580409572781, 1.361356816555577}, 
     {0.8377580409572781, 1.2566370614359172}}]}, {CMYKColor[0.25, 0.5, \
0.225, 0.1], 
   Polygon[{{0.7330382858376183, 1.361356816555577}, {0.7330382858376183, \
1.4660765716752366}, {0.8377580409572781, 1.4660765716752366}, 
     {0.8377580409572781, 1.361356816555577}}]}, {CMYKColor[0.25, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{0.7330382858376183, 1.4660765716752366}, {0.7330382858376183, \
1.5707963267948966}, {0.8377580409572781, 1.5707963267948966}, 
     {0.8377580409572781, 1.4660765716752366}}]}, {CMYKColor[0.25, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 1.5707963267948966}, {0.7330382858376183, \
1.6755160819145563}, {0.8377580409572781, 1.6755160819145563}, 
     {0.8377580409572781, 1.5707963267948966}}]}, {CMYKColor[0.25, 0.5, \
0.275, 0.1], 
   Polygon[{{0.7330382858376183, 1.6755160819145563}, {0.7330382858376183, \
1.780235837034216}, {0.8377580409572781, 1.780235837034216}, 
     {0.8377580409572781, 1.6755160819145563}}]}, {CMYKColor[0.25, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{0.7330382858376183, 1.780235837034216}, {0.7330382858376183, \
1.8849555921538759}, {0.8377580409572781, 1.8849555921538759}, 
     {0.8377580409572781, 1.780235837034216}}]}, {CMYKColor[0.25, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{0.7330382858376183, 1.8849555921538759}, {0.7330382858376183, \
1.9896753472735356}, {0.8377580409572781, 1.9896753472735356}, 
     {0.8377580409572781, 1.8849555921538759}}]}, {CMYKColor[0.25, 0.5, \
0.325, 0.1], 
   Polygon[{{0.7330382858376183, 1.9896753472735356}, {0.7330382858376183, \
2.0943951023931953}, {0.8377580409572781, 2.0943951023931953}, 
     {0.8377580409572781, 1.9896753472735356}}]}, {CMYKColor[0.25, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{0.7330382858376183, 2.0943951023931953}, {0.7330382858376183, \
2.199114857512855}, {0.8377580409572781, 2.199114857512855}, 
     {0.8377580409572781, 2.0943951023931953}}]}, {CMYKColor[0.25, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{0.7330382858376183, 2.199114857512855}, {0.7330382858376183, \
2.3038346126325147}, {0.8377580409572781, 2.3038346126325147}, 
     {0.8377580409572781, 2.199114857512855}}]}, {CMYKColor[0.25, 0.5, 0.375, \
0.1], 
   Polygon[{{0.7330382858376183, 2.3038346126325147}, {0.7330382858376183, \
2.4085543677521746}, {0.8377580409572781, 2.4085543677521746}, 
     {0.8377580409572781, 2.3038346126325147}}]}, {CMYKColor[0.25, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{0.7330382858376183, 2.4085543677521746}, {0.7330382858376183, \
2.5132741228718345}, {0.8377580409572781, 2.5132741228718345}, 
     {0.8377580409572781, 2.4085543677521746}}]}, {CMYKColor[0.25, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 2.5132741228718345}, {0.7330382858376183, \
2.617993877991494}, {0.8377580409572781, 2.617993877991494}, 
     {0.8377580409572781, 2.5132741228718345}}]}, {CMYKColor[0.25, 0.5, \
0.425, 0.1], 
   Polygon[{{0.7330382858376183, 2.617993877991494}, {0.7330382858376183, \
2.722713633111154}, {0.8377580409572781, 2.722713633111154}, 
     {0.8377580409572781, 2.617993877991494}}]}, {CMYKColor[0.25, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{0.7330382858376183, 2.722713633111154}, {0.7330382858376183, \
2.827433388230814}, {0.8377580409572781, 2.827433388230814}, 
     {0.8377580409572781, 2.722713633111154}}]}, {CMYKColor[0.25, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 2.827433388230814}, {0.7330382858376183, \
2.9321531433504733}, {0.8377580409572781, 2.9321531433504733}, 
     {0.8377580409572781, 2.827433388230814}}]}, {CMYKColor[0.25, 0.5, 0.475, \
0.1], 
   Polygon[{{0.7330382858376183, 2.9321531433504733}, {0.7330382858376183, \
3.036872898470133}, {0.8377580409572781, 3.036872898470133}, 
     {0.8377580409572781, 2.9321531433504733}}]}, {CMYKColor[0.25, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{0.7330382858376183, 3.036872898470133}, {0.7330382858376183, \
3.141592653589793}, {0.8377580409572781, 3.141592653589793}, 
     {0.8377580409572781, 3.036872898470133}}]}, {CMYKColor[0.25, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 3.141592653589793}, {0.7330382858376183, \
3.2463124087094526}, {0.8377580409572781, 3.2463124087094526}, 
     {0.8377580409572781, 3.141592653589793}}]}, {CMYKColor[0.25, 0.5, 0.525, \
0.1], 
   Polygon[{{0.7330382858376183, 3.2463124087094526}, {0.7330382858376183, \
3.3510321638291125}, {0.8377580409572781, 3.3510321638291125}, 
     {0.8377580409572781, 3.2463124087094526}}]}, {CMYKColor[0.25, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{0.7330382858376183, 3.3510321638291125}, {0.7330382858376183, \
3.4557519189487724}, {0.8377580409572781, 3.4557519189487724}, 
     {0.8377580409572781, 3.3510321638291125}}]}, {CMYKColor[0.25, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 3.4557519189487724}, {0.7330382858376183, \
3.560471674068432}, {0.8377580409572781, 3.560471674068432}, 
     {0.8377580409572781, 3.4557519189487724}}]}, {CMYKColor[0.25, 0.5, \
0.575, 0.1], 
   Polygon[{{0.7330382858376183, 3.560471674068432}, {0.7330382858376183, \
3.665191429188092}, {0.8377580409572781, 3.665191429188092}, 
     {0.8377580409572781, 3.560471674068432}}]}, {CMYKColor[0.25, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{0.7330382858376183, 3.665191429188092}, {0.7330382858376183, \
3.7699111843077517}, {0.8377580409572781, 3.7699111843077517}, 
     {0.8377580409572781, 3.665191429188092}}]}, {CMYKColor[0.25, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 3.7699111843077517}, {0.7330382858376183, \
3.874630939427411}, {0.8377580409572781, 3.874630939427411}, 
     {0.8377580409572781, 3.7699111843077517}}]}, {CMYKColor[0.25, 0.5, \
0.625, 0.1], 
   Polygon[{{0.7330382858376183, 3.874630939427411}, {0.7330382858376183, \
3.979350694547071}, {0.8377580409572781, 3.979350694547071}, 
     {0.8377580409572781, 3.874630939427411}}]}, {CMYKColor[0.25, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{0.7330382858376183, 3.979350694547071}, {0.7330382858376183, \
4.084070449666731}, {0.8377580409572781, 4.084070449666731}, 
     {0.8377580409572781, 3.979350694547071}}]}, {CMYKColor[0.25, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 4.084070449666731}, {0.7330382858376183, \
4.1887902047863905}, {0.8377580409572781, 4.1887902047863905}, 
     {0.8377580409572781, 4.084070449666731}}]}, {CMYKColor[0.25, 0.5, 0.675, \
0.1], 
   Polygon[{{0.7330382858376183, 4.1887902047863905}, {0.7330382858376183, \
4.29350995990605}, {0.8377580409572781, 4.29350995990605}, 
     {0.8377580409572781, 4.1887902047863905}}]}, {CMYKColor[0.25, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{0.7330382858376183, 4.29350995990605}, {0.7330382858376183, \
4.39822971502571}, {0.8377580409572781, 4.39822971502571}, 
     {0.8377580409572781, 4.29350995990605}}]}, {CMYKColor[0.25, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{0.7330382858376183, 4.39822971502571}, {0.7330382858376183, \
4.50294947014537}, {0.8377580409572781, 4.50294947014537}, 
     {0.8377580409572781, 4.39822971502571}}]}, {CMYKColor[0.25, 0.5, 0.725, \
0.1], 
   Polygon[{{0.7330382858376183, 4.50294947014537}, {0.7330382858376183, \
4.607669225265029}, {0.8377580409572781, 4.607669225265029}, 
     {0.8377580409572781, 4.50294947014537}}]}, {CMYKColor[0.25, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{0.7330382858376183, 4.607669225265029}, {0.7330382858376183, \
4.71238898038469}, {0.8377580409572781, 4.71238898038469}, 
     {0.8377580409572781, 4.607669225265029}}]}, {CMYKColor[0.25, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 4.71238898038469}, {0.7330382858376183, \
4.817108735504349}, {0.8377580409572781, 4.817108735504349}, 
     {0.8377580409572781, 4.71238898038469}}]}, {CMYKColor[0.25, 0.5, 0.775, \
0.1], 
   Polygon[{{0.7330382858376183, 4.817108735504349}, {0.7330382858376183, \
4.921828490624009}, {0.8377580409572781, 4.921828490624009}, 
     {0.8377580409572781, 4.817108735504349}}]}, {CMYKColor[0.25, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{0.7330382858376183, 4.921828490624009}, {0.7330382858376183, \
5.026548245743669}, {0.8377580409572781, 5.026548245743669}, 
     {0.8377580409572781, 4.921828490624009}}]}, {CMYKColor[0.25, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 5.026548245743669}, {0.7330382858376183, \
5.1312680008633285}, {0.8377580409572781, 5.1312680008633285}, 
     {0.8377580409572781, 5.026548245743669}}]}, {CMYKColor[0.25, 0.5, 0.825, \
0.1], 
   Polygon[{{0.7330382858376183, 5.1312680008633285}, {0.7330382858376183, \
5.235987755982988}, {0.8377580409572781, 5.235987755982988}, 
     {0.8377580409572781, 5.1312680008633285}}]}, {CMYKColor[0.25, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{0.7330382858376183, 5.235987755982988}, {0.7330382858376183, \
5.340707511102648}, {0.8377580409572781, 5.340707511102648}, 
     {0.8377580409572781, 5.235987755982988}}]}, {CMYKColor[0.25, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 5.340707511102648}, {0.7330382858376183, \
5.445427266222308}, {0.8377580409572781, 5.445427266222308}, 
     {0.8377580409572781, 5.340707511102648}}]}, {CMYKColor[0.25, 0.5, 0.875, \
0.1], 
   Polygon[{{0.7330382858376183, 5.445427266222308}, {0.7330382858376183, \
5.550147021341967}, {0.8377580409572781, 5.550147021341967}, 
     {0.8377580409572781, 5.445427266222308}}]}, {CMYKColor[0.25, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{0.7330382858376183, 5.550147021341967}, {0.7330382858376183, \
5.654866776461628}, {0.8377580409572781, 5.654866776461628}, 
     {0.8377580409572781, 5.550147021341967}}]}, {CMYKColor[0.25, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{0.7330382858376183, 5.654866776461628}, {0.7330382858376183, \
5.759586531581287}, {0.8377580409572781, 5.759586531581287}, 
     {0.8377580409572781, 5.654866776461628}}]}, {CMYKColor[0.25, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{0.7330382858376183, 5.759586531581287}, {0.7330382858376183, \
5.864306286700947}, {0.8377580409572781, 5.864306286700947}, 
     {0.8377580409572781, 5.759586531581287}}]}, {CMYKColor[0.25, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{0.7330382858376183, 5.864306286700947}, {0.7330382858376183, \
5.969026041820607}, {0.8377580409572781, 5.969026041820607}, 
     {0.8377580409572781, 5.864306286700947}}]}, {CMYKColor[0.25, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{0.7330382858376183, 5.969026041820607}, {0.7330382858376183, \
6.073745796940266}, {0.8377580409572781, 6.073745796940266}, 
     {0.8377580409572781, 5.969026041820607}}]}, {CMYKColor[0.25, 0.5, 0.975, \
0.1], 
   Polygon[{{0.7330382858376183, 6.073745796940266}, {0.7330382858376183, \
6.178465552059926}, {0.8377580409572781, 6.178465552059926}, 
     {0.8377580409572781, 6.073745796940266}}]}, {CMYKColor[0.25, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{0.7330382858376183, 6.178465552059926}, {0.7330382858376183, \
6.283185307179586}, {0.8377580409572781, 6.283185307179586}, 
     {0.8377580409572781, 6.178465552059926}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 0.}, {0.8377580409572781, \
0.10471975511965977}, {0.9424777960769379, 0.10471975511965977}, 
     {0.9424777960769379, 0.}}]}, {CMYKColor[0.2833333333333333, 0.5, 0.025, \
0.1], 
   Polygon[{{0.8377580409572781, 0.10471975511965977}, {0.8377580409572781, \
0.20943951023931953}, {0.9424777960769379, 0.20943951023931953}, 
     {0.9424777960769379, 0.10471975511965977}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.8377580409572781, 0.20943951023931953}, {0.8377580409572781, \
0.3141592653589793}, {0.9424777960769379, 0.3141592653589793}, 
     {0.9424777960769379, 0.20943951023931953}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.8377580409572781, 0.3141592653589793}, {0.8377580409572781, \
0.41887902047863906}, {0.9424777960769379, 0.41887902047863906}, 
     {0.9424777960769379, 0.3141592653589793}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{0.8377580409572781, 0.41887902047863906}, {0.8377580409572781, \
0.5235987755982988}, {0.9424777960769379, 0.5235987755982988}, 
     {0.9424777960769379, 0.41887902047863906}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.8377580409572781, 0.5235987755982988}, {0.8377580409572781, \
0.6283185307179586}, {0.9424777960769379, 0.6283185307179586}, 
     {0.9424777960769379, 0.5235987755982988}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.8377580409572781, 0.6283185307179586}, {0.8377580409572781, \
0.7330382858376183}, {0.9424777960769379, 0.7330382858376183}, 
     {0.9424777960769379, 0.6283185307179586}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{0.8377580409572781, 0.7330382858376183}, {0.8377580409572781, \
0.8377580409572781}, {0.9424777960769379, 0.8377580409572781}, 
     {0.9424777960769379, 0.7330382858376183}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.8377580409572781, 0.8377580409572781}, {0.8377580409572781, \
0.9424777960769379}, {0.9424777960769379, 0.9424777960769379}, 
     {0.9424777960769379, 0.8377580409572781}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 0.9424777960769379}, {0.8377580409572781, \
1.0471975511965976}, {0.9424777960769379, 1.0471975511965976}, 
     {0.9424777960769379, 0.9424777960769379}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{0.8377580409572781, 1.0471975511965976}, {0.8377580409572781, \
1.1519173063162573}, {0.9424777960769379, 1.1519173063162573}, 
     {0.9424777960769379, 1.0471975511965976}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.8377580409572781, 1.1519173063162573}, {0.8377580409572781, \
1.2566370614359172}, {0.9424777960769379, 1.2566370614359172}, 
     {0.9424777960769379, 1.1519173063162573}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.8377580409572781, 1.2566370614359172}, {0.8377580409572781, \
1.361356816555577}, {0.9424777960769379, 1.361356816555577}, 
     {0.9424777960769379, 1.2566370614359172}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{0.8377580409572781, 1.361356816555577}, {0.8377580409572781, \
1.4660765716752366}, {0.9424777960769379, 1.4660765716752366}, 
     {0.9424777960769379, 1.361356816555577}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.8377580409572781, 1.4660765716752366}, {0.8377580409572781, \
1.5707963267948966}, {0.9424777960769379, 1.5707963267948966}, 
     {0.9424777960769379, 1.4660765716752366}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 1.5707963267948966}, {0.8377580409572781, \
1.6755160819145563}, {0.9424777960769379, 1.6755160819145563}, 
     {0.9424777960769379, 1.5707963267948966}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{0.8377580409572781, 1.6755160819145563}, {0.8377580409572781, \
1.780235837034216}, {0.9424777960769379, 1.780235837034216}, 
     {0.9424777960769379, 1.6755160819145563}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0.8377580409572781, 1.780235837034216}, {0.8377580409572781, \
1.8849555921538759}, {0.9424777960769379, 1.8849555921538759}, 
     {0.9424777960769379, 1.780235837034216}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0.8377580409572781, 1.8849555921538759}, {0.8377580409572781, \
1.9896753472735356}, {0.9424777960769379, 1.9896753472735356}, 
     {0.9424777960769379, 1.8849555921538759}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{0.8377580409572781, 1.9896753472735356}, {0.8377580409572781, \
2.0943951023931953}, {0.9424777960769379, 2.0943951023931953}, 
     {0.9424777960769379, 1.9896753472735356}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{0.8377580409572781, 2.0943951023931953}, {0.8377580409572781, \
2.199114857512855}, {0.9424777960769379, 2.199114857512855}, 
     {0.9424777960769379, 2.0943951023931953}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0.8377580409572781, 2.199114857512855}, {0.8377580409572781, \
2.3038346126325147}, {0.9424777960769379, 2.3038346126325147}, 
     {0.9424777960769379, 2.199114857512855}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{0.8377580409572781, 2.3038346126325147}, {0.8377580409572781, \
2.4085543677521746}, {0.9424777960769379, 2.4085543677521746}, 
     {0.9424777960769379, 2.3038346126325147}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{0.8377580409572781, 2.4085543677521746}, {0.8377580409572781, \
2.5132741228718345}, {0.9424777960769379, 2.5132741228718345}, 
     {0.9424777960769379, 2.4085543677521746}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 2.5132741228718345}, {0.8377580409572781, \
2.617993877991494}, {0.9424777960769379, 2.617993877991494}, 
     {0.9424777960769379, 2.5132741228718345}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{0.8377580409572781, 2.617993877991494}, {0.8377580409572781, \
2.722713633111154}, {0.9424777960769379, 2.722713633111154}, 
     {0.9424777960769379, 2.617993877991494}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{0.8377580409572781, 2.722713633111154}, {0.8377580409572781, \
2.827433388230814}, {0.9424777960769379, 2.827433388230814}, 
     {0.9424777960769379, 2.722713633111154}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 2.827433388230814}, {0.8377580409572781, \
2.9321531433504733}, {0.9424777960769379, 2.9321531433504733}, 
     {0.9424777960769379, 2.827433388230814}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{0.8377580409572781, 2.9321531433504733}, {0.8377580409572781, \
3.036872898470133}, {0.9424777960769379, 3.036872898470133}, 
     {0.9424777960769379, 2.9321531433504733}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{0.8377580409572781, 3.036872898470133}, {0.8377580409572781, \
3.141592653589793}, {0.9424777960769379, 3.141592653589793}, 
     {0.9424777960769379, 3.036872898470133}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 3.141592653589793}, {0.8377580409572781, \
3.2463124087094526}, {0.9424777960769379, 3.2463124087094526}, 
     {0.9424777960769379, 3.141592653589793}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{0.8377580409572781, 3.2463124087094526}, {0.8377580409572781, \
3.3510321638291125}, {0.9424777960769379, 3.3510321638291125}, 
     {0.9424777960769379, 3.2463124087094526}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{0.8377580409572781, 3.3510321638291125}, {0.8377580409572781, \
3.4557519189487724}, {0.9424777960769379, 3.4557519189487724}, 
     {0.9424777960769379, 3.3510321638291125}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 3.4557519189487724}, {0.8377580409572781, \
3.560471674068432}, {0.9424777960769379, 3.560471674068432}, 
     {0.9424777960769379, 3.4557519189487724}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{0.8377580409572781, 3.560471674068432}, {0.8377580409572781, \
3.665191429188092}, {0.9424777960769379, 3.665191429188092}, 
     {0.9424777960769379, 3.560471674068432}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{0.8377580409572781, 3.665191429188092}, {0.8377580409572781, \
3.7699111843077517}, {0.9424777960769379, 3.7699111843077517}, 
     {0.9424777960769379, 3.665191429188092}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 3.7699111843077517}, {0.8377580409572781, \
3.874630939427411}, {0.9424777960769379, 3.874630939427411}, 
     {0.9424777960769379, 3.7699111843077517}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{0.8377580409572781, 3.874630939427411}, {0.8377580409572781, \
3.979350694547071}, {0.9424777960769379, 3.979350694547071}, 
     {0.9424777960769379, 3.874630939427411}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0.8377580409572781, 3.979350694547071}, {0.8377580409572781, \
4.084070449666731}, {0.9424777960769379, 4.084070449666731}, 
     {0.9424777960769379, 3.979350694547071}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 4.084070449666731}, {0.8377580409572781, \
4.1887902047863905}, {0.9424777960769379, 4.1887902047863905}, 
     {0.9424777960769379, 4.084070449666731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{0.8377580409572781, 4.1887902047863905}, {0.8377580409572781, \
4.29350995990605}, {0.9424777960769379, 4.29350995990605}, 
     {0.9424777960769379, 4.1887902047863905}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0.8377580409572781, 4.29350995990605}, {0.8377580409572781, \
4.39822971502571}, {0.9424777960769379, 4.39822971502571}, 
     {0.9424777960769379, 4.29350995990605}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0.8377580409572781, 4.39822971502571}, {0.8377580409572781, \
4.50294947014537}, {0.9424777960769379, 4.50294947014537}, 
     {0.9424777960769379, 4.39822971502571}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{0.8377580409572781, 4.50294947014537}, {0.8377580409572781, \
4.607669225265029}, {0.9424777960769379, 4.607669225265029}, 
     {0.9424777960769379, 4.50294947014537}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.8377580409572781, 4.607669225265029}, {0.8377580409572781, \
4.71238898038469}, {0.9424777960769379, 4.71238898038469}, 
     {0.9424777960769379, 4.607669225265029}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 4.71238898038469}, {0.8377580409572781, \
4.817108735504349}, {0.9424777960769379, 4.817108735504349}, 
     {0.9424777960769379, 4.71238898038469}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{0.8377580409572781, 4.817108735504349}, {0.8377580409572781, \
4.921828490624009}, {0.9424777960769379, 4.921828490624009}, 
     {0.9424777960769379, 4.817108735504349}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.8377580409572781, 4.921828490624009}, {0.8377580409572781, \
5.026548245743669}, {0.9424777960769379, 5.026548245743669}, 
     {0.9424777960769379, 4.921828490624009}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 5.026548245743669}, {0.8377580409572781, \
5.1312680008633285}, {0.9424777960769379, 5.1312680008633285}, 
     {0.9424777960769379, 5.026548245743669}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{0.8377580409572781, 5.1312680008633285}, {0.8377580409572781, \
5.235987755982988}, {0.9424777960769379, 5.235987755982988}, 
     {0.9424777960769379, 5.1312680008633285}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.8377580409572781, 5.235987755982988}, {0.8377580409572781, \
5.340707511102648}, {0.9424777960769379, 5.340707511102648}, 
     {0.9424777960769379, 5.235987755982988}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 5.340707511102648}, {0.8377580409572781, \
5.445427266222308}, {0.9424777960769379, 5.445427266222308}, 
     {0.9424777960769379, 5.340707511102648}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{0.8377580409572781, 5.445427266222308}, {0.8377580409572781, \
5.550147021341967}, {0.9424777960769379, 5.550147021341967}, 
     {0.9424777960769379, 5.445427266222308}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.8377580409572781, 5.550147021341967}, {0.8377580409572781, \
5.654866776461628}, {0.9424777960769379, 5.654866776461628}, 
     {0.9424777960769379, 5.550147021341967}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.8377580409572781, 5.654866776461628}, {0.8377580409572781, \
5.759586531581287}, {0.9424777960769379, 5.759586531581287}, 
     {0.9424777960769379, 5.654866776461628}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.8377580409572781, 5.759586531581287}, {0.8377580409572781, \
5.864306286700947}, {0.9424777960769379, 5.864306286700947}, 
     {0.9424777960769379, 5.759586531581287}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.8377580409572781, 5.864306286700947}, {0.8377580409572781, \
5.969026041820607}, {0.9424777960769379, 5.969026041820607}, 
     {0.9424777960769379, 5.864306286700947}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.8377580409572781, 5.969026041820607}, {0.8377580409572781, \
6.073745796940266}, {0.9424777960769379, 6.073745796940266}, 
     {0.9424777960769379, 5.969026041820607}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{0.8377580409572781, 6.073745796940266}, {0.8377580409572781, \
6.178465552059926}, {0.9424777960769379, 6.178465552059926}, 
     {0.9424777960769379, 6.073745796940266}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.8377580409572781, 6.178465552059926}, {0.8377580409572781, \
6.283185307179586}, {0.9424777960769379, 6.283185307179586}, 
     {0.9424777960769379, 6.178465552059926}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 0.}, {0.9424777960769379, \
0.10471975511965977}, {1.0471975511965976, 0.10471975511965977}, 
     {1.0471975511965976, 0.}}]}, {CMYKColor[0.31666666666666665, 0.5, 0.025, \
0.1], 
   Polygon[{{0.9424777960769379, 0.10471975511965977}, {0.9424777960769379, \
0.20943951023931953}, {1.0471975511965976, 0.20943951023931953}, 
     {1.0471975511965976, 0.10471975511965977}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.9424777960769379, 0.20943951023931953}, {0.9424777960769379, \
0.3141592653589793}, {1.0471975511965976, 0.3141592653589793}, 
     {1.0471975511965976, 0.20943951023931953}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.9424777960769379, 0.3141592653589793}, {0.9424777960769379, \
0.41887902047863906}, {1.0471975511965976, 0.41887902047863906}, 
     {1.0471975511965976, 0.3141592653589793}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.075, 0.1], 
   Polygon[{{0.9424777960769379, 0.41887902047863906}, {0.9424777960769379, \
0.5235987755982988}, {1.0471975511965976, 0.5235987755982988}, 
     {1.0471975511965976, 0.41887902047863906}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.9424777960769379, 0.5235987755982988}, {0.9424777960769379, \
0.6283185307179586}, {1.0471975511965976, 0.6283185307179586}, 
     {1.0471975511965976, 0.5235987755982988}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.9424777960769379, 0.6283185307179586}, {0.9424777960769379, \
0.7330382858376183}, {1.0471975511965976, 0.7330382858376183}, 
     {1.0471975511965976, 0.6283185307179586}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.125, 0.1], 
   Polygon[{{0.9424777960769379, 0.7330382858376183}, {0.9424777960769379, \
0.8377580409572781}, {1.0471975511965976, 0.8377580409572781}, 
     {1.0471975511965976, 0.7330382858376183}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.9424777960769379, 0.8377580409572781}, {0.9424777960769379, \
0.9424777960769379}, {1.0471975511965976, 0.9424777960769379}, 
     {1.0471975511965976, 0.8377580409572781}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 0.9424777960769379}, {0.9424777960769379, \
1.0471975511965976}, {1.0471975511965976, 1.0471975511965976}, 
     {1.0471975511965976, 0.9424777960769379}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.175, 0.1], 
   Polygon[{{0.9424777960769379, 1.0471975511965976}, {0.9424777960769379, \
1.1519173063162573}, {1.0471975511965976, 1.1519173063162573}, 
     {1.0471975511965976, 1.0471975511965976}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.9424777960769379, 1.1519173063162573}, {0.9424777960769379, \
1.2566370614359172}, {1.0471975511965976, 1.2566370614359172}, 
     {1.0471975511965976, 1.1519173063162573}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.9424777960769379, 1.2566370614359172}, {0.9424777960769379, \
1.361356816555577}, {1.0471975511965976, 1.361356816555577}, 
     {1.0471975511965976, 1.2566370614359172}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.225, 0.1], 
   Polygon[{{0.9424777960769379, 1.361356816555577}, {0.9424777960769379, \
1.4660765716752366}, {1.0471975511965976, 1.4660765716752366}, 
     {1.0471975511965976, 1.361356816555577}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.9424777960769379, 1.4660765716752366}, {0.9424777960769379, \
1.5707963267948966}, {1.0471975511965976, 1.5707963267948966}, 
     {1.0471975511965976, 1.4660765716752366}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 1.5707963267948966}, {0.9424777960769379, \
1.6755160819145563}, {1.0471975511965976, 1.6755160819145563}, 
     {1.0471975511965976, 1.5707963267948966}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.275, 0.1], 
   Polygon[{{0.9424777960769379, 1.6755160819145563}, {0.9424777960769379, \
1.780235837034216}, {1.0471975511965976, 1.780235837034216}, 
     {1.0471975511965976, 1.6755160819145563}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0.9424777960769379, 1.780235837034216}, {0.9424777960769379, \
1.8849555921538759}, {1.0471975511965976, 1.8849555921538759}, 
     {1.0471975511965976, 1.780235837034216}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0.9424777960769379, 1.8849555921538759}, {0.9424777960769379, \
1.9896753472735356}, {1.0471975511965976, 1.9896753472735356}, 
     {1.0471975511965976, 1.8849555921538759}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.325, 0.1], 
   Polygon[{{0.9424777960769379, 1.9896753472735356}, {0.9424777960769379, \
2.0943951023931953}, {1.0471975511965976, 2.0943951023931953}, 
     {1.0471975511965976, 1.9896753472735356}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{0.9424777960769379, 2.0943951023931953}, {0.9424777960769379, \
2.199114857512855}, {1.0471975511965976, 2.199114857512855}, 
     {1.0471975511965976, 2.0943951023931953}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0.9424777960769379, 2.199114857512855}, {0.9424777960769379, \
2.3038346126325147}, {1.0471975511965976, 2.3038346126325147}, 
     {1.0471975511965976, 2.199114857512855}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.375, 0.1], 
   Polygon[{{0.9424777960769379, 2.3038346126325147}, {0.9424777960769379, \
2.4085543677521746}, {1.0471975511965976, 2.4085543677521746}, 
     {1.0471975511965976, 2.3038346126325147}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{0.9424777960769379, 2.4085543677521746}, {0.9424777960769379, \
2.5132741228718345}, {1.0471975511965976, 2.5132741228718345}, 
     {1.0471975511965976, 2.4085543677521746}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 2.5132741228718345}, {0.9424777960769379, \
2.617993877991494}, {1.0471975511965976, 2.617993877991494}, 
     {1.0471975511965976, 2.5132741228718345}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.425, 0.1], 
   Polygon[{{0.9424777960769379, 2.617993877991494}, {0.9424777960769379, \
2.722713633111154}, {1.0471975511965976, 2.722713633111154}, 
     {1.0471975511965976, 2.617993877991494}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{0.9424777960769379, 2.722713633111154}, {0.9424777960769379, \
2.827433388230814}, {1.0471975511965976, 2.827433388230814}, 
     {1.0471975511965976, 2.722713633111154}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 2.827433388230814}, {0.9424777960769379, \
2.9321531433504733}, {1.0471975511965976, 2.9321531433504733}, 
     {1.0471975511965976, 2.827433388230814}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.475, 0.1], 
   Polygon[{{0.9424777960769379, 2.9321531433504733}, {0.9424777960769379, \
3.036872898470133}, {1.0471975511965976, 3.036872898470133}, 
     {1.0471975511965976, 2.9321531433504733}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{0.9424777960769379, 3.036872898470133}, {0.9424777960769379, \
3.141592653589793}, {1.0471975511965976, 3.141592653589793}, 
     {1.0471975511965976, 3.036872898470133}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 3.141592653589793}, {0.9424777960769379, \
3.2463124087094526}, {1.0471975511965976, 3.2463124087094526}, 
     {1.0471975511965976, 3.141592653589793}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.525, 0.1], 
   Polygon[{{0.9424777960769379, 3.2463124087094526}, {0.9424777960769379, \
3.3510321638291125}, {1.0471975511965976, 3.3510321638291125}, 
     {1.0471975511965976, 3.2463124087094526}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{0.9424777960769379, 3.3510321638291125}, {0.9424777960769379, \
3.4557519189487724}, {1.0471975511965976, 3.4557519189487724}, 
     {1.0471975511965976, 3.3510321638291125}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 3.4557519189487724}, {0.9424777960769379, \
3.560471674068432}, {1.0471975511965976, 3.560471674068432}, 
     {1.0471975511965976, 3.4557519189487724}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.575, 0.1], 
   Polygon[{{0.9424777960769379, 3.560471674068432}, {0.9424777960769379, \
3.665191429188092}, {1.0471975511965976, 3.665191429188092}, 
     {1.0471975511965976, 3.560471674068432}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{0.9424777960769379, 3.665191429188092}, {0.9424777960769379, \
3.7699111843077517}, {1.0471975511965976, 3.7699111843077517}, 
     {1.0471975511965976, 3.665191429188092}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 3.7699111843077517}, {0.9424777960769379, \
3.874630939427411}, {1.0471975511965976, 3.874630939427411}, 
     {1.0471975511965976, 3.7699111843077517}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.625, 0.1], 
   Polygon[{{0.9424777960769379, 3.874630939427411}, {0.9424777960769379, \
3.979350694547071}, {1.0471975511965976, 3.979350694547071}, 
     {1.0471975511965976, 3.874630939427411}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0.9424777960769379, 3.979350694547071}, {0.9424777960769379, \
4.084070449666731}, {1.0471975511965976, 4.084070449666731}, 
     {1.0471975511965976, 3.979350694547071}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 4.084070449666731}, {0.9424777960769379, \
4.1887902047863905}, {1.0471975511965976, 4.1887902047863905}, 
     {1.0471975511965976, 4.084070449666731}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.675, 0.1], 
   Polygon[{{0.9424777960769379, 4.1887902047863905}, {0.9424777960769379, \
4.29350995990605}, {1.0471975511965976, 4.29350995990605}, 
     {1.0471975511965976, 4.1887902047863905}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0.9424777960769379, 4.29350995990605}, {0.9424777960769379, \
4.39822971502571}, {1.0471975511965976, 4.39822971502571}, 
     {1.0471975511965976, 4.29350995990605}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0.9424777960769379, 4.39822971502571}, {0.9424777960769379, \
4.50294947014537}, {1.0471975511965976, 4.50294947014537}, 
     {1.0471975511965976, 4.39822971502571}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.725, 0.1], 
   Polygon[{{0.9424777960769379, 4.50294947014537}, {0.9424777960769379, \
4.607669225265029}, {1.0471975511965976, 4.607669225265029}, 
     {1.0471975511965976, 4.50294947014537}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.9424777960769379, 4.607669225265029}, {0.9424777960769379, \
4.71238898038469}, {1.0471975511965976, 4.71238898038469}, 
     {1.0471975511965976, 4.607669225265029}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 4.71238898038469}, {0.9424777960769379, \
4.817108735504349}, {1.0471975511965976, 4.817108735504349}, 
     {1.0471975511965976, 4.71238898038469}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.775, 0.1], 
   Polygon[{{0.9424777960769379, 4.817108735504349}, {0.9424777960769379, \
4.921828490624009}, {1.0471975511965976, 4.921828490624009}, 
     {1.0471975511965976, 4.817108735504349}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.9424777960769379, 4.921828490624009}, {0.9424777960769379, \
5.026548245743669}, {1.0471975511965976, 5.026548245743669}, 
     {1.0471975511965976, 4.921828490624009}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 5.026548245743669}, {0.9424777960769379, \
5.1312680008633285}, {1.0471975511965976, 5.1312680008633285}, 
     {1.0471975511965976, 5.026548245743669}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.825, 0.1], 
   Polygon[{{0.9424777960769379, 5.1312680008633285}, {0.9424777960769379, \
5.235987755982988}, {1.0471975511965976, 5.235987755982988}, 
     {1.0471975511965976, 5.1312680008633285}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.9424777960769379, 5.235987755982988}, {0.9424777960769379, \
5.340707511102648}, {1.0471975511965976, 5.340707511102648}, 
     {1.0471975511965976, 5.235987755982988}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 5.340707511102648}, {0.9424777960769379, \
5.445427266222308}, {1.0471975511965976, 5.445427266222308}, 
     {1.0471975511965976, 5.340707511102648}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.875, 0.1], 
   Polygon[{{0.9424777960769379, 5.445427266222308}, {0.9424777960769379, \
5.550147021341967}, {1.0471975511965976, 5.550147021341967}, 
     {1.0471975511965976, 5.445427266222308}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.9424777960769379, 5.550147021341967}, {0.9424777960769379, \
5.654866776461628}, {1.0471975511965976, 5.654866776461628}, 
     {1.0471975511965976, 5.550147021341967}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.9424777960769379, 5.654866776461628}, {0.9424777960769379, \
5.759586531581287}, {1.0471975511965976, 5.759586531581287}, 
     {1.0471975511965976, 5.654866776461628}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.9424777960769379, 5.759586531581287}, {0.9424777960769379, \
5.864306286700947}, {1.0471975511965976, 5.864306286700947}, 
     {1.0471975511965976, 5.759586531581287}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.9424777960769379, 5.864306286700947}, {0.9424777960769379, \
5.969026041820607}, {1.0471975511965976, 5.969026041820607}, 
     {1.0471975511965976, 5.864306286700947}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.9424777960769379, 5.969026041820607}, {0.9424777960769379, \
6.073745796940266}, {1.0471975511965976, 6.073745796940266}, 
     {1.0471975511965976, 5.969026041820607}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.975, 0.1], 
   Polygon[{{0.9424777960769379, 6.073745796940266}, {0.9424777960769379, \
6.178465552059926}, {1.0471975511965976, 6.178465552059926}, 
     {1.0471975511965976, 6.073745796940266}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.9424777960769379, 6.178465552059926}, {0.9424777960769379, \
6.283185307179586}, {1.0471975511965976, 6.283185307179586}, 
     {1.0471975511965976, 6.178465552059926}}]}, {CMYKColor[0.35, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 0.}, {1.0471975511965976, \
0.10471975511965977}, {1.1519173063162573, 0.10471975511965977}, 
     {1.1519173063162573, 0.}}]}, {CMYKColor[0.35, 0.5, 0.025, 0.1], 
   Polygon[{{1.0471975511965976, 0.10471975511965977}, {1.0471975511965976, \
0.20943951023931953}, {1.1519173063162573, 0.20943951023931953}, 
     {1.1519173063162573, 0.10471975511965977}}]}, {CMYKColor[0.35, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{1.0471975511965976, 0.20943951023931953}, {1.0471975511965976, \
0.3141592653589793}, {1.1519173063162573, 0.3141592653589793}, 
     {1.1519173063162573, 0.20943951023931953}}]}, {CMYKColor[0.35, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{1.0471975511965976, 0.3141592653589793}, {1.0471975511965976, \
0.41887902047863906}, {1.1519173063162573, 0.41887902047863906}, 
     {1.1519173063162573, 0.3141592653589793}}]}, {CMYKColor[0.35, 0.5, \
0.075, 0.1], 
   Polygon[{{1.0471975511965976, 0.41887902047863906}, {1.0471975511965976, \
0.5235987755982988}, {1.1519173063162573, 0.5235987755982988}, 
     {1.1519173063162573, 0.41887902047863906}}]}, {CMYKColor[0.35, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{1.0471975511965976, 0.5235987755982988}, {1.0471975511965976, \
0.6283185307179586}, {1.1519173063162573, 0.6283185307179586}, 
     {1.1519173063162573, 0.5235987755982988}}]}, {CMYKColor[0.35, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{1.0471975511965976, 0.6283185307179586}, {1.0471975511965976, \
0.7330382858376183}, {1.1519173063162573, 0.7330382858376183}, 
     {1.1519173063162573, 0.6283185307179586}}]}, {CMYKColor[0.35, 0.5, \
0.125, 0.1], 
   Polygon[{{1.0471975511965976, 0.7330382858376183}, {1.0471975511965976, \
0.8377580409572781}, {1.1519173063162573, 0.8377580409572781}, 
     {1.1519173063162573, 0.7330382858376183}}]}, {CMYKColor[0.35, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{1.0471975511965976, 0.8377580409572781}, {1.0471975511965976, \
0.9424777960769379}, {1.1519173063162573, 0.9424777960769379}, 
     {1.1519173063162573, 0.8377580409572781}}]}, {CMYKColor[0.35, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 0.9424777960769379}, {1.0471975511965976, \
1.0471975511965976}, {1.1519173063162573, 1.0471975511965976}, 
     {1.1519173063162573, 0.9424777960769379}}]}, {CMYKColor[0.35, 0.5, \
0.175, 0.1], 
   Polygon[{{1.0471975511965976, 1.0471975511965976}, {1.0471975511965976, \
1.1519173063162573}, {1.1519173063162573, 1.1519173063162573}, 
     {1.1519173063162573, 1.0471975511965976}}]}, {CMYKColor[0.35, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{1.0471975511965976, 1.1519173063162573}, {1.0471975511965976, \
1.2566370614359172}, {1.1519173063162573, 1.2566370614359172}, 
     {1.1519173063162573, 1.1519173063162573}}]}, {CMYKColor[0.35, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{1.0471975511965976, 1.2566370614359172}, {1.0471975511965976, \
1.361356816555577}, {1.1519173063162573, 1.361356816555577}, 
     {1.1519173063162573, 1.2566370614359172}}]}, {CMYKColor[0.35, 0.5, \
0.225, 0.1], 
   Polygon[{{1.0471975511965976, 1.361356816555577}, {1.0471975511965976, \
1.4660765716752366}, {1.1519173063162573, 1.4660765716752366}, 
     {1.1519173063162573, 1.361356816555577}}]}, {CMYKColor[0.35, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{1.0471975511965976, 1.4660765716752366}, {1.0471975511965976, \
1.5707963267948966}, {1.1519173063162573, 1.5707963267948966}, 
     {1.1519173063162573, 1.4660765716752366}}]}, {CMYKColor[0.35, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 1.5707963267948966}, {1.0471975511965976, \
1.6755160819145563}, {1.1519173063162573, 1.6755160819145563}, 
     {1.1519173063162573, 1.5707963267948966}}]}, {CMYKColor[0.35, 0.5, \
0.275, 0.1], 
   Polygon[{{1.0471975511965976, 1.6755160819145563}, {1.0471975511965976, \
1.780235837034216}, {1.1519173063162573, 1.780235837034216}, 
     {1.1519173063162573, 1.6755160819145563}}]}, {CMYKColor[0.35, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{1.0471975511965976, 1.780235837034216}, {1.0471975511965976, \
1.8849555921538759}, {1.1519173063162573, 1.8849555921538759}, 
     {1.1519173063162573, 1.780235837034216}}]}, {CMYKColor[0.35, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{1.0471975511965976, 1.8849555921538759}, {1.0471975511965976, \
1.9896753472735356}, {1.1519173063162573, 1.9896753472735356}, 
     {1.1519173063162573, 1.8849555921538759}}]}, {CMYKColor[0.35, 0.5, \
0.325, 0.1], 
   Polygon[{{1.0471975511965976, 1.9896753472735356}, {1.0471975511965976, \
2.0943951023931953}, {1.1519173063162573, 2.0943951023931953}, 
     {1.1519173063162573, 1.9896753472735356}}]}, {CMYKColor[0.35, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{1.0471975511965976, 2.0943951023931953}, {1.0471975511965976, \
2.199114857512855}, {1.1519173063162573, 2.199114857512855}, 
     {1.1519173063162573, 2.0943951023931953}}]}, {CMYKColor[0.35, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{1.0471975511965976, 2.199114857512855}, {1.0471975511965976, \
2.3038346126325147}, {1.1519173063162573, 2.3038346126325147}, 
     {1.1519173063162573, 2.199114857512855}}]}, {CMYKColor[0.35, 0.5, 0.375, \
0.1], 
   Polygon[{{1.0471975511965976, 2.3038346126325147}, {1.0471975511965976, \
2.4085543677521746}, {1.1519173063162573, 2.4085543677521746}, 
     {1.1519173063162573, 2.3038346126325147}}]}, {CMYKColor[0.35, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{1.0471975511965976, 2.4085543677521746}, {1.0471975511965976, \
2.5132741228718345}, {1.1519173063162573, 2.5132741228718345}, 
     {1.1519173063162573, 2.4085543677521746}}]}, {CMYKColor[0.35, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 2.5132741228718345}, {1.0471975511965976, \
2.617993877991494}, {1.1519173063162573, 2.617993877991494}, 
     {1.1519173063162573, 2.5132741228718345}}]}, {CMYKColor[0.35, 0.5, \
0.425, 0.1], 
   Polygon[{{1.0471975511965976, 2.617993877991494}, {1.0471975511965976, \
2.722713633111154}, {1.1519173063162573, 2.722713633111154}, 
     {1.1519173063162573, 2.617993877991494}}]}, {CMYKColor[0.35, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{1.0471975511965976, 2.722713633111154}, {1.0471975511965976, \
2.827433388230814}, {1.1519173063162573, 2.827433388230814}, 
     {1.1519173063162573, 2.722713633111154}}]}, {CMYKColor[0.35, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 2.827433388230814}, {1.0471975511965976, \
2.9321531433504733}, {1.1519173063162573, 2.9321531433504733}, 
     {1.1519173063162573, 2.827433388230814}}]}, {CMYKColor[0.35, 0.5, 0.475, \
0.1], 
   Polygon[{{1.0471975511965976, 2.9321531433504733}, {1.0471975511965976, \
3.036872898470133}, {1.1519173063162573, 3.036872898470133}, 
     {1.1519173063162573, 2.9321531433504733}}]}, {CMYKColor[0.35, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{1.0471975511965976, 3.036872898470133}, {1.0471975511965976, \
3.141592653589793}, {1.1519173063162573, 3.141592653589793}, 
     {1.1519173063162573, 3.036872898470133}}]}, {CMYKColor[0.35, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 3.141592653589793}, {1.0471975511965976, \
3.2463124087094526}, {1.1519173063162573, 3.2463124087094526}, 
     {1.1519173063162573, 3.141592653589793}}]}, {CMYKColor[0.35, 0.5, 0.525, \
0.1], 
   Polygon[{{1.0471975511965976, 3.2463124087094526}, {1.0471975511965976, \
3.3510321638291125}, {1.1519173063162573, 3.3510321638291125}, 
     {1.1519173063162573, 3.2463124087094526}}]}, {CMYKColor[0.35, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{1.0471975511965976, 3.3510321638291125}, {1.0471975511965976, \
3.4557519189487724}, {1.1519173063162573, 3.4557519189487724}, 
     {1.1519173063162573, 3.3510321638291125}}]}, {CMYKColor[0.35, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 3.4557519189487724}, {1.0471975511965976, \
3.560471674068432}, {1.1519173063162573, 3.560471674068432}, 
     {1.1519173063162573, 3.4557519189487724}}]}, {CMYKColor[0.35, 0.5, \
0.575, 0.1], 
   Polygon[{{1.0471975511965976, 3.560471674068432}, {1.0471975511965976, \
3.665191429188092}, {1.1519173063162573, 3.665191429188092}, 
     {1.1519173063162573, 3.560471674068432}}]}, {CMYKColor[0.35, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{1.0471975511965976, 3.665191429188092}, {1.0471975511965976, \
3.7699111843077517}, {1.1519173063162573, 3.7699111843077517}, 
     {1.1519173063162573, 3.665191429188092}}]}, {CMYKColor[0.35, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 3.7699111843077517}, {1.0471975511965976, \
3.874630939427411}, {1.1519173063162573, 3.874630939427411}, 
     {1.1519173063162573, 3.7699111843077517}}]}, {CMYKColor[0.35, 0.5, \
0.625, 0.1], 
   Polygon[{{1.0471975511965976, 3.874630939427411}, {1.0471975511965976, \
3.979350694547071}, {1.1519173063162573, 3.979350694547071}, 
     {1.1519173063162573, 3.874630939427411}}]}, {CMYKColor[0.35, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{1.0471975511965976, 3.979350694547071}, {1.0471975511965976, \
4.084070449666731}, {1.1519173063162573, 4.084070449666731}, 
     {1.1519173063162573, 3.979350694547071}}]}, {CMYKColor[0.35, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 4.084070449666731}, {1.0471975511965976, \
4.1887902047863905}, {1.1519173063162573, 4.1887902047863905}, 
     {1.1519173063162573, 4.084070449666731}}]}, {CMYKColor[0.35, 0.5, 0.675, \
0.1], 
   Polygon[{{1.0471975511965976, 4.1887902047863905}, {1.0471975511965976, \
4.29350995990605}, {1.1519173063162573, 4.29350995990605}, 
     {1.1519173063162573, 4.1887902047863905}}]}, {CMYKColor[0.35, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{1.0471975511965976, 4.29350995990605}, {1.0471975511965976, \
4.39822971502571}, {1.1519173063162573, 4.39822971502571}, 
     {1.1519173063162573, 4.29350995990605}}]}, {CMYKColor[0.35, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{1.0471975511965976, 4.39822971502571}, {1.0471975511965976, \
4.50294947014537}, {1.1519173063162573, 4.50294947014537}, 
     {1.1519173063162573, 4.39822971502571}}]}, {CMYKColor[0.35, 0.5, 0.725, \
0.1], 
   Polygon[{{1.0471975511965976, 4.50294947014537}, {1.0471975511965976, \
4.607669225265029}, {1.1519173063162573, 4.607669225265029}, 
     {1.1519173063162573, 4.50294947014537}}]}, {CMYKColor[0.35, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{1.0471975511965976, 4.607669225265029}, {1.0471975511965976, \
4.71238898038469}, {1.1519173063162573, 4.71238898038469}, 
     {1.1519173063162573, 4.607669225265029}}]}, {CMYKColor[0.35, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 4.71238898038469}, {1.0471975511965976, \
4.817108735504349}, {1.1519173063162573, 4.817108735504349}, 
     {1.1519173063162573, 4.71238898038469}}]}, {CMYKColor[0.35, 0.5, 0.775, \
0.1], 
   Polygon[{{1.0471975511965976, 4.817108735504349}, {1.0471975511965976, \
4.921828490624009}, {1.1519173063162573, 4.921828490624009}, 
     {1.1519173063162573, 4.817108735504349}}]}, {CMYKColor[0.35, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{1.0471975511965976, 4.921828490624009}, {1.0471975511965976, \
5.026548245743669}, {1.1519173063162573, 5.026548245743669}, 
     {1.1519173063162573, 4.921828490624009}}]}, {CMYKColor[0.35, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 5.026548245743669}, {1.0471975511965976, \
5.1312680008633285}, {1.1519173063162573, 5.1312680008633285}, 
     {1.1519173063162573, 5.026548245743669}}]}, {CMYKColor[0.35, 0.5, 0.825, \
0.1], 
   Polygon[{{1.0471975511965976, 5.1312680008633285}, {1.0471975511965976, \
5.235987755982988}, {1.1519173063162573, 5.235987755982988}, 
     {1.1519173063162573, 5.1312680008633285}}]}, {CMYKColor[0.35, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{1.0471975511965976, 5.235987755982988}, {1.0471975511965976, \
5.340707511102648}, {1.1519173063162573, 5.340707511102648}, 
     {1.1519173063162573, 5.235987755982988}}]}, {CMYKColor[0.35, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 5.340707511102648}, {1.0471975511965976, \
5.445427266222308}, {1.1519173063162573, 5.445427266222308}, 
     {1.1519173063162573, 5.340707511102648}}]}, {CMYKColor[0.35, 0.5, 0.875, \
0.1], 
   Polygon[{{1.0471975511965976, 5.445427266222308}, {1.0471975511965976, \
5.550147021341967}, {1.1519173063162573, 5.550147021341967}, 
     {1.1519173063162573, 5.445427266222308}}]}, {CMYKColor[0.35, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{1.0471975511965976, 5.550147021341967}, {1.0471975511965976, \
5.654866776461628}, {1.1519173063162573, 5.654866776461628}, 
     {1.1519173063162573, 5.550147021341967}}]}, {CMYKColor[0.35, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{1.0471975511965976, 5.654866776461628}, {1.0471975511965976, \
5.759586531581287}, {1.1519173063162573, 5.759586531581287}, 
     {1.1519173063162573, 5.654866776461628}}]}, {CMYKColor[0.35, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{1.0471975511965976, 5.759586531581287}, {1.0471975511965976, \
5.864306286700947}, {1.1519173063162573, 5.864306286700947}, 
     {1.1519173063162573, 5.759586531581287}}]}, {CMYKColor[0.35, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{1.0471975511965976, 5.864306286700947}, {1.0471975511965976, \
5.969026041820607}, {1.1519173063162573, 5.969026041820607}, 
     {1.1519173063162573, 5.864306286700947}}]}, {CMYKColor[0.35, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{1.0471975511965976, 5.969026041820607}, {1.0471975511965976, \
6.073745796940266}, {1.1519173063162573, 6.073745796940266}, 
     {1.1519173063162573, 5.969026041820607}}]}, {CMYKColor[0.35, 0.5, 0.975, \
0.1], 
   Polygon[{{1.0471975511965976, 6.073745796940266}, {1.0471975511965976, \
6.178465552059926}, {1.1519173063162573, 6.178465552059926}, 
     {1.1519173063162573, 6.073745796940266}}]}, {CMYKColor[0.35, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{1.0471975511965976, 6.178465552059926}, {1.0471975511965976, \
6.283185307179586}, {1.1519173063162573, 6.283185307179586}, 
     {1.1519173063162573, 6.178465552059926}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 0.}, {1.1519173063162573, \
0.10471975511965977}, {1.2566370614359172, 0.10471975511965977}, 
     {1.2566370614359172, 0.}}]}, {CMYKColor[0.3833333333333333, 0.5, 0.025, \
0.1], 
   Polygon[{{1.1519173063162573, 0.10471975511965977}, {1.1519173063162573, \
0.20943951023931953}, {1.2566370614359172, 0.20943951023931953}, 
     {1.2566370614359172, 0.10471975511965977}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{1.1519173063162573, 0.20943951023931953}, {1.1519173063162573, \
0.3141592653589793}, {1.2566370614359172, 0.3141592653589793}, 
     {1.2566370614359172, 0.20943951023931953}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{1.1519173063162573, 0.3141592653589793}, {1.1519173063162573, \
0.41887902047863906}, {1.2566370614359172, 0.41887902047863906}, 
     {1.2566370614359172, 0.3141592653589793}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{1.1519173063162573, 0.41887902047863906}, {1.1519173063162573, \
0.5235987755982988}, {1.2566370614359172, 0.5235987755982988}, 
     {1.2566370614359172, 0.41887902047863906}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{1.1519173063162573, 0.5235987755982988}, {1.1519173063162573, \
0.6283185307179586}, {1.2566370614359172, 0.6283185307179586}, 
     {1.2566370614359172, 0.5235987755982988}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{1.1519173063162573, 0.6283185307179586}, {1.1519173063162573, \
0.7330382858376183}, {1.2566370614359172, 0.7330382858376183}, 
     {1.2566370614359172, 0.6283185307179586}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{1.1519173063162573, 0.7330382858376183}, {1.1519173063162573, \
0.8377580409572781}, {1.2566370614359172, 0.8377580409572781}, 
     {1.2566370614359172, 0.7330382858376183}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{1.1519173063162573, 0.8377580409572781}, {1.1519173063162573, \
0.9424777960769379}, {1.2566370614359172, 0.9424777960769379}, 
     {1.2566370614359172, 0.8377580409572781}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 0.9424777960769379}, {1.1519173063162573, \
1.0471975511965976}, {1.2566370614359172, 1.0471975511965976}, 
     {1.2566370614359172, 0.9424777960769379}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{1.1519173063162573, 1.0471975511965976}, {1.1519173063162573, \
1.1519173063162573}, {1.2566370614359172, 1.1519173063162573}, 
     {1.2566370614359172, 1.0471975511965976}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{1.1519173063162573, 1.1519173063162573}, {1.1519173063162573, \
1.2566370614359172}, {1.2566370614359172, 1.2566370614359172}, 
     {1.2566370614359172, 1.1519173063162573}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.1519173063162573, 1.2566370614359172}, {1.1519173063162573, \
1.361356816555577}, {1.2566370614359172, 1.361356816555577}, 
     {1.2566370614359172, 1.2566370614359172}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{1.1519173063162573, 1.361356816555577}, {1.1519173063162573, \
1.4660765716752366}, {1.2566370614359172, 1.4660765716752366}, 
     {1.2566370614359172, 1.361356816555577}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.1519173063162573, 1.4660765716752366}, {1.1519173063162573, \
1.5707963267948966}, {1.2566370614359172, 1.5707963267948966}, 
     {1.2566370614359172, 1.4660765716752366}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 1.5707963267948966}, {1.1519173063162573, \
1.6755160819145563}, {1.2566370614359172, 1.6755160819145563}, 
     {1.2566370614359172, 1.5707963267948966}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{1.1519173063162573, 1.6755160819145563}, {1.1519173063162573, \
1.780235837034216}, {1.2566370614359172, 1.780235837034216}, 
     {1.2566370614359172, 1.6755160819145563}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.1519173063162573, 1.780235837034216}, {1.1519173063162573, \
1.8849555921538759}, {1.2566370614359172, 1.8849555921538759}, 
     {1.2566370614359172, 1.780235837034216}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.1519173063162573, 1.8849555921538759}, {1.1519173063162573, \
1.9896753472735356}, {1.2566370614359172, 1.9896753472735356}, 
     {1.2566370614359172, 1.8849555921538759}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{1.1519173063162573, 1.9896753472735356}, {1.1519173063162573, \
2.0943951023931953}, {1.2566370614359172, 2.0943951023931953}, 
     {1.2566370614359172, 1.9896753472735356}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{1.1519173063162573, 2.0943951023931953}, {1.1519173063162573, \
2.199114857512855}, {1.2566370614359172, 2.199114857512855}, 
     {1.2566370614359172, 2.0943951023931953}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{1.1519173063162573, 2.199114857512855}, {1.1519173063162573, \
2.3038346126325147}, {1.2566370614359172, 2.3038346126325147}, 
     {1.2566370614359172, 2.199114857512855}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{1.1519173063162573, 2.3038346126325147}, {1.1519173063162573, \
2.4085543677521746}, {1.2566370614359172, 2.4085543677521746}, 
     {1.2566370614359172, 2.3038346126325147}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{1.1519173063162573, 2.4085543677521746}, {1.1519173063162573, \
2.5132741228718345}, {1.2566370614359172, 2.5132741228718345}, 
     {1.2566370614359172, 2.4085543677521746}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 2.5132741228718345}, {1.1519173063162573, \
2.617993877991494}, {1.2566370614359172, 2.617993877991494}, 
     {1.2566370614359172, 2.5132741228718345}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{1.1519173063162573, 2.617993877991494}, {1.1519173063162573, \
2.722713633111154}, {1.2566370614359172, 2.722713633111154}, 
     {1.2566370614359172, 2.617993877991494}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{1.1519173063162573, 2.722713633111154}, {1.1519173063162573, \
2.827433388230814}, {1.2566370614359172, 2.827433388230814}, 
     {1.2566370614359172, 2.722713633111154}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 2.827433388230814}, {1.1519173063162573, \
2.9321531433504733}, {1.2566370614359172, 2.9321531433504733}, 
     {1.2566370614359172, 2.827433388230814}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{1.1519173063162573, 2.9321531433504733}, {1.1519173063162573, \
3.036872898470133}, {1.2566370614359172, 3.036872898470133}, 
     {1.2566370614359172, 2.9321531433504733}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{1.1519173063162573, 3.036872898470133}, {1.1519173063162573, \
3.141592653589793}, {1.2566370614359172, 3.141592653589793}, 
     {1.2566370614359172, 3.036872898470133}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 3.141592653589793}, {1.1519173063162573, \
3.2463124087094526}, {1.2566370614359172, 3.2463124087094526}, 
     {1.2566370614359172, 3.141592653589793}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{1.1519173063162573, 3.2463124087094526}, {1.1519173063162573, \
3.3510321638291125}, {1.2566370614359172, 3.3510321638291125}, 
     {1.2566370614359172, 3.2463124087094526}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{1.1519173063162573, 3.3510321638291125}, {1.1519173063162573, \
3.4557519189487724}, {1.2566370614359172, 3.4557519189487724}, 
     {1.2566370614359172, 3.3510321638291125}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 3.4557519189487724}, {1.1519173063162573, \
3.560471674068432}, {1.2566370614359172, 3.560471674068432}, 
     {1.2566370614359172, 3.4557519189487724}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{1.1519173063162573, 3.560471674068432}, {1.1519173063162573, \
3.665191429188092}, {1.2566370614359172, 3.665191429188092}, 
     {1.2566370614359172, 3.560471674068432}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{1.1519173063162573, 3.665191429188092}, {1.1519173063162573, \
3.7699111843077517}, {1.2566370614359172, 3.7699111843077517}, 
     {1.2566370614359172, 3.665191429188092}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 3.7699111843077517}, {1.1519173063162573, \
3.874630939427411}, {1.2566370614359172, 3.874630939427411}, 
     {1.2566370614359172, 3.7699111843077517}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{1.1519173063162573, 3.874630939427411}, {1.1519173063162573, \
3.979350694547071}, {1.2566370614359172, 3.979350694547071}, 
     {1.2566370614359172, 3.874630939427411}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{1.1519173063162573, 3.979350694547071}, {1.1519173063162573, \
4.084070449666731}, {1.2566370614359172, 4.084070449666731}, 
     {1.2566370614359172, 3.979350694547071}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 4.084070449666731}, {1.1519173063162573, \
4.1887902047863905}, {1.2566370614359172, 4.1887902047863905}, 
     {1.2566370614359172, 4.084070449666731}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{1.1519173063162573, 4.1887902047863905}, {1.1519173063162573, \
4.29350995990605}, {1.2566370614359172, 4.29350995990605}, 
     {1.2566370614359172, 4.1887902047863905}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{1.1519173063162573, 4.29350995990605}, {1.1519173063162573, \
4.39822971502571}, {1.2566370614359172, 4.39822971502571}, 
     {1.2566370614359172, 4.29350995990605}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.1519173063162573, 4.39822971502571}, {1.1519173063162573, \
4.50294947014537}, {1.2566370614359172, 4.50294947014537}, 
     {1.2566370614359172, 4.39822971502571}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{1.1519173063162573, 4.50294947014537}, {1.1519173063162573, \
4.607669225265029}, {1.2566370614359172, 4.607669225265029}, 
     {1.2566370614359172, 4.50294947014537}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.1519173063162573, 4.607669225265029}, {1.1519173063162573, \
4.71238898038469}, {1.2566370614359172, 4.71238898038469}, 
     {1.2566370614359172, 4.607669225265029}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 4.71238898038469}, {1.1519173063162573, \
4.817108735504349}, {1.2566370614359172, 4.817108735504349}, 
     {1.2566370614359172, 4.71238898038469}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{1.1519173063162573, 4.817108735504349}, {1.1519173063162573, \
4.921828490624009}, {1.2566370614359172, 4.921828490624009}, 
     {1.2566370614359172, 4.817108735504349}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.1519173063162573, 4.921828490624009}, {1.1519173063162573, \
5.026548245743669}, {1.2566370614359172, 5.026548245743669}, 
     {1.2566370614359172, 4.921828490624009}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 5.026548245743669}, {1.1519173063162573, \
5.1312680008633285}, {1.2566370614359172, 5.1312680008633285}, 
     {1.2566370614359172, 5.026548245743669}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{1.1519173063162573, 5.1312680008633285}, {1.1519173063162573, \
5.235987755982988}, {1.2566370614359172, 5.235987755982988}, 
     {1.2566370614359172, 5.1312680008633285}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{1.1519173063162573, 5.235987755982988}, {1.1519173063162573, \
5.340707511102648}, {1.2566370614359172, 5.340707511102648}, 
     {1.2566370614359172, 5.235987755982988}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 5.340707511102648}, {1.1519173063162573, \
5.445427266222308}, {1.2566370614359172, 5.445427266222308}, 
     {1.2566370614359172, 5.340707511102648}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{1.1519173063162573, 5.445427266222308}, {1.1519173063162573, \
5.550147021341967}, {1.2566370614359172, 5.550147021341967}, 
     {1.2566370614359172, 5.445427266222308}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{1.1519173063162573, 5.550147021341967}, {1.1519173063162573, \
5.654866776461628}, {1.2566370614359172, 5.654866776461628}, 
     {1.2566370614359172, 5.550147021341967}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{1.1519173063162573, 5.654866776461628}, {1.1519173063162573, \
5.759586531581287}, {1.2566370614359172, 5.759586531581287}, 
     {1.2566370614359172, 5.654866776461628}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{1.1519173063162573, 5.759586531581287}, {1.1519173063162573, \
5.864306286700947}, {1.2566370614359172, 5.864306286700947}, 
     {1.2566370614359172, 5.759586531581287}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{1.1519173063162573, 5.864306286700947}, {1.1519173063162573, \
5.969026041820607}, {1.2566370614359172, 5.969026041820607}, 
     {1.2566370614359172, 5.864306286700947}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{1.1519173063162573, 5.969026041820607}, {1.1519173063162573, \
6.073745796940266}, {1.2566370614359172, 6.073745796940266}, 
     {1.2566370614359172, 5.969026041820607}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{1.1519173063162573, 6.073745796940266}, {1.1519173063162573, \
6.178465552059926}, {1.2566370614359172, 6.178465552059926}, 
     {1.2566370614359172, 6.073745796940266}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{1.1519173063162573, 6.178465552059926}, {1.1519173063162573, \
6.283185307179586}, {1.2566370614359172, 6.283185307179586}, 
     {1.2566370614359172, 6.178465552059926}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 0.}, {1.2566370614359172, \
0.10471975511965977}, {1.361356816555577, 0.10471975511965977}, 
     {1.361356816555577, 0.}}]}, {CMYKColor[0.4166666666666667, 0.5, 0.025, \
0.1], 
   Polygon[{{1.2566370614359172, 0.10471975511965977}, {1.2566370614359172, \
0.20943951023931953}, {1.361356816555577, 0.20943951023931953}, 
     {1.361356816555577, 0.10471975511965977}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{1.2566370614359172, 0.20943951023931953}, {1.2566370614359172, \
0.3141592653589793}, {1.361356816555577, 0.3141592653589793}, 
     {1.361356816555577, 0.20943951023931953}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{1.2566370614359172, 0.3141592653589793}, {1.2566370614359172, \
0.41887902047863906}, {1.361356816555577, 0.41887902047863906}, 
     {1.361356816555577, 0.3141592653589793}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{1.2566370614359172, 0.41887902047863906}, {1.2566370614359172, \
0.5235987755982988}, {1.361356816555577, 0.5235987755982988}, 
     {1.361356816555577, 0.41887902047863906}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{1.2566370614359172, 0.5235987755982988}, {1.2566370614359172, \
0.6283185307179586}, {1.361356816555577, 0.6283185307179586}, 
     {1.361356816555577, 0.5235987755982988}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{1.2566370614359172, 0.6283185307179586}, {1.2566370614359172, \
0.7330382858376183}, {1.361356816555577, 0.7330382858376183}, 
     {1.361356816555577, 0.6283185307179586}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{1.2566370614359172, 0.7330382858376183}, {1.2566370614359172, \
0.8377580409572781}, {1.361356816555577, 0.8377580409572781}, 
     {1.361356816555577, 0.7330382858376183}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{1.2566370614359172, 0.8377580409572781}, {1.2566370614359172, \
0.9424777960769379}, {1.361356816555577, 0.9424777960769379}, 
     {1.361356816555577, 0.8377580409572781}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 0.9424777960769379}, {1.2566370614359172, \
1.0471975511965976}, {1.361356816555577, 1.0471975511965976}, 
     {1.361356816555577, 0.9424777960769379}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{1.2566370614359172, 1.0471975511965976}, {1.2566370614359172, \
1.1519173063162573}, {1.361356816555577, 1.1519173063162573}, 
     {1.361356816555577, 1.0471975511965976}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{1.2566370614359172, 1.1519173063162573}, {1.2566370614359172, \
1.2566370614359172}, {1.361356816555577, 1.2566370614359172}, 
     {1.361356816555577, 1.1519173063162573}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.2566370614359172, 1.2566370614359172}, {1.2566370614359172, \
1.361356816555577}, {1.361356816555577, 1.361356816555577}, 
     {1.361356816555577, 1.2566370614359172}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{1.2566370614359172, 1.361356816555577}, {1.2566370614359172, \
1.4660765716752366}, {1.361356816555577, 1.4660765716752366}, 
     {1.361356816555577, 1.361356816555577}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.2566370614359172, 1.4660765716752366}, {1.2566370614359172, \
1.5707963267948966}, {1.361356816555577, 1.5707963267948966}, 
     {1.361356816555577, 1.4660765716752366}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 1.5707963267948966}, {1.2566370614359172, \
1.6755160819145563}, {1.361356816555577, 1.6755160819145563}, 
     {1.361356816555577, 1.5707963267948966}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{1.2566370614359172, 1.6755160819145563}, {1.2566370614359172, \
1.780235837034216}, {1.361356816555577, 1.780235837034216}, 
     {1.361356816555577, 1.6755160819145563}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.2566370614359172, 1.780235837034216}, {1.2566370614359172, \
1.8849555921538759}, {1.361356816555577, 1.8849555921538759}, 
     {1.361356816555577, 1.780235837034216}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.2566370614359172, 1.8849555921538759}, {1.2566370614359172, \
1.9896753472735356}, {1.361356816555577, 1.9896753472735356}, 
     {1.361356816555577, 1.8849555921538759}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{1.2566370614359172, 1.9896753472735356}, {1.2566370614359172, \
2.0943951023931953}, {1.361356816555577, 2.0943951023931953}, 
     {1.361356816555577, 1.9896753472735356}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{1.2566370614359172, 2.0943951023931953}, {1.2566370614359172, \
2.199114857512855}, {1.361356816555577, 2.199114857512855}, 
     {1.361356816555577, 2.0943951023931953}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{1.2566370614359172, 2.199114857512855}, {1.2566370614359172, \
2.3038346126325147}, {1.361356816555577, 2.3038346126325147}, 
     {1.361356816555577, 2.199114857512855}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{1.2566370614359172, 2.3038346126325147}, {1.2566370614359172, \
2.4085543677521746}, {1.361356816555577, 2.4085543677521746}, 
     {1.361356816555577, 2.3038346126325147}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{1.2566370614359172, 2.4085543677521746}, {1.2566370614359172, \
2.5132741228718345}, {1.361356816555577, 2.5132741228718345}, 
     {1.361356816555577, 2.4085543677521746}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 2.5132741228718345}, {1.2566370614359172, \
2.617993877991494}, {1.361356816555577, 2.617993877991494}, 
     {1.361356816555577, 2.5132741228718345}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{1.2566370614359172, 2.617993877991494}, {1.2566370614359172, \
2.722713633111154}, {1.361356816555577, 2.722713633111154}, 
     {1.361356816555577, 2.617993877991494}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{1.2566370614359172, 2.722713633111154}, {1.2566370614359172, \
2.827433388230814}, {1.361356816555577, 2.827433388230814}, 
     {1.361356816555577, 2.722713633111154}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 2.827433388230814}, {1.2566370614359172, \
2.9321531433504733}, {1.361356816555577, 2.9321531433504733}, 
     {1.361356816555577, 2.827433388230814}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{1.2566370614359172, 2.9321531433504733}, {1.2566370614359172, \
3.036872898470133}, {1.361356816555577, 3.036872898470133}, 
     {1.361356816555577, 2.9321531433504733}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{1.2566370614359172, 3.036872898470133}, {1.2566370614359172, \
3.141592653589793}, {1.361356816555577, 3.141592653589793}, 
     {1.361356816555577, 3.036872898470133}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 3.141592653589793}, {1.2566370614359172, \
3.2463124087094526}, {1.361356816555577, 3.2463124087094526}, 
     {1.361356816555577, 3.141592653589793}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{1.2566370614359172, 3.2463124087094526}, {1.2566370614359172, \
3.3510321638291125}, {1.361356816555577, 3.3510321638291125}, 
     {1.361356816555577, 3.2463124087094526}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{1.2566370614359172, 3.3510321638291125}, {1.2566370614359172, \
3.4557519189487724}, {1.361356816555577, 3.4557519189487724}, 
     {1.361356816555577, 3.3510321638291125}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 3.4557519189487724}, {1.2566370614359172, \
3.560471674068432}, {1.361356816555577, 3.560471674068432}, 
     {1.361356816555577, 3.4557519189487724}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{1.2566370614359172, 3.560471674068432}, {1.2566370614359172, \
3.665191429188092}, {1.361356816555577, 3.665191429188092}, 
     {1.361356816555577, 3.560471674068432}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{1.2566370614359172, 3.665191429188092}, {1.2566370614359172, \
3.7699111843077517}, {1.361356816555577, 3.7699111843077517}, 
     {1.361356816555577, 3.665191429188092}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 3.7699111843077517}, {1.2566370614359172, \
3.874630939427411}, {1.361356816555577, 3.874630939427411}, 
     {1.361356816555577, 3.7699111843077517}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{1.2566370614359172, 3.874630939427411}, {1.2566370614359172, \
3.979350694547071}, {1.361356816555577, 3.979350694547071}, 
     {1.361356816555577, 3.874630939427411}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{1.2566370614359172, 3.979350694547071}, {1.2566370614359172, \
4.084070449666731}, {1.361356816555577, 4.084070449666731}, 
     {1.361356816555577, 3.979350694547071}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 4.084070449666731}, {1.2566370614359172, \
4.1887902047863905}, {1.361356816555577, 4.1887902047863905}, 
     {1.361356816555577, 4.084070449666731}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{1.2566370614359172, 4.1887902047863905}, {1.2566370614359172, \
4.29350995990605}, {1.361356816555577, 4.29350995990605}, 
     {1.361356816555577, 4.1887902047863905}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{1.2566370614359172, 4.29350995990605}, {1.2566370614359172, \
4.39822971502571}, {1.361356816555577, 4.39822971502571}, 
     {1.361356816555577, 4.29350995990605}}]}, {CMYKColor[0.4166666666666667, \
0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.2566370614359172, 4.39822971502571}, {1.2566370614359172, \
4.50294947014537}, {1.361356816555577, 4.50294947014537}, 
     {1.361356816555577, 4.39822971502571}}]}, {CMYKColor[0.4166666666666667, \
0.5, 0.725, 0.1], 
   Polygon[{{1.2566370614359172, 4.50294947014537}, {1.2566370614359172, \
4.607669225265029}, {1.361356816555577, 4.607669225265029}, 
     {1.361356816555577, 4.50294947014537}}]}, {CMYKColor[0.4166666666666667, \
0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.2566370614359172, 4.607669225265029}, {1.2566370614359172, \
4.71238898038469}, {1.361356816555577, 4.71238898038469}, 
     {1.361356816555577, 4.607669225265029}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 4.71238898038469}, {1.2566370614359172, \
4.817108735504349}, {1.361356816555577, 4.817108735504349}, 
     {1.361356816555577, 4.71238898038469}}]}, {CMYKColor[0.4166666666666667, \
0.5, 0.775, 0.1], 
   Polygon[{{1.2566370614359172, 4.817108735504349}, {1.2566370614359172, \
4.921828490624009}, {1.361356816555577, 4.921828490624009}, 
     {1.361356816555577, 4.817108735504349}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.2566370614359172, 4.921828490624009}, {1.2566370614359172, \
5.026548245743669}, {1.361356816555577, 5.026548245743669}, 
     {1.361356816555577, 4.921828490624009}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 5.026548245743669}, {1.2566370614359172, \
5.1312680008633285}, {1.361356816555577, 5.1312680008633285}, 
     {1.361356816555577, 5.026548245743669}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{1.2566370614359172, 5.1312680008633285}, {1.2566370614359172, \
5.235987755982988}, {1.361356816555577, 5.235987755982988}, 
     {1.361356816555577, 5.1312680008633285}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{1.2566370614359172, 5.235987755982988}, {1.2566370614359172, \
5.340707511102648}, {1.361356816555577, 5.340707511102648}, 
     {1.361356816555577, 5.235987755982988}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 5.340707511102648}, {1.2566370614359172, \
5.445427266222308}, {1.361356816555577, 5.445427266222308}, 
     {1.361356816555577, 5.340707511102648}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{1.2566370614359172, 5.445427266222308}, {1.2566370614359172, \
5.550147021341967}, {1.361356816555577, 5.550147021341967}, 
     {1.361356816555577, 5.445427266222308}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{1.2566370614359172, 5.550147021341967}, {1.2566370614359172, \
5.654866776461628}, {1.361356816555577, 5.654866776461628}, 
     {1.361356816555577, 5.550147021341967}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{1.2566370614359172, 5.654866776461628}, {1.2566370614359172, \
5.759586531581287}, {1.361356816555577, 5.759586531581287}, 
     {1.361356816555577, 5.654866776461628}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{1.2566370614359172, 5.759586531581287}, {1.2566370614359172, \
5.864306286700947}, {1.361356816555577, 5.864306286700947}, 
     {1.361356816555577, 5.759586531581287}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{1.2566370614359172, 5.864306286700947}, {1.2566370614359172, \
5.969026041820607}, {1.361356816555577, 5.969026041820607}, 
     {1.361356816555577, 5.864306286700947}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{1.2566370614359172, 5.969026041820607}, {1.2566370614359172, \
6.073745796940266}, {1.361356816555577, 6.073745796940266}, 
     {1.361356816555577, 5.969026041820607}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{1.2566370614359172, 6.073745796940266}, {1.2566370614359172, \
6.178465552059926}, {1.361356816555577, 6.178465552059926}, 
     {1.361356816555577, 6.073745796940266}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{1.2566370614359172, 6.178465552059926}, {1.2566370614359172, \
6.283185307179586}, {1.361356816555577, 6.283185307179586}, 
     {1.361356816555577, 6.178465552059926}}]}, {CMYKColor[0.45, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{1.361356816555577, 0.}, {1.361356816555577, \
0.10471975511965977}, {1.4660765716752366, 0.10471975511965977}, 
     {1.4660765716752366, 0.}}]}, {CMYKColor[0.45, 0.5, 0.025, 0.1], 
   Polygon[{{1.361356816555577, 0.10471975511965977}, {1.361356816555577, \
0.20943951023931953}, {1.4660765716752366, 0.20943951023931953}, 
     {1.4660765716752366, 0.10471975511965977}}]}, {CMYKColor[0.45, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{1.361356816555577, 0.20943951023931953}, {1.361356816555577, \
0.3141592653589793}, {1.4660765716752366, 0.3141592653589793}, 
     {1.4660765716752366, 0.20943951023931953}}]}, {CMYKColor[0.45, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{1.361356816555577, 0.3141592653589793}, {1.361356816555577, \
0.41887902047863906}, {1.4660765716752366, 0.41887902047863906}, 
     {1.4660765716752366, 0.3141592653589793}}]}, {CMYKColor[0.45, 0.5, \
0.075, 0.1], 
   Polygon[{{1.361356816555577, 0.41887902047863906}, {1.361356816555577, \
0.5235987755982988}, {1.4660765716752366, 0.5235987755982988}, 
     {1.4660765716752366, 0.41887902047863906}}]}, {CMYKColor[0.45, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{1.361356816555577, 0.5235987755982988}, {1.361356816555577, \
0.6283185307179586}, {1.4660765716752366, 0.6283185307179586}, 
     {1.4660765716752366, 0.5235987755982988}}]}, {CMYKColor[0.45, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{1.361356816555577, 0.6283185307179586}, {1.361356816555577, \
0.7330382858376183}, {1.4660765716752366, 0.7330382858376183}, 
     {1.4660765716752366, 0.6283185307179586}}]}, {CMYKColor[0.45, 0.5, \
0.125, 0.1], 
   Polygon[{{1.361356816555577, 0.7330382858376183}, {1.361356816555577, \
0.8377580409572781}, {1.4660765716752366, 0.8377580409572781}, 
     {1.4660765716752366, 0.7330382858376183}}]}, {CMYKColor[0.45, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{1.361356816555577, 0.8377580409572781}, {1.361356816555577, \
0.9424777960769379}, {1.4660765716752366, 0.9424777960769379}, 
     {1.4660765716752366, 0.8377580409572781}}]}, {CMYKColor[0.45, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{1.361356816555577, 0.9424777960769379}, {1.361356816555577, \
1.0471975511965976}, {1.4660765716752366, 1.0471975511965976}, 
     {1.4660765716752366, 0.9424777960769379}}]}, {CMYKColor[0.45, 0.5, \
0.175, 0.1], 
   Polygon[{{1.361356816555577, 1.0471975511965976}, {1.361356816555577, \
1.1519173063162573}, {1.4660765716752366, 1.1519173063162573}, 
     {1.4660765716752366, 1.0471975511965976}}]}, {CMYKColor[0.45, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{1.361356816555577, 1.1519173063162573}, {1.361356816555577, \
1.2566370614359172}, {1.4660765716752366, 1.2566370614359172}, 
     {1.4660765716752366, 1.1519173063162573}}]}, {CMYKColor[0.45, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{1.361356816555577, 1.2566370614359172}, {1.361356816555577, \
1.361356816555577}, {1.4660765716752366, 1.361356816555577}, 
     {1.4660765716752366, 1.2566370614359172}}]}, {CMYKColor[0.45, 0.5, \
0.225, 0.1], 
   Polygon[{{1.361356816555577, 1.361356816555577}, {1.361356816555577, \
1.4660765716752366}, {1.4660765716752366, 1.4660765716752366}, 
     {1.4660765716752366, 1.361356816555577}}]}, {CMYKColor[0.45, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{1.361356816555577, 1.4660765716752366}, {1.361356816555577, \
1.5707963267948966}, {1.4660765716752366, 1.5707963267948966}, 
     {1.4660765716752366, 1.4660765716752366}}]}, {CMYKColor[0.45, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{1.361356816555577, 1.5707963267948966}, {1.361356816555577, \
1.6755160819145563}, {1.4660765716752366, 1.6755160819145563}, 
     {1.4660765716752366, 1.5707963267948966}}]}, {CMYKColor[0.45, 0.5, \
0.275, 0.1], 
   Polygon[{{1.361356816555577, 1.6755160819145563}, {1.361356816555577, \
1.780235837034216}, {1.4660765716752366, 1.780235837034216}, 
     {1.4660765716752366, 1.6755160819145563}}]}, {CMYKColor[0.45, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{1.361356816555577, 1.780235837034216}, {1.361356816555577, \
1.8849555921538759}, {1.4660765716752366, 1.8849555921538759}, 
     {1.4660765716752366, 1.780235837034216}}]}, {CMYKColor[0.45, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{1.361356816555577, 1.8849555921538759}, {1.361356816555577, \
1.9896753472735356}, {1.4660765716752366, 1.9896753472735356}, 
     {1.4660765716752366, 1.8849555921538759}}]}, {CMYKColor[0.45, 0.5, \
0.325, 0.1], 
   Polygon[{{1.361356816555577, 1.9896753472735356}, {1.361356816555577, \
2.0943951023931953}, {1.4660765716752366, 2.0943951023931953}, 
     {1.4660765716752366, 1.9896753472735356}}]}, {CMYKColor[0.45, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{1.361356816555577, 2.0943951023931953}, {1.361356816555577, \
2.199114857512855}, {1.4660765716752366, 2.199114857512855}, 
     {1.4660765716752366, 2.0943951023931953}}]}, {CMYKColor[0.45, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{1.361356816555577, 2.199114857512855}, {1.361356816555577, \
2.3038346126325147}, {1.4660765716752366, 2.3038346126325147}, 
     {1.4660765716752366, 2.199114857512855}}]}, {CMYKColor[0.45, 0.5, 0.375, \
0.1], 
   Polygon[{{1.361356816555577, 2.3038346126325147}, {1.361356816555577, \
2.4085543677521746}, {1.4660765716752366, 2.4085543677521746}, 
     {1.4660765716752366, 2.3038346126325147}}]}, {CMYKColor[0.45, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{1.361356816555577, 2.4085543677521746}, {1.361356816555577, \
2.5132741228718345}, {1.4660765716752366, 2.5132741228718345}, 
     {1.4660765716752366, 2.4085543677521746}}]}, {CMYKColor[0.45, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{1.361356816555577, 2.5132741228718345}, {1.361356816555577, \
2.617993877991494}, {1.4660765716752366, 2.617993877991494}, 
     {1.4660765716752366, 2.5132741228718345}}]}, {CMYKColor[0.45, 0.5, \
0.425, 0.1], 
   Polygon[{{1.361356816555577, 2.617993877991494}, {1.361356816555577, \
2.722713633111154}, {1.4660765716752366, 2.722713633111154}, 
     {1.4660765716752366, 2.617993877991494}}]}, {CMYKColor[0.45, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{1.361356816555577, 2.722713633111154}, {1.361356816555577, \
2.827433388230814}, {1.4660765716752366, 2.827433388230814}, 
     {1.4660765716752366, 2.722713633111154}}]}, {CMYKColor[0.45, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{1.361356816555577, 2.827433388230814}, {1.361356816555577, \
2.9321531433504733}, {1.4660765716752366, 2.9321531433504733}, 
     {1.4660765716752366, 2.827433388230814}}]}, {CMYKColor[0.45, 0.5, 0.475, \
0.1], 
   Polygon[{{1.361356816555577, 2.9321531433504733}, {1.361356816555577, \
3.036872898470133}, {1.4660765716752366, 3.036872898470133}, 
     {1.4660765716752366, 2.9321531433504733}}]}, {CMYKColor[0.45, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{1.361356816555577, 3.036872898470133}, {1.361356816555577, \
3.141592653589793}, {1.4660765716752366, 3.141592653589793}, 
     {1.4660765716752366, 3.036872898470133}}]}, {CMYKColor[0.45, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{1.361356816555577, 3.141592653589793}, {1.361356816555577, \
3.2463124087094526}, {1.4660765716752366, 3.2463124087094526}, 
     {1.4660765716752366, 3.141592653589793}}]}, {CMYKColor[0.45, 0.5, 0.525, \
0.1], 
   Polygon[{{1.361356816555577, 3.2463124087094526}, {1.361356816555577, \
3.3510321638291125}, {1.4660765716752366, 3.3510321638291125}, 
     {1.4660765716752366, 3.2463124087094526}}]}, {CMYKColor[0.45, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{1.361356816555577, 3.3510321638291125}, {1.361356816555577, \
3.4557519189487724}, {1.4660765716752366, 3.4557519189487724}, 
     {1.4660765716752366, 3.3510321638291125}}]}, {CMYKColor[0.45, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{1.361356816555577, 3.4557519189487724}, {1.361356816555577, \
3.560471674068432}, {1.4660765716752366, 3.560471674068432}, 
     {1.4660765716752366, 3.4557519189487724}}]}, {CMYKColor[0.45, 0.5, \
0.575, 0.1], 
   Polygon[{{1.361356816555577, 3.560471674068432}, {1.361356816555577, \
3.665191429188092}, {1.4660765716752366, 3.665191429188092}, 
     {1.4660765716752366, 3.560471674068432}}]}, {CMYKColor[0.45, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{1.361356816555577, 3.665191429188092}, {1.361356816555577, \
3.7699111843077517}, {1.4660765716752366, 3.7699111843077517}, 
     {1.4660765716752366, 3.665191429188092}}]}, {CMYKColor[0.45, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{1.361356816555577, 3.7699111843077517}, {1.361356816555577, \
3.874630939427411}, {1.4660765716752366, 3.874630939427411}, 
     {1.4660765716752366, 3.7699111843077517}}]}, {CMYKColor[0.45, 0.5, \
0.625, 0.1], 
   Polygon[{{1.361356816555577, 3.874630939427411}, {1.361356816555577, \
3.979350694547071}, {1.4660765716752366, 3.979350694547071}, 
     {1.4660765716752366, 3.874630939427411}}]}, {CMYKColor[0.45, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{1.361356816555577, 3.979350694547071}, {1.361356816555577, \
4.084070449666731}, {1.4660765716752366, 4.084070449666731}, 
     {1.4660765716752366, 3.979350694547071}}]}, {CMYKColor[0.45, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{1.361356816555577, 4.084070449666731}, {1.361356816555577, \
4.1887902047863905}, {1.4660765716752366, 4.1887902047863905}, 
     {1.4660765716752366, 4.084070449666731}}]}, {CMYKColor[0.45, 0.5, 0.675, \
0.1], 
   Polygon[{{1.361356816555577, 4.1887902047863905}, {1.361356816555577, \
4.29350995990605}, {1.4660765716752366, 4.29350995990605}, 
     {1.4660765716752366, 4.1887902047863905}}]}, {CMYKColor[0.45, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{1.361356816555577, 4.29350995990605}, {1.361356816555577, \
4.39822971502571}, {1.4660765716752366, 4.39822971502571}, 
     {1.4660765716752366, 4.29350995990605}}]}, {CMYKColor[0.45, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{1.361356816555577, 4.39822971502571}, {1.361356816555577, \
4.50294947014537}, {1.4660765716752366, 4.50294947014537}, 
     {1.4660765716752366, 4.39822971502571}}]}, {CMYKColor[0.45, 0.5, 0.725, \
0.1], 
   Polygon[{{1.361356816555577, 4.50294947014537}, {1.361356816555577, \
4.607669225265029}, {1.4660765716752366, 4.607669225265029}, 
     {1.4660765716752366, 4.50294947014537}}]}, {CMYKColor[0.45, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{1.361356816555577, 4.607669225265029}, {1.361356816555577, \
4.71238898038469}, {1.4660765716752366, 4.71238898038469}, 
     {1.4660765716752366, 4.607669225265029}}]}, {CMYKColor[0.45, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{1.361356816555577, 4.71238898038469}, {1.361356816555577, \
4.817108735504349}, {1.4660765716752366, 4.817108735504349}, 
     {1.4660765716752366, 4.71238898038469}}]}, {CMYKColor[0.45, 0.5, 0.775, \
0.1], 
   Polygon[{{1.361356816555577, 4.817108735504349}, {1.361356816555577, \
4.921828490624009}, {1.4660765716752366, 4.921828490624009}, 
     {1.4660765716752366, 4.817108735504349}}]}, {CMYKColor[0.45, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{1.361356816555577, 4.921828490624009}, {1.361356816555577, \
5.026548245743669}, {1.4660765716752366, 5.026548245743669}, 
     {1.4660765716752366, 4.921828490624009}}]}, {CMYKColor[0.45, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{1.361356816555577, 5.026548245743669}, {1.361356816555577, \
5.1312680008633285}, {1.4660765716752366, 5.1312680008633285}, 
     {1.4660765716752366, 5.026548245743669}}]}, {CMYKColor[0.45, 0.5, 0.825, \
0.1], 
   Polygon[{{1.361356816555577, 5.1312680008633285}, {1.361356816555577, \
5.235987755982988}, {1.4660765716752366, 5.235987755982988}, 
     {1.4660765716752366, 5.1312680008633285}}]}, {CMYKColor[0.45, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{1.361356816555577, 5.235987755982988}, {1.361356816555577, \
5.340707511102648}, {1.4660765716752366, 5.340707511102648}, 
     {1.4660765716752366, 5.235987755982988}}]}, {CMYKColor[0.45, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{1.361356816555577, 5.340707511102648}, {1.361356816555577, \
5.445427266222308}, {1.4660765716752366, 5.445427266222308}, 
     {1.4660765716752366, 5.340707511102648}}]}, {CMYKColor[0.45, 0.5, 0.875, \
0.1], 
   Polygon[{{1.361356816555577, 5.445427266222308}, {1.361356816555577, \
5.550147021341967}, {1.4660765716752366, 5.550147021341967}, 
     {1.4660765716752366, 5.445427266222308}}]}, {CMYKColor[0.45, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{1.361356816555577, 5.550147021341967}, {1.361356816555577, \
5.654866776461628}, {1.4660765716752366, 5.654866776461628}, 
     {1.4660765716752366, 5.550147021341967}}]}, {CMYKColor[0.45, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{1.361356816555577, 5.654866776461628}, {1.361356816555577, \
5.759586531581287}, {1.4660765716752366, 5.759586531581287}, 
     {1.4660765716752366, 5.654866776461628}}]}, {CMYKColor[0.45, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{1.361356816555577, 5.759586531581287}, {1.361356816555577, \
5.864306286700947}, {1.4660765716752366, 5.864306286700947}, 
     {1.4660765716752366, 5.759586531581287}}]}, {CMYKColor[0.45, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{1.361356816555577, 5.864306286700947}, {1.361356816555577, \
5.969026041820607}, {1.4660765716752366, 5.969026041820607}, 
     {1.4660765716752366, 5.864306286700947}}]}, {CMYKColor[0.45, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{1.361356816555577, 5.969026041820607}, {1.361356816555577, \
6.073745796940266}, {1.4660765716752366, 6.073745796940266}, 
     {1.4660765716752366, 5.969026041820607}}]}, {CMYKColor[0.45, 0.5, 0.975, \
0.1], 
   Polygon[{{1.361356816555577, 6.073745796940266}, {1.361356816555577, \
6.178465552059926}, {1.4660765716752366, 6.178465552059926}, 
     {1.4660765716752366, 6.073745796940266}}]}, {CMYKColor[0.45, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{1.361356816555577, 6.178465552059926}, {1.361356816555577, \
6.283185307179586}, {1.4660765716752366, 6.283185307179586}, 
     {1.4660765716752366, 6.178465552059926}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 0.}, {1.4660765716752366, \
0.10471975511965977}, {1.5707963267948966, 0.10471975511965977}, 
     {1.5707963267948966, 0.}}]}, {CMYKColor[0.48333333333333334, 0.5, 0.025, \
0.1], 
   Polygon[{{1.4660765716752366, 0.10471975511965977}, {1.4660765716752366, \
0.20943951023931953}, {1.5707963267948966, 0.20943951023931953}, 
     {1.5707963267948966, 0.10471975511965977}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{1.4660765716752366, 0.20943951023931953}, {1.4660765716752366, \
0.3141592653589793}, {1.5707963267948966, 0.3141592653589793}, 
     {1.5707963267948966, 0.20943951023931953}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{1.4660765716752366, 0.3141592653589793}, {1.4660765716752366, \
0.41887902047863906}, {1.5707963267948966, 0.41887902047863906}, 
     {1.5707963267948966, 0.3141592653589793}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.075, 0.1], 
   Polygon[{{1.4660765716752366, 0.41887902047863906}, {1.4660765716752366, \
0.5235987755982988}, {1.5707963267948966, 0.5235987755982988}, 
     {1.5707963267948966, 0.41887902047863906}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{1.4660765716752366, 0.5235987755982988}, {1.4660765716752366, \
0.6283185307179586}, {1.5707963267948966, 0.6283185307179586}, 
     {1.5707963267948966, 0.5235987755982988}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{1.4660765716752366, 0.6283185307179586}, {1.4660765716752366, \
0.7330382858376183}, {1.5707963267948966, 0.7330382858376183}, 
     {1.5707963267948966, 0.6283185307179586}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.125, 0.1], 
   Polygon[{{1.4660765716752366, 0.7330382858376183}, {1.4660765716752366, \
0.8377580409572781}, {1.5707963267948966, 0.8377580409572781}, 
     {1.5707963267948966, 0.7330382858376183}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{1.4660765716752366, 0.8377580409572781}, {1.4660765716752366, \
0.9424777960769379}, {1.5707963267948966, 0.9424777960769379}, 
     {1.5707963267948966, 0.8377580409572781}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 0.9424777960769379}, {1.4660765716752366, \
1.0471975511965976}, {1.5707963267948966, 1.0471975511965976}, 
     {1.5707963267948966, 0.9424777960769379}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.175, 0.1], 
   Polygon[{{1.4660765716752366, 1.0471975511965976}, {1.4660765716752366, \
1.1519173063162573}, {1.5707963267948966, 1.1519173063162573}, 
     {1.5707963267948966, 1.0471975511965976}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{1.4660765716752366, 1.1519173063162573}, {1.4660765716752366, \
1.2566370614359172}, {1.5707963267948966, 1.2566370614359172}, 
     {1.5707963267948966, 1.1519173063162573}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.4660765716752366, 1.2566370614359172}, {1.4660765716752366, \
1.361356816555577}, {1.5707963267948966, 1.361356816555577}, 
     {1.5707963267948966, 1.2566370614359172}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.225, 0.1], 
   Polygon[{{1.4660765716752366, 1.361356816555577}, {1.4660765716752366, \
1.4660765716752366}, {1.5707963267948966, 1.4660765716752366}, 
     {1.5707963267948966, 1.361356816555577}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.4660765716752366, 1.4660765716752366}, {1.4660765716752366, \
1.5707963267948966}, {1.5707963267948966, 1.5707963267948966}, 
     {1.5707963267948966, 1.4660765716752366}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 1.5707963267948966}, {1.4660765716752366, \
1.6755160819145563}, {1.5707963267948966, 1.6755160819145563}, 
     {1.5707963267948966, 1.5707963267948966}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.275, 0.1], 
   Polygon[{{1.4660765716752366, 1.6755160819145563}, {1.4660765716752366, \
1.780235837034216}, {1.5707963267948966, 1.780235837034216}, 
     {1.5707963267948966, 1.6755160819145563}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.4660765716752366, 1.780235837034216}, {1.4660765716752366, \
1.8849555921538759}, {1.5707963267948966, 1.8849555921538759}, 
     {1.5707963267948966, 1.780235837034216}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.4660765716752366, 1.8849555921538759}, {1.4660765716752366, \
1.9896753472735356}, {1.5707963267948966, 1.9896753472735356}, 
     {1.5707963267948966, 1.8849555921538759}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.325, 0.1], 
   Polygon[{{1.4660765716752366, 1.9896753472735356}, {1.4660765716752366, \
2.0943951023931953}, {1.5707963267948966, 2.0943951023931953}, 
     {1.5707963267948966, 1.9896753472735356}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{1.4660765716752366, 2.0943951023931953}, {1.4660765716752366, \
2.199114857512855}, {1.5707963267948966, 2.199114857512855}, 
     {1.5707963267948966, 2.0943951023931953}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{1.4660765716752366, 2.199114857512855}, {1.4660765716752366, \
2.3038346126325147}, {1.5707963267948966, 2.3038346126325147}, 
     {1.5707963267948966, 2.199114857512855}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.375, 0.1], 
   Polygon[{{1.4660765716752366, 2.3038346126325147}, {1.4660765716752366, \
2.4085543677521746}, {1.5707963267948966, 2.4085543677521746}, 
     {1.5707963267948966, 2.3038346126325147}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{1.4660765716752366, 2.4085543677521746}, {1.4660765716752366, \
2.5132741228718345}, {1.5707963267948966, 2.5132741228718345}, 
     {1.5707963267948966, 2.4085543677521746}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 2.5132741228718345}, {1.4660765716752366, \
2.617993877991494}, {1.5707963267948966, 2.617993877991494}, 
     {1.5707963267948966, 2.5132741228718345}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.425, 0.1], 
   Polygon[{{1.4660765716752366, 2.617993877991494}, {1.4660765716752366, \
2.722713633111154}, {1.5707963267948966, 2.722713633111154}, 
     {1.5707963267948966, 2.617993877991494}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{1.4660765716752366, 2.722713633111154}, {1.4660765716752366, \
2.827433388230814}, {1.5707963267948966, 2.827433388230814}, 
     {1.5707963267948966, 2.722713633111154}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 2.827433388230814}, {1.4660765716752366, \
2.9321531433504733}, {1.5707963267948966, 2.9321531433504733}, 
     {1.5707963267948966, 2.827433388230814}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.475, 0.1], 
   Polygon[{{1.4660765716752366, 2.9321531433504733}, {1.4660765716752366, \
3.036872898470133}, {1.5707963267948966, 3.036872898470133}, 
     {1.5707963267948966, 2.9321531433504733}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{1.4660765716752366, 3.036872898470133}, {1.4660765716752366, \
3.141592653589793}, {1.5707963267948966, 3.141592653589793}, 
     {1.5707963267948966, 3.036872898470133}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 3.141592653589793}, {1.4660765716752366, \
3.2463124087094526}, {1.5707963267948966, 3.2463124087094526}, 
     {1.5707963267948966, 3.141592653589793}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.525, 0.1], 
   Polygon[{{1.4660765716752366, 3.2463124087094526}, {1.4660765716752366, \
3.3510321638291125}, {1.5707963267948966, 3.3510321638291125}, 
     {1.5707963267948966, 3.2463124087094526}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{1.4660765716752366, 3.3510321638291125}, {1.4660765716752366, \
3.4557519189487724}, {1.5707963267948966, 3.4557519189487724}, 
     {1.5707963267948966, 3.3510321638291125}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 3.4557519189487724}, {1.4660765716752366, \
3.560471674068432}, {1.5707963267948966, 3.560471674068432}, 
     {1.5707963267948966, 3.4557519189487724}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.575, 0.1], 
   Polygon[{{1.4660765716752366, 3.560471674068432}, {1.4660765716752366, \
3.665191429188092}, {1.5707963267948966, 3.665191429188092}, 
     {1.5707963267948966, 3.560471674068432}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{1.4660765716752366, 3.665191429188092}, {1.4660765716752366, \
3.7699111843077517}, {1.5707963267948966, 3.7699111843077517}, 
     {1.5707963267948966, 3.665191429188092}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 3.7699111843077517}, {1.4660765716752366, \
3.874630939427411}, {1.5707963267948966, 3.874630939427411}, 
     {1.5707963267948966, 3.7699111843077517}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.625, 0.1], 
   Polygon[{{1.4660765716752366, 3.874630939427411}, {1.4660765716752366, \
3.979350694547071}, {1.5707963267948966, 3.979350694547071}, 
     {1.5707963267948966, 3.874630939427411}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{1.4660765716752366, 3.979350694547071}, {1.4660765716752366, \
4.084070449666731}, {1.5707963267948966, 4.084070449666731}, 
     {1.5707963267948966, 3.979350694547071}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 4.084070449666731}, {1.4660765716752366, \
4.1887902047863905}, {1.5707963267948966, 4.1887902047863905}, 
     {1.5707963267948966, 4.084070449666731}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.675, 0.1], 
   Polygon[{{1.4660765716752366, 4.1887902047863905}, {1.4660765716752366, \
4.29350995990605}, {1.5707963267948966, 4.29350995990605}, 
     {1.5707963267948966, 4.1887902047863905}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{1.4660765716752366, 4.29350995990605}, {1.4660765716752366, \
4.39822971502571}, {1.5707963267948966, 4.39822971502571}, 
     {1.5707963267948966, 4.29350995990605}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.4660765716752366, 4.39822971502571}, {1.4660765716752366, \
4.50294947014537}, {1.5707963267948966, 4.50294947014537}, 
     {1.5707963267948966, 4.39822971502571}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.725, 0.1], 
   Polygon[{{1.4660765716752366, 4.50294947014537}, {1.4660765716752366, \
4.607669225265029}, {1.5707963267948966, 4.607669225265029}, 
     {1.5707963267948966, 4.50294947014537}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.4660765716752366, 4.607669225265029}, {1.4660765716752366, \
4.71238898038469}, {1.5707963267948966, 4.71238898038469}, 
     {1.5707963267948966, 4.607669225265029}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 4.71238898038469}, {1.4660765716752366, \
4.817108735504349}, {1.5707963267948966, 4.817108735504349}, 
     {1.5707963267948966, 4.71238898038469}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.775, 0.1], 
   Polygon[{{1.4660765716752366, 4.817108735504349}, {1.4660765716752366, \
4.921828490624009}, {1.5707963267948966, 4.921828490624009}, 
     {1.5707963267948966, 4.817108735504349}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.4660765716752366, 4.921828490624009}, {1.4660765716752366, \
5.026548245743669}, {1.5707963267948966, 5.026548245743669}, 
     {1.5707963267948966, 4.921828490624009}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 5.026548245743669}, {1.4660765716752366, \
5.1312680008633285}, {1.5707963267948966, 5.1312680008633285}, 
     {1.5707963267948966, 5.026548245743669}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.825, 0.1], 
   Polygon[{{1.4660765716752366, 5.1312680008633285}, {1.4660765716752366, \
5.235987755982988}, {1.5707963267948966, 5.235987755982988}, 
     {1.5707963267948966, 5.1312680008633285}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{1.4660765716752366, 5.235987755982988}, {1.4660765716752366, \
5.340707511102648}, {1.5707963267948966, 5.340707511102648}, 
     {1.5707963267948966, 5.235987755982988}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 5.340707511102648}, {1.4660765716752366, \
5.445427266222308}, {1.5707963267948966, 5.445427266222308}, 
     {1.5707963267948966, 5.340707511102648}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.875, 0.1], 
   Polygon[{{1.4660765716752366, 5.445427266222308}, {1.4660765716752366, \
5.550147021341967}, {1.5707963267948966, 5.550147021341967}, 
     {1.5707963267948966, 5.445427266222308}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{1.4660765716752366, 5.550147021341967}, {1.4660765716752366, \
5.654866776461628}, {1.5707963267948966, 5.654866776461628}, 
     {1.5707963267948966, 5.550147021341967}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{1.4660765716752366, 5.654866776461628}, {1.4660765716752366, \
5.759586531581287}, {1.5707963267948966, 5.759586531581287}, 
     {1.5707963267948966, 5.654866776461628}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{1.4660765716752366, 5.759586531581287}, {1.4660765716752366, \
5.864306286700947}, {1.5707963267948966, 5.864306286700947}, 
     {1.5707963267948966, 5.759586531581287}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{1.4660765716752366, 5.864306286700947}, {1.4660765716752366, \
5.969026041820607}, {1.5707963267948966, 5.969026041820607}, 
     {1.5707963267948966, 5.864306286700947}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{1.4660765716752366, 5.969026041820607}, {1.4660765716752366, \
6.073745796940266}, {1.5707963267948966, 6.073745796940266}, 
     {1.5707963267948966, 5.969026041820607}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.975, 0.1], 
   Polygon[{{1.4660765716752366, 6.073745796940266}, {1.4660765716752366, \
6.178465552059926}, {1.5707963267948966, 6.178465552059926}, 
     {1.5707963267948966, 6.073745796940266}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{1.4660765716752366, 6.178465552059926}, {1.4660765716752366, \
6.283185307179586}, {1.5707963267948966, 6.283185307179586}, 
     {1.5707963267948966, 6.178465552059926}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 0.}, {1.5707963267948966, \
0.10471975511965977}, {1.6755160819145563, 0.10471975511965977}, 
     {1.6755160819145563, 0.}}]}, {CMYKColor[0.5166666666666666, 0.5, 0.025, \
0.1], 
   Polygon[{{1.5707963267948966, 0.10471975511965977}, {1.5707963267948966, \
0.20943951023931953}, {1.6755160819145563, 0.20943951023931953}, 
     {1.6755160819145563, 0.10471975511965977}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{1.5707963267948966, 0.20943951023931953}, {1.5707963267948966, \
0.3141592653589793}, {1.6755160819145563, 0.3141592653589793}, 
     {1.6755160819145563, 0.20943951023931953}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{1.5707963267948966, 0.3141592653589793}, {1.5707963267948966, \
0.41887902047863906}, {1.6755160819145563, 0.41887902047863906}, 
     {1.6755160819145563, 0.3141592653589793}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.075, 0.1], 
   Polygon[{{1.5707963267948966, 0.41887902047863906}, {1.5707963267948966, \
0.5235987755982988}, {1.6755160819145563, 0.5235987755982988}, 
     {1.6755160819145563, 0.41887902047863906}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{1.5707963267948966, 0.5235987755982988}, {1.5707963267948966, \
0.6283185307179586}, {1.6755160819145563, 0.6283185307179586}, 
     {1.6755160819145563, 0.5235987755982988}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{1.5707963267948966, 0.6283185307179586}, {1.5707963267948966, \
0.7330382858376183}, {1.6755160819145563, 0.7330382858376183}, 
     {1.6755160819145563, 0.6283185307179586}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.125, 0.1], 
   Polygon[{{1.5707963267948966, 0.7330382858376183}, {1.5707963267948966, \
0.8377580409572781}, {1.6755160819145563, 0.8377580409572781}, 
     {1.6755160819145563, 0.7330382858376183}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{1.5707963267948966, 0.8377580409572781}, {1.5707963267948966, \
0.9424777960769379}, {1.6755160819145563, 0.9424777960769379}, 
     {1.6755160819145563, 0.8377580409572781}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 0.9424777960769379}, {1.5707963267948966, \
1.0471975511965976}, {1.6755160819145563, 1.0471975511965976}, 
     {1.6755160819145563, 0.9424777960769379}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.175, 0.1], 
   Polygon[{{1.5707963267948966, 1.0471975511965976}, {1.5707963267948966, \
1.1519173063162573}, {1.6755160819145563, 1.1519173063162573}, 
     {1.6755160819145563, 1.0471975511965976}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{1.5707963267948966, 1.1519173063162573}, {1.5707963267948966, \
1.2566370614359172}, {1.6755160819145563, 1.2566370614359172}, 
     {1.6755160819145563, 1.1519173063162573}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.5707963267948966, 1.2566370614359172}, {1.5707963267948966, \
1.361356816555577}, {1.6755160819145563, 1.361356816555577}, 
     {1.6755160819145563, 1.2566370614359172}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.225, 0.1], 
   Polygon[{{1.5707963267948966, 1.361356816555577}, {1.5707963267948966, \
1.4660765716752366}, {1.6755160819145563, 1.4660765716752366}, 
     {1.6755160819145563, 1.361356816555577}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.5707963267948966, 1.4660765716752366}, {1.5707963267948966, \
1.5707963267948966}, {1.6755160819145563, 1.5707963267948966}, 
     {1.6755160819145563, 1.4660765716752366}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 1.5707963267948966}, {1.5707963267948966, \
1.6755160819145563}, {1.6755160819145563, 1.6755160819145563}, 
     {1.6755160819145563, 1.5707963267948966}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.275, 0.1], 
   Polygon[{{1.5707963267948966, 1.6755160819145563}, {1.5707963267948966, \
1.780235837034216}, {1.6755160819145563, 1.780235837034216}, 
     {1.6755160819145563, 1.6755160819145563}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.5707963267948966, 1.780235837034216}, {1.5707963267948966, \
1.8849555921538759}, {1.6755160819145563, 1.8849555921538759}, 
     {1.6755160819145563, 1.780235837034216}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.5707963267948966, 1.8849555921538759}, {1.5707963267948966, \
1.9896753472735356}, {1.6755160819145563, 1.9896753472735356}, 
     {1.6755160819145563, 1.8849555921538759}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.325, 0.1], 
   Polygon[{{1.5707963267948966, 1.9896753472735356}, {1.5707963267948966, \
2.0943951023931953}, {1.6755160819145563, 2.0943951023931953}, 
     {1.6755160819145563, 1.9896753472735356}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{1.5707963267948966, 2.0943951023931953}, {1.5707963267948966, \
2.199114857512855}, {1.6755160819145563, 2.199114857512855}, 
     {1.6755160819145563, 2.0943951023931953}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{1.5707963267948966, 2.199114857512855}, {1.5707963267948966, \
2.3038346126325147}, {1.6755160819145563, 2.3038346126325147}, 
     {1.6755160819145563, 2.199114857512855}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.375, 0.1], 
   Polygon[{{1.5707963267948966, 2.3038346126325147}, {1.5707963267948966, \
2.4085543677521746}, {1.6755160819145563, 2.4085543677521746}, 
     {1.6755160819145563, 2.3038346126325147}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{1.5707963267948966, 2.4085543677521746}, {1.5707963267948966, \
2.5132741228718345}, {1.6755160819145563, 2.5132741228718345}, 
     {1.6755160819145563, 2.4085543677521746}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 2.5132741228718345}, {1.5707963267948966, \
2.617993877991494}, {1.6755160819145563, 2.617993877991494}, 
     {1.6755160819145563, 2.5132741228718345}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.425, 0.1], 
   Polygon[{{1.5707963267948966, 2.617993877991494}, {1.5707963267948966, \
2.722713633111154}, {1.6755160819145563, 2.722713633111154}, 
     {1.6755160819145563, 2.617993877991494}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{1.5707963267948966, 2.722713633111154}, {1.5707963267948966, \
2.827433388230814}, {1.6755160819145563, 2.827433388230814}, 
     {1.6755160819145563, 2.722713633111154}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 2.827433388230814}, {1.5707963267948966, \
2.9321531433504733}, {1.6755160819145563, 2.9321531433504733}, 
     {1.6755160819145563, 2.827433388230814}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.475, 0.1], 
   Polygon[{{1.5707963267948966, 2.9321531433504733}, {1.5707963267948966, \
3.036872898470133}, {1.6755160819145563, 3.036872898470133}, 
     {1.6755160819145563, 2.9321531433504733}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{1.5707963267948966, 3.036872898470133}, {1.5707963267948966, \
3.141592653589793}, {1.6755160819145563, 3.141592653589793}, 
     {1.6755160819145563, 3.036872898470133}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 3.141592653589793}, {1.5707963267948966, \
3.2463124087094526}, {1.6755160819145563, 3.2463124087094526}, 
     {1.6755160819145563, 3.141592653589793}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.525, 0.1], 
   Polygon[{{1.5707963267948966, 3.2463124087094526}, {1.5707963267948966, \
3.3510321638291125}, {1.6755160819145563, 3.3510321638291125}, 
     {1.6755160819145563, 3.2463124087094526}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{1.5707963267948966, 3.3510321638291125}, {1.5707963267948966, \
3.4557519189487724}, {1.6755160819145563, 3.4557519189487724}, 
     {1.6755160819145563, 3.3510321638291125}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 3.4557519189487724}, {1.5707963267948966, \
3.560471674068432}, {1.6755160819145563, 3.560471674068432}, 
     {1.6755160819145563, 3.4557519189487724}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.575, 0.1], 
   Polygon[{{1.5707963267948966, 3.560471674068432}, {1.5707963267948966, \
3.665191429188092}, {1.6755160819145563, 3.665191429188092}, 
     {1.6755160819145563, 3.560471674068432}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{1.5707963267948966, 3.665191429188092}, {1.5707963267948966, \
3.7699111843077517}, {1.6755160819145563, 3.7699111843077517}, 
     {1.6755160819145563, 3.665191429188092}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 3.7699111843077517}, {1.5707963267948966, \
3.874630939427411}, {1.6755160819145563, 3.874630939427411}, 
     {1.6755160819145563, 3.7699111843077517}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.625, 0.1], 
   Polygon[{{1.5707963267948966, 3.874630939427411}, {1.5707963267948966, \
3.979350694547071}, {1.6755160819145563, 3.979350694547071}, 
     {1.6755160819145563, 3.874630939427411}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{1.5707963267948966, 3.979350694547071}, {1.5707963267948966, \
4.084070449666731}, {1.6755160819145563, 4.084070449666731}, 
     {1.6755160819145563, 3.979350694547071}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 4.084070449666731}, {1.5707963267948966, \
4.1887902047863905}, {1.6755160819145563, 4.1887902047863905}, 
     {1.6755160819145563, 4.084070449666731}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.675, 0.1], 
   Polygon[{{1.5707963267948966, 4.1887902047863905}, {1.5707963267948966, \
4.29350995990605}, {1.6755160819145563, 4.29350995990605}, 
     {1.6755160819145563, 4.1887902047863905}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{1.5707963267948966, 4.29350995990605}, {1.5707963267948966, \
4.39822971502571}, {1.6755160819145563, 4.39822971502571}, 
     {1.6755160819145563, 4.29350995990605}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.5707963267948966, 4.39822971502571}, {1.5707963267948966, \
4.50294947014537}, {1.6755160819145563, 4.50294947014537}, 
     {1.6755160819145563, 4.39822971502571}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.725, 0.1], 
   Polygon[{{1.5707963267948966, 4.50294947014537}, {1.5707963267948966, \
4.607669225265029}, {1.6755160819145563, 4.607669225265029}, 
     {1.6755160819145563, 4.50294947014537}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.5707963267948966, 4.607669225265029}, {1.5707963267948966, \
4.71238898038469}, {1.6755160819145563, 4.71238898038469}, 
     {1.6755160819145563, 4.607669225265029}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 4.71238898038469}, {1.5707963267948966, \
4.817108735504349}, {1.6755160819145563, 4.817108735504349}, 
     {1.6755160819145563, 4.71238898038469}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.775, 0.1], 
   Polygon[{{1.5707963267948966, 4.817108735504349}, {1.5707963267948966, \
4.921828490624009}, {1.6755160819145563, 4.921828490624009}, 
     {1.6755160819145563, 4.817108735504349}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.5707963267948966, 4.921828490624009}, {1.5707963267948966, \
5.026548245743669}, {1.6755160819145563, 5.026548245743669}, 
     {1.6755160819145563, 4.921828490624009}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 5.026548245743669}, {1.5707963267948966, \
5.1312680008633285}, {1.6755160819145563, 5.1312680008633285}, 
     {1.6755160819145563, 5.026548245743669}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.825, 0.1], 
   Polygon[{{1.5707963267948966, 5.1312680008633285}, {1.5707963267948966, \
5.235987755982988}, {1.6755160819145563, 5.235987755982988}, 
     {1.6755160819145563, 5.1312680008633285}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{1.5707963267948966, 5.235987755982988}, {1.5707963267948966, \
5.340707511102648}, {1.6755160819145563, 5.340707511102648}, 
     {1.6755160819145563, 5.235987755982988}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 5.340707511102648}, {1.5707963267948966, \
5.445427266222308}, {1.6755160819145563, 5.445427266222308}, 
     {1.6755160819145563, 5.340707511102648}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.875, 0.1], 
   Polygon[{{1.5707963267948966, 5.445427266222308}, {1.5707963267948966, \
5.550147021341967}, {1.6755160819145563, 5.550147021341967}, 
     {1.6755160819145563, 5.445427266222308}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{1.5707963267948966, 5.550147021341967}, {1.5707963267948966, \
5.654866776461628}, {1.6755160819145563, 5.654866776461628}, 
     {1.6755160819145563, 5.550147021341967}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{1.5707963267948966, 5.654866776461628}, {1.5707963267948966, \
5.759586531581287}, {1.6755160819145563, 5.759586531581287}, 
     {1.6755160819145563, 5.654866776461628}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{1.5707963267948966, 5.759586531581287}, {1.5707963267948966, \
5.864306286700947}, {1.6755160819145563, 5.864306286700947}, 
     {1.6755160819145563, 5.759586531581287}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{1.5707963267948966, 5.864306286700947}, {1.5707963267948966, \
5.969026041820607}, {1.6755160819145563, 5.969026041820607}, 
     {1.6755160819145563, 5.864306286700947}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{1.5707963267948966, 5.969026041820607}, {1.5707963267948966, \
6.073745796940266}, {1.6755160819145563, 6.073745796940266}, 
     {1.6755160819145563, 5.969026041820607}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.975, 0.1], 
   Polygon[{{1.5707963267948966, 6.073745796940266}, {1.5707963267948966, \
6.178465552059926}, {1.6755160819145563, 6.178465552059926}, 
     {1.6755160819145563, 6.073745796940266}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{1.5707963267948966, 6.178465552059926}, {1.5707963267948966, \
6.283185307179586}, {1.6755160819145563, 6.283185307179586}, 
     {1.6755160819145563, 6.178465552059926}}]}, {CMYKColor[0.55, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 0.}, {1.6755160819145563, \
0.10471975511965977}, {1.780235837034216, 0.10471975511965977}, 
     {1.780235837034216, 0.}}]}, {CMYKColor[0.55, 0.5, 0.025, 0.1], 
   Polygon[{{1.6755160819145563, 0.10471975511965977}, {1.6755160819145563, \
0.20943951023931953}, {1.780235837034216, 0.20943951023931953}, 
     {1.780235837034216, 0.10471975511965977}}]}, {CMYKColor[0.55, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{1.6755160819145563, 0.20943951023931953}, {1.6755160819145563, \
0.3141592653589793}, {1.780235837034216, 0.3141592653589793}, 
     {1.780235837034216, 0.20943951023931953}}]}, {CMYKColor[0.55, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{1.6755160819145563, 0.3141592653589793}, {1.6755160819145563, \
0.41887902047863906}, {1.780235837034216, 0.41887902047863906}, 
     {1.780235837034216, 0.3141592653589793}}]}, {CMYKColor[0.55, 0.5, 0.075, \
0.1], 
   Polygon[{{1.6755160819145563, 0.41887902047863906}, {1.6755160819145563, \
0.5235987755982988}, {1.780235837034216, 0.5235987755982988}, 
     {1.780235837034216, 0.41887902047863906}}]}, {CMYKColor[0.55, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{1.6755160819145563, 0.5235987755982988}, {1.6755160819145563, \
0.6283185307179586}, {1.780235837034216, 0.6283185307179586}, 
     {1.780235837034216, 0.5235987755982988}}]}, {CMYKColor[0.55, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{1.6755160819145563, 0.6283185307179586}, {1.6755160819145563, \
0.7330382858376183}, {1.780235837034216, 0.7330382858376183}, 
     {1.780235837034216, 0.6283185307179586}}]}, {CMYKColor[0.55, 0.5, 0.125, \
0.1], 
   Polygon[{{1.6755160819145563, 0.7330382858376183}, {1.6755160819145563, \
0.8377580409572781}, {1.780235837034216, 0.8377580409572781}, 
     {1.780235837034216, 0.7330382858376183}}]}, {CMYKColor[0.55, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{1.6755160819145563, 0.8377580409572781}, {1.6755160819145563, \
0.9424777960769379}, {1.780235837034216, 0.9424777960769379}, 
     {1.780235837034216, 0.8377580409572781}}]}, {CMYKColor[0.55, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 0.9424777960769379}, {1.6755160819145563, \
1.0471975511965976}, {1.780235837034216, 1.0471975511965976}, 
     {1.780235837034216, 0.9424777960769379}}]}, {CMYKColor[0.55, 0.5, 0.175, \
0.1], 
   Polygon[{{1.6755160819145563, 1.0471975511965976}, {1.6755160819145563, \
1.1519173063162573}, {1.780235837034216, 1.1519173063162573}, 
     {1.780235837034216, 1.0471975511965976}}]}, {CMYKColor[0.55, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{1.6755160819145563, 1.1519173063162573}, {1.6755160819145563, \
1.2566370614359172}, {1.780235837034216, 1.2566370614359172}, 
     {1.780235837034216, 1.1519173063162573}}]}, {CMYKColor[0.55, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{1.6755160819145563, 1.2566370614359172}, {1.6755160819145563, \
1.361356816555577}, {1.780235837034216, 1.361356816555577}, 
     {1.780235837034216, 1.2566370614359172}}]}, {CMYKColor[0.55, 0.5, 0.225, \
0.1], 
   Polygon[{{1.6755160819145563, 1.361356816555577}, {1.6755160819145563, \
1.4660765716752366}, {1.780235837034216, 1.4660765716752366}, 
     {1.780235837034216, 1.361356816555577}}]}, {CMYKColor[0.55, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{1.6755160819145563, 1.4660765716752366}, {1.6755160819145563, \
1.5707963267948966}, {1.780235837034216, 1.5707963267948966}, 
     {1.780235837034216, 1.4660765716752366}}]}, {CMYKColor[0.55, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 1.5707963267948966}, {1.6755160819145563, \
1.6755160819145563}, {1.780235837034216, 1.6755160819145563}, 
     {1.780235837034216, 1.5707963267948966}}]}, {CMYKColor[0.55, 0.5, 0.275, \
0.1], 
   Polygon[{{1.6755160819145563, 1.6755160819145563}, {1.6755160819145563, \
1.780235837034216}, {1.780235837034216, 1.780235837034216}, 
     {1.780235837034216, 1.6755160819145563}}]}, {CMYKColor[0.55, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{1.6755160819145563, 1.780235837034216}, {1.6755160819145563, \
1.8849555921538759}, {1.780235837034216, 1.8849555921538759}, 
     {1.780235837034216, 1.780235837034216}}]}, {CMYKColor[0.55, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{1.6755160819145563, 1.8849555921538759}, {1.6755160819145563, \
1.9896753472735356}, {1.780235837034216, 1.9896753472735356}, 
     {1.780235837034216, 1.8849555921538759}}]}, {CMYKColor[0.55, 0.5, 0.325, \
0.1], 
   Polygon[{{1.6755160819145563, 1.9896753472735356}, {1.6755160819145563, \
2.0943951023931953}, {1.780235837034216, 2.0943951023931953}, 
     {1.780235837034216, 1.9896753472735356}}]}, {CMYKColor[0.55, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{1.6755160819145563, 2.0943951023931953}, {1.6755160819145563, \
2.199114857512855}, {1.780235837034216, 2.199114857512855}, 
     {1.780235837034216, 2.0943951023931953}}]}, {CMYKColor[0.55, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{1.6755160819145563, 2.199114857512855}, {1.6755160819145563, \
2.3038346126325147}, {1.780235837034216, 2.3038346126325147}, 
     {1.780235837034216, 2.199114857512855}}]}, {CMYKColor[0.55, 0.5, 0.375, \
0.1], 
   Polygon[{{1.6755160819145563, 2.3038346126325147}, {1.6755160819145563, \
2.4085543677521746}, {1.780235837034216, 2.4085543677521746}, 
     {1.780235837034216, 2.3038346126325147}}]}, {CMYKColor[0.55, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{1.6755160819145563, 2.4085543677521746}, {1.6755160819145563, \
2.5132741228718345}, {1.780235837034216, 2.5132741228718345}, 
     {1.780235837034216, 2.4085543677521746}}]}, {CMYKColor[0.55, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 2.5132741228718345}, {1.6755160819145563, \
2.617993877991494}, {1.780235837034216, 2.617993877991494}, 
     {1.780235837034216, 2.5132741228718345}}]}, {CMYKColor[0.55, 0.5, 0.425, \
0.1], 
   Polygon[{{1.6755160819145563, 2.617993877991494}, {1.6755160819145563, \
2.722713633111154}, {1.780235837034216, 2.722713633111154}, 
     {1.780235837034216, 2.617993877991494}}]}, {CMYKColor[0.55, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{1.6755160819145563, 2.722713633111154}, {1.6755160819145563, \
2.827433388230814}, {1.780235837034216, 2.827433388230814}, 
     {1.780235837034216, 2.722713633111154}}]}, {CMYKColor[0.55, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 2.827433388230814}, {1.6755160819145563, \
2.9321531433504733}, {1.780235837034216, 2.9321531433504733}, 
     {1.780235837034216, 2.827433388230814}}]}, {CMYKColor[0.55, 0.5, 0.475, \
0.1], 
   Polygon[{{1.6755160819145563, 2.9321531433504733}, {1.6755160819145563, \
3.036872898470133}, {1.780235837034216, 3.036872898470133}, 
     {1.780235837034216, 2.9321531433504733}}]}, {CMYKColor[0.55, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{1.6755160819145563, 3.036872898470133}, {1.6755160819145563, \
3.141592653589793}, {1.780235837034216, 3.141592653589793}, 
     {1.780235837034216, 3.036872898470133}}]}, {CMYKColor[0.55, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 3.141592653589793}, {1.6755160819145563, \
3.2463124087094526}, {1.780235837034216, 3.2463124087094526}, 
     {1.780235837034216, 3.141592653589793}}]}, {CMYKColor[0.55, 0.5, 0.525, \
0.1], 
   Polygon[{{1.6755160819145563, 3.2463124087094526}, {1.6755160819145563, \
3.3510321638291125}, {1.780235837034216, 3.3510321638291125}, 
     {1.780235837034216, 3.2463124087094526}}]}, {CMYKColor[0.55, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{1.6755160819145563, 3.3510321638291125}, {1.6755160819145563, \
3.4557519189487724}, {1.780235837034216, 3.4557519189487724}, 
     {1.780235837034216, 3.3510321638291125}}]}, {CMYKColor[0.55, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 3.4557519189487724}, {1.6755160819145563, \
3.560471674068432}, {1.780235837034216, 3.560471674068432}, 
     {1.780235837034216, 3.4557519189487724}}]}, {CMYKColor[0.55, 0.5, 0.575, \
0.1], 
   Polygon[{{1.6755160819145563, 3.560471674068432}, {1.6755160819145563, \
3.665191429188092}, {1.780235837034216, 3.665191429188092}, 
     {1.780235837034216, 3.560471674068432}}]}, {CMYKColor[0.55, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{1.6755160819145563, 3.665191429188092}, {1.6755160819145563, \
3.7699111843077517}, {1.780235837034216, 3.7699111843077517}, 
     {1.780235837034216, 3.665191429188092}}]}, {CMYKColor[0.55, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 3.7699111843077517}, {1.6755160819145563, \
3.874630939427411}, {1.780235837034216, 3.874630939427411}, 
     {1.780235837034216, 3.7699111843077517}}]}, {CMYKColor[0.55, 0.5, 0.625, \
0.1], 
   Polygon[{{1.6755160819145563, 3.874630939427411}, {1.6755160819145563, \
3.979350694547071}, {1.780235837034216, 3.979350694547071}, 
     {1.780235837034216, 3.874630939427411}}]}, {CMYKColor[0.55, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{1.6755160819145563, 3.979350694547071}, {1.6755160819145563, \
4.084070449666731}, {1.780235837034216, 4.084070449666731}, 
     {1.780235837034216, 3.979350694547071}}]}, {CMYKColor[0.55, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 4.084070449666731}, {1.6755160819145563, \
4.1887902047863905}, {1.780235837034216, 4.1887902047863905}, 
     {1.780235837034216, 4.084070449666731}}]}, {CMYKColor[0.55, 0.5, 0.675, \
0.1], 
   Polygon[{{1.6755160819145563, 4.1887902047863905}, {1.6755160819145563, \
4.29350995990605}, {1.780235837034216, 4.29350995990605}, 
     {1.780235837034216, 4.1887902047863905}}]}, {CMYKColor[0.55, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{1.6755160819145563, 4.29350995990605}, {1.6755160819145563, \
4.39822971502571}, {1.780235837034216, 4.39822971502571}, 
     {1.780235837034216, 4.29350995990605}}]}, {CMYKColor[0.55, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{1.6755160819145563, 4.39822971502571}, {1.6755160819145563, \
4.50294947014537}, {1.780235837034216, 4.50294947014537}, 
     {1.780235837034216, 4.39822971502571}}]}, {CMYKColor[0.55, 0.5, 0.725, \
0.1], 
   Polygon[{{1.6755160819145563, 4.50294947014537}, {1.6755160819145563, \
4.607669225265029}, {1.780235837034216, 4.607669225265029}, 
     {1.780235837034216, 4.50294947014537}}]}, {CMYKColor[0.55, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{1.6755160819145563, 4.607669225265029}, {1.6755160819145563, \
4.71238898038469}, {1.780235837034216, 4.71238898038469}, 
     {1.780235837034216, 4.607669225265029}}]}, {CMYKColor[0.55, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 4.71238898038469}, {1.6755160819145563, \
4.817108735504349}, {1.780235837034216, 4.817108735504349}, 
     {1.780235837034216, 4.71238898038469}}]}, {CMYKColor[0.55, 0.5, 0.775, \
0.1], 
   Polygon[{{1.6755160819145563, 4.817108735504349}, {1.6755160819145563, \
4.921828490624009}, {1.780235837034216, 4.921828490624009}, 
     {1.780235837034216, 4.817108735504349}}]}, {CMYKColor[0.55, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{1.6755160819145563, 4.921828490624009}, {1.6755160819145563, \
5.026548245743669}, {1.780235837034216, 5.026548245743669}, 
     {1.780235837034216, 4.921828490624009}}]}, {CMYKColor[0.55, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 5.026548245743669}, {1.6755160819145563, \
5.1312680008633285}, {1.780235837034216, 5.1312680008633285}, 
     {1.780235837034216, 5.026548245743669}}]}, {CMYKColor[0.55, 0.5, 0.825, \
0.1], 
   Polygon[{{1.6755160819145563, 5.1312680008633285}, {1.6755160819145563, \
5.235987755982988}, {1.780235837034216, 5.235987755982988}, 
     {1.780235837034216, 5.1312680008633285}}]}, {CMYKColor[0.55, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{1.6755160819145563, 5.235987755982988}, {1.6755160819145563, \
5.340707511102648}, {1.780235837034216, 5.340707511102648}, 
     {1.780235837034216, 5.235987755982988}}]}, {CMYKColor[0.55, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 5.340707511102648}, {1.6755160819145563, \
5.445427266222308}, {1.780235837034216, 5.445427266222308}, 
     {1.780235837034216, 5.340707511102648}}]}, {CMYKColor[0.55, 0.5, 0.875, \
0.1], 
   Polygon[{{1.6755160819145563, 5.445427266222308}, {1.6755160819145563, \
5.550147021341967}, {1.780235837034216, 5.550147021341967}, 
     {1.780235837034216, 5.445427266222308}}]}, {CMYKColor[0.55, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{1.6755160819145563, 5.550147021341967}, {1.6755160819145563, \
5.654866776461628}, {1.780235837034216, 5.654866776461628}, 
     {1.780235837034216, 5.550147021341967}}]}, {CMYKColor[0.55, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{1.6755160819145563, 5.654866776461628}, {1.6755160819145563, \
5.759586531581287}, {1.780235837034216, 5.759586531581287}, 
     {1.780235837034216, 5.654866776461628}}]}, {CMYKColor[0.55, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{1.6755160819145563, 5.759586531581287}, {1.6755160819145563, \
5.864306286700947}, {1.780235837034216, 5.864306286700947}, 
     {1.780235837034216, 5.759586531581287}}]}, {CMYKColor[0.55, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{1.6755160819145563, 5.864306286700947}, {1.6755160819145563, \
5.969026041820607}, {1.780235837034216, 5.969026041820607}, 
     {1.780235837034216, 5.864306286700947}}]}, {CMYKColor[0.55, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{1.6755160819145563, 5.969026041820607}, {1.6755160819145563, \
6.073745796940266}, {1.780235837034216, 6.073745796940266}, 
     {1.780235837034216, 5.969026041820607}}]}, {CMYKColor[0.55, 0.5, 0.975, \
0.1], 
   Polygon[{{1.6755160819145563, 6.073745796940266}, {1.6755160819145563, \
6.178465552059926}, {1.780235837034216, 6.178465552059926}, 
     {1.780235837034216, 6.073745796940266}}]}, {CMYKColor[0.55, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{1.6755160819145563, 6.178465552059926}, {1.6755160819145563, \
6.283185307179586}, {1.780235837034216, 6.283185307179586}, 
     {1.780235837034216, 6.178465552059926}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{1.780235837034216, 0.}, {1.780235837034216, \
0.10471975511965977}, {1.8849555921538759, 0.10471975511965977}, 
     {1.8849555921538759, 0.}}]}, {CMYKColor[0.5833333333333334, 0.5, 0.025, \
0.1], 
   Polygon[{{1.780235837034216, 0.10471975511965977}, {1.780235837034216, \
0.20943951023931953}, {1.8849555921538759, 0.20943951023931953}, 
     {1.8849555921538759, 0.10471975511965977}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{1.780235837034216, 0.20943951023931953}, {1.780235837034216, \
0.3141592653589793}, {1.8849555921538759, 0.3141592653589793}, 
     {1.8849555921538759, 0.20943951023931953}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{1.780235837034216, 0.3141592653589793}, {1.780235837034216, \
0.41887902047863906}, {1.8849555921538759, 0.41887902047863906}, 
     {1.8849555921538759, 0.3141592653589793}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.075, 0.1], 
   Polygon[{{1.780235837034216, 0.41887902047863906}, {1.780235837034216, \
0.5235987755982988}, {1.8849555921538759, 0.5235987755982988}, 
     {1.8849555921538759, 0.41887902047863906}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{1.780235837034216, 0.5235987755982988}, {1.780235837034216, \
0.6283185307179586}, {1.8849555921538759, 0.6283185307179586}, 
     {1.8849555921538759, 0.5235987755982988}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{1.780235837034216, 0.6283185307179586}, {1.780235837034216, \
0.7330382858376183}, {1.8849555921538759, 0.7330382858376183}, 
     {1.8849555921538759, 0.6283185307179586}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.125, 0.1], 
   Polygon[{{1.780235837034216, 0.7330382858376183}, {1.780235837034216, \
0.8377580409572781}, {1.8849555921538759, 0.8377580409572781}, 
     {1.8849555921538759, 0.7330382858376183}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{1.780235837034216, 0.8377580409572781}, {1.780235837034216, \
0.9424777960769379}, {1.8849555921538759, 0.9424777960769379}, 
     {1.8849555921538759, 0.8377580409572781}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{1.780235837034216, 0.9424777960769379}, {1.780235837034216, \
1.0471975511965976}, {1.8849555921538759, 1.0471975511965976}, 
     {1.8849555921538759, 0.9424777960769379}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.175, 0.1], 
   Polygon[{{1.780235837034216, 1.0471975511965976}, {1.780235837034216, \
1.1519173063162573}, {1.8849555921538759, 1.1519173063162573}, 
     {1.8849555921538759, 1.0471975511965976}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{1.780235837034216, 1.1519173063162573}, {1.780235837034216, \
1.2566370614359172}, {1.8849555921538759, 1.2566370614359172}, 
     {1.8849555921538759, 1.1519173063162573}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.780235837034216, 1.2566370614359172}, {1.780235837034216, \
1.361356816555577}, {1.8849555921538759, 1.361356816555577}, 
     {1.8849555921538759, 1.2566370614359172}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.225, 0.1], 
   Polygon[{{1.780235837034216, 1.361356816555577}, {1.780235837034216, \
1.4660765716752366}, {1.8849555921538759, 1.4660765716752366}, 
     {1.8849555921538759, 1.361356816555577}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.780235837034216, 1.4660765716752366}, {1.780235837034216, \
1.5707963267948966}, {1.8849555921538759, 1.5707963267948966}, 
     {1.8849555921538759, 1.4660765716752366}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.780235837034216, 1.5707963267948966}, {1.780235837034216, \
1.6755160819145563}, {1.8849555921538759, 1.6755160819145563}, 
     {1.8849555921538759, 1.5707963267948966}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.275, 0.1], 
   Polygon[{{1.780235837034216, 1.6755160819145563}, {1.780235837034216, \
1.780235837034216}, {1.8849555921538759, 1.780235837034216}, 
     {1.8849555921538759, 1.6755160819145563}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.780235837034216, 1.780235837034216}, {1.780235837034216, \
1.8849555921538759}, {1.8849555921538759, 1.8849555921538759}, 
     {1.8849555921538759, 1.780235837034216}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.780235837034216, 1.8849555921538759}, {1.780235837034216, \
1.9896753472735356}, {1.8849555921538759, 1.9896753472735356}, 
     {1.8849555921538759, 1.8849555921538759}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.325, 0.1], 
   Polygon[{{1.780235837034216, 1.9896753472735356}, {1.780235837034216, \
2.0943951023931953}, {1.8849555921538759, 2.0943951023931953}, 
     {1.8849555921538759, 1.9896753472735356}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{1.780235837034216, 2.0943951023931953}, {1.780235837034216, \
2.199114857512855}, {1.8849555921538759, 2.199114857512855}, 
     {1.8849555921538759, 2.0943951023931953}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{1.780235837034216, 2.199114857512855}, {1.780235837034216, \
2.3038346126325147}, {1.8849555921538759, 2.3038346126325147}, 
     {1.8849555921538759, 2.199114857512855}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.375, 0.1], 
   Polygon[{{1.780235837034216, 2.3038346126325147}, {1.780235837034216, \
2.4085543677521746}, {1.8849555921538759, 2.4085543677521746}, 
     {1.8849555921538759, 2.3038346126325147}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{1.780235837034216, 2.4085543677521746}, {1.780235837034216, \
2.5132741228718345}, {1.8849555921538759, 2.5132741228718345}, 
     {1.8849555921538759, 2.4085543677521746}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{1.780235837034216, 2.5132741228718345}, {1.780235837034216, \
2.617993877991494}, {1.8849555921538759, 2.617993877991494}, 
     {1.8849555921538759, 2.5132741228718345}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.425, 0.1], 
   Polygon[{{1.780235837034216, 2.617993877991494}, {1.780235837034216, \
2.722713633111154}, {1.8849555921538759, 2.722713633111154}, 
     {1.8849555921538759, 2.617993877991494}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{1.780235837034216, 2.722713633111154}, {1.780235837034216, \
2.827433388230814}, {1.8849555921538759, 2.827433388230814}, 
     {1.8849555921538759, 2.722713633111154}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{1.780235837034216, 2.827433388230814}, {1.780235837034216, \
2.9321531433504733}, {1.8849555921538759, 2.9321531433504733}, 
     {1.8849555921538759, 2.827433388230814}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.475, 0.1], 
   Polygon[{{1.780235837034216, 2.9321531433504733}, {1.780235837034216, \
3.036872898470133}, {1.8849555921538759, 3.036872898470133}, 
     {1.8849555921538759, 2.9321531433504733}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{1.780235837034216, 3.036872898470133}, {1.780235837034216, \
3.141592653589793}, {1.8849555921538759, 3.141592653589793}, 
     {1.8849555921538759, 3.036872898470133}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{1.780235837034216, 3.141592653589793}, {1.780235837034216, \
3.2463124087094526}, {1.8849555921538759, 3.2463124087094526}, 
     {1.8849555921538759, 3.141592653589793}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.525, 0.1], 
   Polygon[{{1.780235837034216, 3.2463124087094526}, {1.780235837034216, \
3.3510321638291125}, {1.8849555921538759, 3.3510321638291125}, 
     {1.8849555921538759, 3.2463124087094526}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{1.780235837034216, 3.3510321638291125}, {1.780235837034216, \
3.4557519189487724}, {1.8849555921538759, 3.4557519189487724}, 
     {1.8849555921538759, 3.3510321638291125}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{1.780235837034216, 3.4557519189487724}, {1.780235837034216, \
3.560471674068432}, {1.8849555921538759, 3.560471674068432}, 
     {1.8849555921538759, 3.4557519189487724}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.575, 0.1], 
   Polygon[{{1.780235837034216, 3.560471674068432}, {1.780235837034216, \
3.665191429188092}, {1.8849555921538759, 3.665191429188092}, 
     {1.8849555921538759, 3.560471674068432}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{1.780235837034216, 3.665191429188092}, {1.780235837034216, \
3.7699111843077517}, {1.8849555921538759, 3.7699111843077517}, 
     {1.8849555921538759, 3.665191429188092}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{1.780235837034216, 3.7699111843077517}, {1.780235837034216, \
3.874630939427411}, {1.8849555921538759, 3.874630939427411}, 
     {1.8849555921538759, 3.7699111843077517}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.625, 0.1], 
   Polygon[{{1.780235837034216, 3.874630939427411}, {1.780235837034216, \
3.979350694547071}, {1.8849555921538759, 3.979350694547071}, 
     {1.8849555921538759, 3.874630939427411}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{1.780235837034216, 3.979350694547071}, {1.780235837034216, \
4.084070449666731}, {1.8849555921538759, 4.084070449666731}, 
     {1.8849555921538759, 3.979350694547071}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{1.780235837034216, 4.084070449666731}, {1.780235837034216, \
4.1887902047863905}, {1.8849555921538759, 4.1887902047863905}, 
     {1.8849555921538759, 4.084070449666731}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.675, 0.1], 
   Polygon[{{1.780235837034216, 4.1887902047863905}, {1.780235837034216, \
4.29350995990605}, {1.8849555921538759, 4.29350995990605}, 
     {1.8849555921538759, 4.1887902047863905}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{1.780235837034216, 4.29350995990605}, {1.780235837034216, \
4.39822971502571}, {1.8849555921538759, 4.39822971502571}, 
     {1.8849555921538759, 4.29350995990605}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.780235837034216, 4.39822971502571}, {1.780235837034216, \
4.50294947014537}, {1.8849555921538759, 4.50294947014537}, 
     {1.8849555921538759, 4.39822971502571}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.725, 0.1], 
   Polygon[{{1.780235837034216, 4.50294947014537}, {1.780235837034216, \
4.607669225265029}, {1.8849555921538759, 4.607669225265029}, 
     {1.8849555921538759, 4.50294947014537}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.780235837034216, 4.607669225265029}, {1.780235837034216, \
4.71238898038469}, {1.8849555921538759, 4.71238898038469}, 
     {1.8849555921538759, 4.607669225265029}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.780235837034216, 4.71238898038469}, {1.780235837034216, \
4.817108735504349}, {1.8849555921538759, 4.817108735504349}, 
     {1.8849555921538759, 4.71238898038469}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.775, 0.1], 
   Polygon[{{1.780235837034216, 4.817108735504349}, {1.780235837034216, \
4.921828490624009}, {1.8849555921538759, 4.921828490624009}, 
     {1.8849555921538759, 4.817108735504349}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.780235837034216, 4.921828490624009}, {1.780235837034216, \
5.026548245743669}, {1.8849555921538759, 5.026548245743669}, 
     {1.8849555921538759, 4.921828490624009}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.780235837034216, 5.026548245743669}, {1.780235837034216, \
5.1312680008633285}, {1.8849555921538759, 5.1312680008633285}, 
     {1.8849555921538759, 5.026548245743669}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.825, 0.1], 
   Polygon[{{1.780235837034216, 5.1312680008633285}, {1.780235837034216, \
5.235987755982988}, {1.8849555921538759, 5.235987755982988}, 
     {1.8849555921538759, 5.1312680008633285}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{1.780235837034216, 5.235987755982988}, {1.780235837034216, \
5.340707511102648}, {1.8849555921538759, 5.340707511102648}, 
     {1.8849555921538759, 5.235987755982988}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{1.780235837034216, 5.340707511102648}, {1.780235837034216, \
5.445427266222308}, {1.8849555921538759, 5.445427266222308}, 
     {1.8849555921538759, 5.340707511102648}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.875, 0.1], 
   Polygon[{{1.780235837034216, 5.445427266222308}, {1.780235837034216, \
5.550147021341967}, {1.8849555921538759, 5.550147021341967}, 
     {1.8849555921538759, 5.445427266222308}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{1.780235837034216, 5.550147021341967}, {1.780235837034216, \
5.654866776461628}, {1.8849555921538759, 5.654866776461628}, 
     {1.8849555921538759, 5.550147021341967}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{1.780235837034216, 5.654866776461628}, {1.780235837034216, \
5.759586531581287}, {1.8849555921538759, 5.759586531581287}, 
     {1.8849555921538759, 5.654866776461628}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{1.780235837034216, 5.759586531581287}, {1.780235837034216, \
5.864306286700947}, {1.8849555921538759, 5.864306286700947}, 
     {1.8849555921538759, 5.759586531581287}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{1.780235837034216, 5.864306286700947}, {1.780235837034216, \
5.969026041820607}, {1.8849555921538759, 5.969026041820607}, 
     {1.8849555921538759, 5.864306286700947}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{1.780235837034216, 5.969026041820607}, {1.780235837034216, \
6.073745796940266}, {1.8849555921538759, 6.073745796940266}, 
     {1.8849555921538759, 5.969026041820607}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.975, 0.1], 
   Polygon[{{1.780235837034216, 6.073745796940266}, {1.780235837034216, \
6.178465552059926}, {1.8849555921538759, 6.178465552059926}, 
     {1.8849555921538759, 6.073745796940266}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{1.780235837034216, 6.178465552059926}, {1.780235837034216, \
6.283185307179586}, {1.8849555921538759, 6.283185307179586}, 
     {1.8849555921538759, 6.178465552059926}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 0.}, {1.8849555921538759, \
0.10471975511965977}, {1.9896753472735356, 0.10471975511965977}, 
     {1.9896753472735356, 0.}}]}, {CMYKColor[0.6166666666666667, 0.5, 0.025, \
0.1], 
   Polygon[{{1.8849555921538759, 0.10471975511965977}, {1.8849555921538759, \
0.20943951023931953}, {1.9896753472735356, 0.20943951023931953}, 
     {1.9896753472735356, 0.10471975511965977}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{1.8849555921538759, 0.20943951023931953}, {1.8849555921538759, \
0.3141592653589793}, {1.9896753472735356, 0.3141592653589793}, 
     {1.9896753472735356, 0.20943951023931953}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{1.8849555921538759, 0.3141592653589793}, {1.8849555921538759, \
0.41887902047863906}, {1.9896753472735356, 0.41887902047863906}, 
     {1.9896753472735356, 0.3141592653589793}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{1.8849555921538759, 0.41887902047863906}, {1.8849555921538759, \
0.5235987755982988}, {1.9896753472735356, 0.5235987755982988}, 
     {1.9896753472735356, 0.41887902047863906}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{1.8849555921538759, 0.5235987755982988}, {1.8849555921538759, \
0.6283185307179586}, {1.9896753472735356, 0.6283185307179586}, 
     {1.9896753472735356, 0.5235987755982988}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{1.8849555921538759, 0.6283185307179586}, {1.8849555921538759, \
0.7330382858376183}, {1.9896753472735356, 0.7330382858376183}, 
     {1.9896753472735356, 0.6283185307179586}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{1.8849555921538759, 0.7330382858376183}, {1.8849555921538759, \
0.8377580409572781}, {1.9896753472735356, 0.8377580409572781}, 
     {1.9896753472735356, 0.7330382858376183}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{1.8849555921538759, 0.8377580409572781}, {1.8849555921538759, \
0.9424777960769379}, {1.9896753472735356, 0.9424777960769379}, 
     {1.9896753472735356, 0.8377580409572781}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 0.9424777960769379}, {1.8849555921538759, \
1.0471975511965976}, {1.9896753472735356, 1.0471975511965976}, 
     {1.9896753472735356, 0.9424777960769379}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{1.8849555921538759, 1.0471975511965976}, {1.8849555921538759, \
1.1519173063162573}, {1.9896753472735356, 1.1519173063162573}, 
     {1.9896753472735356, 1.0471975511965976}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{1.8849555921538759, 1.1519173063162573}, {1.8849555921538759, \
1.2566370614359172}, {1.9896753472735356, 1.2566370614359172}, 
     {1.9896753472735356, 1.1519173063162573}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.8849555921538759, 1.2566370614359172}, {1.8849555921538759, \
1.361356816555577}, {1.9896753472735356, 1.361356816555577}, 
     {1.9896753472735356, 1.2566370614359172}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{1.8849555921538759, 1.361356816555577}, {1.8849555921538759, \
1.4660765716752366}, {1.9896753472735356, 1.4660765716752366}, 
     {1.9896753472735356, 1.361356816555577}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.8849555921538759, 1.4660765716752366}, {1.8849555921538759, \
1.5707963267948966}, {1.9896753472735356, 1.5707963267948966}, 
     {1.9896753472735356, 1.4660765716752366}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 1.5707963267948966}, {1.8849555921538759, \
1.6755160819145563}, {1.9896753472735356, 1.6755160819145563}, 
     {1.9896753472735356, 1.5707963267948966}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{1.8849555921538759, 1.6755160819145563}, {1.8849555921538759, \
1.780235837034216}, {1.9896753472735356, 1.780235837034216}, 
     {1.9896753472735356, 1.6755160819145563}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.8849555921538759, 1.780235837034216}, {1.8849555921538759, \
1.8849555921538759}, {1.9896753472735356, 1.8849555921538759}, 
     {1.9896753472735356, 1.780235837034216}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.8849555921538759, 1.8849555921538759}, {1.8849555921538759, \
1.9896753472735356}, {1.9896753472735356, 1.9896753472735356}, 
     {1.9896753472735356, 1.8849555921538759}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{1.8849555921538759, 1.9896753472735356}, {1.8849555921538759, \
2.0943951023931953}, {1.9896753472735356, 2.0943951023931953}, 
     {1.9896753472735356, 1.9896753472735356}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{1.8849555921538759, 2.0943951023931953}, {1.8849555921538759, \
2.199114857512855}, {1.9896753472735356, 2.199114857512855}, 
     {1.9896753472735356, 2.0943951023931953}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{1.8849555921538759, 2.199114857512855}, {1.8849555921538759, \
2.3038346126325147}, {1.9896753472735356, 2.3038346126325147}, 
     {1.9896753472735356, 2.199114857512855}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{1.8849555921538759, 2.3038346126325147}, {1.8849555921538759, \
2.4085543677521746}, {1.9896753472735356, 2.4085543677521746}, 
     {1.9896753472735356, 2.3038346126325147}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{1.8849555921538759, 2.4085543677521746}, {1.8849555921538759, \
2.5132741228718345}, {1.9896753472735356, 2.5132741228718345}, 
     {1.9896753472735356, 2.4085543677521746}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 2.5132741228718345}, {1.8849555921538759, \
2.617993877991494}, {1.9896753472735356, 2.617993877991494}, 
     {1.9896753472735356, 2.5132741228718345}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{1.8849555921538759, 2.617993877991494}, {1.8849555921538759, \
2.722713633111154}, {1.9896753472735356, 2.722713633111154}, 
     {1.9896753472735356, 2.617993877991494}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{1.8849555921538759, 2.722713633111154}, {1.8849555921538759, \
2.827433388230814}, {1.9896753472735356, 2.827433388230814}, 
     {1.9896753472735356, 2.722713633111154}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 2.827433388230814}, {1.8849555921538759, \
2.9321531433504733}, {1.9896753472735356, 2.9321531433504733}, 
     {1.9896753472735356, 2.827433388230814}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{1.8849555921538759, 2.9321531433504733}, {1.8849555921538759, \
3.036872898470133}, {1.9896753472735356, 3.036872898470133}, 
     {1.9896753472735356, 2.9321531433504733}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{1.8849555921538759, 3.036872898470133}, {1.8849555921538759, \
3.141592653589793}, {1.9896753472735356, 3.141592653589793}, 
     {1.9896753472735356, 3.036872898470133}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 3.141592653589793}, {1.8849555921538759, \
3.2463124087094526}, {1.9896753472735356, 3.2463124087094526}, 
     {1.9896753472735356, 3.141592653589793}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{1.8849555921538759, 3.2463124087094526}, {1.8849555921538759, \
3.3510321638291125}, {1.9896753472735356, 3.3510321638291125}, 
     {1.9896753472735356, 3.2463124087094526}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{1.8849555921538759, 3.3510321638291125}, {1.8849555921538759, \
3.4557519189487724}, {1.9896753472735356, 3.4557519189487724}, 
     {1.9896753472735356, 3.3510321638291125}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 3.4557519189487724}, {1.8849555921538759, \
3.560471674068432}, {1.9896753472735356, 3.560471674068432}, 
     {1.9896753472735356, 3.4557519189487724}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{1.8849555921538759, 3.560471674068432}, {1.8849555921538759, \
3.665191429188092}, {1.9896753472735356, 3.665191429188092}, 
     {1.9896753472735356, 3.560471674068432}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{1.8849555921538759, 3.665191429188092}, {1.8849555921538759, \
3.7699111843077517}, {1.9896753472735356, 3.7699111843077517}, 
     {1.9896753472735356, 3.665191429188092}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 3.7699111843077517}, {1.8849555921538759, \
3.874630939427411}, {1.9896753472735356, 3.874630939427411}, 
     {1.9896753472735356, 3.7699111843077517}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{1.8849555921538759, 3.874630939427411}, {1.8849555921538759, \
3.979350694547071}, {1.9896753472735356, 3.979350694547071}, 
     {1.9896753472735356, 3.874630939427411}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{1.8849555921538759, 3.979350694547071}, {1.8849555921538759, \
4.084070449666731}, {1.9896753472735356, 4.084070449666731}, 
     {1.9896753472735356, 3.979350694547071}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 4.084070449666731}, {1.8849555921538759, \
4.1887902047863905}, {1.9896753472735356, 4.1887902047863905}, 
     {1.9896753472735356, 4.084070449666731}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{1.8849555921538759, 4.1887902047863905}, {1.8849555921538759, \
4.29350995990605}, {1.9896753472735356, 4.29350995990605}, 
     {1.9896753472735356, 4.1887902047863905}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{1.8849555921538759, 4.29350995990605}, {1.8849555921538759, \
4.39822971502571}, {1.9896753472735356, 4.39822971502571}, 
     {1.9896753472735356, 4.29350995990605}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.8849555921538759, 4.39822971502571}, {1.8849555921538759, \
4.50294947014537}, {1.9896753472735356, 4.50294947014537}, 
     {1.9896753472735356, 4.39822971502571}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{1.8849555921538759, 4.50294947014537}, {1.8849555921538759, \
4.607669225265029}, {1.9896753472735356, 4.607669225265029}, 
     {1.9896753472735356, 4.50294947014537}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.8849555921538759, 4.607669225265029}, {1.8849555921538759, \
4.71238898038469}, {1.9896753472735356, 4.71238898038469}, 
     {1.9896753472735356, 4.607669225265029}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 4.71238898038469}, {1.8849555921538759, \
4.817108735504349}, {1.9896753472735356, 4.817108735504349}, 
     {1.9896753472735356, 4.71238898038469}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.775, 0.1], 
   Polygon[{{1.8849555921538759, 4.817108735504349}, {1.8849555921538759, \
4.921828490624009}, {1.9896753472735356, 4.921828490624009}, 
     {1.9896753472735356, 4.817108735504349}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.8849555921538759, 4.921828490624009}, {1.8849555921538759, \
5.026548245743669}, {1.9896753472735356, 5.026548245743669}, 
     {1.9896753472735356, 4.921828490624009}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 5.026548245743669}, {1.8849555921538759, \
5.1312680008633285}, {1.9896753472735356, 5.1312680008633285}, 
     {1.9896753472735356, 5.026548245743669}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{1.8849555921538759, 5.1312680008633285}, {1.8849555921538759, \
5.235987755982988}, {1.9896753472735356, 5.235987755982988}, 
     {1.9896753472735356, 5.1312680008633285}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{1.8849555921538759, 5.235987755982988}, {1.8849555921538759, \
5.340707511102648}, {1.9896753472735356, 5.340707511102648}, 
     {1.9896753472735356, 5.235987755982988}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 5.340707511102648}, {1.8849555921538759, \
5.445427266222308}, {1.9896753472735356, 5.445427266222308}, 
     {1.9896753472735356, 5.340707511102648}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{1.8849555921538759, 5.445427266222308}, {1.8849555921538759, \
5.550147021341967}, {1.9896753472735356, 5.550147021341967}, 
     {1.9896753472735356, 5.445427266222308}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{1.8849555921538759, 5.550147021341967}, {1.8849555921538759, \
5.654866776461628}, {1.9896753472735356, 5.654866776461628}, 
     {1.9896753472735356, 5.550147021341967}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{1.8849555921538759, 5.654866776461628}, {1.8849555921538759, \
5.759586531581287}, {1.9896753472735356, 5.759586531581287}, 
     {1.9896753472735356, 5.654866776461628}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{1.8849555921538759, 5.759586531581287}, {1.8849555921538759, \
5.864306286700947}, {1.9896753472735356, 5.864306286700947}, 
     {1.9896753472735356, 5.759586531581287}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{1.8849555921538759, 5.864306286700947}, {1.8849555921538759, \
5.969026041820607}, {1.9896753472735356, 5.969026041820607}, 
     {1.9896753472735356, 5.864306286700947}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{1.8849555921538759, 5.969026041820607}, {1.8849555921538759, \
6.073745796940266}, {1.9896753472735356, 6.073745796940266}, 
     {1.9896753472735356, 5.969026041820607}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{1.8849555921538759, 6.073745796940266}, {1.8849555921538759, \
6.178465552059926}, {1.9896753472735356, 6.178465552059926}, 
     {1.9896753472735356, 6.073745796940266}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{1.8849555921538759, 6.178465552059926}, {1.8849555921538759, \
6.283185307179586}, {1.9896753472735356, 6.283185307179586}, 
     {1.9896753472735356, 6.178465552059926}}]}, {CMYKColor[0.65, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 0.}, {1.9896753472735356, \
0.10471975511965977}, {2.0943951023931953, 0.10471975511965977}, 
     {2.0943951023931953, 0.}}]}, {CMYKColor[0.65, 0.5, 0.025, 0.1], 
   Polygon[{{1.9896753472735356, 0.10471975511965977}, {1.9896753472735356, \
0.20943951023931953}, {2.0943951023931953, 0.20943951023931953}, 
     {2.0943951023931953, 0.10471975511965977}}]}, {CMYKColor[0.65, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{1.9896753472735356, 0.20943951023931953}, {1.9896753472735356, \
0.3141592653589793}, {2.0943951023931953, 0.3141592653589793}, 
     {2.0943951023931953, 0.20943951023931953}}]}, {CMYKColor[0.65, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{1.9896753472735356, 0.3141592653589793}, {1.9896753472735356, \
0.41887902047863906}, {2.0943951023931953, 0.41887902047863906}, 
     {2.0943951023931953, 0.3141592653589793}}]}, {CMYKColor[0.65, 0.5, \
0.075, 0.1], 
   Polygon[{{1.9896753472735356, 0.41887902047863906}, {1.9896753472735356, \
0.5235987755982988}, {2.0943951023931953, 0.5235987755982988}, 
     {2.0943951023931953, 0.41887902047863906}}]}, {CMYKColor[0.65, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{1.9896753472735356, 0.5235987755982988}, {1.9896753472735356, \
0.6283185307179586}, {2.0943951023931953, 0.6283185307179586}, 
     {2.0943951023931953, 0.5235987755982988}}]}, {CMYKColor[0.65, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{1.9896753472735356, 0.6283185307179586}, {1.9896753472735356, \
0.7330382858376183}, {2.0943951023931953, 0.7330382858376183}, 
     {2.0943951023931953, 0.6283185307179586}}]}, {CMYKColor[0.65, 0.5, \
0.125, 0.1], 
   Polygon[{{1.9896753472735356, 0.7330382858376183}, {1.9896753472735356, \
0.8377580409572781}, {2.0943951023931953, 0.8377580409572781}, 
     {2.0943951023931953, 0.7330382858376183}}]}, {CMYKColor[0.65, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{1.9896753472735356, 0.8377580409572781}, {1.9896753472735356, \
0.9424777960769379}, {2.0943951023931953, 0.9424777960769379}, 
     {2.0943951023931953, 0.8377580409572781}}]}, {CMYKColor[0.65, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 0.9424777960769379}, {1.9896753472735356, \
1.0471975511965976}, {2.0943951023931953, 1.0471975511965976}, 
     {2.0943951023931953, 0.9424777960769379}}]}, {CMYKColor[0.65, 0.5, \
0.175, 0.1], 
   Polygon[{{1.9896753472735356, 1.0471975511965976}, {1.9896753472735356, \
1.1519173063162573}, {2.0943951023931953, 1.1519173063162573}, 
     {2.0943951023931953, 1.0471975511965976}}]}, {CMYKColor[0.65, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{1.9896753472735356, 1.1519173063162573}, {1.9896753472735356, \
1.2566370614359172}, {2.0943951023931953, 1.2566370614359172}, 
     {2.0943951023931953, 1.1519173063162573}}]}, {CMYKColor[0.65, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{1.9896753472735356, 1.2566370614359172}, {1.9896753472735356, \
1.361356816555577}, {2.0943951023931953, 1.361356816555577}, 
     {2.0943951023931953, 1.2566370614359172}}]}, {CMYKColor[0.65, 0.5, \
0.225, 0.1], 
   Polygon[{{1.9896753472735356, 1.361356816555577}, {1.9896753472735356, \
1.4660765716752366}, {2.0943951023931953, 1.4660765716752366}, 
     {2.0943951023931953, 1.361356816555577}}]}, {CMYKColor[0.65, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{1.9896753472735356, 1.4660765716752366}, {1.9896753472735356, \
1.5707963267948966}, {2.0943951023931953, 1.5707963267948966}, 
     {2.0943951023931953, 1.4660765716752366}}]}, {CMYKColor[0.65, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 1.5707963267948966}, {1.9896753472735356, \
1.6755160819145563}, {2.0943951023931953, 1.6755160819145563}, 
     {2.0943951023931953, 1.5707963267948966}}]}, {CMYKColor[0.65, 0.5, \
0.275, 0.1], 
   Polygon[{{1.9896753472735356, 1.6755160819145563}, {1.9896753472735356, \
1.780235837034216}, {2.0943951023931953, 1.780235837034216}, 
     {2.0943951023931953, 1.6755160819145563}}]}, {CMYKColor[0.65, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{1.9896753472735356, 1.780235837034216}, {1.9896753472735356, \
1.8849555921538759}, {2.0943951023931953, 1.8849555921538759}, 
     {2.0943951023931953, 1.780235837034216}}]}, {CMYKColor[0.65, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{1.9896753472735356, 1.8849555921538759}, {1.9896753472735356, \
1.9896753472735356}, {2.0943951023931953, 1.9896753472735356}, 
     {2.0943951023931953, 1.8849555921538759}}]}, {CMYKColor[0.65, 0.5, \
0.325, 0.1], 
   Polygon[{{1.9896753472735356, 1.9896753472735356}, {1.9896753472735356, \
2.0943951023931953}, {2.0943951023931953, 2.0943951023931953}, 
     {2.0943951023931953, 1.9896753472735356}}]}, {CMYKColor[0.65, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{1.9896753472735356, 2.0943951023931953}, {1.9896753472735356, \
2.199114857512855}, {2.0943951023931953, 2.199114857512855}, 
     {2.0943951023931953, 2.0943951023931953}}]}, {CMYKColor[0.65, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{1.9896753472735356, 2.199114857512855}, {1.9896753472735356, \
2.3038346126325147}, {2.0943951023931953, 2.3038346126325147}, 
     {2.0943951023931953, 2.199114857512855}}]}, {CMYKColor[0.65, 0.5, 0.375, \
0.1], 
   Polygon[{{1.9896753472735356, 2.3038346126325147}, {1.9896753472735356, \
2.4085543677521746}, {2.0943951023931953, 2.4085543677521746}, 
     {2.0943951023931953, 2.3038346126325147}}]}, {CMYKColor[0.65, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{1.9896753472735356, 2.4085543677521746}, {1.9896753472735356, \
2.5132741228718345}, {2.0943951023931953, 2.5132741228718345}, 
     {2.0943951023931953, 2.4085543677521746}}]}, {CMYKColor[0.65, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 2.5132741228718345}, {1.9896753472735356, \
2.617993877991494}, {2.0943951023931953, 2.617993877991494}, 
     {2.0943951023931953, 2.5132741228718345}}]}, {CMYKColor[0.65, 0.5, \
0.425, 0.1], 
   Polygon[{{1.9896753472735356, 2.617993877991494}, {1.9896753472735356, \
2.722713633111154}, {2.0943951023931953, 2.722713633111154}, 
     {2.0943951023931953, 2.617993877991494}}]}, {CMYKColor[0.65, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{1.9896753472735356, 2.722713633111154}, {1.9896753472735356, \
2.827433388230814}, {2.0943951023931953, 2.827433388230814}, 
     {2.0943951023931953, 2.722713633111154}}]}, {CMYKColor[0.65, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 2.827433388230814}, {1.9896753472735356, \
2.9321531433504733}, {2.0943951023931953, 2.9321531433504733}, 
     {2.0943951023931953, 2.827433388230814}}]}, {CMYKColor[0.65, 0.5, 0.475, \
0.1], 
   Polygon[{{1.9896753472735356, 2.9321531433504733}, {1.9896753472735356, \
3.036872898470133}, {2.0943951023931953, 3.036872898470133}, 
     {2.0943951023931953, 2.9321531433504733}}]}, {CMYKColor[0.65, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{1.9896753472735356, 3.036872898470133}, {1.9896753472735356, \
3.141592653589793}, {2.0943951023931953, 3.141592653589793}, 
     {2.0943951023931953, 3.036872898470133}}]}, {CMYKColor[0.65, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 3.141592653589793}, {1.9896753472735356, \
3.2463124087094526}, {2.0943951023931953, 3.2463124087094526}, 
     {2.0943951023931953, 3.141592653589793}}]}, {CMYKColor[0.65, 0.5, 0.525, \
0.1], 
   Polygon[{{1.9896753472735356, 3.2463124087094526}, {1.9896753472735356, \
3.3510321638291125}, {2.0943951023931953, 3.3510321638291125}, 
     {2.0943951023931953, 3.2463124087094526}}]}, {CMYKColor[0.65, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{1.9896753472735356, 3.3510321638291125}, {1.9896753472735356, \
3.4557519189487724}, {2.0943951023931953, 3.4557519189487724}, 
     {2.0943951023931953, 3.3510321638291125}}]}, {CMYKColor[0.65, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 3.4557519189487724}, {1.9896753472735356, \
3.560471674068432}, {2.0943951023931953, 3.560471674068432}, 
     {2.0943951023931953, 3.4557519189487724}}]}, {CMYKColor[0.65, 0.5, \
0.575, 0.1], 
   Polygon[{{1.9896753472735356, 3.560471674068432}, {1.9896753472735356, \
3.665191429188092}, {2.0943951023931953, 3.665191429188092}, 
     {2.0943951023931953, 3.560471674068432}}]}, {CMYKColor[0.65, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{1.9896753472735356, 3.665191429188092}, {1.9896753472735356, \
3.7699111843077517}, {2.0943951023931953, 3.7699111843077517}, 
     {2.0943951023931953, 3.665191429188092}}]}, {CMYKColor[0.65, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 3.7699111843077517}, {1.9896753472735356, \
3.874630939427411}, {2.0943951023931953, 3.874630939427411}, 
     {2.0943951023931953, 3.7699111843077517}}]}, {CMYKColor[0.65, 0.5, \
0.625, 0.1], 
   Polygon[{{1.9896753472735356, 3.874630939427411}, {1.9896753472735356, \
3.979350694547071}, {2.0943951023931953, 3.979350694547071}, 
     {2.0943951023931953, 3.874630939427411}}]}, {CMYKColor[0.65, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{1.9896753472735356, 3.979350694547071}, {1.9896753472735356, \
4.084070449666731}, {2.0943951023931953, 4.084070449666731}, 
     {2.0943951023931953, 3.979350694547071}}]}, {CMYKColor[0.65, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 4.084070449666731}, {1.9896753472735356, \
4.1887902047863905}, {2.0943951023931953, 4.1887902047863905}, 
     {2.0943951023931953, 4.084070449666731}}]}, {CMYKColor[0.65, 0.5, 0.675, \
0.1], 
   Polygon[{{1.9896753472735356, 4.1887902047863905}, {1.9896753472735356, \
4.29350995990605}, {2.0943951023931953, 4.29350995990605}, 
     {2.0943951023931953, 4.1887902047863905}}]}, {CMYKColor[0.65, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{1.9896753472735356, 4.29350995990605}, {1.9896753472735356, \
4.39822971502571}, {2.0943951023931953, 4.39822971502571}, 
     {2.0943951023931953, 4.29350995990605}}]}, {CMYKColor[0.65, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{1.9896753472735356, 4.39822971502571}, {1.9896753472735356, \
4.50294947014537}, {2.0943951023931953, 4.50294947014537}, 
     {2.0943951023931953, 4.39822971502571}}]}, {CMYKColor[0.65, 0.5, 0.725, \
0.1], 
   Polygon[{{1.9896753472735356, 4.50294947014537}, {1.9896753472735356, \
4.607669225265029}, {2.0943951023931953, 4.607669225265029}, 
     {2.0943951023931953, 4.50294947014537}}]}, {CMYKColor[0.65, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{1.9896753472735356, 4.607669225265029}, {1.9896753472735356, \
4.71238898038469}, {2.0943951023931953, 4.71238898038469}, 
     {2.0943951023931953, 4.607669225265029}}]}, {CMYKColor[0.65, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 4.71238898038469}, {1.9896753472735356, \
4.817108735504349}, {2.0943951023931953, 4.817108735504349}, 
     {2.0943951023931953, 4.71238898038469}}]}, {CMYKColor[0.65, 0.5, 0.775, \
0.1], 
   Polygon[{{1.9896753472735356, 4.817108735504349}, {1.9896753472735356, \
4.921828490624009}, {2.0943951023931953, 4.921828490624009}, 
     {2.0943951023931953, 4.817108735504349}}]}, {CMYKColor[0.65, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{1.9896753472735356, 4.921828490624009}, {1.9896753472735356, \
5.026548245743669}, {2.0943951023931953, 5.026548245743669}, 
     {2.0943951023931953, 4.921828490624009}}]}, {CMYKColor[0.65, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 5.026548245743669}, {1.9896753472735356, \
5.1312680008633285}, {2.0943951023931953, 5.1312680008633285}, 
     {2.0943951023931953, 5.026548245743669}}]}, {CMYKColor[0.65, 0.5, 0.825, \
0.1], 
   Polygon[{{1.9896753472735356, 5.1312680008633285}, {1.9896753472735356, \
5.235987755982988}, {2.0943951023931953, 5.235987755982988}, 
     {2.0943951023931953, 5.1312680008633285}}]}, {CMYKColor[0.65, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{1.9896753472735356, 5.235987755982988}, {1.9896753472735356, \
5.340707511102648}, {2.0943951023931953, 5.340707511102648}, 
     {2.0943951023931953, 5.235987755982988}}]}, {CMYKColor[0.65, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 5.340707511102648}, {1.9896753472735356, \
5.445427266222308}, {2.0943951023931953, 5.445427266222308}, 
     {2.0943951023931953, 5.340707511102648}}]}, {CMYKColor[0.65, 0.5, 0.875, \
0.1], 
   Polygon[{{1.9896753472735356, 5.445427266222308}, {1.9896753472735356, \
5.550147021341967}, {2.0943951023931953, 5.550147021341967}, 
     {2.0943951023931953, 5.445427266222308}}]}, {CMYKColor[0.65, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{1.9896753472735356, 5.550147021341967}, {1.9896753472735356, \
5.654866776461628}, {2.0943951023931953, 5.654866776461628}, 
     {2.0943951023931953, 5.550147021341967}}]}, {CMYKColor[0.65, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{1.9896753472735356, 5.654866776461628}, {1.9896753472735356, \
5.759586531581287}, {2.0943951023931953, 5.759586531581287}, 
     {2.0943951023931953, 5.654866776461628}}]}, {CMYKColor[0.65, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{1.9896753472735356, 5.759586531581287}, {1.9896753472735356, \
5.864306286700947}, {2.0943951023931953, 5.864306286700947}, 
     {2.0943951023931953, 5.759586531581287}}]}, {CMYKColor[0.65, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{1.9896753472735356, 5.864306286700947}, {1.9896753472735356, \
5.969026041820607}, {2.0943951023931953, 5.969026041820607}, 
     {2.0943951023931953, 5.864306286700947}}]}, {CMYKColor[0.65, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{1.9896753472735356, 5.969026041820607}, {1.9896753472735356, \
6.073745796940266}, {2.0943951023931953, 6.073745796940266}, 
     {2.0943951023931953, 5.969026041820607}}]}, {CMYKColor[0.65, 0.5, 0.975, \
0.1], 
   Polygon[{{1.9896753472735356, 6.073745796940266}, {1.9896753472735356, \
6.178465552059926}, {2.0943951023931953, 6.178465552059926}, 
     {2.0943951023931953, 6.073745796940266}}]}, {CMYKColor[0.65, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{1.9896753472735356, 6.178465552059926}, {1.9896753472735356, \
6.283185307179586}, {2.0943951023931953, 6.283185307179586}, 
     {2.0943951023931953, 6.178465552059926}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 0.}, {2.0943951023931953, \
0.10471975511965977}, {2.199114857512855, 0.10471975511965977}, 
     {2.199114857512855, 0.}}]}, {CMYKColor[0.6833333333333333, 0.5, 0.025, \
0.1], 
   Polygon[{{2.0943951023931953, 0.10471975511965977}, {2.0943951023931953, \
0.20943951023931953}, {2.199114857512855, 0.20943951023931953}, 
     {2.199114857512855, 0.10471975511965977}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{2.0943951023931953, 0.20943951023931953}, {2.0943951023931953, \
0.3141592653589793}, {2.199114857512855, 0.3141592653589793}, 
     {2.199114857512855, 0.20943951023931953}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{2.0943951023931953, 0.3141592653589793}, {2.0943951023931953, \
0.41887902047863906}, {2.199114857512855, 0.41887902047863906}, 
     {2.199114857512855, 0.3141592653589793}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{2.0943951023931953, 0.41887902047863906}, {2.0943951023931953, \
0.5235987755982988}, {2.199114857512855, 0.5235987755982988}, 
     {2.199114857512855, 0.41887902047863906}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{2.0943951023931953, 0.5235987755982988}, {2.0943951023931953, \
0.6283185307179586}, {2.199114857512855, 0.6283185307179586}, 
     {2.199114857512855, 0.5235987755982988}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{2.0943951023931953, 0.6283185307179586}, {2.0943951023931953, \
0.7330382858376183}, {2.199114857512855, 0.7330382858376183}, 
     {2.199114857512855, 0.6283185307179586}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{2.0943951023931953, 0.7330382858376183}, {2.0943951023931953, \
0.8377580409572781}, {2.199114857512855, 0.8377580409572781}, 
     {2.199114857512855, 0.7330382858376183}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{2.0943951023931953, 0.8377580409572781}, {2.0943951023931953, \
0.9424777960769379}, {2.199114857512855, 0.9424777960769379}, 
     {2.199114857512855, 0.8377580409572781}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 0.9424777960769379}, {2.0943951023931953, \
1.0471975511965976}, {2.199114857512855, 1.0471975511965976}, 
     {2.199114857512855, 0.9424777960769379}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{2.0943951023931953, 1.0471975511965976}, {2.0943951023931953, \
1.1519173063162573}, {2.199114857512855, 1.1519173063162573}, 
     {2.199114857512855, 1.0471975511965976}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{2.0943951023931953, 1.1519173063162573}, {2.0943951023931953, \
1.2566370614359172}, {2.199114857512855, 1.2566370614359172}, 
     {2.199114857512855, 1.1519173063162573}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{2.0943951023931953, 1.2566370614359172}, {2.0943951023931953, \
1.361356816555577}, {2.199114857512855, 1.361356816555577}, 
     {2.199114857512855, 1.2566370614359172}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{2.0943951023931953, 1.361356816555577}, {2.0943951023931953, \
1.4660765716752366}, {2.199114857512855, 1.4660765716752366}, 
     {2.199114857512855, 1.361356816555577}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{2.0943951023931953, 1.4660765716752366}, {2.0943951023931953, \
1.5707963267948966}, {2.199114857512855, 1.5707963267948966}, 
     {2.199114857512855, 1.4660765716752366}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 1.5707963267948966}, {2.0943951023931953, \
1.6755160819145563}, {2.199114857512855, 1.6755160819145563}, 
     {2.199114857512855, 1.5707963267948966}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{2.0943951023931953, 1.6755160819145563}, {2.0943951023931953, \
1.780235837034216}, {2.199114857512855, 1.780235837034216}, 
     {2.199114857512855, 1.6755160819145563}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{2.0943951023931953, 1.780235837034216}, {2.0943951023931953, \
1.8849555921538759}, {2.199114857512855, 1.8849555921538759}, 
     {2.199114857512855, 1.780235837034216}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{2.0943951023931953, 1.8849555921538759}, {2.0943951023931953, \
1.9896753472735356}, {2.199114857512855, 1.9896753472735356}, 
     {2.199114857512855, 1.8849555921538759}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{2.0943951023931953, 1.9896753472735356}, {2.0943951023931953, \
2.0943951023931953}, {2.199114857512855, 2.0943951023931953}, 
     {2.199114857512855, 1.9896753472735356}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.0943951023931953, 2.0943951023931953}, {2.0943951023931953, \
2.199114857512855}, {2.199114857512855, 2.199114857512855}, 
     {2.199114857512855, 2.0943951023931953}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.0943951023931953, 2.199114857512855}, {2.0943951023931953, \
2.3038346126325147}, {2.199114857512855, 2.3038346126325147}, 
     {2.199114857512855, 2.199114857512855}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{2.0943951023931953, 2.3038346126325147}, {2.0943951023931953, \
2.4085543677521746}, {2.199114857512855, 2.4085543677521746}, 
     {2.199114857512855, 2.3038346126325147}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{2.0943951023931953, 2.4085543677521746}, {2.0943951023931953, \
2.5132741228718345}, {2.199114857512855, 2.5132741228718345}, 
     {2.199114857512855, 2.4085543677521746}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 2.5132741228718345}, {2.0943951023931953, \
2.617993877991494}, {2.199114857512855, 2.617993877991494}, 
     {2.199114857512855, 2.5132741228718345}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{2.0943951023931953, 2.617993877991494}, {2.0943951023931953, \
2.722713633111154}, {2.199114857512855, 2.722713633111154}, 
     {2.199114857512855, 2.617993877991494}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{2.0943951023931953, 2.722713633111154}, {2.0943951023931953, \
2.827433388230814}, {2.199114857512855, 2.827433388230814}, 
     {2.199114857512855, 2.722713633111154}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 2.827433388230814}, {2.0943951023931953, \
2.9321531433504733}, {2.199114857512855, 2.9321531433504733}, 
     {2.199114857512855, 2.827433388230814}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{2.0943951023931953, 2.9321531433504733}, {2.0943951023931953, \
3.036872898470133}, {2.199114857512855, 3.036872898470133}, 
     {2.199114857512855, 2.9321531433504733}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{2.0943951023931953, 3.036872898470133}, {2.0943951023931953, \
3.141592653589793}, {2.199114857512855, 3.141592653589793}, 
     {2.199114857512855, 3.036872898470133}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 3.141592653589793}, {2.0943951023931953, \
3.2463124087094526}, {2.199114857512855, 3.2463124087094526}, 
     {2.199114857512855, 3.141592653589793}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{2.0943951023931953, 3.2463124087094526}, {2.0943951023931953, \
3.3510321638291125}, {2.199114857512855, 3.3510321638291125}, 
     {2.199114857512855, 3.2463124087094526}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{2.0943951023931953, 3.3510321638291125}, {2.0943951023931953, \
3.4557519189487724}, {2.199114857512855, 3.4557519189487724}, 
     {2.199114857512855, 3.3510321638291125}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 3.4557519189487724}, {2.0943951023931953, \
3.560471674068432}, {2.199114857512855, 3.560471674068432}, 
     {2.199114857512855, 3.4557519189487724}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{2.0943951023931953, 3.560471674068432}, {2.0943951023931953, \
3.665191429188092}, {2.199114857512855, 3.665191429188092}, 
     {2.199114857512855, 3.560471674068432}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{2.0943951023931953, 3.665191429188092}, {2.0943951023931953, \
3.7699111843077517}, {2.199114857512855, 3.7699111843077517}, 
     {2.199114857512855, 3.665191429188092}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 3.7699111843077517}, {2.0943951023931953, \
3.874630939427411}, {2.199114857512855, 3.874630939427411}, 
     {2.199114857512855, 3.7699111843077517}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{2.0943951023931953, 3.874630939427411}, {2.0943951023931953, \
3.979350694547071}, {2.199114857512855, 3.979350694547071}, 
     {2.199114857512855, 3.874630939427411}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{2.0943951023931953, 3.979350694547071}, {2.0943951023931953, \
4.084070449666731}, {2.199114857512855, 4.084070449666731}, 
     {2.199114857512855, 3.979350694547071}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 4.084070449666731}, {2.0943951023931953, \
4.1887902047863905}, {2.199114857512855, 4.1887902047863905}, 
     {2.199114857512855, 4.084070449666731}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{2.0943951023931953, 4.1887902047863905}, {2.0943951023931953, \
4.29350995990605}, {2.199114857512855, 4.29350995990605}, 
     {2.199114857512855, 4.1887902047863905}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.0943951023931953, 4.29350995990605}, {2.0943951023931953, \
4.39822971502571}, {2.199114857512855, 4.39822971502571}, 
     {2.199114857512855, 4.29350995990605}}]}, {CMYKColor[0.6833333333333333, \
0.5, 0.7083333333333334, 0.1], 
   Polygon[{{2.0943951023931953, 4.39822971502571}, {2.0943951023931953, \
4.50294947014537}, {2.199114857512855, 4.50294947014537}, 
     {2.199114857512855, 4.39822971502571}}]}, {CMYKColor[0.6833333333333333, \
0.5, 0.725, 0.1], 
   Polygon[{{2.0943951023931953, 4.50294947014537}, {2.0943951023931953, \
4.607669225265029}, {2.199114857512855, 4.607669225265029}, 
     {2.199114857512855, 4.50294947014537}}]}, {CMYKColor[0.6833333333333333, \
0.5, 0.7416666666666667, 0.1], 
   Polygon[{{2.0943951023931953, 4.607669225265029}, {2.0943951023931953, \
4.71238898038469}, {2.199114857512855, 4.71238898038469}, 
     {2.199114857512855, 4.607669225265029}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 4.71238898038469}, {2.0943951023931953, \
4.817108735504349}, {2.199114857512855, 4.817108735504349}, 
     {2.199114857512855, 4.71238898038469}}]}, {CMYKColor[0.6833333333333333, \
0.5, 0.775, 0.1], 
   Polygon[{{2.0943951023931953, 4.817108735504349}, {2.0943951023931953, \
4.921828490624009}, {2.199114857512855, 4.921828490624009}, 
     {2.199114857512855, 4.817108735504349}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{2.0943951023931953, 4.921828490624009}, {2.0943951023931953, \
5.026548245743669}, {2.199114857512855, 5.026548245743669}, 
     {2.199114857512855, 4.921828490624009}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 5.026548245743669}, {2.0943951023931953, \
5.1312680008633285}, {2.199114857512855, 5.1312680008633285}, 
     {2.199114857512855, 5.026548245743669}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{2.0943951023931953, 5.1312680008633285}, {2.0943951023931953, \
5.235987755982988}, {2.199114857512855, 5.235987755982988}, 
     {2.199114857512855, 5.1312680008633285}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.0943951023931953, 5.235987755982988}, {2.0943951023931953, \
5.340707511102648}, {2.199114857512855, 5.340707511102648}, 
     {2.199114857512855, 5.235987755982988}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 5.340707511102648}, {2.0943951023931953, \
5.445427266222308}, {2.199114857512855, 5.445427266222308}, 
     {2.199114857512855, 5.340707511102648}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{2.0943951023931953, 5.445427266222308}, {2.0943951023931953, \
5.550147021341967}, {2.199114857512855, 5.550147021341967}, 
     {2.199114857512855, 5.445427266222308}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{2.0943951023931953, 5.550147021341967}, {2.0943951023931953, \
5.654866776461628}, {2.199114857512855, 5.654866776461628}, 
     {2.199114857512855, 5.550147021341967}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{2.0943951023931953, 5.654866776461628}, {2.0943951023931953, \
5.759586531581287}, {2.199114857512855, 5.759586531581287}, 
     {2.199114857512855, 5.654866776461628}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{2.0943951023931953, 5.759586531581287}, {2.0943951023931953, \
5.864306286700947}, {2.199114857512855, 5.864306286700947}, 
     {2.199114857512855, 5.759586531581287}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{2.0943951023931953, 5.864306286700947}, {2.0943951023931953, \
5.969026041820607}, {2.199114857512855, 5.969026041820607}, 
     {2.199114857512855, 5.864306286700947}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{2.0943951023931953, 5.969026041820607}, {2.0943951023931953, \
6.073745796940266}, {2.199114857512855, 6.073745796940266}, 
     {2.199114857512855, 5.969026041820607}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{2.0943951023931953, 6.073745796940266}, {2.0943951023931953, \
6.178465552059926}, {2.199114857512855, 6.178465552059926}, 
     {2.199114857512855, 6.073745796940266}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{2.0943951023931953, 6.178465552059926}, {2.0943951023931953, \
6.283185307179586}, {2.199114857512855, 6.283185307179586}, 
     {2.199114857512855, 6.178465552059926}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{2.199114857512855, 0.}, {2.199114857512855, \
0.10471975511965977}, {2.3038346126325147, 0.10471975511965977}, 
     {2.3038346126325147, 0.}}]}, {CMYKColor[0.7166666666666667, 0.5, 0.025, \
0.1], 
   Polygon[{{2.199114857512855, 0.10471975511965977}, {2.199114857512855, \
0.20943951023931953}, {2.3038346126325147, 0.20943951023931953}, 
     {2.3038346126325147, 0.10471975511965977}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{2.199114857512855, 0.20943951023931953}, {2.199114857512855, \
0.3141592653589793}, {2.3038346126325147, 0.3141592653589793}, 
     {2.3038346126325147, 0.20943951023931953}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{2.199114857512855, 0.3141592653589793}, {2.199114857512855, \
0.41887902047863906}, {2.3038346126325147, 0.41887902047863906}, 
     {2.3038346126325147, 0.3141592653589793}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{2.199114857512855, 0.41887902047863906}, {2.199114857512855, \
0.5235987755982988}, {2.3038346126325147, 0.5235987755982988}, 
     {2.3038346126325147, 0.41887902047863906}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{2.199114857512855, 0.5235987755982988}, {2.199114857512855, \
0.6283185307179586}, {2.3038346126325147, 0.6283185307179586}, 
     {2.3038346126325147, 0.5235987755982988}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{2.199114857512855, 0.6283185307179586}, {2.199114857512855, \
0.7330382858376183}, {2.3038346126325147, 0.7330382858376183}, 
     {2.3038346126325147, 0.6283185307179586}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{2.199114857512855, 0.7330382858376183}, {2.199114857512855, \
0.8377580409572781}, {2.3038346126325147, 0.8377580409572781}, 
     {2.3038346126325147, 0.7330382858376183}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{2.199114857512855, 0.8377580409572781}, {2.199114857512855, \
0.9424777960769379}, {2.3038346126325147, 0.9424777960769379}, 
     {2.3038346126325147, 0.8377580409572781}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.199114857512855, 0.9424777960769379}, {2.199114857512855, \
1.0471975511965976}, {2.3038346126325147, 1.0471975511965976}, 
     {2.3038346126325147, 0.9424777960769379}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{2.199114857512855, 1.0471975511965976}, {2.199114857512855, \
1.1519173063162573}, {2.3038346126325147, 1.1519173063162573}, 
     {2.3038346126325147, 1.0471975511965976}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{2.199114857512855, 1.1519173063162573}, {2.199114857512855, \
1.2566370614359172}, {2.3038346126325147, 1.2566370614359172}, 
     {2.3038346126325147, 1.1519173063162573}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{2.199114857512855, 1.2566370614359172}, {2.199114857512855, \
1.361356816555577}, {2.3038346126325147, 1.361356816555577}, 
     {2.3038346126325147, 1.2566370614359172}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{2.199114857512855, 1.361356816555577}, {2.199114857512855, \
1.4660765716752366}, {2.3038346126325147, 1.4660765716752366}, 
     {2.3038346126325147, 1.361356816555577}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{2.199114857512855, 1.4660765716752366}, {2.199114857512855, \
1.5707963267948966}, {2.3038346126325147, 1.5707963267948966}, 
     {2.3038346126325147, 1.4660765716752366}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{2.199114857512855, 1.5707963267948966}, {2.199114857512855, \
1.6755160819145563}, {2.3038346126325147, 1.6755160819145563}, 
     {2.3038346126325147, 1.5707963267948966}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{2.199114857512855, 1.6755160819145563}, {2.199114857512855, \
1.780235837034216}, {2.3038346126325147, 1.780235837034216}, 
     {2.3038346126325147, 1.6755160819145563}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{2.199114857512855, 1.780235837034216}, {2.199114857512855, \
1.8849555921538759}, {2.3038346126325147, 1.8849555921538759}, 
     {2.3038346126325147, 1.780235837034216}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{2.199114857512855, 1.8849555921538759}, {2.199114857512855, \
1.9896753472735356}, {2.3038346126325147, 1.9896753472735356}, 
     {2.3038346126325147, 1.8849555921538759}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{2.199114857512855, 1.9896753472735356}, {2.199114857512855, \
2.0943951023931953}, {2.3038346126325147, 2.0943951023931953}, 
     {2.3038346126325147, 1.9896753472735356}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.199114857512855, 2.0943951023931953}, {2.199114857512855, \
2.199114857512855}, {2.3038346126325147, 2.199114857512855}, 
     {2.3038346126325147, 2.0943951023931953}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.199114857512855, 2.199114857512855}, {2.199114857512855, \
2.3038346126325147}, {2.3038346126325147, 2.3038346126325147}, 
     {2.3038346126325147, 2.199114857512855}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{2.199114857512855, 2.3038346126325147}, {2.199114857512855, \
2.4085543677521746}, {2.3038346126325147, 2.4085543677521746}, 
     {2.3038346126325147, 2.3038346126325147}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{2.199114857512855, 2.4085543677521746}, {2.199114857512855, \
2.5132741228718345}, {2.3038346126325147, 2.5132741228718345}, 
     {2.3038346126325147, 2.4085543677521746}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{2.199114857512855, 2.5132741228718345}, {2.199114857512855, \
2.617993877991494}, {2.3038346126325147, 2.617993877991494}, 
     {2.3038346126325147, 2.5132741228718345}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{2.199114857512855, 2.617993877991494}, {2.199114857512855, \
2.722713633111154}, {2.3038346126325147, 2.722713633111154}, 
     {2.3038346126325147, 2.617993877991494}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{2.199114857512855, 2.722713633111154}, {2.199114857512855, \
2.827433388230814}, {2.3038346126325147, 2.827433388230814}, 
     {2.3038346126325147, 2.722713633111154}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{2.199114857512855, 2.827433388230814}, {2.199114857512855, \
2.9321531433504733}, {2.3038346126325147, 2.9321531433504733}, 
     {2.3038346126325147, 2.827433388230814}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{2.199114857512855, 2.9321531433504733}, {2.199114857512855, \
3.036872898470133}, {2.3038346126325147, 3.036872898470133}, 
     {2.3038346126325147, 2.9321531433504733}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{2.199114857512855, 3.036872898470133}, {2.199114857512855, \
3.141592653589793}, {2.3038346126325147, 3.141592653589793}, 
     {2.3038346126325147, 3.036872898470133}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{2.199114857512855, 3.141592653589793}, {2.199114857512855, \
3.2463124087094526}, {2.3038346126325147, 3.2463124087094526}, 
     {2.3038346126325147, 3.141592653589793}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{2.199114857512855, 3.2463124087094526}, {2.199114857512855, \
3.3510321638291125}, {2.3038346126325147, 3.3510321638291125}, 
     {2.3038346126325147, 3.2463124087094526}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{2.199114857512855, 3.3510321638291125}, {2.199114857512855, \
3.4557519189487724}, {2.3038346126325147, 3.4557519189487724}, 
     {2.3038346126325147, 3.3510321638291125}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{2.199114857512855, 3.4557519189487724}, {2.199114857512855, \
3.560471674068432}, {2.3038346126325147, 3.560471674068432}, 
     {2.3038346126325147, 3.4557519189487724}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{2.199114857512855, 3.560471674068432}, {2.199114857512855, \
3.665191429188092}, {2.3038346126325147, 3.665191429188092}, 
     {2.3038346126325147, 3.560471674068432}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{2.199114857512855, 3.665191429188092}, {2.199114857512855, \
3.7699111843077517}, {2.3038346126325147, 3.7699111843077517}, 
     {2.3038346126325147, 3.665191429188092}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{2.199114857512855, 3.7699111843077517}, {2.199114857512855, \
3.874630939427411}, {2.3038346126325147, 3.874630939427411}, 
     {2.3038346126325147, 3.7699111843077517}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{2.199114857512855, 3.874630939427411}, {2.199114857512855, \
3.979350694547071}, {2.3038346126325147, 3.979350694547071}, 
     {2.3038346126325147, 3.874630939427411}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{2.199114857512855, 3.979350694547071}, {2.199114857512855, \
4.084070449666731}, {2.3038346126325147, 4.084070449666731}, 
     {2.3038346126325147, 3.979350694547071}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.199114857512855, 4.084070449666731}, {2.199114857512855, \
4.1887902047863905}, {2.3038346126325147, 4.1887902047863905}, 
     {2.3038346126325147, 4.084070449666731}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{2.199114857512855, 4.1887902047863905}, {2.199114857512855, \
4.29350995990605}, {2.3038346126325147, 4.29350995990605}, 
     {2.3038346126325147, 4.1887902047863905}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.199114857512855, 4.29350995990605}, {2.199114857512855, \
4.39822971502571}, {2.3038346126325147, 4.39822971502571}, 
     {2.3038346126325147, 4.29350995990605}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{2.199114857512855, 4.39822971502571}, {2.199114857512855, \
4.50294947014537}, {2.3038346126325147, 4.50294947014537}, 
     {2.3038346126325147, 4.39822971502571}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{2.199114857512855, 4.50294947014537}, {2.199114857512855, \
4.607669225265029}, {2.3038346126325147, 4.607669225265029}, 
     {2.3038346126325147, 4.50294947014537}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{2.199114857512855, 4.607669225265029}, {2.199114857512855, \
4.71238898038469}, {2.3038346126325147, 4.71238898038469}, 
     {2.3038346126325147, 4.607669225265029}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{2.199114857512855, 4.71238898038469}, {2.199114857512855, \
4.817108735504349}, {2.3038346126325147, 4.817108735504349}, 
     {2.3038346126325147, 4.71238898038469}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.775, 0.1], 
   Polygon[{{2.199114857512855, 4.817108735504349}, {2.199114857512855, \
4.921828490624009}, {2.3038346126325147, 4.921828490624009}, 
     {2.3038346126325147, 4.817108735504349}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{2.199114857512855, 4.921828490624009}, {2.199114857512855, \
5.026548245743669}, {2.3038346126325147, 5.026548245743669}, 
     {2.3038346126325147, 4.921828490624009}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{2.199114857512855, 5.026548245743669}, {2.199114857512855, \
5.1312680008633285}, {2.3038346126325147, 5.1312680008633285}, 
     {2.3038346126325147, 5.026548245743669}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{2.199114857512855, 5.1312680008633285}, {2.199114857512855, \
5.235987755982988}, {2.3038346126325147, 5.235987755982988}, 
     {2.3038346126325147, 5.1312680008633285}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.199114857512855, 5.235987755982988}, {2.199114857512855, \
5.340707511102648}, {2.3038346126325147, 5.340707511102648}, 
     {2.3038346126325147, 5.235987755982988}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.199114857512855, 5.340707511102648}, {2.199114857512855, \
5.445427266222308}, {2.3038346126325147, 5.445427266222308}, 
     {2.3038346126325147, 5.340707511102648}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{2.199114857512855, 5.445427266222308}, {2.199114857512855, \
5.550147021341967}, {2.3038346126325147, 5.550147021341967}, 
     {2.3038346126325147, 5.445427266222308}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{2.199114857512855, 5.550147021341967}, {2.199114857512855, \
5.654866776461628}, {2.3038346126325147, 5.654866776461628}, 
     {2.3038346126325147, 5.550147021341967}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{2.199114857512855, 5.654866776461628}, {2.199114857512855, \
5.759586531581287}, {2.3038346126325147, 5.759586531581287}, 
     {2.3038346126325147, 5.654866776461628}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{2.199114857512855, 5.759586531581287}, {2.199114857512855, \
5.864306286700947}, {2.3038346126325147, 5.864306286700947}, 
     {2.3038346126325147, 5.759586531581287}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{2.199114857512855, 5.864306286700947}, {2.199114857512855, \
5.969026041820607}, {2.3038346126325147, 5.969026041820607}, 
     {2.3038346126325147, 5.864306286700947}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{2.199114857512855, 5.969026041820607}, {2.199114857512855, \
6.073745796940266}, {2.3038346126325147, 6.073745796940266}, 
     {2.3038346126325147, 5.969026041820607}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{2.199114857512855, 6.073745796940266}, {2.199114857512855, \
6.178465552059926}, {2.3038346126325147, 6.178465552059926}, 
     {2.3038346126325147, 6.073745796940266}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{2.199114857512855, 6.178465552059926}, {2.199114857512855, \
6.283185307179586}, {2.3038346126325147, 6.283185307179586}, 
     {2.3038346126325147, 6.178465552059926}}]}, {CMYKColor[0.75, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 0.}, {2.3038346126325147, \
0.10471975511965977}, {2.4085543677521746, 0.10471975511965977}, 
     {2.4085543677521746, 0.}}]}, {CMYKColor[0.75, 0.5, 0.025, 0.1], 
   Polygon[{{2.3038346126325147, 0.10471975511965977}, {2.3038346126325147, \
0.20943951023931953}, {2.4085543677521746, 0.20943951023931953}, 
     {2.4085543677521746, 0.10471975511965977}}]}, {CMYKColor[0.75, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{2.3038346126325147, 0.20943951023931953}, {2.3038346126325147, \
0.3141592653589793}, {2.4085543677521746, 0.3141592653589793}, 
     {2.4085543677521746, 0.20943951023931953}}]}, {CMYKColor[0.75, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{2.3038346126325147, 0.3141592653589793}, {2.3038346126325147, \
0.41887902047863906}, {2.4085543677521746, 0.41887902047863906}, 
     {2.4085543677521746, 0.3141592653589793}}]}, {CMYKColor[0.75, 0.5, \
0.075, 0.1], 
   Polygon[{{2.3038346126325147, 0.41887902047863906}, {2.3038346126325147, \
0.5235987755982988}, {2.4085543677521746, 0.5235987755982988}, 
     {2.4085543677521746, 0.41887902047863906}}]}, {CMYKColor[0.75, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{2.3038346126325147, 0.5235987755982988}, {2.3038346126325147, \
0.6283185307179586}, {2.4085543677521746, 0.6283185307179586}, 
     {2.4085543677521746, 0.5235987755982988}}]}, {CMYKColor[0.75, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{2.3038346126325147, 0.6283185307179586}, {2.3038346126325147, \
0.7330382858376183}, {2.4085543677521746, 0.7330382858376183}, 
     {2.4085543677521746, 0.6283185307179586}}]}, {CMYKColor[0.75, 0.5, \
0.125, 0.1], 
   Polygon[{{2.3038346126325147, 0.7330382858376183}, {2.3038346126325147, \
0.8377580409572781}, {2.4085543677521746, 0.8377580409572781}, 
     {2.4085543677521746, 0.7330382858376183}}]}, {CMYKColor[0.75, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{2.3038346126325147, 0.8377580409572781}, {2.3038346126325147, \
0.9424777960769379}, {2.4085543677521746, 0.9424777960769379}, 
     {2.4085543677521746, 0.8377580409572781}}]}, {CMYKColor[0.75, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 0.9424777960769379}, {2.3038346126325147, \
1.0471975511965976}, {2.4085543677521746, 1.0471975511965976}, 
     {2.4085543677521746, 0.9424777960769379}}]}, {CMYKColor[0.75, 0.5, \
0.175, 0.1], 
   Polygon[{{2.3038346126325147, 1.0471975511965976}, {2.3038346126325147, \
1.1519173063162573}, {2.4085543677521746, 1.1519173063162573}, 
     {2.4085543677521746, 1.0471975511965976}}]}, {CMYKColor[0.75, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{2.3038346126325147, 1.1519173063162573}, {2.3038346126325147, \
1.2566370614359172}, {2.4085543677521746, 1.2566370614359172}, 
     {2.4085543677521746, 1.1519173063162573}}]}, {CMYKColor[0.75, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{2.3038346126325147, 1.2566370614359172}, {2.3038346126325147, \
1.361356816555577}, {2.4085543677521746, 1.361356816555577}, 
     {2.4085543677521746, 1.2566370614359172}}]}, {CMYKColor[0.75, 0.5, \
0.225, 0.1], 
   Polygon[{{2.3038346126325147, 1.361356816555577}, {2.3038346126325147, \
1.4660765716752366}, {2.4085543677521746, 1.4660765716752366}, 
     {2.4085543677521746, 1.361356816555577}}]}, {CMYKColor[0.75, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{2.3038346126325147, 1.4660765716752366}, {2.3038346126325147, \
1.5707963267948966}, {2.4085543677521746, 1.5707963267948966}, 
     {2.4085543677521746, 1.4660765716752366}}]}, {CMYKColor[0.75, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 1.5707963267948966}, {2.3038346126325147, \
1.6755160819145563}, {2.4085543677521746, 1.6755160819145563}, 
     {2.4085543677521746, 1.5707963267948966}}]}, {CMYKColor[0.75, 0.5, \
0.275, 0.1], 
   Polygon[{{2.3038346126325147, 1.6755160819145563}, {2.3038346126325147, \
1.780235837034216}, {2.4085543677521746, 1.780235837034216}, 
     {2.4085543677521746, 1.6755160819145563}}]}, {CMYKColor[0.75, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{2.3038346126325147, 1.780235837034216}, {2.3038346126325147, \
1.8849555921538759}, {2.4085543677521746, 1.8849555921538759}, 
     {2.4085543677521746, 1.780235837034216}}]}, {CMYKColor[0.75, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{2.3038346126325147, 1.8849555921538759}, {2.3038346126325147, \
1.9896753472735356}, {2.4085543677521746, 1.9896753472735356}, 
     {2.4085543677521746, 1.8849555921538759}}]}, {CMYKColor[0.75, 0.5, \
0.325, 0.1], 
   Polygon[{{2.3038346126325147, 1.9896753472735356}, {2.3038346126325147, \
2.0943951023931953}, {2.4085543677521746, 2.0943951023931953}, 
     {2.4085543677521746, 1.9896753472735356}}]}, {CMYKColor[0.75, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{2.3038346126325147, 2.0943951023931953}, {2.3038346126325147, \
2.199114857512855}, {2.4085543677521746, 2.199114857512855}, 
     {2.4085543677521746, 2.0943951023931953}}]}, {CMYKColor[0.75, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{2.3038346126325147, 2.199114857512855}, {2.3038346126325147, \
2.3038346126325147}, {2.4085543677521746, 2.3038346126325147}, 
     {2.4085543677521746, 2.199114857512855}}]}, {CMYKColor[0.75, 0.5, 0.375, \
0.1], 
   Polygon[{{2.3038346126325147, 2.3038346126325147}, {2.3038346126325147, \
2.4085543677521746}, {2.4085543677521746, 2.4085543677521746}, 
     {2.4085543677521746, 2.3038346126325147}}]}, {CMYKColor[0.75, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{2.3038346126325147, 2.4085543677521746}, {2.3038346126325147, \
2.5132741228718345}, {2.4085543677521746, 2.5132741228718345}, 
     {2.4085543677521746, 2.4085543677521746}}]}, {CMYKColor[0.75, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 2.5132741228718345}, {2.3038346126325147, \
2.617993877991494}, {2.4085543677521746, 2.617993877991494}, 
     {2.4085543677521746, 2.5132741228718345}}]}, {CMYKColor[0.75, 0.5, \
0.425, 0.1], 
   Polygon[{{2.3038346126325147, 2.617993877991494}, {2.3038346126325147, \
2.722713633111154}, {2.4085543677521746, 2.722713633111154}, 
     {2.4085543677521746, 2.617993877991494}}]}, {CMYKColor[0.75, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{2.3038346126325147, 2.722713633111154}, {2.3038346126325147, \
2.827433388230814}, {2.4085543677521746, 2.827433388230814}, 
     {2.4085543677521746, 2.722713633111154}}]}, {CMYKColor[0.75, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 2.827433388230814}, {2.3038346126325147, \
2.9321531433504733}, {2.4085543677521746, 2.9321531433504733}, 
     {2.4085543677521746, 2.827433388230814}}]}, {CMYKColor[0.75, 0.5, 0.475, \
0.1], 
   Polygon[{{2.3038346126325147, 2.9321531433504733}, {2.3038346126325147, \
3.036872898470133}, {2.4085543677521746, 3.036872898470133}, 
     {2.4085543677521746, 2.9321531433504733}}]}, {CMYKColor[0.75, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{2.3038346126325147, 3.036872898470133}, {2.3038346126325147, \
3.141592653589793}, {2.4085543677521746, 3.141592653589793}, 
     {2.4085543677521746, 3.036872898470133}}]}, {CMYKColor[0.75, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 3.141592653589793}, {2.3038346126325147, \
3.2463124087094526}, {2.4085543677521746, 3.2463124087094526}, 
     {2.4085543677521746, 3.141592653589793}}]}, {CMYKColor[0.75, 0.5, 0.525, \
0.1], 
   Polygon[{{2.3038346126325147, 3.2463124087094526}, {2.3038346126325147, \
3.3510321638291125}, {2.4085543677521746, 3.3510321638291125}, 
     {2.4085543677521746, 3.2463124087094526}}]}, {CMYKColor[0.75, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{2.3038346126325147, 3.3510321638291125}, {2.3038346126325147, \
3.4557519189487724}, {2.4085543677521746, 3.4557519189487724}, 
     {2.4085543677521746, 3.3510321638291125}}]}, {CMYKColor[0.75, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 3.4557519189487724}, {2.3038346126325147, \
3.560471674068432}, {2.4085543677521746, 3.560471674068432}, 
     {2.4085543677521746, 3.4557519189487724}}]}, {CMYKColor[0.75, 0.5, \
0.575, 0.1], 
   Polygon[{{2.3038346126325147, 3.560471674068432}, {2.3038346126325147, \
3.665191429188092}, {2.4085543677521746, 3.665191429188092}, 
     {2.4085543677521746, 3.560471674068432}}]}, {CMYKColor[0.75, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{2.3038346126325147, 3.665191429188092}, {2.3038346126325147, \
3.7699111843077517}, {2.4085543677521746, 3.7699111843077517}, 
     {2.4085543677521746, 3.665191429188092}}]}, {CMYKColor[0.75, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 3.7699111843077517}, {2.3038346126325147, \
3.874630939427411}, {2.4085543677521746, 3.874630939427411}, 
     {2.4085543677521746, 3.7699111843077517}}]}, {CMYKColor[0.75, 0.5, \
0.625, 0.1], 
   Polygon[{{2.3038346126325147, 3.874630939427411}, {2.3038346126325147, \
3.979350694547071}, {2.4085543677521746, 3.979350694547071}, 
     {2.4085543677521746, 3.874630939427411}}]}, {CMYKColor[0.75, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{2.3038346126325147, 3.979350694547071}, {2.3038346126325147, \
4.084070449666731}, {2.4085543677521746, 4.084070449666731}, 
     {2.4085543677521746, 3.979350694547071}}]}, {CMYKColor[0.75, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 4.084070449666731}, {2.3038346126325147, \
4.1887902047863905}, {2.4085543677521746, 4.1887902047863905}, 
     {2.4085543677521746, 4.084070449666731}}]}, {CMYKColor[0.75, 0.5, 0.675, \
0.1], 
   Polygon[{{2.3038346126325147, 4.1887902047863905}, {2.3038346126325147, \
4.29350995990605}, {2.4085543677521746, 4.29350995990605}, 
     {2.4085543677521746, 4.1887902047863905}}]}, {CMYKColor[0.75, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{2.3038346126325147, 4.29350995990605}, {2.3038346126325147, \
4.39822971502571}, {2.4085543677521746, 4.39822971502571}, 
     {2.4085543677521746, 4.29350995990605}}]}, {CMYKColor[0.75, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{2.3038346126325147, 4.39822971502571}, {2.3038346126325147, \
4.50294947014537}, {2.4085543677521746, 4.50294947014537}, 
     {2.4085543677521746, 4.39822971502571}}]}, {CMYKColor[0.75, 0.5, 0.725, \
0.1], 
   Polygon[{{2.3038346126325147, 4.50294947014537}, {2.3038346126325147, \
4.607669225265029}, {2.4085543677521746, 4.607669225265029}, 
     {2.4085543677521746, 4.50294947014537}}]}, {CMYKColor[0.75, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{2.3038346126325147, 4.607669225265029}, {2.3038346126325147, \
4.71238898038469}, {2.4085543677521746, 4.71238898038469}, 
     {2.4085543677521746, 4.607669225265029}}]}, {CMYKColor[0.75, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 4.71238898038469}, {2.3038346126325147, \
4.817108735504349}, {2.4085543677521746, 4.817108735504349}, 
     {2.4085543677521746, 4.71238898038469}}]}, {CMYKColor[0.75, 0.5, 0.775, \
0.1], 
   Polygon[{{2.3038346126325147, 4.817108735504349}, {2.3038346126325147, \
4.921828490624009}, {2.4085543677521746, 4.921828490624009}, 
     {2.4085543677521746, 4.817108735504349}}]}, {CMYKColor[0.75, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{2.3038346126325147, 4.921828490624009}, {2.3038346126325147, \
5.026548245743669}, {2.4085543677521746, 5.026548245743669}, 
     {2.4085543677521746, 4.921828490624009}}]}, {CMYKColor[0.75, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 5.026548245743669}, {2.3038346126325147, \
5.1312680008633285}, {2.4085543677521746, 5.1312680008633285}, 
     {2.4085543677521746, 5.026548245743669}}]}, {CMYKColor[0.75, 0.5, 0.825, \
0.1], 
   Polygon[{{2.3038346126325147, 5.1312680008633285}, {2.3038346126325147, \
5.235987755982988}, {2.4085543677521746, 5.235987755982988}, 
     {2.4085543677521746, 5.1312680008633285}}]}, {CMYKColor[0.75, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{2.3038346126325147, 5.235987755982988}, {2.3038346126325147, \
5.340707511102648}, {2.4085543677521746, 5.340707511102648}, 
     {2.4085543677521746, 5.235987755982988}}]}, {CMYKColor[0.75, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 5.340707511102648}, {2.3038346126325147, \
5.445427266222308}, {2.4085543677521746, 5.445427266222308}, 
     {2.4085543677521746, 5.340707511102648}}]}, {CMYKColor[0.75, 0.5, 0.875, \
0.1], 
   Polygon[{{2.3038346126325147, 5.445427266222308}, {2.3038346126325147, \
5.550147021341967}, {2.4085543677521746, 5.550147021341967}, 
     {2.4085543677521746, 5.445427266222308}}]}, {CMYKColor[0.75, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{2.3038346126325147, 5.550147021341967}, {2.3038346126325147, \
5.654866776461628}, {2.4085543677521746, 5.654866776461628}, 
     {2.4085543677521746, 5.550147021341967}}]}, {CMYKColor[0.75, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{2.3038346126325147, 5.654866776461628}, {2.3038346126325147, \
5.759586531581287}, {2.4085543677521746, 5.759586531581287}, 
     {2.4085543677521746, 5.654866776461628}}]}, {CMYKColor[0.75, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{2.3038346126325147, 5.759586531581287}, {2.3038346126325147, \
5.864306286700947}, {2.4085543677521746, 5.864306286700947}, 
     {2.4085543677521746, 5.759586531581287}}]}, {CMYKColor[0.75, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{2.3038346126325147, 5.864306286700947}, {2.3038346126325147, \
5.969026041820607}, {2.4085543677521746, 5.969026041820607}, 
     {2.4085543677521746, 5.864306286700947}}]}, {CMYKColor[0.75, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{2.3038346126325147, 5.969026041820607}, {2.3038346126325147, \
6.073745796940266}, {2.4085543677521746, 6.073745796940266}, 
     {2.4085543677521746, 5.969026041820607}}]}, {CMYKColor[0.75, 0.5, 0.975, \
0.1], 
   Polygon[{{2.3038346126325147, 6.073745796940266}, {2.3038346126325147, \
6.178465552059926}, {2.4085543677521746, 6.178465552059926}, 
     {2.4085543677521746, 6.073745796940266}}]}, {CMYKColor[0.75, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{2.3038346126325147, 6.178465552059926}, {2.3038346126325147, \
6.283185307179586}, {2.4085543677521746, 6.283185307179586}, 
     {2.4085543677521746, 6.178465552059926}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 0.}, {2.4085543677521746, \
0.10471975511965977}, {2.5132741228718345, 0.10471975511965977}, 
     {2.5132741228718345, 0.}}]}, {CMYKColor[0.7833333333333333, 0.5, 0.025, \
0.1], 
   Polygon[{{2.4085543677521746, 0.10471975511965977}, {2.4085543677521746, \
0.20943951023931953}, {2.5132741228718345, 0.20943951023931953}, 
     {2.5132741228718345, 0.10471975511965977}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{2.4085543677521746, 0.20943951023931953}, {2.4085543677521746, \
0.3141592653589793}, {2.5132741228718345, 0.3141592653589793}, 
     {2.5132741228718345, 0.20943951023931953}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{2.4085543677521746, 0.3141592653589793}, {2.4085543677521746, \
0.41887902047863906}, {2.5132741228718345, 0.41887902047863906}, 
     {2.5132741228718345, 0.3141592653589793}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{2.4085543677521746, 0.41887902047863906}, {2.4085543677521746, \
0.5235987755982988}, {2.5132741228718345, 0.5235987755982988}, 
     {2.5132741228718345, 0.41887902047863906}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{2.4085543677521746, 0.5235987755982988}, {2.4085543677521746, \
0.6283185307179586}, {2.5132741228718345, 0.6283185307179586}, 
     {2.5132741228718345, 0.5235987755982988}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{2.4085543677521746, 0.6283185307179586}, {2.4085543677521746, \
0.7330382858376183}, {2.5132741228718345, 0.7330382858376183}, 
     {2.5132741228718345, 0.6283185307179586}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{2.4085543677521746, 0.7330382858376183}, {2.4085543677521746, \
0.8377580409572781}, {2.5132741228718345, 0.8377580409572781}, 
     {2.5132741228718345, 0.7330382858376183}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{2.4085543677521746, 0.8377580409572781}, {2.4085543677521746, \
0.9424777960769379}, {2.5132741228718345, 0.9424777960769379}, 
     {2.5132741228718345, 0.8377580409572781}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 0.9424777960769379}, {2.4085543677521746, \
1.0471975511965976}, {2.5132741228718345, 1.0471975511965976}, 
     {2.5132741228718345, 0.9424777960769379}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{2.4085543677521746, 1.0471975511965976}, {2.4085543677521746, \
1.1519173063162573}, {2.5132741228718345, 1.1519173063162573}, 
     {2.5132741228718345, 1.0471975511965976}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{2.4085543677521746, 1.1519173063162573}, {2.4085543677521746, \
1.2566370614359172}, {2.5132741228718345, 1.2566370614359172}, 
     {2.5132741228718345, 1.1519173063162573}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{2.4085543677521746, 1.2566370614359172}, {2.4085543677521746, \
1.361356816555577}, {2.5132741228718345, 1.361356816555577}, 
     {2.5132741228718345, 1.2566370614359172}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{2.4085543677521746, 1.361356816555577}, {2.4085543677521746, \
1.4660765716752366}, {2.5132741228718345, 1.4660765716752366}, 
     {2.5132741228718345, 1.361356816555577}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{2.4085543677521746, 1.4660765716752366}, {2.4085543677521746, \
1.5707963267948966}, {2.5132741228718345, 1.5707963267948966}, 
     {2.5132741228718345, 1.4660765716752366}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 1.5707963267948966}, {2.4085543677521746, \
1.6755160819145563}, {2.5132741228718345, 1.6755160819145563}, 
     {2.5132741228718345, 1.5707963267948966}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{2.4085543677521746, 1.6755160819145563}, {2.4085543677521746, \
1.780235837034216}, {2.5132741228718345, 1.780235837034216}, 
     {2.5132741228718345, 1.6755160819145563}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{2.4085543677521746, 1.780235837034216}, {2.4085543677521746, \
1.8849555921538759}, {2.5132741228718345, 1.8849555921538759}, 
     {2.5132741228718345, 1.780235837034216}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{2.4085543677521746, 1.8849555921538759}, {2.4085543677521746, \
1.9896753472735356}, {2.5132741228718345, 1.9896753472735356}, 
     {2.5132741228718345, 1.8849555921538759}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{2.4085543677521746, 1.9896753472735356}, {2.4085543677521746, \
2.0943951023931953}, {2.5132741228718345, 2.0943951023931953}, 
     {2.5132741228718345, 1.9896753472735356}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.4085543677521746, 2.0943951023931953}, {2.4085543677521746, \
2.199114857512855}, {2.5132741228718345, 2.199114857512855}, 
     {2.5132741228718345, 2.0943951023931953}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.4085543677521746, 2.199114857512855}, {2.4085543677521746, \
2.3038346126325147}, {2.5132741228718345, 2.3038346126325147}, 
     {2.5132741228718345, 2.199114857512855}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{2.4085543677521746, 2.3038346126325147}, {2.4085543677521746, \
2.4085543677521746}, {2.5132741228718345, 2.4085543677521746}, 
     {2.5132741228718345, 2.3038346126325147}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{2.4085543677521746, 2.4085543677521746}, {2.4085543677521746, \
2.5132741228718345}, {2.5132741228718345, 2.5132741228718345}, 
     {2.5132741228718345, 2.4085543677521746}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 2.5132741228718345}, {2.4085543677521746, \
2.617993877991494}, {2.5132741228718345, 2.617993877991494}, 
     {2.5132741228718345, 2.5132741228718345}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{2.4085543677521746, 2.617993877991494}, {2.4085543677521746, \
2.722713633111154}, {2.5132741228718345, 2.722713633111154}, 
     {2.5132741228718345, 2.617993877991494}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{2.4085543677521746, 2.722713633111154}, {2.4085543677521746, \
2.827433388230814}, {2.5132741228718345, 2.827433388230814}, 
     {2.5132741228718345, 2.722713633111154}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 2.827433388230814}, {2.4085543677521746, \
2.9321531433504733}, {2.5132741228718345, 2.9321531433504733}, 
     {2.5132741228718345, 2.827433388230814}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{2.4085543677521746, 2.9321531433504733}, {2.4085543677521746, \
3.036872898470133}, {2.5132741228718345, 3.036872898470133}, 
     {2.5132741228718345, 2.9321531433504733}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{2.4085543677521746, 3.036872898470133}, {2.4085543677521746, \
3.141592653589793}, {2.5132741228718345, 3.141592653589793}, 
     {2.5132741228718345, 3.036872898470133}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 3.141592653589793}, {2.4085543677521746, \
3.2463124087094526}, {2.5132741228718345, 3.2463124087094526}, 
     {2.5132741228718345, 3.141592653589793}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{2.4085543677521746, 3.2463124087094526}, {2.4085543677521746, \
3.3510321638291125}, {2.5132741228718345, 3.3510321638291125}, 
     {2.5132741228718345, 3.2463124087094526}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{2.4085543677521746, 3.3510321638291125}, {2.4085543677521746, \
3.4557519189487724}, {2.5132741228718345, 3.4557519189487724}, 
     {2.5132741228718345, 3.3510321638291125}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 3.4557519189487724}, {2.4085543677521746, \
3.560471674068432}, {2.5132741228718345, 3.560471674068432}, 
     {2.5132741228718345, 3.4557519189487724}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{2.4085543677521746, 3.560471674068432}, {2.4085543677521746, \
3.665191429188092}, {2.5132741228718345, 3.665191429188092}, 
     {2.5132741228718345, 3.560471674068432}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{2.4085543677521746, 3.665191429188092}, {2.4085543677521746, \
3.7699111843077517}, {2.5132741228718345, 3.7699111843077517}, 
     {2.5132741228718345, 3.665191429188092}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 3.7699111843077517}, {2.4085543677521746, \
3.874630939427411}, {2.5132741228718345, 3.874630939427411}, 
     {2.5132741228718345, 3.7699111843077517}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{2.4085543677521746, 3.874630939427411}, {2.4085543677521746, \
3.979350694547071}, {2.5132741228718345, 3.979350694547071}, 
     {2.5132741228718345, 3.874630939427411}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{2.4085543677521746, 3.979350694547071}, {2.4085543677521746, \
4.084070449666731}, {2.5132741228718345, 4.084070449666731}, 
     {2.5132741228718345, 3.979350694547071}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 4.084070449666731}, {2.4085543677521746, \
4.1887902047863905}, {2.5132741228718345, 4.1887902047863905}, 
     {2.5132741228718345, 4.084070449666731}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{2.4085543677521746, 4.1887902047863905}, {2.4085543677521746, \
4.29350995990605}, {2.5132741228718345, 4.29350995990605}, 
     {2.5132741228718345, 4.1887902047863905}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.4085543677521746, 4.29350995990605}, {2.4085543677521746, \
4.39822971502571}, {2.5132741228718345, 4.39822971502571}, 
     {2.5132741228718345, 4.29350995990605}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{2.4085543677521746, 4.39822971502571}, {2.4085543677521746, \
4.50294947014537}, {2.5132741228718345, 4.50294947014537}, 
     {2.5132741228718345, 4.39822971502571}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{2.4085543677521746, 4.50294947014537}, {2.4085543677521746, \
4.607669225265029}, {2.5132741228718345, 4.607669225265029}, 
     {2.5132741228718345, 4.50294947014537}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{2.4085543677521746, 4.607669225265029}, {2.4085543677521746, \
4.71238898038469}, {2.5132741228718345, 4.71238898038469}, 
     {2.5132741228718345, 4.607669225265029}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 4.71238898038469}, {2.4085543677521746, \
4.817108735504349}, {2.5132741228718345, 4.817108735504349}, 
     {2.5132741228718345, 4.71238898038469}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{2.4085543677521746, 4.817108735504349}, {2.4085543677521746, \
4.921828490624009}, {2.5132741228718345, 4.921828490624009}, 
     {2.5132741228718345, 4.817108735504349}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{2.4085543677521746, 4.921828490624009}, {2.4085543677521746, \
5.026548245743669}, {2.5132741228718345, 5.026548245743669}, 
     {2.5132741228718345, 4.921828490624009}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 5.026548245743669}, {2.4085543677521746, \
5.1312680008633285}, {2.5132741228718345, 5.1312680008633285}, 
     {2.5132741228718345, 5.026548245743669}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{2.4085543677521746, 5.1312680008633285}, {2.4085543677521746, \
5.235987755982988}, {2.5132741228718345, 5.235987755982988}, 
     {2.5132741228718345, 5.1312680008633285}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.4085543677521746, 5.235987755982988}, {2.4085543677521746, \
5.340707511102648}, {2.5132741228718345, 5.340707511102648}, 
     {2.5132741228718345, 5.235987755982988}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 5.340707511102648}, {2.4085543677521746, \
5.445427266222308}, {2.5132741228718345, 5.445427266222308}, 
     {2.5132741228718345, 5.340707511102648}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{2.4085543677521746, 5.445427266222308}, {2.4085543677521746, \
5.550147021341967}, {2.5132741228718345, 5.550147021341967}, 
     {2.5132741228718345, 5.445427266222308}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{2.4085543677521746, 5.550147021341967}, {2.4085543677521746, \
5.654866776461628}, {2.5132741228718345, 5.654866776461628}, 
     {2.5132741228718345, 5.550147021341967}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{2.4085543677521746, 5.654866776461628}, {2.4085543677521746, \
5.759586531581287}, {2.5132741228718345, 5.759586531581287}, 
     {2.5132741228718345, 5.654866776461628}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{2.4085543677521746, 5.759586531581287}, {2.4085543677521746, \
5.864306286700947}, {2.5132741228718345, 5.864306286700947}, 
     {2.5132741228718345, 5.759586531581287}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{2.4085543677521746, 5.864306286700947}, {2.4085543677521746, \
5.969026041820607}, {2.5132741228718345, 5.969026041820607}, 
     {2.5132741228718345, 5.864306286700947}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{2.4085543677521746, 5.969026041820607}, {2.4085543677521746, \
6.073745796940266}, {2.5132741228718345, 6.073745796940266}, 
     {2.5132741228718345, 5.969026041820607}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{2.4085543677521746, 6.073745796940266}, {2.4085543677521746, \
6.178465552059926}, {2.5132741228718345, 6.178465552059926}, 
     {2.5132741228718345, 6.073745796940266}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{2.4085543677521746, 6.178465552059926}, {2.4085543677521746, \
6.283185307179586}, {2.5132741228718345, 6.283185307179586}, 
     {2.5132741228718345, 6.178465552059926}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 0.}, {2.5132741228718345, \
0.10471975511965977}, {2.617993877991494, 0.10471975511965977}, 
     {2.617993877991494, 0.}}]}, {CMYKColor[0.8166666666666667, 0.5, 0.025, \
0.1], 
   Polygon[{{2.5132741228718345, 0.10471975511965977}, {2.5132741228718345, \
0.20943951023931953}, {2.617993877991494, 0.20943951023931953}, 
     {2.617993877991494, 0.10471975511965977}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{2.5132741228718345, 0.20943951023931953}, {2.5132741228718345, \
0.3141592653589793}, {2.617993877991494, 0.3141592653589793}, 
     {2.617993877991494, 0.20943951023931953}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{2.5132741228718345, 0.3141592653589793}, {2.5132741228718345, \
0.41887902047863906}, {2.617993877991494, 0.41887902047863906}, 
     {2.617993877991494, 0.3141592653589793}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{2.5132741228718345, 0.41887902047863906}, {2.5132741228718345, \
0.5235987755982988}, {2.617993877991494, 0.5235987755982988}, 
     {2.617993877991494, 0.41887902047863906}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{2.5132741228718345, 0.5235987755982988}, {2.5132741228718345, \
0.6283185307179586}, {2.617993877991494, 0.6283185307179586}, 
     {2.617993877991494, 0.5235987755982988}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{2.5132741228718345, 0.6283185307179586}, {2.5132741228718345, \
0.7330382858376183}, {2.617993877991494, 0.7330382858376183}, 
     {2.617993877991494, 0.6283185307179586}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{2.5132741228718345, 0.7330382858376183}, {2.5132741228718345, \
0.8377580409572781}, {2.617993877991494, 0.8377580409572781}, 
     {2.617993877991494, 0.7330382858376183}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{2.5132741228718345, 0.8377580409572781}, {2.5132741228718345, \
0.9424777960769379}, {2.617993877991494, 0.9424777960769379}, 
     {2.617993877991494, 0.8377580409572781}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 0.9424777960769379}, {2.5132741228718345, \
1.0471975511965976}, {2.617993877991494, 1.0471975511965976}, 
     {2.617993877991494, 0.9424777960769379}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{2.5132741228718345, 1.0471975511965976}, {2.5132741228718345, \
1.1519173063162573}, {2.617993877991494, 1.1519173063162573}, 
     {2.617993877991494, 1.0471975511965976}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{2.5132741228718345, 1.1519173063162573}, {2.5132741228718345, \
1.2566370614359172}, {2.617993877991494, 1.2566370614359172}, 
     {2.617993877991494, 1.1519173063162573}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{2.5132741228718345, 1.2566370614359172}, {2.5132741228718345, \
1.361356816555577}, {2.617993877991494, 1.361356816555577}, 
     {2.617993877991494, 1.2566370614359172}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{2.5132741228718345, 1.361356816555577}, {2.5132741228718345, \
1.4660765716752366}, {2.617993877991494, 1.4660765716752366}, 
     {2.617993877991494, 1.361356816555577}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{2.5132741228718345, 1.4660765716752366}, {2.5132741228718345, \
1.5707963267948966}, {2.617993877991494, 1.5707963267948966}, 
     {2.617993877991494, 1.4660765716752366}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 1.5707963267948966}, {2.5132741228718345, \
1.6755160819145563}, {2.617993877991494, 1.6755160819145563}, 
     {2.617993877991494, 1.5707963267948966}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{2.5132741228718345, 1.6755160819145563}, {2.5132741228718345, \
1.780235837034216}, {2.617993877991494, 1.780235837034216}, 
     {2.617993877991494, 1.6755160819145563}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{2.5132741228718345, 1.780235837034216}, {2.5132741228718345, \
1.8849555921538759}, {2.617993877991494, 1.8849555921538759}, 
     {2.617993877991494, 1.780235837034216}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{2.5132741228718345, 1.8849555921538759}, {2.5132741228718345, \
1.9896753472735356}, {2.617993877991494, 1.9896753472735356}, 
     {2.617993877991494, 1.8849555921538759}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{2.5132741228718345, 1.9896753472735356}, {2.5132741228718345, \
2.0943951023931953}, {2.617993877991494, 2.0943951023931953}, 
     {2.617993877991494, 1.9896753472735356}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.5132741228718345, 2.0943951023931953}, {2.5132741228718345, \
2.199114857512855}, {2.617993877991494, 2.199114857512855}, 
     {2.617993877991494, 2.0943951023931953}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.5132741228718345, 2.199114857512855}, {2.5132741228718345, \
2.3038346126325147}, {2.617993877991494, 2.3038346126325147}, 
     {2.617993877991494, 2.199114857512855}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{2.5132741228718345, 2.3038346126325147}, {2.5132741228718345, \
2.4085543677521746}, {2.617993877991494, 2.4085543677521746}, 
     {2.617993877991494, 2.3038346126325147}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{2.5132741228718345, 2.4085543677521746}, {2.5132741228718345, \
2.5132741228718345}, {2.617993877991494, 2.5132741228718345}, 
     {2.617993877991494, 2.4085543677521746}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 2.5132741228718345}, {2.5132741228718345, \
2.617993877991494}, {2.617993877991494, 2.617993877991494}, 
     {2.617993877991494, 2.5132741228718345}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{2.5132741228718345, 2.617993877991494}, {2.5132741228718345, \
2.722713633111154}, {2.617993877991494, 2.722713633111154}, 
     {2.617993877991494, 2.617993877991494}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{2.5132741228718345, 2.722713633111154}, {2.5132741228718345, \
2.827433388230814}, {2.617993877991494, 2.827433388230814}, 
     {2.617993877991494, 2.722713633111154}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 2.827433388230814}, {2.5132741228718345, \
2.9321531433504733}, {2.617993877991494, 2.9321531433504733}, 
     {2.617993877991494, 2.827433388230814}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{2.5132741228718345, 2.9321531433504733}, {2.5132741228718345, \
3.036872898470133}, {2.617993877991494, 3.036872898470133}, 
     {2.617993877991494, 2.9321531433504733}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{2.5132741228718345, 3.036872898470133}, {2.5132741228718345, \
3.141592653589793}, {2.617993877991494, 3.141592653589793}, 
     {2.617993877991494, 3.036872898470133}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 3.141592653589793}, {2.5132741228718345, \
3.2463124087094526}, {2.617993877991494, 3.2463124087094526}, 
     {2.617993877991494, 3.141592653589793}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{2.5132741228718345, 3.2463124087094526}, {2.5132741228718345, \
3.3510321638291125}, {2.617993877991494, 3.3510321638291125}, 
     {2.617993877991494, 3.2463124087094526}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{2.5132741228718345, 3.3510321638291125}, {2.5132741228718345, \
3.4557519189487724}, {2.617993877991494, 3.4557519189487724}, 
     {2.617993877991494, 3.3510321638291125}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 3.4557519189487724}, {2.5132741228718345, \
3.560471674068432}, {2.617993877991494, 3.560471674068432}, 
     {2.617993877991494, 3.4557519189487724}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{2.5132741228718345, 3.560471674068432}, {2.5132741228718345, \
3.665191429188092}, {2.617993877991494, 3.665191429188092}, 
     {2.617993877991494, 3.560471674068432}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{2.5132741228718345, 3.665191429188092}, {2.5132741228718345, \
3.7699111843077517}, {2.617993877991494, 3.7699111843077517}, 
     {2.617993877991494, 3.665191429188092}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 3.7699111843077517}, {2.5132741228718345, \
3.874630939427411}, {2.617993877991494, 3.874630939427411}, 
     {2.617993877991494, 3.7699111843077517}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{2.5132741228718345, 3.874630939427411}, {2.5132741228718345, \
3.979350694547071}, {2.617993877991494, 3.979350694547071}, 
     {2.617993877991494, 3.874630939427411}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{2.5132741228718345, 3.979350694547071}, {2.5132741228718345, \
4.084070449666731}, {2.617993877991494, 4.084070449666731}, 
     {2.617993877991494, 3.979350694547071}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 4.084070449666731}, {2.5132741228718345, \
4.1887902047863905}, {2.617993877991494, 4.1887902047863905}, 
     {2.617993877991494, 4.084070449666731}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{2.5132741228718345, 4.1887902047863905}, {2.5132741228718345, \
4.29350995990605}, {2.617993877991494, 4.29350995990605}, 
     {2.617993877991494, 4.1887902047863905}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.5132741228718345, 4.29350995990605}, {2.5132741228718345, \
4.39822971502571}, {2.617993877991494, 4.39822971502571}, 
     {2.617993877991494, 4.29350995990605}}]}, {CMYKColor[0.8166666666666667, \
0.5, 0.7083333333333334, 0.1], 
   Polygon[{{2.5132741228718345, 4.39822971502571}, {2.5132741228718345, \
4.50294947014537}, {2.617993877991494, 4.50294947014537}, 
     {2.617993877991494, 4.39822971502571}}]}, {CMYKColor[0.8166666666666667, \
0.5, 0.725, 0.1], 
   Polygon[{{2.5132741228718345, 4.50294947014537}, {2.5132741228718345, \
4.607669225265029}, {2.617993877991494, 4.607669225265029}, 
     {2.617993877991494, 4.50294947014537}}]}, {CMYKColor[0.8166666666666667, \
0.5, 0.7416666666666667, 0.1], 
   Polygon[{{2.5132741228718345, 4.607669225265029}, {2.5132741228718345, \
4.71238898038469}, {2.617993877991494, 4.71238898038469}, 
     {2.617993877991494, 4.607669225265029}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 4.71238898038469}, {2.5132741228718345, \
4.817108735504349}, {2.617993877991494, 4.817108735504349}, 
     {2.617993877991494, 4.71238898038469}}]}, {CMYKColor[0.8166666666666667, \
0.5, 0.775, 0.1], 
   Polygon[{{2.5132741228718345, 4.817108735504349}, {2.5132741228718345, \
4.921828490624009}, {2.617993877991494, 4.921828490624009}, 
     {2.617993877991494, 4.817108735504349}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{2.5132741228718345, 4.921828490624009}, {2.5132741228718345, \
5.026548245743669}, {2.617993877991494, 5.026548245743669}, 
     {2.617993877991494, 4.921828490624009}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 5.026548245743669}, {2.5132741228718345, \
5.1312680008633285}, {2.617993877991494, 5.1312680008633285}, 
     {2.617993877991494, 5.026548245743669}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{2.5132741228718345, 5.1312680008633285}, {2.5132741228718345, \
5.235987755982988}, {2.617993877991494, 5.235987755982988}, 
     {2.617993877991494, 5.1312680008633285}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.5132741228718345, 5.235987755982988}, {2.5132741228718345, \
5.340707511102648}, {2.617993877991494, 5.340707511102648}, 
     {2.617993877991494, 5.235987755982988}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 5.340707511102648}, {2.5132741228718345, \
5.445427266222308}, {2.617993877991494, 5.445427266222308}, 
     {2.617993877991494, 5.340707511102648}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{2.5132741228718345, 5.445427266222308}, {2.5132741228718345, \
5.550147021341967}, {2.617993877991494, 5.550147021341967}, 
     {2.617993877991494, 5.445427266222308}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{2.5132741228718345, 5.550147021341967}, {2.5132741228718345, \
5.654866776461628}, {2.617993877991494, 5.654866776461628}, 
     {2.617993877991494, 5.550147021341967}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{2.5132741228718345, 5.654866776461628}, {2.5132741228718345, \
5.759586531581287}, {2.617993877991494, 5.759586531581287}, 
     {2.617993877991494, 5.654866776461628}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{2.5132741228718345, 5.759586531581287}, {2.5132741228718345, \
5.864306286700947}, {2.617993877991494, 5.864306286700947}, 
     {2.617993877991494, 5.759586531581287}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{2.5132741228718345, 5.864306286700947}, {2.5132741228718345, \
5.969026041820607}, {2.617993877991494, 5.969026041820607}, 
     {2.617993877991494, 5.864306286700947}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{2.5132741228718345, 5.969026041820607}, {2.5132741228718345, \
6.073745796940266}, {2.617993877991494, 6.073745796940266}, 
     {2.617993877991494, 5.969026041820607}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{2.5132741228718345, 6.073745796940266}, {2.5132741228718345, \
6.178465552059926}, {2.617993877991494, 6.178465552059926}, 
     {2.617993877991494, 6.073745796940266}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{2.5132741228718345, 6.178465552059926}, {2.5132741228718345, \
6.283185307179586}, {2.617993877991494, 6.283185307179586}, 
     {2.617993877991494, 6.178465552059926}}]}, {CMYKColor[0.85, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{2.617993877991494, 0.}, {2.617993877991494, \
0.10471975511965977}, {2.722713633111154, 0.10471975511965977}, 
     {2.722713633111154, 0.}}]}, {CMYKColor[0.85, 0.5, 0.025, 0.1], 
   Polygon[{{2.617993877991494, 0.10471975511965977}, {2.617993877991494, \
0.20943951023931953}, {2.722713633111154, 0.20943951023931953}, 
     {2.722713633111154, 0.10471975511965977}}]}, {CMYKColor[0.85, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{2.617993877991494, 0.20943951023931953}, {2.617993877991494, \
0.3141592653589793}, {2.722713633111154, 0.3141592653589793}, 
     {2.722713633111154, 0.20943951023931953}}]}, {CMYKColor[0.85, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{2.617993877991494, 0.3141592653589793}, {2.617993877991494, \
0.41887902047863906}, {2.722713633111154, 0.41887902047863906}, 
     {2.722713633111154, 0.3141592653589793}}]}, {CMYKColor[0.85, 0.5, 0.075, \
0.1], 
   Polygon[{{2.617993877991494, 0.41887902047863906}, {2.617993877991494, \
0.5235987755982988}, {2.722713633111154, 0.5235987755982988}, 
     {2.722713633111154, 0.41887902047863906}}]}, {CMYKColor[0.85, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{2.617993877991494, 0.5235987755982988}, {2.617993877991494, \
0.6283185307179586}, {2.722713633111154, 0.6283185307179586}, 
     {2.722713633111154, 0.5235987755982988}}]}, {CMYKColor[0.85, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{2.617993877991494, 0.6283185307179586}, {2.617993877991494, \
0.7330382858376183}, {2.722713633111154, 0.7330382858376183}, 
     {2.722713633111154, 0.6283185307179586}}]}, {CMYKColor[0.85, 0.5, 0.125, \
0.1], 
   Polygon[{{2.617993877991494, 0.7330382858376183}, {2.617993877991494, \
0.8377580409572781}, {2.722713633111154, 0.8377580409572781}, 
     {2.722713633111154, 0.7330382858376183}}]}, {CMYKColor[0.85, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{2.617993877991494, 0.8377580409572781}, {2.617993877991494, \
0.9424777960769379}, {2.722713633111154, 0.9424777960769379}, 
     {2.722713633111154, 0.8377580409572781}}]}, {CMYKColor[0.85, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{2.617993877991494, 0.9424777960769379}, {2.617993877991494, \
1.0471975511965976}, {2.722713633111154, 1.0471975511965976}, 
     {2.722713633111154, 0.9424777960769379}}]}, {CMYKColor[0.85, 0.5, 0.175, \
0.1], 
   Polygon[{{2.617993877991494, 1.0471975511965976}, {2.617993877991494, \
1.1519173063162573}, {2.722713633111154, 1.1519173063162573}, 
     {2.722713633111154, 1.0471975511965976}}]}, {CMYKColor[0.85, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{2.617993877991494, 1.1519173063162573}, {2.617993877991494, \
1.2566370614359172}, {2.722713633111154, 1.2566370614359172}, 
     {2.722713633111154, 1.1519173063162573}}]}, {CMYKColor[0.85, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{2.617993877991494, 1.2566370614359172}, {2.617993877991494, \
1.361356816555577}, {2.722713633111154, 1.361356816555577}, 
     {2.722713633111154, 1.2566370614359172}}]}, {CMYKColor[0.85, 0.5, 0.225, \
0.1], 
   Polygon[{{2.617993877991494, 1.361356816555577}, {2.617993877991494, \
1.4660765716752366}, {2.722713633111154, 1.4660765716752366}, 
     {2.722713633111154, 1.361356816555577}}]}, {CMYKColor[0.85, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{2.617993877991494, 1.4660765716752366}, {2.617993877991494, \
1.5707963267948966}, {2.722713633111154, 1.5707963267948966}, 
     {2.722713633111154, 1.4660765716752366}}]}, {CMYKColor[0.85, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{2.617993877991494, 1.5707963267948966}, {2.617993877991494, \
1.6755160819145563}, {2.722713633111154, 1.6755160819145563}, 
     {2.722713633111154, 1.5707963267948966}}]}, {CMYKColor[0.85, 0.5, 0.275, \
0.1], 
   Polygon[{{2.617993877991494, 1.6755160819145563}, {2.617993877991494, \
1.780235837034216}, {2.722713633111154, 1.780235837034216}, 
     {2.722713633111154, 1.6755160819145563}}]}, {CMYKColor[0.85, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{2.617993877991494, 1.780235837034216}, {2.617993877991494, \
1.8849555921538759}, {2.722713633111154, 1.8849555921538759}, 
     {2.722713633111154, 1.780235837034216}}]}, {CMYKColor[0.85, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{2.617993877991494, 1.8849555921538759}, {2.617993877991494, \
1.9896753472735356}, {2.722713633111154, 1.9896753472735356}, 
     {2.722713633111154, 1.8849555921538759}}]}, {CMYKColor[0.85, 0.5, 0.325, \
0.1], 
   Polygon[{{2.617993877991494, 1.9896753472735356}, {2.617993877991494, \
2.0943951023931953}, {2.722713633111154, 2.0943951023931953}, 
     {2.722713633111154, 1.9896753472735356}}]}, {CMYKColor[0.85, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{2.617993877991494, 2.0943951023931953}, {2.617993877991494, \
2.199114857512855}, {2.722713633111154, 2.199114857512855}, 
     {2.722713633111154, 2.0943951023931953}}]}, {CMYKColor[0.85, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{2.617993877991494, 2.199114857512855}, {2.617993877991494, \
2.3038346126325147}, {2.722713633111154, 2.3038346126325147}, 
     {2.722713633111154, 2.199114857512855}}]}, {CMYKColor[0.85, 0.5, 0.375, \
0.1], 
   Polygon[{{2.617993877991494, 2.3038346126325147}, {2.617993877991494, \
2.4085543677521746}, {2.722713633111154, 2.4085543677521746}, 
     {2.722713633111154, 2.3038346126325147}}]}, {CMYKColor[0.85, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{2.617993877991494, 2.4085543677521746}, {2.617993877991494, \
2.5132741228718345}, {2.722713633111154, 2.5132741228718345}, 
     {2.722713633111154, 2.4085543677521746}}]}, {CMYKColor[0.85, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{2.617993877991494, 2.5132741228718345}, {2.617993877991494, \
2.617993877991494}, {2.722713633111154, 2.617993877991494}, 
     {2.722713633111154, 2.5132741228718345}}]}, {CMYKColor[0.85, 0.5, 0.425, \
0.1], 
   Polygon[{{2.617993877991494, 2.617993877991494}, {2.617993877991494, \
2.722713633111154}, {2.722713633111154, 2.722713633111154}, 
     {2.722713633111154, 2.617993877991494}}]}, {CMYKColor[0.85, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{2.617993877991494, 2.722713633111154}, {2.617993877991494, \
2.827433388230814}, {2.722713633111154, 2.827433388230814}, 
     {2.722713633111154, 2.722713633111154}}]}, {CMYKColor[0.85, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{2.617993877991494, 2.827433388230814}, {2.617993877991494, \
2.9321531433504733}, {2.722713633111154, 2.9321531433504733}, 
     {2.722713633111154, 2.827433388230814}}]}, {CMYKColor[0.85, 0.5, 0.475, \
0.1], 
   Polygon[{{2.617993877991494, 2.9321531433504733}, {2.617993877991494, \
3.036872898470133}, {2.722713633111154, 3.036872898470133}, 
     {2.722713633111154, 2.9321531433504733}}]}, {CMYKColor[0.85, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{2.617993877991494, 3.036872898470133}, {2.617993877991494, \
3.141592653589793}, {2.722713633111154, 3.141592653589793}, 
     {2.722713633111154, 3.036872898470133}}]}, {CMYKColor[0.85, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{2.617993877991494, 3.141592653589793}, {2.617993877991494, \
3.2463124087094526}, {2.722713633111154, 3.2463124087094526}, 
     {2.722713633111154, 3.141592653589793}}]}, {CMYKColor[0.85, 0.5, 0.525, \
0.1], 
   Polygon[{{2.617993877991494, 3.2463124087094526}, {2.617993877991494, \
3.3510321638291125}, {2.722713633111154, 3.3510321638291125}, 
     {2.722713633111154, 3.2463124087094526}}]}, {CMYKColor[0.85, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{2.617993877991494, 3.3510321638291125}, {2.617993877991494, \
3.4557519189487724}, {2.722713633111154, 3.4557519189487724}, 
     {2.722713633111154, 3.3510321638291125}}]}, {CMYKColor[0.85, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{2.617993877991494, 3.4557519189487724}, {2.617993877991494, \
3.560471674068432}, {2.722713633111154, 3.560471674068432}, 
     {2.722713633111154, 3.4557519189487724}}]}, {CMYKColor[0.85, 0.5, 0.575, \
0.1], 
   Polygon[{{2.617993877991494, 3.560471674068432}, {2.617993877991494, \
3.665191429188092}, {2.722713633111154, 3.665191429188092}, 
     {2.722713633111154, 3.560471674068432}}]}, {CMYKColor[0.85, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{2.617993877991494, 3.665191429188092}, {2.617993877991494, \
3.7699111843077517}, {2.722713633111154, 3.7699111843077517}, 
     {2.722713633111154, 3.665191429188092}}]}, {CMYKColor[0.85, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{2.617993877991494, 3.7699111843077517}, {2.617993877991494, \
3.874630939427411}, {2.722713633111154, 3.874630939427411}, 
     {2.722713633111154, 3.7699111843077517}}]}, {CMYKColor[0.85, 0.5, 0.625, \
0.1], 
   Polygon[{{2.617993877991494, 3.874630939427411}, {2.617993877991494, \
3.979350694547071}, {2.722713633111154, 3.979350694547071}, 
     {2.722713633111154, 3.874630939427411}}]}, {CMYKColor[0.85, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{2.617993877991494, 3.979350694547071}, {2.617993877991494, \
4.084070449666731}, {2.722713633111154, 4.084070449666731}, 
     {2.722713633111154, 3.979350694547071}}]}, {CMYKColor[0.85, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{2.617993877991494, 4.084070449666731}, {2.617993877991494, \
4.1887902047863905}, {2.722713633111154, 4.1887902047863905}, 
     {2.722713633111154, 4.084070449666731}}]}, {CMYKColor[0.85, 0.5, 0.675, \
0.1], 
   Polygon[{{2.617993877991494, 4.1887902047863905}, {2.617993877991494, \
4.29350995990605}, {2.722713633111154, 4.29350995990605}, 
     {2.722713633111154, 4.1887902047863905}}]}, {CMYKColor[0.85, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{2.617993877991494, 4.29350995990605}, {2.617993877991494, \
4.39822971502571}, {2.722713633111154, 4.39822971502571}, 
     {2.722713633111154, 4.29350995990605}}]}, {CMYKColor[0.85, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{2.617993877991494, 4.39822971502571}, {2.617993877991494, \
4.50294947014537}, {2.722713633111154, 4.50294947014537}, 
     {2.722713633111154, 4.39822971502571}}]}, {CMYKColor[0.85, 0.5, 0.725, \
0.1], 
   Polygon[{{2.617993877991494, 4.50294947014537}, {2.617993877991494, \
4.607669225265029}, {2.722713633111154, 4.607669225265029}, 
     {2.722713633111154, 4.50294947014537}}]}, {CMYKColor[0.85, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{2.617993877991494, 4.607669225265029}, {2.617993877991494, \
4.71238898038469}, {2.722713633111154, 4.71238898038469}, 
     {2.722713633111154, 4.607669225265029}}]}, {CMYKColor[0.85, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{2.617993877991494, 4.71238898038469}, {2.617993877991494, \
4.817108735504349}, {2.722713633111154, 4.817108735504349}, 
     {2.722713633111154, 4.71238898038469}}]}, {CMYKColor[0.85, 0.5, 0.775, \
0.1], 
   Polygon[{{2.617993877991494, 4.817108735504349}, {2.617993877991494, \
4.921828490624009}, {2.722713633111154, 4.921828490624009}, 
     {2.722713633111154, 4.817108735504349}}]}, {CMYKColor[0.85, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{2.617993877991494, 4.921828490624009}, {2.617993877991494, \
5.026548245743669}, {2.722713633111154, 5.026548245743669}, 
     {2.722713633111154, 4.921828490624009}}]}, {CMYKColor[0.85, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{2.617993877991494, 5.026548245743669}, {2.617993877991494, \
5.1312680008633285}, {2.722713633111154, 5.1312680008633285}, 
     {2.722713633111154, 5.026548245743669}}]}, {CMYKColor[0.85, 0.5, 0.825, \
0.1], 
   Polygon[{{2.617993877991494, 5.1312680008633285}, {2.617993877991494, \
5.235987755982988}, {2.722713633111154, 5.235987755982988}, 
     {2.722713633111154, 5.1312680008633285}}]}, {CMYKColor[0.85, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{2.617993877991494, 5.235987755982988}, {2.617993877991494, \
5.340707511102648}, {2.722713633111154, 5.340707511102648}, 
     {2.722713633111154, 5.235987755982988}}]}, {CMYKColor[0.85, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{2.617993877991494, 5.340707511102648}, {2.617993877991494, \
5.445427266222308}, {2.722713633111154, 5.445427266222308}, 
     {2.722713633111154, 5.340707511102648}}]}, {CMYKColor[0.85, 0.5, 0.875, \
0.1], 
   Polygon[{{2.617993877991494, 5.445427266222308}, {2.617993877991494, \
5.550147021341967}, {2.722713633111154, 5.550147021341967}, 
     {2.722713633111154, 5.445427266222308}}]}, {CMYKColor[0.85, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{2.617993877991494, 5.550147021341967}, {2.617993877991494, \
5.654866776461628}, {2.722713633111154, 5.654866776461628}, 
     {2.722713633111154, 5.550147021341967}}]}, {CMYKColor[0.85, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{2.617993877991494, 5.654866776461628}, {2.617993877991494, \
5.759586531581287}, {2.722713633111154, 5.759586531581287}, 
     {2.722713633111154, 5.654866776461628}}]}, {CMYKColor[0.85, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{2.617993877991494, 5.759586531581287}, {2.617993877991494, \
5.864306286700947}, {2.722713633111154, 5.864306286700947}, 
     {2.722713633111154, 5.759586531581287}}]}, {CMYKColor[0.85, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{2.617993877991494, 5.864306286700947}, {2.617993877991494, \
5.969026041820607}, {2.722713633111154, 5.969026041820607}, 
     {2.722713633111154, 5.864306286700947}}]}, {CMYKColor[0.85, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{2.617993877991494, 5.969026041820607}, {2.617993877991494, \
6.073745796940266}, {2.722713633111154, 6.073745796940266}, 
     {2.722713633111154, 5.969026041820607}}]}, {CMYKColor[0.85, 0.5, 0.975, \
0.1], 
   Polygon[{{2.617993877991494, 6.073745796940266}, {2.617993877991494, \
6.178465552059926}, {2.722713633111154, 6.178465552059926}, 
     {2.722713633111154, 6.073745796940266}}]}, {CMYKColor[0.85, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{2.617993877991494, 6.178465552059926}, {2.617993877991494, \
6.283185307179586}, {2.722713633111154, 6.283185307179586}, 
     {2.722713633111154, 6.178465552059926}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{2.722713633111154, 0.}, {2.722713633111154, \
0.10471975511965977}, {2.827433388230814, 0.10471975511965977}, 
     {2.827433388230814, 0.}}]}, {CMYKColor[0.8833333333333333, 0.5, 0.025, \
0.1], 
   Polygon[{{2.722713633111154, 0.10471975511965977}, {2.722713633111154, \
0.20943951023931953}, {2.827433388230814, 0.20943951023931953}, 
     {2.827433388230814, 0.10471975511965977}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{2.722713633111154, 0.20943951023931953}, {2.722713633111154, \
0.3141592653589793}, {2.827433388230814, 0.3141592653589793}, 
     {2.827433388230814, 0.20943951023931953}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{2.722713633111154, 0.3141592653589793}, {2.722713633111154, \
0.41887902047863906}, {2.827433388230814, 0.41887902047863906}, 
     {2.827433388230814, 0.3141592653589793}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{2.722713633111154, 0.41887902047863906}, {2.722713633111154, \
0.5235987755982988}, {2.827433388230814, 0.5235987755982988}, 
     {2.827433388230814, 0.41887902047863906}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{2.722713633111154, 0.5235987755982988}, {2.722713633111154, \
0.6283185307179586}, {2.827433388230814, 0.6283185307179586}, 
     {2.827433388230814, 0.5235987755982988}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{2.722713633111154, 0.6283185307179586}, {2.722713633111154, \
0.7330382858376183}, {2.827433388230814, 0.7330382858376183}, 
     {2.827433388230814, 0.6283185307179586}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{2.722713633111154, 0.7330382858376183}, {2.722713633111154, \
0.8377580409572781}, {2.827433388230814, 0.8377580409572781}, 
     {2.827433388230814, 0.7330382858376183}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{2.722713633111154, 0.8377580409572781}, {2.722713633111154, \
0.9424777960769379}, {2.827433388230814, 0.9424777960769379}, 
     {2.827433388230814, 0.8377580409572781}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.722713633111154, 0.9424777960769379}, {2.722713633111154, \
1.0471975511965976}, {2.827433388230814, 1.0471975511965976}, 
     {2.827433388230814, 0.9424777960769379}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{2.722713633111154, 1.0471975511965976}, {2.722713633111154, \
1.1519173063162573}, {2.827433388230814, 1.1519173063162573}, 
     {2.827433388230814, 1.0471975511965976}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{2.722713633111154, 1.1519173063162573}, {2.722713633111154, \
1.2566370614359172}, {2.827433388230814, 1.2566370614359172}, 
     {2.827433388230814, 1.1519173063162573}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{2.722713633111154, 1.2566370614359172}, {2.722713633111154, \
1.361356816555577}, {2.827433388230814, 1.361356816555577}, 
     {2.827433388230814, 1.2566370614359172}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{2.722713633111154, 1.361356816555577}, {2.722713633111154, \
1.4660765716752366}, {2.827433388230814, 1.4660765716752366}, 
     {2.827433388230814, 1.361356816555577}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{2.722713633111154, 1.4660765716752366}, {2.722713633111154, \
1.5707963267948966}, {2.827433388230814, 1.5707963267948966}, 
     {2.827433388230814, 1.4660765716752366}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{2.722713633111154, 1.5707963267948966}, {2.722713633111154, \
1.6755160819145563}, {2.827433388230814, 1.6755160819145563}, 
     {2.827433388230814, 1.5707963267948966}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{2.722713633111154, 1.6755160819145563}, {2.722713633111154, \
1.780235837034216}, {2.827433388230814, 1.780235837034216}, 
     {2.827433388230814, 1.6755160819145563}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{2.722713633111154, 1.780235837034216}, {2.722713633111154, \
1.8849555921538759}, {2.827433388230814, 1.8849555921538759}, 
     {2.827433388230814, 1.780235837034216}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{2.722713633111154, 1.8849555921538759}, {2.722713633111154, \
1.9896753472735356}, {2.827433388230814, 1.9896753472735356}, 
     {2.827433388230814, 1.8849555921538759}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{2.722713633111154, 1.9896753472735356}, {2.722713633111154, \
2.0943951023931953}, {2.827433388230814, 2.0943951023931953}, 
     {2.827433388230814, 1.9896753472735356}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.722713633111154, 2.0943951023931953}, {2.722713633111154, \
2.199114857512855}, {2.827433388230814, 2.199114857512855}, 
     {2.827433388230814, 2.0943951023931953}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.722713633111154, 2.199114857512855}, {2.722713633111154, \
2.3038346126325147}, {2.827433388230814, 2.3038346126325147}, 
     {2.827433388230814, 2.199114857512855}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{2.722713633111154, 2.3038346126325147}, {2.722713633111154, \
2.4085543677521746}, {2.827433388230814, 2.4085543677521746}, 
     {2.827433388230814, 2.3038346126325147}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{2.722713633111154, 2.4085543677521746}, {2.722713633111154, \
2.5132741228718345}, {2.827433388230814, 2.5132741228718345}, 
     {2.827433388230814, 2.4085543677521746}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{2.722713633111154, 2.5132741228718345}, {2.722713633111154, \
2.617993877991494}, {2.827433388230814, 2.617993877991494}, 
     {2.827433388230814, 2.5132741228718345}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{2.722713633111154, 2.617993877991494}, {2.722713633111154, \
2.722713633111154}, {2.827433388230814, 2.722713633111154}, 
     {2.827433388230814, 2.617993877991494}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{2.722713633111154, 2.722713633111154}, {2.722713633111154, \
2.827433388230814}, {2.827433388230814, 2.827433388230814}, 
     {2.827433388230814, 2.722713633111154}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{2.722713633111154, 2.827433388230814}, {2.722713633111154, \
2.9321531433504733}, {2.827433388230814, 2.9321531433504733}, 
     {2.827433388230814, 2.827433388230814}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{2.722713633111154, 2.9321531433504733}, {2.722713633111154, \
3.036872898470133}, {2.827433388230814, 3.036872898470133}, 
     {2.827433388230814, 2.9321531433504733}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{2.722713633111154, 3.036872898470133}, {2.722713633111154, \
3.141592653589793}, {2.827433388230814, 3.141592653589793}, 
     {2.827433388230814, 3.036872898470133}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{2.722713633111154, 3.141592653589793}, {2.722713633111154, \
3.2463124087094526}, {2.827433388230814, 3.2463124087094526}, 
     {2.827433388230814, 3.141592653589793}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{2.722713633111154, 3.2463124087094526}, {2.722713633111154, \
3.3510321638291125}, {2.827433388230814, 3.3510321638291125}, 
     {2.827433388230814, 3.2463124087094526}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{2.722713633111154, 3.3510321638291125}, {2.722713633111154, \
3.4557519189487724}, {2.827433388230814, 3.4557519189487724}, 
     {2.827433388230814, 3.3510321638291125}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{2.722713633111154, 3.4557519189487724}, {2.722713633111154, \
3.560471674068432}, {2.827433388230814, 3.560471674068432}, 
     {2.827433388230814, 3.4557519189487724}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{2.722713633111154, 3.560471674068432}, {2.722713633111154, \
3.665191429188092}, {2.827433388230814, 3.665191429188092}, 
     {2.827433388230814, 3.560471674068432}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{2.722713633111154, 3.665191429188092}, {2.722713633111154, \
3.7699111843077517}, {2.827433388230814, 3.7699111843077517}, 
     {2.827433388230814, 3.665191429188092}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{2.722713633111154, 3.7699111843077517}, {2.722713633111154, \
3.874630939427411}, {2.827433388230814, 3.874630939427411}, 
     {2.827433388230814, 3.7699111843077517}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{2.722713633111154, 3.874630939427411}, {2.722713633111154, \
3.979350694547071}, {2.827433388230814, 3.979350694547071}, 
     {2.827433388230814, 3.874630939427411}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{2.722713633111154, 3.979350694547071}, {2.722713633111154, \
4.084070449666731}, {2.827433388230814, 4.084070449666731}, 
     {2.827433388230814, 3.979350694547071}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.722713633111154, 4.084070449666731}, {2.722713633111154, \
4.1887902047863905}, {2.827433388230814, 4.1887902047863905}, 
     {2.827433388230814, 4.084070449666731}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{2.722713633111154, 4.1887902047863905}, {2.722713633111154, \
4.29350995990605}, {2.827433388230814, 4.29350995990605}, 
     {2.827433388230814, 4.1887902047863905}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.722713633111154, 4.29350995990605}, {2.722713633111154, \
4.39822971502571}, {2.827433388230814, 4.39822971502571}, 
     {2.827433388230814, 4.29350995990605}}]}, {CMYKColor[0.8833333333333333, \
0.5, 0.7083333333333334, 0.1], 
   Polygon[{{2.722713633111154, 4.39822971502571}, {2.722713633111154, \
4.50294947014537}, {2.827433388230814, 4.50294947014537}, 
     {2.827433388230814, 4.39822971502571}}]}, {CMYKColor[0.8833333333333333, \
0.5, 0.725, 0.1], 
   Polygon[{{2.722713633111154, 4.50294947014537}, {2.722713633111154, \
4.607669225265029}, {2.827433388230814, 4.607669225265029}, 
     {2.827433388230814, 4.50294947014537}}]}, {CMYKColor[0.8833333333333333, \
0.5, 0.7416666666666667, 0.1], 
   Polygon[{{2.722713633111154, 4.607669225265029}, {2.722713633111154, \
4.71238898038469}, {2.827433388230814, 4.71238898038469}, 
     {2.827433388230814, 4.607669225265029}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{2.722713633111154, 4.71238898038469}, {2.722713633111154, \
4.817108735504349}, {2.827433388230814, 4.817108735504349}, 
     {2.827433388230814, 4.71238898038469}}]}, {CMYKColor[0.8833333333333333, \
0.5, 0.775, 0.1], 
   Polygon[{{2.722713633111154, 4.817108735504349}, {2.722713633111154, \
4.921828490624009}, {2.827433388230814, 4.921828490624009}, 
     {2.827433388230814, 4.817108735504349}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{2.722713633111154, 4.921828490624009}, {2.722713633111154, \
5.026548245743669}, {2.827433388230814, 5.026548245743669}, 
     {2.827433388230814, 4.921828490624009}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{2.722713633111154, 5.026548245743669}, {2.722713633111154, \
5.1312680008633285}, {2.827433388230814, 5.1312680008633285}, 
     {2.827433388230814, 5.026548245743669}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{2.722713633111154, 5.1312680008633285}, {2.722713633111154, \
5.235987755982988}, {2.827433388230814, 5.235987755982988}, 
     {2.827433388230814, 5.1312680008633285}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.722713633111154, 5.235987755982988}, {2.722713633111154, \
5.340707511102648}, {2.827433388230814, 5.340707511102648}, 
     {2.827433388230814, 5.235987755982988}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.722713633111154, 5.340707511102648}, {2.722713633111154, \
5.445427266222308}, {2.827433388230814, 5.445427266222308}, 
     {2.827433388230814, 5.340707511102648}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{2.722713633111154, 5.445427266222308}, {2.722713633111154, \
5.550147021341967}, {2.827433388230814, 5.550147021341967}, 
     {2.827433388230814, 5.445427266222308}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{2.722713633111154, 5.550147021341967}, {2.722713633111154, \
5.654866776461628}, {2.827433388230814, 5.654866776461628}, 
     {2.827433388230814, 5.550147021341967}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{2.722713633111154, 5.654866776461628}, {2.722713633111154, \
5.759586531581287}, {2.827433388230814, 5.759586531581287}, 
     {2.827433388230814, 5.654866776461628}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{2.722713633111154, 5.759586531581287}, {2.722713633111154, \
5.864306286700947}, {2.827433388230814, 5.864306286700947}, 
     {2.827433388230814, 5.759586531581287}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{2.722713633111154, 5.864306286700947}, {2.722713633111154, \
5.969026041820607}, {2.827433388230814, 5.969026041820607}, 
     {2.827433388230814, 5.864306286700947}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{2.722713633111154, 5.969026041820607}, {2.722713633111154, \
6.073745796940266}, {2.827433388230814, 6.073745796940266}, 
     {2.827433388230814, 5.969026041820607}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{2.722713633111154, 6.073745796940266}, {2.722713633111154, \
6.178465552059926}, {2.827433388230814, 6.178465552059926}, 
     {2.827433388230814, 6.073745796940266}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{2.722713633111154, 6.178465552059926}, {2.722713633111154, \
6.283185307179586}, {2.827433388230814, 6.283185307179586}, 
     {2.827433388230814, 6.178465552059926}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{2.827433388230814, 0.}, {2.827433388230814, \
0.10471975511965977}, {2.9321531433504733, 0.10471975511965977}, 
     {2.9321531433504733, 0.}}]}, {CMYKColor[0.9166666666666666, 0.5, 0.025, \
0.1], 
   Polygon[{{2.827433388230814, 0.10471975511965977}, {2.827433388230814, \
0.20943951023931953}, {2.9321531433504733, 0.20943951023931953}, 
     {2.9321531433504733, 0.10471975511965977}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{2.827433388230814, 0.20943951023931953}, {2.827433388230814, \
0.3141592653589793}, {2.9321531433504733, 0.3141592653589793}, 
     {2.9321531433504733, 0.20943951023931953}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{2.827433388230814, 0.3141592653589793}, {2.827433388230814, \
0.41887902047863906}, {2.9321531433504733, 0.41887902047863906}, 
     {2.9321531433504733, 0.3141592653589793}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.075, 0.1], 
   Polygon[{{2.827433388230814, 0.41887902047863906}, {2.827433388230814, \
0.5235987755982988}, {2.9321531433504733, 0.5235987755982988}, 
     {2.9321531433504733, 0.41887902047863906}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{2.827433388230814, 0.5235987755982988}, {2.827433388230814, \
0.6283185307179586}, {2.9321531433504733, 0.6283185307179586}, 
     {2.9321531433504733, 0.5235987755982988}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{2.827433388230814, 0.6283185307179586}, {2.827433388230814, \
0.7330382858376183}, {2.9321531433504733, 0.7330382858376183}, 
     {2.9321531433504733, 0.6283185307179586}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.125, 0.1], 
   Polygon[{{2.827433388230814, 0.7330382858376183}, {2.827433388230814, \
0.8377580409572781}, {2.9321531433504733, 0.8377580409572781}, 
     {2.9321531433504733, 0.7330382858376183}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{2.827433388230814, 0.8377580409572781}, {2.827433388230814, \
0.9424777960769379}, {2.9321531433504733, 0.9424777960769379}, 
     {2.9321531433504733, 0.8377580409572781}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.827433388230814, 0.9424777960769379}, {2.827433388230814, \
1.0471975511965976}, {2.9321531433504733, 1.0471975511965976}, 
     {2.9321531433504733, 0.9424777960769379}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.175, 0.1], 
   Polygon[{{2.827433388230814, 1.0471975511965976}, {2.827433388230814, \
1.1519173063162573}, {2.9321531433504733, 1.1519173063162573}, 
     {2.9321531433504733, 1.0471975511965976}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{2.827433388230814, 1.1519173063162573}, {2.827433388230814, \
1.2566370614359172}, {2.9321531433504733, 1.2566370614359172}, 
     {2.9321531433504733, 1.1519173063162573}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{2.827433388230814, 1.2566370614359172}, {2.827433388230814, \
1.361356816555577}, {2.9321531433504733, 1.361356816555577}, 
     {2.9321531433504733, 1.2566370614359172}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.225, 0.1], 
   Polygon[{{2.827433388230814, 1.361356816555577}, {2.827433388230814, \
1.4660765716752366}, {2.9321531433504733, 1.4660765716752366}, 
     {2.9321531433504733, 1.361356816555577}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{2.827433388230814, 1.4660765716752366}, {2.827433388230814, \
1.5707963267948966}, {2.9321531433504733, 1.5707963267948966}, 
     {2.9321531433504733, 1.4660765716752366}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{2.827433388230814, 1.5707963267948966}, {2.827433388230814, \
1.6755160819145563}, {2.9321531433504733, 1.6755160819145563}, 
     {2.9321531433504733, 1.5707963267948966}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.275, 0.1], 
   Polygon[{{2.827433388230814, 1.6755160819145563}, {2.827433388230814, \
1.780235837034216}, {2.9321531433504733, 1.780235837034216}, 
     {2.9321531433504733, 1.6755160819145563}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{2.827433388230814, 1.780235837034216}, {2.827433388230814, \
1.8849555921538759}, {2.9321531433504733, 1.8849555921538759}, 
     {2.9321531433504733, 1.780235837034216}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{2.827433388230814, 1.8849555921538759}, {2.827433388230814, \
1.9896753472735356}, {2.9321531433504733, 1.9896753472735356}, 
     {2.9321531433504733, 1.8849555921538759}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.325, 0.1], 
   Polygon[{{2.827433388230814, 1.9896753472735356}, {2.827433388230814, \
2.0943951023931953}, {2.9321531433504733, 2.0943951023931953}, 
     {2.9321531433504733, 1.9896753472735356}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.827433388230814, 2.0943951023931953}, {2.827433388230814, \
2.199114857512855}, {2.9321531433504733, 2.199114857512855}, 
     {2.9321531433504733, 2.0943951023931953}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.827433388230814, 2.199114857512855}, {2.827433388230814, \
2.3038346126325147}, {2.9321531433504733, 2.3038346126325147}, 
     {2.9321531433504733, 2.199114857512855}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.375, 0.1], 
   Polygon[{{2.827433388230814, 2.3038346126325147}, {2.827433388230814, \
2.4085543677521746}, {2.9321531433504733, 2.4085543677521746}, 
     {2.9321531433504733, 2.3038346126325147}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{2.827433388230814, 2.4085543677521746}, {2.827433388230814, \
2.5132741228718345}, {2.9321531433504733, 2.5132741228718345}, 
     {2.9321531433504733, 2.4085543677521746}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{2.827433388230814, 2.5132741228718345}, {2.827433388230814, \
2.617993877991494}, {2.9321531433504733, 2.617993877991494}, 
     {2.9321531433504733, 2.5132741228718345}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.425, 0.1], 
   Polygon[{{2.827433388230814, 2.617993877991494}, {2.827433388230814, \
2.722713633111154}, {2.9321531433504733, 2.722713633111154}, 
     {2.9321531433504733, 2.617993877991494}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{2.827433388230814, 2.722713633111154}, {2.827433388230814, \
2.827433388230814}, {2.9321531433504733, 2.827433388230814}, 
     {2.9321531433504733, 2.722713633111154}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{2.827433388230814, 2.827433388230814}, {2.827433388230814, \
2.9321531433504733}, {2.9321531433504733, 2.9321531433504733}, 
     {2.9321531433504733, 2.827433388230814}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.475, 0.1], 
   Polygon[{{2.827433388230814, 2.9321531433504733}, {2.827433388230814, \
3.036872898470133}, {2.9321531433504733, 3.036872898470133}, 
     {2.9321531433504733, 2.9321531433504733}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{2.827433388230814, 3.036872898470133}, {2.827433388230814, \
3.141592653589793}, {2.9321531433504733, 3.141592653589793}, 
     {2.9321531433504733, 3.036872898470133}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{2.827433388230814, 3.141592653589793}, {2.827433388230814, \
3.2463124087094526}, {2.9321531433504733, 3.2463124087094526}, 
     {2.9321531433504733, 3.141592653589793}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.525, 0.1], 
   Polygon[{{2.827433388230814, 3.2463124087094526}, {2.827433388230814, \
3.3510321638291125}, {2.9321531433504733, 3.3510321638291125}, 
     {2.9321531433504733, 3.2463124087094526}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{2.827433388230814, 3.3510321638291125}, {2.827433388230814, \
3.4557519189487724}, {2.9321531433504733, 3.4557519189487724}, 
     {2.9321531433504733, 3.3510321638291125}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{2.827433388230814, 3.4557519189487724}, {2.827433388230814, \
3.560471674068432}, {2.9321531433504733, 3.560471674068432}, 
     {2.9321531433504733, 3.4557519189487724}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.575, 0.1], 
   Polygon[{{2.827433388230814, 3.560471674068432}, {2.827433388230814, \
3.665191429188092}, {2.9321531433504733, 3.665191429188092}, 
     {2.9321531433504733, 3.560471674068432}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{2.827433388230814, 3.665191429188092}, {2.827433388230814, \
3.7699111843077517}, {2.9321531433504733, 3.7699111843077517}, 
     {2.9321531433504733, 3.665191429188092}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{2.827433388230814, 3.7699111843077517}, {2.827433388230814, \
3.874630939427411}, {2.9321531433504733, 3.874630939427411}, 
     {2.9321531433504733, 3.7699111843077517}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.625, 0.1], 
   Polygon[{{2.827433388230814, 3.874630939427411}, {2.827433388230814, \
3.979350694547071}, {2.9321531433504733, 3.979350694547071}, 
     {2.9321531433504733, 3.874630939427411}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{2.827433388230814, 3.979350694547071}, {2.827433388230814, \
4.084070449666731}, {2.9321531433504733, 4.084070449666731}, 
     {2.9321531433504733, 3.979350694547071}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.827433388230814, 4.084070449666731}, {2.827433388230814, \
4.1887902047863905}, {2.9321531433504733, 4.1887902047863905}, 
     {2.9321531433504733, 4.084070449666731}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.675, 0.1], 
   Polygon[{{2.827433388230814, 4.1887902047863905}, {2.827433388230814, \
4.29350995990605}, {2.9321531433504733, 4.29350995990605}, 
     {2.9321531433504733, 4.1887902047863905}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.827433388230814, 4.29350995990605}, {2.827433388230814, \
4.39822971502571}, {2.9321531433504733, 4.39822971502571}, 
     {2.9321531433504733, 4.29350995990605}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{2.827433388230814, 4.39822971502571}, {2.827433388230814, \
4.50294947014537}, {2.9321531433504733, 4.50294947014537}, 
     {2.9321531433504733, 4.39822971502571}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.725, 0.1], 
   Polygon[{{2.827433388230814, 4.50294947014537}, {2.827433388230814, \
4.607669225265029}, {2.9321531433504733, 4.607669225265029}, 
     {2.9321531433504733, 4.50294947014537}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{2.827433388230814, 4.607669225265029}, {2.827433388230814, \
4.71238898038469}, {2.9321531433504733, 4.71238898038469}, 
     {2.9321531433504733, 4.607669225265029}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{2.827433388230814, 4.71238898038469}, {2.827433388230814, \
4.817108735504349}, {2.9321531433504733, 4.817108735504349}, 
     {2.9321531433504733, 4.71238898038469}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.775, 0.1], 
   Polygon[{{2.827433388230814, 4.817108735504349}, {2.827433388230814, \
4.921828490624009}, {2.9321531433504733, 4.921828490624009}, 
     {2.9321531433504733, 4.817108735504349}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{2.827433388230814, 4.921828490624009}, {2.827433388230814, \
5.026548245743669}, {2.9321531433504733, 5.026548245743669}, 
     {2.9321531433504733, 4.921828490624009}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{2.827433388230814, 5.026548245743669}, {2.827433388230814, \
5.1312680008633285}, {2.9321531433504733, 5.1312680008633285}, 
     {2.9321531433504733, 5.026548245743669}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.825, 0.1], 
   Polygon[{{2.827433388230814, 5.1312680008633285}, {2.827433388230814, \
5.235987755982988}, {2.9321531433504733, 5.235987755982988}, 
     {2.9321531433504733, 5.1312680008633285}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.827433388230814, 5.235987755982988}, {2.827433388230814, \
5.340707511102648}, {2.9321531433504733, 5.340707511102648}, 
     {2.9321531433504733, 5.235987755982988}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.827433388230814, 5.340707511102648}, {2.827433388230814, \
5.445427266222308}, {2.9321531433504733, 5.445427266222308}, 
     {2.9321531433504733, 5.340707511102648}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.875, 0.1], 
   Polygon[{{2.827433388230814, 5.445427266222308}, {2.827433388230814, \
5.550147021341967}, {2.9321531433504733, 5.550147021341967}, 
     {2.9321531433504733, 5.445427266222308}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{2.827433388230814, 5.550147021341967}, {2.827433388230814, \
5.654866776461628}, {2.9321531433504733, 5.654866776461628}, 
     {2.9321531433504733, 5.550147021341967}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{2.827433388230814, 5.654866776461628}, {2.827433388230814, \
5.759586531581287}, {2.9321531433504733, 5.759586531581287}, 
     {2.9321531433504733, 5.654866776461628}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{2.827433388230814, 5.759586531581287}, {2.827433388230814, \
5.864306286700947}, {2.9321531433504733, 5.864306286700947}, 
     {2.9321531433504733, 5.759586531581287}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{2.827433388230814, 5.864306286700947}, {2.827433388230814, \
5.969026041820607}, {2.9321531433504733, 5.969026041820607}, 
     {2.9321531433504733, 5.864306286700947}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{2.827433388230814, 5.969026041820607}, {2.827433388230814, \
6.073745796940266}, {2.9321531433504733, 6.073745796940266}, 
     {2.9321531433504733, 5.969026041820607}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.975, 0.1], 
   Polygon[{{2.827433388230814, 6.073745796940266}, {2.827433388230814, \
6.178465552059926}, {2.9321531433504733, 6.178465552059926}, 
     {2.9321531433504733, 6.073745796940266}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{2.827433388230814, 6.178465552059926}, {2.827433388230814, \
6.283185307179586}, {2.9321531433504733, 6.283185307179586}, 
     {2.9321531433504733, 6.178465552059926}}]}, {CMYKColor[0.95, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 0.}, {2.9321531433504733, \
0.10471975511965977}, {3.036872898470133, 0.10471975511965977}, 
     {3.036872898470133, 0.}}]}, {CMYKColor[0.95, 0.5, 0.025, 0.1], 
   Polygon[{{2.9321531433504733, 0.10471975511965977}, {2.9321531433504733, \
0.20943951023931953}, {3.036872898470133, 0.20943951023931953}, 
     {3.036872898470133, 0.10471975511965977}}]}, {CMYKColor[0.95, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{2.9321531433504733, 0.20943951023931953}, {2.9321531433504733, \
0.3141592653589793}, {3.036872898470133, 0.3141592653589793}, 
     {3.036872898470133, 0.20943951023931953}}]}, {CMYKColor[0.95, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{2.9321531433504733, 0.3141592653589793}, {2.9321531433504733, \
0.41887902047863906}, {3.036872898470133, 0.41887902047863906}, 
     {3.036872898470133, 0.3141592653589793}}]}, {CMYKColor[0.95, 0.5, 0.075, \
0.1], 
   Polygon[{{2.9321531433504733, 0.41887902047863906}, {2.9321531433504733, \
0.5235987755982988}, {3.036872898470133, 0.5235987755982988}, 
     {3.036872898470133, 0.41887902047863906}}]}, {CMYKColor[0.95, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{2.9321531433504733, 0.5235987755982988}, {2.9321531433504733, \
0.6283185307179586}, {3.036872898470133, 0.6283185307179586}, 
     {3.036872898470133, 0.5235987755982988}}]}, {CMYKColor[0.95, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{2.9321531433504733, 0.6283185307179586}, {2.9321531433504733, \
0.7330382858376183}, {3.036872898470133, 0.7330382858376183}, 
     {3.036872898470133, 0.6283185307179586}}]}, {CMYKColor[0.95, 0.5, 0.125, \
0.1], 
   Polygon[{{2.9321531433504733, 0.7330382858376183}, {2.9321531433504733, \
0.8377580409572781}, {3.036872898470133, 0.8377580409572781}, 
     {3.036872898470133, 0.7330382858376183}}]}, {CMYKColor[0.95, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{2.9321531433504733, 0.8377580409572781}, {2.9321531433504733, \
0.9424777960769379}, {3.036872898470133, 0.9424777960769379}, 
     {3.036872898470133, 0.8377580409572781}}]}, {CMYKColor[0.95, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 0.9424777960769379}, {2.9321531433504733, \
1.0471975511965976}, {3.036872898470133, 1.0471975511965976}, 
     {3.036872898470133, 0.9424777960769379}}]}, {CMYKColor[0.95, 0.5, 0.175, \
0.1], 
   Polygon[{{2.9321531433504733, 1.0471975511965976}, {2.9321531433504733, \
1.1519173063162573}, {3.036872898470133, 1.1519173063162573}, 
     {3.036872898470133, 1.0471975511965976}}]}, {CMYKColor[0.95, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{2.9321531433504733, 1.1519173063162573}, {2.9321531433504733, \
1.2566370614359172}, {3.036872898470133, 1.2566370614359172}, 
     {3.036872898470133, 1.1519173063162573}}]}, {CMYKColor[0.95, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{2.9321531433504733, 1.2566370614359172}, {2.9321531433504733, \
1.361356816555577}, {3.036872898470133, 1.361356816555577}, 
     {3.036872898470133, 1.2566370614359172}}]}, {CMYKColor[0.95, 0.5, 0.225, \
0.1], 
   Polygon[{{2.9321531433504733, 1.361356816555577}, {2.9321531433504733, \
1.4660765716752366}, {3.036872898470133, 1.4660765716752366}, 
     {3.036872898470133, 1.361356816555577}}]}, {CMYKColor[0.95, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{2.9321531433504733, 1.4660765716752366}, {2.9321531433504733, \
1.5707963267948966}, {3.036872898470133, 1.5707963267948966}, 
     {3.036872898470133, 1.4660765716752366}}]}, {CMYKColor[0.95, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 1.5707963267948966}, {2.9321531433504733, \
1.6755160819145563}, {3.036872898470133, 1.6755160819145563}, 
     {3.036872898470133, 1.5707963267948966}}]}, {CMYKColor[0.95, 0.5, 0.275, \
0.1], 
   Polygon[{{2.9321531433504733, 1.6755160819145563}, {2.9321531433504733, \
1.780235837034216}, {3.036872898470133, 1.780235837034216}, 
     {3.036872898470133, 1.6755160819145563}}]}, {CMYKColor[0.95, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{2.9321531433504733, 1.780235837034216}, {2.9321531433504733, \
1.8849555921538759}, {3.036872898470133, 1.8849555921538759}, 
     {3.036872898470133, 1.780235837034216}}]}, {CMYKColor[0.95, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{2.9321531433504733, 1.8849555921538759}, {2.9321531433504733, \
1.9896753472735356}, {3.036872898470133, 1.9896753472735356}, 
     {3.036872898470133, 1.8849555921538759}}]}, {CMYKColor[0.95, 0.5, 0.325, \
0.1], 
   Polygon[{{2.9321531433504733, 1.9896753472735356}, {2.9321531433504733, \
2.0943951023931953}, {3.036872898470133, 2.0943951023931953}, 
     {3.036872898470133, 1.9896753472735356}}]}, {CMYKColor[0.95, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{2.9321531433504733, 2.0943951023931953}, {2.9321531433504733, \
2.199114857512855}, {3.036872898470133, 2.199114857512855}, 
     {3.036872898470133, 2.0943951023931953}}]}, {CMYKColor[0.95, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{2.9321531433504733, 2.199114857512855}, {2.9321531433504733, \
2.3038346126325147}, {3.036872898470133, 2.3038346126325147}, 
     {3.036872898470133, 2.199114857512855}}]}, {CMYKColor[0.95, 0.5, 0.375, \
0.1], 
   Polygon[{{2.9321531433504733, 2.3038346126325147}, {2.9321531433504733, \
2.4085543677521746}, {3.036872898470133, 2.4085543677521746}, 
     {3.036872898470133, 2.3038346126325147}}]}, {CMYKColor[0.95, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{2.9321531433504733, 2.4085543677521746}, {2.9321531433504733, \
2.5132741228718345}, {3.036872898470133, 2.5132741228718345}, 
     {3.036872898470133, 2.4085543677521746}}]}, {CMYKColor[0.95, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 2.5132741228718345}, {2.9321531433504733, \
2.617993877991494}, {3.036872898470133, 2.617993877991494}, 
     {3.036872898470133, 2.5132741228718345}}]}, {CMYKColor[0.95, 0.5, 0.425, \
0.1], 
   Polygon[{{2.9321531433504733, 2.617993877991494}, {2.9321531433504733, \
2.722713633111154}, {3.036872898470133, 2.722713633111154}, 
     {3.036872898470133, 2.617993877991494}}]}, {CMYKColor[0.95, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{2.9321531433504733, 2.722713633111154}, {2.9321531433504733, \
2.827433388230814}, {3.036872898470133, 2.827433388230814}, 
     {3.036872898470133, 2.722713633111154}}]}, {CMYKColor[0.95, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 2.827433388230814}, {2.9321531433504733, \
2.9321531433504733}, {3.036872898470133, 2.9321531433504733}, 
     {3.036872898470133, 2.827433388230814}}]}, {CMYKColor[0.95, 0.5, 0.475, \
0.1], 
   Polygon[{{2.9321531433504733, 2.9321531433504733}, {2.9321531433504733, \
3.036872898470133}, {3.036872898470133, 3.036872898470133}, 
     {3.036872898470133, 2.9321531433504733}}]}, {CMYKColor[0.95, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{2.9321531433504733, 3.036872898470133}, {2.9321531433504733, \
3.141592653589793}, {3.036872898470133, 3.141592653589793}, 
     {3.036872898470133, 3.036872898470133}}]}, {CMYKColor[0.95, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 3.141592653589793}, {2.9321531433504733, \
3.2463124087094526}, {3.036872898470133, 3.2463124087094526}, 
     {3.036872898470133, 3.141592653589793}}]}, {CMYKColor[0.95, 0.5, 0.525, \
0.1], 
   Polygon[{{2.9321531433504733, 3.2463124087094526}, {2.9321531433504733, \
3.3510321638291125}, {3.036872898470133, 3.3510321638291125}, 
     {3.036872898470133, 3.2463124087094526}}]}, {CMYKColor[0.95, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{2.9321531433504733, 3.3510321638291125}, {2.9321531433504733, \
3.4557519189487724}, {3.036872898470133, 3.4557519189487724}, 
     {3.036872898470133, 3.3510321638291125}}]}, {CMYKColor[0.95, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 3.4557519189487724}, {2.9321531433504733, \
3.560471674068432}, {3.036872898470133, 3.560471674068432}, 
     {3.036872898470133, 3.4557519189487724}}]}, {CMYKColor[0.95, 0.5, 0.575, \
0.1], 
   Polygon[{{2.9321531433504733, 3.560471674068432}, {2.9321531433504733, \
3.665191429188092}, {3.036872898470133, 3.665191429188092}, 
     {3.036872898470133, 3.560471674068432}}]}, {CMYKColor[0.95, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{2.9321531433504733, 3.665191429188092}, {2.9321531433504733, \
3.7699111843077517}, {3.036872898470133, 3.7699111843077517}, 
     {3.036872898470133, 3.665191429188092}}]}, {CMYKColor[0.95, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 3.7699111843077517}, {2.9321531433504733, \
3.874630939427411}, {3.036872898470133, 3.874630939427411}, 
     {3.036872898470133, 3.7699111843077517}}]}, {CMYKColor[0.95, 0.5, 0.625, \
0.1], 
   Polygon[{{2.9321531433504733, 3.874630939427411}, {2.9321531433504733, \
3.979350694547071}, {3.036872898470133, 3.979350694547071}, 
     {3.036872898470133, 3.874630939427411}}]}, {CMYKColor[0.95, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{2.9321531433504733, 3.979350694547071}, {2.9321531433504733, \
4.084070449666731}, {3.036872898470133, 4.084070449666731}, 
     {3.036872898470133, 3.979350694547071}}]}, {CMYKColor[0.95, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 4.084070449666731}, {2.9321531433504733, \
4.1887902047863905}, {3.036872898470133, 4.1887902047863905}, 
     {3.036872898470133, 4.084070449666731}}]}, {CMYKColor[0.95, 0.5, 0.675, \
0.1], 
   Polygon[{{2.9321531433504733, 4.1887902047863905}, {2.9321531433504733, \
4.29350995990605}, {3.036872898470133, 4.29350995990605}, 
     {3.036872898470133, 4.1887902047863905}}]}, {CMYKColor[0.95, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{2.9321531433504733, 4.29350995990605}, {2.9321531433504733, \
4.39822971502571}, {3.036872898470133, 4.39822971502571}, 
     {3.036872898470133, 4.29350995990605}}]}, {CMYKColor[0.95, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{2.9321531433504733, 4.39822971502571}, {2.9321531433504733, \
4.50294947014537}, {3.036872898470133, 4.50294947014537}, 
     {3.036872898470133, 4.39822971502571}}]}, {CMYKColor[0.95, 0.5, 0.725, \
0.1], 
   Polygon[{{2.9321531433504733, 4.50294947014537}, {2.9321531433504733, \
4.607669225265029}, {3.036872898470133, 4.607669225265029}, 
     {3.036872898470133, 4.50294947014537}}]}, {CMYKColor[0.95, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{2.9321531433504733, 4.607669225265029}, {2.9321531433504733, \
4.71238898038469}, {3.036872898470133, 4.71238898038469}, 
     {3.036872898470133, 4.607669225265029}}]}, {CMYKColor[0.95, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 4.71238898038469}, {2.9321531433504733, \
4.817108735504349}, {3.036872898470133, 4.817108735504349}, 
     {3.036872898470133, 4.71238898038469}}]}, {CMYKColor[0.95, 0.5, 0.775, \
0.1], 
   Polygon[{{2.9321531433504733, 4.817108735504349}, {2.9321531433504733, \
4.921828490624009}, {3.036872898470133, 4.921828490624009}, 
     {3.036872898470133, 4.817108735504349}}]}, {CMYKColor[0.95, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{2.9321531433504733, 4.921828490624009}, {2.9321531433504733, \
5.026548245743669}, {3.036872898470133, 5.026548245743669}, 
     {3.036872898470133, 4.921828490624009}}]}, {CMYKColor[0.95, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 5.026548245743669}, {2.9321531433504733, \
5.1312680008633285}, {3.036872898470133, 5.1312680008633285}, 
     {3.036872898470133, 5.026548245743669}}]}, {CMYKColor[0.95, 0.5, 0.825, \
0.1], 
   Polygon[{{2.9321531433504733, 5.1312680008633285}, {2.9321531433504733, \
5.235987755982988}, {3.036872898470133, 5.235987755982988}, 
     {3.036872898470133, 5.1312680008633285}}]}, {CMYKColor[0.95, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{2.9321531433504733, 5.235987755982988}, {2.9321531433504733, \
5.340707511102648}, {3.036872898470133, 5.340707511102648}, 
     {3.036872898470133, 5.235987755982988}}]}, {CMYKColor[0.95, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 5.340707511102648}, {2.9321531433504733, \
5.445427266222308}, {3.036872898470133, 5.445427266222308}, 
     {3.036872898470133, 5.340707511102648}}]}, {CMYKColor[0.95, 0.5, 0.875, \
0.1], 
   Polygon[{{2.9321531433504733, 5.445427266222308}, {2.9321531433504733, \
5.550147021341967}, {3.036872898470133, 5.550147021341967}, 
     {3.036872898470133, 5.445427266222308}}]}, {CMYKColor[0.95, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{2.9321531433504733, 5.550147021341967}, {2.9321531433504733, \
5.654866776461628}, {3.036872898470133, 5.654866776461628}, 
     {3.036872898470133, 5.550147021341967}}]}, {CMYKColor[0.95, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{2.9321531433504733, 5.654866776461628}, {2.9321531433504733, \
5.759586531581287}, {3.036872898470133, 5.759586531581287}, 
     {3.036872898470133, 5.654866776461628}}]}, {CMYKColor[0.95, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{2.9321531433504733, 5.759586531581287}, {2.9321531433504733, \
5.864306286700947}, {3.036872898470133, 5.864306286700947}, 
     {3.036872898470133, 5.759586531581287}}]}, {CMYKColor[0.95, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{2.9321531433504733, 5.864306286700947}, {2.9321531433504733, \
5.969026041820607}, {3.036872898470133, 5.969026041820607}, 
     {3.036872898470133, 5.864306286700947}}]}, {CMYKColor[0.95, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{2.9321531433504733, 5.969026041820607}, {2.9321531433504733, \
6.073745796940266}, {3.036872898470133, 6.073745796940266}, 
     {3.036872898470133, 5.969026041820607}}]}, {CMYKColor[0.95, 0.5, 0.975, \
0.1], 
   Polygon[{{2.9321531433504733, 6.073745796940266}, {2.9321531433504733, \
6.178465552059926}, {3.036872898470133, 6.178465552059926}, 
     {3.036872898470133, 6.073745796940266}}]}, {CMYKColor[0.95, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{2.9321531433504733, 6.178465552059926}, {2.9321531433504733, \
6.283185307179586}, {3.036872898470133, 6.283185307179586}, 
     {3.036872898470133, 6.178465552059926}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{3.036872898470133, 0.}, {3.036872898470133, \
0.10471975511965977}, {3.141592653589793, 0.10471975511965977}, 
     {3.141592653589793, 0.}}]}, {CMYKColor[0.9833333333333333, 0.5, 0.025, \
0.1], 
   Polygon[{{3.036872898470133, 0.10471975511965977}, {3.036872898470133, \
0.20943951023931953}, {3.141592653589793, 0.20943951023931953}, 
     {3.141592653589793, 0.10471975511965977}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{3.036872898470133, 0.20943951023931953}, {3.036872898470133, \
0.3141592653589793}, {3.141592653589793, 0.3141592653589793}, 
     {3.141592653589793, 0.20943951023931953}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{3.036872898470133, 0.3141592653589793}, {3.036872898470133, \
0.41887902047863906}, {3.141592653589793, 0.41887902047863906}, 
     {3.141592653589793, 0.3141592653589793}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{3.036872898470133, 0.41887902047863906}, {3.036872898470133, \
0.5235987755982988}, {3.141592653589793, 0.5235987755982988}, 
     {3.141592653589793, 0.41887902047863906}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{3.036872898470133, 0.5235987755982988}, {3.036872898470133, \
0.6283185307179586}, {3.141592653589793, 0.6283185307179586}, 
     {3.141592653589793, 0.5235987755982988}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{3.036872898470133, 0.6283185307179586}, {3.036872898470133, \
0.7330382858376183}, {3.141592653589793, 0.7330382858376183}, 
     {3.141592653589793, 0.6283185307179586}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{3.036872898470133, 0.7330382858376183}, {3.036872898470133, \
0.8377580409572781}, {3.141592653589793, 0.8377580409572781}, 
     {3.141592653589793, 0.7330382858376183}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{3.036872898470133, 0.8377580409572781}, {3.036872898470133, \
0.9424777960769379}, {3.141592653589793, 0.9424777960769379}, 
     {3.141592653589793, 0.8377580409572781}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{3.036872898470133, 0.9424777960769379}, {3.036872898470133, \
1.0471975511965976}, {3.141592653589793, 1.0471975511965976}, 
     {3.141592653589793, 0.9424777960769379}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{3.036872898470133, 1.0471975511965976}, {3.036872898470133, \
1.1519173063162573}, {3.141592653589793, 1.1519173063162573}, 
     {3.141592653589793, 1.0471975511965976}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{3.036872898470133, 1.1519173063162573}, {3.036872898470133, \
1.2566370614359172}, {3.141592653589793, 1.2566370614359172}, 
     {3.141592653589793, 1.1519173063162573}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{3.036872898470133, 1.2566370614359172}, {3.036872898470133, \
1.361356816555577}, {3.141592653589793, 1.361356816555577}, 
     {3.141592653589793, 1.2566370614359172}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{3.036872898470133, 1.361356816555577}, {3.036872898470133, \
1.4660765716752366}, {3.141592653589793, 1.4660765716752366}, 
     {3.141592653589793, 1.361356816555577}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{3.036872898470133, 1.4660765716752366}, {3.036872898470133, \
1.5707963267948966}, {3.141592653589793, 1.5707963267948966}, 
     {3.141592653589793, 1.4660765716752366}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{3.036872898470133, 1.5707963267948966}, {3.036872898470133, \
1.6755160819145563}, {3.141592653589793, 1.6755160819145563}, 
     {3.141592653589793, 1.5707963267948966}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{3.036872898470133, 1.6755160819145563}, {3.036872898470133, \
1.780235837034216}, {3.141592653589793, 1.780235837034216}, 
     {3.141592653589793, 1.6755160819145563}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{3.036872898470133, 1.780235837034216}, {3.036872898470133, \
1.8849555921538759}, {3.141592653589793, 1.8849555921538759}, 
     {3.141592653589793, 1.780235837034216}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{3.036872898470133, 1.8849555921538759}, {3.036872898470133, \
1.9896753472735356}, {3.141592653589793, 1.9896753472735356}, 
     {3.141592653589793, 1.8849555921538759}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{3.036872898470133, 1.9896753472735356}, {3.036872898470133, \
2.0943951023931953}, {3.141592653589793, 2.0943951023931953}, 
     {3.141592653589793, 1.9896753472735356}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{3.036872898470133, 2.0943951023931953}, {3.036872898470133, \
2.199114857512855}, {3.141592653589793, 2.199114857512855}, 
     {3.141592653589793, 2.0943951023931953}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{3.036872898470133, 2.199114857512855}, {3.036872898470133, \
2.3038346126325147}, {3.141592653589793, 2.3038346126325147}, 
     {3.141592653589793, 2.199114857512855}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{3.036872898470133, 2.3038346126325147}, {3.036872898470133, \
2.4085543677521746}, {3.141592653589793, 2.4085543677521746}, 
     {3.141592653589793, 2.3038346126325147}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{3.036872898470133, 2.4085543677521746}, {3.036872898470133, \
2.5132741228718345}, {3.141592653589793, 2.5132741228718345}, 
     {3.141592653589793, 2.4085543677521746}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{3.036872898470133, 2.5132741228718345}, {3.036872898470133, \
2.617993877991494}, {3.141592653589793, 2.617993877991494}, 
     {3.141592653589793, 2.5132741228718345}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{3.036872898470133, 2.617993877991494}, {3.036872898470133, \
2.722713633111154}, {3.141592653589793, 2.722713633111154}, 
     {3.141592653589793, 2.617993877991494}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{3.036872898470133, 2.722713633111154}, {3.036872898470133, \
2.827433388230814}, {3.141592653589793, 2.827433388230814}, 
     {3.141592653589793, 2.722713633111154}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{3.036872898470133, 2.827433388230814}, {3.036872898470133, \
2.9321531433504733}, {3.141592653589793, 2.9321531433504733}, 
     {3.141592653589793, 2.827433388230814}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{3.036872898470133, 2.9321531433504733}, {3.036872898470133, \
3.036872898470133}, {3.141592653589793, 3.036872898470133}, 
     {3.141592653589793, 2.9321531433504733}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{3.036872898470133, 3.036872898470133}, {3.036872898470133, \
3.141592653589793}, {3.141592653589793, 3.141592653589793}, 
     {3.141592653589793, 3.036872898470133}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{3.036872898470133, 3.141592653589793}, {3.036872898470133, \
3.2463124087094526}, {3.141592653589793, 3.2463124087094526}, 
     {3.141592653589793, 3.141592653589793}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{3.036872898470133, 3.2463124087094526}, {3.036872898470133, \
3.3510321638291125}, {3.141592653589793, 3.3510321638291125}, 
     {3.141592653589793, 3.2463124087094526}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{3.036872898470133, 3.3510321638291125}, {3.036872898470133, \
3.4557519189487724}, {3.141592653589793, 3.4557519189487724}, 
     {3.141592653589793, 3.3510321638291125}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{3.036872898470133, 3.4557519189487724}, {3.036872898470133, \
3.560471674068432}, {3.141592653589793, 3.560471674068432}, 
     {3.141592653589793, 3.4557519189487724}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{3.036872898470133, 3.560471674068432}, {3.036872898470133, \
3.665191429188092}, {3.141592653589793, 3.665191429188092}, 
     {3.141592653589793, 3.560471674068432}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{3.036872898470133, 3.665191429188092}, {3.036872898470133, \
3.7699111843077517}, {3.141592653589793, 3.7699111843077517}, 
     {3.141592653589793, 3.665191429188092}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{3.036872898470133, 3.7699111843077517}, {3.036872898470133, \
3.874630939427411}, {3.141592653589793, 3.874630939427411}, 
     {3.141592653589793, 3.7699111843077517}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{3.036872898470133, 3.874630939427411}, {3.036872898470133, \
3.979350694547071}, {3.141592653589793, 3.979350694547071}, 
     {3.141592653589793, 3.874630939427411}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{3.036872898470133, 3.979350694547071}, {3.036872898470133, \
4.084070449666731}, {3.141592653589793, 4.084070449666731}, 
     {3.141592653589793, 3.979350694547071}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{3.036872898470133, 4.084070449666731}, {3.036872898470133, \
4.1887902047863905}, {3.141592653589793, 4.1887902047863905}, 
     {3.141592653589793, 4.084070449666731}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{3.036872898470133, 4.1887902047863905}, {3.036872898470133, \
4.29350995990605}, {3.141592653589793, 4.29350995990605}, 
     {3.141592653589793, 4.1887902047863905}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{3.036872898470133, 4.29350995990605}, {3.036872898470133, \
4.39822971502571}, {3.141592653589793, 4.39822971502571}, 
     {3.141592653589793, 4.29350995990605}}]}, {CMYKColor[0.9833333333333333, \
0.5, 0.7083333333333334, 0.1], 
   Polygon[{{3.036872898470133, 4.39822971502571}, {3.036872898470133, \
4.50294947014537}, {3.141592653589793, 4.50294947014537}, 
     {3.141592653589793, 4.39822971502571}}]}, {CMYKColor[0.9833333333333333, \
0.5, 0.725, 0.1], 
   Polygon[{{3.036872898470133, 4.50294947014537}, {3.036872898470133, \
4.607669225265029}, {3.141592653589793, 4.607669225265029}, 
     {3.141592653589793, 4.50294947014537}}]}, {CMYKColor[0.9833333333333333, \
0.5, 0.7416666666666667, 0.1], 
   Polygon[{{3.036872898470133, 4.607669225265029}, {3.036872898470133, \
4.71238898038469}, {3.141592653589793, 4.71238898038469}, 
     {3.141592653589793, 4.607669225265029}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{3.036872898470133, 4.71238898038469}, {3.036872898470133, \
4.817108735504349}, {3.141592653589793, 4.817108735504349}, 
     {3.141592653589793, 4.71238898038469}}]}, {CMYKColor[0.9833333333333333, \
0.5, 0.775, 0.1], 
   Polygon[{{3.036872898470133, 4.817108735504349}, {3.036872898470133, \
4.921828490624009}, {3.141592653589793, 4.921828490624009}, 
     {3.141592653589793, 4.817108735504349}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{3.036872898470133, 4.921828490624009}, {3.036872898470133, \
5.026548245743669}, {3.141592653589793, 5.026548245743669}, 
     {3.141592653589793, 4.921828490624009}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{3.036872898470133, 5.026548245743669}, {3.036872898470133, \
5.1312680008633285}, {3.141592653589793, 5.1312680008633285}, 
     {3.141592653589793, 5.026548245743669}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{3.036872898470133, 5.1312680008633285}, {3.036872898470133, \
5.235987755982988}, {3.141592653589793, 5.235987755982988}, 
     {3.141592653589793, 5.1312680008633285}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{3.036872898470133, 5.235987755982988}, {3.036872898470133, \
5.340707511102648}, {3.141592653589793, 5.340707511102648}, 
     {3.141592653589793, 5.235987755982988}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{3.036872898470133, 5.340707511102648}, {3.036872898470133, \
5.445427266222308}, {3.141592653589793, 5.445427266222308}, 
     {3.141592653589793, 5.340707511102648}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{3.036872898470133, 5.445427266222308}, {3.036872898470133, \
5.550147021341967}, {3.141592653589793, 5.550147021341967}, 
     {3.141592653589793, 5.445427266222308}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{3.036872898470133, 5.550147021341967}, {3.036872898470133, \
5.654866776461628}, {3.141592653589793, 5.654866776461628}, 
     {3.141592653589793, 5.550147021341967}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{3.036872898470133, 5.654866776461628}, {3.036872898470133, \
5.759586531581287}, {3.141592653589793, 5.759586531581287}, 
     {3.141592653589793, 5.654866776461628}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{3.036872898470133, 5.759586531581287}, {3.036872898470133, \
5.864306286700947}, {3.141592653589793, 5.864306286700947}, 
     {3.141592653589793, 5.759586531581287}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{3.036872898470133, 5.864306286700947}, {3.036872898470133, \
5.969026041820607}, {3.141592653589793, 5.969026041820607}, 
     {3.141592653589793, 5.864306286700947}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{3.036872898470133, 5.969026041820607}, {3.036872898470133, \
6.073745796940266}, {3.141592653589793, 6.073745796940266}, 
     {3.141592653589793, 5.969026041820607}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{3.036872898470133, 6.073745796940266}, {3.036872898470133, \
6.178465552059926}, {3.141592653589793, 6.178465552059926}, 
     {3.141592653589793, 6.073745796940266}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{3.036872898470133, 6.178465552059926}, {3.036872898470133, \
6.283185307179586}, {3.141592653589793, 6.283185307179586}, 
     {3.141592653589793, 6.178465552059926}}]}, Line[{{0., 0.}, {0., \
0.10471975511965977}, {0.10471975511965977, 0.10471975511965977}, 
    {0.10471975511965977, 0.}, {0., 0.}}], Line[{{0., 0.10471975511965977}, \
{0., 0.20943951023931953}, {0.10471975511965977, 0.20943951023931953}, 
    {0.10471975511965977, 0.10471975511965977}, {0., 0.10471975511965977}}], 
  Line[{{0., 0.20943951023931953}, {0., 0.3141592653589793}, \
{0.10471975511965977, 0.3141592653589793}, 
    {0.10471975511965977, 0.20943951023931953}, {0., 0.20943951023931953}}], 
  Line[{{0., 0.3141592653589793}, {0., 0.41887902047863906}, \
{0.10471975511965977, 0.41887902047863906}, 
    {0.10471975511965977, 0.3141592653589793}, {0., 0.3141592653589793}}], 
  Line[{{0., 0.41887902047863906}, {0., 0.5235987755982988}, \
{0.10471975511965977, 0.5235987755982988}, 
    {0.10471975511965977, 0.41887902047863906}, {0., 0.41887902047863906}}], 
  Line[{{0., 0.5235987755982988}, {0., 0.6283185307179586}, \
{0.10471975511965977, 0.6283185307179586}, {0.10471975511965977, \
0.5235987755982988}, 
    {0., 0.5235987755982988}}], Line[{{0., 0.6283185307179586}, {0., \
0.7330382858376183}, {0.10471975511965977, 0.7330382858376183}, 
    {0.10471975511965977, 0.6283185307179586}, {0., 0.6283185307179586}}], 
  Line[{{0., 0.7330382858376183}, {0., 0.8377580409572781}, \
{0.10471975511965977, 0.8377580409572781}, {0.10471975511965977, \
0.7330382858376183}, 
    {0., 0.7330382858376183}}], Line[{{0., 0.8377580409572781}, {0., \
0.9424777960769379}, {0.10471975511965977, 0.9424777960769379}, 
    {0.10471975511965977, 0.8377580409572781}, {0., 0.8377580409572781}}], 
  Line[{{0., 0.9424777960769379}, {0., 1.0471975511965976}, \
{0.10471975511965977, 1.0471975511965976}, {0.10471975511965977, \
0.9424777960769379}, 
    {0., 0.9424777960769379}}], Line[{{0., 1.0471975511965976}, {0., \
1.1519173063162573}, {0.10471975511965977, 1.1519173063162573}, 
    {0.10471975511965977, 1.0471975511965976}, {0., 1.0471975511965976}}], 
  Line[{{0., 1.1519173063162573}, {0., 1.2566370614359172}, \
{0.10471975511965977, 1.2566370614359172}, {0.10471975511965977, \
1.1519173063162573}, 
    {0., 1.1519173063162573}}], Line[{{0., 1.2566370614359172}, {0., \
1.361356816555577}, {0.10471975511965977, 1.361356816555577}, 
    {0.10471975511965977, 1.2566370614359172}, {0., 1.2566370614359172}}], 
  Line[{{0., 1.361356816555577}, {0., 1.4660765716752366}, \
{0.10471975511965977, 1.4660765716752366}, {0.10471975511965977, \
1.361356816555577}, 
    {0., 1.361356816555577}}], Line[{{0., 1.4660765716752366}, {0., \
1.5707963267948966}, {0.10471975511965977, 1.5707963267948966}, 
    {0.10471975511965977, 1.4660765716752366}, {0., 1.4660765716752366}}], 
  Line[{{0., 1.5707963267948966}, {0., 1.6755160819145563}, \
{0.10471975511965977, 1.6755160819145563}, {0.10471975511965977, \
1.5707963267948966}, 
    {0., 1.5707963267948966}}], Line[{{0., 1.6755160819145563}, {0., \
1.780235837034216}, {0.10471975511965977, 1.780235837034216}, 
    {0.10471975511965977, 1.6755160819145563}, {0., 1.6755160819145563}}], 
  Line[{{0., 1.780235837034216}, {0., 1.8849555921538759}, \
{0.10471975511965977, 1.8849555921538759}, {0.10471975511965977, \
1.780235837034216}, 
    {0., 1.780235837034216}}], Line[{{0., 1.8849555921538759}, {0., \
1.9896753472735356}, {0.10471975511965977, 1.9896753472735356}, 
    {0.10471975511965977, 1.8849555921538759}, {0., 1.8849555921538759}}], 
  Line[{{0., 1.9896753472735356}, {0., 2.0943951023931953}, \
{0.10471975511965977, 2.0943951023931953}, {0.10471975511965977, \
1.9896753472735356}, 
    {0., 1.9896753472735356}}], Line[{{0., 2.0943951023931953}, {0., \
2.199114857512855}, {0.10471975511965977, 2.199114857512855}, 
    {0.10471975511965977, 2.0943951023931953}, {0., 2.0943951023931953}}], 
  Line[{{0., 2.199114857512855}, {0., 2.3038346126325147}, \
{0.10471975511965977, 2.3038346126325147}, {0.10471975511965977, \
2.199114857512855}, 
    {0., 2.199114857512855}}], Line[{{0., 2.3038346126325147}, {0., \
2.4085543677521746}, {0.10471975511965977, 2.4085543677521746}, 
    {0.10471975511965977, 2.3038346126325147}, {0., 2.3038346126325147}}], 
  Line[{{0., 2.4085543677521746}, {0., 2.5132741228718345}, \
{0.10471975511965977, 2.5132741228718345}, {0.10471975511965977, \
2.4085543677521746}, 
    {0., 2.4085543677521746}}], Line[{{0., 2.5132741228718345}, {0., \
2.617993877991494}, {0.10471975511965977, 2.617993877991494}, 
    {0.10471975511965977, 2.5132741228718345}, {0., 2.5132741228718345}}], 
  Line[{{0., 2.617993877991494}, {0., 2.722713633111154}, \
{0.10471975511965977, 2.722713633111154}, {0.10471975511965977, \
2.617993877991494}, 
    {0., 2.617993877991494}}], Line[{{0., 2.722713633111154}, {0., \
2.827433388230814}, {0.10471975511965977, 2.827433388230814}, 
    {0.10471975511965977, 2.722713633111154}, {0., 2.722713633111154}}], 
  Line[{{0., 2.827433388230814}, {0., 2.9321531433504733}, \
{0.10471975511965977, 2.9321531433504733}, {0.10471975511965977, \
2.827433388230814}, 
    {0., 2.827433388230814}}], Line[{{0., 2.9321531433504733}, {0., \
3.036872898470133}, {0.10471975511965977, 3.036872898470133}, 
    {0.10471975511965977, 2.9321531433504733}, {0., 2.9321531433504733}}], 
  Line[{{0., 3.036872898470133}, {0., 3.141592653589793}, \
{0.10471975511965977, 3.141592653589793}, {0.10471975511965977, \
3.036872898470133}, 
    {0., 3.036872898470133}}], Line[{{0., 3.141592653589793}, {0., \
3.2463124087094526}, {0.10471975511965977, 3.2463124087094526}, 
    {0.10471975511965977, 3.141592653589793}, {0., 3.141592653589793}}], 
  Line[{{0., 3.2463124087094526}, {0., 3.3510321638291125}, \
{0.10471975511965977, 3.3510321638291125}, {0.10471975511965977, \
3.2463124087094526}, 
    {0., 3.2463124087094526}}], Line[{{0., 3.3510321638291125}, {0., \
3.4557519189487724}, {0.10471975511965977, 3.4557519189487724}, 
    {0.10471975511965977, 3.3510321638291125}, {0., 3.3510321638291125}}], 
  Line[{{0., 3.4557519189487724}, {0., 3.560471674068432}, \
{0.10471975511965977, 3.560471674068432}, {0.10471975511965977, \
3.4557519189487724}, 
    {0., 3.4557519189487724}}], Line[{{0., 3.560471674068432}, {0., \
3.665191429188092}, {0.10471975511965977, 3.665191429188092}, 
    {0.10471975511965977, 3.560471674068432}, {0., 3.560471674068432}}], 
  Line[{{0., 3.665191429188092}, {0., 3.7699111843077517}, \
{0.10471975511965977, 3.7699111843077517}, {0.10471975511965977, \
3.665191429188092}, 
    {0., 3.665191429188092}}], Line[{{0., 3.7699111843077517}, {0., \
3.874630939427411}, {0.10471975511965977, 3.874630939427411}, 
    {0.10471975511965977, 3.7699111843077517}, {0., 3.7699111843077517}}], 
  Line[{{0., 3.874630939427411}, {0., 3.979350694547071}, \
{0.10471975511965977, 3.979350694547071}, {0.10471975511965977, \
3.874630939427411}, 
    {0., 3.874630939427411}}], Line[{{0., 3.979350694547071}, {0., \
4.084070449666731}, {0.10471975511965977, 4.084070449666731}, 
    {0.10471975511965977, 3.979350694547071}, {0., 3.979350694547071}}], 
  Line[{{0., 4.084070449666731}, {0., 4.1887902047863905}, \
{0.10471975511965977, 4.1887902047863905}, {0.10471975511965977, \
4.084070449666731}, 
    {0., 4.084070449666731}}], Line[{{0., 4.1887902047863905}, {0., \
4.29350995990605}, {0.10471975511965977, 4.29350995990605}, 
    {0.10471975511965977, 4.1887902047863905}, {0., 4.1887902047863905}}], 
  Line[{{0., 4.29350995990605}, {0., 4.39822971502571}, {0.10471975511965977, \
4.39822971502571}, {0.10471975511965977, 4.29350995990605}, 
    {0., 4.29350995990605}}], Line[{{0., 4.39822971502571}, {0., \
4.50294947014537}, {0.10471975511965977, 4.50294947014537}, 
    {0.10471975511965977, 4.39822971502571}, {0., 4.39822971502571}}], 
  Line[{{0., 4.50294947014537}, {0., 4.607669225265029}, \
{0.10471975511965977, 4.607669225265029}, {0.10471975511965977, \
4.50294947014537}, 
    {0., 4.50294947014537}}], Line[{{0., 4.607669225265029}, {0., \
4.71238898038469}, {0.10471975511965977, 4.71238898038469}, 
    {0.10471975511965977, 4.607669225265029}, {0., 4.607669225265029}}], 
  Line[{{0., 4.71238898038469}, {0., 4.817108735504349}, \
{0.10471975511965977, 4.817108735504349}, {0.10471975511965977, \
4.71238898038469}, 
    {0., 4.71238898038469}}], Line[{{0., 4.817108735504349}, {0., \
4.921828490624009}, {0.10471975511965977, 4.921828490624009}, 
    {0.10471975511965977, 4.817108735504349}, {0., 4.817108735504349}}], 
  Line[{{0., 4.921828490624009}, {0., 5.026548245743669}, \
{0.10471975511965977, 5.026548245743669}, {0.10471975511965977, \
4.921828490624009}, 
    {0., 4.921828490624009}}], Line[{{0., 5.026548245743669}, {0., \
5.1312680008633285}, {0.10471975511965977, 5.1312680008633285}, 
    {0.10471975511965977, 5.026548245743669}, {0., 5.026548245743669}}], 
  Line[{{0., 5.1312680008633285}, {0., 5.235987755982988}, \
{0.10471975511965977, 5.235987755982988}, {0.10471975511965977, \
5.1312680008633285}, 
    {0., 5.1312680008633285}}], Line[{{0., 5.235987755982988}, {0., \
5.340707511102648}, {0.10471975511965977, 5.340707511102648}, 
    {0.10471975511965977, 5.235987755982988}, {0., 5.235987755982988}}], 
  Line[{{0., 5.340707511102648}, {0., 5.445427266222308}, \
{0.10471975511965977, 5.445427266222308}, {0.10471975511965977, \
5.340707511102648}, 
    {0., 5.340707511102648}}], Line[{{0., 5.445427266222308}, {0., \
5.550147021341967}, {0.10471975511965977, 5.550147021341967}, 
    {0.10471975511965977, 5.445427266222308}, {0., 5.445427266222308}}], 
  Line[{{0., 5.550147021341967}, {0., 5.654866776461628}, \
{0.10471975511965977, 5.654866776461628}, {0.10471975511965977, \
5.550147021341967}, 
    {0., 5.550147021341967}}], Line[{{0., 5.654866776461628}, {0., \
5.759586531581287}, {0.10471975511965977, 5.759586531581287}, 
    {0.10471975511965977, 5.654866776461628}, {0., 5.654866776461628}}], 
  Line[{{0., 5.759586531581287}, {0., 5.864306286700947}, \
{0.10471975511965977, 5.864306286700947}, {0.10471975511965977, \
5.759586531581287}, 
    {0., 5.759586531581287}}], Line[{{0., 5.864306286700947}, {0., \
5.969026041820607}, {0.10471975511965977, 5.969026041820607}, 
    {0.10471975511965977, 5.864306286700947}, {0., 5.864306286700947}}], 
  Line[{{0., 5.969026041820607}, {0., 6.073745796940266}, \
{0.10471975511965977, 6.073745796940266}, {0.10471975511965977, \
5.969026041820607}, 
    {0., 5.969026041820607}}], Line[{{0., 6.073745796940266}, {0., \
6.178465552059926}, {0.10471975511965977, 6.178465552059926}, 
    {0.10471975511965977, 6.073745796940266}, {0., 6.073745796940266}}], 
  Line[{{0., 6.178465552059926}, {0., 6.283185307179586}, \
{0.10471975511965977, 6.283185307179586}, {0.10471975511965977, \
6.178465552059926}, 
    {0., 6.178465552059926}}], Line[{{0.10471975511965977, 0.}, \
{0.10471975511965977, 0.10471975511965977}, 
    {0.20943951023931953, 0.10471975511965977}, {0.20943951023931953, 0.}, \
{0.10471975511965977, 0.}}], 
  Line[{{0.10471975511965977, 0.10471975511965977}, {0.10471975511965977, \
0.20943951023931953}, {0.20943951023931953, 0.20943951023931953}, 
    {0.20943951023931953, 0.10471975511965977}, {0.10471975511965977, \
0.10471975511965977}}], 
  Line[{{0.10471975511965977, 0.20943951023931953}, {0.10471975511965977, \
0.3141592653589793}, {0.20943951023931953, 0.3141592653589793}, 
    {0.20943951023931953, 0.20943951023931953}, {0.10471975511965977, \
0.20943951023931953}}], 
  Line[{{0.10471975511965977, 0.3141592653589793}, {0.10471975511965977, \
0.41887902047863906}, {0.20943951023931953, 0.41887902047863906}, 
    {0.20943951023931953, 0.3141592653589793}, {0.10471975511965977, \
0.3141592653589793}}], 
  Line[{{0.10471975511965977, 0.41887902047863906}, {0.10471975511965977, \
0.5235987755982988}, {0.20943951023931953, 0.5235987755982988}, 
    {0.20943951023931953, 0.41887902047863906}, {0.10471975511965977, \
0.41887902047863906}}], 
  Line[{{0.10471975511965977, 0.5235987755982988}, {0.10471975511965977, \
0.6283185307179586}, {0.20943951023931953, 0.6283185307179586}, 
    {0.20943951023931953, 0.5235987755982988}, {0.10471975511965977, \
0.5235987755982988}}], 
  Line[{{0.10471975511965977, 0.6283185307179586}, {0.10471975511965977, \
0.7330382858376183}, {0.20943951023931953, 0.7330382858376183}, 
    {0.20943951023931953, 0.6283185307179586}, {0.10471975511965977, \
0.6283185307179586}}], 
  Line[{{0.10471975511965977, 0.7330382858376183}, {0.10471975511965977, \
0.8377580409572781}, {0.20943951023931953, 0.8377580409572781}, 
    {0.20943951023931953, 0.7330382858376183}, {0.10471975511965977, \
0.7330382858376183}}], 
  Line[{{0.10471975511965977, 0.8377580409572781}, {0.10471975511965977, \
0.9424777960769379}, {0.20943951023931953, 0.9424777960769379}, 
    {0.20943951023931953, 0.8377580409572781}, {0.10471975511965977, \
0.8377580409572781}}], 
  Line[{{0.10471975511965977, 0.9424777960769379}, {0.10471975511965977, \
1.0471975511965976}, {0.20943951023931953, 1.0471975511965976}, 
    {0.20943951023931953, 0.9424777960769379}, {0.10471975511965977, \
0.9424777960769379}}], 
  Line[{{0.10471975511965977, 1.0471975511965976}, {0.10471975511965977, \
1.1519173063162573}, {0.20943951023931953, 1.1519173063162573}, 
    {0.20943951023931953, 1.0471975511965976}, {0.10471975511965977, \
1.0471975511965976}}], 
  Line[{{0.10471975511965977, 1.1519173063162573}, {0.10471975511965977, \
1.2566370614359172}, {0.20943951023931953, 1.2566370614359172}, 
    {0.20943951023931953, 1.1519173063162573}, {0.10471975511965977, \
1.1519173063162573}}], 
  Line[{{0.10471975511965977, 1.2566370614359172}, {0.10471975511965977, \
1.361356816555577}, {0.20943951023931953, 1.361356816555577}, 
    {0.20943951023931953, 1.2566370614359172}, {0.10471975511965977, \
1.2566370614359172}}], 
  Line[{{0.10471975511965977, 1.361356816555577}, {0.10471975511965977, \
1.4660765716752366}, {0.20943951023931953, 1.4660765716752366}, 
    {0.20943951023931953, 1.361356816555577}, {0.10471975511965977, \
1.361356816555577}}], 
  Line[{{0.10471975511965977, 1.4660765716752366}, {0.10471975511965977, \
1.5707963267948966}, {0.20943951023931953, 1.5707963267948966}, 
    {0.20943951023931953, 1.4660765716752366}, {0.10471975511965977, \
1.4660765716752366}}], 
  Line[{{0.10471975511965977, 1.5707963267948966}, {0.10471975511965977, \
1.6755160819145563}, {0.20943951023931953, 1.6755160819145563}, 
    {0.20943951023931953, 1.5707963267948966}, {0.10471975511965977, \
1.5707963267948966}}], 
  Line[{{0.10471975511965977, 1.6755160819145563}, {0.10471975511965977, \
1.780235837034216}, {0.20943951023931953, 1.780235837034216}, 
    {0.20943951023931953, 1.6755160819145563}, {0.10471975511965977, \
1.6755160819145563}}], 
  Line[{{0.10471975511965977, 1.780235837034216}, {0.10471975511965977, \
1.8849555921538759}, {0.20943951023931953, 1.8849555921538759}, 
    {0.20943951023931953, 1.780235837034216}, {0.10471975511965977, \
1.780235837034216}}], 
  Line[{{0.10471975511965977, 1.8849555921538759}, {0.10471975511965977, \
1.9896753472735356}, {0.20943951023931953, 1.9896753472735356}, 
    {0.20943951023931953, 1.8849555921538759}, {0.10471975511965977, \
1.8849555921538759}}], 
  Line[{{0.10471975511965977, 1.9896753472735356}, {0.10471975511965977, \
2.0943951023931953}, {0.20943951023931953, 2.0943951023931953}, 
    {0.20943951023931953, 1.9896753472735356}, {0.10471975511965977, \
1.9896753472735356}}], 
  Line[{{0.10471975511965977, 2.0943951023931953}, {0.10471975511965977, \
2.199114857512855}, {0.20943951023931953, 2.199114857512855}, 
    {0.20943951023931953, 2.0943951023931953}, {0.10471975511965977, \
2.0943951023931953}}], 
  Line[{{0.10471975511965977, 2.199114857512855}, {0.10471975511965977, \
2.3038346126325147}, {0.20943951023931953, 2.3038346126325147}, 
    {0.20943951023931953, 2.199114857512855}, {0.10471975511965977, \
2.199114857512855}}], 
  Line[{{0.10471975511965977, 2.3038346126325147}, {0.10471975511965977, \
2.4085543677521746}, {0.20943951023931953, 2.4085543677521746}, 
    {0.20943951023931953, 2.3038346126325147}, {0.10471975511965977, \
2.3038346126325147}}], 
  Line[{{0.10471975511965977, 2.4085543677521746}, {0.10471975511965977, \
2.5132741228718345}, {0.20943951023931953, 2.5132741228718345}, 
    {0.20943951023931953, 2.4085543677521746}, {0.10471975511965977, \
2.4085543677521746}}], 
  Line[{{0.10471975511965977, 2.5132741228718345}, {0.10471975511965977, \
2.617993877991494}, {0.20943951023931953, 2.617993877991494}, 
    {0.20943951023931953, 2.5132741228718345}, {0.10471975511965977, \
2.5132741228718345}}], 
  Line[{{0.10471975511965977, 2.617993877991494}, {0.10471975511965977, \
2.722713633111154}, {0.20943951023931953, 2.722713633111154}, 
    {0.20943951023931953, 2.617993877991494}, {0.10471975511965977, \
2.617993877991494}}], 
  Line[{{0.10471975511965977, 2.722713633111154}, {0.10471975511965977, \
2.827433388230814}, {0.20943951023931953, 2.827433388230814}, 
    {0.20943951023931953, 2.722713633111154}, {0.10471975511965977, \
2.722713633111154}}], 
  Line[{{0.10471975511965977, 2.827433388230814}, {0.10471975511965977, \
2.9321531433504733}, {0.20943951023931953, 2.9321531433504733}, 
    {0.20943951023931953, 2.827433388230814}, {0.10471975511965977, \
2.827433388230814}}], 
  Line[{{0.10471975511965977, 2.9321531433504733}, {0.10471975511965977, \
3.036872898470133}, {0.20943951023931953, 3.036872898470133}, 
    {0.20943951023931953, 2.9321531433504733}, {0.10471975511965977, \
2.9321531433504733}}], 
  Line[{{0.10471975511965977, 3.036872898470133}, {0.10471975511965977, \
3.141592653589793}, {0.20943951023931953, 3.141592653589793}, 
    {0.20943951023931953, 3.036872898470133}, {0.10471975511965977, \
3.036872898470133}}], 
  Line[{{0.10471975511965977, 3.141592653589793}, {0.10471975511965977, \
3.2463124087094526}, {0.20943951023931953, 3.2463124087094526}, 
    {0.20943951023931953, 3.141592653589793}, {0.10471975511965977, \
3.141592653589793}}], 
  Line[{{0.10471975511965977, 3.2463124087094526}, {0.10471975511965977, \
3.3510321638291125}, {0.20943951023931953, 3.3510321638291125}, 
    {0.20943951023931953, 3.2463124087094526}, {0.10471975511965977, \
3.2463124087094526}}], 
  Line[{{0.10471975511965977, 3.3510321638291125}, {0.10471975511965977, \
3.4557519189487724}, {0.20943951023931953, 3.4557519189487724}, 
    {0.20943951023931953, 3.3510321638291125}, {0.10471975511965977, \
3.3510321638291125}}], 
  Line[{{0.10471975511965977, 3.4557519189487724}, {0.10471975511965977, \
3.560471674068432}, {0.20943951023931953, 3.560471674068432}, 
    {0.20943951023931953, 3.4557519189487724}, {0.10471975511965977, \
3.4557519189487724}}], 
  Line[{{0.10471975511965977, 3.560471674068432}, {0.10471975511965977, \
3.665191429188092}, {0.20943951023931953, 3.665191429188092}, 
    {0.20943951023931953, 3.560471674068432}, {0.10471975511965977, \
3.560471674068432}}], 
  Line[{{0.10471975511965977, 3.665191429188092}, {0.10471975511965977, \
3.7699111843077517}, {0.20943951023931953, 3.7699111843077517}, 
    {0.20943951023931953, 3.665191429188092}, {0.10471975511965977, \
3.665191429188092}}], 
  Line[{{0.10471975511965977, 3.7699111843077517}, {0.10471975511965977, \
3.874630939427411}, {0.20943951023931953, 3.874630939427411}, 
    {0.20943951023931953, 3.7699111843077517}, {0.10471975511965977, \
3.7699111843077517}}], 
  Line[{{0.10471975511965977, 3.874630939427411}, {0.10471975511965977, \
3.979350694547071}, {0.20943951023931953, 3.979350694547071}, 
    {0.20943951023931953, 3.874630939427411}, {0.10471975511965977, \
3.874630939427411}}], 
  Line[{{0.10471975511965977, 3.979350694547071}, {0.10471975511965977, \
4.084070449666731}, {0.20943951023931953, 4.084070449666731}, 
    {0.20943951023931953, 3.979350694547071}, {0.10471975511965977, \
3.979350694547071}}], 
  Line[{{0.10471975511965977, 4.084070449666731}, {0.10471975511965977, \
4.1887902047863905}, {0.20943951023931953, 4.1887902047863905}, 
    {0.20943951023931953, 4.084070449666731}, {0.10471975511965977, \
4.084070449666731}}], 
  Line[{{0.10471975511965977, 4.1887902047863905}, {0.10471975511965977, \
4.29350995990605}, {0.20943951023931953, 4.29350995990605}, 
    {0.20943951023931953, 4.1887902047863905}, {0.10471975511965977, \
4.1887902047863905}}], 
  Line[{{0.10471975511965977, 4.29350995990605}, {0.10471975511965977, \
4.39822971502571}, {0.20943951023931953, 4.39822971502571}, 
    {0.20943951023931953, 4.29350995990605}, {0.10471975511965977, \
4.29350995990605}}], 
  Line[{{0.10471975511965977, 4.39822971502571}, {0.10471975511965977, \
4.50294947014537}, {0.20943951023931953, 4.50294947014537}, 
    {0.20943951023931953, 4.39822971502571}, {0.10471975511965977, \
4.39822971502571}}], 
  Line[{{0.10471975511965977, 4.50294947014537}, {0.10471975511965977, \
4.607669225265029}, {0.20943951023931953, 4.607669225265029}, 
    {0.20943951023931953, 4.50294947014537}, {0.10471975511965977, \
4.50294947014537}}], 
  Line[{{0.10471975511965977, 4.607669225265029}, {0.10471975511965977, \
4.71238898038469}, {0.20943951023931953, 4.71238898038469}, 
    {0.20943951023931953, 4.607669225265029}, {0.10471975511965977, \
4.607669225265029}}], 
  Line[{{0.10471975511965977, 4.71238898038469}, {0.10471975511965977, \
4.817108735504349}, {0.20943951023931953, 4.817108735504349}, 
    {0.20943951023931953, 4.71238898038469}, {0.10471975511965977, \
4.71238898038469}}], 
  Line[{{0.10471975511965977, 4.817108735504349}, {0.10471975511965977, \
4.921828490624009}, {0.20943951023931953, 4.921828490624009}, 
    {0.20943951023931953, 4.817108735504349}, {0.10471975511965977, \
4.817108735504349}}], 
  Line[{{0.10471975511965977, 4.921828490624009}, {0.10471975511965977, \
5.026548245743669}, {0.20943951023931953, 5.026548245743669}, 
    {0.20943951023931953, 4.921828490624009}, {0.10471975511965977, \
4.921828490624009}}], 
  Line[{{0.10471975511965977, 5.026548245743669}, {0.10471975511965977, \
5.1312680008633285}, {0.20943951023931953, 5.1312680008633285}, 
    {0.20943951023931953, 5.026548245743669}, {0.10471975511965977, \
5.026548245743669}}], 
  Line[{{0.10471975511965977, 5.1312680008633285}, {0.10471975511965977, \
5.235987755982988}, {0.20943951023931953, 5.235987755982988}, 
    {0.20943951023931953, 5.1312680008633285}, {0.10471975511965977, \
5.1312680008633285}}], 
  Line[{{0.10471975511965977, 5.235987755982988}, {0.10471975511965977, \
5.340707511102648}, {0.20943951023931953, 5.340707511102648}, 
    {0.20943951023931953, 5.235987755982988}, {0.10471975511965977, \
5.235987755982988}}], 
  Line[{{0.10471975511965977, 5.340707511102648}, {0.10471975511965977, \
5.445427266222308}, {0.20943951023931953, 5.445427266222308}, 
    {0.20943951023931953, 5.340707511102648}, {0.10471975511965977, \
5.340707511102648}}], 
  Line[{{0.10471975511965977, 5.445427266222308}, {0.10471975511965977, \
5.550147021341967}, {0.20943951023931953, 5.550147021341967}, 
    {0.20943951023931953, 5.445427266222308}, {0.10471975511965977, \
5.445427266222308}}], 
  Line[{{0.10471975511965977, 5.550147021341967}, {0.10471975511965977, \
5.654866776461628}, {0.20943951023931953, 5.654866776461628}, 
    {0.20943951023931953, 5.550147021341967}, {0.10471975511965977, \
5.550147021341967}}], 
  Line[{{0.10471975511965977, 5.654866776461628}, {0.10471975511965977, \
5.759586531581287}, {0.20943951023931953, 5.759586531581287}, 
    {0.20943951023931953, 5.654866776461628}, {0.10471975511965977, \
5.654866776461628}}], 
  Line[{{0.10471975511965977, 5.759586531581287}, {0.10471975511965977, \
5.864306286700947}, {0.20943951023931953, 5.864306286700947}, 
    {0.20943951023931953, 5.759586531581287}, {0.10471975511965977, \
5.759586531581287}}], 
  Line[{{0.10471975511965977, 5.864306286700947}, {0.10471975511965977, \
5.969026041820607}, {0.20943951023931953, 5.969026041820607}, 
    {0.20943951023931953, 5.864306286700947}, {0.10471975511965977, \
5.864306286700947}}], 
  Line[{{0.10471975511965977, 5.969026041820607}, {0.10471975511965977, \
6.073745796940266}, {0.20943951023931953, 6.073745796940266}, 
    {0.20943951023931953, 5.969026041820607}, {0.10471975511965977, \
5.969026041820607}}], 
  Line[{{0.10471975511965977, 6.073745796940266}, {0.10471975511965977, \
6.178465552059926}, {0.20943951023931953, 6.178465552059926}, 
    {0.20943951023931953, 6.073745796940266}, {0.10471975511965977, \
6.073745796940266}}], 
  Line[{{0.10471975511965977, 6.178465552059926}, {0.10471975511965977, \
6.283185307179586}, {0.20943951023931953, 6.283185307179586}, 
    {0.20943951023931953, 6.178465552059926}, {0.10471975511965977, \
6.178465552059926}}], 
  Line[{{0.20943951023931953, 0.}, {0.20943951023931953, \
0.10471975511965977}, {0.3141592653589793, 0.10471975511965977}, 
    {0.3141592653589793, 0.}, {0.20943951023931953, 0.}}], \
Line[{{0.20943951023931953, 0.10471975511965977}, 
    {0.20943951023931953, 0.20943951023931953}, {0.3141592653589793, \
0.20943951023931953}, {0.3141592653589793, 0.10471975511965977}, 
    {0.20943951023931953, 0.10471975511965977}}], Line[{{0.20943951023931953, \
0.20943951023931953}, {0.20943951023931953, 0.3141592653589793}, 
    {0.3141592653589793, 0.3141592653589793}, {0.3141592653589793, \
0.20943951023931953}, {0.20943951023931953, 0.20943951023931953}}], 
  Line[{{0.20943951023931953, 0.3141592653589793}, {0.20943951023931953, \
0.41887902047863906}, {0.3141592653589793, 0.41887902047863906}, 
    {0.3141592653589793, 0.3141592653589793}, {0.20943951023931953, \
0.3141592653589793}}], 
  Line[{{0.20943951023931953, 0.41887902047863906}, {0.20943951023931953, \
0.5235987755982988}, {0.3141592653589793, 0.5235987755982988}, 
    {0.3141592653589793, 0.41887902047863906}, {0.20943951023931953, \
0.41887902047863906}}], 
  Line[{{0.20943951023931953, 0.5235987755982988}, {0.20943951023931953, \
0.6283185307179586}, {0.3141592653589793, 0.6283185307179586}, 
    {0.3141592653589793, 0.5235987755982988}, {0.20943951023931953, \
0.5235987755982988}}], 
  Line[{{0.20943951023931953, 0.6283185307179586}, {0.20943951023931953, \
0.7330382858376183}, {0.3141592653589793, 0.7330382858376183}, 
    {0.3141592653589793, 0.6283185307179586}, {0.20943951023931953, \
0.6283185307179586}}], 
  Line[{{0.20943951023931953, 0.7330382858376183}, {0.20943951023931953, \
0.8377580409572781}, {0.3141592653589793, 0.8377580409572781}, 
    {0.3141592653589793, 0.7330382858376183}, {0.20943951023931953, \
0.7330382858376183}}], 
  Line[{{0.20943951023931953, 0.8377580409572781}, {0.20943951023931953, \
0.9424777960769379}, {0.3141592653589793, 0.9424777960769379}, 
    {0.3141592653589793, 0.8377580409572781}, {0.20943951023931953, \
0.8377580409572781}}], 
  Line[{{0.20943951023931953, 0.9424777960769379}, {0.20943951023931953, \
1.0471975511965976}, {0.3141592653589793, 1.0471975511965976}, 
    {0.3141592653589793, 0.9424777960769379}, {0.20943951023931953, \
0.9424777960769379}}], 
  Line[{{0.20943951023931953, 1.0471975511965976}, {0.20943951023931953, \
1.1519173063162573}, {0.3141592653589793, 1.1519173063162573}, 
    {0.3141592653589793, 1.0471975511965976}, {0.20943951023931953, \
1.0471975511965976}}], 
  Line[{{0.20943951023931953, 1.1519173063162573}, {0.20943951023931953, \
1.2566370614359172}, {0.3141592653589793, 1.2566370614359172}, 
    {0.3141592653589793, 1.1519173063162573}, {0.20943951023931953, \
1.1519173063162573}}], 
  Line[{{0.20943951023931953, 1.2566370614359172}, {0.20943951023931953, \
1.361356816555577}, {0.3141592653589793, 1.361356816555577}, 
    {0.3141592653589793, 1.2566370614359172}, {0.20943951023931953, \
1.2566370614359172}}], 
  Line[{{0.20943951023931953, 1.361356816555577}, {0.20943951023931953, \
1.4660765716752366}, {0.3141592653589793, 1.4660765716752366}, 
    {0.3141592653589793, 1.361356816555577}, {0.20943951023931953, \
1.361356816555577}}], 
  Line[{{0.20943951023931953, 1.4660765716752366}, {0.20943951023931953, \
1.5707963267948966}, {0.3141592653589793, 1.5707963267948966}, 
    {0.3141592653589793, 1.4660765716752366}, {0.20943951023931953, \
1.4660765716752366}}], 
  Line[{{0.20943951023931953, 1.5707963267948966}, {0.20943951023931953, \
1.6755160819145563}, {0.3141592653589793, 1.6755160819145563}, 
    {0.3141592653589793, 1.5707963267948966}, {0.20943951023931953, \
1.5707963267948966}}], 
  Line[{{0.20943951023931953, 1.6755160819145563}, {0.20943951023931953, \
1.780235837034216}, {0.3141592653589793, 1.780235837034216}, 
    {0.3141592653589793, 1.6755160819145563}, {0.20943951023931953, \
1.6755160819145563}}], 
  Line[{{0.20943951023931953, 1.780235837034216}, {0.20943951023931953, \
1.8849555921538759}, {0.3141592653589793, 1.8849555921538759}, 
    {0.3141592653589793, 1.780235837034216}, {0.20943951023931953, \
1.780235837034216}}], 
  Line[{{0.20943951023931953, 1.8849555921538759}, {0.20943951023931953, \
1.9896753472735356}, {0.3141592653589793, 1.9896753472735356}, 
    {0.3141592653589793, 1.8849555921538759}, {0.20943951023931953, \
1.8849555921538759}}], 
  Line[{{0.20943951023931953, 1.9896753472735356}, {0.20943951023931953, \
2.0943951023931953}, {0.3141592653589793, 2.0943951023931953}, 
    {0.3141592653589793, 1.9896753472735356}, {0.20943951023931953, \
1.9896753472735356}}], 
  Line[{{0.20943951023931953, 2.0943951023931953}, {0.20943951023931953, \
2.199114857512855}, {0.3141592653589793, 2.199114857512855}, 
    {0.3141592653589793, 2.0943951023931953}, {0.20943951023931953, \
2.0943951023931953}}], 
  Line[{{0.20943951023931953, 2.199114857512855}, {0.20943951023931953, \
2.3038346126325147}, {0.3141592653589793, 2.3038346126325147}, 
    {0.3141592653589793, 2.199114857512855}, {0.20943951023931953, \
2.199114857512855}}], 
  Line[{{0.20943951023931953, 2.3038346126325147}, {0.20943951023931953, \
2.4085543677521746}, {0.3141592653589793, 2.4085543677521746}, 
    {0.3141592653589793, 2.3038346126325147}, {0.20943951023931953, \
2.3038346126325147}}], 
  Line[{{0.20943951023931953, 2.4085543677521746}, {0.20943951023931953, \
2.5132741228718345}, {0.3141592653589793, 2.5132741228718345}, 
    {0.3141592653589793, 2.4085543677521746}, {0.20943951023931953, \
2.4085543677521746}}], 
  Line[{{0.20943951023931953, 2.5132741228718345}, {0.20943951023931953, \
2.617993877991494}, {0.3141592653589793, 2.617993877991494}, 
    {0.3141592653589793, 2.5132741228718345}, {0.20943951023931953, \
2.5132741228718345}}], 
  Line[{{0.20943951023931953, 2.617993877991494}, {0.20943951023931953, \
2.722713633111154}, {0.3141592653589793, 2.722713633111154}, 
    {0.3141592653589793, 2.617993877991494}, {0.20943951023931953, \
2.617993877991494}}], 
  Line[{{0.20943951023931953, 2.722713633111154}, {0.20943951023931953, \
2.827433388230814}, {0.3141592653589793, 2.827433388230814}, 
    {0.3141592653589793, 2.722713633111154}, {0.20943951023931953, \
2.722713633111154}}], 
  Line[{{0.20943951023931953, 2.827433388230814}, {0.20943951023931953, \
2.9321531433504733}, {0.3141592653589793, 2.9321531433504733}, 
    {0.3141592653589793, 2.827433388230814}, {0.20943951023931953, \
2.827433388230814}}], 
  Line[{{0.20943951023931953, 2.9321531433504733}, {0.20943951023931953, \
3.036872898470133}, {0.3141592653589793, 3.036872898470133}, 
    {0.3141592653589793, 2.9321531433504733}, {0.20943951023931953, \
2.9321531433504733}}], 
  Line[{{0.20943951023931953, 3.036872898470133}, {0.20943951023931953, \
3.141592653589793}, {0.3141592653589793, 3.141592653589793}, 
    {0.3141592653589793, 3.036872898470133}, {0.20943951023931953, \
3.036872898470133}}], 
  Line[{{0.20943951023931953, 3.141592653589793}, {0.20943951023931953, \
3.2463124087094526}, {0.3141592653589793, 3.2463124087094526}, 
    {0.3141592653589793, 3.141592653589793}, {0.20943951023931953, \
3.141592653589793}}], 
  Line[{{0.20943951023931953, 3.2463124087094526}, {0.20943951023931953, \
3.3510321638291125}, {0.3141592653589793, 3.3510321638291125}, 
    {0.3141592653589793, 3.2463124087094526}, {0.20943951023931953, \
3.2463124087094526}}], 
  Line[{{0.20943951023931953, 3.3510321638291125}, {0.20943951023931953, \
3.4557519189487724}, {0.3141592653589793, 3.4557519189487724}, 
    {0.3141592653589793, 3.3510321638291125}, {0.20943951023931953, \
3.3510321638291125}}], 
  Line[{{0.20943951023931953, 3.4557519189487724}, {0.20943951023931953, \
3.560471674068432}, {0.3141592653589793, 3.560471674068432}, 
    {0.3141592653589793, 3.4557519189487724}, {0.20943951023931953, \
3.4557519189487724}}], 
  Line[{{0.20943951023931953, 3.560471674068432}, {0.20943951023931953, \
3.665191429188092}, {0.3141592653589793, 3.665191429188092}, 
    {0.3141592653589793, 3.560471674068432}, {0.20943951023931953, \
3.560471674068432}}], 
  Line[{{0.20943951023931953, 3.665191429188092}, {0.20943951023931953, \
3.7699111843077517}, {0.3141592653589793, 3.7699111843077517}, 
    {0.3141592653589793, 3.665191429188092}, {0.20943951023931953, \
3.665191429188092}}], 
  Line[{{0.20943951023931953, 3.7699111843077517}, {0.20943951023931953, \
3.874630939427411}, {0.3141592653589793, 3.874630939427411}, 
    {0.3141592653589793, 3.7699111843077517}, {0.20943951023931953, \
3.7699111843077517}}], 
  Line[{{0.20943951023931953, 3.874630939427411}, {0.20943951023931953, \
3.979350694547071}, {0.3141592653589793, 3.979350694547071}, 
    {0.3141592653589793, 3.874630939427411}, {0.20943951023931953, \
3.874630939427411}}], 
  Line[{{0.20943951023931953, 3.979350694547071}, {0.20943951023931953, \
4.084070449666731}, {0.3141592653589793, 4.084070449666731}, 
    {0.3141592653589793, 3.979350694547071}, {0.20943951023931953, \
3.979350694547071}}], 
  Line[{{0.20943951023931953, 4.084070449666731}, {0.20943951023931953, \
4.1887902047863905}, {0.3141592653589793, 4.1887902047863905}, 
    {0.3141592653589793, 4.084070449666731}, {0.20943951023931953, \
4.084070449666731}}], 
  Line[{{0.20943951023931953, 4.1887902047863905}, {0.20943951023931953, \
4.29350995990605}, {0.3141592653589793, 4.29350995990605}, 
    {0.3141592653589793, 4.1887902047863905}, {0.20943951023931953, \
4.1887902047863905}}], 
  Line[{{0.20943951023931953, 4.29350995990605}, {0.20943951023931953, \
4.39822971502571}, {0.3141592653589793, 4.39822971502571}, 
    {0.3141592653589793, 4.29350995990605}, {0.20943951023931953, \
4.29350995990605}}], 
  Line[{{0.20943951023931953, 4.39822971502571}, {0.20943951023931953, \
4.50294947014537}, {0.3141592653589793, 4.50294947014537}, 
    {0.3141592653589793, 4.39822971502571}, {0.20943951023931953, \
4.39822971502571}}], 
  Line[{{0.20943951023931953, 4.50294947014537}, {0.20943951023931953, \
4.607669225265029}, {0.3141592653589793, 4.607669225265029}, 
    {0.3141592653589793, 4.50294947014537}, {0.20943951023931953, \
4.50294947014537}}], 
  Line[{{0.20943951023931953, 4.607669225265029}, {0.20943951023931953, \
4.71238898038469}, {0.3141592653589793, 4.71238898038469}, 
    {0.3141592653589793, 4.607669225265029}, {0.20943951023931953, \
4.607669225265029}}], 
  Line[{{0.20943951023931953, 4.71238898038469}, {0.20943951023931953, \
4.817108735504349}, {0.3141592653589793, 4.817108735504349}, 
    {0.3141592653589793, 4.71238898038469}, {0.20943951023931953, \
4.71238898038469}}], 
  Line[{{0.20943951023931953, 4.817108735504349}, {0.20943951023931953, \
4.921828490624009}, {0.3141592653589793, 4.921828490624009}, 
    {0.3141592653589793, 4.817108735504349}, {0.20943951023931953, \
4.817108735504349}}], 
  Line[{{0.20943951023931953, 4.921828490624009}, {0.20943951023931953, \
5.026548245743669}, {0.3141592653589793, 5.026548245743669}, 
    {0.3141592653589793, 4.921828490624009}, {0.20943951023931953, \
4.921828490624009}}], 
  Line[{{0.20943951023931953, 5.026548245743669}, {0.20943951023931953, \
5.1312680008633285}, {0.3141592653589793, 5.1312680008633285}, 
    {0.3141592653589793, 5.026548245743669}, {0.20943951023931953, \
5.026548245743669}}], 
  Line[{{0.20943951023931953, 5.1312680008633285}, {0.20943951023931953, \
5.235987755982988}, {0.3141592653589793, 5.235987755982988}, 
    {0.3141592653589793, 5.1312680008633285}, {0.20943951023931953, \
5.1312680008633285}}], 
  Line[{{0.20943951023931953, 5.235987755982988}, {0.20943951023931953, \
5.340707511102648}, {0.3141592653589793, 5.340707511102648}, 
    {0.3141592653589793, 5.235987755982988}, {0.20943951023931953, \
5.235987755982988}}], 
  Line[{{0.20943951023931953, 5.340707511102648}, {0.20943951023931953, \
5.445427266222308}, {0.3141592653589793, 5.445427266222308}, 
    {0.3141592653589793, 5.340707511102648}, {0.20943951023931953, \
5.340707511102648}}], 
  Line[{{0.20943951023931953, 5.445427266222308}, {0.20943951023931953, \
5.550147021341967}, {0.3141592653589793, 5.550147021341967}, 
    {0.3141592653589793, 5.445427266222308}, {0.20943951023931953, \
5.445427266222308}}], 
  Line[{{0.20943951023931953, 5.550147021341967}, {0.20943951023931953, \
5.654866776461628}, {0.3141592653589793, 5.654866776461628}, 
    {0.3141592653589793, 5.550147021341967}, {0.20943951023931953, \
5.550147021341967}}], 
  Line[{{0.20943951023931953, 5.654866776461628}, {0.20943951023931953, \
5.759586531581287}, {0.3141592653589793, 5.759586531581287}, 
    {0.3141592653589793, 5.654866776461628}, {0.20943951023931953, \
5.654866776461628}}], 
  Line[{{0.20943951023931953, 5.759586531581287}, {0.20943951023931953, \
5.864306286700947}, {0.3141592653589793, 5.864306286700947}, 
    {0.3141592653589793, 5.759586531581287}, {0.20943951023931953, \
5.759586531581287}}], 
  Line[{{0.20943951023931953, 5.864306286700947}, {0.20943951023931953, \
5.969026041820607}, {0.3141592653589793, 5.969026041820607}, 
    {0.3141592653589793, 5.864306286700947}, {0.20943951023931953, \
5.864306286700947}}], 
  Line[{{0.20943951023931953, 5.969026041820607}, {0.20943951023931953, \
6.073745796940266}, {0.3141592653589793, 6.073745796940266}, 
    {0.3141592653589793, 5.969026041820607}, {0.20943951023931953, \
5.969026041820607}}], 
  Line[{{0.20943951023931953, 6.073745796940266}, {0.20943951023931953, \
6.178465552059926}, {0.3141592653589793, 6.178465552059926}, 
    {0.3141592653589793, 6.073745796940266}, {0.20943951023931953, \
6.073745796940266}}], 
  Line[{{0.20943951023931953, 6.178465552059926}, {0.20943951023931953, \
6.283185307179586}, {0.3141592653589793, 6.283185307179586}, 
    {0.3141592653589793, 6.178465552059926}, {0.20943951023931953, \
6.178465552059926}}], 
  Line[{{0.3141592653589793, 0.}, {0.3141592653589793, 0.10471975511965977}, \
{0.41887902047863906, 0.10471975511965977}, 
    {0.41887902047863906, 0.}, {0.3141592653589793, 0.}}], \
Line[{{0.3141592653589793, 0.10471975511965977}, 
    {0.3141592653589793, 0.20943951023931953}, {0.41887902047863906, \
0.20943951023931953}, {0.41887902047863906, 0.10471975511965977}, 
    {0.3141592653589793, 0.10471975511965977}}], Line[{{0.3141592653589793, \
0.20943951023931953}, {0.3141592653589793, 0.3141592653589793}, 
    {0.41887902047863906, 0.3141592653589793}, {0.41887902047863906, \
0.20943951023931953}, {0.3141592653589793, 0.20943951023931953}}], 
  Line[{{0.3141592653589793, 0.3141592653589793}, {0.3141592653589793, \
0.41887902047863906}, {0.41887902047863906, 0.41887902047863906}, 
    {0.41887902047863906, 0.3141592653589793}, {0.3141592653589793, \
0.3141592653589793}}], 
  Line[{{0.3141592653589793, 0.41887902047863906}, {0.3141592653589793, \
0.5235987755982988}, {0.41887902047863906, 0.5235987755982988}, 
    {0.41887902047863906, 0.41887902047863906}, {0.3141592653589793, \
0.41887902047863906}}], 
  Line[{{0.3141592653589793, 0.5235987755982988}, {0.3141592653589793, \
0.6283185307179586}, {0.41887902047863906, 0.6283185307179586}, 
    {0.41887902047863906, 0.5235987755982988}, {0.3141592653589793, \
0.5235987755982988}}], 
  Line[{{0.3141592653589793, 0.6283185307179586}, {0.3141592653589793, \
0.7330382858376183}, {0.41887902047863906, 0.7330382858376183}, 
    {0.41887902047863906, 0.6283185307179586}, {0.3141592653589793, \
0.6283185307179586}}], 
  Line[{{0.3141592653589793, 0.7330382858376183}, {0.3141592653589793, \
0.8377580409572781}, {0.41887902047863906, 0.8377580409572781}, 
    {0.41887902047863906, 0.7330382858376183}, {0.3141592653589793, \
0.7330382858376183}}], 
  Line[{{0.3141592653589793, 0.8377580409572781}, {0.3141592653589793, \
0.9424777960769379}, {0.41887902047863906, 0.9424777960769379}, 
    {0.41887902047863906, 0.8377580409572781}, {0.3141592653589793, \
0.8377580409572781}}], 
  Line[{{0.3141592653589793, 0.9424777960769379}, {0.3141592653589793, \
1.0471975511965976}, {0.41887902047863906, 1.0471975511965976}, 
    {0.41887902047863906, 0.9424777960769379}, {0.3141592653589793, \
0.9424777960769379}}], 
  Line[{{0.3141592653589793, 1.0471975511965976}, {0.3141592653589793, \
1.1519173063162573}, {0.41887902047863906, 1.1519173063162573}, 
    {0.41887902047863906, 1.0471975511965976}, {0.3141592653589793, \
1.0471975511965976}}], 
  Line[{{0.3141592653589793, 1.1519173063162573}, {0.3141592653589793, \
1.2566370614359172}, {0.41887902047863906, 1.2566370614359172}, 
    {0.41887902047863906, 1.1519173063162573}, {0.3141592653589793, \
1.1519173063162573}}], 
  Line[{{0.3141592653589793, 1.2566370614359172}, {0.3141592653589793, \
1.361356816555577}, {0.41887902047863906, 1.361356816555577}, 
    {0.41887902047863906, 1.2566370614359172}, {0.3141592653589793, \
1.2566370614359172}}], 
  Line[{{0.3141592653589793, 1.361356816555577}, {0.3141592653589793, \
1.4660765716752366}, {0.41887902047863906, 1.4660765716752366}, 
    {0.41887902047863906, 1.361356816555577}, {0.3141592653589793, \
1.361356816555577}}], 
  Line[{{0.3141592653589793, 1.4660765716752366}, {0.3141592653589793, \
1.5707963267948966}, {0.41887902047863906, 1.5707963267948966}, 
    {0.41887902047863906, 1.4660765716752366}, {0.3141592653589793, \
1.4660765716752366}}], 
  Line[{{0.3141592653589793, 1.5707963267948966}, {0.3141592653589793, \
1.6755160819145563}, {0.41887902047863906, 1.6755160819145563}, 
    {0.41887902047863906, 1.5707963267948966}, {0.3141592653589793, \
1.5707963267948966}}], 
  Line[{{0.3141592653589793, 1.6755160819145563}, {0.3141592653589793, \
1.780235837034216}, {0.41887902047863906, 1.780235837034216}, 
    {0.41887902047863906, 1.6755160819145563}, {0.3141592653589793, \
1.6755160819145563}}], 
  Line[{{0.3141592653589793, 1.780235837034216}, {0.3141592653589793, \
1.8849555921538759}, {0.41887902047863906, 1.8849555921538759}, 
    {0.41887902047863906, 1.780235837034216}, {0.3141592653589793, \
1.780235837034216}}], 
  Line[{{0.3141592653589793, 1.8849555921538759}, {0.3141592653589793, \
1.9896753472735356}, {0.41887902047863906, 1.9896753472735356}, 
    {0.41887902047863906, 1.8849555921538759}, {0.3141592653589793, \
1.8849555921538759}}], 
  Line[{{0.3141592653589793, 1.9896753472735356}, {0.3141592653589793, \
2.0943951023931953}, {0.41887902047863906, 2.0943951023931953}, 
    {0.41887902047863906, 1.9896753472735356}, {0.3141592653589793, \
1.9896753472735356}}], 
  Line[{{0.3141592653589793, 2.0943951023931953}, {0.3141592653589793, \
2.199114857512855}, {0.41887902047863906, 2.199114857512855}, 
    {0.41887902047863906, 2.0943951023931953}, {0.3141592653589793, \
2.0943951023931953}}], 
  Line[{{0.3141592653589793, 2.199114857512855}, {0.3141592653589793, \
2.3038346126325147}, {0.41887902047863906, 2.3038346126325147}, 
    {0.41887902047863906, 2.199114857512855}, {0.3141592653589793, \
2.199114857512855}}], 
  Line[{{0.3141592653589793, 2.3038346126325147}, {0.3141592653589793, \
2.4085543677521746}, {0.41887902047863906, 2.4085543677521746}, 
    {0.41887902047863906, 2.3038346126325147}, {0.3141592653589793, \
2.3038346126325147}}], 
  Line[{{0.3141592653589793, 2.4085543677521746}, {0.3141592653589793, \
2.5132741228718345}, {0.41887902047863906, 2.5132741228718345}, 
    {0.41887902047863906, 2.4085543677521746}, {0.3141592653589793, \
2.4085543677521746}}], 
  Line[{{0.3141592653589793, 2.5132741228718345}, {0.3141592653589793, \
2.617993877991494}, {0.41887902047863906, 2.617993877991494}, 
    {0.41887902047863906, 2.5132741228718345}, {0.3141592653589793, \
2.5132741228718345}}], 
  Line[{{0.3141592653589793, 2.617993877991494}, {0.3141592653589793, \
2.722713633111154}, {0.41887902047863906, 2.722713633111154}, 
    {0.41887902047863906, 2.617993877991494}, {0.3141592653589793, \
2.617993877991494}}], 
  Line[{{0.3141592653589793, 2.722713633111154}, {0.3141592653589793, \
2.827433388230814}, {0.41887902047863906, 2.827433388230814}, 
    {0.41887902047863906, 2.722713633111154}, {0.3141592653589793, \
2.722713633111154}}], 
  Line[{{0.3141592653589793, 2.827433388230814}, {0.3141592653589793, \
2.9321531433504733}, {0.41887902047863906, 2.9321531433504733}, 
    {0.41887902047863906, 2.827433388230814}, {0.3141592653589793, \
2.827433388230814}}], 
  Line[{{0.3141592653589793, 2.9321531433504733}, {0.3141592653589793, \
3.036872898470133}, {0.41887902047863906, 3.036872898470133}, 
    {0.41887902047863906, 2.9321531433504733}, {0.3141592653589793, \
2.9321531433504733}}], 
  Line[{{0.3141592653589793, 3.036872898470133}, {0.3141592653589793, \
3.141592653589793}, {0.41887902047863906, 3.141592653589793}, 
    {0.41887902047863906, 3.036872898470133}, {0.3141592653589793, \
3.036872898470133}}], 
  Line[{{0.3141592653589793, 3.141592653589793}, {0.3141592653589793, \
3.2463124087094526}, {0.41887902047863906, 3.2463124087094526}, 
    {0.41887902047863906, 3.141592653589793}, {0.3141592653589793, \
3.141592653589793}}], 
  Line[{{0.3141592653589793, 3.2463124087094526}, {0.3141592653589793, \
3.3510321638291125}, {0.41887902047863906, 3.3510321638291125}, 
    {0.41887902047863906, 3.2463124087094526}, {0.3141592653589793, \
3.2463124087094526}}], 
  Line[{{0.3141592653589793, 3.3510321638291125}, {0.3141592653589793, \
3.4557519189487724}, {0.41887902047863906, 3.4557519189487724}, 
    {0.41887902047863906, 3.3510321638291125}, {0.3141592653589793, \
3.3510321638291125}}], 
  Line[{{0.3141592653589793, 3.4557519189487724}, {0.3141592653589793, \
3.560471674068432}, {0.41887902047863906, 3.560471674068432}, 
    {0.41887902047863906, 3.4557519189487724}, {0.3141592653589793, \
3.4557519189487724}}], 
  Line[{{0.3141592653589793, 3.560471674068432}, {0.3141592653589793, \
3.665191429188092}, {0.41887902047863906, 3.665191429188092}, 
    {0.41887902047863906, 3.560471674068432}, {0.3141592653589793, \
3.560471674068432}}], 
  Line[{{0.3141592653589793, 3.665191429188092}, {0.3141592653589793, \
3.7699111843077517}, {0.41887902047863906, 3.7699111843077517}, 
    {0.41887902047863906, 3.665191429188092}, {0.3141592653589793, \
3.665191429188092}}], 
  Line[{{0.3141592653589793, 3.7699111843077517}, {0.3141592653589793, \
3.874630939427411}, {0.41887902047863906, 3.874630939427411}, 
    {0.41887902047863906, 3.7699111843077517}, {0.3141592653589793, \
3.7699111843077517}}], 
  Line[{{0.3141592653589793, 3.874630939427411}, {0.3141592653589793, \
3.979350694547071}, {0.41887902047863906, 3.979350694547071}, 
    {0.41887902047863906, 3.874630939427411}, {0.3141592653589793, \
3.874630939427411}}], 
  Line[{{0.3141592653589793, 3.979350694547071}, {0.3141592653589793, \
4.084070449666731}, {0.41887902047863906, 4.084070449666731}, 
    {0.41887902047863906, 3.979350694547071}, {0.3141592653589793, \
3.979350694547071}}], 
  Line[{{0.3141592653589793, 4.084070449666731}, {0.3141592653589793, \
4.1887902047863905}, {0.41887902047863906, 4.1887902047863905}, 
    {0.41887902047863906, 4.084070449666731}, {0.3141592653589793, \
4.084070449666731}}], 
  Line[{{0.3141592653589793, 4.1887902047863905}, {0.3141592653589793, \
4.29350995990605}, {0.41887902047863906, 4.29350995990605}, 
    {0.41887902047863906, 4.1887902047863905}, {0.3141592653589793, \
4.1887902047863905}}], 
  Line[{{0.3141592653589793, 4.29350995990605}, {0.3141592653589793, \
4.39822971502571}, {0.41887902047863906, 4.39822971502571}, 
    {0.41887902047863906, 4.29350995990605}, {0.3141592653589793, \
4.29350995990605}}], 
  Line[{{0.3141592653589793, 4.39822971502571}, {0.3141592653589793, \
4.50294947014537}, {0.41887902047863906, 4.50294947014537}, 
    {0.41887902047863906, 4.39822971502571}, {0.3141592653589793, \
4.39822971502571}}], 
  Line[{{0.3141592653589793, 4.50294947014537}, {0.3141592653589793, \
4.607669225265029}, {0.41887902047863906, 4.607669225265029}, 
    {0.41887902047863906, 4.50294947014537}, {0.3141592653589793, \
4.50294947014537}}], 
  Line[{{0.3141592653589793, 4.607669225265029}, {0.3141592653589793, \
4.71238898038469}, {0.41887902047863906, 4.71238898038469}, 
    {0.41887902047863906, 4.607669225265029}, {0.3141592653589793, \
4.607669225265029}}], 
  Line[{{0.3141592653589793, 4.71238898038469}, {0.3141592653589793, \
4.817108735504349}, {0.41887902047863906, 4.817108735504349}, 
    {0.41887902047863906, 4.71238898038469}, {0.3141592653589793, \
4.71238898038469}}], 
  Line[{{0.3141592653589793, 4.817108735504349}, {0.3141592653589793, \
4.921828490624009}, {0.41887902047863906, 4.921828490624009}, 
    {0.41887902047863906, 4.817108735504349}, {0.3141592653589793, \
4.817108735504349}}], 
  Line[{{0.3141592653589793, 4.921828490624009}, {0.3141592653589793, \
5.026548245743669}, {0.41887902047863906, 5.026548245743669}, 
    {0.41887902047863906, 4.921828490624009}, {0.3141592653589793, \
4.921828490624009}}], 
  Line[{{0.3141592653589793, 5.026548245743669}, {0.3141592653589793, \
5.1312680008633285}, {0.41887902047863906, 5.1312680008633285}, 
    {0.41887902047863906, 5.026548245743669}, {0.3141592653589793, \
5.026548245743669}}], 
  Line[{{0.3141592653589793, 5.1312680008633285}, {0.3141592653589793, \
5.235987755982988}, {0.41887902047863906, 5.235987755982988}, 
    {0.41887902047863906, 5.1312680008633285}, {0.3141592653589793, \
5.1312680008633285}}], 
  Line[{{0.3141592653589793, 5.235987755982988}, {0.3141592653589793, \
5.340707511102648}, {0.41887902047863906, 5.340707511102648}, 
    {0.41887902047863906, 5.235987755982988}, {0.3141592653589793, \
5.235987755982988}}], 
  Line[{{0.3141592653589793, 5.340707511102648}, {0.3141592653589793, \
5.445427266222308}, {0.41887902047863906, 5.445427266222308}, 
    {0.41887902047863906, 5.340707511102648}, {0.3141592653589793, \
5.340707511102648}}], 
  Line[{{0.3141592653589793, 5.445427266222308}, {0.3141592653589793, \
5.550147021341967}, {0.41887902047863906, 5.550147021341967}, 
    {0.41887902047863906, 5.445427266222308}, {0.3141592653589793, \
5.445427266222308}}], 
  Line[{{0.3141592653589793, 5.550147021341967}, {0.3141592653589793, \
5.654866776461628}, {0.41887902047863906, 5.654866776461628}, 
    {0.41887902047863906, 5.550147021341967}, {0.3141592653589793, \
5.550147021341967}}], 
  Line[{{0.3141592653589793, 5.654866776461628}, {0.3141592653589793, \
5.759586531581287}, {0.41887902047863906, 5.759586531581287}, 
    {0.41887902047863906, 5.654866776461628}, {0.3141592653589793, \
5.654866776461628}}], 
  Line[{{0.3141592653589793, 5.759586531581287}, {0.3141592653589793, \
5.864306286700947}, {0.41887902047863906, 5.864306286700947}, 
    {0.41887902047863906, 5.759586531581287}, {0.3141592653589793, \
5.759586531581287}}], 
  Line[{{0.3141592653589793, 5.864306286700947}, {0.3141592653589793, \
5.969026041820607}, {0.41887902047863906, 5.969026041820607}, 
    {0.41887902047863906, 5.864306286700947}, {0.3141592653589793, \
5.864306286700947}}], 
  Line[{{0.3141592653589793, 5.969026041820607}, {0.3141592653589793, \
6.073745796940266}, {0.41887902047863906, 6.073745796940266}, 
    {0.41887902047863906, 5.969026041820607}, {0.3141592653589793, \
5.969026041820607}}], 
  Line[{{0.3141592653589793, 6.073745796940266}, {0.3141592653589793, \
6.178465552059926}, {0.41887902047863906, 6.178465552059926}, 
    {0.41887902047863906, 6.073745796940266}, {0.3141592653589793, \
6.073745796940266}}], 
  Line[{{0.3141592653589793, 6.178465552059926}, {0.3141592653589793, \
6.283185307179586}, {0.41887902047863906, 6.283185307179586}, 
    {0.41887902047863906, 6.178465552059926}, {0.3141592653589793, \
6.178465552059926}}], 
  Line[{{0.41887902047863906, 0.}, {0.41887902047863906, \
0.10471975511965977}, {0.5235987755982988, 0.10471975511965977}, 
    {0.5235987755982988, 0.}, {0.41887902047863906, 0.}}], \
Line[{{0.41887902047863906, 0.10471975511965977}, 
    {0.41887902047863906, 0.20943951023931953}, {0.5235987755982988, \
0.20943951023931953}, {0.5235987755982988, 0.10471975511965977}, 
    {0.41887902047863906, 0.10471975511965977}}], Line[{{0.41887902047863906, \
0.20943951023931953}, {0.41887902047863906, 0.3141592653589793}, 
    {0.5235987755982988, 0.3141592653589793}, {0.5235987755982988, \
0.20943951023931953}, {0.41887902047863906, 0.20943951023931953}}], 
  Line[{{0.41887902047863906, 0.3141592653589793}, {0.41887902047863906, \
0.41887902047863906}, {0.5235987755982988, 0.41887902047863906}, 
    {0.5235987755982988, 0.3141592653589793}, {0.41887902047863906, \
0.3141592653589793}}], 
  Line[{{0.41887902047863906, 0.41887902047863906}, {0.41887902047863906, \
0.5235987755982988}, {0.5235987755982988, 0.5235987755982988}, 
    {0.5235987755982988, 0.41887902047863906}, {0.41887902047863906, \
0.41887902047863906}}], 
  Line[{{0.41887902047863906, 0.5235987755982988}, {0.41887902047863906, \
0.6283185307179586}, {0.5235987755982988, 0.6283185307179586}, 
    {0.5235987755982988, 0.5235987755982988}, {0.41887902047863906, \
0.5235987755982988}}], 
  Line[{{0.41887902047863906, 0.6283185307179586}, {0.41887902047863906, \
0.7330382858376183}, {0.5235987755982988, 0.7330382858376183}, 
    {0.5235987755982988, 0.6283185307179586}, {0.41887902047863906, \
0.6283185307179586}}], 
  Line[{{0.41887902047863906, 0.7330382858376183}, {0.41887902047863906, \
0.8377580409572781}, {0.5235987755982988, 0.8377580409572781}, 
    {0.5235987755982988, 0.7330382858376183}, {0.41887902047863906, \
0.7330382858376183}}], 
  Line[{{0.41887902047863906, 0.8377580409572781}, {0.41887902047863906, \
0.9424777960769379}, {0.5235987755982988, 0.9424777960769379}, 
    {0.5235987755982988, 0.8377580409572781}, {0.41887902047863906, \
0.8377580409572781}}], 
  Line[{{0.41887902047863906, 0.9424777960769379}, {0.41887902047863906, \
1.0471975511965976}, {0.5235987755982988, 1.0471975511965976}, 
    {0.5235987755982988, 0.9424777960769379}, {0.41887902047863906, \
0.9424777960769379}}], 
  Line[{{0.41887902047863906, 1.0471975511965976}, {0.41887902047863906, \
1.1519173063162573}, {0.5235987755982988, 1.1519173063162573}, 
    {0.5235987755982988, 1.0471975511965976}, {0.41887902047863906, \
1.0471975511965976}}], 
  Line[{{0.41887902047863906, 1.1519173063162573}, {0.41887902047863906, \
1.2566370614359172}, {0.5235987755982988, 1.2566370614359172}, 
    {0.5235987755982988, 1.1519173063162573}, {0.41887902047863906, \
1.1519173063162573}}], 
  Line[{{0.41887902047863906, 1.2566370614359172}, {0.41887902047863906, \
1.361356816555577}, {0.5235987755982988, 1.361356816555577}, 
    {0.5235987755982988, 1.2566370614359172}, {0.41887902047863906, \
1.2566370614359172}}], 
  Line[{{0.41887902047863906, 1.361356816555577}, {0.41887902047863906, \
1.4660765716752366}, {0.5235987755982988, 1.4660765716752366}, 
    {0.5235987755982988, 1.361356816555577}, {0.41887902047863906, \
1.361356816555577}}], 
  Line[{{0.41887902047863906, 1.4660765716752366}, {0.41887902047863906, \
1.5707963267948966}, {0.5235987755982988, 1.5707963267948966}, 
    {0.5235987755982988, 1.4660765716752366}, {0.41887902047863906, \
1.4660765716752366}}], 
  Line[{{0.41887902047863906, 1.5707963267948966}, {0.41887902047863906, \
1.6755160819145563}, {0.5235987755982988, 1.6755160819145563}, 
    {0.5235987755982988, 1.5707963267948966}, {0.41887902047863906, \
1.5707963267948966}}], 
  Line[{{0.41887902047863906, 1.6755160819145563}, {0.41887902047863906, \
1.780235837034216}, {0.5235987755982988, 1.780235837034216}, 
    {0.5235987755982988, 1.6755160819145563}, {0.41887902047863906, \
1.6755160819145563}}], 
  Line[{{0.41887902047863906, 1.780235837034216}, {0.41887902047863906, \
1.8849555921538759}, {0.5235987755982988, 1.8849555921538759}, 
    {0.5235987755982988, 1.780235837034216}, {0.41887902047863906, \
1.780235837034216}}], 
  Line[{{0.41887902047863906, 1.8849555921538759}, {0.41887902047863906, \
1.9896753472735356}, {0.5235987755982988, 1.9896753472735356}, 
    {0.5235987755982988, 1.8849555921538759}, {0.41887902047863906, \
1.8849555921538759}}], 
  Line[{{0.41887902047863906, 1.9896753472735356}, {0.41887902047863906, \
2.0943951023931953}, {0.5235987755982988, 2.0943951023931953}, 
    {0.5235987755982988, 1.9896753472735356}, {0.41887902047863906, \
1.9896753472735356}}], 
  Line[{{0.41887902047863906, 2.0943951023931953}, {0.41887902047863906, \
2.199114857512855}, {0.5235987755982988, 2.199114857512855}, 
    {0.5235987755982988, 2.0943951023931953}, {0.41887902047863906, \
2.0943951023931953}}], 
  Line[{{0.41887902047863906, 2.199114857512855}, {0.41887902047863906, \
2.3038346126325147}, {0.5235987755982988, 2.3038346126325147}, 
    {0.5235987755982988, 2.199114857512855}, {0.41887902047863906, \
2.199114857512855}}], 
  Line[{{0.41887902047863906, 2.3038346126325147}, {0.41887902047863906, \
2.4085543677521746}, {0.5235987755982988, 2.4085543677521746}, 
    {0.5235987755982988, 2.3038346126325147}, {0.41887902047863906, \
2.3038346126325147}}], 
  Line[{{0.41887902047863906, 2.4085543677521746}, {0.41887902047863906, \
2.5132741228718345}, {0.5235987755982988, 2.5132741228718345}, 
    {0.5235987755982988, 2.4085543677521746}, {0.41887902047863906, \
2.4085543677521746}}], 
  Line[{{0.41887902047863906, 2.5132741228718345}, {0.41887902047863906, \
2.617993877991494}, {0.5235987755982988, 2.617993877991494}, 
    {0.5235987755982988, 2.5132741228718345}, {0.41887902047863906, \
2.5132741228718345}}], 
  Line[{{0.41887902047863906, 2.617993877991494}, {0.41887902047863906, \
2.722713633111154}, {0.5235987755982988, 2.722713633111154}, 
    {0.5235987755982988, 2.617993877991494}, {0.41887902047863906, \
2.617993877991494}}], 
  Line[{{0.41887902047863906, 2.722713633111154}, {0.41887902047863906, \
2.827433388230814}, {0.5235987755982988, 2.827433388230814}, 
    {0.5235987755982988, 2.722713633111154}, {0.41887902047863906, \
2.722713633111154}}], 
  Line[{{0.41887902047863906, 2.827433388230814}, {0.41887902047863906, \
2.9321531433504733}, {0.5235987755982988, 2.9321531433504733}, 
    {0.5235987755982988, 2.827433388230814}, {0.41887902047863906, \
2.827433388230814}}], 
  Line[{{0.41887902047863906, 2.9321531433504733}, {0.41887902047863906, \
3.036872898470133}, {0.5235987755982988, 3.036872898470133}, 
    {0.5235987755982988, 2.9321531433504733}, {0.41887902047863906, \
2.9321531433504733}}], 
  Line[{{0.41887902047863906, 3.036872898470133}, {0.41887902047863906, \
3.141592653589793}, {0.5235987755982988, 3.141592653589793}, 
    {0.5235987755982988, 3.036872898470133}, {0.41887902047863906, \
3.036872898470133}}], 
  Line[{{0.41887902047863906, 3.141592653589793}, {0.41887902047863906, \
3.2463124087094526}, {0.5235987755982988, 3.2463124087094526}, 
    {0.5235987755982988, 3.141592653589793}, {0.41887902047863906, \
3.141592653589793}}], 
  Line[{{0.41887902047863906, 3.2463124087094526}, {0.41887902047863906, \
3.3510321638291125}, {0.5235987755982988, 3.3510321638291125}, 
    {0.5235987755982988, 3.2463124087094526}, {0.41887902047863906, \
3.2463124087094526}}], 
  Line[{{0.41887902047863906, 3.3510321638291125}, {0.41887902047863906, \
3.4557519189487724}, {0.5235987755982988, 3.4557519189487724}, 
    {0.5235987755982988, 3.3510321638291125}, {0.41887902047863906, \
3.3510321638291125}}], 
  Line[{{0.41887902047863906, 3.4557519189487724}, {0.41887902047863906, \
3.560471674068432}, {0.5235987755982988, 3.560471674068432}, 
    {0.5235987755982988, 3.4557519189487724}, {0.41887902047863906, \
3.4557519189487724}}], 
  Line[{{0.41887902047863906, 3.560471674068432}, {0.41887902047863906, \
3.665191429188092}, {0.5235987755982988, 3.665191429188092}, 
    {0.5235987755982988, 3.560471674068432}, {0.41887902047863906, \
3.560471674068432}}], 
  Line[{{0.41887902047863906, 3.665191429188092}, {0.41887902047863906, \
3.7699111843077517}, {0.5235987755982988, 3.7699111843077517}, 
    {0.5235987755982988, 3.665191429188092}, {0.41887902047863906, \
3.665191429188092}}], 
  Line[{{0.41887902047863906, 3.7699111843077517}, {0.41887902047863906, \
3.874630939427411}, {0.5235987755982988, 3.874630939427411}, 
    {0.5235987755982988, 3.7699111843077517}, {0.41887902047863906, \
3.7699111843077517}}], 
  Line[{{0.41887902047863906, 3.874630939427411}, {0.41887902047863906, \
3.979350694547071}, {0.5235987755982988, 3.979350694547071}, 
    {0.5235987755982988, 3.874630939427411}, {0.41887902047863906, \
3.874630939427411}}], 
  Line[{{0.41887902047863906, 3.979350694547071}, {0.41887902047863906, \
4.084070449666731}, {0.5235987755982988, 4.084070449666731}, 
    {0.5235987755982988, 3.979350694547071}, {0.41887902047863906, \
3.979350694547071}}], 
  Line[{{0.41887902047863906, 4.084070449666731}, {0.41887902047863906, \
4.1887902047863905}, {0.5235987755982988, 4.1887902047863905}, 
    {0.5235987755982988, 4.084070449666731}, {0.41887902047863906, \
4.084070449666731}}], 
  Line[{{0.41887902047863906, 4.1887902047863905}, {0.41887902047863906, \
4.29350995990605}, {0.5235987755982988, 4.29350995990605}, 
    {0.5235987755982988, 4.1887902047863905}, {0.41887902047863906, \
4.1887902047863905}}], 
  Line[{{0.41887902047863906, 4.29350995990605}, {0.41887902047863906, \
4.39822971502571}, {0.5235987755982988, 4.39822971502571}, 
    {0.5235987755982988, 4.29350995990605}, {0.41887902047863906, \
4.29350995990605}}], 
  Line[{{0.41887902047863906, 4.39822971502571}, {0.41887902047863906, \
4.50294947014537}, {0.5235987755982988, 4.50294947014537}, 
    {0.5235987755982988, 4.39822971502571}, {0.41887902047863906, \
4.39822971502571}}], 
  Line[{{0.41887902047863906, 4.50294947014537}, {0.41887902047863906, \
4.607669225265029}, {0.5235987755982988, 4.607669225265029}, 
    {0.5235987755982988, 4.50294947014537}, {0.41887902047863906, \
4.50294947014537}}], 
  Line[{{0.41887902047863906, 4.607669225265029}, {0.41887902047863906, \
4.71238898038469}, {0.5235987755982988, 4.71238898038469}, 
    {0.5235987755982988, 4.607669225265029}, {0.41887902047863906, \
4.607669225265029}}], 
  Line[{{0.41887902047863906, 4.71238898038469}, {0.41887902047863906, \
4.817108735504349}, {0.5235987755982988, 4.817108735504349}, 
    {0.5235987755982988, 4.71238898038469}, {0.41887902047863906, \
4.71238898038469}}], 
  Line[{{0.41887902047863906, 4.817108735504349}, {0.41887902047863906, \
4.921828490624009}, {0.5235987755982988, 4.921828490624009}, 
    {0.5235987755982988, 4.817108735504349}, {0.41887902047863906, \
4.817108735504349}}], 
  Line[{{0.41887902047863906, 4.921828490624009}, {0.41887902047863906, \
5.026548245743669}, {0.5235987755982988, 5.026548245743669}, 
    {0.5235987755982988, 4.921828490624009}, {0.41887902047863906, \
4.921828490624009}}], 
  Line[{{0.41887902047863906, 5.026548245743669}, {0.41887902047863906, \
5.1312680008633285}, {0.5235987755982988, 5.1312680008633285}, 
    {0.5235987755982988, 5.026548245743669}, {0.41887902047863906, \
5.026548245743669}}], 
  Line[{{0.41887902047863906, 5.1312680008633285}, {0.41887902047863906, \
5.235987755982988}, {0.5235987755982988, 5.235987755982988}, 
    {0.5235987755982988, 5.1312680008633285}, {0.41887902047863906, \
5.1312680008633285}}], 
  Line[{{0.41887902047863906, 5.235987755982988}, {0.41887902047863906, \
5.340707511102648}, {0.5235987755982988, 5.340707511102648}, 
    {0.5235987755982988, 5.235987755982988}, {0.41887902047863906, \
5.235987755982988}}], 
  Line[{{0.41887902047863906, 5.340707511102648}, {0.41887902047863906, \
5.445427266222308}, {0.5235987755982988, 5.445427266222308}, 
    {0.5235987755982988, 5.340707511102648}, {0.41887902047863906, \
5.340707511102648}}], 
  Line[{{0.41887902047863906, 5.445427266222308}, {0.41887902047863906, \
5.550147021341967}, {0.5235987755982988, 5.550147021341967}, 
    {0.5235987755982988, 5.445427266222308}, {0.41887902047863906, \
5.445427266222308}}], 
  Line[{{0.41887902047863906, 5.550147021341967}, {0.41887902047863906, \
5.654866776461628}, {0.5235987755982988, 5.654866776461628}, 
    {0.5235987755982988, 5.550147021341967}, {0.41887902047863906, \
5.550147021341967}}], 
  Line[{{0.41887902047863906, 5.654866776461628}, {0.41887902047863906, \
5.759586531581287}, {0.5235987755982988, 5.759586531581287}, 
    {0.5235987755982988, 5.654866776461628}, {0.41887902047863906, \
5.654866776461628}}], 
  Line[{{0.41887902047863906, 5.759586531581287}, {0.41887902047863906, \
5.864306286700947}, {0.5235987755982988, 5.864306286700947}, 
    {0.5235987755982988, 5.759586531581287}, {0.41887902047863906, \
5.759586531581287}}], 
  Line[{{0.41887902047863906, 5.864306286700947}, {0.41887902047863906, \
5.969026041820607}, {0.5235987755982988, 5.969026041820607}, 
    {0.5235987755982988, 5.864306286700947}, {0.41887902047863906, \
5.864306286700947}}], 
  Line[{{0.41887902047863906, 5.969026041820607}, {0.41887902047863906, \
6.073745796940266}, {0.5235987755982988, 6.073745796940266}, 
    {0.5235987755982988, 5.969026041820607}, {0.41887902047863906, \
5.969026041820607}}], 
  Line[{{0.41887902047863906, 6.073745796940266}, {0.41887902047863906, \
6.178465552059926}, {0.5235987755982988, 6.178465552059926}, 
    {0.5235987755982988, 6.073745796940266}, {0.41887902047863906, \
6.073745796940266}}], 
  Line[{{0.41887902047863906, 6.178465552059926}, {0.41887902047863906, \
6.283185307179586}, {0.5235987755982988, 6.283185307179586}, 
    {0.5235987755982988, 6.178465552059926}, {0.41887902047863906, \
6.178465552059926}}], 
  Line[{{0.5235987755982988, 0.}, {0.5235987755982988, 0.10471975511965977}, \
{0.6283185307179586, 0.10471975511965977}, {0.6283185307179586, 0.}, 
    {0.5235987755982988, 0.}}], Line[{{0.5235987755982988, \
0.10471975511965977}, {0.5235987755982988, 0.20943951023931953}, 
    {0.6283185307179586, 0.20943951023931953}, {0.6283185307179586, \
0.10471975511965977}, {0.5235987755982988, 0.10471975511965977}}], 
  Line[{{0.5235987755982988, 0.20943951023931953}, {0.5235987755982988, \
0.3141592653589793}, {0.6283185307179586, 0.3141592653589793}, 
    {0.6283185307179586, 0.20943951023931953}, {0.5235987755982988, \
0.20943951023931953}}], 
  Line[{{0.5235987755982988, 0.3141592653589793}, {0.5235987755982988, \
0.41887902047863906}, {0.6283185307179586, 0.41887902047863906}, 
    {0.6283185307179586, 0.3141592653589793}, {0.5235987755982988, \
0.3141592653589793}}], 
  Line[{{0.5235987755982988, 0.41887902047863906}, {0.5235987755982988, \
0.5235987755982988}, {0.6283185307179586, 0.5235987755982988}, 
    {0.6283185307179586, 0.41887902047863906}, {0.5235987755982988, \
0.41887902047863906}}], 
  Line[{{0.5235987755982988, 0.5235987755982988}, {0.5235987755982988, \
0.6283185307179586}, {0.6283185307179586, 0.6283185307179586}, 
    {0.6283185307179586, 0.5235987755982988}, {0.5235987755982988, \
0.5235987755982988}}], 
  Line[{{0.5235987755982988, 0.6283185307179586}, {0.5235987755982988, \
0.7330382858376183}, {0.6283185307179586, 0.7330382858376183}, 
    {0.6283185307179586, 0.6283185307179586}, {0.5235987755982988, \
0.6283185307179586}}], 
  Line[{{0.5235987755982988, 0.7330382858376183}, {0.5235987755982988, \
0.8377580409572781}, {0.6283185307179586, 0.8377580409572781}, 
    {0.6283185307179586, 0.7330382858376183}, {0.5235987755982988, \
0.7330382858376183}}], 
  Line[{{0.5235987755982988, 0.8377580409572781}, {0.5235987755982988, \
0.9424777960769379}, {0.6283185307179586, 0.9424777960769379}, 
    {0.6283185307179586, 0.8377580409572781}, {0.5235987755982988, \
0.8377580409572781}}], 
  Line[{{0.5235987755982988, 0.9424777960769379}, {0.5235987755982988, \
1.0471975511965976}, {0.6283185307179586, 1.0471975511965976}, 
    {0.6283185307179586, 0.9424777960769379}, {0.5235987755982988, \
0.9424777960769379}}], 
  Line[{{0.5235987755982988, 1.0471975511965976}, {0.5235987755982988, \
1.1519173063162573}, {0.6283185307179586, 1.1519173063162573}, 
    {0.6283185307179586, 1.0471975511965976}, {0.5235987755982988, \
1.0471975511965976}}], 
  Line[{{0.5235987755982988, 1.1519173063162573}, {0.5235987755982988, \
1.2566370614359172}, {0.6283185307179586, 1.2566370614359172}, 
    {0.6283185307179586, 1.1519173063162573}, {0.5235987755982988, \
1.1519173063162573}}], 
  Line[{{0.5235987755982988, 1.2566370614359172}, {0.5235987755982988, \
1.361356816555577}, {0.6283185307179586, 1.361356816555577}, 
    {0.6283185307179586, 1.2566370614359172}, {0.5235987755982988, \
1.2566370614359172}}], 
  Line[{{0.5235987755982988, 1.361356816555577}, {0.5235987755982988, \
1.4660765716752366}, {0.6283185307179586, 1.4660765716752366}, 
    {0.6283185307179586, 1.361356816555577}, {0.5235987755982988, \
1.361356816555577}}], 
  Line[{{0.5235987755982988, 1.4660765716752366}, {0.5235987755982988, \
1.5707963267948966}, {0.6283185307179586, 1.5707963267948966}, 
    {0.6283185307179586, 1.4660765716752366}, {0.5235987755982988, \
1.4660765716752366}}], 
  Line[{{0.5235987755982988, 1.5707963267948966}, {0.5235987755982988, \
1.6755160819145563}, {0.6283185307179586, 1.6755160819145563}, 
    {0.6283185307179586, 1.5707963267948966}, {0.5235987755982988, \
1.5707963267948966}}], 
  Line[{{0.5235987755982988, 1.6755160819145563}, {0.5235987755982988, \
1.780235837034216}, {0.6283185307179586, 1.780235837034216}, 
    {0.6283185307179586, 1.6755160819145563}, {0.5235987755982988, \
1.6755160819145563}}], 
  Line[{{0.5235987755982988, 1.780235837034216}, {0.5235987755982988, \
1.8849555921538759}, {0.6283185307179586, 1.8849555921538759}, 
    {0.6283185307179586, 1.780235837034216}, {0.5235987755982988, \
1.780235837034216}}], 
  Line[{{0.5235987755982988, 1.8849555921538759}, {0.5235987755982988, \
1.9896753472735356}, {0.6283185307179586, 1.9896753472735356}, 
    {0.6283185307179586, 1.8849555921538759}, {0.5235987755982988, \
1.8849555921538759}}], 
  Line[{{0.5235987755982988, 1.9896753472735356}, {0.5235987755982988, \
2.0943951023931953}, {0.6283185307179586, 2.0943951023931953}, 
    {0.6283185307179586, 1.9896753472735356}, {0.5235987755982988, \
1.9896753472735356}}], 
  Line[{{0.5235987755982988, 2.0943951023931953}, {0.5235987755982988, \
2.199114857512855}, {0.6283185307179586, 2.199114857512855}, 
    {0.6283185307179586, 2.0943951023931953}, {0.5235987755982988, \
2.0943951023931953}}], 
  Line[{{0.5235987755982988, 2.199114857512855}, {0.5235987755982988, \
2.3038346126325147}, {0.6283185307179586, 2.3038346126325147}, 
    {0.6283185307179586, 2.199114857512855}, {0.5235987755982988, \
2.199114857512855}}], 
  Line[{{0.5235987755982988, 2.3038346126325147}, {0.5235987755982988, \
2.4085543677521746}, {0.6283185307179586, 2.4085543677521746}, 
    {0.6283185307179586, 2.3038346126325147}, {0.5235987755982988, \
2.3038346126325147}}], 
  Line[{{0.5235987755982988, 2.4085543677521746}, {0.5235987755982988, \
2.5132741228718345}, {0.6283185307179586, 2.5132741228718345}, 
    {0.6283185307179586, 2.4085543677521746}, {0.5235987755982988, \
2.4085543677521746}}], 
  Line[{{0.5235987755982988, 2.5132741228718345}, {0.5235987755982988, \
2.617993877991494}, {0.6283185307179586, 2.617993877991494}, 
    {0.6283185307179586, 2.5132741228718345}, {0.5235987755982988, \
2.5132741228718345}}], 
  Line[{{0.5235987755982988, 2.617993877991494}, {0.5235987755982988, \
2.722713633111154}, {0.6283185307179586, 2.722713633111154}, 
    {0.6283185307179586, 2.617993877991494}, {0.5235987755982988, \
2.617993877991494}}], 
  Line[{{0.5235987755982988, 2.722713633111154}, {0.5235987755982988, \
2.827433388230814}, {0.6283185307179586, 2.827433388230814}, 
    {0.6283185307179586, 2.722713633111154}, {0.5235987755982988, \
2.722713633111154}}], 
  Line[{{0.5235987755982988, 2.827433388230814}, {0.5235987755982988, \
2.9321531433504733}, {0.6283185307179586, 2.9321531433504733}, 
    {0.6283185307179586, 2.827433388230814}, {0.5235987755982988, \
2.827433388230814}}], 
  Line[{{0.5235987755982988, 2.9321531433504733}, {0.5235987755982988, \
3.036872898470133}, {0.6283185307179586, 3.036872898470133}, 
    {0.6283185307179586, 2.9321531433504733}, {0.5235987755982988, \
2.9321531433504733}}], 
  Line[{{0.5235987755982988, 3.036872898470133}, {0.5235987755982988, \
3.141592653589793}, {0.6283185307179586, 3.141592653589793}, 
    {0.6283185307179586, 3.036872898470133}, {0.5235987755982988, \
3.036872898470133}}], 
  Line[{{0.5235987755982988, 3.141592653589793}, {0.5235987755982988, \
3.2463124087094526}, {0.6283185307179586, 3.2463124087094526}, 
    {0.6283185307179586, 3.141592653589793}, {0.5235987755982988, \
3.141592653589793}}], 
  Line[{{0.5235987755982988, 3.2463124087094526}, {0.5235987755982988, \
3.3510321638291125}, {0.6283185307179586, 3.3510321638291125}, 
    {0.6283185307179586, 3.2463124087094526}, {0.5235987755982988, \
3.2463124087094526}}], 
  Line[{{0.5235987755982988, 3.3510321638291125}, {0.5235987755982988, \
3.4557519189487724}, {0.6283185307179586, 3.4557519189487724}, 
    {0.6283185307179586, 3.3510321638291125}, {0.5235987755982988, \
3.3510321638291125}}], 
  Line[{{0.5235987755982988, 3.4557519189487724}, {0.5235987755982988, \
3.560471674068432}, {0.6283185307179586, 3.560471674068432}, 
    {0.6283185307179586, 3.4557519189487724}, {0.5235987755982988, \
3.4557519189487724}}], 
  Line[{{0.5235987755982988, 3.560471674068432}, {0.5235987755982988, \
3.665191429188092}, {0.6283185307179586, 3.665191429188092}, 
    {0.6283185307179586, 3.560471674068432}, {0.5235987755982988, \
3.560471674068432}}], 
  Line[{{0.5235987755982988, 3.665191429188092}, {0.5235987755982988, \
3.7699111843077517}, {0.6283185307179586, 3.7699111843077517}, 
    {0.6283185307179586, 3.665191429188092}, {0.5235987755982988, \
3.665191429188092}}], 
  Line[{{0.5235987755982988, 3.7699111843077517}, {0.5235987755982988, \
3.874630939427411}, {0.6283185307179586, 3.874630939427411}, 
    {0.6283185307179586, 3.7699111843077517}, {0.5235987755982988, \
3.7699111843077517}}], 
  Line[{{0.5235987755982988, 3.874630939427411}, {0.5235987755982988, \
3.979350694547071}, {0.6283185307179586, 3.979350694547071}, 
    {0.6283185307179586, 3.874630939427411}, {0.5235987755982988, \
3.874630939427411}}], 
  Line[{{0.5235987755982988, 3.979350694547071}, {0.5235987755982988, \
4.084070449666731}, {0.6283185307179586, 4.084070449666731}, 
    {0.6283185307179586, 3.979350694547071}, {0.5235987755982988, \
3.979350694547071}}], 
  Line[{{0.5235987755982988, 4.084070449666731}, {0.5235987755982988, \
4.1887902047863905}, {0.6283185307179586, 4.1887902047863905}, 
    {0.6283185307179586, 4.084070449666731}, {0.5235987755982988, \
4.084070449666731}}], 
  Line[{{0.5235987755982988, 4.1887902047863905}, {0.5235987755982988, \
4.29350995990605}, {0.6283185307179586, 4.29350995990605}, 
    {0.6283185307179586, 4.1887902047863905}, {0.5235987755982988, \
4.1887902047863905}}], 
  Line[{{0.5235987755982988, 4.29350995990605}, {0.5235987755982988, \
4.39822971502571}, {0.6283185307179586, 4.39822971502571}, 
    {0.6283185307179586, 4.29350995990605}, {0.5235987755982988, \
4.29350995990605}}], 
  Line[{{0.5235987755982988, 4.39822971502571}, {0.5235987755982988, \
4.50294947014537}, {0.6283185307179586, 4.50294947014537}, 
    {0.6283185307179586, 4.39822971502571}, {0.5235987755982988, \
4.39822971502571}}], 
  Line[{{0.5235987755982988, 4.50294947014537}, {0.5235987755982988, \
4.607669225265029}, {0.6283185307179586, 4.607669225265029}, 
    {0.6283185307179586, 4.50294947014537}, {0.5235987755982988, \
4.50294947014537}}], 
  Line[{{0.5235987755982988, 4.607669225265029}, {0.5235987755982988, \
4.71238898038469}, {0.6283185307179586, 4.71238898038469}, 
    {0.6283185307179586, 4.607669225265029}, {0.5235987755982988, \
4.607669225265029}}], 
  Line[{{0.5235987755982988, 4.71238898038469}, {0.5235987755982988, \
4.817108735504349}, {0.6283185307179586, 4.817108735504349}, 
    {0.6283185307179586, 4.71238898038469}, {0.5235987755982988, \
4.71238898038469}}], 
  Line[{{0.5235987755982988, 4.817108735504349}, {0.5235987755982988, \
4.921828490624009}, {0.6283185307179586, 4.921828490624009}, 
    {0.6283185307179586, 4.817108735504349}, {0.5235987755982988, \
4.817108735504349}}], 
  Line[{{0.5235987755982988, 4.921828490624009}, {0.5235987755982988, \
5.026548245743669}, {0.6283185307179586, 5.026548245743669}, 
    {0.6283185307179586, 4.921828490624009}, {0.5235987755982988, \
4.921828490624009}}], 
  Line[{{0.5235987755982988, 5.026548245743669}, {0.5235987755982988, \
5.1312680008633285}, {0.6283185307179586, 5.1312680008633285}, 
    {0.6283185307179586, 5.026548245743669}, {0.5235987755982988, \
5.026548245743669}}], 
  Line[{{0.5235987755982988, 5.1312680008633285}, {0.5235987755982988, \
5.235987755982988}, {0.6283185307179586, 5.235987755982988}, 
    {0.6283185307179586, 5.1312680008633285}, {0.5235987755982988, \
5.1312680008633285}}], 
  Line[{{0.5235987755982988, 5.235987755982988}, {0.5235987755982988, \
5.340707511102648}, {0.6283185307179586, 5.340707511102648}, 
    {0.6283185307179586, 5.235987755982988}, {0.5235987755982988, \
5.235987755982988}}], 
  Line[{{0.5235987755982988, 5.340707511102648}, {0.5235987755982988, \
5.445427266222308}, {0.6283185307179586, 5.445427266222308}, 
    {0.6283185307179586, 5.340707511102648}, {0.5235987755982988, \
5.340707511102648}}], 
  Line[{{0.5235987755982988, 5.445427266222308}, {0.5235987755982988, \
5.550147021341967}, {0.6283185307179586, 5.550147021341967}, 
    {0.6283185307179586, 5.445427266222308}, {0.5235987755982988, \
5.445427266222308}}], 
  Line[{{0.5235987755982988, 5.550147021341967}, {0.5235987755982988, \
5.654866776461628}, {0.6283185307179586, 5.654866776461628}, 
    {0.6283185307179586, 5.550147021341967}, {0.5235987755982988, \
5.550147021341967}}], 
  Line[{{0.5235987755982988, 5.654866776461628}, {0.5235987755982988, \
5.759586531581287}, {0.6283185307179586, 5.759586531581287}, 
    {0.6283185307179586, 5.654866776461628}, {0.5235987755982988, \
5.654866776461628}}], 
  Line[{{0.5235987755982988, 5.759586531581287}, {0.5235987755982988, \
5.864306286700947}, {0.6283185307179586, 5.864306286700947}, 
    {0.6283185307179586, 5.759586531581287}, {0.5235987755982988, \
5.759586531581287}}], 
  Line[{{0.5235987755982988, 5.864306286700947}, {0.5235987755982988, \
5.969026041820607}, {0.6283185307179586, 5.969026041820607}, 
    {0.6283185307179586, 5.864306286700947}, {0.5235987755982988, \
5.864306286700947}}], 
  Line[{{0.5235987755982988, 5.969026041820607}, {0.5235987755982988, \
6.073745796940266}, {0.6283185307179586, 6.073745796940266}, 
    {0.6283185307179586, 5.969026041820607}, {0.5235987755982988, \
5.969026041820607}}], 
  Line[{{0.5235987755982988, 6.073745796940266}, {0.5235987755982988, \
6.178465552059926}, {0.6283185307179586, 6.178465552059926}, 
    {0.6283185307179586, 6.073745796940266}, {0.5235987755982988, \
6.073745796940266}}], 
  Line[{{0.5235987755982988, 6.178465552059926}, {0.5235987755982988, \
6.283185307179586}, {0.6283185307179586, 6.283185307179586}, 
    {0.6283185307179586, 6.178465552059926}, {0.5235987755982988, \
6.178465552059926}}], 
  Line[{{0.6283185307179586, 0.}, {0.6283185307179586, 0.10471975511965977}, \
{0.7330382858376183, 0.10471975511965977}, {0.7330382858376183, 0.}, 
    {0.6283185307179586, 0.}}], Line[{{0.6283185307179586, \
0.10471975511965977}, {0.6283185307179586, 0.20943951023931953}, 
    {0.7330382858376183, 0.20943951023931953}, {0.7330382858376183, \
0.10471975511965977}, {0.6283185307179586, 0.10471975511965977}}], 
  Line[{{0.6283185307179586, 0.20943951023931953}, {0.6283185307179586, \
0.3141592653589793}, {0.7330382858376183, 0.3141592653589793}, 
    {0.7330382858376183, 0.20943951023931953}, {0.6283185307179586, \
0.20943951023931953}}], 
  Line[{{0.6283185307179586, 0.3141592653589793}, {0.6283185307179586, \
0.41887902047863906}, {0.7330382858376183, 0.41887902047863906}, 
    {0.7330382858376183, 0.3141592653589793}, {0.6283185307179586, \
0.3141592653589793}}], 
  Line[{{0.6283185307179586, 0.41887902047863906}, {0.6283185307179586, \
0.5235987755982988}, {0.7330382858376183, 0.5235987755982988}, 
    {0.7330382858376183, 0.41887902047863906}, {0.6283185307179586, \
0.41887902047863906}}], 
  Line[{{0.6283185307179586, 0.5235987755982988}, {0.6283185307179586, \
0.6283185307179586}, {0.7330382858376183, 0.6283185307179586}, 
    {0.7330382858376183, 0.5235987755982988}, {0.6283185307179586, \
0.5235987755982988}}], 
  Line[{{0.6283185307179586, 0.6283185307179586}, {0.6283185307179586, \
0.7330382858376183}, {0.7330382858376183, 0.7330382858376183}, 
    {0.7330382858376183, 0.6283185307179586}, {0.6283185307179586, \
0.6283185307179586}}], 
  Line[{{0.6283185307179586, 0.7330382858376183}, {0.6283185307179586, \
0.8377580409572781}, {0.7330382858376183, 0.8377580409572781}, 
    {0.7330382858376183, 0.7330382858376183}, {0.6283185307179586, \
0.7330382858376183}}], 
  Line[{{0.6283185307179586, 0.8377580409572781}, {0.6283185307179586, \
0.9424777960769379}, {0.7330382858376183, 0.9424777960769379}, 
    {0.7330382858376183, 0.8377580409572781}, {0.6283185307179586, \
0.8377580409572781}}], 
  Line[{{0.6283185307179586, 0.9424777960769379}, {0.6283185307179586, \
1.0471975511965976}, {0.7330382858376183, 1.0471975511965976}, 
    {0.7330382858376183, 0.9424777960769379}, {0.6283185307179586, \
0.9424777960769379}}], 
  Line[{{0.6283185307179586, 1.0471975511965976}, {0.6283185307179586, \
1.1519173063162573}, {0.7330382858376183, 1.1519173063162573}, 
    {0.7330382858376183, 1.0471975511965976}, {0.6283185307179586, \
1.0471975511965976}}], 
  Line[{{0.6283185307179586, 1.1519173063162573}, {0.6283185307179586, \
1.2566370614359172}, {0.7330382858376183, 1.2566370614359172}, 
    {0.7330382858376183, 1.1519173063162573}, {0.6283185307179586, \
1.1519173063162573}}], 
  Line[{{0.6283185307179586, 1.2566370614359172}, {0.6283185307179586, \
1.361356816555577}, {0.7330382858376183, 1.361356816555577}, 
    {0.7330382858376183, 1.2566370614359172}, {0.6283185307179586, \
1.2566370614359172}}], 
  Line[{{0.6283185307179586, 1.361356816555577}, {0.6283185307179586, \
1.4660765716752366}, {0.7330382858376183, 1.4660765716752366}, 
    {0.7330382858376183, 1.361356816555577}, {0.6283185307179586, \
1.361356816555577}}], 
  Line[{{0.6283185307179586, 1.4660765716752366}, {0.6283185307179586, \
1.5707963267948966}, {0.7330382858376183, 1.5707963267948966}, 
    {0.7330382858376183, 1.4660765716752366}, {0.6283185307179586, \
1.4660765716752366}}], 
  Line[{{0.6283185307179586, 1.5707963267948966}, {0.6283185307179586, \
1.6755160819145563}, {0.7330382858376183, 1.6755160819145563}, 
    {0.7330382858376183, 1.5707963267948966}, {0.6283185307179586, \
1.5707963267948966}}], 
  Line[{{0.6283185307179586, 1.6755160819145563}, {0.6283185307179586, \
1.780235837034216}, {0.7330382858376183, 1.780235837034216}, 
    {0.7330382858376183, 1.6755160819145563}, {0.6283185307179586, \
1.6755160819145563}}], 
  Line[{{0.6283185307179586, 1.780235837034216}, {0.6283185307179586, \
1.8849555921538759}, {0.7330382858376183, 1.8849555921538759}, 
    {0.7330382858376183, 1.780235837034216}, {0.6283185307179586, \
1.780235837034216}}], 
  Line[{{0.6283185307179586, 1.8849555921538759}, {0.6283185307179586, \
1.9896753472735356}, {0.7330382858376183, 1.9896753472735356}, 
    {0.7330382858376183, 1.8849555921538759}, {0.6283185307179586, \
1.8849555921538759}}], 
  Line[{{0.6283185307179586, 1.9896753472735356}, {0.6283185307179586, \
2.0943951023931953}, {0.7330382858376183, 2.0943951023931953}, 
    {0.7330382858376183, 1.9896753472735356}, {0.6283185307179586, \
1.9896753472735356}}], 
  Line[{{0.6283185307179586, 2.0943951023931953}, {0.6283185307179586, \
2.199114857512855}, {0.7330382858376183, 2.199114857512855}, 
    {0.7330382858376183, 2.0943951023931953}, {0.6283185307179586, \
2.0943951023931953}}], 
  Line[{{0.6283185307179586, 2.199114857512855}, {0.6283185307179586, \
2.3038346126325147}, {0.7330382858376183, 2.3038346126325147}, 
    {0.7330382858376183, 2.199114857512855}, {0.6283185307179586, \
2.199114857512855}}], 
  Line[{{0.6283185307179586, 2.3038346126325147}, {0.6283185307179586, \
2.4085543677521746}, {0.7330382858376183, 2.4085543677521746}, 
    {0.7330382858376183, 2.3038346126325147}, {0.6283185307179586, \
2.3038346126325147}}], 
  Line[{{0.6283185307179586, 2.4085543677521746}, {0.6283185307179586, \
2.5132741228718345}, {0.7330382858376183, 2.5132741228718345}, 
    {0.7330382858376183, 2.4085543677521746}, {0.6283185307179586, \
2.4085543677521746}}], 
  Line[{{0.6283185307179586, 2.5132741228718345}, {0.6283185307179586, \
2.617993877991494}, {0.7330382858376183, 2.617993877991494}, 
    {0.7330382858376183, 2.5132741228718345}, {0.6283185307179586, \
2.5132741228718345}}], 
  Line[{{0.6283185307179586, 2.617993877991494}, {0.6283185307179586, \
2.722713633111154}, {0.7330382858376183, 2.722713633111154}, 
    {0.7330382858376183, 2.617993877991494}, {0.6283185307179586, \
2.617993877991494}}], 
  Line[{{0.6283185307179586, 2.722713633111154}, {0.6283185307179586, \
2.827433388230814}, {0.7330382858376183, 2.827433388230814}, 
    {0.7330382858376183, 2.722713633111154}, {0.6283185307179586, \
2.722713633111154}}], 
  Line[{{0.6283185307179586, 2.827433388230814}, {0.6283185307179586, \
2.9321531433504733}, {0.7330382858376183, 2.9321531433504733}, 
    {0.7330382858376183, 2.827433388230814}, {0.6283185307179586, \
2.827433388230814}}], 
  Line[{{0.6283185307179586, 2.9321531433504733}, {0.6283185307179586, \
3.036872898470133}, {0.7330382858376183, 3.036872898470133}, 
    {0.7330382858376183, 2.9321531433504733}, {0.6283185307179586, \
2.9321531433504733}}], 
  Line[{{0.6283185307179586, 3.036872898470133}, {0.6283185307179586, \
3.141592653589793}, {0.7330382858376183, 3.141592653589793}, 
    {0.7330382858376183, 3.036872898470133}, {0.6283185307179586, \
3.036872898470133}}], 
  Line[{{0.6283185307179586, 3.141592653589793}, {0.6283185307179586, \
3.2463124087094526}, {0.7330382858376183, 3.2463124087094526}, 
    {0.7330382858376183, 3.141592653589793}, {0.6283185307179586, \
3.141592653589793}}], 
  Line[{{0.6283185307179586, 3.2463124087094526}, {0.6283185307179586, \
3.3510321638291125}, {0.7330382858376183, 3.3510321638291125}, 
    {0.7330382858376183, 3.2463124087094526}, {0.6283185307179586, \
3.2463124087094526}}], 
  Line[{{0.6283185307179586, 3.3510321638291125}, {0.6283185307179586, \
3.4557519189487724}, {0.7330382858376183, 3.4557519189487724}, 
    {0.7330382858376183, 3.3510321638291125}, {0.6283185307179586, \
3.3510321638291125}}], 
  Line[{{0.6283185307179586, 3.4557519189487724}, {0.6283185307179586, \
3.560471674068432}, {0.7330382858376183, 3.560471674068432}, 
    {0.7330382858376183, 3.4557519189487724}, {0.6283185307179586, \
3.4557519189487724}}], 
  Line[{{0.6283185307179586, 3.560471674068432}, {0.6283185307179586, \
3.665191429188092}, {0.7330382858376183, 3.665191429188092}, 
    {0.7330382858376183, 3.560471674068432}, {0.6283185307179586, \
3.560471674068432}}], 
  Line[{{0.6283185307179586, 3.665191429188092}, {0.6283185307179586, \
3.7699111843077517}, {0.7330382858376183, 3.7699111843077517}, 
    {0.7330382858376183, 3.665191429188092}, {0.6283185307179586, \
3.665191429188092}}], 
  Line[{{0.6283185307179586, 3.7699111843077517}, {0.6283185307179586, \
3.874630939427411}, {0.7330382858376183, 3.874630939427411}, 
    {0.7330382858376183, 3.7699111843077517}, {0.6283185307179586, \
3.7699111843077517}}], 
  Line[{{0.6283185307179586, 3.874630939427411}, {0.6283185307179586, \
3.979350694547071}, {0.7330382858376183, 3.979350694547071}, 
    {0.7330382858376183, 3.874630939427411}, {0.6283185307179586, \
3.874630939427411}}], 
  Line[{{0.6283185307179586, 3.979350694547071}, {0.6283185307179586, \
4.084070449666731}, {0.7330382858376183, 4.084070449666731}, 
    {0.7330382858376183, 3.979350694547071}, {0.6283185307179586, \
3.979350694547071}}], 
  Line[{{0.6283185307179586, 4.084070449666731}, {0.6283185307179586, \
4.1887902047863905}, {0.7330382858376183, 4.1887902047863905}, 
    {0.7330382858376183, 4.084070449666731}, {0.6283185307179586, \
4.084070449666731}}], 
  Line[{{0.6283185307179586, 4.1887902047863905}, {0.6283185307179586, \
4.29350995990605}, {0.7330382858376183, 4.29350995990605}, 
    {0.7330382858376183, 4.1887902047863905}, {0.6283185307179586, \
4.1887902047863905}}], 
  Line[{{0.6283185307179586, 4.29350995990605}, {0.6283185307179586, \
4.39822971502571}, {0.7330382858376183, 4.39822971502571}, 
    {0.7330382858376183, 4.29350995990605}, {0.6283185307179586, \
4.29350995990605}}], 
  Line[{{0.6283185307179586, 4.39822971502571}, {0.6283185307179586, \
4.50294947014537}, {0.7330382858376183, 4.50294947014537}, 
    {0.7330382858376183, 4.39822971502571}, {0.6283185307179586, \
4.39822971502571}}], 
  Line[{{0.6283185307179586, 4.50294947014537}, {0.6283185307179586, \
4.607669225265029}, {0.7330382858376183, 4.607669225265029}, 
    {0.7330382858376183, 4.50294947014537}, {0.6283185307179586, \
4.50294947014537}}], 
  Line[{{0.6283185307179586, 4.607669225265029}, {0.6283185307179586, \
4.71238898038469}, {0.7330382858376183, 4.71238898038469}, 
    {0.7330382858376183, 4.607669225265029}, {0.6283185307179586, \
4.607669225265029}}], 
  Line[{{0.6283185307179586, 4.71238898038469}, {0.6283185307179586, \
4.817108735504349}, {0.7330382858376183, 4.817108735504349}, 
    {0.7330382858376183, 4.71238898038469}, {0.6283185307179586, \
4.71238898038469}}], 
  Line[{{0.6283185307179586, 4.817108735504349}, {0.6283185307179586, \
4.921828490624009}, {0.7330382858376183, 4.921828490624009}, 
    {0.7330382858376183, 4.817108735504349}, {0.6283185307179586, \
4.817108735504349}}], 
  Line[{{0.6283185307179586, 4.921828490624009}, {0.6283185307179586, \
5.026548245743669}, {0.7330382858376183, 5.026548245743669}, 
    {0.7330382858376183, 4.921828490624009}, {0.6283185307179586, \
4.921828490624009}}], 
  Line[{{0.6283185307179586, 5.026548245743669}, {0.6283185307179586, \
5.1312680008633285}, {0.7330382858376183, 5.1312680008633285}, 
    {0.7330382858376183, 5.026548245743669}, {0.6283185307179586, \
5.026548245743669}}], 
  Line[{{0.6283185307179586, 5.1312680008633285}, {0.6283185307179586, \
5.235987755982988}, {0.7330382858376183, 5.235987755982988}, 
    {0.7330382858376183, 5.1312680008633285}, {0.6283185307179586, \
5.1312680008633285}}], 
  Line[{{0.6283185307179586, 5.235987755982988}, {0.6283185307179586, \
5.340707511102648}, {0.7330382858376183, 5.340707511102648}, 
    {0.7330382858376183, 5.235987755982988}, {0.6283185307179586, \
5.235987755982988}}], 
  Line[{{0.6283185307179586, 5.340707511102648}, {0.6283185307179586, \
5.445427266222308}, {0.7330382858376183, 5.445427266222308}, 
    {0.7330382858376183, 5.340707511102648}, {0.6283185307179586, \
5.340707511102648}}], 
  Line[{{0.6283185307179586, 5.445427266222308}, {0.6283185307179586, \
5.550147021341967}, {0.7330382858376183, 5.550147021341967}, 
    {0.7330382858376183, 5.445427266222308}, {0.6283185307179586, \
5.445427266222308}}], 
  Line[{{0.6283185307179586, 5.550147021341967}, {0.6283185307179586, \
5.654866776461628}, {0.7330382858376183, 5.654866776461628}, 
    {0.7330382858376183, 5.550147021341967}, {0.6283185307179586, \
5.550147021341967}}], 
  Line[{{0.6283185307179586, 5.654866776461628}, {0.6283185307179586, \
5.759586531581287}, {0.7330382858376183, 5.759586531581287}, 
    {0.7330382858376183, 5.654866776461628}, {0.6283185307179586, \
5.654866776461628}}], 
  Line[{{0.6283185307179586, 5.759586531581287}, {0.6283185307179586, \
5.864306286700947}, {0.7330382858376183, 5.864306286700947}, 
    {0.7330382858376183, 5.759586531581287}, {0.6283185307179586, \
5.759586531581287}}], 
  Line[{{0.6283185307179586, 5.864306286700947}, {0.6283185307179586, \
5.969026041820607}, {0.7330382858376183, 5.969026041820607}, 
    {0.7330382858376183, 5.864306286700947}, {0.6283185307179586, \
5.864306286700947}}], 
  Line[{{0.6283185307179586, 5.969026041820607}, {0.6283185307179586, \
6.073745796940266}, {0.7330382858376183, 6.073745796940266}, 
    {0.7330382858376183, 5.969026041820607}, {0.6283185307179586, \
5.969026041820607}}], 
  Line[{{0.6283185307179586, 6.073745796940266}, {0.6283185307179586, \
6.178465552059926}, {0.7330382858376183, 6.178465552059926}, 
    {0.7330382858376183, 6.073745796940266}, {0.6283185307179586, \
6.073745796940266}}], 
  Line[{{0.6283185307179586, 6.178465552059926}, {0.6283185307179586, \
6.283185307179586}, {0.7330382858376183, 6.283185307179586}, 
    {0.7330382858376183, 6.178465552059926}, {0.6283185307179586, \
6.178465552059926}}], 
  Line[{{0.7330382858376183, 0.}, {0.7330382858376183, 0.10471975511965977}, \
{0.8377580409572781, 0.10471975511965977}, {0.8377580409572781, 0.}, 
    {0.7330382858376183, 0.}}], Line[{{0.7330382858376183, \
0.10471975511965977}, {0.7330382858376183, 0.20943951023931953}, 
    {0.8377580409572781, 0.20943951023931953}, {0.8377580409572781, \
0.10471975511965977}, {0.7330382858376183, 0.10471975511965977}}], 
  Line[{{0.7330382858376183, 0.20943951023931953}, {0.7330382858376183, \
0.3141592653589793}, {0.8377580409572781, 0.3141592653589793}, 
    {0.8377580409572781, 0.20943951023931953}, {0.7330382858376183, \
0.20943951023931953}}], 
  Line[{{0.7330382858376183, 0.3141592653589793}, {0.7330382858376183, \
0.41887902047863906}, {0.8377580409572781, 0.41887902047863906}, 
    {0.8377580409572781, 0.3141592653589793}, {0.7330382858376183, \
0.3141592653589793}}], 
  Line[{{0.7330382858376183, 0.41887902047863906}, {0.7330382858376183, \
0.5235987755982988}, {0.8377580409572781, 0.5235987755982988}, 
    {0.8377580409572781, 0.41887902047863906}, {0.7330382858376183, \
0.41887902047863906}}], 
  Line[{{0.7330382858376183, 0.5235987755982988}, {0.7330382858376183, \
0.6283185307179586}, {0.8377580409572781, 0.6283185307179586}, 
    {0.8377580409572781, 0.5235987755982988}, {0.7330382858376183, \
0.5235987755982988}}], 
  Line[{{0.7330382858376183, 0.6283185307179586}, {0.7330382858376183, \
0.7330382858376183}, {0.8377580409572781, 0.7330382858376183}, 
    {0.8377580409572781, 0.6283185307179586}, {0.7330382858376183, \
0.6283185307179586}}], 
  Line[{{0.7330382858376183, 0.7330382858376183}, {0.7330382858376183, \
0.8377580409572781}, {0.8377580409572781, 0.8377580409572781}, 
    {0.8377580409572781, 0.7330382858376183}, {0.7330382858376183, \
0.7330382858376183}}], 
  Line[{{0.7330382858376183, 0.8377580409572781}, {0.7330382858376183, \
0.9424777960769379}, {0.8377580409572781, 0.9424777960769379}, 
    {0.8377580409572781, 0.8377580409572781}, {0.7330382858376183, \
0.8377580409572781}}], 
  Line[{{0.7330382858376183, 0.9424777960769379}, {0.7330382858376183, \
1.0471975511965976}, {0.8377580409572781, 1.0471975511965976}, 
    {0.8377580409572781, 0.9424777960769379}, {0.7330382858376183, \
0.9424777960769379}}], 
  Line[{{0.7330382858376183, 1.0471975511965976}, {0.7330382858376183, \
1.1519173063162573}, {0.8377580409572781, 1.1519173063162573}, 
    {0.8377580409572781, 1.0471975511965976}, {0.7330382858376183, \
1.0471975511965976}}], 
  Line[{{0.7330382858376183, 1.1519173063162573}, {0.7330382858376183, \
1.2566370614359172}, {0.8377580409572781, 1.2566370614359172}, 
    {0.8377580409572781, 1.1519173063162573}, {0.7330382858376183, \
1.1519173063162573}}], 
  Line[{{0.7330382858376183, 1.2566370614359172}, {0.7330382858376183, \
1.361356816555577}, {0.8377580409572781, 1.361356816555577}, 
    {0.8377580409572781, 1.2566370614359172}, {0.7330382858376183, \
1.2566370614359172}}], 
  Line[{{0.7330382858376183, 1.361356816555577}, {0.7330382858376183, \
1.4660765716752366}, {0.8377580409572781, 1.4660765716752366}, 
    {0.8377580409572781, 1.361356816555577}, {0.7330382858376183, \
1.361356816555577}}], 
  Line[{{0.7330382858376183, 1.4660765716752366}, {0.7330382858376183, \
1.5707963267948966}, {0.8377580409572781, 1.5707963267948966}, 
    {0.8377580409572781, 1.4660765716752366}, {0.7330382858376183, \
1.4660765716752366}}], 
  Line[{{0.7330382858376183, 1.5707963267948966}, {0.7330382858376183, \
1.6755160819145563}, {0.8377580409572781, 1.6755160819145563}, 
    {0.8377580409572781, 1.5707963267948966}, {0.7330382858376183, \
1.5707963267948966}}], 
  Line[{{0.7330382858376183, 1.6755160819145563}, {0.7330382858376183, \
1.780235837034216}, {0.8377580409572781, 1.780235837034216}, 
    {0.8377580409572781, 1.6755160819145563}, {0.7330382858376183, \
1.6755160819145563}}], 
  Line[{{0.7330382858376183, 1.780235837034216}, {0.7330382858376183, \
1.8849555921538759}, {0.8377580409572781, 1.8849555921538759}, 
    {0.8377580409572781, 1.780235837034216}, {0.7330382858376183, \
1.780235837034216}}], 
  Line[{{0.7330382858376183, 1.8849555921538759}, {0.7330382858376183, \
1.9896753472735356}, {0.8377580409572781, 1.9896753472735356}, 
    {0.8377580409572781, 1.8849555921538759}, {0.7330382858376183, \
1.8849555921538759}}], 
  Line[{{0.7330382858376183, 1.9896753472735356}, {0.7330382858376183, \
2.0943951023931953}, {0.8377580409572781, 2.0943951023931953}, 
    {0.8377580409572781, 1.9896753472735356}, {0.7330382858376183, \
1.9896753472735356}}], 
  Line[{{0.7330382858376183, 2.0943951023931953}, {0.7330382858376183, \
2.199114857512855}, {0.8377580409572781, 2.199114857512855}, 
    {0.8377580409572781, 2.0943951023931953}, {0.7330382858376183, \
2.0943951023931953}}], 
  Line[{{0.7330382858376183, 2.199114857512855}, {0.7330382858376183, \
2.3038346126325147}, {0.8377580409572781, 2.3038346126325147}, 
    {0.8377580409572781, 2.199114857512855}, {0.7330382858376183, \
2.199114857512855}}], 
  Line[{{0.7330382858376183, 2.3038346126325147}, {0.7330382858376183, \
2.4085543677521746}, {0.8377580409572781, 2.4085543677521746}, 
    {0.8377580409572781, 2.3038346126325147}, {0.7330382858376183, \
2.3038346126325147}}], 
  Line[{{0.7330382858376183, 2.4085543677521746}, {0.7330382858376183, \
2.5132741228718345}, {0.8377580409572781, 2.5132741228718345}, 
    {0.8377580409572781, 2.4085543677521746}, {0.7330382858376183, \
2.4085543677521746}}], 
  Line[{{0.7330382858376183, 2.5132741228718345}, {0.7330382858376183, \
2.617993877991494}, {0.8377580409572781, 2.617993877991494}, 
    {0.8377580409572781, 2.5132741228718345}, {0.7330382858376183, \
2.5132741228718345}}], 
  Line[{{0.7330382858376183, 2.617993877991494}, {0.7330382858376183, \
2.722713633111154}, {0.8377580409572781, 2.722713633111154}, 
    {0.8377580409572781, 2.617993877991494}, {0.7330382858376183, \
2.617993877991494}}], 
  Line[{{0.7330382858376183, 2.722713633111154}, {0.7330382858376183, \
2.827433388230814}, {0.8377580409572781, 2.827433388230814}, 
    {0.8377580409572781, 2.722713633111154}, {0.7330382858376183, \
2.722713633111154}}], 
  Line[{{0.7330382858376183, 2.827433388230814}, {0.7330382858376183, \
2.9321531433504733}, {0.8377580409572781, 2.9321531433504733}, 
    {0.8377580409572781, 2.827433388230814}, {0.7330382858376183, \
2.827433388230814}}], 
  Line[{{0.7330382858376183, 2.9321531433504733}, {0.7330382858376183, \
3.036872898470133}, {0.8377580409572781, 3.036872898470133}, 
    {0.8377580409572781, 2.9321531433504733}, {0.7330382858376183, \
2.9321531433504733}}], 
  Line[{{0.7330382858376183, 3.036872898470133}, {0.7330382858376183, \
3.141592653589793}, {0.8377580409572781, 3.141592653589793}, 
    {0.8377580409572781, 3.036872898470133}, {0.7330382858376183, \
3.036872898470133}}], 
  Line[{{0.7330382858376183, 3.141592653589793}, {0.7330382858376183, \
3.2463124087094526}, {0.8377580409572781, 3.2463124087094526}, 
    {0.8377580409572781, 3.141592653589793}, {0.7330382858376183, \
3.141592653589793}}], 
  Line[{{0.7330382858376183, 3.2463124087094526}, {0.7330382858376183, \
3.3510321638291125}, {0.8377580409572781, 3.3510321638291125}, 
    {0.8377580409572781, 3.2463124087094526}, {0.7330382858376183, \
3.2463124087094526}}], 
  Line[{{0.7330382858376183, 3.3510321638291125}, {0.7330382858376183, \
3.4557519189487724}, {0.8377580409572781, 3.4557519189487724}, 
    {0.8377580409572781, 3.3510321638291125}, {0.7330382858376183, \
3.3510321638291125}}], 
  Line[{{0.7330382858376183, 3.4557519189487724}, {0.7330382858376183, \
3.560471674068432}, {0.8377580409572781, 3.560471674068432}, 
    {0.8377580409572781, 3.4557519189487724}, {0.7330382858376183, \
3.4557519189487724}}], 
  Line[{{0.7330382858376183, 3.560471674068432}, {0.7330382858376183, \
3.665191429188092}, {0.8377580409572781, 3.665191429188092}, 
    {0.8377580409572781, 3.560471674068432}, {0.7330382858376183, \
3.560471674068432}}], 
  Line[{{0.7330382858376183, 3.665191429188092}, {0.7330382858376183, \
3.7699111843077517}, {0.8377580409572781, 3.7699111843077517}, 
    {0.8377580409572781, 3.665191429188092}, {0.7330382858376183, \
3.665191429188092}}], 
  Line[{{0.7330382858376183, 3.7699111843077517}, {0.7330382858376183, \
3.874630939427411}, {0.8377580409572781, 3.874630939427411}, 
    {0.8377580409572781, 3.7699111843077517}, {0.7330382858376183, \
3.7699111843077517}}], 
  Line[{{0.7330382858376183, 3.874630939427411}, {0.7330382858376183, \
3.979350694547071}, {0.8377580409572781, 3.979350694547071}, 
    {0.8377580409572781, 3.874630939427411}, {0.7330382858376183, \
3.874630939427411}}], 
  Line[{{0.7330382858376183, 3.979350694547071}, {0.7330382858376183, \
4.084070449666731}, {0.8377580409572781, 4.084070449666731}, 
    {0.8377580409572781, 3.979350694547071}, {0.7330382858376183, \
3.979350694547071}}], 
  Line[{{0.7330382858376183, 4.084070449666731}, {0.7330382858376183, \
4.1887902047863905}, {0.8377580409572781, 4.1887902047863905}, 
    {0.8377580409572781, 4.084070449666731}, {0.7330382858376183, \
4.084070449666731}}], 
  Line[{{0.7330382858376183, 4.1887902047863905}, {0.7330382858376183, \
4.29350995990605}, {0.8377580409572781, 4.29350995990605}, 
    {0.8377580409572781, 4.1887902047863905}, {0.7330382858376183, \
4.1887902047863905}}], 
  Line[{{0.7330382858376183, 4.29350995990605}, {0.7330382858376183, \
4.39822971502571}, {0.8377580409572781, 4.39822971502571}, 
    {0.8377580409572781, 4.29350995990605}, {0.7330382858376183, \
4.29350995990605}}], 
  Line[{{0.7330382858376183, 4.39822971502571}, {0.7330382858376183, \
4.50294947014537}, {0.8377580409572781, 4.50294947014537}, 
    {0.8377580409572781, 4.39822971502571}, {0.7330382858376183, \
4.39822971502571}}], 
  Line[{{0.7330382858376183, 4.50294947014537}, {0.7330382858376183, \
4.607669225265029}, {0.8377580409572781, 4.607669225265029}, 
    {0.8377580409572781, 4.50294947014537}, {0.7330382858376183, \
4.50294947014537}}], 
  Line[{{0.7330382858376183, 4.607669225265029}, {0.7330382858376183, \
4.71238898038469}, {0.8377580409572781, 4.71238898038469}, 
    {0.8377580409572781, 4.607669225265029}, {0.7330382858376183, \
4.607669225265029}}], 
  Line[{{0.7330382858376183, 4.71238898038469}, {0.7330382858376183, \
4.817108735504349}, {0.8377580409572781, 4.817108735504349}, 
    {0.8377580409572781, 4.71238898038469}, {0.7330382858376183, \
4.71238898038469}}], 
  Line[{{0.7330382858376183, 4.817108735504349}, {0.7330382858376183, \
4.921828490624009}, {0.8377580409572781, 4.921828490624009}, 
    {0.8377580409572781, 4.817108735504349}, {0.7330382858376183, \
4.817108735504349}}], 
  Line[{{0.7330382858376183, 4.921828490624009}, {0.7330382858376183, \
5.026548245743669}, {0.8377580409572781, 5.026548245743669}, 
    {0.8377580409572781, 4.921828490624009}, {0.7330382858376183, \
4.921828490624009}}], 
  Line[{{0.7330382858376183, 5.026548245743669}, {0.7330382858376183, \
5.1312680008633285}, {0.8377580409572781, 5.1312680008633285}, 
    {0.8377580409572781, 5.026548245743669}, {0.7330382858376183, \
5.026548245743669}}], 
  Line[{{0.7330382858376183, 5.1312680008633285}, {0.7330382858376183, \
5.235987755982988}, {0.8377580409572781, 5.235987755982988}, 
    {0.8377580409572781, 5.1312680008633285}, {0.7330382858376183, \
5.1312680008633285}}], 
  Line[{{0.7330382858376183, 5.235987755982988}, {0.7330382858376183, \
5.340707511102648}, {0.8377580409572781, 5.340707511102648}, 
    {0.8377580409572781, 5.235987755982988}, {0.7330382858376183, \
5.235987755982988}}], 
  Line[{{0.7330382858376183, 5.340707511102648}, {0.7330382858376183, \
5.445427266222308}, {0.8377580409572781, 5.445427266222308}, 
    {0.8377580409572781, 5.340707511102648}, {0.7330382858376183, \
5.340707511102648}}], 
  Line[{{0.7330382858376183, 5.445427266222308}, {0.7330382858376183, \
5.550147021341967}, {0.8377580409572781, 5.550147021341967}, 
    {0.8377580409572781, 5.445427266222308}, {0.7330382858376183, \
5.445427266222308}}], 
  Line[{{0.7330382858376183, 5.550147021341967}, {0.7330382858376183, \
5.654866776461628}, {0.8377580409572781, 5.654866776461628}, 
    {0.8377580409572781, 5.550147021341967}, {0.7330382858376183, \
5.550147021341967}}], 
  Line[{{0.7330382858376183, 5.654866776461628}, {0.7330382858376183, \
5.759586531581287}, {0.8377580409572781, 5.759586531581287}, 
    {0.8377580409572781, 5.654866776461628}, {0.7330382858376183, \
5.654866776461628}}], 
  Line[{{0.7330382858376183, 5.759586531581287}, {0.7330382858376183, \
5.864306286700947}, {0.8377580409572781, 5.864306286700947}, 
    {0.8377580409572781, 5.759586531581287}, {0.7330382858376183, \
5.759586531581287}}], 
  Line[{{0.7330382858376183, 5.864306286700947}, {0.7330382858376183, \
5.969026041820607}, {0.8377580409572781, 5.969026041820607}, 
    {0.8377580409572781, 5.864306286700947}, {0.7330382858376183, \
5.864306286700947}}], 
  Line[{{0.7330382858376183, 5.969026041820607}, {0.7330382858376183, \
6.073745796940266}, {0.8377580409572781, 6.073745796940266}, 
    {0.8377580409572781, 5.969026041820607}, {0.7330382858376183, \
5.969026041820607}}], 
  Line[{{0.7330382858376183, 6.073745796940266}, {0.7330382858376183, \
6.178465552059926}, {0.8377580409572781, 6.178465552059926}, 
    {0.8377580409572781, 6.073745796940266}, {0.7330382858376183, \
6.073745796940266}}], 
  Line[{{0.7330382858376183, 6.178465552059926}, {0.7330382858376183, \
6.283185307179586}, {0.8377580409572781, 6.283185307179586}, 
    {0.8377580409572781, 6.178465552059926}, {0.7330382858376183, \
6.178465552059926}}], 
  Line[{{0.8377580409572781, 0.}, {0.8377580409572781, 0.10471975511965977}, \
{0.9424777960769379, 0.10471975511965977}, {0.9424777960769379, 0.}, 
    {0.8377580409572781, 0.}}], Line[{{0.8377580409572781, \
0.10471975511965977}, {0.8377580409572781, 0.20943951023931953}, 
    {0.9424777960769379, 0.20943951023931953}, {0.9424777960769379, \
0.10471975511965977}, {0.8377580409572781, 0.10471975511965977}}], 
  Line[{{0.8377580409572781, 0.20943951023931953}, {0.8377580409572781, \
0.3141592653589793}, {0.9424777960769379, 0.3141592653589793}, 
    {0.9424777960769379, 0.20943951023931953}, {0.8377580409572781, \
0.20943951023931953}}], 
  Line[{{0.8377580409572781, 0.3141592653589793}, {0.8377580409572781, \
0.41887902047863906}, {0.9424777960769379, 0.41887902047863906}, 
    {0.9424777960769379, 0.3141592653589793}, {0.8377580409572781, \
0.3141592653589793}}], 
  Line[{{0.8377580409572781, 0.41887902047863906}, {0.8377580409572781, \
0.5235987755982988}, {0.9424777960769379, 0.5235987755982988}, 
    {0.9424777960769379, 0.41887902047863906}, {0.8377580409572781, \
0.41887902047863906}}], 
  Line[{{0.8377580409572781, 0.5235987755982988}, {0.8377580409572781, \
0.6283185307179586}, {0.9424777960769379, 0.6283185307179586}, 
    {0.9424777960769379, 0.5235987755982988}, {0.8377580409572781, \
0.5235987755982988}}], 
  Line[{{0.8377580409572781, 0.6283185307179586}, {0.8377580409572781, \
0.7330382858376183}, {0.9424777960769379, 0.7330382858376183}, 
    {0.9424777960769379, 0.6283185307179586}, {0.8377580409572781, \
0.6283185307179586}}], 
  Line[{{0.8377580409572781, 0.7330382858376183}, {0.8377580409572781, \
0.8377580409572781}, {0.9424777960769379, 0.8377580409572781}, 
    {0.9424777960769379, 0.7330382858376183}, {0.8377580409572781, \
0.7330382858376183}}], 
  Line[{{0.8377580409572781, 0.8377580409572781}, {0.8377580409572781, \
0.9424777960769379}, {0.9424777960769379, 0.9424777960769379}, 
    {0.9424777960769379, 0.8377580409572781}, {0.8377580409572781, \
0.8377580409572781}}], 
  Line[{{0.8377580409572781, 0.9424777960769379}, {0.8377580409572781, \
1.0471975511965976}, {0.9424777960769379, 1.0471975511965976}, 
    {0.9424777960769379, 0.9424777960769379}, {0.8377580409572781, \
0.9424777960769379}}], 
  Line[{{0.8377580409572781, 1.0471975511965976}, {0.8377580409572781, \
1.1519173063162573}, {0.9424777960769379, 1.1519173063162573}, 
    {0.9424777960769379, 1.0471975511965976}, {0.8377580409572781, \
1.0471975511965976}}], 
  Line[{{0.8377580409572781, 1.1519173063162573}, {0.8377580409572781, \
1.2566370614359172}, {0.9424777960769379, 1.2566370614359172}, 
    {0.9424777960769379, 1.1519173063162573}, {0.8377580409572781, \
1.1519173063162573}}], 
  Line[{{0.8377580409572781, 1.2566370614359172}, {0.8377580409572781, \
1.361356816555577}, {0.9424777960769379, 1.361356816555577}, 
    {0.9424777960769379, 1.2566370614359172}, {0.8377580409572781, \
1.2566370614359172}}], 
  Line[{{0.8377580409572781, 1.361356816555577}, {0.8377580409572781, \
1.4660765716752366}, {0.9424777960769379, 1.4660765716752366}, 
    {0.9424777960769379, 1.361356816555577}, {0.8377580409572781, \
1.361356816555577}}], 
  Line[{{0.8377580409572781, 1.4660765716752366}, {0.8377580409572781, \
1.5707963267948966}, {0.9424777960769379, 1.5707963267948966}, 
    {0.9424777960769379, 1.4660765716752366}, {0.8377580409572781, \
1.4660765716752366}}], 
  Line[{{0.8377580409572781, 1.5707963267948966}, {0.8377580409572781, \
1.6755160819145563}, {0.9424777960769379, 1.6755160819145563}, 
    {0.9424777960769379, 1.5707963267948966}, {0.8377580409572781, \
1.5707963267948966}}], 
  Line[{{0.8377580409572781, 1.6755160819145563}, {0.8377580409572781, \
1.780235837034216}, {0.9424777960769379, 1.780235837034216}, 
    {0.9424777960769379, 1.6755160819145563}, {0.8377580409572781, \
1.6755160819145563}}], 
  Line[{{0.8377580409572781, 1.780235837034216}, {0.8377580409572781, \
1.8849555921538759}, {0.9424777960769379, 1.8849555921538759}, 
    {0.9424777960769379, 1.780235837034216}, {0.8377580409572781, \
1.780235837034216}}], 
  Line[{{0.8377580409572781, 1.8849555921538759}, {0.8377580409572781, \
1.9896753472735356}, {0.9424777960769379, 1.9896753472735356}, 
    {0.9424777960769379, 1.8849555921538759}, {0.8377580409572781, \
1.8849555921538759}}], 
  Line[{{0.8377580409572781, 1.9896753472735356}, {0.8377580409572781, \
2.0943951023931953}, {0.9424777960769379, 2.0943951023931953}, 
    {0.9424777960769379, 1.9896753472735356}, {0.8377580409572781, \
1.9896753472735356}}], 
  Line[{{0.8377580409572781, 2.0943951023931953}, {0.8377580409572781, \
2.199114857512855}, {0.9424777960769379, 2.199114857512855}, 
    {0.9424777960769379, 2.0943951023931953}, {0.8377580409572781, \
2.0943951023931953}}], 
  Line[{{0.8377580409572781, 2.199114857512855}, {0.8377580409572781, \
2.3038346126325147}, {0.9424777960769379, 2.3038346126325147}, 
    {0.9424777960769379, 2.199114857512855}, {0.8377580409572781, \
2.199114857512855}}], 
  Line[{{0.8377580409572781, 2.3038346126325147}, {0.8377580409572781, \
2.4085543677521746}, {0.9424777960769379, 2.4085543677521746}, 
    {0.9424777960769379, 2.3038346126325147}, {0.8377580409572781, \
2.3038346126325147}}], 
  Line[{{0.8377580409572781, 2.4085543677521746}, {0.8377580409572781, \
2.5132741228718345}, {0.9424777960769379, 2.5132741228718345}, 
    {0.9424777960769379, 2.4085543677521746}, {0.8377580409572781, \
2.4085543677521746}}], 
  Line[{{0.8377580409572781, 2.5132741228718345}, {0.8377580409572781, \
2.617993877991494}, {0.9424777960769379, 2.617993877991494}, 
    {0.9424777960769379, 2.5132741228718345}, {0.8377580409572781, \
2.5132741228718345}}], 
  Line[{{0.8377580409572781, 2.617993877991494}, {0.8377580409572781, \
2.722713633111154}, {0.9424777960769379, 2.722713633111154}, 
    {0.9424777960769379, 2.617993877991494}, {0.8377580409572781, \
2.617993877991494}}], 
  Line[{{0.8377580409572781, 2.722713633111154}, {0.8377580409572781, \
2.827433388230814}, {0.9424777960769379, 2.827433388230814}, 
    {0.9424777960769379, 2.722713633111154}, {0.8377580409572781, \
2.722713633111154}}], 
  Line[{{0.8377580409572781, 2.827433388230814}, {0.8377580409572781, \
2.9321531433504733}, {0.9424777960769379, 2.9321531433504733}, 
    {0.9424777960769379, 2.827433388230814}, {0.8377580409572781, \
2.827433388230814}}], 
  Line[{{0.8377580409572781, 2.9321531433504733}, {0.8377580409572781, \
3.036872898470133}, {0.9424777960769379, 3.036872898470133}, 
    {0.9424777960769379, 2.9321531433504733}, {0.8377580409572781, \
2.9321531433504733}}], 
  Line[{{0.8377580409572781, 3.036872898470133}, {0.8377580409572781, \
3.141592653589793}, {0.9424777960769379, 3.141592653589793}, 
    {0.9424777960769379, 3.036872898470133}, {0.8377580409572781, \
3.036872898470133}}], 
  Line[{{0.8377580409572781, 3.141592653589793}, {0.8377580409572781, \
3.2463124087094526}, {0.9424777960769379, 3.2463124087094526}, 
    {0.9424777960769379, 3.141592653589793}, {0.8377580409572781, \
3.141592653589793}}], 
  Line[{{0.8377580409572781, 3.2463124087094526}, {0.8377580409572781, \
3.3510321638291125}, {0.9424777960769379, 3.3510321638291125}, 
    {0.9424777960769379, 3.2463124087094526}, {0.8377580409572781, \
3.2463124087094526}}], 
  Line[{{0.8377580409572781, 3.3510321638291125}, {0.8377580409572781, \
3.4557519189487724}, {0.9424777960769379, 3.4557519189487724}, 
    {0.9424777960769379, 3.3510321638291125}, {0.8377580409572781, \
3.3510321638291125}}], 
  Line[{{0.8377580409572781, 3.4557519189487724}, {0.8377580409572781, \
3.560471674068432}, {0.9424777960769379, 3.560471674068432}, 
    {0.9424777960769379, 3.4557519189487724}, {0.8377580409572781, \
3.4557519189487724}}], 
  Line[{{0.8377580409572781, 3.560471674068432}, {0.8377580409572781, \
3.665191429188092}, {0.9424777960769379, 3.665191429188092}, 
    {0.9424777960769379, 3.560471674068432}, {0.8377580409572781, \
3.560471674068432}}], 
  Line[{{0.8377580409572781, 3.665191429188092}, {0.8377580409572781, \
3.7699111843077517}, {0.9424777960769379, 3.7699111843077517}, 
    {0.9424777960769379, 3.665191429188092}, {0.8377580409572781, \
3.665191429188092}}], 
  Line[{{0.8377580409572781, 3.7699111843077517}, {0.8377580409572781, \
3.874630939427411}, {0.9424777960769379, 3.874630939427411}, 
    {0.9424777960769379, 3.7699111843077517}, {0.8377580409572781, \
3.7699111843077517}}], 
  Line[{{0.8377580409572781, 3.874630939427411}, {0.8377580409572781, \
3.979350694547071}, {0.9424777960769379, 3.979350694547071}, 
    {0.9424777960769379, 3.874630939427411}, {0.8377580409572781, \
3.874630939427411}}], 
  Line[{{0.8377580409572781, 3.979350694547071}, {0.8377580409572781, \
4.084070449666731}, {0.9424777960769379, 4.084070449666731}, 
    {0.9424777960769379, 3.979350694547071}, {0.8377580409572781, \
3.979350694547071}}], 
  Line[{{0.8377580409572781, 4.084070449666731}, {0.8377580409572781, \
4.1887902047863905}, {0.9424777960769379, 4.1887902047863905}, 
    {0.9424777960769379, 4.084070449666731}, {0.8377580409572781, \
4.084070449666731}}], 
  Line[{{0.8377580409572781, 4.1887902047863905}, {0.8377580409572781, \
4.29350995990605}, {0.9424777960769379, 4.29350995990605}, 
    {0.9424777960769379, 4.1887902047863905}, {0.8377580409572781, \
4.1887902047863905}}], 
  Line[{{0.8377580409572781, 4.29350995990605}, {0.8377580409572781, \
4.39822971502571}, {0.9424777960769379, 4.39822971502571}, 
    {0.9424777960769379, 4.29350995990605}, {0.8377580409572781, \
4.29350995990605}}], 
  Line[{{0.8377580409572781, 4.39822971502571}, {0.8377580409572781, \
4.50294947014537}, {0.9424777960769379, 4.50294947014537}, 
    {0.9424777960769379, 4.39822971502571}, {0.8377580409572781, \
4.39822971502571}}], 
  Line[{{0.8377580409572781, 4.50294947014537}, {0.8377580409572781, \
4.607669225265029}, {0.9424777960769379, 4.607669225265029}, 
    {0.9424777960769379, 4.50294947014537}, {0.8377580409572781, \
4.50294947014537}}], 
  Line[{{0.8377580409572781, 4.607669225265029}, {0.8377580409572781, \
4.71238898038469}, {0.9424777960769379, 4.71238898038469}, 
    {0.9424777960769379, 4.607669225265029}, {0.8377580409572781, \
4.607669225265029}}], 
  Line[{{0.8377580409572781, 4.71238898038469}, {0.8377580409572781, \
4.817108735504349}, {0.9424777960769379, 4.817108735504349}, 
    {0.9424777960769379, 4.71238898038469}, {0.8377580409572781, \
4.71238898038469}}], 
  Line[{{0.8377580409572781, 4.817108735504349}, {0.8377580409572781, \
4.921828490624009}, {0.9424777960769379, 4.921828490624009}, 
    {0.9424777960769379, 4.817108735504349}, {0.8377580409572781, \
4.817108735504349}}], 
  Line[{{0.8377580409572781, 4.921828490624009}, {0.8377580409572781, \
5.026548245743669}, {0.9424777960769379, 5.026548245743669}, 
    {0.9424777960769379, 4.921828490624009}, {0.8377580409572781, \
4.921828490624009}}], 
  Line[{{0.8377580409572781, 5.026548245743669}, {0.8377580409572781, \
5.1312680008633285}, {0.9424777960769379, 5.1312680008633285}, 
    {0.9424777960769379, 5.026548245743669}, {0.8377580409572781, \
5.026548245743669}}], 
  Line[{{0.8377580409572781, 5.1312680008633285}, {0.8377580409572781, \
5.235987755982988}, {0.9424777960769379, 5.235987755982988}, 
    {0.9424777960769379, 5.1312680008633285}, {0.8377580409572781, \
5.1312680008633285}}], 
  Line[{{0.8377580409572781, 5.235987755982988}, {0.8377580409572781, \
5.340707511102648}, {0.9424777960769379, 5.340707511102648}, 
    {0.9424777960769379, 5.235987755982988}, {0.8377580409572781, \
5.235987755982988}}], 
  Line[{{0.8377580409572781, 5.340707511102648}, {0.8377580409572781, \
5.445427266222308}, {0.9424777960769379, 5.445427266222308}, 
    {0.9424777960769379, 5.340707511102648}, {0.8377580409572781, \
5.340707511102648}}], 
  Line[{{0.8377580409572781, 5.445427266222308}, {0.8377580409572781, \
5.550147021341967}, {0.9424777960769379, 5.550147021341967}, 
    {0.9424777960769379, 5.445427266222308}, {0.8377580409572781, \
5.445427266222308}}], 
  Line[{{0.8377580409572781, 5.550147021341967}, {0.8377580409572781, \
5.654866776461628}, {0.9424777960769379, 5.654866776461628}, 
    {0.9424777960769379, 5.550147021341967}, {0.8377580409572781, \
5.550147021341967}}], 
  Line[{{0.8377580409572781, 5.654866776461628}, {0.8377580409572781, \
5.759586531581287}, {0.9424777960769379, 5.759586531581287}, 
    {0.9424777960769379, 5.654866776461628}, {0.8377580409572781, \
5.654866776461628}}], 
  Line[{{0.8377580409572781, 5.759586531581287}, {0.8377580409572781, \
5.864306286700947}, {0.9424777960769379, 5.864306286700947}, 
    {0.9424777960769379, 5.759586531581287}, {0.8377580409572781, \
5.759586531581287}}], 
  Line[{{0.8377580409572781, 5.864306286700947}, {0.8377580409572781, \
5.969026041820607}, {0.9424777960769379, 5.969026041820607}, 
    {0.9424777960769379, 5.864306286700947}, {0.8377580409572781, \
5.864306286700947}}], 
  Line[{{0.8377580409572781, 5.969026041820607}, {0.8377580409572781, \
6.073745796940266}, {0.9424777960769379, 6.073745796940266}, 
    {0.9424777960769379, 5.969026041820607}, {0.8377580409572781, \
5.969026041820607}}], 
  Line[{{0.8377580409572781, 6.073745796940266}, {0.8377580409572781, \
6.178465552059926}, {0.9424777960769379, 6.178465552059926}, 
    {0.9424777960769379, 6.073745796940266}, {0.8377580409572781, \
6.073745796940266}}], 
  Line[{{0.8377580409572781, 6.178465552059926}, {0.8377580409572781, \
6.283185307179586}, {0.9424777960769379, 6.283185307179586}, 
    {0.9424777960769379, 6.178465552059926}, {0.8377580409572781, \
6.178465552059926}}], 
  Line[{{0.9424777960769379, 0.}, {0.9424777960769379, 0.10471975511965977}, \
{1.0471975511965976, 0.10471975511965977}, {1.0471975511965976, 0.}, 
    {0.9424777960769379, 0.}}], Line[{{0.9424777960769379, \
0.10471975511965977}, {0.9424777960769379, 0.20943951023931953}, 
    {1.0471975511965976, 0.20943951023931953}, {1.0471975511965976, \
0.10471975511965977}, {0.9424777960769379, 0.10471975511965977}}], 
  Line[{{0.9424777960769379, 0.20943951023931953}, {0.9424777960769379, \
0.3141592653589793}, {1.0471975511965976, 0.3141592653589793}, 
    {1.0471975511965976, 0.20943951023931953}, {0.9424777960769379, \
0.20943951023931953}}], 
  Line[{{0.9424777960769379, 0.3141592653589793}, {0.9424777960769379, \
0.41887902047863906}, {1.0471975511965976, 0.41887902047863906}, 
    {1.0471975511965976, 0.3141592653589793}, {0.9424777960769379, \
0.3141592653589793}}], 
  Line[{{0.9424777960769379, 0.41887902047863906}, {0.9424777960769379, \
0.5235987755982988}, {1.0471975511965976, 0.5235987755982988}, 
    {1.0471975511965976, 0.41887902047863906}, {0.9424777960769379, \
0.41887902047863906}}], 
  Line[{{0.9424777960769379, 0.5235987755982988}, {0.9424777960769379, \
0.6283185307179586}, {1.0471975511965976, 0.6283185307179586}, 
    {1.0471975511965976, 0.5235987755982988}, {0.9424777960769379, \
0.5235987755982988}}], 
  Line[{{0.9424777960769379, 0.6283185307179586}, {0.9424777960769379, \
0.7330382858376183}, {1.0471975511965976, 0.7330382858376183}, 
    {1.0471975511965976, 0.6283185307179586}, {0.9424777960769379, \
0.6283185307179586}}], 
  Line[{{0.9424777960769379, 0.7330382858376183}, {0.9424777960769379, \
0.8377580409572781}, {1.0471975511965976, 0.8377580409572781}, 
    {1.0471975511965976, 0.7330382858376183}, {0.9424777960769379, \
0.7330382858376183}}], 
  Line[{{0.9424777960769379, 0.8377580409572781}, {0.9424777960769379, \
0.9424777960769379}, {1.0471975511965976, 0.9424777960769379}, 
    {1.0471975511965976, 0.8377580409572781}, {0.9424777960769379, \
0.8377580409572781}}], 
  Line[{{0.9424777960769379, 0.9424777960769379}, {0.9424777960769379, \
1.0471975511965976}, {1.0471975511965976, 1.0471975511965976}, 
    {1.0471975511965976, 0.9424777960769379}, {0.9424777960769379, \
0.9424777960769379}}], 
  Line[{{0.9424777960769379, 1.0471975511965976}, {0.9424777960769379, \
1.1519173063162573}, {1.0471975511965976, 1.1519173063162573}, 
    {1.0471975511965976, 1.0471975511965976}, {0.9424777960769379, \
1.0471975511965976}}], 
  Line[{{0.9424777960769379, 1.1519173063162573}, {0.9424777960769379, \
1.2566370614359172}, {1.0471975511965976, 1.2566370614359172}, 
    {1.0471975511965976, 1.1519173063162573}, {0.9424777960769379, \
1.1519173063162573}}], 
  Line[{{0.9424777960769379, 1.2566370614359172}, {0.9424777960769379, \
1.361356816555577}, {1.0471975511965976, 1.361356816555577}, 
    {1.0471975511965976, 1.2566370614359172}, {0.9424777960769379, \
1.2566370614359172}}], 
  Line[{{0.9424777960769379, 1.361356816555577}, {0.9424777960769379, \
1.4660765716752366}, {1.0471975511965976, 1.4660765716752366}, 
    {1.0471975511965976, 1.361356816555577}, {0.9424777960769379, \
1.361356816555577}}], 
  Line[{{0.9424777960769379, 1.4660765716752366}, {0.9424777960769379, \
1.5707963267948966}, {1.0471975511965976, 1.5707963267948966}, 
    {1.0471975511965976, 1.4660765716752366}, {0.9424777960769379, \
1.4660765716752366}}], 
  Line[{{0.9424777960769379, 1.5707963267948966}, {0.9424777960769379, \
1.6755160819145563}, {1.0471975511965976, 1.6755160819145563}, 
    {1.0471975511965976, 1.5707963267948966}, {0.9424777960769379, \
1.5707963267948966}}], 
  Line[{{0.9424777960769379, 1.6755160819145563}, {0.9424777960769379, \
1.780235837034216}, {1.0471975511965976, 1.780235837034216}, 
    {1.0471975511965976, 1.6755160819145563}, {0.9424777960769379, \
1.6755160819145563}}], 
  Line[{{0.9424777960769379, 1.780235837034216}, {0.9424777960769379, \
1.8849555921538759}, {1.0471975511965976, 1.8849555921538759}, 
    {1.0471975511965976, 1.780235837034216}, {0.9424777960769379, \
1.780235837034216}}], 
  Line[{{0.9424777960769379, 1.8849555921538759}, {0.9424777960769379, \
1.9896753472735356}, {1.0471975511965976, 1.9896753472735356}, 
    {1.0471975511965976, 1.8849555921538759}, {0.9424777960769379, \
1.8849555921538759}}], 
  Line[{{0.9424777960769379, 1.9896753472735356}, {0.9424777960769379, \
2.0943951023931953}, {1.0471975511965976, 2.0943951023931953}, 
    {1.0471975511965976, 1.9896753472735356}, {0.9424777960769379, \
1.9896753472735356}}], 
  Line[{{0.9424777960769379, 2.0943951023931953}, {0.9424777960769379, \
2.199114857512855}, {1.0471975511965976, 2.199114857512855}, 
    {1.0471975511965976, 2.0943951023931953}, {0.9424777960769379, \
2.0943951023931953}}], 
  Line[{{0.9424777960769379, 2.199114857512855}, {0.9424777960769379, \
2.3038346126325147}, {1.0471975511965976, 2.3038346126325147}, 
    {1.0471975511965976, 2.199114857512855}, {0.9424777960769379, \
2.199114857512855}}], 
  Line[{{0.9424777960769379, 2.3038346126325147}, {0.9424777960769379, \
2.4085543677521746}, {1.0471975511965976, 2.4085543677521746}, 
    {1.0471975511965976, 2.3038346126325147}, {0.9424777960769379, \
2.3038346126325147}}], 
  Line[{{0.9424777960769379, 2.4085543677521746}, {0.9424777960769379, \
2.5132741228718345}, {1.0471975511965976, 2.5132741228718345}, 
    {1.0471975511965976, 2.4085543677521746}, {0.9424777960769379, \
2.4085543677521746}}], 
  Line[{{0.9424777960769379, 2.5132741228718345}, {0.9424777960769379, \
2.617993877991494}, {1.0471975511965976, 2.617993877991494}, 
    {1.0471975511965976, 2.5132741228718345}, {0.9424777960769379, \
2.5132741228718345}}], 
  Line[{{0.9424777960769379, 2.617993877991494}, {0.9424777960769379, \
2.722713633111154}, {1.0471975511965976, 2.722713633111154}, 
    {1.0471975511965976, 2.617993877991494}, {0.9424777960769379, \
2.617993877991494}}], 
  Line[{{0.9424777960769379, 2.722713633111154}, {0.9424777960769379, \
2.827433388230814}, {1.0471975511965976, 2.827433388230814}, 
    {1.0471975511965976, 2.722713633111154}, {0.9424777960769379, \
2.722713633111154}}], 
  Line[{{0.9424777960769379, 2.827433388230814}, {0.9424777960769379, \
2.9321531433504733}, {1.0471975511965976, 2.9321531433504733}, 
    {1.0471975511965976, 2.827433388230814}, {0.9424777960769379, \
2.827433388230814}}], 
  Line[{{0.9424777960769379, 2.9321531433504733}, {0.9424777960769379, \
3.036872898470133}, {1.0471975511965976, 3.036872898470133}, 
    {1.0471975511965976, 2.9321531433504733}, {0.9424777960769379, \
2.9321531433504733}}], 
  Line[{{0.9424777960769379, 3.036872898470133}, {0.9424777960769379, \
3.141592653589793}, {1.0471975511965976, 3.141592653589793}, 
    {1.0471975511965976, 3.036872898470133}, {0.9424777960769379, \
3.036872898470133}}], 
  Line[{{0.9424777960769379, 3.141592653589793}, {0.9424777960769379, \
3.2463124087094526}, {1.0471975511965976, 3.2463124087094526}, 
    {1.0471975511965976, 3.141592653589793}, {0.9424777960769379, \
3.141592653589793}}], 
  Line[{{0.9424777960769379, 3.2463124087094526}, {0.9424777960769379, \
3.3510321638291125}, {1.0471975511965976, 3.3510321638291125}, 
    {1.0471975511965976, 3.2463124087094526}, {0.9424777960769379, \
3.2463124087094526}}], 
  Line[{{0.9424777960769379, 3.3510321638291125}, {0.9424777960769379, \
3.4557519189487724}, {1.0471975511965976, 3.4557519189487724}, 
    {1.0471975511965976, 3.3510321638291125}, {0.9424777960769379, \
3.3510321638291125}}], 
  Line[{{0.9424777960769379, 3.4557519189487724}, {0.9424777960769379, \
3.560471674068432}, {1.0471975511965976, 3.560471674068432}, 
    {1.0471975511965976, 3.4557519189487724}, {0.9424777960769379, \
3.4557519189487724}}], 
  Line[{{0.9424777960769379, 3.560471674068432}, {0.9424777960769379, \
3.665191429188092}, {1.0471975511965976, 3.665191429188092}, 
    {1.0471975511965976, 3.560471674068432}, {0.9424777960769379, \
3.560471674068432}}], 
  Line[{{0.9424777960769379, 3.665191429188092}, {0.9424777960769379, \
3.7699111843077517}, {1.0471975511965976, 3.7699111843077517}, 
    {1.0471975511965976, 3.665191429188092}, {0.9424777960769379, \
3.665191429188092}}], 
  Line[{{0.9424777960769379, 3.7699111843077517}, {0.9424777960769379, \
3.874630939427411}, {1.0471975511965976, 3.874630939427411}, 
    {1.0471975511965976, 3.7699111843077517}, {0.9424777960769379, \
3.7699111843077517}}], 
  Line[{{0.9424777960769379, 3.874630939427411}, {0.9424777960769379, \
3.979350694547071}, {1.0471975511965976, 3.979350694547071}, 
    {1.0471975511965976, 3.874630939427411}, {0.9424777960769379, \
3.874630939427411}}], 
  Line[{{0.9424777960769379, 3.979350694547071}, {0.9424777960769379, \
4.084070449666731}, {1.0471975511965976, 4.084070449666731}, 
    {1.0471975511965976, 3.979350694547071}, {0.9424777960769379, \
3.979350694547071}}], 
  Line[{{0.9424777960769379, 4.084070449666731}, {0.9424777960769379, \
4.1887902047863905}, {1.0471975511965976, 4.1887902047863905}, 
    {1.0471975511965976, 4.084070449666731}, {0.9424777960769379, \
4.084070449666731}}], 
  Line[{{0.9424777960769379, 4.1887902047863905}, {0.9424777960769379, \
4.29350995990605}, {1.0471975511965976, 4.29350995990605}, 
    {1.0471975511965976, 4.1887902047863905}, {0.9424777960769379, \
4.1887902047863905}}], 
  Line[{{0.9424777960769379, 4.29350995990605}, {0.9424777960769379, \
4.39822971502571}, {1.0471975511965976, 4.39822971502571}, 
    {1.0471975511965976, 4.29350995990605}, {0.9424777960769379, \
4.29350995990605}}], 
  Line[{{0.9424777960769379, 4.39822971502571}, {0.9424777960769379, \
4.50294947014537}, {1.0471975511965976, 4.50294947014537}, 
    {1.0471975511965976, 4.39822971502571}, {0.9424777960769379, \
4.39822971502571}}], 
  Line[{{0.9424777960769379, 4.50294947014537}, {0.9424777960769379, \
4.607669225265029}, {1.0471975511965976, 4.607669225265029}, 
    {1.0471975511965976, 4.50294947014537}, {0.9424777960769379, \
4.50294947014537}}], 
  Line[{{0.9424777960769379, 4.607669225265029}, {0.9424777960769379, \
4.71238898038469}, {1.0471975511965976, 4.71238898038469}, 
    {1.0471975511965976, 4.607669225265029}, {0.9424777960769379, \
4.607669225265029}}], 
  Line[{{0.9424777960769379, 4.71238898038469}, {0.9424777960769379, \
4.817108735504349}, {1.0471975511965976, 4.817108735504349}, 
    {1.0471975511965976, 4.71238898038469}, {0.9424777960769379, \
4.71238898038469}}], 
  Line[{{0.9424777960769379, 4.817108735504349}, {0.9424777960769379, \
4.921828490624009}, {1.0471975511965976, 4.921828490624009}, 
    {1.0471975511965976, 4.817108735504349}, {0.9424777960769379, \
4.817108735504349}}], 
  Line[{{0.9424777960769379, 4.921828490624009}, {0.9424777960769379, \
5.026548245743669}, {1.0471975511965976, 5.026548245743669}, 
    {1.0471975511965976, 4.921828490624009}, {0.9424777960769379, \
4.921828490624009}}], 
  Line[{{0.9424777960769379, 5.026548245743669}, {0.9424777960769379, \
5.1312680008633285}, {1.0471975511965976, 5.1312680008633285}, 
    {1.0471975511965976, 5.026548245743669}, {0.9424777960769379, \
5.026548245743669}}], 
  Line[{{0.9424777960769379, 5.1312680008633285}, {0.9424777960769379, \
5.235987755982988}, {1.0471975511965976, 5.235987755982988}, 
    {1.0471975511965976, 5.1312680008633285}, {0.9424777960769379, \
5.1312680008633285}}], 
  Line[{{0.9424777960769379, 5.235987755982988}, {0.9424777960769379, \
5.340707511102648}, {1.0471975511965976, 5.340707511102648}, 
    {1.0471975511965976, 5.235987755982988}, {0.9424777960769379, \
5.235987755982988}}], 
  Line[{{0.9424777960769379, 5.340707511102648}, {0.9424777960769379, \
5.445427266222308}, {1.0471975511965976, 5.445427266222308}, 
    {1.0471975511965976, 5.340707511102648}, {0.9424777960769379, \
5.340707511102648}}], 
  Line[{{0.9424777960769379, 5.445427266222308}, {0.9424777960769379, \
5.550147021341967}, {1.0471975511965976, 5.550147021341967}, 
    {1.0471975511965976, 5.445427266222308}, {0.9424777960769379, \
5.445427266222308}}], 
  Line[{{0.9424777960769379, 5.550147021341967}, {0.9424777960769379, \
5.654866776461628}, {1.0471975511965976, 5.654866776461628}, 
    {1.0471975511965976, 5.550147021341967}, {0.9424777960769379, \
5.550147021341967}}], 
  Line[{{0.9424777960769379, 5.654866776461628}, {0.9424777960769379, \
5.759586531581287}, {1.0471975511965976, 5.759586531581287}, 
    {1.0471975511965976, 5.654866776461628}, {0.9424777960769379, \
5.654866776461628}}], 
  Line[{{0.9424777960769379, 5.759586531581287}, {0.9424777960769379, \
5.864306286700947}, {1.0471975511965976, 5.864306286700947}, 
    {1.0471975511965976, 5.759586531581287}, {0.9424777960769379, \
5.759586531581287}}], 
  Line[{{0.9424777960769379, 5.864306286700947}, {0.9424777960769379, \
5.969026041820607}, {1.0471975511965976, 5.969026041820607}, 
    {1.0471975511965976, 5.864306286700947}, {0.9424777960769379, \
5.864306286700947}}], 
  Line[{{0.9424777960769379, 5.969026041820607}, {0.9424777960769379, \
6.073745796940266}, {1.0471975511965976, 6.073745796940266}, 
    {1.0471975511965976, 5.969026041820607}, {0.9424777960769379, \
5.969026041820607}}], 
  Line[{{0.9424777960769379, 6.073745796940266}, {0.9424777960769379, \
6.178465552059926}, {1.0471975511965976, 6.178465552059926}, 
    {1.0471975511965976, 6.073745796940266}, {0.9424777960769379, \
6.073745796940266}}], 
  Line[{{0.9424777960769379, 6.178465552059926}, {0.9424777960769379, \
6.283185307179586}, {1.0471975511965976, 6.283185307179586}, 
    {1.0471975511965976, 6.178465552059926}, {0.9424777960769379, \
6.178465552059926}}], 
  Line[{{1.0471975511965976, 0.}, {1.0471975511965976, 0.10471975511965977}, \
{1.1519173063162573, 0.10471975511965977}, {1.1519173063162573, 0.}, 
    {1.0471975511965976, 0.}}], Line[{{1.0471975511965976, \
0.10471975511965977}, {1.0471975511965976, 0.20943951023931953}, 
    {1.1519173063162573, 0.20943951023931953}, {1.1519173063162573, \
0.10471975511965977}, {1.0471975511965976, 0.10471975511965977}}], 
  Line[{{1.0471975511965976, 0.20943951023931953}, {1.0471975511965976, \
0.3141592653589793}, {1.1519173063162573, 0.3141592653589793}, 
    {1.1519173063162573, 0.20943951023931953}, {1.0471975511965976, \
0.20943951023931953}}], 
  Line[{{1.0471975511965976, 0.3141592653589793}, {1.0471975511965976, \
0.41887902047863906}, {1.1519173063162573, 0.41887902047863906}, 
    {1.1519173063162573, 0.3141592653589793}, {1.0471975511965976, \
0.3141592653589793}}], 
  Line[{{1.0471975511965976, 0.41887902047863906}, {1.0471975511965976, \
0.5235987755982988}, {1.1519173063162573, 0.5235987755982988}, 
    {1.1519173063162573, 0.41887902047863906}, {1.0471975511965976, \
0.41887902047863906}}], 
  Line[{{1.0471975511965976, 0.5235987755982988}, {1.0471975511965976, \
0.6283185307179586}, {1.1519173063162573, 0.6283185307179586}, 
    {1.1519173063162573, 0.5235987755982988}, {1.0471975511965976, \
0.5235987755982988}}], 
  Line[{{1.0471975511965976, 0.6283185307179586}, {1.0471975511965976, \
0.7330382858376183}, {1.1519173063162573, 0.7330382858376183}, 
    {1.1519173063162573, 0.6283185307179586}, {1.0471975511965976, \
0.6283185307179586}}], 
  Line[{{1.0471975511965976, 0.7330382858376183}, {1.0471975511965976, \
0.8377580409572781}, {1.1519173063162573, 0.8377580409572781}, 
    {1.1519173063162573, 0.7330382858376183}, {1.0471975511965976, \
0.7330382858376183}}], 
  Line[{{1.0471975511965976, 0.8377580409572781}, {1.0471975511965976, \
0.9424777960769379}, {1.1519173063162573, 0.9424777960769379}, 
    {1.1519173063162573, 0.8377580409572781}, {1.0471975511965976, \
0.8377580409572781}}], 
  Line[{{1.0471975511965976, 0.9424777960769379}, {1.0471975511965976, \
1.0471975511965976}, {1.1519173063162573, 1.0471975511965976}, 
    {1.1519173063162573, 0.9424777960769379}, {1.0471975511965976, \
0.9424777960769379}}], 
  Line[{{1.0471975511965976, 1.0471975511965976}, {1.0471975511965976, \
1.1519173063162573}, {1.1519173063162573, 1.1519173063162573}, 
    {1.1519173063162573, 1.0471975511965976}, {1.0471975511965976, \
1.0471975511965976}}], 
  Line[{{1.0471975511965976, 1.1519173063162573}, {1.0471975511965976, \
1.2566370614359172}, {1.1519173063162573, 1.2566370614359172}, 
    {1.1519173063162573, 1.1519173063162573}, {1.0471975511965976, \
1.1519173063162573}}], 
  Line[{{1.0471975511965976, 1.2566370614359172}, {1.0471975511965976, \
1.361356816555577}, {1.1519173063162573, 1.361356816555577}, 
    {1.1519173063162573, 1.2566370614359172}, {1.0471975511965976, \
1.2566370614359172}}], 
  Line[{{1.0471975511965976, 1.361356816555577}, {1.0471975511965976, \
1.4660765716752366}, {1.1519173063162573, 1.4660765716752366}, 
    {1.1519173063162573, 1.361356816555577}, {1.0471975511965976, \
1.361356816555577}}], 
  Line[{{1.0471975511965976, 1.4660765716752366}, {1.0471975511965976, \
1.5707963267948966}, {1.1519173063162573, 1.5707963267948966}, 
    {1.1519173063162573, 1.4660765716752366}, {1.0471975511965976, \
1.4660765716752366}}], 
  Line[{{1.0471975511965976, 1.5707963267948966}, {1.0471975511965976, \
1.6755160819145563}, {1.1519173063162573, 1.6755160819145563}, 
    {1.1519173063162573, 1.5707963267948966}, {1.0471975511965976, \
1.5707963267948966}}], 
  Line[{{1.0471975511965976, 1.6755160819145563}, {1.0471975511965976, \
1.780235837034216}, {1.1519173063162573, 1.780235837034216}, 
    {1.1519173063162573, 1.6755160819145563}, {1.0471975511965976, \
1.6755160819145563}}], 
  Line[{{1.0471975511965976, 1.780235837034216}, {1.0471975511965976, \
1.8849555921538759}, {1.1519173063162573, 1.8849555921538759}, 
    {1.1519173063162573, 1.780235837034216}, {1.0471975511965976, \
1.780235837034216}}], 
  Line[{{1.0471975511965976, 1.8849555921538759}, {1.0471975511965976, \
1.9896753472735356}, {1.1519173063162573, 1.9896753472735356}, 
    {1.1519173063162573, 1.8849555921538759}, {1.0471975511965976, \
1.8849555921538759}}], 
  Line[{{1.0471975511965976, 1.9896753472735356}, {1.0471975511965976, \
2.0943951023931953}, {1.1519173063162573, 2.0943951023931953}, 
    {1.1519173063162573, 1.9896753472735356}, {1.0471975511965976, \
1.9896753472735356}}], 
  Line[{{1.0471975511965976, 2.0943951023931953}, {1.0471975511965976, \
2.199114857512855}, {1.1519173063162573, 2.199114857512855}, 
    {1.1519173063162573, 2.0943951023931953}, {1.0471975511965976, \
2.0943951023931953}}], 
  Line[{{1.0471975511965976, 2.199114857512855}, {1.0471975511965976, \
2.3038346126325147}, {1.1519173063162573, 2.3038346126325147}, 
    {1.1519173063162573, 2.199114857512855}, {1.0471975511965976, \
2.199114857512855}}], 
  Line[{{1.0471975511965976, 2.3038346126325147}, {1.0471975511965976, \
2.4085543677521746}, {1.1519173063162573, 2.4085543677521746}, 
    {1.1519173063162573, 2.3038346126325147}, {1.0471975511965976, \
2.3038346126325147}}], 
  Line[{{1.0471975511965976, 2.4085543677521746}, {1.0471975511965976, \
2.5132741228718345}, {1.1519173063162573, 2.5132741228718345}, 
    {1.1519173063162573, 2.4085543677521746}, {1.0471975511965976, \
2.4085543677521746}}], 
  Line[{{1.0471975511965976, 2.5132741228718345}, {1.0471975511965976, \
2.617993877991494}, {1.1519173063162573, 2.617993877991494}, 
    {1.1519173063162573, 2.5132741228718345}, {1.0471975511965976, \
2.5132741228718345}}], 
  Line[{{1.0471975511965976, 2.617993877991494}, {1.0471975511965976, \
2.722713633111154}, {1.1519173063162573, 2.722713633111154}, 
    {1.1519173063162573, 2.617993877991494}, {1.0471975511965976, \
2.617993877991494}}], 
  Line[{{1.0471975511965976, 2.722713633111154}, {1.0471975511965976, \
2.827433388230814}, {1.1519173063162573, 2.827433388230814}, 
    {1.1519173063162573, 2.722713633111154}, {1.0471975511965976, \
2.722713633111154}}], 
  Line[{{1.0471975511965976, 2.827433388230814}, {1.0471975511965976, \
2.9321531433504733}, {1.1519173063162573, 2.9321531433504733}, 
    {1.1519173063162573, 2.827433388230814}, {1.0471975511965976, \
2.827433388230814}}], 
  Line[{{1.0471975511965976, 2.9321531433504733}, {1.0471975511965976, \
3.036872898470133}, {1.1519173063162573, 3.036872898470133}, 
    {1.1519173063162573, 2.9321531433504733}, {1.0471975511965976, \
2.9321531433504733}}], 
  Line[{{1.0471975511965976, 3.036872898470133}, {1.0471975511965976, \
3.141592653589793}, {1.1519173063162573, 3.141592653589793}, 
    {1.1519173063162573, 3.036872898470133}, {1.0471975511965976, \
3.036872898470133}}], 
  Line[{{1.0471975511965976, 3.141592653589793}, {1.0471975511965976, \
3.2463124087094526}, {1.1519173063162573, 3.2463124087094526}, 
    {1.1519173063162573, 3.141592653589793}, {1.0471975511965976, \
3.141592653589793}}], 
  Line[{{1.0471975511965976, 3.2463124087094526}, {1.0471975511965976, \
3.3510321638291125}, {1.1519173063162573, 3.3510321638291125}, 
    {1.1519173063162573, 3.2463124087094526}, {1.0471975511965976, \
3.2463124087094526}}], 
  Line[{{1.0471975511965976, 3.3510321638291125}, {1.0471975511965976, \
3.4557519189487724}, {1.1519173063162573, 3.4557519189487724}, 
    {1.1519173063162573, 3.3510321638291125}, {1.0471975511965976, \
3.3510321638291125}}], 
  Line[{{1.0471975511965976, 3.4557519189487724}, {1.0471975511965976, \
3.560471674068432}, {1.1519173063162573, 3.560471674068432}, 
    {1.1519173063162573, 3.4557519189487724}, {1.0471975511965976, \
3.4557519189487724}}], 
  Line[{{1.0471975511965976, 3.560471674068432}, {1.0471975511965976, \
3.665191429188092}, {1.1519173063162573, 3.665191429188092}, 
    {1.1519173063162573, 3.560471674068432}, {1.0471975511965976, \
3.560471674068432}}], 
  Line[{{1.0471975511965976, 3.665191429188092}, {1.0471975511965976, \
3.7699111843077517}, {1.1519173063162573, 3.7699111843077517}, 
    {1.1519173063162573, 3.665191429188092}, {1.0471975511965976, \
3.665191429188092}}], 
  Line[{{1.0471975511965976, 3.7699111843077517}, {1.0471975511965976, \
3.874630939427411}, {1.1519173063162573, 3.874630939427411}, 
    {1.1519173063162573, 3.7699111843077517}, {1.0471975511965976, \
3.7699111843077517}}], 
  Line[{{1.0471975511965976, 3.874630939427411}, {1.0471975511965976, \
3.979350694547071}, {1.1519173063162573, 3.979350694547071}, 
    {1.1519173063162573, 3.874630939427411}, {1.0471975511965976, \
3.874630939427411}}], 
  Line[{{1.0471975511965976, 3.979350694547071}, {1.0471975511965976, \
4.084070449666731}, {1.1519173063162573, 4.084070449666731}, 
    {1.1519173063162573, 3.979350694547071}, {1.0471975511965976, \
3.979350694547071}}], 
  Line[{{1.0471975511965976, 4.084070449666731}, {1.0471975511965976, \
4.1887902047863905}, {1.1519173063162573, 4.1887902047863905}, 
    {1.1519173063162573, 4.084070449666731}, {1.0471975511965976, \
4.084070449666731}}], 
  Line[{{1.0471975511965976, 4.1887902047863905}, {1.0471975511965976, \
4.29350995990605}, {1.1519173063162573, 4.29350995990605}, 
    {1.1519173063162573, 4.1887902047863905}, {1.0471975511965976, \
4.1887902047863905}}], 
  Line[{{1.0471975511965976, 4.29350995990605}, {1.0471975511965976, \
4.39822971502571}, {1.1519173063162573, 4.39822971502571}, 
    {1.1519173063162573, 4.29350995990605}, {1.0471975511965976, \
4.29350995990605}}], 
  Line[{{1.0471975511965976, 4.39822971502571}, {1.0471975511965976, \
4.50294947014537}, {1.1519173063162573, 4.50294947014537}, 
    {1.1519173063162573, 4.39822971502571}, {1.0471975511965976, \
4.39822971502571}}], 
  Line[{{1.0471975511965976, 4.50294947014537}, {1.0471975511965976, \
4.607669225265029}, {1.1519173063162573, 4.607669225265029}, 
    {1.1519173063162573, 4.50294947014537}, {1.0471975511965976, \
4.50294947014537}}], 
  Line[{{1.0471975511965976, 4.607669225265029}, {1.0471975511965976, \
4.71238898038469}, {1.1519173063162573, 4.71238898038469}, 
    {1.1519173063162573, 4.607669225265029}, {1.0471975511965976, \
4.607669225265029}}], 
  Line[{{1.0471975511965976, 4.71238898038469}, {1.0471975511965976, \
4.817108735504349}, {1.1519173063162573, 4.817108735504349}, 
    {1.1519173063162573, 4.71238898038469}, {1.0471975511965976, \
4.71238898038469}}], 
  Line[{{1.0471975511965976, 4.817108735504349}, {1.0471975511965976, \
4.921828490624009}, {1.1519173063162573, 4.921828490624009}, 
    {1.1519173063162573, 4.817108735504349}, {1.0471975511965976, \
4.817108735504349}}], 
  Line[{{1.0471975511965976, 4.921828490624009}, {1.0471975511965976, \
5.026548245743669}, {1.1519173063162573, 5.026548245743669}, 
    {1.1519173063162573, 4.921828490624009}, {1.0471975511965976, \
4.921828490624009}}], 
  Line[{{1.0471975511965976, 5.026548245743669}, {1.0471975511965976, \
5.1312680008633285}, {1.1519173063162573, 5.1312680008633285}, 
    {1.1519173063162573, 5.026548245743669}, {1.0471975511965976, \
5.026548245743669}}], 
  Line[{{1.0471975511965976, 5.1312680008633285}, {1.0471975511965976, \
5.235987755982988}, {1.1519173063162573, 5.235987755982988}, 
    {1.1519173063162573, 5.1312680008633285}, {1.0471975511965976, \
5.1312680008633285}}], 
  Line[{{1.0471975511965976, 5.235987755982988}, {1.0471975511965976, \
5.340707511102648}, {1.1519173063162573, 5.340707511102648}, 
    {1.1519173063162573, 5.235987755982988}, {1.0471975511965976, \
5.235987755982988}}], 
  Line[{{1.0471975511965976, 5.340707511102648}, {1.0471975511965976, \
5.445427266222308}, {1.1519173063162573, 5.445427266222308}, 
    {1.1519173063162573, 5.340707511102648}, {1.0471975511965976, \
5.340707511102648}}], 
  Line[{{1.0471975511965976, 5.445427266222308}, {1.0471975511965976, \
5.550147021341967}, {1.1519173063162573, 5.550147021341967}, 
    {1.1519173063162573, 5.445427266222308}, {1.0471975511965976, \
5.445427266222308}}], 
  Line[{{1.0471975511965976, 5.550147021341967}, {1.0471975511965976, \
5.654866776461628}, {1.1519173063162573, 5.654866776461628}, 
    {1.1519173063162573, 5.550147021341967}, {1.0471975511965976, \
5.550147021341967}}], 
  Line[{{1.0471975511965976, 5.654866776461628}, {1.0471975511965976, \
5.759586531581287}, {1.1519173063162573, 5.759586531581287}, 
    {1.1519173063162573, 5.654866776461628}, {1.0471975511965976, \
5.654866776461628}}], 
  Line[{{1.0471975511965976, 5.759586531581287}, {1.0471975511965976, \
5.864306286700947}, {1.1519173063162573, 5.864306286700947}, 
    {1.1519173063162573, 5.759586531581287}, {1.0471975511965976, \
5.759586531581287}}], 
  Line[{{1.0471975511965976, 5.864306286700947}, {1.0471975511965976, \
5.969026041820607}, {1.1519173063162573, 5.969026041820607}, 
    {1.1519173063162573, 5.864306286700947}, {1.0471975511965976, \
5.864306286700947}}], 
  Line[{{1.0471975511965976, 5.969026041820607}, {1.0471975511965976, \
6.073745796940266}, {1.1519173063162573, 6.073745796940266}, 
    {1.1519173063162573, 5.969026041820607}, {1.0471975511965976, \
5.969026041820607}}], 
  Line[{{1.0471975511965976, 6.073745796940266}, {1.0471975511965976, \
6.178465552059926}, {1.1519173063162573, 6.178465552059926}, 
    {1.1519173063162573, 6.073745796940266}, {1.0471975511965976, \
6.073745796940266}}], 
  Line[{{1.0471975511965976, 6.178465552059926}, {1.0471975511965976, \
6.283185307179586}, {1.1519173063162573, 6.283185307179586}, 
    {1.1519173063162573, 6.178465552059926}, {1.0471975511965976, \
6.178465552059926}}], 
  Line[{{1.1519173063162573, 0.}, {1.1519173063162573, 0.10471975511965977}, \
{1.2566370614359172, 0.10471975511965977}, {1.2566370614359172, 0.}, 
    {1.1519173063162573, 0.}}], Line[{{1.1519173063162573, \
0.10471975511965977}, {1.1519173063162573, 0.20943951023931953}, 
    {1.2566370614359172, 0.20943951023931953}, {1.2566370614359172, \
0.10471975511965977}, {1.1519173063162573, 0.10471975511965977}}], 
  Line[{{1.1519173063162573, 0.20943951023931953}, {1.1519173063162573, \
0.3141592653589793}, {1.2566370614359172, 0.3141592653589793}, 
    {1.2566370614359172, 0.20943951023931953}, {1.1519173063162573, \
0.20943951023931953}}], 
  Line[{{1.1519173063162573, 0.3141592653589793}, {1.1519173063162573, \
0.41887902047863906}, {1.2566370614359172, 0.41887902047863906}, 
    {1.2566370614359172, 0.3141592653589793}, {1.1519173063162573, \
0.3141592653589793}}], 
  Line[{{1.1519173063162573, 0.41887902047863906}, {1.1519173063162573, \
0.5235987755982988}, {1.2566370614359172, 0.5235987755982988}, 
    {1.2566370614359172, 0.41887902047863906}, {1.1519173063162573, \
0.41887902047863906}}], 
  Line[{{1.1519173063162573, 0.5235987755982988}, {1.1519173063162573, \
0.6283185307179586}, {1.2566370614359172, 0.6283185307179586}, 
    {1.2566370614359172, 0.5235987755982988}, {1.1519173063162573, \
0.5235987755982988}}], 
  Line[{{1.1519173063162573, 0.6283185307179586}, {1.1519173063162573, \
0.7330382858376183}, {1.2566370614359172, 0.7330382858376183}, 
    {1.2566370614359172, 0.6283185307179586}, {1.1519173063162573, \
0.6283185307179586}}], 
  Line[{{1.1519173063162573, 0.7330382858376183}, {1.1519173063162573, \
0.8377580409572781}, {1.2566370614359172, 0.8377580409572781}, 
    {1.2566370614359172, 0.7330382858376183}, {1.1519173063162573, \
0.7330382858376183}}], 
  Line[{{1.1519173063162573, 0.8377580409572781}, {1.1519173063162573, \
0.9424777960769379}, {1.2566370614359172, 0.9424777960769379}, 
    {1.2566370614359172, 0.8377580409572781}, {1.1519173063162573, \
0.8377580409572781}}], 
  Line[{{1.1519173063162573, 0.9424777960769379}, {1.1519173063162573, \
1.0471975511965976}, {1.2566370614359172, 1.0471975511965976}, 
    {1.2566370614359172, 0.9424777960769379}, {1.1519173063162573, \
0.9424777960769379}}], 
  Line[{{1.1519173063162573, 1.0471975511965976}, {1.1519173063162573, \
1.1519173063162573}, {1.2566370614359172, 1.1519173063162573}, 
    {1.2566370614359172, 1.0471975511965976}, {1.1519173063162573, \
1.0471975511965976}}], 
  Line[{{1.1519173063162573, 1.1519173063162573}, {1.1519173063162573, \
1.2566370614359172}, {1.2566370614359172, 1.2566370614359172}, 
    {1.2566370614359172, 1.1519173063162573}, {1.1519173063162573, \
1.1519173063162573}}], 
  Line[{{1.1519173063162573, 1.2566370614359172}, {1.1519173063162573, \
1.361356816555577}, {1.2566370614359172, 1.361356816555577}, 
    {1.2566370614359172, 1.2566370614359172}, {1.1519173063162573, \
1.2566370614359172}}], 
  Line[{{1.1519173063162573, 1.361356816555577}, {1.1519173063162573, \
1.4660765716752366}, {1.2566370614359172, 1.4660765716752366}, 
    {1.2566370614359172, 1.361356816555577}, {1.1519173063162573, \
1.361356816555577}}], 
  Line[{{1.1519173063162573, 1.4660765716752366}, {1.1519173063162573, \
1.5707963267948966}, {1.2566370614359172, 1.5707963267948966}, 
    {1.2566370614359172, 1.4660765716752366}, {1.1519173063162573, \
1.4660765716752366}}], 
  Line[{{1.1519173063162573, 1.5707963267948966}, {1.1519173063162573, \
1.6755160819145563}, {1.2566370614359172, 1.6755160819145563}, 
    {1.2566370614359172, 1.5707963267948966}, {1.1519173063162573, \
1.5707963267948966}}], 
  Line[{{1.1519173063162573, 1.6755160819145563}, {1.1519173063162573, \
1.780235837034216}, {1.2566370614359172, 1.780235837034216}, 
    {1.2566370614359172, 1.6755160819145563}, {1.1519173063162573, \
1.6755160819145563}}], 
  Line[{{1.1519173063162573, 1.780235837034216}, {1.1519173063162573, \
1.8849555921538759}, {1.2566370614359172, 1.8849555921538759}, 
    {1.2566370614359172, 1.780235837034216}, {1.1519173063162573, \
1.780235837034216}}], 
  Line[{{1.1519173063162573, 1.8849555921538759}, {1.1519173063162573, \
1.9896753472735356}, {1.2566370614359172, 1.9896753472735356}, 
    {1.2566370614359172, 1.8849555921538759}, {1.1519173063162573, \
1.8849555921538759}}], 
  Line[{{1.1519173063162573, 1.9896753472735356}, {1.1519173063162573, \
2.0943951023931953}, {1.2566370614359172, 2.0943951023931953}, 
    {1.2566370614359172, 1.9896753472735356}, {1.1519173063162573, \
1.9896753472735356}}], 
  Line[{{1.1519173063162573, 2.0943951023931953}, {1.1519173063162573, \
2.199114857512855}, {1.2566370614359172, 2.199114857512855}, 
    {1.2566370614359172, 2.0943951023931953}, {1.1519173063162573, \
2.0943951023931953}}], 
  Line[{{1.1519173063162573, 2.199114857512855}, {1.1519173063162573, \
2.3038346126325147}, {1.2566370614359172, 2.3038346126325147}, 
    {1.2566370614359172, 2.199114857512855}, {1.1519173063162573, \
2.199114857512855}}], 
  Line[{{1.1519173063162573, 2.3038346126325147}, {1.1519173063162573, \
2.4085543677521746}, {1.2566370614359172, 2.4085543677521746}, 
    {1.2566370614359172, 2.3038346126325147}, {1.1519173063162573, \
2.3038346126325147}}], 
  Line[{{1.1519173063162573, 2.4085543677521746}, {1.1519173063162573, \
2.5132741228718345}, {1.2566370614359172, 2.5132741228718345}, 
    {1.2566370614359172, 2.4085543677521746}, {1.1519173063162573, \
2.4085543677521746}}], 
  Line[{{1.1519173063162573, 2.5132741228718345}, {1.1519173063162573, \
2.617993877991494}, {1.2566370614359172, 2.617993877991494}, 
    {1.2566370614359172, 2.5132741228718345}, {1.1519173063162573, \
2.5132741228718345}}], 
  Line[{{1.1519173063162573, 2.617993877991494}, {1.1519173063162573, \
2.722713633111154}, {1.2566370614359172, 2.722713633111154}, 
    {1.2566370614359172, 2.617993877991494}, {1.1519173063162573, \
2.617993877991494}}], 
  Line[{{1.1519173063162573, 2.722713633111154}, {1.1519173063162573, \
2.827433388230814}, {1.2566370614359172, 2.827433388230814}, 
    {1.2566370614359172, 2.722713633111154}, {1.1519173063162573, \
2.722713633111154}}], 
  Line[{{1.1519173063162573, 2.827433388230814}, {1.1519173063162573, \
2.9321531433504733}, {1.2566370614359172, 2.9321531433504733}, 
    {1.2566370614359172, 2.827433388230814}, {1.1519173063162573, \
2.827433388230814}}], 
  Line[{{1.1519173063162573, 2.9321531433504733}, {1.1519173063162573, \
3.036872898470133}, {1.2566370614359172, 3.036872898470133}, 
    {1.2566370614359172, 2.9321531433504733}, {1.1519173063162573, \
2.9321531433504733}}], 
  Line[{{1.1519173063162573, 3.036872898470133}, {1.1519173063162573, \
3.141592653589793}, {1.2566370614359172, 3.141592653589793}, 
    {1.2566370614359172, 3.036872898470133}, {1.1519173063162573, \
3.036872898470133}}], 
  Line[{{1.1519173063162573, 3.141592653589793}, {1.1519173063162573, \
3.2463124087094526}, {1.2566370614359172, 3.2463124087094526}, 
    {1.2566370614359172, 3.141592653589793}, {1.1519173063162573, \
3.141592653589793}}], 
  Line[{{1.1519173063162573, 3.2463124087094526}, {1.1519173063162573, \
3.3510321638291125}, {1.2566370614359172, 3.3510321638291125}, 
    {1.2566370614359172, 3.2463124087094526}, {1.1519173063162573, \
3.2463124087094526}}], 
  Line[{{1.1519173063162573, 3.3510321638291125}, {1.1519173063162573, \
3.4557519189487724}, {1.2566370614359172, 3.4557519189487724}, 
    {1.2566370614359172, 3.3510321638291125}, {1.1519173063162573, \
3.3510321638291125}}], 
  Line[{{1.1519173063162573, 3.4557519189487724}, {1.1519173063162573, \
3.560471674068432}, {1.2566370614359172, 3.560471674068432}, 
    {1.2566370614359172, 3.4557519189487724}, {1.1519173063162573, \
3.4557519189487724}}], 
  Line[{{1.1519173063162573, 3.560471674068432}, {1.1519173063162573, \
3.665191429188092}, {1.2566370614359172, 3.665191429188092}, 
    {1.2566370614359172, 3.560471674068432}, {1.1519173063162573, \
3.560471674068432}}], 
  Line[{{1.1519173063162573, 3.665191429188092}, {1.1519173063162573, \
3.7699111843077517}, {1.2566370614359172, 3.7699111843077517}, 
    {1.2566370614359172, 3.665191429188092}, {1.1519173063162573, \
3.665191429188092}}], 
  Line[{{1.1519173063162573, 3.7699111843077517}, {1.1519173063162573, \
3.874630939427411}, {1.2566370614359172, 3.874630939427411}, 
    {1.2566370614359172, 3.7699111843077517}, {1.1519173063162573, \
3.7699111843077517}}], 
  Line[{{1.1519173063162573, 3.874630939427411}, {1.1519173063162573, \
3.979350694547071}, {1.2566370614359172, 3.979350694547071}, 
    {1.2566370614359172, 3.874630939427411}, {1.1519173063162573, \
3.874630939427411}}], 
  Line[{{1.1519173063162573, 3.979350694547071}, {1.1519173063162573, \
4.084070449666731}, {1.2566370614359172, 4.084070449666731}, 
    {1.2566370614359172, 3.979350694547071}, {1.1519173063162573, \
3.979350694547071}}], 
  Line[{{1.1519173063162573, 4.084070449666731}, {1.1519173063162573, \
4.1887902047863905}, {1.2566370614359172, 4.1887902047863905}, 
    {1.2566370614359172, 4.084070449666731}, {1.1519173063162573, \
4.084070449666731}}], 
  Line[{{1.1519173063162573, 4.1887902047863905}, {1.1519173063162573, \
4.29350995990605}, {1.2566370614359172, 4.29350995990605}, 
    {1.2566370614359172, 4.1887902047863905}, {1.1519173063162573, \
4.1887902047863905}}], 
  Line[{{1.1519173063162573, 4.29350995990605}, {1.1519173063162573, \
4.39822971502571}, {1.2566370614359172, 4.39822971502571}, 
    {1.2566370614359172, 4.29350995990605}, {1.1519173063162573, \
4.29350995990605}}], 
  Line[{{1.1519173063162573, 4.39822971502571}, {1.1519173063162573, \
4.50294947014537}, {1.2566370614359172, 4.50294947014537}, 
    {1.2566370614359172, 4.39822971502571}, {1.1519173063162573, \
4.39822971502571}}], 
  Line[{{1.1519173063162573, 4.50294947014537}, {1.1519173063162573, \
4.607669225265029}, {1.2566370614359172, 4.607669225265029}, 
    {1.2566370614359172, 4.50294947014537}, {1.1519173063162573, \
4.50294947014537}}], 
  Line[{{1.1519173063162573, 4.607669225265029}, {1.1519173063162573, \
4.71238898038469}, {1.2566370614359172, 4.71238898038469}, 
    {1.2566370614359172, 4.607669225265029}, {1.1519173063162573, \
4.607669225265029}}], 
  Line[{{1.1519173063162573, 4.71238898038469}, {1.1519173063162573, \
4.817108735504349}, {1.2566370614359172, 4.817108735504349}, 
    {1.2566370614359172, 4.71238898038469}, {1.1519173063162573, \
4.71238898038469}}], 
  Line[{{1.1519173063162573, 4.817108735504349}, {1.1519173063162573, \
4.921828490624009}, {1.2566370614359172, 4.921828490624009}, 
    {1.2566370614359172, 4.817108735504349}, {1.1519173063162573, \
4.817108735504349}}], 
  Line[{{1.1519173063162573, 4.921828490624009}, {1.1519173063162573, \
5.026548245743669}, {1.2566370614359172, 5.026548245743669}, 
    {1.2566370614359172, 4.921828490624009}, {1.1519173063162573, \
4.921828490624009}}], 
  Line[{{1.1519173063162573, 5.026548245743669}, {1.1519173063162573, \
5.1312680008633285}, {1.2566370614359172, 5.1312680008633285}, 
    {1.2566370614359172, 5.026548245743669}, {1.1519173063162573, \
5.026548245743669}}], 
  Line[{{1.1519173063162573, 5.1312680008633285}, {1.1519173063162573, \
5.235987755982988}, {1.2566370614359172, 5.235987755982988}, 
    {1.2566370614359172, 5.1312680008633285}, {1.1519173063162573, \
5.1312680008633285}}], 
  Line[{{1.1519173063162573, 5.235987755982988}, {1.1519173063162573, \
5.340707511102648}, {1.2566370614359172, 5.340707511102648}, 
    {1.2566370614359172, 5.235987755982988}, {1.1519173063162573, \
5.235987755982988}}], 
  Line[{{1.1519173063162573, 5.340707511102648}, {1.1519173063162573, \
5.445427266222308}, {1.2566370614359172, 5.445427266222308}, 
    {1.2566370614359172, 5.340707511102648}, {1.1519173063162573, \
5.340707511102648}}], 
  Line[{{1.1519173063162573, 5.445427266222308}, {1.1519173063162573, \
5.550147021341967}, {1.2566370614359172, 5.550147021341967}, 
    {1.2566370614359172, 5.445427266222308}, {1.1519173063162573, \
5.445427266222308}}], 
  Line[{{1.1519173063162573, 5.550147021341967}, {1.1519173063162573, \
5.654866776461628}, {1.2566370614359172, 5.654866776461628}, 
    {1.2566370614359172, 5.550147021341967}, {1.1519173063162573, \
5.550147021341967}}], 
  Line[{{1.1519173063162573, 5.654866776461628}, {1.1519173063162573, \
5.759586531581287}, {1.2566370614359172, 5.759586531581287}, 
    {1.2566370614359172, 5.654866776461628}, {1.1519173063162573, \
5.654866776461628}}], 
  Line[{{1.1519173063162573, 5.759586531581287}, {1.1519173063162573, \
5.864306286700947}, {1.2566370614359172, 5.864306286700947}, 
    {1.2566370614359172, 5.759586531581287}, {1.1519173063162573, \
5.759586531581287}}], 
  Line[{{1.1519173063162573, 5.864306286700947}, {1.1519173063162573, \
5.969026041820607}, {1.2566370614359172, 5.969026041820607}, 
    {1.2566370614359172, 5.864306286700947}, {1.1519173063162573, \
5.864306286700947}}], 
  Line[{{1.1519173063162573, 5.969026041820607}, {1.1519173063162573, \
6.073745796940266}, {1.2566370614359172, 6.073745796940266}, 
    {1.2566370614359172, 5.969026041820607}, {1.1519173063162573, \
5.969026041820607}}], 
  Line[{{1.1519173063162573, 6.073745796940266}, {1.1519173063162573, \
6.178465552059926}, {1.2566370614359172, 6.178465552059926}, 
    {1.2566370614359172, 6.073745796940266}, {1.1519173063162573, \
6.073745796940266}}], 
  Line[{{1.1519173063162573, 6.178465552059926}, {1.1519173063162573, \
6.283185307179586}, {1.2566370614359172, 6.283185307179586}, 
    {1.2566370614359172, 6.178465552059926}, {1.1519173063162573, \
6.178465552059926}}], 
  Line[{{1.2566370614359172, 0.}, {1.2566370614359172, 0.10471975511965977}, \
{1.361356816555577, 0.10471975511965977}, {1.361356816555577, 0.}, 
    {1.2566370614359172, 0.}}], Line[{{1.2566370614359172, \
0.10471975511965977}, {1.2566370614359172, 0.20943951023931953}, 
    {1.361356816555577, 0.20943951023931953}, {1.361356816555577, \
0.10471975511965977}, {1.2566370614359172, 0.10471975511965977}}], 
  Line[{{1.2566370614359172, 0.20943951023931953}, {1.2566370614359172, \
0.3141592653589793}, {1.361356816555577, 0.3141592653589793}, 
    {1.361356816555577, 0.20943951023931953}, {1.2566370614359172, \
0.20943951023931953}}], 
  Line[{{1.2566370614359172, 0.3141592653589793}, {1.2566370614359172, \
0.41887902047863906}, {1.361356816555577, 0.41887902047863906}, 
    {1.361356816555577, 0.3141592653589793}, {1.2566370614359172, \
0.3141592653589793}}], 
  Line[{{1.2566370614359172, 0.41887902047863906}, {1.2566370614359172, \
0.5235987755982988}, {1.361356816555577, 0.5235987755982988}, 
    {1.361356816555577, 0.41887902047863906}, {1.2566370614359172, \
0.41887902047863906}}], 
  Line[{{1.2566370614359172, 0.5235987755982988}, {1.2566370614359172, \
0.6283185307179586}, {1.361356816555577, 0.6283185307179586}, 
    {1.361356816555577, 0.5235987755982988}, {1.2566370614359172, \
0.5235987755982988}}], 
  Line[{{1.2566370614359172, 0.6283185307179586}, {1.2566370614359172, \
0.7330382858376183}, {1.361356816555577, 0.7330382858376183}, 
    {1.361356816555577, 0.6283185307179586}, {1.2566370614359172, \
0.6283185307179586}}], 
  Line[{{1.2566370614359172, 0.7330382858376183}, {1.2566370614359172, \
0.8377580409572781}, {1.361356816555577, 0.8377580409572781}, 
    {1.361356816555577, 0.7330382858376183}, {1.2566370614359172, \
0.7330382858376183}}], 
  Line[{{1.2566370614359172, 0.8377580409572781}, {1.2566370614359172, \
0.9424777960769379}, {1.361356816555577, 0.9424777960769379}, 
    {1.361356816555577, 0.8377580409572781}, {1.2566370614359172, \
0.8377580409572781}}], 
  Line[{{1.2566370614359172, 0.9424777960769379}, {1.2566370614359172, \
1.0471975511965976}, {1.361356816555577, 1.0471975511965976}, 
    {1.361356816555577, 0.9424777960769379}, {1.2566370614359172, \
0.9424777960769379}}], 
  Line[{{1.2566370614359172, 1.0471975511965976}, {1.2566370614359172, \
1.1519173063162573}, {1.361356816555577, 1.1519173063162573}, 
    {1.361356816555577, 1.0471975511965976}, {1.2566370614359172, \
1.0471975511965976}}], 
  Line[{{1.2566370614359172, 1.1519173063162573}, {1.2566370614359172, \
1.2566370614359172}, {1.361356816555577, 1.2566370614359172}, 
    {1.361356816555577, 1.1519173063162573}, {1.2566370614359172, \
1.1519173063162573}}], 
  Line[{{1.2566370614359172, 1.2566370614359172}, {1.2566370614359172, \
1.361356816555577}, {1.361356816555577, 1.361356816555577}, 
    {1.361356816555577, 1.2566370614359172}, {1.2566370614359172, \
1.2566370614359172}}], 
  Line[{{1.2566370614359172, 1.361356816555577}, {1.2566370614359172, \
1.4660765716752366}, {1.361356816555577, 1.4660765716752366}, 
    {1.361356816555577, 1.361356816555577}, {1.2566370614359172, \
1.361356816555577}}], 
  Line[{{1.2566370614359172, 1.4660765716752366}, {1.2566370614359172, \
1.5707963267948966}, {1.361356816555577, 1.5707963267948966}, 
    {1.361356816555577, 1.4660765716752366}, {1.2566370614359172, \
1.4660765716752366}}], 
  Line[{{1.2566370614359172, 1.5707963267948966}, {1.2566370614359172, \
1.6755160819145563}, {1.361356816555577, 1.6755160819145563}, 
    {1.361356816555577, 1.5707963267948966}, {1.2566370614359172, \
1.5707963267948966}}], 
  Line[{{1.2566370614359172, 1.6755160819145563}, {1.2566370614359172, \
1.780235837034216}, {1.361356816555577, 1.780235837034216}, 
    {1.361356816555577, 1.6755160819145563}, {1.2566370614359172, \
1.6755160819145563}}], 
  Line[{{1.2566370614359172, 1.780235837034216}, {1.2566370614359172, \
1.8849555921538759}, {1.361356816555577, 1.8849555921538759}, 
    {1.361356816555577, 1.780235837034216}, {1.2566370614359172, \
1.780235837034216}}], 
  Line[{{1.2566370614359172, 1.8849555921538759}, {1.2566370614359172, \
1.9896753472735356}, {1.361356816555577, 1.9896753472735356}, 
    {1.361356816555577, 1.8849555921538759}, {1.2566370614359172, \
1.8849555921538759}}], 
  Line[{{1.2566370614359172, 1.9896753472735356}, {1.2566370614359172, \
2.0943951023931953}, {1.361356816555577, 2.0943951023931953}, 
    {1.361356816555577, 1.9896753472735356}, {1.2566370614359172, \
1.9896753472735356}}], 
  Line[{{1.2566370614359172, 2.0943951023931953}, {1.2566370614359172, \
2.199114857512855}, {1.361356816555577, 2.199114857512855}, 
    {1.361356816555577, 2.0943951023931953}, {1.2566370614359172, \
2.0943951023931953}}], 
  Line[{{1.2566370614359172, 2.199114857512855}, {1.2566370614359172, \
2.3038346126325147}, {1.361356816555577, 2.3038346126325147}, 
    {1.361356816555577, 2.199114857512855}, {1.2566370614359172, \
2.199114857512855}}], 
  Line[{{1.2566370614359172, 2.3038346126325147}, {1.2566370614359172, \
2.4085543677521746}, {1.361356816555577, 2.4085543677521746}, 
    {1.361356816555577, 2.3038346126325147}, {1.2566370614359172, \
2.3038346126325147}}], 
  Line[{{1.2566370614359172, 2.4085543677521746}, {1.2566370614359172, \
2.5132741228718345}, {1.361356816555577, 2.5132741228718345}, 
    {1.361356816555577, 2.4085543677521746}, {1.2566370614359172, \
2.4085543677521746}}], 
  Line[{{1.2566370614359172, 2.5132741228718345}, {1.2566370614359172, \
2.617993877991494}, {1.361356816555577, 2.617993877991494}, 
    {1.361356816555577, 2.5132741228718345}, {1.2566370614359172, \
2.5132741228718345}}], 
  Line[{{1.2566370614359172, 2.617993877991494}, {1.2566370614359172, \
2.722713633111154}, {1.361356816555577, 2.722713633111154}, 
    {1.361356816555577, 2.617993877991494}, {1.2566370614359172, \
2.617993877991494}}], 
  Line[{{1.2566370614359172, 2.722713633111154}, {1.2566370614359172, \
2.827433388230814}, {1.361356816555577, 2.827433388230814}, 
    {1.361356816555577, 2.722713633111154}, {1.2566370614359172, \
2.722713633111154}}], 
  Line[{{1.2566370614359172, 2.827433388230814}, {1.2566370614359172, \
2.9321531433504733}, {1.361356816555577, 2.9321531433504733}, 
    {1.361356816555577, 2.827433388230814}, {1.2566370614359172, \
2.827433388230814}}], 
  Line[{{1.2566370614359172, 2.9321531433504733}, {1.2566370614359172, \
3.036872898470133}, {1.361356816555577, 3.036872898470133}, 
    {1.361356816555577, 2.9321531433504733}, {1.2566370614359172, \
2.9321531433504733}}], 
  Line[{{1.2566370614359172, 3.036872898470133}, {1.2566370614359172, \
3.141592653589793}, {1.361356816555577, 3.141592653589793}, 
    {1.361356816555577, 3.036872898470133}, {1.2566370614359172, \
3.036872898470133}}], 
  Line[{{1.2566370614359172, 3.141592653589793}, {1.2566370614359172, \
3.2463124087094526}, {1.361356816555577, 3.2463124087094526}, 
    {1.361356816555577, 3.141592653589793}, {1.2566370614359172, \
3.141592653589793}}], 
  Line[{{1.2566370614359172, 3.2463124087094526}, {1.2566370614359172, \
3.3510321638291125}, {1.361356816555577, 3.3510321638291125}, 
    {1.361356816555577, 3.2463124087094526}, {1.2566370614359172, \
3.2463124087094526}}], 
  Line[{{1.2566370614359172, 3.3510321638291125}, {1.2566370614359172, \
3.4557519189487724}, {1.361356816555577, 3.4557519189487724}, 
    {1.361356816555577, 3.3510321638291125}, {1.2566370614359172, \
3.3510321638291125}}], 
  Line[{{1.2566370614359172, 3.4557519189487724}, {1.2566370614359172, \
3.560471674068432}, {1.361356816555577, 3.560471674068432}, 
    {1.361356816555577, 3.4557519189487724}, {1.2566370614359172, \
3.4557519189487724}}], 
  Line[{{1.2566370614359172, 3.560471674068432}, {1.2566370614359172, \
3.665191429188092}, {1.361356816555577, 3.665191429188092}, 
    {1.361356816555577, 3.560471674068432}, {1.2566370614359172, \
3.560471674068432}}], 
  Line[{{1.2566370614359172, 3.665191429188092}, {1.2566370614359172, \
3.7699111843077517}, {1.361356816555577, 3.7699111843077517}, 
    {1.361356816555577, 3.665191429188092}, {1.2566370614359172, \
3.665191429188092}}], 
  Line[{{1.2566370614359172, 3.7699111843077517}, {1.2566370614359172, \
3.874630939427411}, {1.361356816555577, 3.874630939427411}, 
    {1.361356816555577, 3.7699111843077517}, {1.2566370614359172, \
3.7699111843077517}}], 
  Line[{{1.2566370614359172, 3.874630939427411}, {1.2566370614359172, \
3.979350694547071}, {1.361356816555577, 3.979350694547071}, 
    {1.361356816555577, 3.874630939427411}, {1.2566370614359172, \
3.874630939427411}}], 
  Line[{{1.2566370614359172, 3.979350694547071}, {1.2566370614359172, \
4.084070449666731}, {1.361356816555577, 4.084070449666731}, 
    {1.361356816555577, 3.979350694547071}, {1.2566370614359172, \
3.979350694547071}}], 
  Line[{{1.2566370614359172, 4.084070449666731}, {1.2566370614359172, \
4.1887902047863905}, {1.361356816555577, 4.1887902047863905}, 
    {1.361356816555577, 4.084070449666731}, {1.2566370614359172, \
4.084070449666731}}], 
  Line[{{1.2566370614359172, 4.1887902047863905}, {1.2566370614359172, \
4.29350995990605}, {1.361356816555577, 4.29350995990605}, 
    {1.361356816555577, 4.1887902047863905}, {1.2566370614359172, \
4.1887902047863905}}], 
  Line[{{1.2566370614359172, 4.29350995990605}, {1.2566370614359172, \
4.39822971502571}, {1.361356816555577, 4.39822971502571}, 
    {1.361356816555577, 4.29350995990605}, {1.2566370614359172, \
4.29350995990605}}], 
  Line[{{1.2566370614359172, 4.39822971502571}, {1.2566370614359172, \
4.50294947014537}, {1.361356816555577, 4.50294947014537}, 
    {1.361356816555577, 4.39822971502571}, {1.2566370614359172, \
4.39822971502571}}], 
  Line[{{1.2566370614359172, 4.50294947014537}, {1.2566370614359172, \
4.607669225265029}, {1.361356816555577, 4.607669225265029}, 
    {1.361356816555577, 4.50294947014537}, {1.2566370614359172, \
4.50294947014537}}], 
  Line[{{1.2566370614359172, 4.607669225265029}, {1.2566370614359172, \
4.71238898038469}, {1.361356816555577, 4.71238898038469}, 
    {1.361356816555577, 4.607669225265029}, {1.2566370614359172, \
4.607669225265029}}], 
  Line[{{1.2566370614359172, 4.71238898038469}, {1.2566370614359172, \
4.817108735504349}, {1.361356816555577, 4.817108735504349}, 
    {1.361356816555577, 4.71238898038469}, {1.2566370614359172, \
4.71238898038469}}], 
  Line[{{1.2566370614359172, 4.817108735504349}, {1.2566370614359172, \
4.921828490624009}, {1.361356816555577, 4.921828490624009}, 
    {1.361356816555577, 4.817108735504349}, {1.2566370614359172, \
4.817108735504349}}], 
  Line[{{1.2566370614359172, 4.921828490624009}, {1.2566370614359172, \
5.026548245743669}, {1.361356816555577, 5.026548245743669}, 
    {1.361356816555577, 4.921828490624009}, {1.2566370614359172, \
4.921828490624009}}], 
  Line[{{1.2566370614359172, 5.026548245743669}, {1.2566370614359172, \
5.1312680008633285}, {1.361356816555577, 5.1312680008633285}, 
    {1.361356816555577, 5.026548245743669}, {1.2566370614359172, \
5.026548245743669}}], 
  Line[{{1.2566370614359172, 5.1312680008633285}, {1.2566370614359172, \
5.235987755982988}, {1.361356816555577, 5.235987755982988}, 
    {1.361356816555577, 5.1312680008633285}, {1.2566370614359172, \
5.1312680008633285}}], 
  Line[{{1.2566370614359172, 5.235987755982988}, {1.2566370614359172, \
5.340707511102648}, {1.361356816555577, 5.340707511102648}, 
    {1.361356816555577, 5.235987755982988}, {1.2566370614359172, \
5.235987755982988}}], 
  Line[{{1.2566370614359172, 5.340707511102648}, {1.2566370614359172, \
5.445427266222308}, {1.361356816555577, 5.445427266222308}, 
    {1.361356816555577, 5.340707511102648}, {1.2566370614359172, \
5.340707511102648}}], 
  Line[{{1.2566370614359172, 5.445427266222308}, {1.2566370614359172, \
5.550147021341967}, {1.361356816555577, 5.550147021341967}, 
    {1.361356816555577, 5.445427266222308}, {1.2566370614359172, \
5.445427266222308}}], 
  Line[{{1.2566370614359172, 5.550147021341967}, {1.2566370614359172, \
5.654866776461628}, {1.361356816555577, 5.654866776461628}, 
    {1.361356816555577, 5.550147021341967}, {1.2566370614359172, \
5.550147021341967}}], 
  Line[{{1.2566370614359172, 5.654866776461628}, {1.2566370614359172, \
5.759586531581287}, {1.361356816555577, 5.759586531581287}, 
    {1.361356816555577, 5.654866776461628}, {1.2566370614359172, \
5.654866776461628}}], 
  Line[{{1.2566370614359172, 5.759586531581287}, {1.2566370614359172, \
5.864306286700947}, {1.361356816555577, 5.864306286700947}, 
    {1.361356816555577, 5.759586531581287}, {1.2566370614359172, \
5.759586531581287}}], 
  Line[{{1.2566370614359172, 5.864306286700947}, {1.2566370614359172, \
5.969026041820607}, {1.361356816555577, 5.969026041820607}, 
    {1.361356816555577, 5.864306286700947}, {1.2566370614359172, \
5.864306286700947}}], 
  Line[{{1.2566370614359172, 5.969026041820607}, {1.2566370614359172, \
6.073745796940266}, {1.361356816555577, 6.073745796940266}, 
    {1.361356816555577, 5.969026041820607}, {1.2566370614359172, \
5.969026041820607}}], 
  Line[{{1.2566370614359172, 6.073745796940266}, {1.2566370614359172, \
6.178465552059926}, {1.361356816555577, 6.178465552059926}, 
    {1.361356816555577, 6.073745796940266}, {1.2566370614359172, \
6.073745796940266}}], 
  Line[{{1.2566370614359172, 6.178465552059926}, {1.2566370614359172, \
6.283185307179586}, {1.361356816555577, 6.283185307179586}, 
    {1.361356816555577, 6.178465552059926}, {1.2566370614359172, \
6.178465552059926}}], 
  Line[{{1.361356816555577, 0.}, {1.361356816555577, 0.10471975511965977}, \
{1.4660765716752366, 0.10471975511965977}, {1.4660765716752366, 0.}, 
    {1.361356816555577, 0.}}], Line[{{1.361356816555577, \
0.10471975511965977}, {1.361356816555577, 0.20943951023931953}, 
    {1.4660765716752366, 0.20943951023931953}, {1.4660765716752366, \
0.10471975511965977}, {1.361356816555577, 0.10471975511965977}}], 
  Line[{{1.361356816555577, 0.20943951023931953}, {1.361356816555577, \
0.3141592653589793}, {1.4660765716752366, 0.3141592653589793}, 
    {1.4660765716752366, 0.20943951023931953}, {1.361356816555577, \
0.20943951023931953}}], 
  Line[{{1.361356816555577, 0.3141592653589793}, {1.361356816555577, \
0.41887902047863906}, {1.4660765716752366, 0.41887902047863906}, 
    {1.4660765716752366, 0.3141592653589793}, {1.361356816555577, \
0.3141592653589793}}], 
  Line[{{1.361356816555577, 0.41887902047863906}, {1.361356816555577, \
0.5235987755982988}, {1.4660765716752366, 0.5235987755982988}, 
    {1.4660765716752366, 0.41887902047863906}, {1.361356816555577, \
0.41887902047863906}}], 
  Line[{{1.361356816555577, 0.5235987755982988}, {1.361356816555577, \
0.6283185307179586}, {1.4660765716752366, 0.6283185307179586}, 
    {1.4660765716752366, 0.5235987755982988}, {1.361356816555577, \
0.5235987755982988}}], 
  Line[{{1.361356816555577, 0.6283185307179586}, {1.361356816555577, \
0.7330382858376183}, {1.4660765716752366, 0.7330382858376183}, 
    {1.4660765716752366, 0.6283185307179586}, {1.361356816555577, \
0.6283185307179586}}], 
  Line[{{1.361356816555577, 0.7330382858376183}, {1.361356816555577, \
0.8377580409572781}, {1.4660765716752366, 0.8377580409572781}, 
    {1.4660765716752366, 0.7330382858376183}, {1.361356816555577, \
0.7330382858376183}}], 
  Line[{{1.361356816555577, 0.8377580409572781}, {1.361356816555577, \
0.9424777960769379}, {1.4660765716752366, 0.9424777960769379}, 
    {1.4660765716752366, 0.8377580409572781}, {1.361356816555577, \
0.8377580409572781}}], 
  Line[{{1.361356816555577, 0.9424777960769379}, {1.361356816555577, \
1.0471975511965976}, {1.4660765716752366, 1.0471975511965976}, 
    {1.4660765716752366, 0.9424777960769379}, {1.361356816555577, \
0.9424777960769379}}], 
  Line[{{1.361356816555577, 1.0471975511965976}, {1.361356816555577, \
1.1519173063162573}, {1.4660765716752366, 1.1519173063162573}, 
    {1.4660765716752366, 1.0471975511965976}, {1.361356816555577, \
1.0471975511965976}}], 
  Line[{{1.361356816555577, 1.1519173063162573}, {1.361356816555577, \
1.2566370614359172}, {1.4660765716752366, 1.2566370614359172}, 
    {1.4660765716752366, 1.1519173063162573}, {1.361356816555577, \
1.1519173063162573}}], 
  Line[{{1.361356816555577, 1.2566370614359172}, {1.361356816555577, \
1.361356816555577}, {1.4660765716752366, 1.361356816555577}, 
    {1.4660765716752366, 1.2566370614359172}, {1.361356816555577, \
1.2566370614359172}}], 
  Line[{{1.361356816555577, 1.361356816555577}, {1.361356816555577, \
1.4660765716752366}, {1.4660765716752366, 1.4660765716752366}, 
    {1.4660765716752366, 1.361356816555577}, {1.361356816555577, \
1.361356816555577}}], 
  Line[{{1.361356816555577, 1.4660765716752366}, {1.361356816555577, \
1.5707963267948966}, {1.4660765716752366, 1.5707963267948966}, 
    {1.4660765716752366, 1.4660765716752366}, {1.361356816555577, \
1.4660765716752366}}], 
  Line[{{1.361356816555577, 1.5707963267948966}, {1.361356816555577, \
1.6755160819145563}, {1.4660765716752366, 1.6755160819145563}, 
    {1.4660765716752366, 1.5707963267948966}, {1.361356816555577, \
1.5707963267948966}}], 
  Line[{{1.361356816555577, 1.6755160819145563}, {1.361356816555577, \
1.780235837034216}, {1.4660765716752366, 1.780235837034216}, 
    {1.4660765716752366, 1.6755160819145563}, {1.361356816555577, \
1.6755160819145563}}], 
  Line[{{1.361356816555577, 1.780235837034216}, {1.361356816555577, \
1.8849555921538759}, {1.4660765716752366, 1.8849555921538759}, 
    {1.4660765716752366, 1.780235837034216}, {1.361356816555577, \
1.780235837034216}}], 
  Line[{{1.361356816555577, 1.8849555921538759}, {1.361356816555577, \
1.9896753472735356}, {1.4660765716752366, 1.9896753472735356}, 
    {1.4660765716752366, 1.8849555921538759}, {1.361356816555577, \
1.8849555921538759}}], 
  Line[{{1.361356816555577, 1.9896753472735356}, {1.361356816555577, \
2.0943951023931953}, {1.4660765716752366, 2.0943951023931953}, 
    {1.4660765716752366, 1.9896753472735356}, {1.361356816555577, \
1.9896753472735356}}], 
  Line[{{1.361356816555577, 2.0943951023931953}, {1.361356816555577, \
2.199114857512855}, {1.4660765716752366, 2.199114857512855}, 
    {1.4660765716752366, 2.0943951023931953}, {1.361356816555577, \
2.0943951023931953}}], 
  Line[{{1.361356816555577, 2.199114857512855}, {1.361356816555577, \
2.3038346126325147}, {1.4660765716752366, 2.3038346126325147}, 
    {1.4660765716752366, 2.199114857512855}, {1.361356816555577, \
2.199114857512855}}], 
  Line[{{1.361356816555577, 2.3038346126325147}, {1.361356816555577, \
2.4085543677521746}, {1.4660765716752366, 2.4085543677521746}, 
    {1.4660765716752366, 2.3038346126325147}, {1.361356816555577, \
2.3038346126325147}}], 
  Line[{{1.361356816555577, 2.4085543677521746}, {1.361356816555577, \
2.5132741228718345}, {1.4660765716752366, 2.5132741228718345}, 
    {1.4660765716752366, 2.4085543677521746}, {1.361356816555577, \
2.4085543677521746}}], 
  Line[{{1.361356816555577, 2.5132741228718345}, {1.361356816555577, \
2.617993877991494}, {1.4660765716752366, 2.617993877991494}, 
    {1.4660765716752366, 2.5132741228718345}, {1.361356816555577, \
2.5132741228718345}}], 
  Line[{{1.361356816555577, 2.617993877991494}, {1.361356816555577, \
2.722713633111154}, {1.4660765716752366, 2.722713633111154}, 
    {1.4660765716752366, 2.617993877991494}, {1.361356816555577, \
2.617993877991494}}], 
  Line[{{1.361356816555577, 2.722713633111154}, {1.361356816555577, \
2.827433388230814}, {1.4660765716752366, 2.827433388230814}, 
    {1.4660765716752366, 2.722713633111154}, {1.361356816555577, \
2.722713633111154}}], 
  Line[{{1.361356816555577, 2.827433388230814}, {1.361356816555577, \
2.9321531433504733}, {1.4660765716752366, 2.9321531433504733}, 
    {1.4660765716752366, 2.827433388230814}, {1.361356816555577, \
2.827433388230814}}], 
  Line[{{1.361356816555577, 2.9321531433504733}, {1.361356816555577, \
3.036872898470133}, {1.4660765716752366, 3.036872898470133}, 
    {1.4660765716752366, 2.9321531433504733}, {1.361356816555577, \
2.9321531433504733}}], 
  Line[{{1.361356816555577, 3.036872898470133}, {1.361356816555577, \
3.141592653589793}, {1.4660765716752366, 3.141592653589793}, 
    {1.4660765716752366, 3.036872898470133}, {1.361356816555577, \
3.036872898470133}}], 
  Line[{{1.361356816555577, 3.141592653589793}, {1.361356816555577, \
3.2463124087094526}, {1.4660765716752366, 3.2463124087094526}, 
    {1.4660765716752366, 3.141592653589793}, {1.361356816555577, \
3.141592653589793}}], 
  Line[{{1.361356816555577, 3.2463124087094526}, {1.361356816555577, \
3.3510321638291125}, {1.4660765716752366, 3.3510321638291125}, 
    {1.4660765716752366, 3.2463124087094526}, {1.361356816555577, \
3.2463124087094526}}], 
  Line[{{1.361356816555577, 3.3510321638291125}, {1.361356816555577, \
3.4557519189487724}, {1.4660765716752366, 3.4557519189487724}, 
    {1.4660765716752366, 3.3510321638291125}, {1.361356816555577, \
3.3510321638291125}}], 
  Line[{{1.361356816555577, 3.4557519189487724}, {1.361356816555577, \
3.560471674068432}, {1.4660765716752366, 3.560471674068432}, 
    {1.4660765716752366, 3.4557519189487724}, {1.361356816555577, \
3.4557519189487724}}], 
  Line[{{1.361356816555577, 3.560471674068432}, {1.361356816555577, \
3.665191429188092}, {1.4660765716752366, 3.665191429188092}, 
    {1.4660765716752366, 3.560471674068432}, {1.361356816555577, \
3.560471674068432}}], 
  Line[{{1.361356816555577, 3.665191429188092}, {1.361356816555577, \
3.7699111843077517}, {1.4660765716752366, 3.7699111843077517}, 
    {1.4660765716752366, 3.665191429188092}, {1.361356816555577, \
3.665191429188092}}], 
  Line[{{1.361356816555577, 3.7699111843077517}, {1.361356816555577, \
3.874630939427411}, {1.4660765716752366, 3.874630939427411}, 
    {1.4660765716752366, 3.7699111843077517}, {1.361356816555577, \
3.7699111843077517}}], 
  Line[{{1.361356816555577, 3.874630939427411}, {1.361356816555577, \
3.979350694547071}, {1.4660765716752366, 3.979350694547071}, 
    {1.4660765716752366, 3.874630939427411}, {1.361356816555577, \
3.874630939427411}}], 
  Line[{{1.361356816555577, 3.979350694547071}, {1.361356816555577, \
4.084070449666731}, {1.4660765716752366, 4.084070449666731}, 
    {1.4660765716752366, 3.979350694547071}, {1.361356816555577, \
3.979350694547071}}], 
  Line[{{1.361356816555577, 4.084070449666731}, {1.361356816555577, \
4.1887902047863905}, {1.4660765716752366, 4.1887902047863905}, 
    {1.4660765716752366, 4.084070449666731}, {1.361356816555577, \
4.084070449666731}}], 
  Line[{{1.361356816555577, 4.1887902047863905}, {1.361356816555577, \
4.29350995990605}, {1.4660765716752366, 4.29350995990605}, 
    {1.4660765716752366, 4.1887902047863905}, {1.361356816555577, \
4.1887902047863905}}], 
  Line[{{1.361356816555577, 4.29350995990605}, {1.361356816555577, \
4.39822971502571}, {1.4660765716752366, 4.39822971502571}, 
    {1.4660765716752366, 4.29350995990605}, {1.361356816555577, \
4.29350995990605}}], 
  Line[{{1.361356816555577, 4.39822971502571}, {1.361356816555577, \
4.50294947014537}, {1.4660765716752366, 4.50294947014537}, 
    {1.4660765716752366, 4.39822971502571}, {1.361356816555577, \
4.39822971502571}}], 
  Line[{{1.361356816555577, 4.50294947014537}, {1.361356816555577, \
4.607669225265029}, {1.4660765716752366, 4.607669225265029}, 
    {1.4660765716752366, 4.50294947014537}, {1.361356816555577, \
4.50294947014537}}], 
  Line[{{1.361356816555577, 4.607669225265029}, {1.361356816555577, \
4.71238898038469}, {1.4660765716752366, 4.71238898038469}, 
    {1.4660765716752366, 4.607669225265029}, {1.361356816555577, \
4.607669225265029}}], 
  Line[{{1.361356816555577, 4.71238898038469}, {1.361356816555577, \
4.817108735504349}, {1.4660765716752366, 4.817108735504349}, 
    {1.4660765716752366, 4.71238898038469}, {1.361356816555577, \
4.71238898038469}}], 
  Line[{{1.361356816555577, 4.817108735504349}, {1.361356816555577, \
4.921828490624009}, {1.4660765716752366, 4.921828490624009}, 
    {1.4660765716752366, 4.817108735504349}, {1.361356816555577, \
4.817108735504349}}], 
  Line[{{1.361356816555577, 4.921828490624009}, {1.361356816555577, \
5.026548245743669}, {1.4660765716752366, 5.026548245743669}, 
    {1.4660765716752366, 4.921828490624009}, {1.361356816555577, \
4.921828490624009}}], 
  Line[{{1.361356816555577, 5.026548245743669}, {1.361356816555577, \
5.1312680008633285}, {1.4660765716752366, 5.1312680008633285}, 
    {1.4660765716752366, 5.026548245743669}, {1.361356816555577, \
5.026548245743669}}], 
  Line[{{1.361356816555577, 5.1312680008633285}, {1.361356816555577, \
5.235987755982988}, {1.4660765716752366, 5.235987755982988}, 
    {1.4660765716752366, 5.1312680008633285}, {1.361356816555577, \
5.1312680008633285}}], 
  Line[{{1.361356816555577, 5.235987755982988}, {1.361356816555577, \
5.340707511102648}, {1.4660765716752366, 5.340707511102648}, 
    {1.4660765716752366, 5.235987755982988}, {1.361356816555577, \
5.235987755982988}}], 
  Line[{{1.361356816555577, 5.340707511102648}, {1.361356816555577, \
5.445427266222308}, {1.4660765716752366, 5.445427266222308}, 
    {1.4660765716752366, 5.340707511102648}, {1.361356816555577, \
5.340707511102648}}], 
  Line[{{1.361356816555577, 5.445427266222308}, {1.361356816555577, \
5.550147021341967}, {1.4660765716752366, 5.550147021341967}, 
    {1.4660765716752366, 5.445427266222308}, {1.361356816555577, \
5.445427266222308}}], 
  Line[{{1.361356816555577, 5.550147021341967}, {1.361356816555577, \
5.654866776461628}, {1.4660765716752366, 5.654866776461628}, 
    {1.4660765716752366, 5.550147021341967}, {1.361356816555577, \
5.550147021341967}}], 
  Line[{{1.361356816555577, 5.654866776461628}, {1.361356816555577, \
5.759586531581287}, {1.4660765716752366, 5.759586531581287}, 
    {1.4660765716752366, 5.654866776461628}, {1.361356816555577, \
5.654866776461628}}], 
  Line[{{1.361356816555577, 5.759586531581287}, {1.361356816555577, \
5.864306286700947}, {1.4660765716752366, 5.864306286700947}, 
    {1.4660765716752366, 5.759586531581287}, {1.361356816555577, \
5.759586531581287}}], 
  Line[{{1.361356816555577, 5.864306286700947}, {1.361356816555577, \
5.969026041820607}, {1.4660765716752366, 5.969026041820607}, 
    {1.4660765716752366, 5.864306286700947}, {1.361356816555577, \
5.864306286700947}}], 
  Line[{{1.361356816555577, 5.969026041820607}, {1.361356816555577, \
6.073745796940266}, {1.4660765716752366, 6.073745796940266}, 
    {1.4660765716752366, 5.969026041820607}, {1.361356816555577, \
5.969026041820607}}], 
  Line[{{1.361356816555577, 6.073745796940266}, {1.361356816555577, \
6.178465552059926}, {1.4660765716752366, 6.178465552059926}, 
    {1.4660765716752366, 6.073745796940266}, {1.361356816555577, \
6.073745796940266}}], 
  Line[{{1.361356816555577, 6.178465552059926}, {1.361356816555577, \
6.283185307179586}, {1.4660765716752366, 6.283185307179586}, 
    {1.4660765716752366, 6.178465552059926}, {1.361356816555577, \
6.178465552059926}}], 
  Line[{{1.4660765716752366, 0.}, {1.4660765716752366, 0.10471975511965977}, \
{1.5707963267948966, 0.10471975511965977}, {1.5707963267948966, 0.}, 
    {1.4660765716752366, 0.}}], Line[{{1.4660765716752366, \
0.10471975511965977}, {1.4660765716752366, 0.20943951023931953}, 
    {1.5707963267948966, 0.20943951023931953}, {1.5707963267948966, \
0.10471975511965977}, {1.4660765716752366, 0.10471975511965977}}], 
  Line[{{1.4660765716752366, 0.20943951023931953}, {1.4660765716752366, \
0.3141592653589793}, {1.5707963267948966, 0.3141592653589793}, 
    {1.5707963267948966, 0.20943951023931953}, {1.4660765716752366, \
0.20943951023931953}}], 
  Line[{{1.4660765716752366, 0.3141592653589793}, {1.4660765716752366, \
0.41887902047863906}, {1.5707963267948966, 0.41887902047863906}, 
    {1.5707963267948966, 0.3141592653589793}, {1.4660765716752366, \
0.3141592653589793}}], 
  Line[{{1.4660765716752366, 0.41887902047863906}, {1.4660765716752366, \
0.5235987755982988}, {1.5707963267948966, 0.5235987755982988}, 
    {1.5707963267948966, 0.41887902047863906}, {1.4660765716752366, \
0.41887902047863906}}], 
  Line[{{1.4660765716752366, 0.5235987755982988}, {1.4660765716752366, \
0.6283185307179586}, {1.5707963267948966, 0.6283185307179586}, 
    {1.5707963267948966, 0.5235987755982988}, {1.4660765716752366, \
0.5235987755982988}}], 
  Line[{{1.4660765716752366, 0.6283185307179586}, {1.4660765716752366, \
0.7330382858376183}, {1.5707963267948966, 0.7330382858376183}, 
    {1.5707963267948966, 0.6283185307179586}, {1.4660765716752366, \
0.6283185307179586}}], 
  Line[{{1.4660765716752366, 0.7330382858376183}, {1.4660765716752366, \
0.8377580409572781}, {1.5707963267948966, 0.8377580409572781}, 
    {1.5707963267948966, 0.7330382858376183}, {1.4660765716752366, \
0.7330382858376183}}], 
  Line[{{1.4660765716752366, 0.8377580409572781}, {1.4660765716752366, \
0.9424777960769379}, {1.5707963267948966, 0.9424777960769379}, 
    {1.5707963267948966, 0.8377580409572781}, {1.4660765716752366, \
0.8377580409572781}}], 
  Line[{{1.4660765716752366, 0.9424777960769379}, {1.4660765716752366, \
1.0471975511965976}, {1.5707963267948966, 1.0471975511965976}, 
    {1.5707963267948966, 0.9424777960769379}, {1.4660765716752366, \
0.9424777960769379}}], 
  Line[{{1.4660765716752366, 1.0471975511965976}, {1.4660765716752366, \
1.1519173063162573}, {1.5707963267948966, 1.1519173063162573}, 
    {1.5707963267948966, 1.0471975511965976}, {1.4660765716752366, \
1.0471975511965976}}], 
  Line[{{1.4660765716752366, 1.1519173063162573}, {1.4660765716752366, \
1.2566370614359172}, {1.5707963267948966, 1.2566370614359172}, 
    {1.5707963267948966, 1.1519173063162573}, {1.4660765716752366, \
1.1519173063162573}}], 
  Line[{{1.4660765716752366, 1.2566370614359172}, {1.4660765716752366, \
1.361356816555577}, {1.5707963267948966, 1.361356816555577}, 
    {1.5707963267948966, 1.2566370614359172}, {1.4660765716752366, \
1.2566370614359172}}], 
  Line[{{1.4660765716752366, 1.361356816555577}, {1.4660765716752366, \
1.4660765716752366}, {1.5707963267948966, 1.4660765716752366}, 
    {1.5707963267948966, 1.361356816555577}, {1.4660765716752366, \
1.361356816555577}}], 
  Line[{{1.4660765716752366, 1.4660765716752366}, {1.4660765716752366, \
1.5707963267948966}, {1.5707963267948966, 1.5707963267948966}, 
    {1.5707963267948966, 1.4660765716752366}, {1.4660765716752366, \
1.4660765716752366}}], 
  Line[{{1.4660765716752366, 1.5707963267948966}, {1.4660765716752366, \
1.6755160819145563}, {1.5707963267948966, 1.6755160819145563}, 
    {1.5707963267948966, 1.5707963267948966}, {1.4660765716752366, \
1.5707963267948966}}], 
  Line[{{1.4660765716752366, 1.6755160819145563}, {1.4660765716752366, \
1.780235837034216}, {1.5707963267948966, 1.780235837034216}, 
    {1.5707963267948966, 1.6755160819145563}, {1.4660765716752366, \
1.6755160819145563}}], 
  Line[{{1.4660765716752366, 1.780235837034216}, {1.4660765716752366, \
1.8849555921538759}, {1.5707963267948966, 1.8849555921538759}, 
    {1.5707963267948966, 1.780235837034216}, {1.4660765716752366, \
1.780235837034216}}], 
  Line[{{1.4660765716752366, 1.8849555921538759}, {1.4660765716752366, \
1.9896753472735356}, {1.5707963267948966, 1.9896753472735356}, 
    {1.5707963267948966, 1.8849555921538759}, {1.4660765716752366, \
1.8849555921538759}}], 
  Line[{{1.4660765716752366, 1.9896753472735356}, {1.4660765716752366, \
2.0943951023931953}, {1.5707963267948966, 2.0943951023931953}, 
    {1.5707963267948966, 1.9896753472735356}, {1.4660765716752366, \
1.9896753472735356}}], 
  Line[{{1.4660765716752366, 2.0943951023931953}, {1.4660765716752366, \
2.199114857512855}, {1.5707963267948966, 2.199114857512855}, 
    {1.5707963267948966, 2.0943951023931953}, {1.4660765716752366, \
2.0943951023931953}}], 
  Line[{{1.4660765716752366, 2.199114857512855}, {1.4660765716752366, \
2.3038346126325147}, {1.5707963267948966, 2.3038346126325147}, 
    {1.5707963267948966, 2.199114857512855}, {1.4660765716752366, \
2.199114857512855}}], 
  Line[{{1.4660765716752366, 2.3038346126325147}, {1.4660765716752366, \
2.4085543677521746}, {1.5707963267948966, 2.4085543677521746}, 
    {1.5707963267948966, 2.3038346126325147}, {1.4660765716752366, \
2.3038346126325147}}], 
  Line[{{1.4660765716752366, 2.4085543677521746}, {1.4660765716752366, \
2.5132741228718345}, {1.5707963267948966, 2.5132741228718345}, 
    {1.5707963267948966, 2.4085543677521746}, {1.4660765716752366, \
2.4085543677521746}}], 
  Line[{{1.4660765716752366, 2.5132741228718345}, {1.4660765716752366, \
2.617993877991494}, {1.5707963267948966, 2.617993877991494}, 
    {1.5707963267948966, 2.5132741228718345}, {1.4660765716752366, \
2.5132741228718345}}], 
  Line[{{1.4660765716752366, 2.617993877991494}, {1.4660765716752366, \
2.722713633111154}, {1.5707963267948966, 2.722713633111154}, 
    {1.5707963267948966, 2.617993877991494}, {1.4660765716752366, \
2.617993877991494}}], 
  Line[{{1.4660765716752366, 2.722713633111154}, {1.4660765716752366, \
2.827433388230814}, {1.5707963267948966, 2.827433388230814}, 
    {1.5707963267948966, 2.722713633111154}, {1.4660765716752366, \
2.722713633111154}}], 
  Line[{{1.4660765716752366, 2.827433388230814}, {1.4660765716752366, \
2.9321531433504733}, {1.5707963267948966, 2.9321531433504733}, 
    {1.5707963267948966, 2.827433388230814}, {1.4660765716752366, \
2.827433388230814}}], 
  Line[{{1.4660765716752366, 2.9321531433504733}, {1.4660765716752366, \
3.036872898470133}, {1.5707963267948966, 3.036872898470133}, 
    {1.5707963267948966, 2.9321531433504733}, {1.4660765716752366, \
2.9321531433504733}}], 
  Line[{{1.4660765716752366, 3.036872898470133}, {1.4660765716752366, \
3.141592653589793}, {1.5707963267948966, 3.141592653589793}, 
    {1.5707963267948966, 3.036872898470133}, {1.4660765716752366, \
3.036872898470133}}], 
  Line[{{1.4660765716752366, 3.141592653589793}, {1.4660765716752366, \
3.2463124087094526}, {1.5707963267948966, 3.2463124087094526}, 
    {1.5707963267948966, 3.141592653589793}, {1.4660765716752366, \
3.141592653589793}}], 
  Line[{{1.4660765716752366, 3.2463124087094526}, {1.4660765716752366, \
3.3510321638291125}, {1.5707963267948966, 3.3510321638291125}, 
    {1.5707963267948966, 3.2463124087094526}, {1.4660765716752366, \
3.2463124087094526}}], 
  Line[{{1.4660765716752366, 3.3510321638291125}, {1.4660765716752366, \
3.4557519189487724}, {1.5707963267948966, 3.4557519189487724}, 
    {1.5707963267948966, 3.3510321638291125}, {1.4660765716752366, \
3.3510321638291125}}], 
  Line[{{1.4660765716752366, 3.4557519189487724}, {1.4660765716752366, \
3.560471674068432}, {1.5707963267948966, 3.560471674068432}, 
    {1.5707963267948966, 3.4557519189487724}, {1.4660765716752366, \
3.4557519189487724}}], 
  Line[{{1.4660765716752366, 3.560471674068432}, {1.4660765716752366, \
3.665191429188092}, {1.5707963267948966, 3.665191429188092}, 
    {1.5707963267948966, 3.560471674068432}, {1.4660765716752366, \
3.560471674068432}}], 
  Line[{{1.4660765716752366, 3.665191429188092}, {1.4660765716752366, \
3.7699111843077517}, {1.5707963267948966, 3.7699111843077517}, 
    {1.5707963267948966, 3.665191429188092}, {1.4660765716752366, \
3.665191429188092}}], 
  Line[{{1.4660765716752366, 3.7699111843077517}, {1.4660765716752366, \
3.874630939427411}, {1.5707963267948966, 3.874630939427411}, 
    {1.5707963267948966, 3.7699111843077517}, {1.4660765716752366, \
3.7699111843077517}}], 
  Line[{{1.4660765716752366, 3.874630939427411}, {1.4660765716752366, \
3.979350694547071}, {1.5707963267948966, 3.979350694547071}, 
    {1.5707963267948966, 3.874630939427411}, {1.4660765716752366, \
3.874630939427411}}], 
  Line[{{1.4660765716752366, 3.979350694547071}, {1.4660765716752366, \
4.084070449666731}, {1.5707963267948966, 4.084070449666731}, 
    {1.5707963267948966, 3.979350694547071}, {1.4660765716752366, \
3.979350694547071}}], 
  Line[{{1.4660765716752366, 4.084070449666731}, {1.4660765716752366, \
4.1887902047863905}, {1.5707963267948966, 4.1887902047863905}, 
    {1.5707963267948966, 4.084070449666731}, {1.4660765716752366, \
4.084070449666731}}], 
  Line[{{1.4660765716752366, 4.1887902047863905}, {1.4660765716752366, \
4.29350995990605}, {1.5707963267948966, 4.29350995990605}, 
    {1.5707963267948966, 4.1887902047863905}, {1.4660765716752366, \
4.1887902047863905}}], 
  Line[{{1.4660765716752366, 4.29350995990605}, {1.4660765716752366, \
4.39822971502571}, {1.5707963267948966, 4.39822971502571}, 
    {1.5707963267948966, 4.29350995990605}, {1.4660765716752366, \
4.29350995990605}}], 
  Line[{{1.4660765716752366, 4.39822971502571}, {1.4660765716752366, \
4.50294947014537}, {1.5707963267948966, 4.50294947014537}, 
    {1.5707963267948966, 4.39822971502571}, {1.4660765716752366, \
4.39822971502571}}], 
  Line[{{1.4660765716752366, 4.50294947014537}, {1.4660765716752366, \
4.607669225265029}, {1.5707963267948966, 4.607669225265029}, 
    {1.5707963267948966, 4.50294947014537}, {1.4660765716752366, \
4.50294947014537}}], 
  Line[{{1.4660765716752366, 4.607669225265029}, {1.4660765716752366, \
4.71238898038469}, {1.5707963267948966, 4.71238898038469}, 
    {1.5707963267948966, 4.607669225265029}, {1.4660765716752366, \
4.607669225265029}}], 
  Line[{{1.4660765716752366, 4.71238898038469}, {1.4660765716752366, \
4.817108735504349}, {1.5707963267948966, 4.817108735504349}, 
    {1.5707963267948966, 4.71238898038469}, {1.4660765716752366, \
4.71238898038469}}], 
  Line[{{1.4660765716752366, 4.817108735504349}, {1.4660765716752366, \
4.921828490624009}, {1.5707963267948966, 4.921828490624009}, 
    {1.5707963267948966, 4.817108735504349}, {1.4660765716752366, \
4.817108735504349}}], 
  Line[{{1.4660765716752366, 4.921828490624009}, {1.4660765716752366, \
5.026548245743669}, {1.5707963267948966, 5.026548245743669}, 
    {1.5707963267948966, 4.921828490624009}, {1.4660765716752366, \
4.921828490624009}}], 
  Line[{{1.4660765716752366, 5.026548245743669}, {1.4660765716752366, \
5.1312680008633285}, {1.5707963267948966, 5.1312680008633285}, 
    {1.5707963267948966, 5.026548245743669}, {1.4660765716752366, \
5.026548245743669}}], 
  Line[{{1.4660765716752366, 5.1312680008633285}, {1.4660765716752366, \
5.235987755982988}, {1.5707963267948966, 5.235987755982988}, 
    {1.5707963267948966, 5.1312680008633285}, {1.4660765716752366, \
5.1312680008633285}}], 
  Line[{{1.4660765716752366, 5.235987755982988}, {1.4660765716752366, \
5.340707511102648}, {1.5707963267948966, 5.340707511102648}, 
    {1.5707963267948966, 5.235987755982988}, {1.4660765716752366, \
5.235987755982988}}], 
  Line[{{1.4660765716752366, 5.340707511102648}, {1.4660765716752366, \
5.445427266222308}, {1.5707963267948966, 5.445427266222308}, 
    {1.5707963267948966, 5.340707511102648}, {1.4660765716752366, \
5.340707511102648}}], 
  Line[{{1.4660765716752366, 5.445427266222308}, {1.4660765716752366, \
5.550147021341967}, {1.5707963267948966, 5.550147021341967}, 
    {1.5707963267948966, 5.445427266222308}, {1.4660765716752366, \
5.445427266222308}}], 
  Line[{{1.4660765716752366, 5.550147021341967}, {1.4660765716752366, \
5.654866776461628}, {1.5707963267948966, 5.654866776461628}, 
    {1.5707963267948966, 5.550147021341967}, {1.4660765716752366, \
5.550147021341967}}], 
  Line[{{1.4660765716752366, 5.654866776461628}, {1.4660765716752366, \
5.759586531581287}, {1.5707963267948966, 5.759586531581287}, 
    {1.5707963267948966, 5.654866776461628}, {1.4660765716752366, \
5.654866776461628}}], 
  Line[{{1.4660765716752366, 5.759586531581287}, {1.4660765716752366, \
5.864306286700947}, {1.5707963267948966, 5.864306286700947}, 
    {1.5707963267948966, 5.759586531581287}, {1.4660765716752366, \
5.759586531581287}}], 
  Line[{{1.4660765716752366, 5.864306286700947}, {1.4660765716752366, \
5.969026041820607}, {1.5707963267948966, 5.969026041820607}, 
    {1.5707963267948966, 5.864306286700947}, {1.4660765716752366, \
5.864306286700947}}], 
  Line[{{1.4660765716752366, 5.969026041820607}, {1.4660765716752366, \
6.073745796940266}, {1.5707963267948966, 6.073745796940266}, 
    {1.5707963267948966, 5.969026041820607}, {1.4660765716752366, \
5.969026041820607}}], 
  Line[{{1.4660765716752366, 6.073745796940266}, {1.4660765716752366, \
6.178465552059926}, {1.5707963267948966, 6.178465552059926}, 
    {1.5707963267948966, 6.073745796940266}, {1.4660765716752366, \
6.073745796940266}}], 
  Line[{{1.4660765716752366, 6.178465552059926}, {1.4660765716752366, \
6.283185307179586}, {1.5707963267948966, 6.283185307179586}, 
    {1.5707963267948966, 6.178465552059926}, {1.4660765716752366, \
6.178465552059926}}], 
  Line[{{1.5707963267948966, 0.}, {1.5707963267948966, 0.10471975511965977}, \
{1.6755160819145563, 0.10471975511965977}, {1.6755160819145563, 0.}, 
    {1.5707963267948966, 0.}}], Line[{{1.5707963267948966, \
0.10471975511965977}, {1.5707963267948966, 0.20943951023931953}, 
    {1.6755160819145563, 0.20943951023931953}, {1.6755160819145563, \
0.10471975511965977}, {1.5707963267948966, 0.10471975511965977}}], 
  Line[{{1.5707963267948966, 0.20943951023931953}, {1.5707963267948966, \
0.3141592653589793}, {1.6755160819145563, 0.3141592653589793}, 
    {1.6755160819145563, 0.20943951023931953}, {1.5707963267948966, \
0.20943951023931953}}], 
  Line[{{1.5707963267948966, 0.3141592653589793}, {1.5707963267948966, \
0.41887902047863906}, {1.6755160819145563, 0.41887902047863906}, 
    {1.6755160819145563, 0.3141592653589793}, {1.5707963267948966, \
0.3141592653589793}}], 
  Line[{{1.5707963267948966, 0.41887902047863906}, {1.5707963267948966, \
0.5235987755982988}, {1.6755160819145563, 0.5235987755982988}, 
    {1.6755160819145563, 0.41887902047863906}, {1.5707963267948966, \
0.41887902047863906}}], 
  Line[{{1.5707963267948966, 0.5235987755982988}, {1.5707963267948966, \
0.6283185307179586}, {1.6755160819145563, 0.6283185307179586}, 
    {1.6755160819145563, 0.5235987755982988}, {1.5707963267948966, \
0.5235987755982988}}], 
  Line[{{1.5707963267948966, 0.6283185307179586}, {1.5707963267948966, \
0.7330382858376183}, {1.6755160819145563, 0.7330382858376183}, 
    {1.6755160819145563, 0.6283185307179586}, {1.5707963267948966, \
0.6283185307179586}}], 
  Line[{{1.5707963267948966, 0.7330382858376183}, {1.5707963267948966, \
0.8377580409572781}, {1.6755160819145563, 0.8377580409572781}, 
    {1.6755160819145563, 0.7330382858376183}, {1.5707963267948966, \
0.7330382858376183}}], 
  Line[{{1.5707963267948966, 0.8377580409572781}, {1.5707963267948966, \
0.9424777960769379}, {1.6755160819145563, 0.9424777960769379}, 
    {1.6755160819145563, 0.8377580409572781}, {1.5707963267948966, \
0.8377580409572781}}], 
  Line[{{1.5707963267948966, 0.9424777960769379}, {1.5707963267948966, \
1.0471975511965976}, {1.6755160819145563, 1.0471975511965976}, 
    {1.6755160819145563, 0.9424777960769379}, {1.5707963267948966, \
0.9424777960769379}}], 
  Line[{{1.5707963267948966, 1.0471975511965976}, {1.5707963267948966, \
1.1519173063162573}, {1.6755160819145563, 1.1519173063162573}, 
    {1.6755160819145563, 1.0471975511965976}, {1.5707963267948966, \
1.0471975511965976}}], 
  Line[{{1.5707963267948966, 1.1519173063162573}, {1.5707963267948966, \
1.2566370614359172}, {1.6755160819145563, 1.2566370614359172}, 
    {1.6755160819145563, 1.1519173063162573}, {1.5707963267948966, \
1.1519173063162573}}], 
  Line[{{1.5707963267948966, 1.2566370614359172}, {1.5707963267948966, \
1.361356816555577}, {1.6755160819145563, 1.361356816555577}, 
    {1.6755160819145563, 1.2566370614359172}, {1.5707963267948966, \
1.2566370614359172}}], 
  Line[{{1.5707963267948966, 1.361356816555577}, {1.5707963267948966, \
1.4660765716752366}, {1.6755160819145563, 1.4660765716752366}, 
    {1.6755160819145563, 1.361356816555577}, {1.5707963267948966, \
1.361356816555577}}], 
  Line[{{1.5707963267948966, 1.4660765716752366}, {1.5707963267948966, \
1.5707963267948966}, {1.6755160819145563, 1.5707963267948966}, 
    {1.6755160819145563, 1.4660765716752366}, {1.5707963267948966, \
1.4660765716752366}}], 
  Line[{{1.5707963267948966, 1.5707963267948966}, {1.5707963267948966, \
1.6755160819145563}, {1.6755160819145563, 1.6755160819145563}, 
    {1.6755160819145563, 1.5707963267948966}, {1.5707963267948966, \
1.5707963267948966}}], 
  Line[{{1.5707963267948966, 1.6755160819145563}, {1.5707963267948966, \
1.780235837034216}, {1.6755160819145563, 1.780235837034216}, 
    {1.6755160819145563, 1.6755160819145563}, {1.5707963267948966, \
1.6755160819145563}}], 
  Line[{{1.5707963267948966, 1.780235837034216}, {1.5707963267948966, \
1.8849555921538759}, {1.6755160819145563, 1.8849555921538759}, 
    {1.6755160819145563, 1.780235837034216}, {1.5707963267948966, \
1.780235837034216}}], 
  Line[{{1.5707963267948966, 1.8849555921538759}, {1.5707963267948966, \
1.9896753472735356}, {1.6755160819145563, 1.9896753472735356}, 
    {1.6755160819145563, 1.8849555921538759}, {1.5707963267948966, \
1.8849555921538759}}], 
  Line[{{1.5707963267948966, 1.9896753472735356}, {1.5707963267948966, \
2.0943951023931953}, {1.6755160819145563, 2.0943951023931953}, 
    {1.6755160819145563, 1.9896753472735356}, {1.5707963267948966, \
1.9896753472735356}}], 
  Line[{{1.5707963267948966, 2.0943951023931953}, {1.5707963267948966, \
2.199114857512855}, {1.6755160819145563, 2.199114857512855}, 
    {1.6755160819145563, 2.0943951023931953}, {1.5707963267948966, \
2.0943951023931953}}], 
  Line[{{1.5707963267948966, 2.199114857512855}, {1.5707963267948966, \
2.3038346126325147}, {1.6755160819145563, 2.3038346126325147}, 
    {1.6755160819145563, 2.199114857512855}, {1.5707963267948966, \
2.199114857512855}}], 
  Line[{{1.5707963267948966, 2.3038346126325147}, {1.5707963267948966, \
2.4085543677521746}, {1.6755160819145563, 2.4085543677521746}, 
    {1.6755160819145563, 2.3038346126325147}, {1.5707963267948966, \
2.3038346126325147}}], 
  Line[{{1.5707963267948966, 2.4085543677521746}, {1.5707963267948966, \
2.5132741228718345}, {1.6755160819145563, 2.5132741228718345}, 
    {1.6755160819145563, 2.4085543677521746}, {1.5707963267948966, \
2.4085543677521746}}], 
  Line[{{1.5707963267948966, 2.5132741228718345}, {1.5707963267948966, \
2.617993877991494}, {1.6755160819145563, 2.617993877991494}, 
    {1.6755160819145563, 2.5132741228718345}, {1.5707963267948966, \
2.5132741228718345}}], 
  Line[{{1.5707963267948966, 2.617993877991494}, {1.5707963267948966, \
2.722713633111154}, {1.6755160819145563, 2.722713633111154}, 
    {1.6755160819145563, 2.617993877991494}, {1.5707963267948966, \
2.617993877991494}}], 
  Line[{{1.5707963267948966, 2.722713633111154}, {1.5707963267948966, \
2.827433388230814}, {1.6755160819145563, 2.827433388230814}, 
    {1.6755160819145563, 2.722713633111154}, {1.5707963267948966, \
2.722713633111154}}], 
  Line[{{1.5707963267948966, 2.827433388230814}, {1.5707963267948966, \
2.9321531433504733}, {1.6755160819145563, 2.9321531433504733}, 
    {1.6755160819145563, 2.827433388230814}, {1.5707963267948966, \
2.827433388230814}}], 
  Line[{{1.5707963267948966, 2.9321531433504733}, {1.5707963267948966, \
3.036872898470133}, {1.6755160819145563, 3.036872898470133}, 
    {1.6755160819145563, 2.9321531433504733}, {1.5707963267948966, \
2.9321531433504733}}], 
  Line[{{1.5707963267948966, 3.036872898470133}, {1.5707963267948966, \
3.141592653589793}, {1.6755160819145563, 3.141592653589793}, 
    {1.6755160819145563, 3.036872898470133}, {1.5707963267948966, \
3.036872898470133}}], 
  Line[{{1.5707963267948966, 3.141592653589793}, {1.5707963267948966, \
3.2463124087094526}, {1.6755160819145563, 3.2463124087094526}, 
    {1.6755160819145563, 3.141592653589793}, {1.5707963267948966, \
3.141592653589793}}], 
  Line[{{1.5707963267948966, 3.2463124087094526}, {1.5707963267948966, \
3.3510321638291125}, {1.6755160819145563, 3.3510321638291125}, 
    {1.6755160819145563, 3.2463124087094526}, {1.5707963267948966, \
3.2463124087094526}}], 
  Line[{{1.5707963267948966, 3.3510321638291125}, {1.5707963267948966, \
3.4557519189487724}, {1.6755160819145563, 3.4557519189487724}, 
    {1.6755160819145563, 3.3510321638291125}, {1.5707963267948966, \
3.3510321638291125}}], 
  Line[{{1.5707963267948966, 3.4557519189487724}, {1.5707963267948966, \
3.560471674068432}, {1.6755160819145563, 3.560471674068432}, 
    {1.6755160819145563, 3.4557519189487724}, {1.5707963267948966, \
3.4557519189487724}}], 
  Line[{{1.5707963267948966, 3.560471674068432}, {1.5707963267948966, \
3.665191429188092}, {1.6755160819145563, 3.665191429188092}, 
    {1.6755160819145563, 3.560471674068432}, {1.5707963267948966, \
3.560471674068432}}], 
  Line[{{1.5707963267948966, 3.665191429188092}, {1.5707963267948966, \
3.7699111843077517}, {1.6755160819145563, 3.7699111843077517}, 
    {1.6755160819145563, 3.665191429188092}, {1.5707963267948966, \
3.665191429188092}}], 
  Line[{{1.5707963267948966, 3.7699111843077517}, {1.5707963267948966, \
3.874630939427411}, {1.6755160819145563, 3.874630939427411}, 
    {1.6755160819145563, 3.7699111843077517}, {1.5707963267948966, \
3.7699111843077517}}], 
  Line[{{1.5707963267948966, 3.874630939427411}, {1.5707963267948966, \
3.979350694547071}, {1.6755160819145563, 3.979350694547071}, 
    {1.6755160819145563, 3.874630939427411}, {1.5707963267948966, \
3.874630939427411}}], 
  Line[{{1.5707963267948966, 3.979350694547071}, {1.5707963267948966, \
4.084070449666731}, {1.6755160819145563, 4.084070449666731}, 
    {1.6755160819145563, 3.979350694547071}, {1.5707963267948966, \
3.979350694547071}}], 
  Line[{{1.5707963267948966, 4.084070449666731}, {1.5707963267948966, \
4.1887902047863905}, {1.6755160819145563, 4.1887902047863905}, 
    {1.6755160819145563, 4.084070449666731}, {1.5707963267948966, \
4.084070449666731}}], 
  Line[{{1.5707963267948966, 4.1887902047863905}, {1.5707963267948966, \
4.29350995990605}, {1.6755160819145563, 4.29350995990605}, 
    {1.6755160819145563, 4.1887902047863905}, {1.5707963267948966, \
4.1887902047863905}}], 
  Line[{{1.5707963267948966, 4.29350995990605}, {1.5707963267948966, \
4.39822971502571}, {1.6755160819145563, 4.39822971502571}, 
    {1.6755160819145563, 4.29350995990605}, {1.5707963267948966, \
4.29350995990605}}], 
  Line[{{1.5707963267948966, 4.39822971502571}, {1.5707963267948966, \
4.50294947014537}, {1.6755160819145563, 4.50294947014537}, 
    {1.6755160819145563, 4.39822971502571}, {1.5707963267948966, \
4.39822971502571}}], 
  Line[{{1.5707963267948966, 4.50294947014537}, {1.5707963267948966, \
4.607669225265029}, {1.6755160819145563, 4.607669225265029}, 
    {1.6755160819145563, 4.50294947014537}, {1.5707963267948966, \
4.50294947014537}}], 
  Line[{{1.5707963267948966, 4.607669225265029}, {1.5707963267948966, \
4.71238898038469}, {1.6755160819145563, 4.71238898038469}, 
    {1.6755160819145563, 4.607669225265029}, {1.5707963267948966, \
4.607669225265029}}], 
  Line[{{1.5707963267948966, 4.71238898038469}, {1.5707963267948966, \
4.817108735504349}, {1.6755160819145563, 4.817108735504349}, 
    {1.6755160819145563, 4.71238898038469}, {1.5707963267948966, \
4.71238898038469}}], 
  Line[{{1.5707963267948966, 4.817108735504349}, {1.5707963267948966, \
4.921828490624009}, {1.6755160819145563, 4.921828490624009}, 
    {1.6755160819145563, 4.817108735504349}, {1.5707963267948966, \
4.817108735504349}}], 
  Line[{{1.5707963267948966, 4.921828490624009}, {1.5707963267948966, \
5.026548245743669}, {1.6755160819145563, 5.026548245743669}, 
    {1.6755160819145563, 4.921828490624009}, {1.5707963267948966, \
4.921828490624009}}], 
  Line[{{1.5707963267948966, 5.026548245743669}, {1.5707963267948966, \
5.1312680008633285}, {1.6755160819145563, 5.1312680008633285}, 
    {1.6755160819145563, 5.026548245743669}, {1.5707963267948966, \
5.026548245743669}}], 
  Line[{{1.5707963267948966, 5.1312680008633285}, {1.5707963267948966, \
5.235987755982988}, {1.6755160819145563, 5.235987755982988}, 
    {1.6755160819145563, 5.1312680008633285}, {1.5707963267948966, \
5.1312680008633285}}], 
  Line[{{1.5707963267948966, 5.235987755982988}, {1.5707963267948966, \
5.340707511102648}, {1.6755160819145563, 5.340707511102648}, 
    {1.6755160819145563, 5.235987755982988}, {1.5707963267948966, \
5.235987755982988}}], 
  Line[{{1.5707963267948966, 5.340707511102648}, {1.5707963267948966, \
5.445427266222308}, {1.6755160819145563, 5.445427266222308}, 
    {1.6755160819145563, 5.340707511102648}, {1.5707963267948966, \
5.340707511102648}}], 
  Line[{{1.5707963267948966, 5.445427266222308}, {1.5707963267948966, \
5.550147021341967}, {1.6755160819145563, 5.550147021341967}, 
    {1.6755160819145563, 5.445427266222308}, {1.5707963267948966, \
5.445427266222308}}], 
  Line[{{1.5707963267948966, 5.550147021341967}, {1.5707963267948966, \
5.654866776461628}, {1.6755160819145563, 5.654866776461628}, 
    {1.6755160819145563, 5.550147021341967}, {1.5707963267948966, \
5.550147021341967}}], 
  Line[{{1.5707963267948966, 5.654866776461628}, {1.5707963267948966, \
5.759586531581287}, {1.6755160819145563, 5.759586531581287}, 
    {1.6755160819145563, 5.654866776461628}, {1.5707963267948966, \
5.654866776461628}}], 
  Line[{{1.5707963267948966, 5.759586531581287}, {1.5707963267948966, \
5.864306286700947}, {1.6755160819145563, 5.864306286700947}, 
    {1.6755160819145563, 5.759586531581287}, {1.5707963267948966, \
5.759586531581287}}], 
  Line[{{1.5707963267948966, 5.864306286700947}, {1.5707963267948966, \
5.969026041820607}, {1.6755160819145563, 5.969026041820607}, 
    {1.6755160819145563, 5.864306286700947}, {1.5707963267948966, \
5.864306286700947}}], 
  Line[{{1.5707963267948966, 5.969026041820607}, {1.5707963267948966, \
6.073745796940266}, {1.6755160819145563, 6.073745796940266}, 
    {1.6755160819145563, 5.969026041820607}, {1.5707963267948966, \
5.969026041820607}}], 
  Line[{{1.5707963267948966, 6.073745796940266}, {1.5707963267948966, \
6.178465552059926}, {1.6755160819145563, 6.178465552059926}, 
    {1.6755160819145563, 6.073745796940266}, {1.5707963267948966, \
6.073745796940266}}], 
  Line[{{1.5707963267948966, 6.178465552059926}, {1.5707963267948966, \
6.283185307179586}, {1.6755160819145563, 6.283185307179586}, 
    {1.6755160819145563, 6.178465552059926}, {1.5707963267948966, \
6.178465552059926}}], 
  Line[{{1.6755160819145563, 0.}, {1.6755160819145563, 0.10471975511965977}, \
{1.780235837034216, 0.10471975511965977}, {1.780235837034216, 0.}, 
    {1.6755160819145563, 0.}}], Line[{{1.6755160819145563, \
0.10471975511965977}, {1.6755160819145563, 0.20943951023931953}, 
    {1.780235837034216, 0.20943951023931953}, {1.780235837034216, \
0.10471975511965977}, {1.6755160819145563, 0.10471975511965977}}], 
  Line[{{1.6755160819145563, 0.20943951023931953}, {1.6755160819145563, \
0.3141592653589793}, {1.780235837034216, 0.3141592653589793}, 
    {1.780235837034216, 0.20943951023931953}, {1.6755160819145563, \
0.20943951023931953}}], 
  Line[{{1.6755160819145563, 0.3141592653589793}, {1.6755160819145563, \
0.41887902047863906}, {1.780235837034216, 0.41887902047863906}, 
    {1.780235837034216, 0.3141592653589793}, {1.6755160819145563, \
0.3141592653589793}}], 
  Line[{{1.6755160819145563, 0.41887902047863906}, {1.6755160819145563, \
0.5235987755982988}, {1.780235837034216, 0.5235987755982988}, 
    {1.780235837034216, 0.41887902047863906}, {1.6755160819145563, \
0.41887902047863906}}], 
  Line[{{1.6755160819145563, 0.5235987755982988}, {1.6755160819145563, \
0.6283185307179586}, {1.780235837034216, 0.6283185307179586}, 
    {1.780235837034216, 0.5235987755982988}, {1.6755160819145563, \
0.5235987755982988}}], 
  Line[{{1.6755160819145563, 0.6283185307179586}, {1.6755160819145563, \
0.7330382858376183}, {1.780235837034216, 0.7330382858376183}, 
    {1.780235837034216, 0.6283185307179586}, {1.6755160819145563, \
0.6283185307179586}}], 
  Line[{{1.6755160819145563, 0.7330382858376183}, {1.6755160819145563, \
0.8377580409572781}, {1.780235837034216, 0.8377580409572781}, 
    {1.780235837034216, 0.7330382858376183}, {1.6755160819145563, \
0.7330382858376183}}], 
  Line[{{1.6755160819145563, 0.8377580409572781}, {1.6755160819145563, \
0.9424777960769379}, {1.780235837034216, 0.9424777960769379}, 
    {1.780235837034216, 0.8377580409572781}, {1.6755160819145563, \
0.8377580409572781}}], 
  Line[{{1.6755160819145563, 0.9424777960769379}, {1.6755160819145563, \
1.0471975511965976}, {1.780235837034216, 1.0471975511965976}, 
    {1.780235837034216, 0.9424777960769379}, {1.6755160819145563, \
0.9424777960769379}}], 
  Line[{{1.6755160819145563, 1.0471975511965976}, {1.6755160819145563, \
1.1519173063162573}, {1.780235837034216, 1.1519173063162573}, 
    {1.780235837034216, 1.0471975511965976}, {1.6755160819145563, \
1.0471975511965976}}], 
  Line[{{1.6755160819145563, 1.1519173063162573}, {1.6755160819145563, \
1.2566370614359172}, {1.780235837034216, 1.2566370614359172}, 
    {1.780235837034216, 1.1519173063162573}, {1.6755160819145563, \
1.1519173063162573}}], 
  Line[{{1.6755160819145563, 1.2566370614359172}, {1.6755160819145563, \
1.361356816555577}, {1.780235837034216, 1.361356816555577}, 
    {1.780235837034216, 1.2566370614359172}, {1.6755160819145563, \
1.2566370614359172}}], 
  Line[{{1.6755160819145563, 1.361356816555577}, {1.6755160819145563, \
1.4660765716752366}, {1.780235837034216, 1.4660765716752366}, 
    {1.780235837034216, 1.361356816555577}, {1.6755160819145563, \
1.361356816555577}}], 
  Line[{{1.6755160819145563, 1.4660765716752366}, {1.6755160819145563, \
1.5707963267948966}, {1.780235837034216, 1.5707963267948966}, 
    {1.780235837034216, 1.4660765716752366}, {1.6755160819145563, \
1.4660765716752366}}], 
  Line[{{1.6755160819145563, 1.5707963267948966}, {1.6755160819145563, \
1.6755160819145563}, {1.780235837034216, 1.6755160819145563}, 
    {1.780235837034216, 1.5707963267948966}, {1.6755160819145563, \
1.5707963267948966}}], 
  Line[{{1.6755160819145563, 1.6755160819145563}, {1.6755160819145563, \
1.780235837034216}, {1.780235837034216, 1.780235837034216}, 
    {1.780235837034216, 1.6755160819145563}, {1.6755160819145563, \
1.6755160819145563}}], 
  Line[{{1.6755160819145563, 1.780235837034216}, {1.6755160819145563, \
1.8849555921538759}, {1.780235837034216, 1.8849555921538759}, 
    {1.780235837034216, 1.780235837034216}, {1.6755160819145563, \
1.780235837034216}}], 
  Line[{{1.6755160819145563, 1.8849555921538759}, {1.6755160819145563, \
1.9896753472735356}, {1.780235837034216, 1.9896753472735356}, 
    {1.780235837034216, 1.8849555921538759}, {1.6755160819145563, \
1.8849555921538759}}], 
  Line[{{1.6755160819145563, 1.9896753472735356}, {1.6755160819145563, \
2.0943951023931953}, {1.780235837034216, 2.0943951023931953}, 
    {1.780235837034216, 1.9896753472735356}, {1.6755160819145563, \
1.9896753472735356}}], 
  Line[{{1.6755160819145563, 2.0943951023931953}, {1.6755160819145563, \
2.199114857512855}, {1.780235837034216, 2.199114857512855}, 
    {1.780235837034216, 2.0943951023931953}, {1.6755160819145563, \
2.0943951023931953}}], 
  Line[{{1.6755160819145563, 2.199114857512855}, {1.6755160819145563, \
2.3038346126325147}, {1.780235837034216, 2.3038346126325147}, 
    {1.780235837034216, 2.199114857512855}, {1.6755160819145563, \
2.199114857512855}}], 
  Line[{{1.6755160819145563, 2.3038346126325147}, {1.6755160819145563, \
2.4085543677521746}, {1.780235837034216, 2.4085543677521746}, 
    {1.780235837034216, 2.3038346126325147}, {1.6755160819145563, \
2.3038346126325147}}], 
  Line[{{1.6755160819145563, 2.4085543677521746}, {1.6755160819145563, \
2.5132741228718345}, {1.780235837034216, 2.5132741228718345}, 
    {1.780235837034216, 2.4085543677521746}, {1.6755160819145563, \
2.4085543677521746}}], 
  Line[{{1.6755160819145563, 2.5132741228718345}, {1.6755160819145563, \
2.617993877991494}, {1.780235837034216, 2.617993877991494}, 
    {1.780235837034216, 2.5132741228718345}, {1.6755160819145563, \
2.5132741228718345}}], 
  Line[{{1.6755160819145563, 2.617993877991494}, {1.6755160819145563, \
2.722713633111154}, {1.780235837034216, 2.722713633111154}, 
    {1.780235837034216, 2.617993877991494}, {1.6755160819145563, \
2.617993877991494}}], 
  Line[{{1.6755160819145563, 2.722713633111154}, {1.6755160819145563, \
2.827433388230814}, {1.780235837034216, 2.827433388230814}, 
    {1.780235837034216, 2.722713633111154}, {1.6755160819145563, \
2.722713633111154}}], 
  Line[{{1.6755160819145563, 2.827433388230814}, {1.6755160819145563, \
2.9321531433504733}, {1.780235837034216, 2.9321531433504733}, 
    {1.780235837034216, 2.827433388230814}, {1.6755160819145563, \
2.827433388230814}}], 
  Line[{{1.6755160819145563, 2.9321531433504733}, {1.6755160819145563, \
3.036872898470133}, {1.780235837034216, 3.036872898470133}, 
    {1.780235837034216, 2.9321531433504733}, {1.6755160819145563, \
2.9321531433504733}}], 
  Line[{{1.6755160819145563, 3.036872898470133}, {1.6755160819145563, \
3.141592653589793}, {1.780235837034216, 3.141592653589793}, 
    {1.780235837034216, 3.036872898470133}, {1.6755160819145563, \
3.036872898470133}}], 
  Line[{{1.6755160819145563, 3.141592653589793}, {1.6755160819145563, \
3.2463124087094526}, {1.780235837034216, 3.2463124087094526}, 
    {1.780235837034216, 3.141592653589793}, {1.6755160819145563, \
3.141592653589793}}], 
  Line[{{1.6755160819145563, 3.2463124087094526}, {1.6755160819145563, \
3.3510321638291125}, {1.780235837034216, 3.3510321638291125}, 
    {1.780235837034216, 3.2463124087094526}, {1.6755160819145563, \
3.2463124087094526}}], 
  Line[{{1.6755160819145563, 3.3510321638291125}, {1.6755160819145563, \
3.4557519189487724}, {1.780235837034216, 3.4557519189487724}, 
    {1.780235837034216, 3.3510321638291125}, {1.6755160819145563, \
3.3510321638291125}}], 
  Line[{{1.6755160819145563, 3.4557519189487724}, {1.6755160819145563, \
3.560471674068432}, {1.780235837034216, 3.560471674068432}, 
    {1.780235837034216, 3.4557519189487724}, {1.6755160819145563, \
3.4557519189487724}}], 
  Line[{{1.6755160819145563, 3.560471674068432}, {1.6755160819145563, \
3.665191429188092}, {1.780235837034216, 3.665191429188092}, 
    {1.780235837034216, 3.560471674068432}, {1.6755160819145563, \
3.560471674068432}}], 
  Line[{{1.6755160819145563, 3.665191429188092}, {1.6755160819145563, \
3.7699111843077517}, {1.780235837034216, 3.7699111843077517}, 
    {1.780235837034216, 3.665191429188092}, {1.6755160819145563, \
3.665191429188092}}], 
  Line[{{1.6755160819145563, 3.7699111843077517}, {1.6755160819145563, \
3.874630939427411}, {1.780235837034216, 3.874630939427411}, 
    {1.780235837034216, 3.7699111843077517}, {1.6755160819145563, \
3.7699111843077517}}], 
  Line[{{1.6755160819145563, 3.874630939427411}, {1.6755160819145563, \
3.979350694547071}, {1.780235837034216, 3.979350694547071}, 
    {1.780235837034216, 3.874630939427411}, {1.6755160819145563, \
3.874630939427411}}], 
  Line[{{1.6755160819145563, 3.979350694547071}, {1.6755160819145563, \
4.084070449666731}, {1.780235837034216, 4.084070449666731}, 
    {1.780235837034216, 3.979350694547071}, {1.6755160819145563, \
3.979350694547071}}], 
  Line[{{1.6755160819145563, 4.084070449666731}, {1.6755160819145563, \
4.1887902047863905}, {1.780235837034216, 4.1887902047863905}, 
    {1.780235837034216, 4.084070449666731}, {1.6755160819145563, \
4.084070449666731}}], 
  Line[{{1.6755160819145563, 4.1887902047863905}, {1.6755160819145563, \
4.29350995990605}, {1.780235837034216, 4.29350995990605}, 
    {1.780235837034216, 4.1887902047863905}, {1.6755160819145563, \
4.1887902047863905}}], 
  Line[{{1.6755160819145563, 4.29350995990605}, {1.6755160819145563, \
4.39822971502571}, {1.780235837034216, 4.39822971502571}, 
    {1.780235837034216, 4.29350995990605}, {1.6755160819145563, \
4.29350995990605}}], 
  Line[{{1.6755160819145563, 4.39822971502571}, {1.6755160819145563, \
4.50294947014537}, {1.780235837034216, 4.50294947014537}, 
    {1.780235837034216, 4.39822971502571}, {1.6755160819145563, \
4.39822971502571}}], 
  Line[{{1.6755160819145563, 4.50294947014537}, {1.6755160819145563, \
4.607669225265029}, {1.780235837034216, 4.607669225265029}, 
    {1.780235837034216, 4.50294947014537}, {1.6755160819145563, \
4.50294947014537}}], 
  Line[{{1.6755160819145563, 4.607669225265029}, {1.6755160819145563, \
4.71238898038469}, {1.780235837034216, 4.71238898038469}, 
    {1.780235837034216, 4.607669225265029}, {1.6755160819145563, \
4.607669225265029}}], 
  Line[{{1.6755160819145563, 4.71238898038469}, {1.6755160819145563, \
4.817108735504349}, {1.780235837034216, 4.817108735504349}, 
    {1.780235837034216, 4.71238898038469}, {1.6755160819145563, \
4.71238898038469}}], 
  Line[{{1.6755160819145563, 4.817108735504349}, {1.6755160819145563, \
4.921828490624009}, {1.780235837034216, 4.921828490624009}, 
    {1.780235837034216, 4.817108735504349}, {1.6755160819145563, \
4.817108735504349}}], 
  Line[{{1.6755160819145563, 4.921828490624009}, {1.6755160819145563, \
5.026548245743669}, {1.780235837034216, 5.026548245743669}, 
    {1.780235837034216, 4.921828490624009}, {1.6755160819145563, \
4.921828490624009}}], 
  Line[{{1.6755160819145563, 5.026548245743669}, {1.6755160819145563, \
5.1312680008633285}, {1.780235837034216, 5.1312680008633285}, 
    {1.780235837034216, 5.026548245743669}, {1.6755160819145563, \
5.026548245743669}}], 
  Line[{{1.6755160819145563, 5.1312680008633285}, {1.6755160819145563, \
5.235987755982988}, {1.780235837034216, 5.235987755982988}, 
    {1.780235837034216, 5.1312680008633285}, {1.6755160819145563, \
5.1312680008633285}}], 
  Line[{{1.6755160819145563, 5.235987755982988}, {1.6755160819145563, \
5.340707511102648}, {1.780235837034216, 5.340707511102648}, 
    {1.780235837034216, 5.235987755982988}, {1.6755160819145563, \
5.235987755982988}}], 
  Line[{{1.6755160819145563, 5.340707511102648}, {1.6755160819145563, \
5.445427266222308}, {1.780235837034216, 5.445427266222308}, 
    {1.780235837034216, 5.340707511102648}, {1.6755160819145563, \
5.340707511102648}}], 
  Line[{{1.6755160819145563, 5.445427266222308}, {1.6755160819145563, \
5.550147021341967}, {1.780235837034216, 5.550147021341967}, 
    {1.780235837034216, 5.445427266222308}, {1.6755160819145563, \
5.445427266222308}}], 
  Line[{{1.6755160819145563, 5.550147021341967}, {1.6755160819145563, \
5.654866776461628}, {1.780235837034216, 5.654866776461628}, 
    {1.780235837034216, 5.550147021341967}, {1.6755160819145563, \
5.550147021341967}}], 
  Line[{{1.6755160819145563, 5.654866776461628}, {1.6755160819145563, \
5.759586531581287}, {1.780235837034216, 5.759586531581287}, 
    {1.780235837034216, 5.654866776461628}, {1.6755160819145563, \
5.654866776461628}}], 
  Line[{{1.6755160819145563, 5.759586531581287}, {1.6755160819145563, \
5.864306286700947}, {1.780235837034216, 5.864306286700947}, 
    {1.780235837034216, 5.759586531581287}, {1.6755160819145563, \
5.759586531581287}}], 
  Line[{{1.6755160819145563, 5.864306286700947}, {1.6755160819145563, \
5.969026041820607}, {1.780235837034216, 5.969026041820607}, 
    {1.780235837034216, 5.864306286700947}, {1.6755160819145563, \
5.864306286700947}}], 
  Line[{{1.6755160819145563, 5.969026041820607}, {1.6755160819145563, \
6.073745796940266}, {1.780235837034216, 6.073745796940266}, 
    {1.780235837034216, 5.969026041820607}, {1.6755160819145563, \
5.969026041820607}}], 
  Line[{{1.6755160819145563, 6.073745796940266}, {1.6755160819145563, \
6.178465552059926}, {1.780235837034216, 6.178465552059926}, 
    {1.780235837034216, 6.073745796940266}, {1.6755160819145563, \
6.073745796940266}}], 
  Line[{{1.6755160819145563, 6.178465552059926}, {1.6755160819145563, \
6.283185307179586}, {1.780235837034216, 6.283185307179586}, 
    {1.780235837034216, 6.178465552059926}, {1.6755160819145563, \
6.178465552059926}}], 
  Line[{{1.780235837034216, 0.}, {1.780235837034216, 0.10471975511965977}, \
{1.8849555921538759, 0.10471975511965977}, {1.8849555921538759, 0.}, 
    {1.780235837034216, 0.}}], Line[{{1.780235837034216, \
0.10471975511965977}, {1.780235837034216, 0.20943951023931953}, 
    {1.8849555921538759, 0.20943951023931953}, {1.8849555921538759, \
0.10471975511965977}, {1.780235837034216, 0.10471975511965977}}], 
  Line[{{1.780235837034216, 0.20943951023931953}, {1.780235837034216, \
0.3141592653589793}, {1.8849555921538759, 0.3141592653589793}, 
    {1.8849555921538759, 0.20943951023931953}, {1.780235837034216, \
0.20943951023931953}}], 
  Line[{{1.780235837034216, 0.3141592653589793}, {1.780235837034216, \
0.41887902047863906}, {1.8849555921538759, 0.41887902047863906}, 
    {1.8849555921538759, 0.3141592653589793}, {1.780235837034216, \
0.3141592653589793}}], 
  Line[{{1.780235837034216, 0.41887902047863906}, {1.780235837034216, \
0.5235987755982988}, {1.8849555921538759, 0.5235987755982988}, 
    {1.8849555921538759, 0.41887902047863906}, {1.780235837034216, \
0.41887902047863906}}], 
  Line[{{1.780235837034216, 0.5235987755982988}, {1.780235837034216, \
0.6283185307179586}, {1.8849555921538759, 0.6283185307179586}, 
    {1.8849555921538759, 0.5235987755982988}, {1.780235837034216, \
0.5235987755982988}}], 
  Line[{{1.780235837034216, 0.6283185307179586}, {1.780235837034216, \
0.7330382858376183}, {1.8849555921538759, 0.7330382858376183}, 
    {1.8849555921538759, 0.6283185307179586}, {1.780235837034216, \
0.6283185307179586}}], 
  Line[{{1.780235837034216, 0.7330382858376183}, {1.780235837034216, \
0.8377580409572781}, {1.8849555921538759, 0.8377580409572781}, 
    {1.8849555921538759, 0.7330382858376183}, {1.780235837034216, \
0.7330382858376183}}], 
  Line[{{1.780235837034216, 0.8377580409572781}, {1.780235837034216, \
0.9424777960769379}, {1.8849555921538759, 0.9424777960769379}, 
    {1.8849555921538759, 0.8377580409572781}, {1.780235837034216, \
0.8377580409572781}}], 
  Line[{{1.780235837034216, 0.9424777960769379}, {1.780235837034216, \
1.0471975511965976}, {1.8849555921538759, 1.0471975511965976}, 
    {1.8849555921538759, 0.9424777960769379}, {1.780235837034216, \
0.9424777960769379}}], 
  Line[{{1.780235837034216, 1.0471975511965976}, {1.780235837034216, \
1.1519173063162573}, {1.8849555921538759, 1.1519173063162573}, 
    {1.8849555921538759, 1.0471975511965976}, {1.780235837034216, \
1.0471975511965976}}], 
  Line[{{1.780235837034216, 1.1519173063162573}, {1.780235837034216, \
1.2566370614359172}, {1.8849555921538759, 1.2566370614359172}, 
    {1.8849555921538759, 1.1519173063162573}, {1.780235837034216, \
1.1519173063162573}}], 
  Line[{{1.780235837034216, 1.2566370614359172}, {1.780235837034216, \
1.361356816555577}, {1.8849555921538759, 1.361356816555577}, 
    {1.8849555921538759, 1.2566370614359172}, {1.780235837034216, \
1.2566370614359172}}], 
  Line[{{1.780235837034216, 1.361356816555577}, {1.780235837034216, \
1.4660765716752366}, {1.8849555921538759, 1.4660765716752366}, 
    {1.8849555921538759, 1.361356816555577}, {1.780235837034216, \
1.361356816555577}}], 
  Line[{{1.780235837034216, 1.4660765716752366}, {1.780235837034216, \
1.5707963267948966}, {1.8849555921538759, 1.5707963267948966}, 
    {1.8849555921538759, 1.4660765716752366}, {1.780235837034216, \
1.4660765716752366}}], 
  Line[{{1.780235837034216, 1.5707963267948966}, {1.780235837034216, \
1.6755160819145563}, {1.8849555921538759, 1.6755160819145563}, 
    {1.8849555921538759, 1.5707963267948966}, {1.780235837034216, \
1.5707963267948966}}], 
  Line[{{1.780235837034216, 1.6755160819145563}, {1.780235837034216, \
1.780235837034216}, {1.8849555921538759, 1.780235837034216}, 
    {1.8849555921538759, 1.6755160819145563}, {1.780235837034216, \
1.6755160819145563}}], 
  Line[{{1.780235837034216, 1.780235837034216}, {1.780235837034216, \
1.8849555921538759}, {1.8849555921538759, 1.8849555921538759}, 
    {1.8849555921538759, 1.780235837034216}, {1.780235837034216, \
1.780235837034216}}], 
  Line[{{1.780235837034216, 1.8849555921538759}, {1.780235837034216, \
1.9896753472735356}, {1.8849555921538759, 1.9896753472735356}, 
    {1.8849555921538759, 1.8849555921538759}, {1.780235837034216, \
1.8849555921538759}}], 
  Line[{{1.780235837034216, 1.9896753472735356}, {1.780235837034216, \
2.0943951023931953}, {1.8849555921538759, 2.0943951023931953}, 
    {1.8849555921538759, 1.9896753472735356}, {1.780235837034216, \
1.9896753472735356}}], 
  Line[{{1.780235837034216, 2.0943951023931953}, {1.780235837034216, \
2.199114857512855}, {1.8849555921538759, 2.199114857512855}, 
    {1.8849555921538759, 2.0943951023931953}, {1.780235837034216, \
2.0943951023931953}}], 
  Line[{{1.780235837034216, 2.199114857512855}, {1.780235837034216, \
2.3038346126325147}, {1.8849555921538759, 2.3038346126325147}, 
    {1.8849555921538759, 2.199114857512855}, {1.780235837034216, \
2.199114857512855}}], 
  Line[{{1.780235837034216, 2.3038346126325147}, {1.780235837034216, \
2.4085543677521746}, {1.8849555921538759, 2.4085543677521746}, 
    {1.8849555921538759, 2.3038346126325147}, {1.780235837034216, \
2.3038346126325147}}], 
  Line[{{1.780235837034216, 2.4085543677521746}, {1.780235837034216, \
2.5132741228718345}, {1.8849555921538759, 2.5132741228718345}, 
    {1.8849555921538759, 2.4085543677521746}, {1.780235837034216, \
2.4085543677521746}}], 
  Line[{{1.780235837034216, 2.5132741228718345}, {1.780235837034216, \
2.617993877991494}, {1.8849555921538759, 2.617993877991494}, 
    {1.8849555921538759, 2.5132741228718345}, {1.780235837034216, \
2.5132741228718345}}], 
  Line[{{1.780235837034216, 2.617993877991494}, {1.780235837034216, \
2.722713633111154}, {1.8849555921538759, 2.722713633111154}, 
    {1.8849555921538759, 2.617993877991494}, {1.780235837034216, \
2.617993877991494}}], 
  Line[{{1.780235837034216, 2.722713633111154}, {1.780235837034216, \
2.827433388230814}, {1.8849555921538759, 2.827433388230814}, 
    {1.8849555921538759, 2.722713633111154}, {1.780235837034216, \
2.722713633111154}}], 
  Line[{{1.780235837034216, 2.827433388230814}, {1.780235837034216, \
2.9321531433504733}, {1.8849555921538759, 2.9321531433504733}, 
    {1.8849555921538759, 2.827433388230814}, {1.780235837034216, \
2.827433388230814}}], 
  Line[{{1.780235837034216, 2.9321531433504733}, {1.780235837034216, \
3.036872898470133}, {1.8849555921538759, 3.036872898470133}, 
    {1.8849555921538759, 2.9321531433504733}, {1.780235837034216, \
2.9321531433504733}}], 
  Line[{{1.780235837034216, 3.036872898470133}, {1.780235837034216, \
3.141592653589793}, {1.8849555921538759, 3.141592653589793}, 
    {1.8849555921538759, 3.036872898470133}, {1.780235837034216, \
3.036872898470133}}], 
  Line[{{1.780235837034216, 3.141592653589793}, {1.780235837034216, \
3.2463124087094526}, {1.8849555921538759, 3.2463124087094526}, 
    {1.8849555921538759, 3.141592653589793}, {1.780235837034216, \
3.141592653589793}}], 
  Line[{{1.780235837034216, 3.2463124087094526}, {1.780235837034216, \
3.3510321638291125}, {1.8849555921538759, 3.3510321638291125}, 
    {1.8849555921538759, 3.2463124087094526}, {1.780235837034216, \
3.2463124087094526}}], 
  Line[{{1.780235837034216, 3.3510321638291125}, {1.780235837034216, \
3.4557519189487724}, {1.8849555921538759, 3.4557519189487724}, 
    {1.8849555921538759, 3.3510321638291125}, {1.780235837034216, \
3.3510321638291125}}], 
  Line[{{1.780235837034216, 3.4557519189487724}, {1.780235837034216, \
3.560471674068432}, {1.8849555921538759, 3.560471674068432}, 
    {1.8849555921538759, 3.4557519189487724}, {1.780235837034216, \
3.4557519189487724}}], 
  Line[{{1.780235837034216, 3.560471674068432}, {1.780235837034216, \
3.665191429188092}, {1.8849555921538759, 3.665191429188092}, 
    {1.8849555921538759, 3.560471674068432}, {1.780235837034216, \
3.560471674068432}}], 
  Line[{{1.780235837034216, 3.665191429188092}, {1.780235837034216, \
3.7699111843077517}, {1.8849555921538759, 3.7699111843077517}, 
    {1.8849555921538759, 3.665191429188092}, {1.780235837034216, \
3.665191429188092}}], 
  Line[{{1.780235837034216, 3.7699111843077517}, {1.780235837034216, \
3.874630939427411}, {1.8849555921538759, 3.874630939427411}, 
    {1.8849555921538759, 3.7699111843077517}, {1.780235837034216, \
3.7699111843077517}}], 
  Line[{{1.780235837034216, 3.874630939427411}, {1.780235837034216, \
3.979350694547071}, {1.8849555921538759, 3.979350694547071}, 
    {1.8849555921538759, 3.874630939427411}, {1.780235837034216, \
3.874630939427411}}], 
  Line[{{1.780235837034216, 3.979350694547071}, {1.780235837034216, \
4.084070449666731}, {1.8849555921538759, 4.084070449666731}, 
    {1.8849555921538759, 3.979350694547071}, {1.780235837034216, \
3.979350694547071}}], 
  Line[{{1.780235837034216, 4.084070449666731}, {1.780235837034216, \
4.1887902047863905}, {1.8849555921538759, 4.1887902047863905}, 
    {1.8849555921538759, 4.084070449666731}, {1.780235837034216, \
4.084070449666731}}], 
  Line[{{1.780235837034216, 4.1887902047863905}, {1.780235837034216, \
4.29350995990605}, {1.8849555921538759, 4.29350995990605}, 
    {1.8849555921538759, 4.1887902047863905}, {1.780235837034216, \
4.1887902047863905}}], 
  Line[{{1.780235837034216, 4.29350995990605}, {1.780235837034216, \
4.39822971502571}, {1.8849555921538759, 4.39822971502571}, 
    {1.8849555921538759, 4.29350995990605}, {1.780235837034216, \
4.29350995990605}}], 
  Line[{{1.780235837034216, 4.39822971502571}, {1.780235837034216, \
4.50294947014537}, {1.8849555921538759, 4.50294947014537}, 
    {1.8849555921538759, 4.39822971502571}, {1.780235837034216, \
4.39822971502571}}], 
  Line[{{1.780235837034216, 4.50294947014537}, {1.780235837034216, \
4.607669225265029}, {1.8849555921538759, 4.607669225265029}, 
    {1.8849555921538759, 4.50294947014537}, {1.780235837034216, \
4.50294947014537}}], 
  Line[{{1.780235837034216, 4.607669225265029}, {1.780235837034216, \
4.71238898038469}, {1.8849555921538759, 4.71238898038469}, 
    {1.8849555921538759, 4.607669225265029}, {1.780235837034216, \
4.607669225265029}}], 
  Line[{{1.780235837034216, 4.71238898038469}, {1.780235837034216, \
4.817108735504349}, {1.8849555921538759, 4.817108735504349}, 
    {1.8849555921538759, 4.71238898038469}, {1.780235837034216, \
4.71238898038469}}], 
  Line[{{1.780235837034216, 4.817108735504349}, {1.780235837034216, \
4.921828490624009}, {1.8849555921538759, 4.921828490624009}, 
    {1.8849555921538759, 4.817108735504349}, {1.780235837034216, \
4.817108735504349}}], 
  Line[{{1.780235837034216, 4.921828490624009}, {1.780235837034216, \
5.026548245743669}, {1.8849555921538759, 5.026548245743669}, 
    {1.8849555921538759, 4.921828490624009}, {1.780235837034216, \
4.921828490624009}}], 
  Line[{{1.780235837034216, 5.026548245743669}, {1.780235837034216, \
5.1312680008633285}, {1.8849555921538759, 5.1312680008633285}, 
    {1.8849555921538759, 5.026548245743669}, {1.780235837034216, \
5.026548245743669}}], 
  Line[{{1.780235837034216, 5.1312680008633285}, {1.780235837034216, \
5.235987755982988}, {1.8849555921538759, 5.235987755982988}, 
    {1.8849555921538759, 5.1312680008633285}, {1.780235837034216, \
5.1312680008633285}}], 
  Line[{{1.780235837034216, 5.235987755982988}, {1.780235837034216, \
5.340707511102648}, {1.8849555921538759, 5.340707511102648}, 
    {1.8849555921538759, 5.235987755982988}, {1.780235837034216, \
5.235987755982988}}], 
  Line[{{1.780235837034216, 5.340707511102648}, {1.780235837034216, \
5.445427266222308}, {1.8849555921538759, 5.445427266222308}, 
    {1.8849555921538759, 5.340707511102648}, {1.780235837034216, \
5.340707511102648}}], 
  Line[{{1.780235837034216, 5.445427266222308}, {1.780235837034216, \
5.550147021341967}, {1.8849555921538759, 5.550147021341967}, 
    {1.8849555921538759, 5.445427266222308}, {1.780235837034216, \
5.445427266222308}}], 
  Line[{{1.780235837034216, 5.550147021341967}, {1.780235837034216, \
5.654866776461628}, {1.8849555921538759, 5.654866776461628}, 
    {1.8849555921538759, 5.550147021341967}, {1.780235837034216, \
5.550147021341967}}], 
  Line[{{1.780235837034216, 5.654866776461628}, {1.780235837034216, \
5.759586531581287}, {1.8849555921538759, 5.759586531581287}, 
    {1.8849555921538759, 5.654866776461628}, {1.780235837034216, \
5.654866776461628}}], 
  Line[{{1.780235837034216, 5.759586531581287}, {1.780235837034216, \
5.864306286700947}, {1.8849555921538759, 5.864306286700947}, 
    {1.8849555921538759, 5.759586531581287}, {1.780235837034216, \
5.759586531581287}}], 
  Line[{{1.780235837034216, 5.864306286700947}, {1.780235837034216, \
5.969026041820607}, {1.8849555921538759, 5.969026041820607}, 
    {1.8849555921538759, 5.864306286700947}, {1.780235837034216, \
5.864306286700947}}], 
  Line[{{1.780235837034216, 5.969026041820607}, {1.780235837034216, \
6.073745796940266}, {1.8849555921538759, 6.073745796940266}, 
    {1.8849555921538759, 5.969026041820607}, {1.780235837034216, \
5.969026041820607}}], 
  Line[{{1.780235837034216, 6.073745796940266}, {1.780235837034216, \
6.178465552059926}, {1.8849555921538759, 6.178465552059926}, 
    {1.8849555921538759, 6.073745796940266}, {1.780235837034216, \
6.073745796940266}}], 
  Line[{{1.780235837034216, 6.178465552059926}, {1.780235837034216, \
6.283185307179586}, {1.8849555921538759, 6.283185307179586}, 
    {1.8849555921538759, 6.178465552059926}, {1.780235837034216, \
6.178465552059926}}], 
  Line[{{1.8849555921538759, 0.}, {1.8849555921538759, 0.10471975511965977}, \
{1.9896753472735356, 0.10471975511965977}, {1.9896753472735356, 0.}, 
    {1.8849555921538759, 0.}}], Line[{{1.8849555921538759, \
0.10471975511965977}, {1.8849555921538759, 0.20943951023931953}, 
    {1.9896753472735356, 0.20943951023931953}, {1.9896753472735356, \
0.10471975511965977}, {1.8849555921538759, 0.10471975511965977}}], 
  Line[{{1.8849555921538759, 0.20943951023931953}, {1.8849555921538759, \
0.3141592653589793}, {1.9896753472735356, 0.3141592653589793}, 
    {1.9896753472735356, 0.20943951023931953}, {1.8849555921538759, \
0.20943951023931953}}], 
  Line[{{1.8849555921538759, 0.3141592653589793}, {1.8849555921538759, \
0.41887902047863906}, {1.9896753472735356, 0.41887902047863906}, 
    {1.9896753472735356, 0.3141592653589793}, {1.8849555921538759, \
0.3141592653589793}}], 
  Line[{{1.8849555921538759, 0.41887902047863906}, {1.8849555921538759, \
0.5235987755982988}, {1.9896753472735356, 0.5235987755982988}, 
    {1.9896753472735356, 0.41887902047863906}, {1.8849555921538759, \
0.41887902047863906}}], 
  Line[{{1.8849555921538759, 0.5235987755982988}, {1.8849555921538759, \
0.6283185307179586}, {1.9896753472735356, 0.6283185307179586}, 
    {1.9896753472735356, 0.5235987755982988}, {1.8849555921538759, \
0.5235987755982988}}], 
  Line[{{1.8849555921538759, 0.6283185307179586}, {1.8849555921538759, \
0.7330382858376183}, {1.9896753472735356, 0.7330382858376183}, 
    {1.9896753472735356, 0.6283185307179586}, {1.8849555921538759, \
0.6283185307179586}}], 
  Line[{{1.8849555921538759, 0.7330382858376183}, {1.8849555921538759, \
0.8377580409572781}, {1.9896753472735356, 0.8377580409572781}, 
    {1.9896753472735356, 0.7330382858376183}, {1.8849555921538759, \
0.7330382858376183}}], 
  Line[{{1.8849555921538759, 0.8377580409572781}, {1.8849555921538759, \
0.9424777960769379}, {1.9896753472735356, 0.9424777960769379}, 
    {1.9896753472735356, 0.8377580409572781}, {1.8849555921538759, \
0.8377580409572781}}], 
  Line[{{1.8849555921538759, 0.9424777960769379}, {1.8849555921538759, \
1.0471975511965976}, {1.9896753472735356, 1.0471975511965976}, 
    {1.9896753472735356, 0.9424777960769379}, {1.8849555921538759, \
0.9424777960769379}}], 
  Line[{{1.8849555921538759, 1.0471975511965976}, {1.8849555921538759, \
1.1519173063162573}, {1.9896753472735356, 1.1519173063162573}, 
    {1.9896753472735356, 1.0471975511965976}, {1.8849555921538759, \
1.0471975511965976}}], 
  Line[{{1.8849555921538759, 1.1519173063162573}, {1.8849555921538759, \
1.2566370614359172}, {1.9896753472735356, 1.2566370614359172}, 
    {1.9896753472735356, 1.1519173063162573}, {1.8849555921538759, \
1.1519173063162573}}], 
  Line[{{1.8849555921538759, 1.2566370614359172}, {1.8849555921538759, \
1.361356816555577}, {1.9896753472735356, 1.361356816555577}, 
    {1.9896753472735356, 1.2566370614359172}, {1.8849555921538759, \
1.2566370614359172}}], 
  Line[{{1.8849555921538759, 1.361356816555577}, {1.8849555921538759, \
1.4660765716752366}, {1.9896753472735356, 1.4660765716752366}, 
    {1.9896753472735356, 1.361356816555577}, {1.8849555921538759, \
1.361356816555577}}], 
  Line[{{1.8849555921538759, 1.4660765716752366}, {1.8849555921538759, \
1.5707963267948966}, {1.9896753472735356, 1.5707963267948966}, 
    {1.9896753472735356, 1.4660765716752366}, {1.8849555921538759, \
1.4660765716752366}}], 
  Line[{{1.8849555921538759, 1.5707963267948966}, {1.8849555921538759, \
1.6755160819145563}, {1.9896753472735356, 1.6755160819145563}, 
    {1.9896753472735356, 1.5707963267948966}, {1.8849555921538759, \
1.5707963267948966}}], 
  Line[{{1.8849555921538759, 1.6755160819145563}, {1.8849555921538759, \
1.780235837034216}, {1.9896753472735356, 1.780235837034216}, 
    {1.9896753472735356, 1.6755160819145563}, {1.8849555921538759, \
1.6755160819145563}}], 
  Line[{{1.8849555921538759, 1.780235837034216}, {1.8849555921538759, \
1.8849555921538759}, {1.9896753472735356, 1.8849555921538759}, 
    {1.9896753472735356, 1.780235837034216}, {1.8849555921538759, \
1.780235837034216}}], 
  Line[{{1.8849555921538759, 1.8849555921538759}, {1.8849555921538759, \
1.9896753472735356}, {1.9896753472735356, 1.9896753472735356}, 
    {1.9896753472735356, 1.8849555921538759}, {1.8849555921538759, \
1.8849555921538759}}], 
  Line[{{1.8849555921538759, 1.9896753472735356}, {1.8849555921538759, \
2.0943951023931953}, {1.9896753472735356, 2.0943951023931953}, 
    {1.9896753472735356, 1.9896753472735356}, {1.8849555921538759, \
1.9896753472735356}}], 
  Line[{{1.8849555921538759, 2.0943951023931953}, {1.8849555921538759, \
2.199114857512855}, {1.9896753472735356, 2.199114857512855}, 
    {1.9896753472735356, 2.0943951023931953}, {1.8849555921538759, \
2.0943951023931953}}], 
  Line[{{1.8849555921538759, 2.199114857512855}, {1.8849555921538759, \
2.3038346126325147}, {1.9896753472735356, 2.3038346126325147}, 
    {1.9896753472735356, 2.199114857512855}, {1.8849555921538759, \
2.199114857512855}}], 
  Line[{{1.8849555921538759, 2.3038346126325147}, {1.8849555921538759, \
2.4085543677521746}, {1.9896753472735356, 2.4085543677521746}, 
    {1.9896753472735356, 2.3038346126325147}, {1.8849555921538759, \
2.3038346126325147}}], 
  Line[{{1.8849555921538759, 2.4085543677521746}, {1.8849555921538759, \
2.5132741228718345}, {1.9896753472735356, 2.5132741228718345}, 
    {1.9896753472735356, 2.4085543677521746}, {1.8849555921538759, \
2.4085543677521746}}], 
  Line[{{1.8849555921538759, 2.5132741228718345}, {1.8849555921538759, \
2.617993877991494}, {1.9896753472735356, 2.617993877991494}, 
    {1.9896753472735356, 2.5132741228718345}, {1.8849555921538759, \
2.5132741228718345}}], 
  Line[{{1.8849555921538759, 2.617993877991494}, {1.8849555921538759, \
2.722713633111154}, {1.9896753472735356, 2.722713633111154}, 
    {1.9896753472735356, 2.617993877991494}, {1.8849555921538759, \
2.617993877991494}}], 
  Line[{{1.8849555921538759, 2.722713633111154}, {1.8849555921538759, \
2.827433388230814}, {1.9896753472735356, 2.827433388230814}, 
    {1.9896753472735356, 2.722713633111154}, {1.8849555921538759, \
2.722713633111154}}], 
  Line[{{1.8849555921538759, 2.827433388230814}, {1.8849555921538759, \
2.9321531433504733}, {1.9896753472735356, 2.9321531433504733}, 
    {1.9896753472735356, 2.827433388230814}, {1.8849555921538759, \
2.827433388230814}}], 
  Line[{{1.8849555921538759, 2.9321531433504733}, {1.8849555921538759, \
3.036872898470133}, {1.9896753472735356, 3.036872898470133}, 
    {1.9896753472735356, 2.9321531433504733}, {1.8849555921538759, \
2.9321531433504733}}], 
  Line[{{1.8849555921538759, 3.036872898470133}, {1.8849555921538759, \
3.141592653589793}, {1.9896753472735356, 3.141592653589793}, 
    {1.9896753472735356, 3.036872898470133}, {1.8849555921538759, \
3.036872898470133}}], 
  Line[{{1.8849555921538759, 3.141592653589793}, {1.8849555921538759, \
3.2463124087094526}, {1.9896753472735356, 3.2463124087094526}, 
    {1.9896753472735356, 3.141592653589793}, {1.8849555921538759, \
3.141592653589793}}], 
  Line[{{1.8849555921538759, 3.2463124087094526}, {1.8849555921538759, \
3.3510321638291125}, {1.9896753472735356, 3.3510321638291125}, 
    {1.9896753472735356, 3.2463124087094526}, {1.8849555921538759, \
3.2463124087094526}}], 
  Line[{{1.8849555921538759, 3.3510321638291125}, {1.8849555921538759, \
3.4557519189487724}, {1.9896753472735356, 3.4557519189487724}, 
    {1.9896753472735356, 3.3510321638291125}, {1.8849555921538759, \
3.3510321638291125}}], 
  Line[{{1.8849555921538759, 3.4557519189487724}, {1.8849555921538759, \
3.560471674068432}, {1.9896753472735356, 3.560471674068432}, 
    {1.9896753472735356, 3.4557519189487724}, {1.8849555921538759, \
3.4557519189487724}}], 
  Line[{{1.8849555921538759, 3.560471674068432}, {1.8849555921538759, \
3.665191429188092}, {1.9896753472735356, 3.665191429188092}, 
    {1.9896753472735356, 3.560471674068432}, {1.8849555921538759, \
3.560471674068432}}], 
  Line[{{1.8849555921538759, 3.665191429188092}, {1.8849555921538759, \
3.7699111843077517}, {1.9896753472735356, 3.7699111843077517}, 
    {1.9896753472735356, 3.665191429188092}, {1.8849555921538759, \
3.665191429188092}}], 
  Line[{{1.8849555921538759, 3.7699111843077517}, {1.8849555921538759, \
3.874630939427411}, {1.9896753472735356, 3.874630939427411}, 
    {1.9896753472735356, 3.7699111843077517}, {1.8849555921538759, \
3.7699111843077517}}], 
  Line[{{1.8849555921538759, 3.874630939427411}, {1.8849555921538759, \
3.979350694547071}, {1.9896753472735356, 3.979350694547071}, 
    {1.9896753472735356, 3.874630939427411}, {1.8849555921538759, \
3.874630939427411}}], 
  Line[{{1.8849555921538759, 3.979350694547071}, {1.8849555921538759, \
4.084070449666731}, {1.9896753472735356, 4.084070449666731}, 
    {1.9896753472735356, 3.979350694547071}, {1.8849555921538759, \
3.979350694547071}}], 
  Line[{{1.8849555921538759, 4.084070449666731}, {1.8849555921538759, \
4.1887902047863905}, {1.9896753472735356, 4.1887902047863905}, 
    {1.9896753472735356, 4.084070449666731}, {1.8849555921538759, \
4.084070449666731}}], 
  Line[{{1.8849555921538759, 4.1887902047863905}, {1.8849555921538759, \
4.29350995990605}, {1.9896753472735356, 4.29350995990605}, 
    {1.9896753472735356, 4.1887902047863905}, {1.8849555921538759, \
4.1887902047863905}}], 
  Line[{{1.8849555921538759, 4.29350995990605}, {1.8849555921538759, \
4.39822971502571}, {1.9896753472735356, 4.39822971502571}, 
    {1.9896753472735356, 4.29350995990605}, {1.8849555921538759, \
4.29350995990605}}], 
  Line[{{1.8849555921538759, 4.39822971502571}, {1.8849555921538759, \
4.50294947014537}, {1.9896753472735356, 4.50294947014537}, 
    {1.9896753472735356, 4.39822971502571}, {1.8849555921538759, \
4.39822971502571}}], 
  Line[{{1.8849555921538759, 4.50294947014537}, {1.8849555921538759, \
4.607669225265029}, {1.9896753472735356, 4.607669225265029}, 
    {1.9896753472735356, 4.50294947014537}, {1.8849555921538759, \
4.50294947014537}}], 
  Line[{{1.8849555921538759, 4.607669225265029}, {1.8849555921538759, \
4.71238898038469}, {1.9896753472735356, 4.71238898038469}, 
    {1.9896753472735356, 4.607669225265029}, {1.8849555921538759, \
4.607669225265029}}], 
  Line[{{1.8849555921538759, 4.71238898038469}, {1.8849555921538759, \
4.817108735504349}, {1.9896753472735356, 4.817108735504349}, 
    {1.9896753472735356, 4.71238898038469}, {1.8849555921538759, \
4.71238898038469}}], 
  Line[{{1.8849555921538759, 4.817108735504349}, {1.8849555921538759, \
4.921828490624009}, {1.9896753472735356, 4.921828490624009}, 
    {1.9896753472735356, 4.817108735504349}, {1.8849555921538759, \
4.817108735504349}}], 
  Line[{{1.8849555921538759, 4.921828490624009}, {1.8849555921538759, \
5.026548245743669}, {1.9896753472735356, 5.026548245743669}, 
    {1.9896753472735356, 4.921828490624009}, {1.8849555921538759, \
4.921828490624009}}], 
  Line[{{1.8849555921538759, 5.026548245743669}, {1.8849555921538759, \
5.1312680008633285}, {1.9896753472735356, 5.1312680008633285}, 
    {1.9896753472735356, 5.026548245743669}, {1.8849555921538759, \
5.026548245743669}}], 
  Line[{{1.8849555921538759, 5.1312680008633285}, {1.8849555921538759, \
5.235987755982988}, {1.9896753472735356, 5.235987755982988}, 
    {1.9896753472735356, 5.1312680008633285}, {1.8849555921538759, \
5.1312680008633285}}], 
  Line[{{1.8849555921538759, 5.235987755982988}, {1.8849555921538759, \
5.340707511102648}, {1.9896753472735356, 5.340707511102648}, 
    {1.9896753472735356, 5.235987755982988}, {1.8849555921538759, \
5.235987755982988}}], 
  Line[{{1.8849555921538759, 5.340707511102648}, {1.8849555921538759, \
5.445427266222308}, {1.9896753472735356, 5.445427266222308}, 
    {1.9896753472735356, 5.340707511102648}, {1.8849555921538759, \
5.340707511102648}}], 
  Line[{{1.8849555921538759, 5.445427266222308}, {1.8849555921538759, \
5.550147021341967}, {1.9896753472735356, 5.550147021341967}, 
    {1.9896753472735356, 5.445427266222308}, {1.8849555921538759, \
5.445427266222308}}], 
  Line[{{1.8849555921538759, 5.550147021341967}, {1.8849555921538759, \
5.654866776461628}, {1.9896753472735356, 5.654866776461628}, 
    {1.9896753472735356, 5.550147021341967}, {1.8849555921538759, \
5.550147021341967}}], 
  Line[{{1.8849555921538759, 5.654866776461628}, {1.8849555921538759, \
5.759586531581287}, {1.9896753472735356, 5.759586531581287}, 
    {1.9896753472735356, 5.654866776461628}, {1.8849555921538759, \
5.654866776461628}}], 
  Line[{{1.8849555921538759, 5.759586531581287}, {1.8849555921538759, \
5.864306286700947}, {1.9896753472735356, 5.864306286700947}, 
    {1.9896753472735356, 5.759586531581287}, {1.8849555921538759, \
5.759586531581287}}], 
  Line[{{1.8849555921538759, 5.864306286700947}, {1.8849555921538759, \
5.969026041820607}, {1.9896753472735356, 5.969026041820607}, 
    {1.9896753472735356, 5.864306286700947}, {1.8849555921538759, \
5.864306286700947}}], 
  Line[{{1.8849555921538759, 5.969026041820607}, {1.8849555921538759, \
6.073745796940266}, {1.9896753472735356, 6.073745796940266}, 
    {1.9896753472735356, 5.969026041820607}, {1.8849555921538759, \
5.969026041820607}}], 
  Line[{{1.8849555921538759, 6.073745796940266}, {1.8849555921538759, \
6.178465552059926}, {1.9896753472735356, 6.178465552059926}, 
    {1.9896753472735356, 6.073745796940266}, {1.8849555921538759, \
6.073745796940266}}], 
  Line[{{1.8849555921538759, 6.178465552059926}, {1.8849555921538759, \
6.283185307179586}, {1.9896753472735356, 6.283185307179586}, 
    {1.9896753472735356, 6.178465552059926}, {1.8849555921538759, \
6.178465552059926}}], 
  Line[{{1.9896753472735356, 0.}, {1.9896753472735356, 0.10471975511965977}, \
{2.0943951023931953, 0.10471975511965977}, {2.0943951023931953, 0.}, 
    {1.9896753472735356, 0.}}], Line[{{1.9896753472735356, \
0.10471975511965977}, {1.9896753472735356, 0.20943951023931953}, 
    {2.0943951023931953, 0.20943951023931953}, {2.0943951023931953, \
0.10471975511965977}, {1.9896753472735356, 0.10471975511965977}}], 
  Line[{{1.9896753472735356, 0.20943951023931953}, {1.9896753472735356, \
0.3141592653589793}, {2.0943951023931953, 0.3141592653589793}, 
    {2.0943951023931953, 0.20943951023931953}, {1.9896753472735356, \
0.20943951023931953}}], 
  Line[{{1.9896753472735356, 0.3141592653589793}, {1.9896753472735356, \
0.41887902047863906}, {2.0943951023931953, 0.41887902047863906}, 
    {2.0943951023931953, 0.3141592653589793}, {1.9896753472735356, \
0.3141592653589793}}], 
  Line[{{1.9896753472735356, 0.41887902047863906}, {1.9896753472735356, \
0.5235987755982988}, {2.0943951023931953, 0.5235987755982988}, 
    {2.0943951023931953, 0.41887902047863906}, {1.9896753472735356, \
0.41887902047863906}}], 
  Line[{{1.9896753472735356, 0.5235987755982988}, {1.9896753472735356, \
0.6283185307179586}, {2.0943951023931953, 0.6283185307179586}, 
    {2.0943951023931953, 0.5235987755982988}, {1.9896753472735356, \
0.5235987755982988}}], 
  Line[{{1.9896753472735356, 0.6283185307179586}, {1.9896753472735356, \
0.7330382858376183}, {2.0943951023931953, 0.7330382858376183}, 
    {2.0943951023931953, 0.6283185307179586}, {1.9896753472735356, \
0.6283185307179586}}], 
  Line[{{1.9896753472735356, 0.7330382858376183}, {1.9896753472735356, \
0.8377580409572781}, {2.0943951023931953, 0.8377580409572781}, 
    {2.0943951023931953, 0.7330382858376183}, {1.9896753472735356, \
0.7330382858376183}}], 
  Line[{{1.9896753472735356, 0.8377580409572781}, {1.9896753472735356, \
0.9424777960769379}, {2.0943951023931953, 0.9424777960769379}, 
    {2.0943951023931953, 0.8377580409572781}, {1.9896753472735356, \
0.8377580409572781}}], 
  Line[{{1.9896753472735356, 0.9424777960769379}, {1.9896753472735356, \
1.0471975511965976}, {2.0943951023931953, 1.0471975511965976}, 
    {2.0943951023931953, 0.9424777960769379}, {1.9896753472735356, \
0.9424777960769379}}], 
  Line[{{1.9896753472735356, 1.0471975511965976}, {1.9896753472735356, \
1.1519173063162573}, {2.0943951023931953, 1.1519173063162573}, 
    {2.0943951023931953, 1.0471975511965976}, {1.9896753472735356, \
1.0471975511965976}}], 
  Line[{{1.9896753472735356, 1.1519173063162573}, {1.9896753472735356, \
1.2566370614359172}, {2.0943951023931953, 1.2566370614359172}, 
    {2.0943951023931953, 1.1519173063162573}, {1.9896753472735356, \
1.1519173063162573}}], 
  Line[{{1.9896753472735356, 1.2566370614359172}, {1.9896753472735356, \
1.361356816555577}, {2.0943951023931953, 1.361356816555577}, 
    {2.0943951023931953, 1.2566370614359172}, {1.9896753472735356, \
1.2566370614359172}}], 
  Line[{{1.9896753472735356, 1.361356816555577}, {1.9896753472735356, \
1.4660765716752366}, {2.0943951023931953, 1.4660765716752366}, 
    {2.0943951023931953, 1.361356816555577}, {1.9896753472735356, \
1.361356816555577}}], 
  Line[{{1.9896753472735356, 1.4660765716752366}, {1.9896753472735356, \
1.5707963267948966}, {2.0943951023931953, 1.5707963267948966}, 
    {2.0943951023931953, 1.4660765716752366}, {1.9896753472735356, \
1.4660765716752366}}], 
  Line[{{1.9896753472735356, 1.5707963267948966}, {1.9896753472735356, \
1.6755160819145563}, {2.0943951023931953, 1.6755160819145563}, 
    {2.0943951023931953, 1.5707963267948966}, {1.9896753472735356, \
1.5707963267948966}}], 
  Line[{{1.9896753472735356, 1.6755160819145563}, {1.9896753472735356, \
1.780235837034216}, {2.0943951023931953, 1.780235837034216}, 
    {2.0943951023931953, 1.6755160819145563}, {1.9896753472735356, \
1.6755160819145563}}], 
  Line[{{1.9896753472735356, 1.780235837034216}, {1.9896753472735356, \
1.8849555921538759}, {2.0943951023931953, 1.8849555921538759}, 
    {2.0943951023931953, 1.780235837034216}, {1.9896753472735356, \
1.780235837034216}}], 
  Line[{{1.9896753472735356, 1.8849555921538759}, {1.9896753472735356, \
1.9896753472735356}, {2.0943951023931953, 1.9896753472735356}, 
    {2.0943951023931953, 1.8849555921538759}, {1.9896753472735356, \
1.8849555921538759}}], 
  Line[{{1.9896753472735356, 1.9896753472735356}, {1.9896753472735356, \
2.0943951023931953}, {2.0943951023931953, 2.0943951023931953}, 
    {2.0943951023931953, 1.9896753472735356}, {1.9896753472735356, \
1.9896753472735356}}], 
  Line[{{1.9896753472735356, 2.0943951023931953}, {1.9896753472735356, \
2.199114857512855}, {2.0943951023931953, 2.199114857512855}, 
    {2.0943951023931953, 2.0943951023931953}, {1.9896753472735356, \
2.0943951023931953}}], 
  Line[{{1.9896753472735356, 2.199114857512855}, {1.9896753472735356, \
2.3038346126325147}, {2.0943951023931953, 2.3038346126325147}, 
    {2.0943951023931953, 2.199114857512855}, {1.9896753472735356, \
2.199114857512855}}], 
  Line[{{1.9896753472735356, 2.3038346126325147}, {1.9896753472735356, \
2.4085543677521746}, {2.0943951023931953, 2.4085543677521746}, 
    {2.0943951023931953, 2.3038346126325147}, {1.9896753472735356, \
2.3038346126325147}}], 
  Line[{{1.9896753472735356, 2.4085543677521746}, {1.9896753472735356, \
2.5132741228718345}, {2.0943951023931953, 2.5132741228718345}, 
    {2.0943951023931953, 2.4085543677521746}, {1.9896753472735356, \
2.4085543677521746}}], 
  Line[{{1.9896753472735356, 2.5132741228718345}, {1.9896753472735356, \
2.617993877991494}, {2.0943951023931953, 2.617993877991494}, 
    {2.0943951023931953, 2.5132741228718345}, {1.9896753472735356, \
2.5132741228718345}}], 
  Line[{{1.9896753472735356, 2.617993877991494}, {1.9896753472735356, \
2.722713633111154}, {2.0943951023931953, 2.722713633111154}, 
    {2.0943951023931953, 2.617993877991494}, {1.9896753472735356, \
2.617993877991494}}], 
  Line[{{1.9896753472735356, 2.722713633111154}, {1.9896753472735356, \
2.827433388230814}, {2.0943951023931953, 2.827433388230814}, 
    {2.0943951023931953, 2.722713633111154}, {1.9896753472735356, \
2.722713633111154}}], 
  Line[{{1.9896753472735356, 2.827433388230814}, {1.9896753472735356, \
2.9321531433504733}, {2.0943951023931953, 2.9321531433504733}, 
    {2.0943951023931953, 2.827433388230814}, {1.9896753472735356, \
2.827433388230814}}], 
  Line[{{1.9896753472735356, 2.9321531433504733}, {1.9896753472735356, \
3.036872898470133}, {2.0943951023931953, 3.036872898470133}, 
    {2.0943951023931953, 2.9321531433504733}, {1.9896753472735356, \
2.9321531433504733}}], 
  Line[{{1.9896753472735356, 3.036872898470133}, {1.9896753472735356, \
3.141592653589793}, {2.0943951023931953, 3.141592653589793}, 
    {2.0943951023931953, 3.036872898470133}, {1.9896753472735356, \
3.036872898470133}}], 
  Line[{{1.9896753472735356, 3.141592653589793}, {1.9896753472735356, \
3.2463124087094526}, {2.0943951023931953, 3.2463124087094526}, 
    {2.0943951023931953, 3.141592653589793}, {1.9896753472735356, \
3.141592653589793}}], 
  Line[{{1.9896753472735356, 3.2463124087094526}, {1.9896753472735356, \
3.3510321638291125}, {2.0943951023931953, 3.3510321638291125}, 
    {2.0943951023931953, 3.2463124087094526}, {1.9896753472735356, \
3.2463124087094526}}], 
  Line[{{1.9896753472735356, 3.3510321638291125}, {1.9896753472735356, \
3.4557519189487724}, {2.0943951023931953, 3.4557519189487724}, 
    {2.0943951023931953, 3.3510321638291125}, {1.9896753472735356, \
3.3510321638291125}}], 
  Line[{{1.9896753472735356, 3.4557519189487724}, {1.9896753472735356, \
3.560471674068432}, {2.0943951023931953, 3.560471674068432}, 
    {2.0943951023931953, 3.4557519189487724}, {1.9896753472735356, \
3.4557519189487724}}], 
  Line[{{1.9896753472735356, 3.560471674068432}, {1.9896753472735356, \
3.665191429188092}, {2.0943951023931953, 3.665191429188092}, 
    {2.0943951023931953, 3.560471674068432}, {1.9896753472735356, \
3.560471674068432}}], 
  Line[{{1.9896753472735356, 3.665191429188092}, {1.9896753472735356, \
3.7699111843077517}, {2.0943951023931953, 3.7699111843077517}, 
    {2.0943951023931953, 3.665191429188092}, {1.9896753472735356, \
3.665191429188092}}], 
  Line[{{1.9896753472735356, 3.7699111843077517}, {1.9896753472735356, \
3.874630939427411}, {2.0943951023931953, 3.874630939427411}, 
    {2.0943951023931953, 3.7699111843077517}, {1.9896753472735356, \
3.7699111843077517}}], 
  Line[{{1.9896753472735356, 3.874630939427411}, {1.9896753472735356, \
3.979350694547071}, {2.0943951023931953, 3.979350694547071}, 
    {2.0943951023931953, 3.874630939427411}, {1.9896753472735356, \
3.874630939427411}}], 
  Line[{{1.9896753472735356, 3.979350694547071}, {1.9896753472735356, \
4.084070449666731}, {2.0943951023931953, 4.084070449666731}, 
    {2.0943951023931953, 3.979350694547071}, {1.9896753472735356, \
3.979350694547071}}], 
  Line[{{1.9896753472735356, 4.084070449666731}, {1.9896753472735356, \
4.1887902047863905}, {2.0943951023931953, 4.1887902047863905}, 
    {2.0943951023931953, 4.084070449666731}, {1.9896753472735356, \
4.084070449666731}}], 
  Line[{{1.9896753472735356, 4.1887902047863905}, {1.9896753472735356, \
4.29350995990605}, {2.0943951023931953, 4.29350995990605}, 
    {2.0943951023931953, 4.1887902047863905}, {1.9896753472735356, \
4.1887902047863905}}], 
  Line[{{1.9896753472735356, 4.29350995990605}, {1.9896753472735356, \
4.39822971502571}, {2.0943951023931953, 4.39822971502571}, 
    {2.0943951023931953, 4.29350995990605}, {1.9896753472735356, \
4.29350995990605}}], 
  Line[{{1.9896753472735356, 4.39822971502571}, {1.9896753472735356, \
4.50294947014537}, {2.0943951023931953, 4.50294947014537}, 
    {2.0943951023931953, 4.39822971502571}, {1.9896753472735356, \
4.39822971502571}}], 
  Line[{{1.9896753472735356, 4.50294947014537}, {1.9896753472735356, \
4.607669225265029}, {2.0943951023931953, 4.607669225265029}, 
    {2.0943951023931953, 4.50294947014537}, {1.9896753472735356, \
4.50294947014537}}], 
  Line[{{1.9896753472735356, 4.607669225265029}, {1.9896753472735356, \
4.71238898038469}, {2.0943951023931953, 4.71238898038469}, 
    {2.0943951023931953, 4.607669225265029}, {1.9896753472735356, \
4.607669225265029}}], 
  Line[{{1.9896753472735356, 4.71238898038469}, {1.9896753472735356, \
4.817108735504349}, {2.0943951023931953, 4.817108735504349}, 
    {2.0943951023931953, 4.71238898038469}, {1.9896753472735356, \
4.71238898038469}}], 
  Line[{{1.9896753472735356, 4.817108735504349}, {1.9896753472735356, \
4.921828490624009}, {2.0943951023931953, 4.921828490624009}, 
    {2.0943951023931953, 4.817108735504349}, {1.9896753472735356, \
4.817108735504349}}], 
  Line[{{1.9896753472735356, 4.921828490624009}, {1.9896753472735356, \
5.026548245743669}, {2.0943951023931953, 5.026548245743669}, 
    {2.0943951023931953, 4.921828490624009}, {1.9896753472735356, \
4.921828490624009}}], 
  Line[{{1.9896753472735356, 5.026548245743669}, {1.9896753472735356, \
5.1312680008633285}, {2.0943951023931953, 5.1312680008633285}, 
    {2.0943951023931953, 5.026548245743669}, {1.9896753472735356, \
5.026548245743669}}], 
  Line[{{1.9896753472735356, 5.1312680008633285}, {1.9896753472735356, \
5.235987755982988}, {2.0943951023931953, 5.235987755982988}, 
    {2.0943951023931953, 5.1312680008633285}, {1.9896753472735356, \
5.1312680008633285}}], 
  Line[{{1.9896753472735356, 5.235987755982988}, {1.9896753472735356, \
5.340707511102648}, {2.0943951023931953, 5.340707511102648}, 
    {2.0943951023931953, 5.235987755982988}, {1.9896753472735356, \
5.235987755982988}}], 
  Line[{{1.9896753472735356, 5.340707511102648}, {1.9896753472735356, \
5.445427266222308}, {2.0943951023931953, 5.445427266222308}, 
    {2.0943951023931953, 5.340707511102648}, {1.9896753472735356, \
5.340707511102648}}], 
  Line[{{1.9896753472735356, 5.445427266222308}, {1.9896753472735356, \
5.550147021341967}, {2.0943951023931953, 5.550147021341967}, 
    {2.0943951023931953, 5.445427266222308}, {1.9896753472735356, \
5.445427266222308}}], 
  Line[{{1.9896753472735356, 5.550147021341967}, {1.9896753472735356, \
5.654866776461628}, {2.0943951023931953, 5.654866776461628}, 
    {2.0943951023931953, 5.550147021341967}, {1.9896753472735356, \
5.550147021341967}}], 
  Line[{{1.9896753472735356, 5.654866776461628}, {1.9896753472735356, \
5.759586531581287}, {2.0943951023931953, 5.759586531581287}, 
    {2.0943951023931953, 5.654866776461628}, {1.9896753472735356, \
5.654866776461628}}], 
  Line[{{1.9896753472735356, 5.759586531581287}, {1.9896753472735356, \
5.864306286700947}, {2.0943951023931953, 5.864306286700947}, 
    {2.0943951023931953, 5.759586531581287}, {1.9896753472735356, \
5.759586531581287}}], 
  Line[{{1.9896753472735356, 5.864306286700947}, {1.9896753472735356, \
5.969026041820607}, {2.0943951023931953, 5.969026041820607}, 
    {2.0943951023931953, 5.864306286700947}, {1.9896753472735356, \
5.864306286700947}}], 
  Line[{{1.9896753472735356, 5.969026041820607}, {1.9896753472735356, \
6.073745796940266}, {2.0943951023931953, 6.073745796940266}, 
    {2.0943951023931953, 5.969026041820607}, {1.9896753472735356, \
5.969026041820607}}], 
  Line[{{1.9896753472735356, 6.073745796940266}, {1.9896753472735356, \
6.178465552059926}, {2.0943951023931953, 6.178465552059926}, 
    {2.0943951023931953, 6.073745796940266}, {1.9896753472735356, \
6.073745796940266}}], 
  Line[{{1.9896753472735356, 6.178465552059926}, {1.9896753472735356, \
6.283185307179586}, {2.0943951023931953, 6.283185307179586}, 
    {2.0943951023931953, 6.178465552059926}, {1.9896753472735356, \
6.178465552059926}}], 
  Line[{{2.0943951023931953, 0.}, {2.0943951023931953, 0.10471975511965977}, \
{2.199114857512855, 0.10471975511965977}, {2.199114857512855, 0.}, 
    {2.0943951023931953, 0.}}], Line[{{2.0943951023931953, \
0.10471975511965977}, {2.0943951023931953, 0.20943951023931953}, 
    {2.199114857512855, 0.20943951023931953}, {2.199114857512855, \
0.10471975511965977}, {2.0943951023931953, 0.10471975511965977}}], 
  Line[{{2.0943951023931953, 0.20943951023931953}, {2.0943951023931953, \
0.3141592653589793}, {2.199114857512855, 0.3141592653589793}, 
    {2.199114857512855, 0.20943951023931953}, {2.0943951023931953, \
0.20943951023931953}}], 
  Line[{{2.0943951023931953, 0.3141592653589793}, {2.0943951023931953, \
0.41887902047863906}, {2.199114857512855, 0.41887902047863906}, 
    {2.199114857512855, 0.3141592653589793}, {2.0943951023931953, \
0.3141592653589793}}], 
  Line[{{2.0943951023931953, 0.41887902047863906}, {2.0943951023931953, \
0.5235987755982988}, {2.199114857512855, 0.5235987755982988}, 
    {2.199114857512855, 0.41887902047863906}, {2.0943951023931953, \
0.41887902047863906}}], 
  Line[{{2.0943951023931953, 0.5235987755982988}, {2.0943951023931953, \
0.6283185307179586}, {2.199114857512855, 0.6283185307179586}, 
    {2.199114857512855, 0.5235987755982988}, {2.0943951023931953, \
0.5235987755982988}}], 
  Line[{{2.0943951023931953, 0.6283185307179586}, {2.0943951023931953, \
0.7330382858376183}, {2.199114857512855, 0.7330382858376183}, 
    {2.199114857512855, 0.6283185307179586}, {2.0943951023931953, \
0.6283185307179586}}], 
  Line[{{2.0943951023931953, 0.7330382858376183}, {2.0943951023931953, \
0.8377580409572781}, {2.199114857512855, 0.8377580409572781}, 
    {2.199114857512855, 0.7330382858376183}, {2.0943951023931953, \
0.7330382858376183}}], 
  Line[{{2.0943951023931953, 0.8377580409572781}, {2.0943951023931953, \
0.9424777960769379}, {2.199114857512855, 0.9424777960769379}, 
    {2.199114857512855, 0.8377580409572781}, {2.0943951023931953, \
0.8377580409572781}}], 
  Line[{{2.0943951023931953, 0.9424777960769379}, {2.0943951023931953, \
1.0471975511965976}, {2.199114857512855, 1.0471975511965976}, 
    {2.199114857512855, 0.9424777960769379}, {2.0943951023931953, \
0.9424777960769379}}], 
  Line[{{2.0943951023931953, 1.0471975511965976}, {2.0943951023931953, \
1.1519173063162573}, {2.199114857512855, 1.1519173063162573}, 
    {2.199114857512855, 1.0471975511965976}, {2.0943951023931953, \
1.0471975511965976}}], 
  Line[{{2.0943951023931953, 1.1519173063162573}, {2.0943951023931953, \
1.2566370614359172}, {2.199114857512855, 1.2566370614359172}, 
    {2.199114857512855, 1.1519173063162573}, {2.0943951023931953, \
1.1519173063162573}}], 
  Line[{{2.0943951023931953, 1.2566370614359172}, {2.0943951023931953, \
1.361356816555577}, {2.199114857512855, 1.361356816555577}, 
    {2.199114857512855, 1.2566370614359172}, {2.0943951023931953, \
1.2566370614359172}}], 
  Line[{{2.0943951023931953, 1.361356816555577}, {2.0943951023931953, \
1.4660765716752366}, {2.199114857512855, 1.4660765716752366}, 
    {2.199114857512855, 1.361356816555577}, {2.0943951023931953, \
1.361356816555577}}], 
  Line[{{2.0943951023931953, 1.4660765716752366}, {2.0943951023931953, \
1.5707963267948966}, {2.199114857512855, 1.5707963267948966}, 
    {2.199114857512855, 1.4660765716752366}, {2.0943951023931953, \
1.4660765716752366}}], 
  Line[{{2.0943951023931953, 1.5707963267948966}, {2.0943951023931953, \
1.6755160819145563}, {2.199114857512855, 1.6755160819145563}, 
    {2.199114857512855, 1.5707963267948966}, {2.0943951023931953, \
1.5707963267948966}}], 
  Line[{{2.0943951023931953, 1.6755160819145563}, {2.0943951023931953, \
1.780235837034216}, {2.199114857512855, 1.780235837034216}, 
    {2.199114857512855, 1.6755160819145563}, {2.0943951023931953, \
1.6755160819145563}}], 
  Line[{{2.0943951023931953, 1.780235837034216}, {2.0943951023931953, \
1.8849555921538759}, {2.199114857512855, 1.8849555921538759}, 
    {2.199114857512855, 1.780235837034216}, {2.0943951023931953, \
1.780235837034216}}], 
  Line[{{2.0943951023931953, 1.8849555921538759}, {2.0943951023931953, \
1.9896753472735356}, {2.199114857512855, 1.9896753472735356}, 
    {2.199114857512855, 1.8849555921538759}, {2.0943951023931953, \
1.8849555921538759}}], 
  Line[{{2.0943951023931953, 1.9896753472735356}, {2.0943951023931953, \
2.0943951023931953}, {2.199114857512855, 2.0943951023931953}, 
    {2.199114857512855, 1.9896753472735356}, {2.0943951023931953, \
1.9896753472735356}}], 
  Line[{{2.0943951023931953, 2.0943951023931953}, {2.0943951023931953, \
2.199114857512855}, {2.199114857512855, 2.199114857512855}, 
    {2.199114857512855, 2.0943951023931953}, {2.0943951023931953, \
2.0943951023931953}}], 
  Line[{{2.0943951023931953, 2.199114857512855}, {2.0943951023931953, \
2.3038346126325147}, {2.199114857512855, 2.3038346126325147}, 
    {2.199114857512855, 2.199114857512855}, {2.0943951023931953, \
2.199114857512855}}], 
  Line[{{2.0943951023931953, 2.3038346126325147}, {2.0943951023931953, \
2.4085543677521746}, {2.199114857512855, 2.4085543677521746}, 
    {2.199114857512855, 2.3038346126325147}, {2.0943951023931953, \
2.3038346126325147}}], 
  Line[{{2.0943951023931953, 2.4085543677521746}, {2.0943951023931953, \
2.5132741228718345}, {2.199114857512855, 2.5132741228718345}, 
    {2.199114857512855, 2.4085543677521746}, {2.0943951023931953, \
2.4085543677521746}}], 
  Line[{{2.0943951023931953, 2.5132741228718345}, {2.0943951023931953, \
2.617993877991494}, {2.199114857512855, 2.617993877991494}, 
    {2.199114857512855, 2.5132741228718345}, {2.0943951023931953, \
2.5132741228718345}}], 
  Line[{{2.0943951023931953, 2.617993877991494}, {2.0943951023931953, \
2.722713633111154}, {2.199114857512855, 2.722713633111154}, 
    {2.199114857512855, 2.617993877991494}, {2.0943951023931953, \
2.617993877991494}}], 
  Line[{{2.0943951023931953, 2.722713633111154}, {2.0943951023931953, \
2.827433388230814}, {2.199114857512855, 2.827433388230814}, 
    {2.199114857512855, 2.722713633111154}, {2.0943951023931953, \
2.722713633111154}}], 
  Line[{{2.0943951023931953, 2.827433388230814}, {2.0943951023931953, \
2.9321531433504733}, {2.199114857512855, 2.9321531433504733}, 
    {2.199114857512855, 2.827433388230814}, {2.0943951023931953, \
2.827433388230814}}], 
  Line[{{2.0943951023931953, 2.9321531433504733}, {2.0943951023931953, \
3.036872898470133}, {2.199114857512855, 3.036872898470133}, 
    {2.199114857512855, 2.9321531433504733}, {2.0943951023931953, \
2.9321531433504733}}], 
  Line[{{2.0943951023931953, 3.036872898470133}, {2.0943951023931953, \
3.141592653589793}, {2.199114857512855, 3.141592653589793}, 
    {2.199114857512855, 3.036872898470133}, {2.0943951023931953, \
3.036872898470133}}], 
  Line[{{2.0943951023931953, 3.141592653589793}, {2.0943951023931953, \
3.2463124087094526}, {2.199114857512855, 3.2463124087094526}, 
    {2.199114857512855, 3.141592653589793}, {2.0943951023931953, \
3.141592653589793}}], 
  Line[{{2.0943951023931953, 3.2463124087094526}, {2.0943951023931953, \
3.3510321638291125}, {2.199114857512855, 3.3510321638291125}, 
    {2.199114857512855, 3.2463124087094526}, {2.0943951023931953, \
3.2463124087094526}}], 
  Line[{{2.0943951023931953, 3.3510321638291125}, {2.0943951023931953, \
3.4557519189487724}, {2.199114857512855, 3.4557519189487724}, 
    {2.199114857512855, 3.3510321638291125}, {2.0943951023931953, \
3.3510321638291125}}], 
  Line[{{2.0943951023931953, 3.4557519189487724}, {2.0943951023931953, \
3.560471674068432}, {2.199114857512855, 3.560471674068432}, 
    {2.199114857512855, 3.4557519189487724}, {2.0943951023931953, \
3.4557519189487724}}], 
  Line[{{2.0943951023931953, 3.560471674068432}, {2.0943951023931953, \
3.665191429188092}, {2.199114857512855, 3.665191429188092}, 
    {2.199114857512855, 3.560471674068432}, {2.0943951023931953, \
3.560471674068432}}], 
  Line[{{2.0943951023931953, 3.665191429188092}, {2.0943951023931953, \
3.7699111843077517}, {2.199114857512855, 3.7699111843077517}, 
    {2.199114857512855, 3.665191429188092}, {2.0943951023931953, \
3.665191429188092}}], 
  Line[{{2.0943951023931953, 3.7699111843077517}, {2.0943951023931953, \
3.874630939427411}, {2.199114857512855, 3.874630939427411}, 
    {2.199114857512855, 3.7699111843077517}, {2.0943951023931953, \
3.7699111843077517}}], 
  Line[{{2.0943951023931953, 3.874630939427411}, {2.0943951023931953, \
3.979350694547071}, {2.199114857512855, 3.979350694547071}, 
    {2.199114857512855, 3.874630939427411}, {2.0943951023931953, \
3.874630939427411}}], 
  Line[{{2.0943951023931953, 3.979350694547071}, {2.0943951023931953, \
4.084070449666731}, {2.199114857512855, 4.084070449666731}, 
    {2.199114857512855, 3.979350694547071}, {2.0943951023931953, \
3.979350694547071}}], 
  Line[{{2.0943951023931953, 4.084070449666731}, {2.0943951023931953, \
4.1887902047863905}, {2.199114857512855, 4.1887902047863905}, 
    {2.199114857512855, 4.084070449666731}, {2.0943951023931953, \
4.084070449666731}}], 
  Line[{{2.0943951023931953, 4.1887902047863905}, {2.0943951023931953, \
4.29350995990605}, {2.199114857512855, 4.29350995990605}, 
    {2.199114857512855, 4.1887902047863905}, {2.0943951023931953, \
4.1887902047863905}}], 
  Line[{{2.0943951023931953, 4.29350995990605}, {2.0943951023931953, \
4.39822971502571}, {2.199114857512855, 4.39822971502571}, 
    {2.199114857512855, 4.29350995990605}, {2.0943951023931953, \
4.29350995990605}}], 
  Line[{{2.0943951023931953, 4.39822971502571}, {2.0943951023931953, \
4.50294947014537}, {2.199114857512855, 4.50294947014537}, 
    {2.199114857512855, 4.39822971502571}, {2.0943951023931953, \
4.39822971502571}}], 
  Line[{{2.0943951023931953, 4.50294947014537}, {2.0943951023931953, \
4.607669225265029}, {2.199114857512855, 4.607669225265029}, 
    {2.199114857512855, 4.50294947014537}, {2.0943951023931953, \
4.50294947014537}}], 
  Line[{{2.0943951023931953, 4.607669225265029}, {2.0943951023931953, \
4.71238898038469}, {2.199114857512855, 4.71238898038469}, 
    {2.199114857512855, 4.607669225265029}, {2.0943951023931953, \
4.607669225265029}}], 
  Line[{{2.0943951023931953, 4.71238898038469}, {2.0943951023931953, \
4.817108735504349}, {2.199114857512855, 4.817108735504349}, 
    {2.199114857512855, 4.71238898038469}, {2.0943951023931953, \
4.71238898038469}}], 
  Line[{{2.0943951023931953, 4.817108735504349}, {2.0943951023931953, \
4.921828490624009}, {2.199114857512855, 4.921828490624009}, 
    {2.199114857512855, 4.817108735504349}, {2.0943951023931953, \
4.817108735504349}}], 
  Line[{{2.0943951023931953, 4.921828490624009}, {2.0943951023931953, \
5.026548245743669}, {2.199114857512855, 5.026548245743669}, 
    {2.199114857512855, 4.921828490624009}, {2.0943951023931953, \
4.921828490624009}}], 
  Line[{{2.0943951023931953, 5.026548245743669}, {2.0943951023931953, \
5.1312680008633285}, {2.199114857512855, 5.1312680008633285}, 
    {2.199114857512855, 5.026548245743669}, {2.0943951023931953, \
5.026548245743669}}], 
  Line[{{2.0943951023931953, 5.1312680008633285}, {2.0943951023931953, \
5.235987755982988}, {2.199114857512855, 5.235987755982988}, 
    {2.199114857512855, 5.1312680008633285}, {2.0943951023931953, \
5.1312680008633285}}], 
  Line[{{2.0943951023931953, 5.235987755982988}, {2.0943951023931953, \
5.340707511102648}, {2.199114857512855, 5.340707511102648}, 
    {2.199114857512855, 5.235987755982988}, {2.0943951023931953, \
5.235987755982988}}], 
  Line[{{2.0943951023931953, 5.340707511102648}, {2.0943951023931953, \
5.445427266222308}, {2.199114857512855, 5.445427266222308}, 
    {2.199114857512855, 5.340707511102648}, {2.0943951023931953, \
5.340707511102648}}], 
  Line[{{2.0943951023931953, 5.445427266222308}, {2.0943951023931953, \
5.550147021341967}, {2.199114857512855, 5.550147021341967}, 
    {2.199114857512855, 5.445427266222308}, {2.0943951023931953, \
5.445427266222308}}], 
  Line[{{2.0943951023931953, 5.550147021341967}, {2.0943951023931953, \
5.654866776461628}, {2.199114857512855, 5.654866776461628}, 
    {2.199114857512855, 5.550147021341967}, {2.0943951023931953, \
5.550147021341967}}], 
  Line[{{2.0943951023931953, 5.654866776461628}, {2.0943951023931953, \
5.759586531581287}, {2.199114857512855, 5.759586531581287}, 
    {2.199114857512855, 5.654866776461628}, {2.0943951023931953, \
5.654866776461628}}], 
  Line[{{2.0943951023931953, 5.759586531581287}, {2.0943951023931953, \
5.864306286700947}, {2.199114857512855, 5.864306286700947}, 
    {2.199114857512855, 5.759586531581287}, {2.0943951023931953, \
5.759586531581287}}], 
  Line[{{2.0943951023931953, 5.864306286700947}, {2.0943951023931953, \
5.969026041820607}, {2.199114857512855, 5.969026041820607}, 
    {2.199114857512855, 5.864306286700947}, {2.0943951023931953, \
5.864306286700947}}], 
  Line[{{2.0943951023931953, 5.969026041820607}, {2.0943951023931953, \
6.073745796940266}, {2.199114857512855, 6.073745796940266}, 
    {2.199114857512855, 5.969026041820607}, {2.0943951023931953, \
5.969026041820607}}], 
  Line[{{2.0943951023931953, 6.073745796940266}, {2.0943951023931953, \
6.178465552059926}, {2.199114857512855, 6.178465552059926}, 
    {2.199114857512855, 6.073745796940266}, {2.0943951023931953, \
6.073745796940266}}], 
  Line[{{2.0943951023931953, 6.178465552059926}, {2.0943951023931953, \
6.283185307179586}, {2.199114857512855, 6.283185307179586}, 
    {2.199114857512855, 6.178465552059926}, {2.0943951023931953, \
6.178465552059926}}], 
  Line[{{2.199114857512855, 0.}, {2.199114857512855, 0.10471975511965977}, \
{2.3038346126325147, 0.10471975511965977}, {2.3038346126325147, 0.}, 
    {2.199114857512855, 0.}}], Line[{{2.199114857512855, \
0.10471975511965977}, {2.199114857512855, 0.20943951023931953}, 
    {2.3038346126325147, 0.20943951023931953}, {2.3038346126325147, \
0.10471975511965977}, {2.199114857512855, 0.10471975511965977}}], 
  Line[{{2.199114857512855, 0.20943951023931953}, {2.199114857512855, \
0.3141592653589793}, {2.3038346126325147, 0.3141592653589793}, 
    {2.3038346126325147, 0.20943951023931953}, {2.199114857512855, \
0.20943951023931953}}], 
  Line[{{2.199114857512855, 0.3141592653589793}, {2.199114857512855, \
0.41887902047863906}, {2.3038346126325147, 0.41887902047863906}, 
    {2.3038346126325147, 0.3141592653589793}, {2.199114857512855, \
0.3141592653589793}}], 
  Line[{{2.199114857512855, 0.41887902047863906}, {2.199114857512855, \
0.5235987755982988}, {2.3038346126325147, 0.5235987755982988}, 
    {2.3038346126325147, 0.41887902047863906}, {2.199114857512855, \
0.41887902047863906}}], 
  Line[{{2.199114857512855, 0.5235987755982988}, {2.199114857512855, \
0.6283185307179586}, {2.3038346126325147, 0.6283185307179586}, 
    {2.3038346126325147, 0.5235987755982988}, {2.199114857512855, \
0.5235987755982988}}], 
  Line[{{2.199114857512855, 0.6283185307179586}, {2.199114857512855, \
0.7330382858376183}, {2.3038346126325147, 0.7330382858376183}, 
    {2.3038346126325147, 0.6283185307179586}, {2.199114857512855, \
0.6283185307179586}}], 
  Line[{{2.199114857512855, 0.7330382858376183}, {2.199114857512855, \
0.8377580409572781}, {2.3038346126325147, 0.8377580409572781}, 
    {2.3038346126325147, 0.7330382858376183}, {2.199114857512855, \
0.7330382858376183}}], 
  Line[{{2.199114857512855, 0.8377580409572781}, {2.199114857512855, \
0.9424777960769379}, {2.3038346126325147, 0.9424777960769379}, 
    {2.3038346126325147, 0.8377580409572781}, {2.199114857512855, \
0.8377580409572781}}], 
  Line[{{2.199114857512855, 0.9424777960769379}, {2.199114857512855, \
1.0471975511965976}, {2.3038346126325147, 1.0471975511965976}, 
    {2.3038346126325147, 0.9424777960769379}, {2.199114857512855, \
0.9424777960769379}}], 
  Line[{{2.199114857512855, 1.0471975511965976}, {2.199114857512855, \
1.1519173063162573}, {2.3038346126325147, 1.1519173063162573}, 
    {2.3038346126325147, 1.0471975511965976}, {2.199114857512855, \
1.0471975511965976}}], 
  Line[{{2.199114857512855, 1.1519173063162573}, {2.199114857512855, \
1.2566370614359172}, {2.3038346126325147, 1.2566370614359172}, 
    {2.3038346126325147, 1.1519173063162573}, {2.199114857512855, \
1.1519173063162573}}], 
  Line[{{2.199114857512855, 1.2566370614359172}, {2.199114857512855, \
1.361356816555577}, {2.3038346126325147, 1.361356816555577}, 
    {2.3038346126325147, 1.2566370614359172}, {2.199114857512855, \
1.2566370614359172}}], 
  Line[{{2.199114857512855, 1.361356816555577}, {2.199114857512855, \
1.4660765716752366}, {2.3038346126325147, 1.4660765716752366}, 
    {2.3038346126325147, 1.361356816555577}, {2.199114857512855, \
1.361356816555577}}], 
  Line[{{2.199114857512855, 1.4660765716752366}, {2.199114857512855, \
1.5707963267948966}, {2.3038346126325147, 1.5707963267948966}, 
    {2.3038346126325147, 1.4660765716752366}, {2.199114857512855, \
1.4660765716752366}}], 
  Line[{{2.199114857512855, 1.5707963267948966}, {2.199114857512855, \
1.6755160819145563}, {2.3038346126325147, 1.6755160819145563}, 
    {2.3038346126325147, 1.5707963267948966}, {2.199114857512855, \
1.5707963267948966}}], 
  Line[{{2.199114857512855, 1.6755160819145563}, {2.199114857512855, \
1.780235837034216}, {2.3038346126325147, 1.780235837034216}, 
    {2.3038346126325147, 1.6755160819145563}, {2.199114857512855, \
1.6755160819145563}}], 
  Line[{{2.199114857512855, 1.780235837034216}, {2.199114857512855, \
1.8849555921538759}, {2.3038346126325147, 1.8849555921538759}, 
    {2.3038346126325147, 1.780235837034216}, {2.199114857512855, \
1.780235837034216}}], 
  Line[{{2.199114857512855, 1.8849555921538759}, {2.199114857512855, \
1.9896753472735356}, {2.3038346126325147, 1.9896753472735356}, 
    {2.3038346126325147, 1.8849555921538759}, {2.199114857512855, \
1.8849555921538759}}], 
  Line[{{2.199114857512855, 1.9896753472735356}, {2.199114857512855, \
2.0943951023931953}, {2.3038346126325147, 2.0943951023931953}, 
    {2.3038346126325147, 1.9896753472735356}, {2.199114857512855, \
1.9896753472735356}}], 
  Line[{{2.199114857512855, 2.0943951023931953}, {2.199114857512855, \
2.199114857512855}, {2.3038346126325147, 2.199114857512855}, 
    {2.3038346126325147, 2.0943951023931953}, {2.199114857512855, \
2.0943951023931953}}], 
  Line[{{2.199114857512855, 2.199114857512855}, {2.199114857512855, \
2.3038346126325147}, {2.3038346126325147, 2.3038346126325147}, 
    {2.3038346126325147, 2.199114857512855}, {2.199114857512855, \
2.199114857512855}}], 
  Line[{{2.199114857512855, 2.3038346126325147}, {2.199114857512855, \
2.4085543677521746}, {2.3038346126325147, 2.4085543677521746}, 
    {2.3038346126325147, 2.3038346126325147}, {2.199114857512855, \
2.3038346126325147}}], 
  Line[{{2.199114857512855, 2.4085543677521746}, {2.199114857512855, \
2.5132741228718345}, {2.3038346126325147, 2.5132741228718345}, 
    {2.3038346126325147, 2.4085543677521746}, {2.199114857512855, \
2.4085543677521746}}], 
  Line[{{2.199114857512855, 2.5132741228718345}, {2.199114857512855, \
2.617993877991494}, {2.3038346126325147, 2.617993877991494}, 
    {2.3038346126325147, 2.5132741228718345}, {2.199114857512855, \
2.5132741228718345}}], 
  Line[{{2.199114857512855, 2.617993877991494}, {2.199114857512855, \
2.722713633111154}, {2.3038346126325147, 2.722713633111154}, 
    {2.3038346126325147, 2.617993877991494}, {2.199114857512855, \
2.617993877991494}}], 
  Line[{{2.199114857512855, 2.722713633111154}, {2.199114857512855, \
2.827433388230814}, {2.3038346126325147, 2.827433388230814}, 
    {2.3038346126325147, 2.722713633111154}, {2.199114857512855, \
2.722713633111154}}], 
  Line[{{2.199114857512855, 2.827433388230814}, {2.199114857512855, \
2.9321531433504733}, {2.3038346126325147, 2.9321531433504733}, 
    {2.3038346126325147, 2.827433388230814}, {2.199114857512855, \
2.827433388230814}}], 
  Line[{{2.199114857512855, 2.9321531433504733}, {2.199114857512855, \
3.036872898470133}, {2.3038346126325147, 3.036872898470133}, 
    {2.3038346126325147, 2.9321531433504733}, {2.199114857512855, \
2.9321531433504733}}], 
  Line[{{2.199114857512855, 3.036872898470133}, {2.199114857512855, \
3.141592653589793}, {2.3038346126325147, 3.141592653589793}, 
    {2.3038346126325147, 3.036872898470133}, {2.199114857512855, \
3.036872898470133}}], 
  Line[{{2.199114857512855, 3.141592653589793}, {2.199114857512855, \
3.2463124087094526}, {2.3038346126325147, 3.2463124087094526}, 
    {2.3038346126325147, 3.141592653589793}, {2.199114857512855, \
3.141592653589793}}], 
  Line[{{2.199114857512855, 3.2463124087094526}, {2.199114857512855, \
3.3510321638291125}, {2.3038346126325147, 3.3510321638291125}, 
    {2.3038346126325147, 3.2463124087094526}, {2.199114857512855, \
3.2463124087094526}}], 
  Line[{{2.199114857512855, 3.3510321638291125}, {2.199114857512855, \
3.4557519189487724}, {2.3038346126325147, 3.4557519189487724}, 
    {2.3038346126325147, 3.3510321638291125}, {2.199114857512855, \
3.3510321638291125}}], 
  Line[{{2.199114857512855, 3.4557519189487724}, {2.199114857512855, \
3.560471674068432}, {2.3038346126325147, 3.560471674068432}, 
    {2.3038346126325147, 3.4557519189487724}, {2.199114857512855, \
3.4557519189487724}}], 
  Line[{{2.199114857512855, 3.560471674068432}, {2.199114857512855, \
3.665191429188092}, {2.3038346126325147, 3.665191429188092}, 
    {2.3038346126325147, 3.560471674068432}, {2.199114857512855, \
3.560471674068432}}], 
  Line[{{2.199114857512855, 3.665191429188092}, {2.199114857512855, \
3.7699111843077517}, {2.3038346126325147, 3.7699111843077517}, 
    {2.3038346126325147, 3.665191429188092}, {2.199114857512855, \
3.665191429188092}}], 
  Line[{{2.199114857512855, 3.7699111843077517}, {2.199114857512855, \
3.874630939427411}, {2.3038346126325147, 3.874630939427411}, 
    {2.3038346126325147, 3.7699111843077517}, {2.199114857512855, \
3.7699111843077517}}], 
  Line[{{2.199114857512855, 3.874630939427411}, {2.199114857512855, \
3.979350694547071}, {2.3038346126325147, 3.979350694547071}, 
    {2.3038346126325147, 3.874630939427411}, {2.199114857512855, \
3.874630939427411}}], 
  Line[{{2.199114857512855, 3.979350694547071}, {2.199114857512855, \
4.084070449666731}, {2.3038346126325147, 4.084070449666731}, 
    {2.3038346126325147, 3.979350694547071}, {2.199114857512855, \
3.979350694547071}}], 
  Line[{{2.199114857512855, 4.084070449666731}, {2.199114857512855, \
4.1887902047863905}, {2.3038346126325147, 4.1887902047863905}, 
    {2.3038346126325147, 4.084070449666731}, {2.199114857512855, \
4.084070449666731}}], 
  Line[{{2.199114857512855, 4.1887902047863905}, {2.199114857512855, \
4.29350995990605}, {2.3038346126325147, 4.29350995990605}, 
    {2.3038346126325147, 4.1887902047863905}, {2.199114857512855, \
4.1887902047863905}}], 
  Line[{{2.199114857512855, 4.29350995990605}, {2.199114857512855, \
4.39822971502571}, {2.3038346126325147, 4.39822971502571}, 
    {2.3038346126325147, 4.29350995990605}, {2.199114857512855, \
4.29350995990605}}], 
  Line[{{2.199114857512855, 4.39822971502571}, {2.199114857512855, \
4.50294947014537}, {2.3038346126325147, 4.50294947014537}, 
    {2.3038346126325147, 4.39822971502571}, {2.199114857512855, \
4.39822971502571}}], 
  Line[{{2.199114857512855, 4.50294947014537}, {2.199114857512855, \
4.607669225265029}, {2.3038346126325147, 4.607669225265029}, 
    {2.3038346126325147, 4.50294947014537}, {2.199114857512855, \
4.50294947014537}}], 
  Line[{{2.199114857512855, 4.607669225265029}, {2.199114857512855, \
4.71238898038469}, {2.3038346126325147, 4.71238898038469}, 
    {2.3038346126325147, 4.607669225265029}, {2.199114857512855, \
4.607669225265029}}], 
  Line[{{2.199114857512855, 4.71238898038469}, {2.199114857512855, \
4.817108735504349}, {2.3038346126325147, 4.817108735504349}, 
    {2.3038346126325147, 4.71238898038469}, {2.199114857512855, \
4.71238898038469}}], 
  Line[{{2.199114857512855, 4.817108735504349}, {2.199114857512855, \
4.921828490624009}, {2.3038346126325147, 4.921828490624009}, 
    {2.3038346126325147, 4.817108735504349}, {2.199114857512855, \
4.817108735504349}}], 
  Line[{{2.199114857512855, 4.921828490624009}, {2.199114857512855, \
5.026548245743669}, {2.3038346126325147, 5.026548245743669}, 
    {2.3038346126325147, 4.921828490624009}, {2.199114857512855, \
4.921828490624009}}], 
  Line[{{2.199114857512855, 5.026548245743669}, {2.199114857512855, \
5.1312680008633285}, {2.3038346126325147, 5.1312680008633285}, 
    {2.3038346126325147, 5.026548245743669}, {2.199114857512855, \
5.026548245743669}}], 
  Line[{{2.199114857512855, 5.1312680008633285}, {2.199114857512855, \
5.235987755982988}, {2.3038346126325147, 5.235987755982988}, 
    {2.3038346126325147, 5.1312680008633285}, {2.199114857512855, \
5.1312680008633285}}], 
  Line[{{2.199114857512855, 5.235987755982988}, {2.199114857512855, \
5.340707511102648}, {2.3038346126325147, 5.340707511102648}, 
    {2.3038346126325147, 5.235987755982988}, {2.199114857512855, \
5.235987755982988}}], 
  Line[{{2.199114857512855, 5.340707511102648}, {2.199114857512855, \
5.445427266222308}, {2.3038346126325147, 5.445427266222308}, 
    {2.3038346126325147, 5.340707511102648}, {2.199114857512855, \
5.340707511102648}}], 
  Line[{{2.199114857512855, 5.445427266222308}, {2.199114857512855, \
5.550147021341967}, {2.3038346126325147, 5.550147021341967}, 
    {2.3038346126325147, 5.445427266222308}, {2.199114857512855, \
5.445427266222308}}], 
  Line[{{2.199114857512855, 5.550147021341967}, {2.199114857512855, \
5.654866776461628}, {2.3038346126325147, 5.654866776461628}, 
    {2.3038346126325147, 5.550147021341967}, {2.199114857512855, \
5.550147021341967}}], 
  Line[{{2.199114857512855, 5.654866776461628}, {2.199114857512855, \
5.759586531581287}, {2.3038346126325147, 5.759586531581287}, 
    {2.3038346126325147, 5.654866776461628}, {2.199114857512855, \
5.654866776461628}}], 
  Line[{{2.199114857512855, 5.759586531581287}, {2.199114857512855, \
5.864306286700947}, {2.3038346126325147, 5.864306286700947}, 
    {2.3038346126325147, 5.759586531581287}, {2.199114857512855, \
5.759586531581287}}], 
  Line[{{2.199114857512855, 5.864306286700947}, {2.199114857512855, \
5.969026041820607}, {2.3038346126325147, 5.969026041820607}, 
    {2.3038346126325147, 5.864306286700947}, {2.199114857512855, \
5.864306286700947}}], 
  Line[{{2.199114857512855, 5.969026041820607}, {2.199114857512855, \
6.073745796940266}, {2.3038346126325147, 6.073745796940266}, 
    {2.3038346126325147, 5.969026041820607}, {2.199114857512855, \
5.969026041820607}}], 
  Line[{{2.199114857512855, 6.073745796940266}, {2.199114857512855, \
6.178465552059926}, {2.3038346126325147, 6.178465552059926}, 
    {2.3038346126325147, 6.073745796940266}, {2.199114857512855, \
6.073745796940266}}], 
  Line[{{2.199114857512855, 6.178465552059926}, {2.199114857512855, \
6.283185307179586}, {2.3038346126325147, 6.283185307179586}, 
    {2.3038346126325147, 6.178465552059926}, {2.199114857512855, \
6.178465552059926}}], 
  Line[{{2.3038346126325147, 0.}, {2.3038346126325147, 0.10471975511965977}, \
{2.4085543677521746, 0.10471975511965977}, {2.4085543677521746, 0.}, 
    {2.3038346126325147, 0.}}], Line[{{2.3038346126325147, \
0.10471975511965977}, {2.3038346126325147, 0.20943951023931953}, 
    {2.4085543677521746, 0.20943951023931953}, {2.4085543677521746, \
0.10471975511965977}, {2.3038346126325147, 0.10471975511965977}}], 
  Line[{{2.3038346126325147, 0.20943951023931953}, {2.3038346126325147, \
0.3141592653589793}, {2.4085543677521746, 0.3141592653589793}, 
    {2.4085543677521746, 0.20943951023931953}, {2.3038346126325147, \
0.20943951023931953}}], 
  Line[{{2.3038346126325147, 0.3141592653589793}, {2.3038346126325147, \
0.41887902047863906}, {2.4085543677521746, 0.41887902047863906}, 
    {2.4085543677521746, 0.3141592653589793}, {2.3038346126325147, \
0.3141592653589793}}], 
  Line[{{2.3038346126325147, 0.41887902047863906}, {2.3038346126325147, \
0.5235987755982988}, {2.4085543677521746, 0.5235987755982988}, 
    {2.4085543677521746, 0.41887902047863906}, {2.3038346126325147, \
0.41887902047863906}}], 
  Line[{{2.3038346126325147, 0.5235987755982988}, {2.3038346126325147, \
0.6283185307179586}, {2.4085543677521746, 0.6283185307179586}, 
    {2.4085543677521746, 0.5235987755982988}, {2.3038346126325147, \
0.5235987755982988}}], 
  Line[{{2.3038346126325147, 0.6283185307179586}, {2.3038346126325147, \
0.7330382858376183}, {2.4085543677521746, 0.7330382858376183}, 
    {2.4085543677521746, 0.6283185307179586}, {2.3038346126325147, \
0.6283185307179586}}], 
  Line[{{2.3038346126325147, 0.7330382858376183}, {2.3038346126325147, \
0.8377580409572781}, {2.4085543677521746, 0.8377580409572781}, 
    {2.4085543677521746, 0.7330382858376183}, {2.3038346126325147, \
0.7330382858376183}}], 
  Line[{{2.3038346126325147, 0.8377580409572781}, {2.3038346126325147, \
0.9424777960769379}, {2.4085543677521746, 0.9424777960769379}, 
    {2.4085543677521746, 0.8377580409572781}, {2.3038346126325147, \
0.8377580409572781}}], 
  Line[{{2.3038346126325147, 0.9424777960769379}, {2.3038346126325147, \
1.0471975511965976}, {2.4085543677521746, 1.0471975511965976}, 
    {2.4085543677521746, 0.9424777960769379}, {2.3038346126325147, \
0.9424777960769379}}], 
  Line[{{2.3038346126325147, 1.0471975511965976}, {2.3038346126325147, \
1.1519173063162573}, {2.4085543677521746, 1.1519173063162573}, 
    {2.4085543677521746, 1.0471975511965976}, {2.3038346126325147, \
1.0471975511965976}}], 
  Line[{{2.3038346126325147, 1.1519173063162573}, {2.3038346126325147, \
1.2566370614359172}, {2.4085543677521746, 1.2566370614359172}, 
    {2.4085543677521746, 1.1519173063162573}, {2.3038346126325147, \
1.1519173063162573}}], 
  Line[{{2.3038346126325147, 1.2566370614359172}, {2.3038346126325147, \
1.361356816555577}, {2.4085543677521746, 1.361356816555577}, 
    {2.4085543677521746, 1.2566370614359172}, {2.3038346126325147, \
1.2566370614359172}}], 
  Line[{{2.3038346126325147, 1.361356816555577}, {2.3038346126325147, \
1.4660765716752366}, {2.4085543677521746, 1.4660765716752366}, 
    {2.4085543677521746, 1.361356816555577}, {2.3038346126325147, \
1.361356816555577}}], 
  Line[{{2.3038346126325147, 1.4660765716752366}, {2.3038346126325147, \
1.5707963267948966}, {2.4085543677521746, 1.5707963267948966}, 
    {2.4085543677521746, 1.4660765716752366}, {2.3038346126325147, \
1.4660765716752366}}], 
  Line[{{2.3038346126325147, 1.5707963267948966}, {2.3038346126325147, \
1.6755160819145563}, {2.4085543677521746, 1.6755160819145563}, 
    {2.4085543677521746, 1.5707963267948966}, {2.3038346126325147, \
1.5707963267948966}}], 
  Line[{{2.3038346126325147, 1.6755160819145563}, {2.3038346126325147, \
1.780235837034216}, {2.4085543677521746, 1.780235837034216}, 
    {2.4085543677521746, 1.6755160819145563}, {2.3038346126325147, \
1.6755160819145563}}], 
  Line[{{2.3038346126325147, 1.780235837034216}, {2.3038346126325147, \
1.8849555921538759}, {2.4085543677521746, 1.8849555921538759}, 
    {2.4085543677521746, 1.780235837034216}, {2.3038346126325147, \
1.780235837034216}}], 
  Line[{{2.3038346126325147, 1.8849555921538759}, {2.3038346126325147, \
1.9896753472735356}, {2.4085543677521746, 1.9896753472735356}, 
    {2.4085543677521746, 1.8849555921538759}, {2.3038346126325147, \
1.8849555921538759}}], 
  Line[{{2.3038346126325147, 1.9896753472735356}, {2.3038346126325147, \
2.0943951023931953}, {2.4085543677521746, 2.0943951023931953}, 
    {2.4085543677521746, 1.9896753472735356}, {2.3038346126325147, \
1.9896753472735356}}], 
  Line[{{2.3038346126325147, 2.0943951023931953}, {2.3038346126325147, \
2.199114857512855}, {2.4085543677521746, 2.199114857512855}, 
    {2.4085543677521746, 2.0943951023931953}, {2.3038346126325147, \
2.0943951023931953}}], 
  Line[{{2.3038346126325147, 2.199114857512855}, {2.3038346126325147, \
2.3038346126325147}, {2.4085543677521746, 2.3038346126325147}, 
    {2.4085543677521746, 2.199114857512855}, {2.3038346126325147, \
2.199114857512855}}], 
  Line[{{2.3038346126325147, 2.3038346126325147}, {2.3038346126325147, \
2.4085543677521746}, {2.4085543677521746, 2.4085543677521746}, 
    {2.4085543677521746, 2.3038346126325147}, {2.3038346126325147, \
2.3038346126325147}}], 
  Line[{{2.3038346126325147, 2.4085543677521746}, {2.3038346126325147, \
2.5132741228718345}, {2.4085543677521746, 2.5132741228718345}, 
    {2.4085543677521746, 2.4085543677521746}, {2.3038346126325147, \
2.4085543677521746}}], 
  Line[{{2.3038346126325147, 2.5132741228718345}, {2.3038346126325147, \
2.617993877991494}, {2.4085543677521746, 2.617993877991494}, 
    {2.4085543677521746, 2.5132741228718345}, {2.3038346126325147, \
2.5132741228718345}}], 
  Line[{{2.3038346126325147, 2.617993877991494}, {2.3038346126325147, \
2.722713633111154}, {2.4085543677521746, 2.722713633111154}, 
    {2.4085543677521746, 2.617993877991494}, {2.3038346126325147, \
2.617993877991494}}], 
  Line[{{2.3038346126325147, 2.722713633111154}, {2.3038346126325147, \
2.827433388230814}, {2.4085543677521746, 2.827433388230814}, 
    {2.4085543677521746, 2.722713633111154}, {2.3038346126325147, \
2.722713633111154}}], 
  Line[{{2.3038346126325147, 2.827433388230814}, {2.3038346126325147, \
2.9321531433504733}, {2.4085543677521746, 2.9321531433504733}, 
    {2.4085543677521746, 2.827433388230814}, {2.3038346126325147, \
2.827433388230814}}], 
  Line[{{2.3038346126325147, 2.9321531433504733}, {2.3038346126325147, \
3.036872898470133}, {2.4085543677521746, 3.036872898470133}, 
    {2.4085543677521746, 2.9321531433504733}, {2.3038346126325147, \
2.9321531433504733}}], 
  Line[{{2.3038346126325147, 3.036872898470133}, {2.3038346126325147, \
3.141592653589793}, {2.4085543677521746, 3.141592653589793}, 
    {2.4085543677521746, 3.036872898470133}, {2.3038346126325147, \
3.036872898470133}}], 
  Line[{{2.3038346126325147, 3.141592653589793}, {2.3038346126325147, \
3.2463124087094526}, {2.4085543677521746, 3.2463124087094526}, 
    {2.4085543677521746, 3.141592653589793}, {2.3038346126325147, \
3.141592653589793}}], 
  Line[{{2.3038346126325147, 3.2463124087094526}, {2.3038346126325147, \
3.3510321638291125}, {2.4085543677521746, 3.3510321638291125}, 
    {2.4085543677521746, 3.2463124087094526}, {2.3038346126325147, \
3.2463124087094526}}], 
  Line[{{2.3038346126325147, 3.3510321638291125}, {2.3038346126325147, \
3.4557519189487724}, {2.4085543677521746, 3.4557519189487724}, 
    {2.4085543677521746, 3.3510321638291125}, {2.3038346126325147, \
3.3510321638291125}}], 
  Line[{{2.3038346126325147, 3.4557519189487724}, {2.3038346126325147, \
3.560471674068432}, {2.4085543677521746, 3.560471674068432}, 
    {2.4085543677521746, 3.4557519189487724}, {2.3038346126325147, \
3.4557519189487724}}], 
  Line[{{2.3038346126325147, 3.560471674068432}, {2.3038346126325147, \
3.665191429188092}, {2.4085543677521746, 3.665191429188092}, 
    {2.4085543677521746, 3.560471674068432}, {2.3038346126325147, \
3.560471674068432}}], 
  Line[{{2.3038346126325147, 3.665191429188092}, {2.3038346126325147, \
3.7699111843077517}, {2.4085543677521746, 3.7699111843077517}, 
    {2.4085543677521746, 3.665191429188092}, {2.3038346126325147, \
3.665191429188092}}], 
  Line[{{2.3038346126325147, 3.7699111843077517}, {2.3038346126325147, \
3.874630939427411}, {2.4085543677521746, 3.874630939427411}, 
    {2.4085543677521746, 3.7699111843077517}, {2.3038346126325147, \
3.7699111843077517}}], 
  Line[{{2.3038346126325147, 3.874630939427411}, {2.3038346126325147, \
3.979350694547071}, {2.4085543677521746, 3.979350694547071}, 
    {2.4085543677521746, 3.874630939427411}, {2.3038346126325147, \
3.874630939427411}}], 
  Line[{{2.3038346126325147, 3.979350694547071}, {2.3038346126325147, \
4.084070449666731}, {2.4085543677521746, 4.084070449666731}, 
    {2.4085543677521746, 3.979350694547071}, {2.3038346126325147, \
3.979350694547071}}], 
  Line[{{2.3038346126325147, 4.084070449666731}, {2.3038346126325147, \
4.1887902047863905}, {2.4085543677521746, 4.1887902047863905}, 
    {2.4085543677521746, 4.084070449666731}, {2.3038346126325147, \
4.084070449666731}}], 
  Line[{{2.3038346126325147, 4.1887902047863905}, {2.3038346126325147, \
4.29350995990605}, {2.4085543677521746, 4.29350995990605}, 
    {2.4085543677521746, 4.1887902047863905}, {2.3038346126325147, \
4.1887902047863905}}], 
  Line[{{2.3038346126325147, 4.29350995990605}, {2.3038346126325147, \
4.39822971502571}, {2.4085543677521746, 4.39822971502571}, 
    {2.4085543677521746, 4.29350995990605}, {2.3038346126325147, \
4.29350995990605}}], 
  Line[{{2.3038346126325147, 4.39822971502571}, {2.3038346126325147, \
4.50294947014537}, {2.4085543677521746, 4.50294947014537}, 
    {2.4085543677521746, 4.39822971502571}, {2.3038346126325147, \
4.39822971502571}}], 
  Line[{{2.3038346126325147, 4.50294947014537}, {2.3038346126325147, \
4.607669225265029}, {2.4085543677521746, 4.607669225265029}, 
    {2.4085543677521746, 4.50294947014537}, {2.3038346126325147, \
4.50294947014537}}], 
  Line[{{2.3038346126325147, 4.607669225265029}, {2.3038346126325147, \
4.71238898038469}, {2.4085543677521746, 4.71238898038469}, 
    {2.4085543677521746, 4.607669225265029}, {2.3038346126325147, \
4.607669225265029}}], 
  Line[{{2.3038346126325147, 4.71238898038469}, {2.3038346126325147, \
4.817108735504349}, {2.4085543677521746, 4.817108735504349}, 
    {2.4085543677521746, 4.71238898038469}, {2.3038346126325147, \
4.71238898038469}}], 
  Line[{{2.3038346126325147, 4.817108735504349}, {2.3038346126325147, \
4.921828490624009}, {2.4085543677521746, 4.921828490624009}, 
    {2.4085543677521746, 4.817108735504349}, {2.3038346126325147, \
4.817108735504349}}], 
  Line[{{2.3038346126325147, 4.921828490624009}, {2.3038346126325147, \
5.026548245743669}, {2.4085543677521746, 5.026548245743669}, 
    {2.4085543677521746, 4.921828490624009}, {2.3038346126325147, \
4.921828490624009}}], 
  Line[{{2.3038346126325147, 5.026548245743669}, {2.3038346126325147, \
5.1312680008633285}, {2.4085543677521746, 5.1312680008633285}, 
    {2.4085543677521746, 5.026548245743669}, {2.3038346126325147, \
5.026548245743669}}], 
  Line[{{2.3038346126325147, 5.1312680008633285}, {2.3038346126325147, \
5.235987755982988}, {2.4085543677521746, 5.235987755982988}, 
    {2.4085543677521746, 5.1312680008633285}, {2.3038346126325147, \
5.1312680008633285}}], 
  Line[{{2.3038346126325147, 5.235987755982988}, {2.3038346126325147, \
5.340707511102648}, {2.4085543677521746, 5.340707511102648}, 
    {2.4085543677521746, 5.235987755982988}, {2.3038346126325147, \
5.235987755982988}}], 
  Line[{{2.3038346126325147, 5.340707511102648}, {2.3038346126325147, \
5.445427266222308}, {2.4085543677521746, 5.445427266222308}, 
    {2.4085543677521746, 5.340707511102648}, {2.3038346126325147, \
5.340707511102648}}], 
  Line[{{2.3038346126325147, 5.445427266222308}, {2.3038346126325147, \
5.550147021341967}, {2.4085543677521746, 5.550147021341967}, 
    {2.4085543677521746, 5.445427266222308}, {2.3038346126325147, \
5.445427266222308}}], 
  Line[{{2.3038346126325147, 5.550147021341967}, {2.3038346126325147, \
5.654866776461628}, {2.4085543677521746, 5.654866776461628}, 
    {2.4085543677521746, 5.550147021341967}, {2.3038346126325147, \
5.550147021341967}}], 
  Line[{{2.3038346126325147, 5.654866776461628}, {2.3038346126325147, \
5.759586531581287}, {2.4085543677521746, 5.759586531581287}, 
    {2.4085543677521746, 5.654866776461628}, {2.3038346126325147, \
5.654866776461628}}], 
  Line[{{2.3038346126325147, 5.759586531581287}, {2.3038346126325147, \
5.864306286700947}, {2.4085543677521746, 5.864306286700947}, 
    {2.4085543677521746, 5.759586531581287}, {2.3038346126325147, \
5.759586531581287}}], 
  Line[{{2.3038346126325147, 5.864306286700947}, {2.3038346126325147, \
5.969026041820607}, {2.4085543677521746, 5.969026041820607}, 
    {2.4085543677521746, 5.864306286700947}, {2.3038346126325147, \
5.864306286700947}}], 
  Line[{{2.3038346126325147, 5.969026041820607}, {2.3038346126325147, \
6.073745796940266}, {2.4085543677521746, 6.073745796940266}, 
    {2.4085543677521746, 5.969026041820607}, {2.3038346126325147, \
5.969026041820607}}], 
  Line[{{2.3038346126325147, 6.073745796940266}, {2.3038346126325147, \
6.178465552059926}, {2.4085543677521746, 6.178465552059926}, 
    {2.4085543677521746, 6.073745796940266}, {2.3038346126325147, \
6.073745796940266}}], 
  Line[{{2.3038346126325147, 6.178465552059926}, {2.3038346126325147, \
6.283185307179586}, {2.4085543677521746, 6.283185307179586}, 
    {2.4085543677521746, 6.178465552059926}, {2.3038346126325147, \
6.178465552059926}}], 
  Line[{{2.4085543677521746, 0.}, {2.4085543677521746, 0.10471975511965977}, \
{2.5132741228718345, 0.10471975511965977}, {2.5132741228718345, 0.}, 
    {2.4085543677521746, 0.}}], Line[{{2.4085543677521746, \
0.10471975511965977}, {2.4085543677521746, 0.20943951023931953}, 
    {2.5132741228718345, 0.20943951023931953}, {2.5132741228718345, \
0.10471975511965977}, {2.4085543677521746, 0.10471975511965977}}], 
  Line[{{2.4085543677521746, 0.20943951023931953}, {2.4085543677521746, \
0.3141592653589793}, {2.5132741228718345, 0.3141592653589793}, 
    {2.5132741228718345, 0.20943951023931953}, {2.4085543677521746, \
0.20943951023931953}}], 
  Line[{{2.4085543677521746, 0.3141592653589793}, {2.4085543677521746, \
0.41887902047863906}, {2.5132741228718345, 0.41887902047863906}, 
    {2.5132741228718345, 0.3141592653589793}, {2.4085543677521746, \
0.3141592653589793}}], 
  Line[{{2.4085543677521746, 0.41887902047863906}, {2.4085543677521746, \
0.5235987755982988}, {2.5132741228718345, 0.5235987755982988}, 
    {2.5132741228718345, 0.41887902047863906}, {2.4085543677521746, \
0.41887902047863906}}], 
  Line[{{2.4085543677521746, 0.5235987755982988}, {2.4085543677521746, \
0.6283185307179586}, {2.5132741228718345, 0.6283185307179586}, 
    {2.5132741228718345, 0.5235987755982988}, {2.4085543677521746, \
0.5235987755982988}}], 
  Line[{{2.4085543677521746, 0.6283185307179586}, {2.4085543677521746, \
0.7330382858376183}, {2.5132741228718345, 0.7330382858376183}, 
    {2.5132741228718345, 0.6283185307179586}, {2.4085543677521746, \
0.6283185307179586}}], 
  Line[{{2.4085543677521746, 0.7330382858376183}, {2.4085543677521746, \
0.8377580409572781}, {2.5132741228718345, 0.8377580409572781}, 
    {2.5132741228718345, 0.7330382858376183}, {2.4085543677521746, \
0.7330382858376183}}], 
  Line[{{2.4085543677521746, 0.8377580409572781}, {2.4085543677521746, \
0.9424777960769379}, {2.5132741228718345, 0.9424777960769379}, 
    {2.5132741228718345, 0.8377580409572781}, {2.4085543677521746, \
0.8377580409572781}}], 
  Line[{{2.4085543677521746, 0.9424777960769379}, {2.4085543677521746, \
1.0471975511965976}, {2.5132741228718345, 1.0471975511965976}, 
    {2.5132741228718345, 0.9424777960769379}, {2.4085543677521746, \
0.9424777960769379}}], 
  Line[{{2.4085543677521746, 1.0471975511965976}, {2.4085543677521746, \
1.1519173063162573}, {2.5132741228718345, 1.1519173063162573}, 
    {2.5132741228718345, 1.0471975511965976}, {2.4085543677521746, \
1.0471975511965976}}], 
  Line[{{2.4085543677521746, 1.1519173063162573}, {2.4085543677521746, \
1.2566370614359172}, {2.5132741228718345, 1.2566370614359172}, 
    {2.5132741228718345, 1.1519173063162573}, {2.4085543677521746, \
1.1519173063162573}}], 
  Line[{{2.4085543677521746, 1.2566370614359172}, {2.4085543677521746, \
1.361356816555577}, {2.5132741228718345, 1.361356816555577}, 
    {2.5132741228718345, 1.2566370614359172}, {2.4085543677521746, \
1.2566370614359172}}], 
  Line[{{2.4085543677521746, 1.361356816555577}, {2.4085543677521746, \
1.4660765716752366}, {2.5132741228718345, 1.4660765716752366}, 
    {2.5132741228718345, 1.361356816555577}, {2.4085543677521746, \
1.361356816555577}}], 
  Line[{{2.4085543677521746, 1.4660765716752366}, {2.4085543677521746, \
1.5707963267948966}, {2.5132741228718345, 1.5707963267948966}, 
    {2.5132741228718345, 1.4660765716752366}, {2.4085543677521746, \
1.4660765716752366}}], 
  Line[{{2.4085543677521746, 1.5707963267948966}, {2.4085543677521746, \
1.6755160819145563}, {2.5132741228718345, 1.6755160819145563}, 
    {2.5132741228718345, 1.5707963267948966}, {2.4085543677521746, \
1.5707963267948966}}], 
  Line[{{2.4085543677521746, 1.6755160819145563}, {2.4085543677521746, \
1.780235837034216}, {2.5132741228718345, 1.780235837034216}, 
    {2.5132741228718345, 1.6755160819145563}, {2.4085543677521746, \
1.6755160819145563}}], 
  Line[{{2.4085543677521746, 1.780235837034216}, {2.4085543677521746, \
1.8849555921538759}, {2.5132741228718345, 1.8849555921538759}, 
    {2.5132741228718345, 1.780235837034216}, {2.4085543677521746, \
1.780235837034216}}], 
  Line[{{2.4085543677521746, 1.8849555921538759}, {2.4085543677521746, \
1.9896753472735356}, {2.5132741228718345, 1.9896753472735356}, 
    {2.5132741228718345, 1.8849555921538759}, {2.4085543677521746, \
1.8849555921538759}}], 
  Line[{{2.4085543677521746, 1.9896753472735356}, {2.4085543677521746, \
2.0943951023931953}, {2.5132741228718345, 2.0943951023931953}, 
    {2.5132741228718345, 1.9896753472735356}, {2.4085543677521746, \
1.9896753472735356}}], 
  Line[{{2.4085543677521746, 2.0943951023931953}, {2.4085543677521746, \
2.199114857512855}, {2.5132741228718345, 2.199114857512855}, 
    {2.5132741228718345, 2.0943951023931953}, {2.4085543677521746, \
2.0943951023931953}}], 
  Line[{{2.4085543677521746, 2.199114857512855}, {2.4085543677521746, \
2.3038346126325147}, {2.5132741228718345, 2.3038346126325147}, 
    {2.5132741228718345, 2.199114857512855}, {2.4085543677521746, \
2.199114857512855}}], 
  Line[{{2.4085543677521746, 2.3038346126325147}, {2.4085543677521746, \
2.4085543677521746}, {2.5132741228718345, 2.4085543677521746}, 
    {2.5132741228718345, 2.3038346126325147}, {2.4085543677521746, \
2.3038346126325147}}], 
  Line[{{2.4085543677521746, 2.4085543677521746}, {2.4085543677521746, \
2.5132741228718345}, {2.5132741228718345, 2.5132741228718345}, 
    {2.5132741228718345, 2.4085543677521746}, {2.4085543677521746, \
2.4085543677521746}}], 
  Line[{{2.4085543677521746, 2.5132741228718345}, {2.4085543677521746, \
2.617993877991494}, {2.5132741228718345, 2.617993877991494}, 
    {2.5132741228718345, 2.5132741228718345}, {2.4085543677521746, \
2.5132741228718345}}], 
  Line[{{2.4085543677521746, 2.617993877991494}, {2.4085543677521746, \
2.722713633111154}, {2.5132741228718345, 2.722713633111154}, 
    {2.5132741228718345, 2.617993877991494}, {2.4085543677521746, \
2.617993877991494}}], 
  Line[{{2.4085543677521746, 2.722713633111154}, {2.4085543677521746, \
2.827433388230814}, {2.5132741228718345, 2.827433388230814}, 
    {2.5132741228718345, 2.722713633111154}, {2.4085543677521746, \
2.722713633111154}}], 
  Line[{{2.4085543677521746, 2.827433388230814}, {2.4085543677521746, \
2.9321531433504733}, {2.5132741228718345, 2.9321531433504733}, 
    {2.5132741228718345, 2.827433388230814}, {2.4085543677521746, \
2.827433388230814}}], 
  Line[{{2.4085543677521746, 2.9321531433504733}, {2.4085543677521746, \
3.036872898470133}, {2.5132741228718345, 3.036872898470133}, 
    {2.5132741228718345, 2.9321531433504733}, {2.4085543677521746, \
2.9321531433504733}}], 
  Line[{{2.4085543677521746, 3.036872898470133}, {2.4085543677521746, \
3.141592653589793}, {2.5132741228718345, 3.141592653589793}, 
    {2.5132741228718345, 3.036872898470133}, {2.4085543677521746, \
3.036872898470133}}], 
  Line[{{2.4085543677521746, 3.141592653589793}, {2.4085543677521746, \
3.2463124087094526}, {2.5132741228718345, 3.2463124087094526}, 
    {2.5132741228718345, 3.141592653589793}, {2.4085543677521746, \
3.141592653589793}}], 
  Line[{{2.4085543677521746, 3.2463124087094526}, {2.4085543677521746, \
3.3510321638291125}, {2.5132741228718345, 3.3510321638291125}, 
    {2.5132741228718345, 3.2463124087094526}, {2.4085543677521746, \
3.2463124087094526}}], 
  Line[{{2.4085543677521746, 3.3510321638291125}, {2.4085543677521746, \
3.4557519189487724}, {2.5132741228718345, 3.4557519189487724}, 
    {2.5132741228718345, 3.3510321638291125}, {2.4085543677521746, \
3.3510321638291125}}], 
  Line[{{2.4085543677521746, 3.4557519189487724}, {2.4085543677521746, \
3.560471674068432}, {2.5132741228718345, 3.560471674068432}, 
    {2.5132741228718345, 3.4557519189487724}, {2.4085543677521746, \
3.4557519189487724}}], 
  Line[{{2.4085543677521746, 3.560471674068432}, {2.4085543677521746, \
3.665191429188092}, {2.5132741228718345, 3.665191429188092}, 
    {2.5132741228718345, 3.560471674068432}, {2.4085543677521746, \
3.560471674068432}}], 
  Line[{{2.4085543677521746, 3.665191429188092}, {2.4085543677521746, \
3.7699111843077517}, {2.5132741228718345, 3.7699111843077517}, 
    {2.5132741228718345, 3.665191429188092}, {2.4085543677521746, \
3.665191429188092}}], 
  Line[{{2.4085543677521746, 3.7699111843077517}, {2.4085543677521746, \
3.874630939427411}, {2.5132741228718345, 3.874630939427411}, 
    {2.5132741228718345, 3.7699111843077517}, {2.4085543677521746, \
3.7699111843077517}}], 
  Line[{{2.4085543677521746, 3.874630939427411}, {2.4085543677521746, \
3.979350694547071}, {2.5132741228718345, 3.979350694547071}, 
    {2.5132741228718345, 3.874630939427411}, {2.4085543677521746, \
3.874630939427411}}], 
  Line[{{2.4085543677521746, 3.979350694547071}, {2.4085543677521746, \
4.084070449666731}, {2.5132741228718345, 4.084070449666731}, 
    {2.5132741228718345, 3.979350694547071}, {2.4085543677521746, \
3.979350694547071}}], 
  Line[{{2.4085543677521746, 4.084070449666731}, {2.4085543677521746, \
4.1887902047863905}, {2.5132741228718345, 4.1887902047863905}, 
    {2.5132741228718345, 4.084070449666731}, {2.4085543677521746, \
4.084070449666731}}], 
  Line[{{2.4085543677521746, 4.1887902047863905}, {2.4085543677521746, \
4.29350995990605}, {2.5132741228718345, 4.29350995990605}, 
    {2.5132741228718345, 4.1887902047863905}, {2.4085543677521746, \
4.1887902047863905}}], 
  Line[{{2.4085543677521746, 4.29350995990605}, {2.4085543677521746, \
4.39822971502571}, {2.5132741228718345, 4.39822971502571}, 
    {2.5132741228718345, 4.29350995990605}, {2.4085543677521746, \
4.29350995990605}}], 
  Line[{{2.4085543677521746, 4.39822971502571}, {2.4085543677521746, \
4.50294947014537}, {2.5132741228718345, 4.50294947014537}, 
    {2.5132741228718345, 4.39822971502571}, {2.4085543677521746, \
4.39822971502571}}], 
  Line[{{2.4085543677521746, 4.50294947014537}, {2.4085543677521746, \
4.607669225265029}, {2.5132741228718345, 4.607669225265029}, 
    {2.5132741228718345, 4.50294947014537}, {2.4085543677521746, \
4.50294947014537}}], 
  Line[{{2.4085543677521746, 4.607669225265029}, {2.4085543677521746, \
4.71238898038469}, {2.5132741228718345, 4.71238898038469}, 
    {2.5132741228718345, 4.607669225265029}, {2.4085543677521746, \
4.607669225265029}}], 
  Line[{{2.4085543677521746, 4.71238898038469}, {2.4085543677521746, \
4.817108735504349}, {2.5132741228718345, 4.817108735504349}, 
    {2.5132741228718345, 4.71238898038469}, {2.4085543677521746, \
4.71238898038469}}], 
  Line[{{2.4085543677521746, 4.817108735504349}, {2.4085543677521746, \
4.921828490624009}, {2.5132741228718345, 4.921828490624009}, 
    {2.5132741228718345, 4.817108735504349}, {2.4085543677521746, \
4.817108735504349}}], 
  Line[{{2.4085543677521746, 4.921828490624009}, {2.4085543677521746, \
5.026548245743669}, {2.5132741228718345, 5.026548245743669}, 
    {2.5132741228718345, 4.921828490624009}, {2.4085543677521746, \
4.921828490624009}}], 
  Line[{{2.4085543677521746, 5.026548245743669}, {2.4085543677521746, \
5.1312680008633285}, {2.5132741228718345, 5.1312680008633285}, 
    {2.5132741228718345, 5.026548245743669}, {2.4085543677521746, \
5.026548245743669}}], 
  Line[{{2.4085543677521746, 5.1312680008633285}, {2.4085543677521746, \
5.235987755982988}, {2.5132741228718345, 5.235987755982988}, 
    {2.5132741228718345, 5.1312680008633285}, {2.4085543677521746, \
5.1312680008633285}}], 
  Line[{{2.4085543677521746, 5.235987755982988}, {2.4085543677521746, \
5.340707511102648}, {2.5132741228718345, 5.340707511102648}, 
    {2.5132741228718345, 5.235987755982988}, {2.4085543677521746, \
5.235987755982988}}], 
  Line[{{2.4085543677521746, 5.340707511102648}, {2.4085543677521746, \
5.445427266222308}, {2.5132741228718345, 5.445427266222308}, 
    {2.5132741228718345, 5.340707511102648}, {2.4085543677521746, \
5.340707511102648}}], 
  Line[{{2.4085543677521746, 5.445427266222308}, {2.4085543677521746, \
5.550147021341967}, {2.5132741228718345, 5.550147021341967}, 
    {2.5132741228718345, 5.445427266222308}, {2.4085543677521746, \
5.445427266222308}}], 
  Line[{{2.4085543677521746, 5.550147021341967}, {2.4085543677521746, \
5.654866776461628}, {2.5132741228718345, 5.654866776461628}, 
    {2.5132741228718345, 5.550147021341967}, {2.4085543677521746, \
5.550147021341967}}], 
  Line[{{2.4085543677521746, 5.654866776461628}, {2.4085543677521746, \
5.759586531581287}, {2.5132741228718345, 5.759586531581287}, 
    {2.5132741228718345, 5.654866776461628}, {2.4085543677521746, \
5.654866776461628}}], 
  Line[{{2.4085543677521746, 5.759586531581287}, {2.4085543677521746, \
5.864306286700947}, {2.5132741228718345, 5.864306286700947}, 
    {2.5132741228718345, 5.759586531581287}, {2.4085543677521746, \
5.759586531581287}}], 
  Line[{{2.4085543677521746, 5.864306286700947}, {2.4085543677521746, \
5.969026041820607}, {2.5132741228718345, 5.969026041820607}, 
    {2.5132741228718345, 5.864306286700947}, {2.4085543677521746, \
5.864306286700947}}], 
  Line[{{2.4085543677521746, 5.969026041820607}, {2.4085543677521746, \
6.073745796940266}, {2.5132741228718345, 6.073745796940266}, 
    {2.5132741228718345, 5.969026041820607}, {2.4085543677521746, \
5.969026041820607}}], 
  Line[{{2.4085543677521746, 6.073745796940266}, {2.4085543677521746, \
6.178465552059926}, {2.5132741228718345, 6.178465552059926}, 
    {2.5132741228718345, 6.073745796940266}, {2.4085543677521746, \
6.073745796940266}}], 
  Line[{{2.4085543677521746, 6.178465552059926}, {2.4085543677521746, \
6.283185307179586}, {2.5132741228718345, 6.283185307179586}, 
    {2.5132741228718345, 6.178465552059926}, {2.4085543677521746, \
6.178465552059926}}], 
  Line[{{2.5132741228718345, 0.}, {2.5132741228718345, 0.10471975511965977}, \
{2.617993877991494, 0.10471975511965977}, {2.617993877991494, 0.}, 
    {2.5132741228718345, 0.}}], Line[{{2.5132741228718345, \
0.10471975511965977}, {2.5132741228718345, 0.20943951023931953}, 
    {2.617993877991494, 0.20943951023931953}, {2.617993877991494, \
0.10471975511965977}, {2.5132741228718345, 0.10471975511965977}}], 
  Line[{{2.5132741228718345, 0.20943951023931953}, {2.5132741228718345, \
0.3141592653589793}, {2.617993877991494, 0.3141592653589793}, 
    {2.617993877991494, 0.20943951023931953}, {2.5132741228718345, \
0.20943951023931953}}], 
  Line[{{2.5132741228718345, 0.3141592653589793}, {2.5132741228718345, \
0.41887902047863906}, {2.617993877991494, 0.41887902047863906}, 
    {2.617993877991494, 0.3141592653589793}, {2.5132741228718345, \
0.3141592653589793}}], 
  Line[{{2.5132741228718345, 0.41887902047863906}, {2.5132741228718345, \
0.5235987755982988}, {2.617993877991494, 0.5235987755982988}, 
    {2.617993877991494, 0.41887902047863906}, {2.5132741228718345, \
0.41887902047863906}}], 
  Line[{{2.5132741228718345, 0.5235987755982988}, {2.5132741228718345, \
0.6283185307179586}, {2.617993877991494, 0.6283185307179586}, 
    {2.617993877991494, 0.5235987755982988}, {2.5132741228718345, \
0.5235987755982988}}], 
  Line[{{2.5132741228718345, 0.6283185307179586}, {2.5132741228718345, \
0.7330382858376183}, {2.617993877991494, 0.7330382858376183}, 
    {2.617993877991494, 0.6283185307179586}, {2.5132741228718345, \
0.6283185307179586}}], 
  Line[{{2.5132741228718345, 0.7330382858376183}, {2.5132741228718345, \
0.8377580409572781}, {2.617993877991494, 0.8377580409572781}, 
    {2.617993877991494, 0.7330382858376183}, {2.5132741228718345, \
0.7330382858376183}}], 
  Line[{{2.5132741228718345, 0.8377580409572781}, {2.5132741228718345, \
0.9424777960769379}, {2.617993877991494, 0.9424777960769379}, 
    {2.617993877991494, 0.8377580409572781}, {2.5132741228718345, \
0.8377580409572781}}], 
  Line[{{2.5132741228718345, 0.9424777960769379}, {2.5132741228718345, \
1.0471975511965976}, {2.617993877991494, 1.0471975511965976}, 
    {2.617993877991494, 0.9424777960769379}, {2.5132741228718345, \
0.9424777960769379}}], 
  Line[{{2.5132741228718345, 1.0471975511965976}, {2.5132741228718345, \
1.1519173063162573}, {2.617993877991494, 1.1519173063162573}, 
    {2.617993877991494, 1.0471975511965976}, {2.5132741228718345, \
1.0471975511965976}}], 
  Line[{{2.5132741228718345, 1.1519173063162573}, {2.5132741228718345, \
1.2566370614359172}, {2.617993877991494, 1.2566370614359172}, 
    {2.617993877991494, 1.1519173063162573}, {2.5132741228718345, \
1.1519173063162573}}], 
  Line[{{2.5132741228718345, 1.2566370614359172}, {2.5132741228718345, \
1.361356816555577}, {2.617993877991494, 1.361356816555577}, 
    {2.617993877991494, 1.2566370614359172}, {2.5132741228718345, \
1.2566370614359172}}], 
  Line[{{2.5132741228718345, 1.361356816555577}, {2.5132741228718345, \
1.4660765716752366}, {2.617993877991494, 1.4660765716752366}, 
    {2.617993877991494, 1.361356816555577}, {2.5132741228718345, \
1.361356816555577}}], 
  Line[{{2.5132741228718345, 1.4660765716752366}, {2.5132741228718345, \
1.5707963267948966}, {2.617993877991494, 1.5707963267948966}, 
    {2.617993877991494, 1.4660765716752366}, {2.5132741228718345, \
1.4660765716752366}}], 
  Line[{{2.5132741228718345, 1.5707963267948966}, {2.5132741228718345, \
1.6755160819145563}, {2.617993877991494, 1.6755160819145563}, 
    {2.617993877991494, 1.5707963267948966}, {2.5132741228718345, \
1.5707963267948966}}], 
  Line[{{2.5132741228718345, 1.6755160819145563}, {2.5132741228718345, \
1.780235837034216}, {2.617993877991494, 1.780235837034216}, 
    {2.617993877991494, 1.6755160819145563}, {2.5132741228718345, \
1.6755160819145563}}], 
  Line[{{2.5132741228718345, 1.780235837034216}, {2.5132741228718345, \
1.8849555921538759}, {2.617993877991494, 1.8849555921538759}, 
    {2.617993877991494, 1.780235837034216}, {2.5132741228718345, \
1.780235837034216}}], 
  Line[{{2.5132741228718345, 1.8849555921538759}, {2.5132741228718345, \
1.9896753472735356}, {2.617993877991494, 1.9896753472735356}, 
    {2.617993877991494, 1.8849555921538759}, {2.5132741228718345, \
1.8849555921538759}}], 
  Line[{{2.5132741228718345, 1.9896753472735356}, {2.5132741228718345, \
2.0943951023931953}, {2.617993877991494, 2.0943951023931953}, 
    {2.617993877991494, 1.9896753472735356}, {2.5132741228718345, \
1.9896753472735356}}], 
  Line[{{2.5132741228718345, 2.0943951023931953}, {2.5132741228718345, \
2.199114857512855}, {2.617993877991494, 2.199114857512855}, 
    {2.617993877991494, 2.0943951023931953}, {2.5132741228718345, \
2.0943951023931953}}], 
  Line[{{2.5132741228718345, 2.199114857512855}, {2.5132741228718345, \
2.3038346126325147}, {2.617993877991494, 2.3038346126325147}, 
    {2.617993877991494, 2.199114857512855}, {2.5132741228718345, \
2.199114857512855}}], 
  Line[{{2.5132741228718345, 2.3038346126325147}, {2.5132741228718345, \
2.4085543677521746}, {2.617993877991494, 2.4085543677521746}, 
    {2.617993877991494, 2.3038346126325147}, {2.5132741228718345, \
2.3038346126325147}}], 
  Line[{{2.5132741228718345, 2.4085543677521746}, {2.5132741228718345, \
2.5132741228718345}, {2.617993877991494, 2.5132741228718345}, 
    {2.617993877991494, 2.4085543677521746}, {2.5132741228718345, \
2.4085543677521746}}], 
  Line[{{2.5132741228718345, 2.5132741228718345}, {2.5132741228718345, \
2.617993877991494}, {2.617993877991494, 2.617993877991494}, 
    {2.617993877991494, 2.5132741228718345}, {2.5132741228718345, \
2.5132741228718345}}], 
  Line[{{2.5132741228718345, 2.617993877991494}, {2.5132741228718345, \
2.722713633111154}, {2.617993877991494, 2.722713633111154}, 
    {2.617993877991494, 2.617993877991494}, {2.5132741228718345, \
2.617993877991494}}], 
  Line[{{2.5132741228718345, 2.722713633111154}, {2.5132741228718345, \
2.827433388230814}, {2.617993877991494, 2.827433388230814}, 
    {2.617993877991494, 2.722713633111154}, {2.5132741228718345, \
2.722713633111154}}], 
  Line[{{2.5132741228718345, 2.827433388230814}, {2.5132741228718345, \
2.9321531433504733}, {2.617993877991494, 2.9321531433504733}, 
    {2.617993877991494, 2.827433388230814}, {2.5132741228718345, \
2.827433388230814}}], 
  Line[{{2.5132741228718345, 2.9321531433504733}, {2.5132741228718345, \
3.036872898470133}, {2.617993877991494, 3.036872898470133}, 
    {2.617993877991494, 2.9321531433504733}, {2.5132741228718345, \
2.9321531433504733}}], 
  Line[{{2.5132741228718345, 3.036872898470133}, {2.5132741228718345, \
3.141592653589793}, {2.617993877991494, 3.141592653589793}, 
    {2.617993877991494, 3.036872898470133}, {2.5132741228718345, \
3.036872898470133}}], 
  Line[{{2.5132741228718345, 3.141592653589793}, {2.5132741228718345, \
3.2463124087094526}, {2.617993877991494, 3.2463124087094526}, 
    {2.617993877991494, 3.141592653589793}, {2.5132741228718345, \
3.141592653589793}}], 
  Line[{{2.5132741228718345, 3.2463124087094526}, {2.5132741228718345, \
3.3510321638291125}, {2.617993877991494, 3.3510321638291125}, 
    {2.617993877991494, 3.2463124087094526}, {2.5132741228718345, \
3.2463124087094526}}], 
  Line[{{2.5132741228718345, 3.3510321638291125}, {2.5132741228718345, \
3.4557519189487724}, {2.617993877991494, 3.4557519189487724}, 
    {2.617993877991494, 3.3510321638291125}, {2.5132741228718345, \
3.3510321638291125}}], 
  Line[{{2.5132741228718345, 3.4557519189487724}, {2.5132741228718345, \
3.560471674068432}, {2.617993877991494, 3.560471674068432}, 
    {2.617993877991494, 3.4557519189487724}, {2.5132741228718345, \
3.4557519189487724}}], 
  Line[{{2.5132741228718345, 3.560471674068432}, {2.5132741228718345, \
3.665191429188092}, {2.617993877991494, 3.665191429188092}, 
    {2.617993877991494, 3.560471674068432}, {2.5132741228718345, \
3.560471674068432}}], 
  Line[{{2.5132741228718345, 3.665191429188092}, {2.5132741228718345, \
3.7699111843077517}, {2.617993877991494, 3.7699111843077517}, 
    {2.617993877991494, 3.665191429188092}, {2.5132741228718345, \
3.665191429188092}}], 
  Line[{{2.5132741228718345, 3.7699111843077517}, {2.5132741228718345, \
3.874630939427411}, {2.617993877991494, 3.874630939427411}, 
    {2.617993877991494, 3.7699111843077517}, {2.5132741228718345, \
3.7699111843077517}}], 
  Line[{{2.5132741228718345, 3.874630939427411}, {2.5132741228718345, \
3.979350694547071}, {2.617993877991494, 3.979350694547071}, 
    {2.617993877991494, 3.874630939427411}, {2.5132741228718345, \
3.874630939427411}}], 
  Line[{{2.5132741228718345, 3.979350694547071}, {2.5132741228718345, \
4.084070449666731}, {2.617993877991494, 4.084070449666731}, 
    {2.617993877991494, 3.979350694547071}, {2.5132741228718345, \
3.979350694547071}}], 
  Line[{{2.5132741228718345, 4.084070449666731}, {2.5132741228718345, \
4.1887902047863905}, {2.617993877991494, 4.1887902047863905}, 
    {2.617993877991494, 4.084070449666731}, {2.5132741228718345, \
4.084070449666731}}], 
  Line[{{2.5132741228718345, 4.1887902047863905}, {2.5132741228718345, \
4.29350995990605}, {2.617993877991494, 4.29350995990605}, 
    {2.617993877991494, 4.1887902047863905}, {2.5132741228718345, \
4.1887902047863905}}], 
  Line[{{2.5132741228718345, 4.29350995990605}, {2.5132741228718345, \
4.39822971502571}, {2.617993877991494, 4.39822971502571}, 
    {2.617993877991494, 4.29350995990605}, {2.5132741228718345, \
4.29350995990605}}], 
  Line[{{2.5132741228718345, 4.39822971502571}, {2.5132741228718345, \
4.50294947014537}, {2.617993877991494, 4.50294947014537}, 
    {2.617993877991494, 4.39822971502571}, {2.5132741228718345, \
4.39822971502571}}], 
  Line[{{2.5132741228718345, 4.50294947014537}, {2.5132741228718345, \
4.607669225265029}, {2.617993877991494, 4.607669225265029}, 
    {2.617993877991494, 4.50294947014537}, {2.5132741228718345, \
4.50294947014537}}], 
  Line[{{2.5132741228718345, 4.607669225265029}, {2.5132741228718345, \
4.71238898038469}, {2.617993877991494, 4.71238898038469}, 
    {2.617993877991494, 4.607669225265029}, {2.5132741228718345, \
4.607669225265029}}], 
  Line[{{2.5132741228718345, 4.71238898038469}, {2.5132741228718345, \
4.817108735504349}, {2.617993877991494, 4.817108735504349}, 
    {2.617993877991494, 4.71238898038469}, {2.5132741228718345, \
4.71238898038469}}], 
  Line[{{2.5132741228718345, 4.817108735504349}, {2.5132741228718345, \
4.921828490624009}, {2.617993877991494, 4.921828490624009}, 
    {2.617993877991494, 4.817108735504349}, {2.5132741228718345, \
4.817108735504349}}], 
  Line[{{2.5132741228718345, 4.921828490624009}, {2.5132741228718345, \
5.026548245743669}, {2.617993877991494, 5.026548245743669}, 
    {2.617993877991494, 4.921828490624009}, {2.5132741228718345, \
4.921828490624009}}], 
  Line[{{2.5132741228718345, 5.026548245743669}, {2.5132741228718345, \
5.1312680008633285}, {2.617993877991494, 5.1312680008633285}, 
    {2.617993877991494, 5.026548245743669}, {2.5132741228718345, \
5.026548245743669}}], 
  Line[{{2.5132741228718345, 5.1312680008633285}, {2.5132741228718345, \
5.235987755982988}, {2.617993877991494, 5.235987755982988}, 
    {2.617993877991494, 5.1312680008633285}, {2.5132741228718345, \
5.1312680008633285}}], 
  Line[{{2.5132741228718345, 5.235987755982988}, {2.5132741228718345, \
5.340707511102648}, {2.617993877991494, 5.340707511102648}, 
    {2.617993877991494, 5.235987755982988}, {2.5132741228718345, \
5.235987755982988}}], 
  Line[{{2.5132741228718345, 5.340707511102648}, {2.5132741228718345, \
5.445427266222308}, {2.617993877991494, 5.445427266222308}, 
    {2.617993877991494, 5.340707511102648}, {2.5132741228718345, \
5.340707511102648}}], 
  Line[{{2.5132741228718345, 5.445427266222308}, {2.5132741228718345, \
5.550147021341967}, {2.617993877991494, 5.550147021341967}, 
    {2.617993877991494, 5.445427266222308}, {2.5132741228718345, \
5.445427266222308}}], 
  Line[{{2.5132741228718345, 5.550147021341967}, {2.5132741228718345, \
5.654866776461628}, {2.617993877991494, 5.654866776461628}, 
    {2.617993877991494, 5.550147021341967}, {2.5132741228718345, \
5.550147021341967}}], 
  Line[{{2.5132741228718345, 5.654866776461628}, {2.5132741228718345, \
5.759586531581287}, {2.617993877991494, 5.759586531581287}, 
    {2.617993877991494, 5.654866776461628}, {2.5132741228718345, \
5.654866776461628}}], 
  Line[{{2.5132741228718345, 5.759586531581287}, {2.5132741228718345, \
5.864306286700947}, {2.617993877991494, 5.864306286700947}, 
    {2.617993877991494, 5.759586531581287}, {2.5132741228718345, \
5.759586531581287}}], 
  Line[{{2.5132741228718345, 5.864306286700947}, {2.5132741228718345, \
5.969026041820607}, {2.617993877991494, 5.969026041820607}, 
    {2.617993877991494, 5.864306286700947}, {2.5132741228718345, \
5.864306286700947}}], 
  Line[{{2.5132741228718345, 5.969026041820607}, {2.5132741228718345, \
6.073745796940266}, {2.617993877991494, 6.073745796940266}, 
    {2.617993877991494, 5.969026041820607}, {2.5132741228718345, \
5.969026041820607}}], 
  Line[{{2.5132741228718345, 6.073745796940266}, {2.5132741228718345, \
6.178465552059926}, {2.617993877991494, 6.178465552059926}, 
    {2.617993877991494, 6.073745796940266}, {2.5132741228718345, \
6.073745796940266}}], 
  Line[{{2.5132741228718345, 6.178465552059926}, {2.5132741228718345, \
6.283185307179586}, {2.617993877991494, 6.283185307179586}, 
    {2.617993877991494, 6.178465552059926}, {2.5132741228718345, \
6.178465552059926}}], 
  Line[{{2.617993877991494, 0.}, {2.617993877991494, 0.10471975511965977}, \
{2.722713633111154, 0.10471975511965977}, {2.722713633111154, 0.}, 
    {2.617993877991494, 0.}}], Line[{{2.617993877991494, \
0.10471975511965977}, {2.617993877991494, 0.20943951023931953}, 
    {2.722713633111154, 0.20943951023931953}, {2.722713633111154, \
0.10471975511965977}, {2.617993877991494, 0.10471975511965977}}], 
  Line[{{2.617993877991494, 0.20943951023931953}, {2.617993877991494, \
0.3141592653589793}, {2.722713633111154, 0.3141592653589793}, 
    {2.722713633111154, 0.20943951023931953}, {2.617993877991494, \
0.20943951023931953}}], 
  Line[{{2.617993877991494, 0.3141592653589793}, {2.617993877991494, \
0.41887902047863906}, {2.722713633111154, 0.41887902047863906}, 
    {2.722713633111154, 0.3141592653589793}, {2.617993877991494, \
0.3141592653589793}}], 
  Line[{{2.617993877991494, 0.41887902047863906}, {2.617993877991494, \
0.5235987755982988}, {2.722713633111154, 0.5235987755982988}, 
    {2.722713633111154, 0.41887902047863906}, {2.617993877991494, \
0.41887902047863906}}], 
  Line[{{2.617993877991494, 0.5235987755982988}, {2.617993877991494, \
0.6283185307179586}, {2.722713633111154, 0.6283185307179586}, 
    {2.722713633111154, 0.5235987755982988}, {2.617993877991494, \
0.5235987755982988}}], 
  Line[{{2.617993877991494, 0.6283185307179586}, {2.617993877991494, \
0.7330382858376183}, {2.722713633111154, 0.7330382858376183}, 
    {2.722713633111154, 0.6283185307179586}, {2.617993877991494, \
0.6283185307179586}}], 
  Line[{{2.617993877991494, 0.7330382858376183}, {2.617993877991494, \
0.8377580409572781}, {2.722713633111154, 0.8377580409572781}, 
    {2.722713633111154, 0.7330382858376183}, {2.617993877991494, \
0.7330382858376183}}], 
  Line[{{2.617993877991494, 0.8377580409572781}, {2.617993877991494, \
0.9424777960769379}, {2.722713633111154, 0.9424777960769379}, 
    {2.722713633111154, 0.8377580409572781}, {2.617993877991494, \
0.8377580409572781}}], 
  Line[{{2.617993877991494, 0.9424777960769379}, {2.617993877991494, \
1.0471975511965976}, {2.722713633111154, 1.0471975511965976}, 
    {2.722713633111154, 0.9424777960769379}, {2.617993877991494, \
0.9424777960769379}}], 
  Line[{{2.617993877991494, 1.0471975511965976}, {2.617993877991494, \
1.1519173063162573}, {2.722713633111154, 1.1519173063162573}, 
    {2.722713633111154, 1.0471975511965976}, {2.617993877991494, \
1.0471975511965976}}], 
  Line[{{2.617993877991494, 1.1519173063162573}, {2.617993877991494, \
1.2566370614359172}, {2.722713633111154, 1.2566370614359172}, 
    {2.722713633111154, 1.1519173063162573}, {2.617993877991494, \
1.1519173063162573}}], 
  Line[{{2.617993877991494, 1.2566370614359172}, {2.617993877991494, \
1.361356816555577}, {2.722713633111154, 1.361356816555577}, 
    {2.722713633111154, 1.2566370614359172}, {2.617993877991494, \
1.2566370614359172}}], 
  Line[{{2.617993877991494, 1.361356816555577}, {2.617993877991494, \
1.4660765716752366}, {2.722713633111154, 1.4660765716752366}, 
    {2.722713633111154, 1.361356816555577}, {2.617993877991494, \
1.361356816555577}}], 
  Line[{{2.617993877991494, 1.4660765716752366}, {2.617993877991494, \
1.5707963267948966}, {2.722713633111154, 1.5707963267948966}, 
    {2.722713633111154, 1.4660765716752366}, {2.617993877991494, \
1.4660765716752366}}], 
  Line[{{2.617993877991494, 1.5707963267948966}, {2.617993877991494, \
1.6755160819145563}, {2.722713633111154, 1.6755160819145563}, 
    {2.722713633111154, 1.5707963267948966}, {2.617993877991494, \
1.5707963267948966}}], 
  Line[{{2.617993877991494, 1.6755160819145563}, {2.617993877991494, \
1.780235837034216}, {2.722713633111154, 1.780235837034216}, 
    {2.722713633111154, 1.6755160819145563}, {2.617993877991494, \
1.6755160819145563}}], 
  Line[{{2.617993877991494, 1.780235837034216}, {2.617993877991494, \
1.8849555921538759}, {2.722713633111154, 1.8849555921538759}, 
    {2.722713633111154, 1.780235837034216}, {2.617993877991494, \
1.780235837034216}}], 
  Line[{{2.617993877991494, 1.8849555921538759}, {2.617993877991494, \
1.9896753472735356}, {2.722713633111154, 1.9896753472735356}, 
    {2.722713633111154, 1.8849555921538759}, {2.617993877991494, \
1.8849555921538759}}], 
  Line[{{2.617993877991494, 1.9896753472735356}, {2.617993877991494, \
2.0943951023931953}, {2.722713633111154, 2.0943951023931953}, 
    {2.722713633111154, 1.9896753472735356}, {2.617993877991494, \
1.9896753472735356}}], 
  Line[{{2.617993877991494, 2.0943951023931953}, {2.617993877991494, \
2.199114857512855}, {2.722713633111154, 2.199114857512855}, 
    {2.722713633111154, 2.0943951023931953}, {2.617993877991494, \
2.0943951023931953}}], 
  Line[{{2.617993877991494, 2.199114857512855}, {2.617993877991494, \
2.3038346126325147}, {2.722713633111154, 2.3038346126325147}, 
    {2.722713633111154, 2.199114857512855}, {2.617993877991494, \
2.199114857512855}}], 
  Line[{{2.617993877991494, 2.3038346126325147}, {2.617993877991494, \
2.4085543677521746}, {2.722713633111154, 2.4085543677521746}, 
    {2.722713633111154, 2.3038346126325147}, {2.617993877991494, \
2.3038346126325147}}], 
  Line[{{2.617993877991494, 2.4085543677521746}, {2.617993877991494, \
2.5132741228718345}, {2.722713633111154, 2.5132741228718345}, 
    {2.722713633111154, 2.4085543677521746}, {2.617993877991494, \
2.4085543677521746}}], 
  Line[{{2.617993877991494, 2.5132741228718345}, {2.617993877991494, \
2.617993877991494}, {2.722713633111154, 2.617993877991494}, 
    {2.722713633111154, 2.5132741228718345}, {2.617993877991494, \
2.5132741228718345}}], 
  Line[{{2.617993877991494, 2.617993877991494}, {2.617993877991494, \
2.722713633111154}, {2.722713633111154, 2.722713633111154}, 
    {2.722713633111154, 2.617993877991494}, {2.617993877991494, \
2.617993877991494}}], 
  Line[{{2.617993877991494, 2.722713633111154}, {2.617993877991494, \
2.827433388230814}, {2.722713633111154, 2.827433388230814}, 
    {2.722713633111154, 2.722713633111154}, {2.617993877991494, \
2.722713633111154}}], 
  Line[{{2.617993877991494, 2.827433388230814}, {2.617993877991494, \
2.9321531433504733}, {2.722713633111154, 2.9321531433504733}, 
    {2.722713633111154, 2.827433388230814}, {2.617993877991494, \
2.827433388230814}}], 
  Line[{{2.617993877991494, 2.9321531433504733}, {2.617993877991494, \
3.036872898470133}, {2.722713633111154, 3.036872898470133}, 
    {2.722713633111154, 2.9321531433504733}, {2.617993877991494, \
2.9321531433504733}}], 
  Line[{{2.617993877991494, 3.036872898470133}, {2.617993877991494, \
3.141592653589793}, {2.722713633111154, 3.141592653589793}, 
    {2.722713633111154, 3.036872898470133}, {2.617993877991494, \
3.036872898470133}}], 
  Line[{{2.617993877991494, 3.141592653589793}, {2.617993877991494, \
3.2463124087094526}, {2.722713633111154, 3.2463124087094526}, 
    {2.722713633111154, 3.141592653589793}, {2.617993877991494, \
3.141592653589793}}], 
  Line[{{2.617993877991494, 3.2463124087094526}, {2.617993877991494, \
3.3510321638291125}, {2.722713633111154, 3.3510321638291125}, 
    {2.722713633111154, 3.2463124087094526}, {2.617993877991494, \
3.2463124087094526}}], 
  Line[{{2.617993877991494, 3.3510321638291125}, {2.617993877991494, \
3.4557519189487724}, {2.722713633111154, 3.4557519189487724}, 
    {2.722713633111154, 3.3510321638291125}, {2.617993877991494, \
3.3510321638291125}}], 
  Line[{{2.617993877991494, 3.4557519189487724}, {2.617993877991494, \
3.560471674068432}, {2.722713633111154, 3.560471674068432}, 
    {2.722713633111154, 3.4557519189487724}, {2.617993877991494, \
3.4557519189487724}}], 
  Line[{{2.617993877991494, 3.560471674068432}, {2.617993877991494, \
3.665191429188092}, {2.722713633111154, 3.665191429188092}, 
    {2.722713633111154, 3.560471674068432}, {2.617993877991494, \
3.560471674068432}}], 
  Line[{{2.617993877991494, 3.665191429188092}, {2.617993877991494, \
3.7699111843077517}, {2.722713633111154, 3.7699111843077517}, 
    {2.722713633111154, 3.665191429188092}, {2.617993877991494, \
3.665191429188092}}], 
  Line[{{2.617993877991494, 3.7699111843077517}, {2.617993877991494, \
3.874630939427411}, {2.722713633111154, 3.874630939427411}, 
    {2.722713633111154, 3.7699111843077517}, {2.617993877991494, \
3.7699111843077517}}], 
  Line[{{2.617993877991494, 3.874630939427411}, {2.617993877991494, \
3.979350694547071}, {2.722713633111154, 3.979350694547071}, 
    {2.722713633111154, 3.874630939427411}, {2.617993877991494, \
3.874630939427411}}], 
  Line[{{2.617993877991494, 3.979350694547071}, {2.617993877991494, \
4.084070449666731}, {2.722713633111154, 4.084070449666731}, 
    {2.722713633111154, 3.979350694547071}, {2.617993877991494, \
3.979350694547071}}], 
  Line[{{2.617993877991494, 4.084070449666731}, {2.617993877991494, \
4.1887902047863905}, {2.722713633111154, 4.1887902047863905}, 
    {2.722713633111154, 4.084070449666731}, {2.617993877991494, \
4.084070449666731}}], 
  Line[{{2.617993877991494, 4.1887902047863905}, {2.617993877991494, \
4.29350995990605}, {2.722713633111154, 4.29350995990605}, 
    {2.722713633111154, 4.1887902047863905}, {2.617993877991494, \
4.1887902047863905}}], 
  Line[{{2.617993877991494, 4.29350995990605}, {2.617993877991494, \
4.39822971502571}, {2.722713633111154, 4.39822971502571}, 
    {2.722713633111154, 4.29350995990605}, {2.617993877991494, \
4.29350995990605}}], 
  Line[{{2.617993877991494, 4.39822971502571}, {2.617993877991494, \
4.50294947014537}, {2.722713633111154, 4.50294947014537}, 
    {2.722713633111154, 4.39822971502571}, {2.617993877991494, \
4.39822971502571}}], 
  Line[{{2.617993877991494, 4.50294947014537}, {2.617993877991494, \
4.607669225265029}, {2.722713633111154, 4.607669225265029}, 
    {2.722713633111154, 4.50294947014537}, {2.617993877991494, \
4.50294947014537}}], 
  Line[{{2.617993877991494, 4.607669225265029}, {2.617993877991494, \
4.71238898038469}, {2.722713633111154, 4.71238898038469}, 
    {2.722713633111154, 4.607669225265029}, {2.617993877991494, \
4.607669225265029}}], 
  Line[{{2.617993877991494, 4.71238898038469}, {2.617993877991494, \
4.817108735504349}, {2.722713633111154, 4.817108735504349}, 
    {2.722713633111154, 4.71238898038469}, {2.617993877991494, \
4.71238898038469}}], 
  Line[{{2.617993877991494, 4.817108735504349}, {2.617993877991494, \
4.921828490624009}, {2.722713633111154, 4.921828490624009}, 
    {2.722713633111154, 4.817108735504349}, {2.617993877991494, \
4.817108735504349}}], 
  Line[{{2.617993877991494, 4.921828490624009}, {2.617993877991494, \
5.026548245743669}, {2.722713633111154, 5.026548245743669}, 
    {2.722713633111154, 4.921828490624009}, {2.617993877991494, \
4.921828490624009}}], 
  Line[{{2.617993877991494, 5.026548245743669}, {2.617993877991494, \
5.1312680008633285}, {2.722713633111154, 5.1312680008633285}, 
    {2.722713633111154, 5.026548245743669}, {2.617993877991494, \
5.026548245743669}}], 
  Line[{{2.617993877991494, 5.1312680008633285}, {2.617993877991494, \
5.235987755982988}, {2.722713633111154, 5.235987755982988}, 
    {2.722713633111154, 5.1312680008633285}, {2.617993877991494, \
5.1312680008633285}}], 
  Line[{{2.617993877991494, 5.235987755982988}, {2.617993877991494, \
5.340707511102648}, {2.722713633111154, 5.340707511102648}, 
    {2.722713633111154, 5.235987755982988}, {2.617993877991494, \
5.235987755982988}}], 
  Line[{{2.617993877991494, 5.340707511102648}, {2.617993877991494, \
5.445427266222308}, {2.722713633111154, 5.445427266222308}, 
    {2.722713633111154, 5.340707511102648}, {2.617993877991494, \
5.340707511102648}}], 
  Line[{{2.617993877991494, 5.445427266222308}, {2.617993877991494, \
5.550147021341967}, {2.722713633111154, 5.550147021341967}, 
    {2.722713633111154, 5.445427266222308}, {2.617993877991494, \
5.445427266222308}}], 
  Line[{{2.617993877991494, 5.550147021341967}, {2.617993877991494, \
5.654866776461628}, {2.722713633111154, 5.654866776461628}, 
    {2.722713633111154, 5.550147021341967}, {2.617993877991494, \
5.550147021341967}}], 
  Line[{{2.617993877991494, 5.654866776461628}, {2.617993877991494, \
5.759586531581287}, {2.722713633111154, 5.759586531581287}, 
    {2.722713633111154, 5.654866776461628}, {2.617993877991494, \
5.654866776461628}}], 
  Line[{{2.617993877991494, 5.759586531581287}, {2.617993877991494, \
5.864306286700947}, {2.722713633111154, 5.864306286700947}, 
    {2.722713633111154, 5.759586531581287}, {2.617993877991494, \
5.759586531581287}}], 
  Line[{{2.617993877991494, 5.864306286700947}, {2.617993877991494, \
5.969026041820607}, {2.722713633111154, 5.969026041820607}, 
    {2.722713633111154, 5.864306286700947}, {2.617993877991494, \
5.864306286700947}}], 
  Line[{{2.617993877991494, 5.969026041820607}, {2.617993877991494, \
6.073745796940266}, {2.722713633111154, 6.073745796940266}, 
    {2.722713633111154, 5.969026041820607}, {2.617993877991494, \
5.969026041820607}}], 
  Line[{{2.617993877991494, 6.073745796940266}, {2.617993877991494, \
6.178465552059926}, {2.722713633111154, 6.178465552059926}, 
    {2.722713633111154, 6.073745796940266}, {2.617993877991494, \
6.073745796940266}}], 
  Line[{{2.617993877991494, 6.178465552059926}, {2.617993877991494, \
6.283185307179586}, {2.722713633111154, 6.283185307179586}, 
    {2.722713633111154, 6.178465552059926}, {2.617993877991494, \
6.178465552059926}}], 
  Line[{{2.722713633111154, 0.}, {2.722713633111154, 0.10471975511965977}, \
{2.827433388230814, 0.10471975511965977}, {2.827433388230814, 0.}, 
    {2.722713633111154, 0.}}], Line[{{2.722713633111154, \
0.10471975511965977}, {2.722713633111154, 0.20943951023931953}, 
    {2.827433388230814, 0.20943951023931953}, {2.827433388230814, \
0.10471975511965977}, {2.722713633111154, 0.10471975511965977}}], 
  Line[{{2.722713633111154, 0.20943951023931953}, {2.722713633111154, \
0.3141592653589793}, {2.827433388230814, 0.3141592653589793}, 
    {2.827433388230814, 0.20943951023931953}, {2.722713633111154, \
0.20943951023931953}}], 
  Line[{{2.722713633111154, 0.3141592653589793}, {2.722713633111154, \
0.41887902047863906}, {2.827433388230814, 0.41887902047863906}, 
    {2.827433388230814, 0.3141592653589793}, {2.722713633111154, \
0.3141592653589793}}], 
  Line[{{2.722713633111154, 0.41887902047863906}, {2.722713633111154, \
0.5235987755982988}, {2.827433388230814, 0.5235987755982988}, 
    {2.827433388230814, 0.41887902047863906}, {2.722713633111154, \
0.41887902047863906}}], 
  Line[{{2.722713633111154, 0.5235987755982988}, {2.722713633111154, \
0.6283185307179586}, {2.827433388230814, 0.6283185307179586}, 
    {2.827433388230814, 0.5235987755982988}, {2.722713633111154, \
0.5235987755982988}}], 
  Line[{{2.722713633111154, 0.6283185307179586}, {2.722713633111154, \
0.7330382858376183}, {2.827433388230814, 0.7330382858376183}, 
    {2.827433388230814, 0.6283185307179586}, {2.722713633111154, \
0.6283185307179586}}], 
  Line[{{2.722713633111154, 0.7330382858376183}, {2.722713633111154, \
0.8377580409572781}, {2.827433388230814, 0.8377580409572781}, 
    {2.827433388230814, 0.7330382858376183}, {2.722713633111154, \
0.7330382858376183}}], 
  Line[{{2.722713633111154, 0.8377580409572781}, {2.722713633111154, \
0.9424777960769379}, {2.827433388230814, 0.9424777960769379}, 
    {2.827433388230814, 0.8377580409572781}, {2.722713633111154, \
0.8377580409572781}}], 
  Line[{{2.722713633111154, 0.9424777960769379}, {2.722713633111154, \
1.0471975511965976}, {2.827433388230814, 1.0471975511965976}, 
    {2.827433388230814, 0.9424777960769379}, {2.722713633111154, \
0.9424777960769379}}], 
  Line[{{2.722713633111154, 1.0471975511965976}, {2.722713633111154, \
1.1519173063162573}, {2.827433388230814, 1.1519173063162573}, 
    {2.827433388230814, 1.0471975511965976}, {2.722713633111154, \
1.0471975511965976}}], 
  Line[{{2.722713633111154, 1.1519173063162573}, {2.722713633111154, \
1.2566370614359172}, {2.827433388230814, 1.2566370614359172}, 
    {2.827433388230814, 1.1519173063162573}, {2.722713633111154, \
1.1519173063162573}}], 
  Line[{{2.722713633111154, 1.2566370614359172}, {2.722713633111154, \
1.361356816555577}, {2.827433388230814, 1.361356816555577}, 
    {2.827433388230814, 1.2566370614359172}, {2.722713633111154, \
1.2566370614359172}}], 
  Line[{{2.722713633111154, 1.361356816555577}, {2.722713633111154, \
1.4660765716752366}, {2.827433388230814, 1.4660765716752366}, 
    {2.827433388230814, 1.361356816555577}, {2.722713633111154, \
1.361356816555577}}], 
  Line[{{2.722713633111154, 1.4660765716752366}, {2.722713633111154, \
1.5707963267948966}, {2.827433388230814, 1.5707963267948966}, 
    {2.827433388230814, 1.4660765716752366}, {2.722713633111154, \
1.4660765716752366}}], 
  Line[{{2.722713633111154, 1.5707963267948966}, {2.722713633111154, \
1.6755160819145563}, {2.827433388230814, 1.6755160819145563}, 
    {2.827433388230814, 1.5707963267948966}, {2.722713633111154, \
1.5707963267948966}}], 
  Line[{{2.722713633111154, 1.6755160819145563}, {2.722713633111154, \
1.780235837034216}, {2.827433388230814, 1.780235837034216}, 
    {2.827433388230814, 1.6755160819145563}, {2.722713633111154, \
1.6755160819145563}}], 
  Line[{{2.722713633111154, 1.780235837034216}, {2.722713633111154, \
1.8849555921538759}, {2.827433388230814, 1.8849555921538759}, 
    {2.827433388230814, 1.780235837034216}, {2.722713633111154, \
1.780235837034216}}], 
  Line[{{2.722713633111154, 1.8849555921538759}, {2.722713633111154, \
1.9896753472735356}, {2.827433388230814, 1.9896753472735356}, 
    {2.827433388230814, 1.8849555921538759}, {2.722713633111154, \
1.8849555921538759}}], 
  Line[{{2.722713633111154, 1.9896753472735356}, {2.722713633111154, \
2.0943951023931953}, {2.827433388230814, 2.0943951023931953}, 
    {2.827433388230814, 1.9896753472735356}, {2.722713633111154, \
1.9896753472735356}}], 
  Line[{{2.722713633111154, 2.0943951023931953}, {2.722713633111154, \
2.199114857512855}, {2.827433388230814, 2.199114857512855}, 
    {2.827433388230814, 2.0943951023931953}, {2.722713633111154, \
2.0943951023931953}}], 
  Line[{{2.722713633111154, 2.199114857512855}, {2.722713633111154, \
2.3038346126325147}, {2.827433388230814, 2.3038346126325147}, 
    {2.827433388230814, 2.199114857512855}, {2.722713633111154, \
2.199114857512855}}], 
  Line[{{2.722713633111154, 2.3038346126325147}, {2.722713633111154, \
2.4085543677521746}, {2.827433388230814, 2.4085543677521746}, 
    {2.827433388230814, 2.3038346126325147}, {2.722713633111154, \
2.3038346126325147}}], 
  Line[{{2.722713633111154, 2.4085543677521746}, {2.722713633111154, \
2.5132741228718345}, {2.827433388230814, 2.5132741228718345}, 
    {2.827433388230814, 2.4085543677521746}, {2.722713633111154, \
2.4085543677521746}}], 
  Line[{{2.722713633111154, 2.5132741228718345}, {2.722713633111154, \
2.617993877991494}, {2.827433388230814, 2.617993877991494}, 
    {2.827433388230814, 2.5132741228718345}, {2.722713633111154, \
2.5132741228718345}}], 
  Line[{{2.722713633111154, 2.617993877991494}, {2.722713633111154, \
2.722713633111154}, {2.827433388230814, 2.722713633111154}, 
    {2.827433388230814, 2.617993877991494}, {2.722713633111154, \
2.617993877991494}}], 
  Line[{{2.722713633111154, 2.722713633111154}, {2.722713633111154, \
2.827433388230814}, {2.827433388230814, 2.827433388230814}, 
    {2.827433388230814, 2.722713633111154}, {2.722713633111154, \
2.722713633111154}}], 
  Line[{{2.722713633111154, 2.827433388230814}, {2.722713633111154, \
2.9321531433504733}, {2.827433388230814, 2.9321531433504733}, 
    {2.827433388230814, 2.827433388230814}, {2.722713633111154, \
2.827433388230814}}], 
  Line[{{2.722713633111154, 2.9321531433504733}, {2.722713633111154, \
3.036872898470133}, {2.827433388230814, 3.036872898470133}, 
    {2.827433388230814, 2.9321531433504733}, {2.722713633111154, \
2.9321531433504733}}], 
  Line[{{2.722713633111154, 3.036872898470133}, {2.722713633111154, \
3.141592653589793}, {2.827433388230814, 3.141592653589793}, 
    {2.827433388230814, 3.036872898470133}, {2.722713633111154, \
3.036872898470133}}], 
  Line[{{2.722713633111154, 3.141592653589793}, {2.722713633111154, \
3.2463124087094526}, {2.827433388230814, 3.2463124087094526}, 
    {2.827433388230814, 3.141592653589793}, {2.722713633111154, \
3.141592653589793}}], 
  Line[{{2.722713633111154, 3.2463124087094526}, {2.722713633111154, \
3.3510321638291125}, {2.827433388230814, 3.3510321638291125}, 
    {2.827433388230814, 3.2463124087094526}, {2.722713633111154, \
3.2463124087094526}}], 
  Line[{{2.722713633111154, 3.3510321638291125}, {2.722713633111154, \
3.4557519189487724}, {2.827433388230814, 3.4557519189487724}, 
    {2.827433388230814, 3.3510321638291125}, {2.722713633111154, \
3.3510321638291125}}], 
  Line[{{2.722713633111154, 3.4557519189487724}, {2.722713633111154, \
3.560471674068432}, {2.827433388230814, 3.560471674068432}, 
    {2.827433388230814, 3.4557519189487724}, {2.722713633111154, \
3.4557519189487724}}], 
  Line[{{2.722713633111154, 3.560471674068432}, {2.722713633111154, \
3.665191429188092}, {2.827433388230814, 3.665191429188092}, 
    {2.827433388230814, 3.560471674068432}, {2.722713633111154, \
3.560471674068432}}], 
  Line[{{2.722713633111154, 3.665191429188092}, {2.722713633111154, \
3.7699111843077517}, {2.827433388230814, 3.7699111843077517}, 
    {2.827433388230814, 3.665191429188092}, {2.722713633111154, \
3.665191429188092}}], 
  Line[{{2.722713633111154, 3.7699111843077517}, {2.722713633111154, \
3.874630939427411}, {2.827433388230814, 3.874630939427411}, 
    {2.827433388230814, 3.7699111843077517}, {2.722713633111154, \
3.7699111843077517}}], 
  Line[{{2.722713633111154, 3.874630939427411}, {2.722713633111154, \
3.979350694547071}, {2.827433388230814, 3.979350694547071}, 
    {2.827433388230814, 3.874630939427411}, {2.722713633111154, \
3.874630939427411}}], 
  Line[{{2.722713633111154, 3.979350694547071}, {2.722713633111154, \
4.084070449666731}, {2.827433388230814, 4.084070449666731}, 
    {2.827433388230814, 3.979350694547071}, {2.722713633111154, \
3.979350694547071}}], 
  Line[{{2.722713633111154, 4.084070449666731}, {2.722713633111154, \
4.1887902047863905}, {2.827433388230814, 4.1887902047863905}, 
    {2.827433388230814, 4.084070449666731}, {2.722713633111154, \
4.084070449666731}}], 
  Line[{{2.722713633111154, 4.1887902047863905}, {2.722713633111154, \
4.29350995990605}, {2.827433388230814, 4.29350995990605}, 
    {2.827433388230814, 4.1887902047863905}, {2.722713633111154, \
4.1887902047863905}}], 
  Line[{{2.722713633111154, 4.29350995990605}, {2.722713633111154, \
4.39822971502571}, {2.827433388230814, 4.39822971502571}, 
    {2.827433388230814, 4.29350995990605}, {2.722713633111154, \
4.29350995990605}}], 
  Line[{{2.722713633111154, 4.39822971502571}, {2.722713633111154, \
4.50294947014537}, {2.827433388230814, 4.50294947014537}, 
    {2.827433388230814, 4.39822971502571}, {2.722713633111154, \
4.39822971502571}}], 
  Line[{{2.722713633111154, 4.50294947014537}, {2.722713633111154, \
4.607669225265029}, {2.827433388230814, 4.607669225265029}, 
    {2.827433388230814, 4.50294947014537}, {2.722713633111154, \
4.50294947014537}}], 
  Line[{{2.722713633111154, 4.607669225265029}, {2.722713633111154, \
4.71238898038469}, {2.827433388230814, 4.71238898038469}, 
    {2.827433388230814, 4.607669225265029}, {2.722713633111154, \
4.607669225265029}}], 
  Line[{{2.722713633111154, 4.71238898038469}, {2.722713633111154, \
4.817108735504349}, {2.827433388230814, 4.817108735504349}, 
    {2.827433388230814, 4.71238898038469}, {2.722713633111154, \
4.71238898038469}}], 
  Line[{{2.722713633111154, 4.817108735504349}, {2.722713633111154, \
4.921828490624009}, {2.827433388230814, 4.921828490624009}, 
    {2.827433388230814, 4.817108735504349}, {2.722713633111154, \
4.817108735504349}}], 
  Line[{{2.722713633111154, 4.921828490624009}, {2.722713633111154, \
5.026548245743669}, {2.827433388230814, 5.026548245743669}, 
    {2.827433388230814, 4.921828490624009}, {2.722713633111154, \
4.921828490624009}}], 
  Line[{{2.722713633111154, 5.026548245743669}, {2.722713633111154, \
5.1312680008633285}, {2.827433388230814, 5.1312680008633285}, 
    {2.827433388230814, 5.026548245743669}, {2.722713633111154, \
5.026548245743669}}], 
  Line[{{2.722713633111154, 5.1312680008633285}, {2.722713633111154, \
5.235987755982988}, {2.827433388230814, 5.235987755982988}, 
    {2.827433388230814, 5.1312680008633285}, {2.722713633111154, \
5.1312680008633285}}], 
  Line[{{2.722713633111154, 5.235987755982988}, {2.722713633111154, \
5.340707511102648}, {2.827433388230814, 5.340707511102648}, 
    {2.827433388230814, 5.235987755982988}, {2.722713633111154, \
5.235987755982988}}], 
  Line[{{2.722713633111154, 5.340707511102648}, {2.722713633111154, \
5.445427266222308}, {2.827433388230814, 5.445427266222308}, 
    {2.827433388230814, 5.340707511102648}, {2.722713633111154, \
5.340707511102648}}], 
  Line[{{2.722713633111154, 5.445427266222308}, {2.722713633111154, \
5.550147021341967}, {2.827433388230814, 5.550147021341967}, 
    {2.827433388230814, 5.445427266222308}, {2.722713633111154, \
5.445427266222308}}], 
  Line[{{2.722713633111154, 5.550147021341967}, {2.722713633111154, \
5.654866776461628}, {2.827433388230814, 5.654866776461628}, 
    {2.827433388230814, 5.550147021341967}, {2.722713633111154, \
5.550147021341967}}], 
  Line[{{2.722713633111154, 5.654866776461628}, {2.722713633111154, \
5.759586531581287}, {2.827433388230814, 5.759586531581287}, 
    {2.827433388230814, 5.654866776461628}, {2.722713633111154, \
5.654866776461628}}], 
  Line[{{2.722713633111154, 5.759586531581287}, {2.722713633111154, \
5.864306286700947}, {2.827433388230814, 5.864306286700947}, 
    {2.827433388230814, 5.759586531581287}, {2.722713633111154, \
5.759586531581287}}], 
  Line[{{2.722713633111154, 5.864306286700947}, {2.722713633111154, \
5.969026041820607}, {2.827433388230814, 5.969026041820607}, 
    {2.827433388230814, 5.864306286700947}, {2.722713633111154, \
5.864306286700947}}], 
  Line[{{2.722713633111154, 5.969026041820607}, {2.722713633111154, \
6.073745796940266}, {2.827433388230814, 6.073745796940266}, 
    {2.827433388230814, 5.969026041820607}, {2.722713633111154, \
5.969026041820607}}], 
  Line[{{2.722713633111154, 6.073745796940266}, {2.722713633111154, \
6.178465552059926}, {2.827433388230814, 6.178465552059926}, 
    {2.827433388230814, 6.073745796940266}, {2.722713633111154, \
6.073745796940266}}], 
  Line[{{2.722713633111154, 6.178465552059926}, {2.722713633111154, \
6.283185307179586}, {2.827433388230814, 6.283185307179586}, 
    {2.827433388230814, 6.178465552059926}, {2.722713633111154, \
6.178465552059926}}], 
  Line[{{2.827433388230814, 0.}, {2.827433388230814, 0.10471975511965977}, \
{2.9321531433504733, 0.10471975511965977}, {2.9321531433504733, 0.}, 
    {2.827433388230814, 0.}}], Line[{{2.827433388230814, \
0.10471975511965977}, {2.827433388230814, 0.20943951023931953}, 
    {2.9321531433504733, 0.20943951023931953}, {2.9321531433504733, \
0.10471975511965977}, {2.827433388230814, 0.10471975511965977}}], 
  Line[{{2.827433388230814, 0.20943951023931953}, {2.827433388230814, \
0.3141592653589793}, {2.9321531433504733, 0.3141592653589793}, 
    {2.9321531433504733, 0.20943951023931953}, {2.827433388230814, \
0.20943951023931953}}], 
  Line[{{2.827433388230814, 0.3141592653589793}, {2.827433388230814, \
0.41887902047863906}, {2.9321531433504733, 0.41887902047863906}, 
    {2.9321531433504733, 0.3141592653589793}, {2.827433388230814, \
0.3141592653589793}}], 
  Line[{{2.827433388230814, 0.41887902047863906}, {2.827433388230814, \
0.5235987755982988}, {2.9321531433504733, 0.5235987755982988}, 
    {2.9321531433504733, 0.41887902047863906}, {2.827433388230814, \
0.41887902047863906}}], 
  Line[{{2.827433388230814, 0.5235987755982988}, {2.827433388230814, \
0.6283185307179586}, {2.9321531433504733, 0.6283185307179586}, 
    {2.9321531433504733, 0.5235987755982988}, {2.827433388230814, \
0.5235987755982988}}], 
  Line[{{2.827433388230814, 0.6283185307179586}, {2.827433388230814, \
0.7330382858376183}, {2.9321531433504733, 0.7330382858376183}, 
    {2.9321531433504733, 0.6283185307179586}, {2.827433388230814, \
0.6283185307179586}}], 
  Line[{{2.827433388230814, 0.7330382858376183}, {2.827433388230814, \
0.8377580409572781}, {2.9321531433504733, 0.8377580409572781}, 
    {2.9321531433504733, 0.7330382858376183}, {2.827433388230814, \
0.7330382858376183}}], 
  Line[{{2.827433388230814, 0.8377580409572781}, {2.827433388230814, \
0.9424777960769379}, {2.9321531433504733, 0.9424777960769379}, 
    {2.9321531433504733, 0.8377580409572781}, {2.827433388230814, \
0.8377580409572781}}], 
  Line[{{2.827433388230814, 0.9424777960769379}, {2.827433388230814, \
1.0471975511965976}, {2.9321531433504733, 1.0471975511965976}, 
    {2.9321531433504733, 0.9424777960769379}, {2.827433388230814, \
0.9424777960769379}}], 
  Line[{{2.827433388230814, 1.0471975511965976}, {2.827433388230814, \
1.1519173063162573}, {2.9321531433504733, 1.1519173063162573}, 
    {2.9321531433504733, 1.0471975511965976}, {2.827433388230814, \
1.0471975511965976}}], 
  Line[{{2.827433388230814, 1.1519173063162573}, {2.827433388230814, \
1.2566370614359172}, {2.9321531433504733, 1.2566370614359172}, 
    {2.9321531433504733, 1.1519173063162573}, {2.827433388230814, \
1.1519173063162573}}], 
  Line[{{2.827433388230814, 1.2566370614359172}, {2.827433388230814, \
1.361356816555577}, {2.9321531433504733, 1.361356816555577}, 
    {2.9321531433504733, 1.2566370614359172}, {2.827433388230814, \
1.2566370614359172}}], 
  Line[{{2.827433388230814, 1.361356816555577}, {2.827433388230814, \
1.4660765716752366}, {2.9321531433504733, 1.4660765716752366}, 
    {2.9321531433504733, 1.361356816555577}, {2.827433388230814, \
1.361356816555577}}], 
  Line[{{2.827433388230814, 1.4660765716752366}, {2.827433388230814, \
1.5707963267948966}, {2.9321531433504733, 1.5707963267948966}, 
    {2.9321531433504733, 1.4660765716752366}, {2.827433388230814, \
1.4660765716752366}}], 
  Line[{{2.827433388230814, 1.5707963267948966}, {2.827433388230814, \
1.6755160819145563}, {2.9321531433504733, 1.6755160819145563}, 
    {2.9321531433504733, 1.5707963267948966}, {2.827433388230814, \
1.5707963267948966}}], 
  Line[{{2.827433388230814, 1.6755160819145563}, {2.827433388230814, \
1.780235837034216}, {2.9321531433504733, 1.780235837034216}, 
    {2.9321531433504733, 1.6755160819145563}, {2.827433388230814, \
1.6755160819145563}}], 
  Line[{{2.827433388230814, 1.780235837034216}, {2.827433388230814, \
1.8849555921538759}, {2.9321531433504733, 1.8849555921538759}, 
    {2.9321531433504733, 1.780235837034216}, {2.827433388230814, \
1.780235837034216}}], 
  Line[{{2.827433388230814, 1.8849555921538759}, {2.827433388230814, \
1.9896753472735356}, {2.9321531433504733, 1.9896753472735356}, 
    {2.9321531433504733, 1.8849555921538759}, {2.827433388230814, \
1.8849555921538759}}], 
  Line[{{2.827433388230814, 1.9896753472735356}, {2.827433388230814, \
2.0943951023931953}, {2.9321531433504733, 2.0943951023931953}, 
    {2.9321531433504733, 1.9896753472735356}, {2.827433388230814, \
1.9896753472735356}}], 
  Line[{{2.827433388230814, 2.0943951023931953}, {2.827433388230814, \
2.199114857512855}, {2.9321531433504733, 2.199114857512855}, 
    {2.9321531433504733, 2.0943951023931953}, {2.827433388230814, \
2.0943951023931953}}], 
  Line[{{2.827433388230814, 2.199114857512855}, {2.827433388230814, \
2.3038346126325147}, {2.9321531433504733, 2.3038346126325147}, 
    {2.9321531433504733, 2.199114857512855}, {2.827433388230814, \
2.199114857512855}}], 
  Line[{{2.827433388230814, 2.3038346126325147}, {2.827433388230814, \
2.4085543677521746}, {2.9321531433504733, 2.4085543677521746}, 
    {2.9321531433504733, 2.3038346126325147}, {2.827433388230814, \
2.3038346126325147}}], 
  Line[{{2.827433388230814, 2.4085543677521746}, {2.827433388230814, \
2.5132741228718345}, {2.9321531433504733, 2.5132741228718345}, 
    {2.9321531433504733, 2.4085543677521746}, {2.827433388230814, \
2.4085543677521746}}], 
  Line[{{2.827433388230814, 2.5132741228718345}, {2.827433388230814, \
2.617993877991494}, {2.9321531433504733, 2.617993877991494}, 
    {2.9321531433504733, 2.5132741228718345}, {2.827433388230814, \
2.5132741228718345}}], 
  Line[{{2.827433388230814, 2.617993877991494}, {2.827433388230814, \
2.722713633111154}, {2.9321531433504733, 2.722713633111154}, 
    {2.9321531433504733, 2.617993877991494}, {2.827433388230814, \
2.617993877991494}}], 
  Line[{{2.827433388230814, 2.722713633111154}, {2.827433388230814, \
2.827433388230814}, {2.9321531433504733, 2.827433388230814}, 
    {2.9321531433504733, 2.722713633111154}, {2.827433388230814, \
2.722713633111154}}], 
  Line[{{2.827433388230814, 2.827433388230814}, {2.827433388230814, \
2.9321531433504733}, {2.9321531433504733, 2.9321531433504733}, 
    {2.9321531433504733, 2.827433388230814}, {2.827433388230814, \
2.827433388230814}}], 
  Line[{{2.827433388230814, 2.9321531433504733}, {2.827433388230814, \
3.036872898470133}, {2.9321531433504733, 3.036872898470133}, 
    {2.9321531433504733, 2.9321531433504733}, {2.827433388230814, \
2.9321531433504733}}], 
  Line[{{2.827433388230814, 3.036872898470133}, {2.827433388230814, \
3.141592653589793}, {2.9321531433504733, 3.141592653589793}, 
    {2.9321531433504733, 3.036872898470133}, {2.827433388230814, \
3.036872898470133}}], 
  Line[{{2.827433388230814, 3.141592653589793}, {2.827433388230814, \
3.2463124087094526}, {2.9321531433504733, 3.2463124087094526}, 
    {2.9321531433504733, 3.141592653589793}, {2.827433388230814, \
3.141592653589793}}], 
  Line[{{2.827433388230814, 3.2463124087094526}, {2.827433388230814, \
3.3510321638291125}, {2.9321531433504733, 3.3510321638291125}, 
    {2.9321531433504733, 3.2463124087094526}, {2.827433388230814, \
3.2463124087094526}}], 
  Line[{{2.827433388230814, 3.3510321638291125}, {2.827433388230814, \
3.4557519189487724}, {2.9321531433504733, 3.4557519189487724}, 
    {2.9321531433504733, 3.3510321638291125}, {2.827433388230814, \
3.3510321638291125}}], 
  Line[{{2.827433388230814, 3.4557519189487724}, {2.827433388230814, \
3.560471674068432}, {2.9321531433504733, 3.560471674068432}, 
    {2.9321531433504733, 3.4557519189487724}, {2.827433388230814, \
3.4557519189487724}}], 
  Line[{{2.827433388230814, 3.560471674068432}, {2.827433388230814, \
3.665191429188092}, {2.9321531433504733, 3.665191429188092}, 
    {2.9321531433504733, 3.560471674068432}, {2.827433388230814, \
3.560471674068432}}], 
  Line[{{2.827433388230814, 3.665191429188092}, {2.827433388230814, \
3.7699111843077517}, {2.9321531433504733, 3.7699111843077517}, 
    {2.9321531433504733, 3.665191429188092}, {2.827433388230814, \
3.665191429188092}}], 
  Line[{{2.827433388230814, 3.7699111843077517}, {2.827433388230814, \
3.874630939427411}, {2.9321531433504733, 3.874630939427411}, 
    {2.9321531433504733, 3.7699111843077517}, {2.827433388230814, \
3.7699111843077517}}], 
  Line[{{2.827433388230814, 3.874630939427411}, {2.827433388230814, \
3.979350694547071}, {2.9321531433504733, 3.979350694547071}, 
    {2.9321531433504733, 3.874630939427411}, {2.827433388230814, \
3.874630939427411}}], 
  Line[{{2.827433388230814, 3.979350694547071}, {2.827433388230814, \
4.084070449666731}, {2.9321531433504733, 4.084070449666731}, 
    {2.9321531433504733, 3.979350694547071}, {2.827433388230814, \
3.979350694547071}}], 
  Line[{{2.827433388230814, 4.084070449666731}, {2.827433388230814, \
4.1887902047863905}, {2.9321531433504733, 4.1887902047863905}, 
    {2.9321531433504733, 4.084070449666731}, {2.827433388230814, \
4.084070449666731}}], 
  Line[{{2.827433388230814, 4.1887902047863905}, {2.827433388230814, \
4.29350995990605}, {2.9321531433504733, 4.29350995990605}, 
    {2.9321531433504733, 4.1887902047863905}, {2.827433388230814, \
4.1887902047863905}}], 
  Line[{{2.827433388230814, 4.29350995990605}, {2.827433388230814, \
4.39822971502571}, {2.9321531433504733, 4.39822971502571}, 
    {2.9321531433504733, 4.29350995990605}, {2.827433388230814, \
4.29350995990605}}], 
  Line[{{2.827433388230814, 4.39822971502571}, {2.827433388230814, \
4.50294947014537}, {2.9321531433504733, 4.50294947014537}, 
    {2.9321531433504733, 4.39822971502571}, {2.827433388230814, \
4.39822971502571}}], 
  Line[{{2.827433388230814, 4.50294947014537}, {2.827433388230814, \
4.607669225265029}, {2.9321531433504733, 4.607669225265029}, 
    {2.9321531433504733, 4.50294947014537}, {2.827433388230814, \
4.50294947014537}}], 
  Line[{{2.827433388230814, 4.607669225265029}, {2.827433388230814, \
4.71238898038469}, {2.9321531433504733, 4.71238898038469}, 
    {2.9321531433504733, 4.607669225265029}, {2.827433388230814, \
4.607669225265029}}], 
  Line[{{2.827433388230814, 4.71238898038469}, {2.827433388230814, \
4.817108735504349}, {2.9321531433504733, 4.817108735504349}, 
    {2.9321531433504733, 4.71238898038469}, {2.827433388230814, \
4.71238898038469}}], 
  Line[{{2.827433388230814, 4.817108735504349}, {2.827433388230814, \
4.921828490624009}, {2.9321531433504733, 4.921828490624009}, 
    {2.9321531433504733, 4.817108735504349}, {2.827433388230814, \
4.817108735504349}}], 
  Line[{{2.827433388230814, 4.921828490624009}, {2.827433388230814, \
5.026548245743669}, {2.9321531433504733, 5.026548245743669}, 
    {2.9321531433504733, 4.921828490624009}, {2.827433388230814, \
4.921828490624009}}], 
  Line[{{2.827433388230814, 5.026548245743669}, {2.827433388230814, \
5.1312680008633285}, {2.9321531433504733, 5.1312680008633285}, 
    {2.9321531433504733, 5.026548245743669}, {2.827433388230814, \
5.026548245743669}}], 
  Line[{{2.827433388230814, 5.1312680008633285}, {2.827433388230814, \
5.235987755982988}, {2.9321531433504733, 5.235987755982988}, 
    {2.9321531433504733, 5.1312680008633285}, {2.827433388230814, \
5.1312680008633285}}], 
  Line[{{2.827433388230814, 5.235987755982988}, {2.827433388230814, \
5.340707511102648}, {2.9321531433504733, 5.340707511102648}, 
    {2.9321531433504733, 5.235987755982988}, {2.827433388230814, \
5.235987755982988}}], 
  Line[{{2.827433388230814, 5.340707511102648}, {2.827433388230814, \
5.445427266222308}, {2.9321531433504733, 5.445427266222308}, 
    {2.9321531433504733, 5.340707511102648}, {2.827433388230814, \
5.340707511102648}}], 
  Line[{{2.827433388230814, 5.445427266222308}, {2.827433388230814, \
5.550147021341967}, {2.9321531433504733, 5.550147021341967}, 
    {2.9321531433504733, 5.445427266222308}, {2.827433388230814, \
5.445427266222308}}], 
  Line[{{2.827433388230814, 5.550147021341967}, {2.827433388230814, \
5.654866776461628}, {2.9321531433504733, 5.654866776461628}, 
    {2.9321531433504733, 5.550147021341967}, {2.827433388230814, \
5.550147021341967}}], 
  Line[{{2.827433388230814, 5.654866776461628}, {2.827433388230814, \
5.759586531581287}, {2.9321531433504733, 5.759586531581287}, 
    {2.9321531433504733, 5.654866776461628}, {2.827433388230814, \
5.654866776461628}}], 
  Line[{{2.827433388230814, 5.759586531581287}, {2.827433388230814, \
5.864306286700947}, {2.9321531433504733, 5.864306286700947}, 
    {2.9321531433504733, 5.759586531581287}, {2.827433388230814, \
5.759586531581287}}], 
  Line[{{2.827433388230814, 5.864306286700947}, {2.827433388230814, \
5.969026041820607}, {2.9321531433504733, 5.969026041820607}, 
    {2.9321531433504733, 5.864306286700947}, {2.827433388230814, \
5.864306286700947}}], 
  Line[{{2.827433388230814, 5.969026041820607}, {2.827433388230814, \
6.073745796940266}, {2.9321531433504733, 6.073745796940266}, 
    {2.9321531433504733, 5.969026041820607}, {2.827433388230814, \
5.969026041820607}}], 
  Line[{{2.827433388230814, 6.073745796940266}, {2.827433388230814, \
6.178465552059926}, {2.9321531433504733, 6.178465552059926}, 
    {2.9321531433504733, 6.073745796940266}, {2.827433388230814, \
6.073745796940266}}], 
  Line[{{2.827433388230814, 6.178465552059926}, {2.827433388230814, \
6.283185307179586}, {2.9321531433504733, 6.283185307179586}, 
    {2.9321531433504733, 6.178465552059926}, {2.827433388230814, \
6.178465552059926}}], 
  Line[{{2.9321531433504733, 0.}, {2.9321531433504733, 0.10471975511965977}, \
{3.036872898470133, 0.10471975511965977}, {3.036872898470133, 0.}, 
    {2.9321531433504733, 0.}}], Line[{{2.9321531433504733, \
0.10471975511965977}, {2.9321531433504733, 0.20943951023931953}, 
    {3.036872898470133, 0.20943951023931953}, {3.036872898470133, \
0.10471975511965977}, {2.9321531433504733, 0.10471975511965977}}], 
  Line[{{2.9321531433504733, 0.20943951023931953}, {2.9321531433504733, \
0.3141592653589793}, {3.036872898470133, 0.3141592653589793}, 
    {3.036872898470133, 0.20943951023931953}, {2.9321531433504733, \
0.20943951023931953}}], 
  Line[{{2.9321531433504733, 0.3141592653589793}, {2.9321531433504733, \
0.41887902047863906}, {3.036872898470133, 0.41887902047863906}, 
    {3.036872898470133, 0.3141592653589793}, {2.9321531433504733, \
0.3141592653589793}}], 
  Line[{{2.9321531433504733, 0.41887902047863906}, {2.9321531433504733, \
0.5235987755982988}, {3.036872898470133, 0.5235987755982988}, 
    {3.036872898470133, 0.41887902047863906}, {2.9321531433504733, \
0.41887902047863906}}], 
  Line[{{2.9321531433504733, 0.5235987755982988}, {2.9321531433504733, \
0.6283185307179586}, {3.036872898470133, 0.6283185307179586}, 
    {3.036872898470133, 0.5235987755982988}, {2.9321531433504733, \
0.5235987755982988}}], 
  Line[{{2.9321531433504733, 0.6283185307179586}, {2.9321531433504733, \
0.7330382858376183}, {3.036872898470133, 0.7330382858376183}, 
    {3.036872898470133, 0.6283185307179586}, {2.9321531433504733, \
0.6283185307179586}}], 
  Line[{{2.9321531433504733, 0.7330382858376183}, {2.9321531433504733, \
0.8377580409572781}, {3.036872898470133, 0.8377580409572781}, 
    {3.036872898470133, 0.7330382858376183}, {2.9321531433504733, \
0.7330382858376183}}], 
  Line[{{2.9321531433504733, 0.8377580409572781}, {2.9321531433504733, \
0.9424777960769379}, {3.036872898470133, 0.9424777960769379}, 
    {3.036872898470133, 0.8377580409572781}, {2.9321531433504733, \
0.8377580409572781}}], 
  Line[{{2.9321531433504733, 0.9424777960769379}, {2.9321531433504733, \
1.0471975511965976}, {3.036872898470133, 1.0471975511965976}, 
    {3.036872898470133, 0.9424777960769379}, {2.9321531433504733, \
0.9424777960769379}}], 
  Line[{{2.9321531433504733, 1.0471975511965976}, {2.9321531433504733, \
1.1519173063162573}, {3.036872898470133, 1.1519173063162573}, 
    {3.036872898470133, 1.0471975511965976}, {2.9321531433504733, \
1.0471975511965976}}], 
  Line[{{2.9321531433504733, 1.1519173063162573}, {2.9321531433504733, \
1.2566370614359172}, {3.036872898470133, 1.2566370614359172}, 
    {3.036872898470133, 1.1519173063162573}, {2.9321531433504733, \
1.1519173063162573}}], 
  Line[{{2.9321531433504733, 1.2566370614359172}, {2.9321531433504733, \
1.361356816555577}, {3.036872898470133, 1.361356816555577}, 
    {3.036872898470133, 1.2566370614359172}, {2.9321531433504733, \
1.2566370614359172}}], 
  Line[{{2.9321531433504733, 1.361356816555577}, {2.9321531433504733, \
1.4660765716752366}, {3.036872898470133, 1.4660765716752366}, 
    {3.036872898470133, 1.361356816555577}, {2.9321531433504733, \
1.361356816555577}}], 
  Line[{{2.9321531433504733, 1.4660765716752366}, {2.9321531433504733, \
1.5707963267948966}, {3.036872898470133, 1.5707963267948966}, 
    {3.036872898470133, 1.4660765716752366}, {2.9321531433504733, \
1.4660765716752366}}], 
  Line[{{2.9321531433504733, 1.5707963267948966}, {2.9321531433504733, \
1.6755160819145563}, {3.036872898470133, 1.6755160819145563}, 
    {3.036872898470133, 1.5707963267948966}, {2.9321531433504733, \
1.5707963267948966}}], 
  Line[{{2.9321531433504733, 1.6755160819145563}, {2.9321531433504733, \
1.780235837034216}, {3.036872898470133, 1.780235837034216}, 
    {3.036872898470133, 1.6755160819145563}, {2.9321531433504733, \
1.6755160819145563}}], 
  Line[{{2.9321531433504733, 1.780235837034216}, {2.9321531433504733, \
1.8849555921538759}, {3.036872898470133, 1.8849555921538759}, 
    {3.036872898470133, 1.780235837034216}, {2.9321531433504733, \
1.780235837034216}}], 
  Line[{{2.9321531433504733, 1.8849555921538759}, {2.9321531433504733, \
1.9896753472735356}, {3.036872898470133, 1.9896753472735356}, 
    {3.036872898470133, 1.8849555921538759}, {2.9321531433504733, \
1.8849555921538759}}], 
  Line[{{2.9321531433504733, 1.9896753472735356}, {2.9321531433504733, \
2.0943951023931953}, {3.036872898470133, 2.0943951023931953}, 
    {3.036872898470133, 1.9896753472735356}, {2.9321531433504733, \
1.9896753472735356}}], 
  Line[{{2.9321531433504733, 2.0943951023931953}, {2.9321531433504733, \
2.199114857512855}, {3.036872898470133, 2.199114857512855}, 
    {3.036872898470133, 2.0943951023931953}, {2.9321531433504733, \
2.0943951023931953}}], 
  Line[{{2.9321531433504733, 2.199114857512855}, {2.9321531433504733, \
2.3038346126325147}, {3.036872898470133, 2.3038346126325147}, 
    {3.036872898470133, 2.199114857512855}, {2.9321531433504733, \
2.199114857512855}}], 
  Line[{{2.9321531433504733, 2.3038346126325147}, {2.9321531433504733, \
2.4085543677521746}, {3.036872898470133, 2.4085543677521746}, 
    {3.036872898470133, 2.3038346126325147}, {2.9321531433504733, \
2.3038346126325147}}], 
  Line[{{2.9321531433504733, 2.4085543677521746}, {2.9321531433504733, \
2.5132741228718345}, {3.036872898470133, 2.5132741228718345}, 
    {3.036872898470133, 2.4085543677521746}, {2.9321531433504733, \
2.4085543677521746}}], 
  Line[{{2.9321531433504733, 2.5132741228718345}, {2.9321531433504733, \
2.617993877991494}, {3.036872898470133, 2.617993877991494}, 
    {3.036872898470133, 2.5132741228718345}, {2.9321531433504733, \
2.5132741228718345}}], 
  Line[{{2.9321531433504733, 2.617993877991494}, {2.9321531433504733, \
2.722713633111154}, {3.036872898470133, 2.722713633111154}, 
    {3.036872898470133, 2.617993877991494}, {2.9321531433504733, \
2.617993877991494}}], 
  Line[{{2.9321531433504733, 2.722713633111154}, {2.9321531433504733, \
2.827433388230814}, {3.036872898470133, 2.827433388230814}, 
    {3.036872898470133, 2.722713633111154}, {2.9321531433504733, \
2.722713633111154}}], 
  Line[{{2.9321531433504733, 2.827433388230814}, {2.9321531433504733, \
2.9321531433504733}, {3.036872898470133, 2.9321531433504733}, 
    {3.036872898470133, 2.827433388230814}, {2.9321531433504733, \
2.827433388230814}}], 
  Line[{{2.9321531433504733, 2.9321531433504733}, {2.9321531433504733, \
3.036872898470133}, {3.036872898470133, 3.036872898470133}, 
    {3.036872898470133, 2.9321531433504733}, {2.9321531433504733, \
2.9321531433504733}}], 
  Line[{{2.9321531433504733, 3.036872898470133}, {2.9321531433504733, \
3.141592653589793}, {3.036872898470133, 3.141592653589793}, 
    {3.036872898470133, 3.036872898470133}, {2.9321531433504733, \
3.036872898470133}}], 
  Line[{{2.9321531433504733, 3.141592653589793}, {2.9321531433504733, \
3.2463124087094526}, {3.036872898470133, 3.2463124087094526}, 
    {3.036872898470133, 3.141592653589793}, {2.9321531433504733, \
3.141592653589793}}], 
  Line[{{2.9321531433504733, 3.2463124087094526}, {2.9321531433504733, \
3.3510321638291125}, {3.036872898470133, 3.3510321638291125}, 
    {3.036872898470133, 3.2463124087094526}, {2.9321531433504733, \
3.2463124087094526}}], 
  Line[{{2.9321531433504733, 3.3510321638291125}, {2.9321531433504733, \
3.4557519189487724}, {3.036872898470133, 3.4557519189487724}, 
    {3.036872898470133, 3.3510321638291125}, {2.9321531433504733, \
3.3510321638291125}}], 
  Line[{{2.9321531433504733, 3.4557519189487724}, {2.9321531433504733, \
3.560471674068432}, {3.036872898470133, 3.560471674068432}, 
    {3.036872898470133, 3.4557519189487724}, {2.9321531433504733, \
3.4557519189487724}}], 
  Line[{{2.9321531433504733, 3.560471674068432}, {2.9321531433504733, \
3.665191429188092}, {3.036872898470133, 3.665191429188092}, 
    {3.036872898470133, 3.560471674068432}, {2.9321531433504733, \
3.560471674068432}}], 
  Line[{{2.9321531433504733, 3.665191429188092}, {2.9321531433504733, \
3.7699111843077517}, {3.036872898470133, 3.7699111843077517}, 
    {3.036872898470133, 3.665191429188092}, {2.9321531433504733, \
3.665191429188092}}], 
  Line[{{2.9321531433504733, 3.7699111843077517}, {2.9321531433504733, \
3.874630939427411}, {3.036872898470133, 3.874630939427411}, 
    {3.036872898470133, 3.7699111843077517}, {2.9321531433504733, \
3.7699111843077517}}], 
  Line[{{2.9321531433504733, 3.874630939427411}, {2.9321531433504733, \
3.979350694547071}, {3.036872898470133, 3.979350694547071}, 
    {3.036872898470133, 3.874630939427411}, {2.9321531433504733, \
3.874630939427411}}], 
  Line[{{2.9321531433504733, 3.979350694547071}, {2.9321531433504733, \
4.084070449666731}, {3.036872898470133, 4.084070449666731}, 
    {3.036872898470133, 3.979350694547071}, {2.9321531433504733, \
3.979350694547071}}], 
  Line[{{2.9321531433504733, 4.084070449666731}, {2.9321531433504733, \
4.1887902047863905}, {3.036872898470133, 4.1887902047863905}, 
    {3.036872898470133, 4.084070449666731}, {2.9321531433504733, \
4.084070449666731}}], 
  Line[{{2.9321531433504733, 4.1887902047863905}, {2.9321531433504733, \
4.29350995990605}, {3.036872898470133, 4.29350995990605}, 
    {3.036872898470133, 4.1887902047863905}, {2.9321531433504733, \
4.1887902047863905}}], 
  Line[{{2.9321531433504733, 4.29350995990605}, {2.9321531433504733, \
4.39822971502571}, {3.036872898470133, 4.39822971502571}, 
    {3.036872898470133, 4.29350995990605}, {2.9321531433504733, \
4.29350995990605}}], 
  Line[{{2.9321531433504733, 4.39822971502571}, {2.9321531433504733, \
4.50294947014537}, {3.036872898470133, 4.50294947014537}, 
    {3.036872898470133, 4.39822971502571}, {2.9321531433504733, \
4.39822971502571}}], 
  Line[{{2.9321531433504733, 4.50294947014537}, {2.9321531433504733, \
4.607669225265029}, {3.036872898470133, 4.607669225265029}, 
    {3.036872898470133, 4.50294947014537}, {2.9321531433504733, \
4.50294947014537}}], 
  Line[{{2.9321531433504733, 4.607669225265029}, {2.9321531433504733, \
4.71238898038469}, {3.036872898470133, 4.71238898038469}, 
    {3.036872898470133, 4.607669225265029}, {2.9321531433504733, \
4.607669225265029}}], 
  Line[{{2.9321531433504733, 4.71238898038469}, {2.9321531433504733, \
4.817108735504349}, {3.036872898470133, 4.817108735504349}, 
    {3.036872898470133, 4.71238898038469}, {2.9321531433504733, \
4.71238898038469}}], 
  Line[{{2.9321531433504733, 4.817108735504349}, {2.9321531433504733, \
4.921828490624009}, {3.036872898470133, 4.921828490624009}, 
    {3.036872898470133, 4.817108735504349}, {2.9321531433504733, \
4.817108735504349}}], 
  Line[{{2.9321531433504733, 4.921828490624009}, {2.9321531433504733, \
5.026548245743669}, {3.036872898470133, 5.026548245743669}, 
    {3.036872898470133, 4.921828490624009}, {2.9321531433504733, \
4.921828490624009}}], 
  Line[{{2.9321531433504733, 5.026548245743669}, {2.9321531433504733, \
5.1312680008633285}, {3.036872898470133, 5.1312680008633285}, 
    {3.036872898470133, 5.026548245743669}, {2.9321531433504733, \
5.026548245743669}}], 
  Line[{{2.9321531433504733, 5.1312680008633285}, {2.9321531433504733, \
5.235987755982988}, {3.036872898470133, 5.235987755982988}, 
    {3.036872898470133, 5.1312680008633285}, {2.9321531433504733, \
5.1312680008633285}}], 
  Line[{{2.9321531433504733, 5.235987755982988}, {2.9321531433504733, \
5.340707511102648}, {3.036872898470133, 5.340707511102648}, 
    {3.036872898470133, 5.235987755982988}, {2.9321531433504733, \
5.235987755982988}}], 
  Line[{{2.9321531433504733, 5.340707511102648}, {2.9321531433504733, \
5.445427266222308}, {3.036872898470133, 5.445427266222308}, 
    {3.036872898470133, 5.340707511102648}, {2.9321531433504733, \
5.340707511102648}}], 
  Line[{{2.9321531433504733, 5.445427266222308}, {2.9321531433504733, \
5.550147021341967}, {3.036872898470133, 5.550147021341967}, 
    {3.036872898470133, 5.445427266222308}, {2.9321531433504733, \
5.445427266222308}}], 
  Line[{{2.9321531433504733, 5.550147021341967}, {2.9321531433504733, \
5.654866776461628}, {3.036872898470133, 5.654866776461628}, 
    {3.036872898470133, 5.550147021341967}, {2.9321531433504733, \
5.550147021341967}}], 
  Line[{{2.9321531433504733, 5.654866776461628}, {2.9321531433504733, \
5.759586531581287}, {3.036872898470133, 5.759586531581287}, 
    {3.036872898470133, 5.654866776461628}, {2.9321531433504733, \
5.654866776461628}}], 
  Line[{{2.9321531433504733, 5.759586531581287}, {2.9321531433504733, \
5.864306286700947}, {3.036872898470133, 5.864306286700947}, 
    {3.036872898470133, 5.759586531581287}, {2.9321531433504733, \
5.759586531581287}}], 
  Line[{{2.9321531433504733, 5.864306286700947}, {2.9321531433504733, \
5.969026041820607}, {3.036872898470133, 5.969026041820607}, 
    {3.036872898470133, 5.864306286700947}, {2.9321531433504733, \
5.864306286700947}}], 
  Line[{{2.9321531433504733, 5.969026041820607}, {2.9321531433504733, \
6.073745796940266}, {3.036872898470133, 6.073745796940266}, 
    {3.036872898470133, 5.969026041820607}, {2.9321531433504733, \
5.969026041820607}}], 
  Line[{{2.9321531433504733, 6.073745796940266}, {2.9321531433504733, \
6.178465552059926}, {3.036872898470133, 6.178465552059926}, 
    {3.036872898470133, 6.073745796940266}, {2.9321531433504733, \
6.073745796940266}}], 
  Line[{{2.9321531433504733, 6.178465552059926}, {2.9321531433504733, \
6.283185307179586}, {3.036872898470133, 6.283185307179586}, 
    {3.036872898470133, 6.178465552059926}, {2.9321531433504733, \
6.178465552059926}}], 
  Line[{{3.036872898470133, 0.}, {3.036872898470133, 0.10471975511965977}, \
{3.141592653589793, 0.10471975511965977}, {3.141592653589793, 0.}, 
    {3.036872898470133, 0.}}], Line[{{3.036872898470133, \
0.10471975511965977}, {3.036872898470133, 0.20943951023931953}, 
    {3.141592653589793, 0.20943951023931953}, {3.141592653589793, \
0.10471975511965977}, {3.036872898470133, 0.10471975511965977}}], 
  Line[{{3.036872898470133, 0.20943951023931953}, {3.036872898470133, \
0.3141592653589793}, {3.141592653589793, 0.3141592653589793}, 
    {3.141592653589793, 0.20943951023931953}, {3.036872898470133, \
0.20943951023931953}}], 
  Line[{{3.036872898470133, 0.3141592653589793}, {3.036872898470133, \
0.41887902047863906}, {3.141592653589793, 0.41887902047863906}, 
    {3.141592653589793, 0.3141592653589793}, {3.036872898470133, \
0.3141592653589793}}], 
  Line[{{3.036872898470133, 0.41887902047863906}, {3.036872898470133, \
0.5235987755982988}, {3.141592653589793, 0.5235987755982988}, 
    {3.141592653589793, 0.41887902047863906}, {3.036872898470133, \
0.41887902047863906}}], 
  Line[{{3.036872898470133, 0.5235987755982988}, {3.036872898470133, \
0.6283185307179586}, {3.141592653589793, 0.6283185307179586}, 
    {3.141592653589793, 0.5235987755982988}, {3.036872898470133, \
0.5235987755982988}}], 
  Line[{{3.036872898470133, 0.6283185307179586}, {3.036872898470133, \
0.7330382858376183}, {3.141592653589793, 0.7330382858376183}, 
    {3.141592653589793, 0.6283185307179586}, {3.036872898470133, \
0.6283185307179586}}], 
  Line[{{3.036872898470133, 0.7330382858376183}, {3.036872898470133, \
0.8377580409572781}, {3.141592653589793, 0.8377580409572781}, 
    {3.141592653589793, 0.7330382858376183}, {3.036872898470133, \
0.7330382858376183}}], 
  Line[{{3.036872898470133, 0.8377580409572781}, {3.036872898470133, \
0.9424777960769379}, {3.141592653589793, 0.9424777960769379}, 
    {3.141592653589793, 0.8377580409572781}, {3.036872898470133, \
0.8377580409572781}}], 
  Line[{{3.036872898470133, 0.9424777960769379}, {3.036872898470133, \
1.0471975511965976}, {3.141592653589793, 1.0471975511965976}, 
    {3.141592653589793, 0.9424777960769379}, {3.036872898470133, \
0.9424777960769379}}], 
  Line[{{3.036872898470133, 1.0471975511965976}, {3.036872898470133, \
1.1519173063162573}, {3.141592653589793, 1.1519173063162573}, 
    {3.141592653589793, 1.0471975511965976}, {3.036872898470133, \
1.0471975511965976}}], 
  Line[{{3.036872898470133, 1.1519173063162573}, {3.036872898470133, \
1.2566370614359172}, {3.141592653589793, 1.2566370614359172}, 
    {3.141592653589793, 1.1519173063162573}, {3.036872898470133, \
1.1519173063162573}}], 
  Line[{{3.036872898470133, 1.2566370614359172}, {3.036872898470133, \
1.361356816555577}, {3.141592653589793, 1.361356816555577}, 
    {3.141592653589793, 1.2566370614359172}, {3.036872898470133, \
1.2566370614359172}}], 
  Line[{{3.036872898470133, 1.361356816555577}, {3.036872898470133, \
1.4660765716752366}, {3.141592653589793, 1.4660765716752366}, 
    {3.141592653589793, 1.361356816555577}, {3.036872898470133, \
1.361356816555577}}], 
  Line[{{3.036872898470133, 1.4660765716752366}, {3.036872898470133, \
1.5707963267948966}, {3.141592653589793, 1.5707963267948966}, 
    {3.141592653589793, 1.4660765716752366}, {3.036872898470133, \
1.4660765716752366}}], 
  Line[{{3.036872898470133, 1.5707963267948966}, {3.036872898470133, \
1.6755160819145563}, {3.141592653589793, 1.6755160819145563}, 
    {3.141592653589793, 1.5707963267948966}, {3.036872898470133, \
1.5707963267948966}}], 
  Line[{{3.036872898470133, 1.6755160819145563}, {3.036872898470133, \
1.780235837034216}, {3.141592653589793, 1.780235837034216}, 
    {3.141592653589793, 1.6755160819145563}, {3.036872898470133, \
1.6755160819145563}}], 
  Line[{{3.036872898470133, 1.780235837034216}, {3.036872898470133, \
1.8849555921538759}, {3.141592653589793, 1.8849555921538759}, 
    {3.141592653589793, 1.780235837034216}, {3.036872898470133, \
1.780235837034216}}], 
  Line[{{3.036872898470133, 1.8849555921538759}, {3.036872898470133, \
1.9896753472735356}, {3.141592653589793, 1.9896753472735356}, 
    {3.141592653589793, 1.8849555921538759}, {3.036872898470133, \
1.8849555921538759}}], 
  Line[{{3.036872898470133, 1.9896753472735356}, {3.036872898470133, \
2.0943951023931953}, {3.141592653589793, 2.0943951023931953}, 
    {3.141592653589793, 1.9896753472735356}, {3.036872898470133, \
1.9896753472735356}}], 
  Line[{{3.036872898470133, 2.0943951023931953}, {3.036872898470133, \
2.199114857512855}, {3.141592653589793, 2.199114857512855}, 
    {3.141592653589793, 2.0943951023931953}, {3.036872898470133, \
2.0943951023931953}}], 
  Line[{{3.036872898470133, 2.199114857512855}, {3.036872898470133, \
2.3038346126325147}, {3.141592653589793, 2.3038346126325147}, 
    {3.141592653589793, 2.199114857512855}, {3.036872898470133, \
2.199114857512855}}], 
  Line[{{3.036872898470133, 2.3038346126325147}, {3.036872898470133, \
2.4085543677521746}, {3.141592653589793, 2.4085543677521746}, 
    {3.141592653589793, 2.3038346126325147}, {3.036872898470133, \
2.3038346126325147}}], 
  Line[{{3.036872898470133, 2.4085543677521746}, {3.036872898470133, \
2.5132741228718345}, {3.141592653589793, 2.5132741228718345}, 
    {3.141592653589793, 2.4085543677521746}, {3.036872898470133, \
2.4085543677521746}}], 
  Line[{{3.036872898470133, 2.5132741228718345}, {3.036872898470133, \
2.617993877991494}, {3.141592653589793, 2.617993877991494}, 
    {3.141592653589793, 2.5132741228718345}, {3.036872898470133, \
2.5132741228718345}}], 
  Line[{{3.036872898470133, 2.617993877991494}, {3.036872898470133, \
2.722713633111154}, {3.141592653589793, 2.722713633111154}, 
    {3.141592653589793, 2.617993877991494}, {3.036872898470133, \
2.617993877991494}}], 
  Line[{{3.036872898470133, 2.722713633111154}, {3.036872898470133, \
2.827433388230814}, {3.141592653589793, 2.827433388230814}, 
    {3.141592653589793, 2.722713633111154}, {3.036872898470133, \
2.722713633111154}}], 
  Line[{{3.036872898470133, 2.827433388230814}, {3.036872898470133, \
2.9321531433504733}, {3.141592653589793, 2.9321531433504733}, 
    {3.141592653589793, 2.827433388230814}, {3.036872898470133, \
2.827433388230814}}], 
  Line[{{3.036872898470133, 2.9321531433504733}, {3.036872898470133, \
3.036872898470133}, {3.141592653589793, 3.036872898470133}, 
    {3.141592653589793, 2.9321531433504733}, {3.036872898470133, \
2.9321531433504733}}], 
  Line[{{3.036872898470133, 3.036872898470133}, {3.036872898470133, \
3.141592653589793}, {3.141592653589793, 3.141592653589793}, 
    {3.141592653589793, 3.036872898470133}, {3.036872898470133, \
3.036872898470133}}], 
  Line[{{3.036872898470133, 3.141592653589793}, {3.036872898470133, \
3.2463124087094526}, {3.141592653589793, 3.2463124087094526}, 
    {3.141592653589793, 3.141592653589793}, {3.036872898470133, \
3.141592653589793}}], 
  Line[{{3.036872898470133, 3.2463124087094526}, {3.036872898470133, \
3.3510321638291125}, {3.141592653589793, 3.3510321638291125}, 
    {3.141592653589793, 3.2463124087094526}, {3.036872898470133, \
3.2463124087094526}}], 
  Line[{{3.036872898470133, 3.3510321638291125}, {3.036872898470133, \
3.4557519189487724}, {3.141592653589793, 3.4557519189487724}, 
    {3.141592653589793, 3.3510321638291125}, {3.036872898470133, \
3.3510321638291125}}], 
  Line[{{3.036872898470133, 3.4557519189487724}, {3.036872898470133, \
3.560471674068432}, {3.141592653589793, 3.560471674068432}, 
    {3.141592653589793, 3.4557519189487724}, {3.036872898470133, \
3.4557519189487724}}], 
  Line[{{3.036872898470133, 3.560471674068432}, {3.036872898470133, \
3.665191429188092}, {3.141592653589793, 3.665191429188092}, 
    {3.141592653589793, 3.560471674068432}, {3.036872898470133, \
3.560471674068432}}], 
  Line[{{3.036872898470133, 3.665191429188092}, {3.036872898470133, \
3.7699111843077517}, {3.141592653589793, 3.7699111843077517}, 
    {3.141592653589793, 3.665191429188092}, {3.036872898470133, \
3.665191429188092}}], 
  Line[{{3.036872898470133, 3.7699111843077517}, {3.036872898470133, \
3.874630939427411}, {3.141592653589793, 3.874630939427411}, 
    {3.141592653589793, 3.7699111843077517}, {3.036872898470133, \
3.7699111843077517}}], 
  Line[{{3.036872898470133, 3.874630939427411}, {3.036872898470133, \
3.979350694547071}, {3.141592653589793, 3.979350694547071}, 
    {3.141592653589793, 3.874630939427411}, {3.036872898470133, \
3.874630939427411}}], 
  Line[{{3.036872898470133, 3.979350694547071}, {3.036872898470133, \
4.084070449666731}, {3.141592653589793, 4.084070449666731}, 
    {3.141592653589793, 3.979350694547071}, {3.036872898470133, \
3.979350694547071}}], 
  Line[{{3.036872898470133, 4.084070449666731}, {3.036872898470133, \
4.1887902047863905}, {3.141592653589793, 4.1887902047863905}, 
    {3.141592653589793, 4.084070449666731}, {3.036872898470133, \
4.084070449666731}}], 
  Line[{{3.036872898470133, 4.1887902047863905}, {3.036872898470133, \
4.29350995990605}, {3.141592653589793, 4.29350995990605}, 
    {3.141592653589793, 4.1887902047863905}, {3.036872898470133, \
4.1887902047863905}}], 
  Line[{{3.036872898470133, 4.29350995990605}, {3.036872898470133, \
4.39822971502571}, {3.141592653589793, 4.39822971502571}, 
    {3.141592653589793, 4.29350995990605}, {3.036872898470133, \
4.29350995990605}}], 
  Line[{{3.036872898470133, 4.39822971502571}, {3.036872898470133, \
4.50294947014537}, {3.141592653589793, 4.50294947014537}, 
    {3.141592653589793, 4.39822971502571}, {3.036872898470133, \
4.39822971502571}}], 
  Line[{{3.036872898470133, 4.50294947014537}, {3.036872898470133, \
4.607669225265029}, {3.141592653589793, 4.607669225265029}, 
    {3.141592653589793, 4.50294947014537}, {3.036872898470133, \
4.50294947014537}}], 
  Line[{{3.036872898470133, 4.607669225265029}, {3.036872898470133, \
4.71238898038469}, {3.141592653589793, 4.71238898038469}, 
    {3.141592653589793, 4.607669225265029}, {3.036872898470133, \
4.607669225265029}}], 
  Line[{{3.036872898470133, 4.71238898038469}, {3.036872898470133, \
4.817108735504349}, {3.141592653589793, 4.817108735504349}, 
    {3.141592653589793, 4.71238898038469}, {3.036872898470133, \
4.71238898038469}}], 
  Line[{{3.036872898470133, 4.817108735504349}, {3.036872898470133, \
4.921828490624009}, {3.141592653589793, 4.921828490624009}, 
    {3.141592653589793, 4.817108735504349}, {3.036872898470133, \
4.817108735504349}}], 
  Line[{{3.036872898470133, 4.921828490624009}, {3.036872898470133, \
5.026548245743669}, {3.141592653589793, 5.026548245743669}, 
    {3.141592653589793, 4.921828490624009}, {3.036872898470133, \
4.921828490624009}}], 
  Line[{{3.036872898470133, 5.026548245743669}, {3.036872898470133, \
5.1312680008633285}, {3.141592653589793, 5.1312680008633285}, 
    {3.141592653589793, 5.026548245743669}, {3.036872898470133, \
5.026548245743669}}], 
  Line[{{3.036872898470133, 5.1312680008633285}, {3.036872898470133, \
5.235987755982988}, {3.141592653589793, 5.235987755982988}, 
    {3.141592653589793, 5.1312680008633285}, {3.036872898470133, \
5.1312680008633285}}], 
  Line[{{3.036872898470133, 5.235987755982988}, {3.036872898470133, \
5.340707511102648}, {3.141592653589793, 5.340707511102648}, 
    {3.141592653589793, 5.235987755982988}, {3.036872898470133, \
5.235987755982988}}], 
  Line[{{3.036872898470133, 5.340707511102648}, {3.036872898470133, \
5.445427266222308}, {3.141592653589793, 5.445427266222308}, 
    {3.141592653589793, 5.340707511102648}, {3.036872898470133, \
5.340707511102648}}], 
  Line[{{3.036872898470133, 5.445427266222308}, {3.036872898470133, \
5.550147021341967}, {3.141592653589793, 5.550147021341967}, 
    {3.141592653589793, 5.445427266222308}, {3.036872898470133, \
5.445427266222308}}], 
  Line[{{3.036872898470133, 5.550147021341967}, {3.036872898470133, \
5.654866776461628}, {3.141592653589793, 5.654866776461628}, 
    {3.141592653589793, 5.550147021341967}, {3.036872898470133, \
5.550147021341967}}], 
  Line[{{3.036872898470133, 5.654866776461628}, {3.036872898470133, \
5.759586531581287}, {3.141592653589793, 5.759586531581287}, 
    {3.141592653589793, 5.654866776461628}, {3.036872898470133, \
5.654866776461628}}], 
  Line[{{3.036872898470133, 5.759586531581287}, {3.036872898470133, \
5.864306286700947}, {3.141592653589793, 5.864306286700947}, 
    {3.141592653589793, 5.759586531581287}, {3.036872898470133, \
5.759586531581287}}], 
  Line[{{3.036872898470133, 5.864306286700947}, {3.036872898470133, \
5.969026041820607}, {3.141592653589793, 5.969026041820607}, 
    {3.141592653589793, 5.864306286700947}, {3.036872898470133, \
5.864306286700947}}], 
  Line[{{3.036872898470133, 5.969026041820607}, {3.036872898470133, \
6.073745796940266}, {3.141592653589793, 6.073745796940266}, 
    {3.141592653589793, 5.969026041820607}, {3.036872898470133, \
5.969026041820607}}], 
  Line[{{3.036872898470133, 6.073745796940266}, {3.036872898470133, \
6.178465552059926}, {3.141592653589793, 6.178465552059926}, 
    {3.141592653589793, 6.073745796940266}, {3.036872898470133, \
6.073745796940266}}], 
  Line[{{3.036872898470133, 6.178465552059926}, {3.036872898470133, \
6.283185307179586}, {3.141592653589793, 6.283185307179586}, 
    {3.141592653589793, 6.178465552059926}, {3.036872898470133, \
6.178465552059926}}]}, {}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell["", "Input"],

Cell[CellGroupData[{

Cell["\<\
mohrfill =  Graphics /@ Transpose[ {colorlist, Polygon /@ thequads} ];
mohrmesh = Graphics /@ ( ClosedLine /@ thequads) ;
Show[  mohrfill,mohrmesh , Axes -> True , AspectRatio -> Automatic]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49726 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.15873 0.0118395 0.15873 [
[.02381 -0.00066 -6 -9 ]
[.02381 -0.00066 6 0 ]
[.34127 -0.00066 -3 -9 ]
[.34127 -0.00066 3 0 ]
[.5 -0.00066 -3 -9 ]
[.5 -0.00066 3 0 ]
[.65873 -0.00066 -3 -9 ]
[.65873 -0.00066 3 0 ]
[.81746 -0.00066 -3 -9 ]
[.81746 -0.00066 3 0 ]
[.97619 -0.00066 -3 -9 ]
[.97619 -0.00066 3 0 ]
[.17004 .0912 -18 -4.5 ]
[.17004 .0912 0 4.5 ]
[.17004 .17057 -6 -4.5 ]
[.17004 .17057 0 4.5 ]
[.17004 .24993 -18 -4.5 ]
[.17004 .24993 0 4.5 ]
[.17004 .3293 -6 -4.5 ]
[.17004 .3293 0 4.5 ]
[.17004 .40866 -18 -4.5 ]
[.17004 .40866 0 4.5 ]
[.17004 .48803 -6 -4.5 ]
[.17004 .48803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .49726 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01184 m
.02381 .01809 L
s
[(-1)] .02381 -0.00066 0 1 Mshowa
.34127 .01184 m
.34127 .01809 L
s
[(1)] .34127 -0.00066 0 1 Mshowa
.5 .01184 m
.5 .01809 L
s
[(2)] .5 -0.00066 0 1 Mshowa
.65873 .01184 m
.65873 .01809 L
s
[(3)] .65873 -0.00066 0 1 Mshowa
.81746 .01184 m
.81746 .01809 L
s
[(4)] .81746 -0.00066 0 1 Mshowa
.97619 .01184 m
.97619 .01809 L
s
[(5)] .97619 -0.00066 0 1 Mshowa
.125 Mabswid
.05556 .01184 m
.05556 .01559 L
s
.0873 .01184 m
.0873 .01559 L
s
.11905 .01184 m
.11905 .01559 L
s
.15079 .01184 m
.15079 .01559 L
s
.21429 .01184 m
.21429 .01559 L
s
.24603 .01184 m
.24603 .01559 L
s
.27778 .01184 m
.27778 .01559 L
s
.30952 .01184 m
.30952 .01559 L
s
.37302 .01184 m
.37302 .01559 L
s
.40476 .01184 m
.40476 .01559 L
s
.43651 .01184 m
.43651 .01559 L
s
.46825 .01184 m
.46825 .01559 L
s
.53175 .01184 m
.53175 .01559 L
s
.56349 .01184 m
.56349 .01559 L
s
.59524 .01184 m
.59524 .01559 L
s
.62698 .01184 m
.62698 .01559 L
s
.69048 .01184 m
.69048 .01559 L
s
.72222 .01184 m
.72222 .01559 L
s
.75397 .01184 m
.75397 .01559 L
s
.78571 .01184 m
.78571 .01559 L
s
.84921 .01184 m
.84921 .01559 L
s
.88095 .01184 m
.88095 .01559 L
s
.9127 .01184 m
.9127 .01559 L
s
.94444 .01184 m
.94444 .01559 L
s
.25 Mabswid
0 .01184 m
1 .01184 L
s
.18254 .0912 m
.18879 .0912 L
s
[(0.5)] .17004 .0912 1 0 Mshowa
.18254 .17057 m
.18879 .17057 L
s
[(1)] .17004 .17057 1 0 Mshowa
.18254 .24993 m
.18879 .24993 L
s
[(1.5)] .17004 .24993 1 0 Mshowa
.18254 .3293 m
.18879 .3293 L
s
[(2)] .17004 .3293 1 0 Mshowa
.18254 .40866 m
.18879 .40866 L
s
[(2.5)] .17004 .40866 1 0 Mshowa
.18254 .48803 m
.18879 .48803 L
s
[(3)] .17004 .48803 1 0 Mshowa
.125 Mabswid
.18254 .02771 m
.18629 .02771 L
s
.18254 .04359 m
.18629 .04359 L
s
.18254 .05946 m
.18629 .05946 L
s
.18254 .07533 m
.18629 .07533 L
s
.18254 .10708 m
.18629 .10708 L
s
.18254 .12295 m
.18629 .12295 L
s
.18254 .13882 m
.18629 .13882 L
s
.18254 .1547 m
.18629 .1547 L
s
.18254 .18644 m
.18629 .18644 L
s
.18254 .20232 m
.18629 .20232 L
s
.18254 .21819 m
.18629 .21819 L
s
.18254 .23406 m
.18629 .23406 L
s
.18254 .26581 m
.18629 .26581 L
s
.18254 .28168 m
.18629 .28168 L
s
.18254 .29755 m
.18629 .29755 L
s
.18254 .31343 m
.18629 .31343 L
s
.18254 .34517 m
.18629 .34517 L
s
.18254 .36105 m
.18629 .36105 L
s
.18254 .37692 m
.18629 .37692 L
s
.18254 .39279 m
.18629 .39279 L
s
.18254 .42454 m
.18629 .42454 L
s
.18254 .44041 m
.18629 .44041 L
s
.18254 .45628 m
.18629 .45628 L
s
.18254 .47216 m
.18629 .47216 L
s
.25 Mabswid
.18254 0 m
.18254 .49726 L
s
0 0 m
1 0 L
1 .49726 L
0 .49726 L
closepath
clip
newpath
.017 .5 .008 .1 k
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03422 .11085 L
F
.017 .5 .025 .1 k
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03416 .11044 L
F
.017 .5 .042 .1 k
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03399 .10923 L
F
.017 .5 .058 .1 k
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03372 .10725 L
F
.017 .5 .075 .1 k
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03335 .10452 L
F
.017 .5 .092 .1 k
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03291 .10111 L
F
.017 .5 .108 .1 k
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03242 .09709 L
F
.017 .5 .125 .1 k
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03189 .09257 L
F
.017 .5 .142 .1 k
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03134 .08766 L
F
.017 .5 .158 .1 k
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.03081 .08253 L
F
.017 .5 .175 .1 k
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.03031 .07736 L
F
.017 .5 .192 .1 k
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02987 .07242 L
F
.017 .5 .208 .1 k
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02951 .06801 L
F
.017 .5 .225 .1 k
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02924 .06446 L
F
.017 .5 .242 .1 k
.02381 .01184 m
.02381 .01184 L
.02901 .06134 L
.02907 .06215 L
F
.017 .5 .258 .1 k
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02901 .06134 L
F
.017 .5 .275 .1 k
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02907 .06215 L
F
.017 .5 .292 .1 k
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02924 .06446 L
F
.017 .5 .308 .1 k
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.02951 .06801 L
F
.017 .5 .325 .1 k
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.02987 .07242 L
F
.017 .5 .342 .1 k
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03031 .07736 L
F
.017 .5 .358 .1 k
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03081 .08253 L
F
.017 .5 .375 .1 k
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03134 .08766 L
F
.017 .5 .392 .1 k
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03189 .09257 L
F
.017 .5 .408 .1 k
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03242 .09709 L
F
.017 .5 .425 .1 k
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03291 .10111 L
F
.017 .5 .442 .1 k
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03335 .10452 L
F
.017 .5 .458 .1 k
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03372 .10725 L
F
.017 .5 .475 .1 k
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03399 .10923 L
F
.017 .5 .492 .1 k
.02381 .01184 m
.02381 .01184 L
.03422 .11085 L
.03416 .11044 L
F
.017 .5 .508 .1 k
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03422 .11085 L
F
.017 .5 .525 .1 k
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03416 .11044 L
F
.017 .5 .542 .1 k
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03399 .10923 L
F
.017 .5 .558 .1 k
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03372 .10725 L
F
.017 .5 .575 .1 k
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03335 .10452 L
F
.017 .5 .592 .1 k
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03291 .10111 L
F
.017 .5 .608 .1 k
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03242 .09709 L
F
.017 .5 .625 .1 k
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03189 .09257 L
F
.017 .5 .642 .1 k
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03134 .08766 L
F
.017 .5 .658 .1 k
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.03081 .08253 L
F
.017 .5 .675 .1 k
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.03031 .07736 L
F
.017 .5 .692 .1 k
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02987 .07242 L
F
.017 .5 .708 .1 k
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02951 .06801 L
F
.017 .5 .725 .1 k
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02924 .06446 L
F
.017 .5 .742 .1 k
.02381 .01184 m
.02381 .01184 L
.02901 .06134 L
.02907 .06215 L
F
.017 .5 .758 .1 k
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02901 .06134 L
F
.017 .5 .775 .1 k
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02907 .06215 L
F
.017 .5 .792 .1 k
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02924 .06446 L
F
.017 .5 .808 .1 k
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.02951 .06801 L
F
.017 .5 .825 .1 k
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.02987 .07242 L
F
.017 .5 .842 .1 k
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03031 .07736 L
F
.017 .5 .858 .1 k
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03081 .08253 L
F
.017 .5 .875 .1 k
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03134 .08766 L
F
.017 .5 .892 .1 k
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03189 .09257 L
F
.017 .5 .908 .1 k
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03242 .09709 L
F
.017 .5 .925 .1 k
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03291 .10111 L
F
.017 .5 .942 .1 k
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03335 .10452 L
F
.017 .5 .958 .1 k
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03372 .10725 L
F
.017 .5 .975 .1 k
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03399 .10923 L
F
.017 .5 .992 .1 k
.02381 .01184 m
.02381 .01184 L
.03422 .11085 L
.03416 .11044 L
F
.05 .5 .008 .1 k
.03422 .11085 m
.03416 .11044 L
.06475 .20474 L
.06498 .20552 L
F
.05 .5 .025 .1 k
.03416 .11044 m
.03399 .10923 L
.06409 .2024 L
.06475 .20474 L
F
.05 .5 .042 .1 k
.03399 .10923 m
.03372 .10725 L
.06301 .19856 L
.06409 .2024 L
F
.05 .5 .058 .1 k
.03372 .10725 m
.03335 .10452 L
.06157 .19327 L
.06301 .19856 L
F
.05 .5 .075 .1 k
.03335 .10452 m
.03291 .10111 L
.05983 .18665 L
.06157 .19327 L
F
.05 .5 .092 .1 k
.03291 .10111 m
.03242 .09709 L
.05787 .17884 L
.05983 .18665 L
F
.05 .5 .108 .1 k
.03242 .09709 m
.03189 .09257 L
.05576 .17002 L
.05787 .17884 L
F
.05 .5 .125 .1 k
.03189 .09257 m
.03134 .08766 L
.05361 .16043 L
.05576 .17002 L
F
.05 .5 .142 .1 k
.03134 .08766 m
.03081 .08253 L
.05151 .15038 L
.05361 .16043 L
F
.05 .5 .158 .1 k
.03081 .08253 m
.03031 .07736 L
.04954 .14026 L
.05151 .15038 L
F
.05 .5 .175 .1 k
.03031 .07736 m
.02987 .07242 L
.0478 .13055 L
.04954 .14026 L
F
.05 .5 .192 .1 k
.02987 .07242 m
.02951 .06801 L
.04636 .12185 L
.0478 .13055 L
F
.05 .5 .208 .1 k
.02951 .06801 m
.02924 .06446 L
.04528 .11485 L
.04636 .12185 L
F
.05 .5 .225 .1 k
.02924 .06446 m
.02907 .06215 L
.04462 .11028 L
.04528 .11485 L
F
.05 .5 .242 .1 k
.02907 .06215 m
.02901 .06134 L
.04439 .10868 L
.04462 .11028 L
F
.05 .5 .258 .1 k
.02901 .06134 m
.02907 .06215 L
.04462 .11028 L
.04439 .10868 L
F
.05 .5 .275 .1 k
.02907 .06215 m
.02924 .06446 L
.04528 .11485 L
.04462 .11028 L
F
.05 .5 .292 .1 k
.02924 .06446 m
.02951 .06801 L
.04636 .12185 L
.04528 .11485 L
F
.05 .5 .308 .1 k
.02951 .06801 m
.02987 .07242 L
.0478 .13055 L
.04636 .12185 L
F
.05 .5 .325 .1 k
.02987 .07242 m
.03031 .07736 L
.04954 .14026 L
.0478 .13055 L
F
.05 .5 .342 .1 k
.03031 .07736 m
.03081 .08253 L
.05151 .15038 L
.04954 .14026 L
F
.05 .5 .358 .1 k
.03081 .08253 m
.03134 .08766 L
.05361 .16043 L
.05151 .15038 L
F
.05 .5 .375 .1 k
.03134 .08766 m
.03189 .09257 L
.05576 .17002 L
.05361 .16043 L
F
.05 .5 .392 .1 k
.03189 .09257 m
.03242 .09709 L
.05787 .17884 L
.05576 .17002 L
F
.05 .5 .408 .1 k
.03242 .09709 m
.03291 .10111 L
.05983 .18665 L
.05787 .17884 L
F
.05 .5 .425 .1 k
.03291 .10111 m
.03335 .10452 L
.06157 .19327 L
.05983 .18665 L
F
.05 .5 .442 .1 k
.03335 .10452 m
.03372 .10725 L
.06301 .19856 L
.06157 .19327 L
F
.05 .5 .458 .1 k
.03372 .10725 m
.03399 .10923 L
.06409 .2024 L
.06301 .19856 L
F
.05 .5 .475 .1 k
.03399 .10923 m
.03416 .11044 L
.06475 .20474 L
.06409 .2024 L
F
.05 .5 .492 .1 k
.03416 .11044 m
.03422 .11085 L
.06498 .20552 L
.06475 .20474 L
F
.05 .5 .508 .1 k
.03422 .11085 m
.03416 .11044 L
.06475 .20474 L
.06498 .20552 L
F
.05 .5 .525 .1 k
.03416 .11044 m
.03399 .10923 L
.06409 .2024 L
.06475 .20474 L
F
.05 .5 .542 .1 k
.03399 .10923 m
.03372 .10725 L
.06301 .19856 L
.06409 .2024 L
F
.05 .5 .558 .1 k
.03372 .10725 m
.03335 .10452 L
.06157 .19327 L
.06301 .19856 L
F
.05 .5 .575 .1 k
.03335 .10452 m
.03291 .10111 L
.05983 .18665 L
.06157 .19327 L
F
.05 .5 .592 .1 k
.03291 .10111 m
.03242 .09709 L
.05787 .17884 L
.05983 .18665 L
F
.05 .5 .608 .1 k
.03242 .09709 m
.03189 .09257 L
.05576 .17002 L
.05787 .17884 L
F
.05 .5 .625 .1 k
.03189 .09257 m
.03134 .08766 L
.05361 .16043 L
.05576 .17002 L
F
.05 .5 .642 .1 k
.03134 .08766 m
.03081 .08253 L
.05151 .15038 L
.05361 .16043 L
F
.05 .5 .658 .1 k
.03081 .08253 m
.03031 .07736 L
.04954 .14026 L
.05151 .15038 L
F
.05 .5 .675 .1 k
.03031 .07736 m
.02987 .07242 L
.0478 .13055 L
.04954 .14026 L
F
.05 .5 .692 .1 k
.02987 .07242 m
.02951 .06801 L
.04636 .12185 L
.0478 .13055 L
F
.05 .5 .708 .1 k
.02951 .06801 m
.02924 .06446 L
.04528 .11485 L
.04636 .12185 L
F
.05 .5 .725 .1 k
.02924 .06446 m
.02907 .06215 L
.04462 .11028 L
.04528 .11485 L
F
.05 .5 .742 .1 k
.02907 .06215 m
.02901 .06134 L
.04439 .10868 L
.04462 .11028 L
F
.05 .5 .758 .1 k
.02901 .06134 m
.02907 .06215 L
.04462 .11028 L
.04439 .10868 L
F
.05 .5 .775 .1 k
.02907 .06215 m
.02924 .06446 L
.04528 .11485 L
.04462 .11028 L
F
.05 .5 .792 .1 k
.02924 .06446 m
.02951 .06801 L
.04636 .12185 L
.04528 .11485 L
F
.05 .5 .808 .1 k
.02951 .06801 m
.02987 .07242 L
.0478 .13055 L
.04636 .12185 L
F
.05 .5 .825 .1 k
.02987 .07242 m
.03031 .07736 L
.04954 .14026 L
.0478 .13055 L
F
.05 .5 .842 .1 k
.03031 .07736 m
.03081 .08253 L
.05151 .15038 L
.04954 .14026 L
F
.05 .5 .858 .1 k
.03081 .08253 m
.03134 .08766 L
.05361 .16043 L
.05151 .15038 L
F
.05 .5 .875 .1 k
.03134 .08766 m
.03189 .09257 L
.05576 .17002 L
.05361 .16043 L
F
.05 .5 .892 .1 k
.03189 .09257 m
.03242 .09709 L
.05787 .17884 L
.05576 .17002 L
F
.05 .5 .908 .1 k
.03242 .09709 m
.03291 .10111 L
.05983 .18665 L
.05787 .17884 L
F
.05 .5 .925 .1 k
.03291 .10111 m
.03335 .10452 L
.06157 .19327 L
.05983 .18665 L
F
.05 .5 .942 .1 k
.03335 .10452 m
.03372 .10725 L
.06301 .19856 L
.06157 .19327 L
F
.05 .5 .958 .1 k
.03372 .10725 m
.03399 .10923 L
.06409 .2024 L
.06301 .19856 L
F
.05 .5 .975 .1 k
.03399 .10923 m
.03416 .11044 L
.06475 .20474 L
.06409 .2024 L
F
.05 .5 .992 .1 k
.03416 .11044 m
.03422 .11085 L
.06498 .20552 L
.06475 .20474 L
F
.083 .5 .008 .1 k
.06498 .20552 m
.06475 .20474 L
.11426 .29063 L
.11475 .29174 L
F
.083 .5 .025 .1 k
.06475 .20474 m
.06409 .2024 L
.11279 .28732 L
.11426 .29063 L
F
.083 .5 .042 .1 k
.06409 .2024 m
.06301 .19856 L
.11041 .28186 L
.11279 .28732 L
F
.083 .5 .058 .1 k
.06301 .19856 m
.06157 .19327 L
.10723 .27434 L
.11041 .28186 L
F
.083 .5 .075 .1 k
.06157 .19327 m
.05983 .18665 L
.10339 .2649 L
.10723 .27434 L
F
.083 .5 .092 .1 k
.05983 .18665 m
.05787 .17884 L
.09904 .25373 L
.10339 .2649 L
F
.083 .5 .108 .1 k
.05787 .17884 m
.05576 .17002 L
.09439 .24107 L
.09904 .25373 L
F
.083 .5 .125 .1 k
.05576 .17002 m
.05361 .16043 L
.08964 .22726 L
.09439 .24107 L
F
.083 .5 .142 .1 k
.05361 .16043 m
.05151 .15038 L
.08499 .21272 L
.08964 .22726 L
F
.083 .5 .158 .1 k
.05151 .15038 m
.04954 .14026 L
.08065 .19802 L
.08499 .21272 L
F
.083 .5 .175 .1 k
.04954 .14026 m
.0478 .13055 L
.0768 .18386 L
.08065 .19802 L
F
.083 .5 .192 .1 k
.0478 .13055 m
.04636 .12185 L
.07362 .17114 L
.0768 .18386 L
F
.083 .5 .208 .1 k
.04636 .12185 m
.04528 .11485 L
.07125 .16087 L
.07362 .17114 L
F
.083 .5 .225 .1 k
.04528 .11485 m
.04462 .11028 L
.06978 .15414 L
.07125 .16087 L
F
.083 .5 .242 .1 k
.04462 .11028 m
.04439 .10868 L
.06928 .15179 L
.06978 .15414 L
F
.083 .5 .258 .1 k
.04439 .10868 m
.04462 .11028 L
.06978 .15414 L
.06928 .15179 L
F
.083 .5 .275 .1 k
.04462 .11028 m
.04528 .11485 L
.07125 .16087 L
.06978 .15414 L
F
.083 .5 .292 .1 k
.04528 .11485 m
.04636 .12185 L
.07362 .17114 L
.07125 .16087 L
F
.083 .5 .308 .1 k
.04636 .12185 m
.0478 .13055 L
.0768 .18386 L
.07362 .17114 L
F
.083 .5 .325 .1 k
.0478 .13055 m
.04954 .14026 L
.08065 .19802 L
.0768 .18386 L
F
.083 .5 .342 .1 k
.04954 .14026 m
.05151 .15038 L
.08499 .21272 L
.08065 .19802 L
F
.083 .5 .358 .1 k
.05151 .15038 m
.05361 .16043 L
.08964 .22726 L
.08499 .21272 L
F
.083 .5 .375 .1 k
.05361 .16043 m
.05576 .17002 L
.09439 .24107 L
.08964 .22726 L
F
.083 .5 .392 .1 k
.05576 .17002 m
.05787 .17884 L
.09904 .25373 L
.09439 .24107 L
F
.083 .5 .408 .1 k
.05787 .17884 m
.05983 .18665 L
.10339 .2649 L
.09904 .25373 L
F
.083 .5 .425 .1 k
.05983 .18665 m
.06157 .19327 L
.10723 .27434 L
.10339 .2649 L
F
.083 .5 .442 .1 k
.06157 .19327 m
.06301 .19856 L
.11041 .28186 L
.10723 .27434 L
F
.083 .5 .458 .1 k
.06301 .19856 m
.06409 .2024 L
.11279 .28732 L
.11041 .28186 L
F
.083 .5 .475 .1 k
.06409 .2024 m
.06475 .20474 L
.11426 .29063 L
.11279 .28732 L
F
.083 .5 .492 .1 k
.06475 .20474 m
.06498 .20552 L
.11475 .29174 L
.11426 .29063 L
F
.083 .5 .508 .1 k
.06498 .20552 m
.06475 .20474 L
.11426 .29063 L
.11475 .29174 L
F
.083 .5 .525 .1 k
.06475 .20474 m
.06409 .2024 L
.11279 .28732 L
.11426 .29063 L
F
.083 .5 .542 .1 k
.06409 .2024 m
.06301 .19856 L
.11041 .28186 L
.11279 .28732 L
F
.083 .5 .558 .1 k
.06301 .19856 m
.06157 .19327 L
.10723 .27434 L
.11041 .28186 L
F
.083 .5 .575 .1 k
.06157 .19327 m
.05983 .18665 L
.10339 .2649 L
.10723 .27434 L
F
.083 .5 .592 .1 k
.05983 .18665 m
.05787 .17884 L
.09904 .25373 L
.10339 .2649 L
F
.083 .5 .608 .1 k
.05787 .17884 m
.05576 .17002 L
.09439 .24107 L
.09904 .25373 L
F
.083 .5 .625 .1 k
.05576 .17002 m
.05361 .16043 L
.08964 .22726 L
.09439 .24107 L
F
.083 .5 .642 .1 k
.05361 .16043 m
.05151 .15038 L
.08499 .21272 L
.08964 .22726 L
F
.083 .5 .658 .1 k
.05151 .15038 m
.04954 .14026 L
.08065 .19802 L
.08499 .21272 L
F
.083 .5 .675 .1 k
.04954 .14026 m
.0478 .13055 L
.0768 .18386 L
.08065 .19802 L
F
.083 .5 .692 .1 k
.0478 .13055 m
.04636 .12185 L
.07362 .17114 L
.0768 .18386 L
F
.083 .5 .708 .1 k
.04636 .12185 m
.04528 .11485 L
.07125 .16087 L
.07362 .17114 L
F
.083 .5 .725 .1 k
.04528 .11485 m
.04462 .11028 L
.06978 .15414 L
.07125 .16087 L
F
.083 .5 .742 .1 k
.04462 .11028 m
.04439 .10868 L
.06928 .15179 L
.06978 .15414 L
F
.083 .5 .758 .1 k
.04439 .10868 m
.04462 .11028 L
.06978 .15414 L
.06928 .15179 L
F
.083 .5 .775 .1 k
.04462 .11028 m
.04528 .11485 L
.07125 .16087 L
.06978 .15414 L
F
.083 .5 .792 .1 k
.04528 .11485 m
.04636 .12185 L
.07362 .17114 L
.07125 .16087 L
F
.083 .5 .808 .1 k
.04636 .12185 m
.0478 .13055 L
.0768 .18386 L
.07362 .17114 L
F
.083 .5 .825 .1 k
.0478 .13055 m
.04954 .14026 L
.08065 .19802 L
.0768 .18386 L
F
.083 .5 .842 .1 k
.04954 .14026 m
.05151 .15038 L
.08499 .21272 L
.08065 .19802 L
F
.083 .5 .858 .1 k
.05151 .15038 m
.05361 .16043 L
.08964 .22726 L
.08499 .21272 L
F
.083 .5 .875 .1 k
.05361 .16043 m
.05576 .17002 L
.09439 .24107 L
.08964 .22726 L
F
.083 .5 .892 .1 k
.05576 .17002 m
.05787 .17884 L
.09904 .25373 L
.09439 .24107 L
F
.083 .5 .908 .1 k
.05787 .17884 m
.05983 .18665 L
.10339 .2649 L
.09904 .25373 L
F
.083 .5 .925 .1 k
.05983 .18665 m
.06157 .19327 L
.10723 .27434 L
.10339 .2649 L
F
.083 .5 .942 .1 k
.06157 .19327 m
.06301 .19856 L
.11041 .28186 L
.10723 .27434 L
F
.083 .5 .958 .1 k
.06301 .19856 m
.06409 .2024 L
.11279 .28732 L
.11041 .28186 L
F
.083 .5 .975 .1 k
.06409 .2024 m
.06475 .20474 L
.11426 .29063 L
.11279 .28732 L
F
.083 .5 .992 .1 k
.06475 .20474 m
.06498 .20552 L
.11475 .29174 L
.11426 .29063 L
F
.117 .5 .008 .1 k
.11475 .29174 m
.11426 .29063 L
.18051 .36436 L
.18137 .36572 L
F
.117 .5 .025 .1 k
.11426 .29063 m
.11279 .28732 L
.17796 .3603 L
.18051 .36436 L
F
.117 .5 .042 .1 k
.11279 .28732 m
.11041 .28186 L
.17384 .3536 L
.17796 .3603 L
F
.117 .5 .058 .1 k
.11041 .28186 m
.10723 .27434 L
.16833 .34433 L
.17384 .3536 L
F
.117 .5 .075 .1 k
.10723 .27434 m
.10339 .2649 L
.16167 .33264 L
.16833 .34433 L
F
.117 .5 .092 .1 k
.10339 .2649 m
.09904 .25373 L
.15415 .31873 L
.16167 .33264 L
F
.117 .5 .108 .1 k
.09904 .25373 m
.09439 .24107 L
.14609 .30289 L
.15415 .31873 L
F
.117 .5 .125 .1 k
.09439 .24107 m
.08964 .22726 L
.13786 .28551 L
.14609 .30289 L
F
.117 .5 .142 .1 k
.08964 .22726 m
.08499 .21272 L
.12981 .2671 L
.13786 .28551 L
F
.117 .5 .158 .1 k
.08499 .21272 m
.08065 .19802 L
.12228 .24838 L
.12981 .2671 L
F
.117 .5 .175 .1 k
.08065 .19802 m
.0768 .18386 L
.11562 .23025 L
.12228 .24838 L
F
.117 .5 .192 .1 k
.0768 .18386 m
.07362 .17114 L
.11011 .21386 L
.11562 .23025 L
F
.117 .5 .208 .1 k
.07362 .17114 m
.07125 .16087 L
.10599 .20058 L
.11011 .21386 L
F
.117 .5 .225 .1 k
.07125 .16087 m
.06978 .15414 L
.10345 .19184 L
.10599 .20058 L
F
.117 .5 .242 .1 k
.06978 .15414 m
.06928 .15179 L
.10259 .18878 L
.10345 .19184 L
F
.117 .5 .258 .1 k
.06928 .15179 m
.06978 .15414 L
.10345 .19184 L
.10259 .18878 L
F
.117 .5 .275 .1 k
.06978 .15414 m
.07125 .16087 L
.10599 .20058 L
.10345 .19184 L
F
.117 .5 .292 .1 k
.07125 .16087 m
.07362 .17114 L
.11011 .21386 L
.10599 .20058 L
F
.117 .5 .308 .1 k
.07362 .17114 m
.0768 .18386 L
.11562 .23025 L
.11011 .21386 L
F
.117 .5 .325 .1 k
.0768 .18386 m
.08065 .19802 L
.12228 .24838 L
.11562 .23025 L
F
.117 .5 .342 .1 k
.08065 .19802 m
.08499 .21272 L
.12981 .2671 L
.12228 .24838 L
F
.117 .5 .358 .1 k
.08499 .21272 m
.08964 .22726 L
.13786 .28551 L
.12981 .2671 L
F
.117 .5 .375 .1 k
.08964 .22726 m
.09439 .24107 L
.14609 .30289 L
.13786 .28551 L
F
.117 .5 .392 .1 k
.09439 .24107 m
.09904 .25373 L
.15415 .31873 L
.14609 .30289 L
F
.117 .5 .408 .1 k
.09904 .25373 m
.10339 .2649 L
.16167 .33264 L
.15415 .31873 L
F
.117 .5 .425 .1 k
.10339 .2649 m
.10723 .27434 L
.16833 .34433 L
.16167 .33264 L
F
.117 .5 .442 .1 k
.10723 .27434 m
.11041 .28186 L
.17384 .3536 L
.16833 .34433 L
F
.117 .5 .458 .1 k
.11041 .28186 m
.11279 .28732 L
.17796 .3603 L
.17384 .3536 L
F
.117 .5 .475 .1 k
.11279 .28732 m
.11426 .29063 L
.18051 .36436 L
.17796 .3603 L
F
.117 .5 .492 .1 k
.11426 .29063 m
.11475 .29174 L
.18137 .36572 L
.18051 .36436 L
F
.117 .5 .508 .1 k
.11475 .29174 m
.11426 .29063 L
.18051 .36436 L
.18137 .36572 L
F
.117 .5 .525 .1 k
.11426 .29063 m
.11279 .28732 L
.17796 .3603 L
.18051 .36436 L
F
.117 .5 .542 .1 k
.11279 .28732 m
.11041 .28186 L
.17384 .3536 L
.17796 .3603 L
F
.117 .5 .558 .1 k
.11041 .28186 m
.10723 .27434 L
.16833 .34433 L
.17384 .3536 L
F
.117 .5 .575 .1 k
.10723 .27434 m
.10339 .2649 L
.16167 .33264 L
.16833 .34433 L
F
.117 .5 .592 .1 k
.10339 .2649 m
.09904 .25373 L
.15415 .31873 L
.16167 .33264 L
F
.117 .5 .608 .1 k
.09904 .25373 m
.09439 .24107 L
.14609 .30289 L
.15415 .31873 L
F
.117 .5 .625 .1 k
.09439 .24107 m
.08964 .22726 L
.13786 .28551 L
.14609 .30289 L
F
.117 .5 .642 .1 k
.08964 .22726 m
.08499 .21272 L
.12981 .2671 L
.13786 .28551 L
F
.117 .5 .658 .1 k
.08499 .21272 m
.08065 .19802 L
.12228 .24838 L
.12981 .2671 L
F
.117 .5 .675 .1 k
.08065 .19802 m
.0768 .18386 L
.11562 .23025 L
.12228 .24838 L
F
.117 .5 .692 .1 k
.0768 .18386 m
.07362 .17114 L
.11011 .21386 L
.11562 .23025 L
F
.117 .5 .708 .1 k
.07362 .17114 m
.07125 .16087 L
.10599 .20058 L
.11011 .21386 L
F
.117 .5 .725 .1 k
.07125 .16087 m
.06978 .15414 L
.10345 .19184 L
.10599 .20058 L
F
.117 .5 .742 .1 k
.06978 .15414 m
.06928 .15179 L
.10259 .18878 L
.10345 .19184 L
F
.117 .5 .758 .1 k
.06928 .15179 m
.06978 .15414 L
.10345 .19184 L
.10259 .18878 L
F
.117 .5 .775 .1 k
.06978 .15414 m
.07125 .16087 L
.10599 .20058 L
.10345 .19184 L
F
.117 .5 .792 .1 k
.07125 .16087 m
.07362 .17114 L
.11011 .21386 L
.10599 .20058 L
F
.117 .5 .808 .1 k
.07362 .17114 m
.0768 .18386 L
.11562 .23025 L
.11011 .21386 L
F
.117 .5 .825 .1 k
.0768 .18386 m
.08065 .19802 L
.12228 .24838 L
.11562 .23025 L
F
.117 .5 .842 .1 k
.08065 .19802 m
.08499 .21272 L
.12981 .2671 L
.12228 .24838 L
F
.117 .5 .858 .1 k
.08499 .21272 m
.08964 .22726 L
.13786 .28551 L
.12981 .2671 L
F
.117 .5 .875 .1 k
.08964 .22726 m
.09439 .24107 L
.14609 .30289 L
.13786 .28551 L
F
.117 .5 .892 .1 k
.09439 .24107 m
.09904 .25373 L
.15415 .31873 L
.14609 .30289 L
F
.117 .5 .908 .1 k
.09904 .25373 m
.10339 .2649 L
.16167 .33264 L
.15415 .31873 L
F
.117 .5 .925 .1 k
.10339 .2649 m
.10723 .27434 L
.16833 .34433 L
.16167 .33264 L
F
.117 .5 .942 .1 k
.10723 .27434 m
.11041 .28186 L
.17384 .3536 L
.16833 .34433 L
F
.117 .5 .958 .1 k
.11041 .28186 m
.11279 .28732 L
.17796 .3603 L
.17384 .3536 L
F
.117 .5 .975 .1 k
.11279 .28732 m
.11426 .29063 L
.18051 .36436 L
.17796 .3603 L
F
.117 .5 .992 .1 k
.11426 .29063 m
.11475 .29174 L
.18137 .36572 L
.18051 .36436 L
F
.15 .5 .008 .1 k
.18137 .36572 m
.18051 .36436 L
.2606 .42273 L
.2619 .42423 L
F
.15 .5 .025 .1 k
.18051 .36436 m
.17796 .3603 L
.25676 .41821 L
.2606 .42273 L
F
.15 .5 .042 .1 k
.17796 .3603 m
.17384 .3536 L
.25054 .41073 L
.25676 .41821 L
F
.15 .5 .058 .1 k
.17384 .3536 m
.16833 .34433 L
.24221 .40033 L
.25054 .41073 L
F
.15 .5 .075 .1 k
.16833 .34433 m
.16167 .33264 L
.23214 .38712 L
.24221 .40033 L
F
.15 .5 .092 .1 k
.16167 .33264 m
.15415 .31873 L
.22077 .37129 L
.23214 .38712 L
F
.15 .5 .108 .1 k
.15415 .31873 m
.14609 .30289 L
.2086 .35311 L
.22077 .37129 L
F
.15 .5 .125 .1 k
.14609 .30289 m
.13786 .28551 L
.19616 .33298 L
.2086 .35311 L
F
.15 .5 .142 .1 k
.13786 .28551 m
.12981 .2671 L
.18399 .31149 L
.19616 .33298 L
F
.15 .5 .158 .1 k
.12981 .2671 m
.12228 .24838 L
.17262 .28944 L
.18399 .31149 L
F
.15 .5 .175 .1 k
.12228 .24838 m
.11562 .23025 L
.16255 .26792 L
.17262 .28944 L
F
.15 .5 .192 .1 k
.11562 .23025 m
.11011 .21386 L
.15423 .24832 L
.16255 .26792 L
F
.15 .5 .208 .1 k
.11011 .21386 m
.10599 .20058 L
.148 .23233 L
.15423 .24832 L
F
.15 .5 .225 .1 k
.10599 .20058 m
.10345 .19184 L
.14416 .22175 L
.148 .23233 L
F
.15 .5 .242 .1 k
.10345 .19184 m
.10259 .18878 L
.14286 .21804 L
.14416 .22175 L
F
.15 .5 .258 .1 k
.10259 .18878 m
.10345 .19184 L
.14416 .22175 L
.14286 .21804 L
F
.15 .5 .275 .1 k
.10345 .19184 m
.10599 .20058 L
.148 .23233 L
.14416 .22175 L
F
.15 .5 .292 .1 k
.10599 .20058 m
.11011 .21386 L
.15423 .24832 L
.148 .23233 L
F
.15 .5 .308 .1 k
.11011 .21386 m
.11562 .23025 L
.16255 .26792 L
.15423 .24832 L
F
.15 .5 .325 .1 k
.11562 .23025 m
.12228 .24838 L
.17262 .28944 L
.16255 .26792 L
F
.15 .5 .342 .1 k
.12228 .24838 m
.12981 .2671 L
.18399 .31149 L
.17262 .28944 L
F
.15 .5 .358 .1 k
.12981 .2671 m
.13786 .28551 L
.19616 .33298 L
.18399 .31149 L
F
.15 .5 .375 .1 k
.13786 .28551 m
.14609 .30289 L
.2086 .35311 L
.19616 .33298 L
F
.15 .5 .392 .1 k
.14609 .30289 m
.15415 .31873 L
.22077 .37129 L
.2086 .35311 L
F
.15 .5 .408 .1 k
.15415 .31873 m
.16167 .33264 L
.23214 .38712 L
.22077 .37129 L
F
.15 .5 .425 .1 k
.16167 .33264 m
.16833 .34433 L
.24221 .40033 L
.23214 .38712 L
F
.15 .5 .442 .1 k
.16833 .34433 m
.17384 .3536 L
.25054 .41073 L
.24221 .40033 L
F
.15 .5 .458 .1 k
.17384 .3536 m
.17796 .3603 L
.25676 .41821 L
.25054 .41073 L
F
.15 .5 .475 .1 k
.17796 .3603 m
.18051 .36436 L
.2606 .42273 L
.25676 .41821 L
F
.15 .5 .492 .1 k
.18051 .36436 m
.18137 .36572 L
.2619 .42423 L
.2606 .42273 L
F
.15 .5 .508 .1 k
.18137 .36572 m
.18051 .36436 L
.2606 .42273 L
.2619 .42423 L
F
.15 .5 .525 .1 k
.18051 .36436 m
.17796 .3603 L
.25676 .41821 L
.2606 .42273 L
F
.15 .5 .542 .1 k
.17796 .3603 m
.17384 .3536 L
.25054 .41073 L
.25676 .41821 L
F
.15 .5 .558 .1 k
.17384 .3536 m
.16833 .34433 L
.24221 .40033 L
.25054 .41073 L
F
.15 .5 .575 .1 k
.16833 .34433 m
.16167 .33264 L
.23214 .38712 L
.24221 .40033 L
F
.15 .5 .592 .1 k
.16167 .33264 m
.15415 .31873 L
.22077 .37129 L
.23214 .38712 L
F
.15 .5 .608 .1 k
.15415 .31873 m
.14609 .30289 L
.2086 .35311 L
.22077 .37129 L
F
.15 .5 .625 .1 k
.14609 .30289 m
.13786 .28551 L
.19616 .33298 L
.2086 .35311 L
F
.15 .5 .642 .1 k
.13786 .28551 m
.12981 .2671 L
.18399 .31149 L
.19616 .33298 L
F
.15 .5 .658 .1 k
.12981 .2671 m
.12228 .24838 L
.17262 .28944 L
.18399 .31149 L
F
.15 .5 .675 .1 k
.12228 .24838 m
.11562 .23025 L
.16255 .26792 L
.17262 .28944 L
F
.15 .5 .692 .1 k
.11562 .23025 m
.11011 .21386 L
.15423 .24832 L
.16255 .26792 L
F
.15 .5 .708 .1 k
.11011 .21386 m
.10599 .20058 L
.148 .23233 L
.15423 .24832 L
F
.15 .5 .725 .1 k
.10599 .20058 m
.10345 .19184 L
.14416 .22175 L
.148 .23233 L
F
.15 .5 .742 .1 k
.10345 .19184 m
.10259 .18878 L
.14286 .21804 L
.14416 .22175 L
F
.15 .5 .758 .1 k
.10259 .18878 m
.10345 .19184 L
.14416 .22175 L
.14286 .21804 L
F
.15 .5 .775 .1 k
.10345 .19184 m
.10599 .20058 L
.148 .23233 L
.14416 .22175 L
F
.15 .5 .792 .1 k
.10599 .20058 m
.11011 .21386 L
.15423 .24832 L
.148 .23233 L
F
.15 .5 .808 .1 k
.11011 .21386 m
.11562 .23025 L
.16255 .26792 L
.15423 .24832 L
F
.15 .5 .825 .1 k
.11562 .23025 m
.12228 .24838 L
.17262 .28944 L
.16255 .26792 L
F
.15 .5 .842 .1 k
.12228 .24838 m
.12981 .2671 L
.18399 .31149 L
.17262 .28944 L
F
.15 .5 .858 .1 k
.12981 .2671 m
.13786 .28551 L
.19616 .33298 L
.18399 .31149 L
F
.15 .5 .875 .1 k
.13786 .28551 m
.14609 .30289 L
.2086 .35311 L
.19616 .33298 L
F
.15 .5 .892 .1 k
.14609 .30289 m
.15415 .31873 L
.22077 .37129 L
.2086 .35311 L
F
.15 .5 .908 .1 k
.15415 .31873 m
.16167 .33264 L
.23214 .38712 L
.22077 .37129 L
F
.15 .5 .925 .1 k
.16167 .33264 m
.16833 .34433 L
.24221 .40033 L
.23214 .38712 L
F
.15 .5 .942 .1 k
.16833 .34433 m
.17384 .3536 L
.25054 .41073 L
.24221 .40033 L
F
.15 .5 .958 .1 k
.17384 .3536 m
.17796 .3603 L
.25676 .41821 L
.25054 .41073 L
F
.15 .5 .975 .1 k
.17796 .3603 m
.18051 .36436 L
.2606 .42273 L
.25676 .41821 L
F
.15 .5 .992 .1 k
.18051 .36436 m
.18137 .36572 L
.2619 .42423 L
.2606 .42273 L
F
.183 .5 .008 .1 k
.2619 .42423 m
.2606 .42273 L
.35105 .46319 L
.35285 .46472 L
F
.183 .5 .025 .1 k
.2606 .42273 m
.25676 .41821 L
.34574 .45858 L
.35105 .46319 L
F
.183 .5 .042 .1 k
.25676 .41821 m
.25054 .41073 L
.33714 .45088 L
.34574 .45858 L
F
.183 .5 .058 .1 k
.25054 .41073 m
.24221 .40033 L
.32563 .44008 L
.33714 .45088 L
F
.183 .5 .075 .1 k
.24221 .40033 m
.23214 .38712 L
.31172 .42623 L
.32563 .44008 L
F
.183 .5 .092 .1 k
.23214 .38712 m
.22077 .37129 L
.29601 .40943 L
.31172 .42623 L
F
.183 .5 .108 .1 k
.22077 .37129 m
.2086 .35311 L
.27919 .38989 L
.29601 .40943 L
F
.183 .5 .125 .1 k
.2086 .35311 m
.19616 .33298 L
.26199 .36799 L
.27919 .38989 L
F
.183 .5 .142 .1 k
.19616 .33298 m
.18399 .31149 L
.24517 .34432 L
.26199 .36799 L
F
.183 .5 .158 .1 k
.18399 .31149 m
.17262 .28944 L
.22946 .31975 L
.24517 .34432 L
F
.183 .5 .175 .1 k
.17262 .28944 m
.16255 .26792 L
.21555 .2955 L
.22946 .31975 L
F
.183 .5 .192 .1 k
.16255 .26792 m
.15423 .24832 L
.20404 .27319 L
.21555 .2955 L
F
.183 .5 .208 .1 k
.15423 .24832 m
.148 .23233 L
.19544 .25483 L
.20404 .27319 L
F
.183 .5 .225 .1 k
.148 .23233 m
.14416 .22175 L
.19013 .2426 L
.19544 .25483 L
F
.183 .5 .242 .1 k
.14416 .22175 m
.14286 .21804 L
.18833 .23828 L
.19013 .2426 L
F
.183 .5 .258 .1 k
.14286 .21804 m
.14416 .22175 L
.19013 .2426 L
.18833 .23828 L
F
.183 .5 .275 .1 k
.14416 .22175 m
.148 .23233 L
.19544 .25483 L
.19013 .2426 L
F
.183 .5 .292 .1 k
.148 .23233 m
.15423 .24832 L
.20404 .27319 L
.19544 .25483 L
F
.183 .5 .308 .1 k
.15423 .24832 m
.16255 .26792 L
.21555 .2955 L
.20404 .27319 L
F
.183 .5 .325 .1 k
.16255 .26792 m
.17262 .28944 L
.22946 .31975 L
.21555 .2955 L
F
.183 .5 .342 .1 k
.17262 .28944 m
.18399 .31149 L
.24517 .34432 L
.22946 .31975 L
F
.183 .5 .358 .1 k
.18399 .31149 m
.19616 .33298 L
.26199 .36799 L
.24517 .34432 L
F
.183 .5 .375 .1 k
.19616 .33298 m
.2086 .35311 L
.27919 .38989 L
.26199 .36799 L
F
.183 .5 .392 .1 k
.2086 .35311 m
.22077 .37129 L
.29601 .40943 L
.27919 .38989 L
F
.183 .5 .408 .1 k
.22077 .37129 m
.23214 .38712 L
.31172 .42623 L
.29601 .40943 L
F
.183 .5 .425 .1 k
.23214 .38712 m
.24221 .40033 L
.32563 .44008 L
.31172 .42623 L
F
.183 .5 .442 .1 k
.24221 .40033 m
.25054 .41073 L
.33714 .45088 L
.32563 .44008 L
F
.183 .5 .458 .1 k
.25054 .41073 m
.25676 .41821 L
.34574 .45858 L
.33714 .45088 L
F
.183 .5 .475 .1 k
.25676 .41821 m
.2606 .42273 L
.35105 .46319 L
.34574 .45858 L
F
.183 .5 .492 .1 k
.2606 .42273 m
.2619 .42423 L
.35285 .46472 L
.35105 .46319 L
F
.183 .5 .508 .1 k
.2619 .42423 m
.2606 .42273 L
.35105 .46319 L
.35285 .46472 L
F
.183 .5 .525 .1 k
.2606 .42273 m
.25676 .41821 L
.34574 .45858 L
.35105 .46319 L
F
.183 .5 .542 .1 k
.25676 .41821 m
.25054 .41073 L
.33714 .45088 L
.34574 .45858 L
F
.183 .5 .558 .1 k
.25054 .41073 m
.24221 .40033 L
.32563 .44008 L
.33714 .45088 L
F
.183 .5 .575 .1 k
.24221 .40033 m
.23214 .38712 L
.31172 .42623 L
.32563 .44008 L
F
.183 .5 .592 .1 k
.23214 .38712 m
.22077 .37129 L
.29601 .40943 L
.31172 .42623 L
F
.183 .5 .608 .1 k
.22077 .37129 m
.2086 .35311 L
.27919 .38989 L
.29601 .40943 L
F
.183 .5 .625 .1 k
.2086 .35311 m
.19616 .33298 L
.26199 .36799 L
.27919 .38989 L
F
.183 .5 .642 .1 k
.19616 .33298 m
.18399 .31149 L
.24517 .34432 L
.26199 .36799 L
F
.183 .5 .658 .1 k
.18399 .31149 m
.17262 .28944 L
.22946 .31975 L
.24517 .34432 L
F
.183 .5 .675 .1 k
.17262 .28944 m
.16255 .26792 L
.21555 .2955 L
.22946 .31975 L
F
.183 .5 .692 .1 k
.16255 .26792 m
.15423 .24832 L
.20404 .27319 L
.21555 .2955 L
F
.183 .5 .708 .1 k
.15423 .24832 m
.148 .23233 L
.19544 .25483 L
.20404 .27319 L
F
.183 .5 .725 .1 k
.148 .23233 m
.14416 .22175 L
.19013 .2426 L
.19544 .25483 L
F
.183 .5 .742 .1 k
.14416 .22175 m
.14286 .21804 L
.18833 .23828 L
.19013 .2426 L
F
.183 .5 .758 .1 k
.14286 .21804 m
.14416 .22175 L
.19013 .2426 L
.18833 .23828 L
F
.183 .5 .775 .1 k
.14416 .22175 m
.148 .23233 L
.19544 .25483 L
.19013 .2426 L
F
.183 .5 .792 .1 k
.148 .23233 m
.15423 .24832 L
.20404 .27319 L
.19544 .25483 L
F
.183 .5 .808 .1 k
.15423 .24832 m
.16255 .26792 L
.21555 .2955 L
.20404 .27319 L
F
.183 .5 .825 .1 k
.16255 .26792 m
.17262 .28944 L
.22946 .31975 L
.21555 .2955 L
F
.183 .5 .842 .1 k
.17262 .28944 m
.18399 .31149 L
.24517 .34432 L
.22946 .31975 L
F
.183 .5 .858 .1 k
.18399 .31149 m
.19616 .33298 L
.26199 .36799 L
.24517 .34432 L
F
.183 .5 .875 .1 k
.19616 .33298 m
.2086 .35311 L
.27919 .38989 L
.26199 .36799 L
F
.183 .5 .892 .1 k
.2086 .35311 m
.22077 .37129 L
.29601 .40943 L
.27919 .38989 L
F
.183 .5 .908 .1 k
.22077 .37129 m
.23214 .38712 L
.31172 .42623 L
.29601 .40943 L
F
.183 .5 .925 .1 k
.23214 .38712 m
.24221 .40033 L
.32563 .44008 L
.31172 .42623 L
F
.183 .5 .942 .1 k
.24221 .40033 m
.25054 .41073 L
.33714 .45088 L
.32563 .44008 L
F
.183 .5 .958 .1 k
.25054 .41073 m
.25676 .41821 L
.34574 .45858 L
.33714 .45088 L
F
.183 .5 .975 .1 k
.25676 .41821 m
.2606 .42273 L
.35105 .46319 L
.34574 .45858 L
F
.183 .5 .992 .1 k
.2606 .42273 m
.2619 .42423 L
.35285 .46472 L
.35105 .46319 L
F
.217 .5 .008 .1 k
.35285 .46472 m
.35105 .46319 L
.44789 .484 L
.45022 .48542 L
F
.217 .5 .025 .1 k
.35105 .46319 m
.34574 .45858 L
.44101 .47969 L
.44789 .484 L
F
.217 .5 .042 .1 k
.34574 .45858 m
.33714 .45088 L
.42987 .47243 L
.44101 .47969 L
F
.217 .5 .058 .1 k
.33714 .45088 m
.32563 .44008 L
.41495 .46209 L
.42987 .47243 L
F
.217 .5 .075 .1 k
.32563 .44008 m
.31172 .42623 L
.39692 .44859 L
.41495 .46209 L
F
.217 .5 .092 .1 k
.31172 .42623 m
.29601 .40943 L
.37656 .43189 L
.39692 .44859 L
F
.217 .5 .108 .1 k
.29601 .40943 m
.27919 .38989 L
.35476 .4121 L
.37656 .43189 L
F
.217 .5 .125 .1 k
.27919 .38989 m
.26199 .36799 L
.33248 .3895 L
.35476 .4121 L
F
.217 .5 .142 .1 k
.26199 .36799 m
.24517 .34432 L
.31068 .36463 L
.33248 .3895 L
F
.217 .5 .158 .1 k
.24517 .34432 m
.22946 .31975 L
.29032 .33841 L
.31068 .36463 L
F
.217 .5 .175 .1 k
.22946 .31975 m
.21555 .2955 L
.27229 .31213 L
.29032 .33841 L
F
.217 .5 .192 .1 k
.21555 .2955 m
.20404 .27319 L
.25738 .28763 L
.27229 .31213 L
F
.217 .5 .208 .1 k
.20404 .27319 m
.19544 .25483 L
.24623 .26722 L
.25738 .28763 L
F
.217 .5 .225 .1 k
.19544 .25483 m
.19013 .2426 L
.23935 .2535 L
.24623 .26722 L
F
.217 .5 .242 .1 k
.19013 .2426 m
.18833 .23828 L
.23702 .24863 L
.23935 .2535 L
F
.217 .5 .258 .1 k
.18833 .23828 m
.19013 .2426 L
.23935 .2535 L
.23702 .24863 L
F
.217 .5 .275 .1 k
.19013 .2426 m
.19544 .25483 L
.24623 .26722 L
.23935 .2535 L
F
.217 .5 .292 .1 k
.19544 .25483 m
.20404 .27319 L
.25738 .28763 L
.24623 .26722 L
F
.217 .5 .308 .1 k
.20404 .27319 m
.21555 .2955 L
.27229 .31213 L
.25738 .28763 L
F
.217 .5 .325 .1 k
.21555 .2955 m
.22946 .31975 L
.29032 .33841 L
.27229 .31213 L
F
.217 .5 .342 .1 k
.22946 .31975 m
.24517 .34432 L
.31068 .36463 L
.29032 .33841 L
F
.217 .5 .358 .1 k
.24517 .34432 m
.26199 .36799 L
.33248 .3895 L
.31068 .36463 L
F
.217 .5 .375 .1 k
.26199 .36799 m
.27919 .38989 L
.35476 .4121 L
.33248 .3895 L
F
.217 .5 .392 .1 k
.27919 .38989 m
.29601 .40943 L
.37656 .43189 L
.35476 .4121 L
F
.217 .5 .408 .1 k
.29601 .40943 m
.31172 .42623 L
.39692 .44859 L
.37656 .43189 L
F
.217 .5 .425 .1 k
.31172 .42623 m
.32563 .44008 L
.41495 .46209 L
.39692 .44859 L
F
.217 .5 .442 .1 k
.32563 .44008 m
.33714 .45088 L
.42987 .47243 L
.41495 .46209 L
F
.217 .5 .458 .1 k
.33714 .45088 m
.34574 .45858 L
.44101 .47969 L
.42987 .47243 L
F
.217 .5 .475 .1 k
.34574 .45858 m
.35105 .46319 L
.44789 .484 L
.44101 .47969 L
F
.217 .5 .492 .1 k
.35105 .46319 m
.35285 .46472 L
.45022 .48542 L
.44789 .484 L
F
.217 .5 .508 .1 k
.35285 .46472 m
.35105 .46319 L
.44789 .484 L
.45022 .48542 L
F
.217 .5 .525 .1 k
.35105 .46319 m
.34574 .45858 L
.44101 .47969 L
.44789 .484 L
F
.217 .5 .542 .1 k
.34574 .45858 m
.33714 .45088 L
.42987 .47243 L
.44101 .47969 L
F
.217 .5 .558 .1 k
.33714 .45088 m
.32563 .44008 L
.41495 .46209 L
.42987 .47243 L
F
.217 .5 .575 .1 k
.32563 .44008 m
.31172 .42623 L
.39692 .44859 L
.41495 .46209 L
F
.217 .5 .592 .1 k
.31172 .42623 m
.29601 .40943 L
.37656 .43189 L
.39692 .44859 L
F
.217 .5 .608 .1 k
.29601 .40943 m
.27919 .38989 L
.35476 .4121 L
.37656 .43189 L
F
.217 .5 .625 .1 k
.27919 .38989 m
.26199 .36799 L
.33248 .3895 L
.35476 .4121 L
F
.217 .5 .642 .1 k
.26199 .36799 m
.24517 .34432 L
.31068 .36463 L
.33248 .3895 L
F
.217 .5 .658 .1 k
.24517 .34432 m
.22946 .31975 L
.29032 .33841 L
.31068 .36463 L
F
.217 .5 .675 .1 k
.22946 .31975 m
.21555 .2955 L
.27229 .31213 L
.29032 .33841 L
F
.217 .5 .692 .1 k
.21555 .2955 m
.20404 .27319 L
.25738 .28763 L
.27229 .31213 L
F
.217 .5 .708 .1 k
.20404 .27319 m
.19544 .25483 L
.24623 .26722 L
.25738 .28763 L
F
.217 .5 .725 .1 k
.19544 .25483 m
.19013 .2426 L
.23935 .2535 L
.24623 .26722 L
F
.217 .5 .742 .1 k
.19013 .2426 m
.18833 .23828 L
.23702 .24863 L
.23935 .2535 L
F
.217 .5 .758 .1 k
.18833 .23828 m
.19013 .2426 L
.23935 .2535 L
.23702 .24863 L
F
.217 .5 .775 .1 k
.19013 .2426 m
.19544 .25483 L
.24623 .26722 L
.23935 .2535 L
F
.217 .5 .792 .1 k
.19544 .25483 m
.20404 .27319 L
.25738 .28763 L
.24623 .26722 L
F
.217 .5 .808 .1 k
.20404 .27319 m
.21555 .2955 L
.27229 .31213 L
.25738 .28763 L
F
.217 .5 .825 .1 k
.21555 .2955 m
.22946 .31975 L
.29032 .33841 L
.27229 .31213 L
F
.217 .5 .842 .1 k
.22946 .31975 m
.24517 .34432 L
.31068 .36463 L
.29032 .33841 L
F
.217 .5 .858 .1 k
.24517 .34432 m
.26199 .36799 L
.33248 .3895 L
.31068 .36463 L
F
.217 .5 .875 .1 k
.26199 .36799 m
.27919 .38989 L
.35476 .4121 L
.33248 .3895 L
F
.217 .5 .892 .1 k
.27919 .38989 m
.29601 .40943 L
.37656 .43189 L
.35476 .4121 L
F
.217 .5 .908 .1 k
.29601 .40943 m
.31172 .42623 L
.39692 .44859 L
.37656 .43189 L
F
.217 .5 .925 .1 k
.31172 .42623 m
.32563 .44008 L
.41495 .46209 L
.39692 .44859 L
F
.217 .5 .942 .1 k
.32563 .44008 m
.33714 .45088 L
.42987 .47243 L
.41495 .46209 L
F
.217 .5 .958 .1 k
.33714 .45088 m
.34574 .45858 L
.44101 .47969 L
.42987 .47243 L
F
.217 .5 .975 .1 k
.34574 .45858 m
.35105 .46319 L
.44789 .484 L
.44101 .47969 L
F
.217 .5 .992 .1 k
.35105 .46319 m
.35285 .46472 L
.45022 .48542 L
.44789 .484 L
F
.25 .5 .008 .1 k
.45022 .48542 m
.44789 .484 L
.5469 .48427 L
.54978 .48542 L
F
.25 .5 .025 .1 k
.44789 .484 m
.44101 .47969 L
.53841 .48074 L
.5469 .48427 L
F
.25 .5 .042 .1 k
.44101 .47969 m
.42987 .47243 L
.52466 .47465 L
.53841 .48074 L
F
.25 .5 .058 .1 k
.42987 .47243 m
.41495 .46209 L
.50627 .46571 L
.52466 .47465 L
F
.25 .5 .075 .1 k
.41495 .46209 m
.39692 .44859 L
.48403 .45365 L
.50627 .46571 L
F
.25 .5 .092 .1 k
.39692 .44859 m
.37656 .43189 L
.45892 .43822 L
.48403 .45365 L
F
.25 .5 .108 .1 k
.37656 .43189 m
.35476 .4121 L
.43203 .41935 L
.45892 .43822 L
F
.25 .5 .125 .1 k
.35476 .4121 m
.33248 .3895 L
.40454 .39718 L
.43203 .41935 L
F
.25 .5 .142 .1 k
.33248 .3895 m
.31068 .36463 L
.37765 .37215 L
.40454 .39718 L
F
.25 .5 .158 .1 k
.31068 .36463 m
.29032 .33841 L
.35254 .34514 L
.37765 .37215 L
F
.25 .5 .175 .1 k
.29032 .33841 m
.27229 .31213 L
.3303 .31753 L
.35254 .34514 L
F
.25 .5 .192 .1 k
.27229 .31213 m
.25738 .28763 L
.31191 .29131 L
.3303 .31753 L
F
.25 .5 .208 .1 k
.25738 .28763 m
.24623 .26722 L
.29816 .26914 L
.31191 .29131 L
F
.25 .5 .225 .1 k
.24623 .26722 m
.23935 .2535 L
.28967 .25403 L
.29816 .26914 L
F
.25 .5 .242 .1 k
.23935 .2535 m
.23702 .24863 L
.28679 .24863 L
.28967 .25403 L
F
.25 .5 .258 .1 k
.23702 .24863 m
.23935 .2535 L
.28967 .25403 L
.28679 .24863 L
F
.25 .5 .275 .1 k
.23935 .2535 m
.24623 .26722 L
.29816 .26914 L
.28967 .25403 L
F
.25 .5 .292 .1 k
.24623 .26722 m
.25738 .28763 L
.31191 .29131 L
.29816 .26914 L
F
.25 .5 .308 .1 k
.25738 .28763 m
.27229 .31213 L
.3303 .31753 L
.31191 .29131 L
F
.25 .5 .325 .1 k
.27229 .31213 m
.29032 .33841 L
.35254 .34514 L
.3303 .31753 L
F
.25 .5 .342 .1 k
.29032 .33841 m
.31068 .36463 L
.37765 .37215 L
.35254 .34514 L
F
.25 .5 .358 .1 k
.31068 .36463 m
.33248 .3895 L
.40454 .39718 L
.37765 .37215 L
F
.25 .5 .375 .1 k
.33248 .3895 m
.35476 .4121 L
.43203 .41935 L
.40454 .39718 L
F
.25 .5 .392 .1 k
.35476 .4121 m
.37656 .43189 L
.45892 .43822 L
.43203 .41935 L
F
.25 .5 .408 .1 k
.37656 .43189 m
.39692 .44859 L
.48403 .45365 L
.45892 .43822 L
F
.25 .5 .425 .1 k
.39692 .44859 m
.41495 .46209 L
.50627 .46571 L
.48403 .45365 L
F
.25 .5 .442 .1 k
.41495 .46209 m
.42987 .47243 L
.52466 .47465 L
.50627 .46571 L
F
.25 .5 .458 .1 k
.42987 .47243 m
.44101 .47969 L
.53841 .48074 L
.52466 .47465 L
F
.25 .5 .475 .1 k
.44101 .47969 m
.44789 .484 L
.5469 .48427 L
.53841 .48074 L
F
.25 .5 .492 .1 k
.44789 .484 m
.45022 .48542 L
.54978 .48542 L
.5469 .48427 L
F
.25 .5 .508 .1 k
.45022 .48542 m
.44789 .484 L
.5469 .48427 L
.54978 .48542 L
F
.25 .5 .525 .1 k
.44789 .484 m
.44101 .47969 L
.53841 .48074 L
.5469 .48427 L
F
.25 .5 .542 .1 k
.44101 .47969 m
.42987 .47243 L
.52466 .47465 L
.53841 .48074 L
F
.25 .5 .558 .1 k
.42987 .47243 m
.41495 .46209 L
.50627 .46571 L
.52466 .47465 L
F
.25 .5 .575 .1 k
.41495 .46209 m
.39692 .44859 L
.48403 .45365 L
.50627 .46571 L
F
.25 .5 .592 .1 k
.39692 .44859 m
.37656 .43189 L
.45892 .43822 L
.48403 .45365 L
F
.25 .5 .608 .1 k
.37656 .43189 m
.35476 .4121 L
.43203 .41935 L
.45892 .43822 L
F
.25 .5 .625 .1 k
.35476 .4121 m
.33248 .3895 L
.40454 .39718 L
.43203 .41935 L
F
.25 .5 .642 .1 k
.33248 .3895 m
.31068 .36463 L
.37765 .37215 L
.40454 .39718 L
F
.25 .5 .658 .1 k
.31068 .36463 m
.29032 .33841 L
.35254 .34514 L
.37765 .37215 L
F
.25 .5 .675 .1 k
.29032 .33841 m
.27229 .31213 L
.3303 .31753 L
.35254 .34514 L
F
.25 .5 .692 .1 k
.27229 .31213 m
.25738 .28763 L
.31191 .29131 L
.3303 .31753 L
F
.25 .5 .708 .1 k
.25738 .28763 m
.24623 .26722 L
.29816 .26914 L
.31191 .29131 L
F
.25 .5 .725 .1 k
.24623 .26722 m
.23935 .2535 L
.28967 .25403 L
.29816 .26914 L
F
.25 .5 .742 .1 k
.23935 .2535 m
.23702 .24863 L
.28679 .24863 L
.28967 .25403 L
F
.25 .5 .758 .1 k
.23702 .24863 m
.23935 .2535 L
.28967 .25403 L
.28679 .24863 L
F
.25 .5 .775 .1 k
.23935 .2535 m
.24623 .26722 L
.29816 .26914 L
.28967 .25403 L
F
.25 .5 .792 .1 k
.24623 .26722 m
.25738 .28763 L
.31191 .29131 L
.29816 .26914 L
F
.25 .5 .808 .1 k
.25738 .28763 m
.27229 .31213 L
.3303 .31753 L
.31191 .29131 L
F
.25 .5 .825 .1 k
.27229 .31213 m
.29032 .33841 L
.35254 .34514 L
.3303 .31753 L
F
.25 .5 .842 .1 k
.29032 .33841 m
.31068 .36463 L
.37765 .37215 L
.35254 .34514 L
F
.25 .5 .858 .1 k
.31068 .36463 m
.33248 .3895 L
.40454 .39718 L
.37765 .37215 L
F
.25 .5 .875 .1 k
.33248 .3895 m
.35476 .4121 L
.43203 .41935 L
.40454 .39718 L
F
.25 .5 .892 .1 k
.35476 .4121 m
.37656 .43189 L
.45892 .43822 L
.43203 .41935 L
F
.25 .5 .908 .1 k
.37656 .43189 m
.39692 .44859 L
.48403 .45365 L
.45892 .43822 L
F
.25 .5 .925 .1 k
.39692 .44859 m
.41495 .46209 L
.50627 .46571 L
.48403 .45365 L
F
.25 .5 .942 .1 k
.41495 .46209 m
.42987 .47243 L
.52466 .47465 L
.50627 .46571 L
F
.25 .5 .958 .1 k
.42987 .47243 m
.44101 .47969 L
.53841 .48074 L
.52466 .47465 L
F
.25 .5 .975 .1 k
.44101 .47969 m
.44789 .484 L
.5469 .48427 L
.53841 .48074 L
F
.25 .5 .992 .1 k
.44789 .484 m
.45022 .48542 L
.54978 .48542 L
.5469 .48427 L
F
.283 .5 .008 .1 k
.54978 .48542 m
.5469 .48427 L
.64375 .46403 L
.64715 .46472 L
F
.283 .5 .025 .1 k
.5469 .48427 m
.53841 .48074 L
.63368 .46181 L
.64375 .46403 L
F
.283 .5 .042 .1 k
.53841 .48074 m
.52466 .47465 L
.61739 .45771 L
.63368 .46181 L
F
.283 .5 .058 .1 k
.52466 .47465 m
.50627 .46571 L
.59559 .45123 L
.61739 .45771 L
F
.283 .5 .075 .1 k
.50627 .46571 m
.48403 .45365 L
.56923 .44179 L
.59559 .45123 L
F
.283 .5 .092 .1 k
.48403 .45365 m
.45892 .43822 L
.53947 .42888 L
.56923 .44179 L
F
.283 .5 .108 .1 k
.45892 .43822 m
.43203 .41935 L
.5076 .41215 L
.53947 .42888 L
F
.283 .5 .125 .1 k
.43203 .41935 m
.40454 .39718 L
.47503 .39154 L
.5076 .41215 L
F
.283 .5 .142 .1 k
.40454 .39718 m
.37765 .37215 L
.44316 .36735 L
.47503 .39154 L
F
.283 .5 .158 .1 k
.37765 .37215 m
.35254 .34514 L
.4134 .34039 L
.44316 .36735 L
F
.283 .5 .175 .1 k
.35254 .34514 m
.3303 .31753 L
.38704 .31207 L
.4134 .34039 L
F
.283 .5 .192 .1 k
.3303 .31753 m
.31191 .29131 L
.36524 .28452 L
.38704 .31207 L
F
.283 .5 .208 .1 k
.31191 .29131 m
.29816 .26914 L
.34895 .26072 L
.36524 .28452 L
F
.283 .5 .225 .1 k
.29816 .26914 m
.28967 .25403 L
.33889 .24423 L
.34895 .26072 L
F
.283 .5 .242 .1 k
.28967 .25403 m
.28679 .24863 L
.33548 .23828 L
.33889 .24423 L
F
.283 .5 .258 .1 k
.28679 .24863 m
.28967 .25403 L
.33889 .24423 L
.33548 .23828 L
F
.283 .5 .275 .1 k
.28967 .25403 m
.29816 .26914 L
.34895 .26072 L
.33889 .24423 L
F
.283 .5 .292 .1 k
.29816 .26914 m
.31191 .29131 L
.36524 .28452 L
.34895 .26072 L
F
.283 .5 .308 .1 k
.31191 .29131 m
.3303 .31753 L
.38704 .31207 L
.36524 .28452 L
F
.283 .5 .325 .1 k
.3303 .31753 m
.35254 .34514 L
.4134 .34039 L
.38704 .31207 L
F
.283 .5 .342 .1 k
.35254 .34514 m
.37765 .37215 L
.44316 .36735 L
.4134 .34039 L
F
.283 .5 .358 .1 k
.37765 .37215 m
.40454 .39718 L
.47503 .39154 L
.44316 .36735 L
F
.283 .5 .375 .1 k
.40454 .39718 m
.43203 .41935 L
.5076 .41215 L
.47503 .39154 L
F
.283 .5 .392 .1 k
.43203 .41935 m
.45892 .43822 L
.53947 .42888 L
.5076 .41215 L
F
.283 .5 .408 .1 k
.45892 .43822 m
.48403 .45365 L
.56923 .44179 L
.53947 .42888 L
F
.283 .5 .425 .1 k
.48403 .45365 m
.50627 .46571 L
.59559 .45123 L
.56923 .44179 L
F
.283 .5 .442 .1 k
.50627 .46571 m
.52466 .47465 L
.61739 .45771 L
.59559 .45123 L
F
.283 .5 .458 .1 k
.52466 .47465 m
.53841 .48074 L
.63368 .46181 L
.61739 .45771 L
F
.283 .5 .475 .1 k
.53841 .48074 m
.5469 .48427 L
.64375 .46403 L
.63368 .46181 L
F
.283 .5 .492 .1 k
.5469 .48427 m
.54978 .48542 L
.64715 .46472 L
.64375 .46403 L
F
.283 .5 .508 .1 k
.54978 .48542 m
.5469 .48427 L
.64375 .46403 L
.64715 .46472 L
F
.283 .5 .525 .1 k
.5469 .48427 m
.53841 .48074 L
.63368 .46181 L
.64375 .46403 L
F
.283 .5 .542 .1 k
.53841 .48074 m
.52466 .47465 L
.61739 .45771 L
.63368 .46181 L
F
.283 .5 .558 .1 k
.52466 .47465 m
.50627 .46571 L
.59559 .45123 L
.61739 .45771 L
F
.283 .5 .575 .1 k
.50627 .46571 m
.48403 .45365 L
.56923 .44179 L
.59559 .45123 L
F
.283 .5 .592 .1 k
.48403 .45365 m
.45892 .43822 L
.53947 .42888 L
.56923 .44179 L
F
.283 .5 .608 .1 k
.45892 .43822 m
.43203 .41935 L
.5076 .41215 L
.53947 .42888 L
F
.283 .5 .625 .1 k
.43203 .41935 m
.40454 .39718 L
.47503 .39154 L
.5076 .41215 L
F
.283 .5 .642 .1 k
.40454 .39718 m
.37765 .37215 L
.44316 .36735 L
.47503 .39154 L
F
.283 .5 .658 .1 k
.37765 .37215 m
.35254 .34514 L
.4134 .34039 L
.44316 .36735 L
F
.283 .5 .675 .1 k
.35254 .34514 m
.3303 .31753 L
.38704 .31207 L
.4134 .34039 L
F
.283 .5 .692 .1 k
.3303 .31753 m
.31191 .29131 L
.36524 .28452 L
.38704 .31207 L
F
.283 .5 .708 .1 k
.31191 .29131 m
.29816 .26914 L
.34895 .26072 L
.36524 .28452 L
F
.283 .5 .725 .1 k
.29816 .26914 m
.28967 .25403 L
.33889 .24423 L
.34895 .26072 L
F
.283 .5 .742 .1 k
.28967 .25403 m
.28679 .24863 L
.33548 .23828 L
.33889 .24423 L
F
.283 .5 .758 .1 k
.28679 .24863 m
.28967 .25403 L
.33889 .24423 L
.33548 .23828 L
F
.283 .5 .775 .1 k
.28967 .25403 m
.29816 .26914 L
.34895 .26072 L
.33889 .24423 L
F
.283 .5 .792 .1 k
.29816 .26914 m
.31191 .29131 L
.36524 .28452 L
.34895 .26072 L
F
.283 .5 .808 .1 k
.31191 .29131 m
.3303 .31753 L
.38704 .31207 L
.36524 .28452 L
F
.283 .5 .825 .1 k
.3303 .31753 m
.35254 .34514 L
.4134 .34039 L
.38704 .31207 L
F
.283 .5 .842 .1 k
.35254 .34514 m
.37765 .37215 L
.44316 .36735 L
.4134 .34039 L
F
.283 .5 .858 .1 k
.37765 .37215 m
.40454 .39718 L
.47503 .39154 L
.44316 .36735 L
F
.283 .5 .875 .1 k
.40454 .39718 m
.43203 .41935 L
.5076 .41215 L
.47503 .39154 L
F
.283 .5 .892 .1 k
.43203 .41935 m
.45892 .43822 L
.53947 .42888 L
.5076 .41215 L
F
.283 .5 .908 .1 k
.45892 .43822 m
.48403 .45365 L
.56923 .44179 L
.53947 .42888 L
F
.283 .5 .925 .1 k
.48403 .45365 m
.50627 .46571 L
.59559 .45123 L
.56923 .44179 L
F
.283 .5 .942 .1 k
.50627 .46571 m
.52466 .47465 L
.61739 .45771 L
.59559 .45123 L
F
.283 .5 .958 .1 k
.52466 .47465 m
.53841 .48074 L
.63368 .46181 L
.61739 .45771 L
F
.283 .5 .975 .1 k
.53841 .48074 m
.5469 .48427 L
.64375 .46403 L
.63368 .46181 L
F
.283 .5 .992 .1 k
.5469 .48427 m
.54978 .48542 L
.64715 .46472 L
.64375 .46403 L
F
.317 .5 .008 .1 k
.64715 .46472 m
.64375 .46403 L
.73419 .42421 L
.7381 .42423 L
F
.317 .5 .025 .1 k
.64375 .46403 m
.63368 .46181 L
.72266 .42394 L
.73419 .42421 L
F
.317 .5 .042 .1 k
.63368 .46181 m
.61739 .45771 L
.70399 .42282 L
.72266 .42394 L
F
.317 .5 .058 .1 k
.61739 .45771 m
.59559 .45123 L
.67901 .41998 L
.70399 .42282 L
F
.317 .5 .075 .1 k
.59559 .45123 m
.56923 .44179 L
.64881 .41445 L
.67901 .41998 L
F
.317 .5 .092 .1 k
.56923 .44179 m
.53947 .42888 L
.61471 .40534 L
.64881 .41445 L
F
.317 .5 .108 .1 k
.53947 .42888 m
.5076 .41215 L
.57819 .39197 L
.61471 .40534 L
F
.317 .5 .125 .1 k
.5076 .41215 m
.47503 .39154 L
.54086 .37401 L
.57819 .39197 L
F
.317 .5 .142 .1 k
.47503 .39154 m
.44316 .36735 L
.50434 .35159 L
.54086 .37401 L
F
.317 .5 .158 .1 k
.44316 .36735 m
.4134 .34039 L
.47024 .3254 L
.50434 .35159 L
F
.317 .5 .175 .1 k
.4134 .34039 m
.38704 .31207 L
.44004 .29685 L
.47024 .3254 L
F
.317 .5 .192 .1 k
.38704 .31207 m
.36524 .28452 L
.41506 .26819 L
.44004 .29685 L
F
.317 .5 .208 .1 k
.36524 .28452 m
.34895 .26072 L
.39639 .24272 L
.41506 .26819 L
F
.317 .5 .225 .1 k
.34895 .26072 m
.33889 .24423 L
.38485 .22465 L
.39639 .24272 L
F
.317 .5 .242 .1 k
.33889 .24423 m
.33548 .23828 L
.38095 .21804 L
.38485 .22465 L
F
.317 .5 .258 .1 k
.33548 .23828 m
.33889 .24423 L
.38485 .22465 L
.38095 .21804 L
F
.317 .5 .275 .1 k
.33889 .24423 m
.34895 .26072 L
.39639 .24272 L
.38485 .22465 L
F
.317 .5 .292 .1 k
.34895 .26072 m
.36524 .28452 L
.41506 .26819 L
.39639 .24272 L
F
.317 .5 .308 .1 k
.36524 .28452 m
.38704 .31207 L
.44004 .29685 L
.41506 .26819 L
F
.317 .5 .325 .1 k
.38704 .31207 m
.4134 .34039 L
.47024 .3254 L
.44004 .29685 L
F
.317 .5 .342 .1 k
.4134 .34039 m
.44316 .36735 L
.50434 .35159 L
.47024 .3254 L
F
.317 .5 .358 .1 k
.44316 .36735 m
.47503 .39154 L
.54086 .37401 L
.50434 .35159 L
F
.317 .5 .375 .1 k
.47503 .39154 m
.5076 .41215 L
.57819 .39197 L
.54086 .37401 L
F
.317 .5 .392 .1 k
.5076 .41215 m
.53947 .42888 L
.61471 .40534 L
.57819 .39197 L
F
.317 .5 .408 .1 k
.53947 .42888 m
.56923 .44179 L
.64881 .41445 L
.61471 .40534 L
F
.317 .5 .425 .1 k
.56923 .44179 m
.59559 .45123 L
.67901 .41998 L
.64881 .41445 L
F
.317 .5 .442 .1 k
.59559 .45123 m
.61739 .45771 L
.70399 .42282 L
.67901 .41998 L
F
.317 .5 .458 .1 k
.61739 .45771 m
.63368 .46181 L
.72266 .42394 L
.70399 .42282 L
F
.317 .5 .475 .1 k
.63368 .46181 m
.64375 .46403 L
.73419 .42421 L
.72266 .42394 L
F
.317 .5 .492 .1 k
.64375 .46403 m
.64715 .46472 L
.7381 .42423 L
.73419 .42421 L
F
.317 .5 .508 .1 k
.64715 .46472 m
.64375 .46403 L
.73419 .42421 L
.7381 .42423 L
F
.317 .5 .525 .1 k
.64375 .46403 m
.63368 .46181 L
.72266 .42394 L
.73419 .42421 L
F
.317 .5 .542 .1 k
.63368 .46181 m
.61739 .45771 L
.70399 .42282 L
.72266 .42394 L
F
.317 .5 .558 .1 k
.61739 .45771 m
.59559 .45123 L
.67901 .41998 L
.70399 .42282 L
F
.317 .5 .575 .1 k
.59559 .45123 m
.56923 .44179 L
.64881 .41445 L
.67901 .41998 L
F
.317 .5 .592 .1 k
.56923 .44179 m
.53947 .42888 L
.61471 .40534 L
.64881 .41445 L
F
.317 .5 .608 .1 k
.53947 .42888 m
.5076 .41215 L
.57819 .39197 L
.61471 .40534 L
F
.317 .5 .625 .1 k
.5076 .41215 m
.47503 .39154 L
.54086 .37401 L
.57819 .39197 L
F
.317 .5 .642 .1 k
.47503 .39154 m
.44316 .36735 L
.50434 .35159 L
.54086 .37401 L
F
.317 .5 .658 .1 k
.44316 .36735 m
.4134 .34039 L
.47024 .3254 L
.50434 .35159 L
F
.317 .5 .675 .1 k
.4134 .34039 m
.38704 .31207 L
.44004 .29685 L
.47024 .3254 L
F
.317 .5 .692 .1 k
.38704 .31207 m
.36524 .28452 L
.41506 .26819 L
.44004 .29685 L
F
.317 .5 .708 .1 k
.36524 .28452 m
.34895 .26072 L
.39639 .24272 L
.41506 .26819 L
F
.317 .5 .725 .1 k
.34895 .26072 m
.33889 .24423 L
.38485 .22465 L
.39639 .24272 L
F
.317 .5 .742 .1 k
.33889 .24423 m
.33548 .23828 L
.38095 .21804 L
.38485 .22465 L
F
.317 .5 .758 .1 k
.33548 .23828 m
.33889 .24423 L
.38485 .22465 L
.38095 .21804 L
F
.317 .5 .775 .1 k
.33889 .24423 m
.34895 .26072 L
.39639 .24272 L
.38485 .22465 L
F
.317 .5 .792 .1 k
.34895 .26072 m
.36524 .28452 L
.41506 .26819 L
.39639 .24272 L
F
.317 .5 .808 .1 k
.36524 .28452 m
.38704 .31207 L
.44004 .29685 L
.41506 .26819 L
F
.317 .5 .825 .1 k
.38704 .31207 m
.4134 .34039 L
.47024 .3254 L
.44004 .29685 L
F
.317 .5 .842 .1 k
.4134 .34039 m
.44316 .36735 L
.50434 .35159 L
.47024 .3254 L
F
.317 .5 .858 .1 k
.44316 .36735 m
.47503 .39154 L
.54086 .37401 L
.50434 .35159 L
F
.317 .5 .875 .1 k
.47503 .39154 m
.5076 .41215 L
.57819 .39197 L
.54086 .37401 L
F
.317 .5 .892 .1 k
.5076 .41215 m
.53947 .42888 L
.61471 .40534 L
.57819 .39197 L
F
.317 .5 .908 .1 k
.53947 .42888 m
.56923 .44179 L
.64881 .41445 L
.61471 .40534 L
F
.317 .5 .925 .1 k
.56923 .44179 m
.59559 .45123 L
.67901 .41998 L
.64881 .41445 L
F
.317 .5 .942 .1 k
.59559 .45123 m
.61739 .45771 L
.70399 .42282 L
.67901 .41998 L
F
.317 .5 .958 .1 k
.61739 .45771 m
.63368 .46181 L
.72266 .42394 L
.70399 .42282 L
F
.317 .5 .975 .1 k
.63368 .46181 m
.64375 .46403 L
.73419 .42421 L
.72266 .42394 L
F
.317 .5 .992 .1 k
.64375 .46403 m
.64715 .46472 L
.7381 .42423 L
.73419 .42421 L
F
.35 .5 .008 .1 k
.7381 .42423 m
.73419 .42421 L
.81429 .36668 L
.81863 .36572 L
F
.35 .5 .025 .1 k
.73419 .42421 m
.72266 .42394 L
.80145 .36919 L
.81429 .36668 L
F
.35 .5 .042 .1 k
.72266 .42394 m
.70399 .42282 L
.78068 .37226 L
.80145 .36919 L
F
.35 .5 .058 .1 k
.70399 .42282 m
.67901 .41998 L
.75289 .37447 L
.78068 .37226 L
F
.35 .5 .075 .1 k
.67901 .41998 m
.64881 .41445 L
.71928 .37428 L
.75289 .37447 L
F
.35 .5 .092 .1 k
.64881 .41445 m
.61471 .40534 L
.68133 .3703 L
.71928 .37428 L
F
.35 .5 .108 .1 k
.61471 .40534 m
.57819 .39197 L
.6407 .36145 L
.68133 .3703 L
F
.35 .5 .125 .1 k
.57819 .39197 m
.54086 .37401 L
.59916 .34712 L
.6407 .36145 L
F
.35 .5 .142 .1 k
.54086 .37401 m
.50434 .35159 L
.55852 .32723 L
.59916 .34712 L
F
.35 .5 .158 .1 k
.50434 .35159 m
.47024 .3254 L
.52057 .30236 L
.55852 .32723 L
F
.35 .5 .175 .1 k
.47024 .3254 m
.44004 .29685 L
.48697 .27385 L
.52057 .30236 L
F
.35 .5 .192 .1 k
.44004 .29685 m
.41506 .26819 L
.45917 .24404 L
.48697 .27385 L
F
.35 .5 .208 .1 k
.41506 .26819 m
.39639 .24272 L
.4384 .21653 L
.45917 .24404 L
F
.35 .5 .225 .1 k
.39639 .24272 m
.38485 .22465 L
.42556 .19634 L
.4384 .21653 L
F
.35 .5 .242 .1 k
.38485 .22465 m
.38095 .21804 L
.42122 .18878 L
.42556 .19634 L
F
.35 .5 .258 .1 k
.38095 .21804 m
.38485 .22465 L
.42556 .19634 L
.42122 .18878 L
F
.35 .5 .275 .1 k
.38485 .22465 m
.39639 .24272 L
.4384 .21653 L
.42556 .19634 L
F
.35 .5 .292 .1 k
.39639 .24272 m
.41506 .26819 L
.45917 .24404 L
.4384 .21653 L
F
.35 .5 .308 .1 k
.41506 .26819 m
.44004 .29685 L
.48697 .27385 L
.45917 .24404 L
F
.35 .5 .325 .1 k
.44004 .29685 m
.47024 .3254 L
.52057 .30236 L
.48697 .27385 L
F
.35 .5 .342 .1 k
.47024 .3254 m
.50434 .35159 L
.55852 .32723 L
.52057 .30236 L
F
.35 .5 .358 .1 k
.50434 .35159 m
.54086 .37401 L
.59916 .34712 L
.55852 .32723 L
F
.35 .5 .375 .1 k
.54086 .37401 m
.57819 .39197 L
.6407 .36145 L
.59916 .34712 L
F
.35 .5 .392 .1 k
.57819 .39197 m
.61471 .40534 L
.68133 .3703 L
.6407 .36145 L
F
.35 .5 .408 .1 k
.61471 .40534 m
.64881 .41445 L
.71928 .37428 L
.68133 .3703 L
F
.35 .5 .425 .1 k
.64881 .41445 m
.67901 .41998 L
.75289 .37447 L
.71928 .37428 L
F
.35 .5 .442 .1 k
.67901 .41998 m
.70399 .42282 L
.78068 .37226 L
.75289 .37447 L
F
.35 .5 .458 .1 k
.70399 .42282 m
.72266 .42394 L
.80145 .36919 L
.78068 .37226 L
F
.35 .5 .475 .1 k
.72266 .42394 m
.73419 .42421 L
.81429 .36668 L
.80145 .36919 L
F
.35 .5 .492 .1 k
.73419 .42421 m
.7381 .42423 L
.81863 .36572 L
.81429 .36668 L
F
.35 .5 .508 .1 k
.7381 .42423 m
.73419 .42421 L
.81429 .36668 L
.81863 .36572 L
F
.35 .5 .525 .1 k
.73419 .42421 m
.72266 .42394 L
.80145 .36919 L
.81429 .36668 L
F
.35 .5 .542 .1 k
.72266 .42394 m
.70399 .42282 L
.78068 .37226 L
.80145 .36919 L
F
.35 .5 .558 .1 k
.70399 .42282 m
.67901 .41998 L
.75289 .37447 L
.78068 .37226 L
F
.35 .5 .575 .1 k
.67901 .41998 m
.64881 .41445 L
.71928 .37428 L
.75289 .37447 L
F
.35 .5 .592 .1 k
.64881 .41445 m
.61471 .40534 L
.68133 .3703 L
.71928 .37428 L
F
.35 .5 .608 .1 k
.61471 .40534 m
.57819 .39197 L
.6407 .36145 L
.68133 .3703 L
F
.35 .5 .625 .1 k
.57819 .39197 m
.54086 .37401 L
.59916 .34712 L
.6407 .36145 L
F
.35 .5 .642 .1 k
.54086 .37401 m
.50434 .35159 L
.55852 .32723 L
.59916 .34712 L
F
.35 .5 .658 .1 k
.50434 .35159 m
.47024 .3254 L
.52057 .30236 L
.55852 .32723 L
F
.35 .5 .675 .1 k
.47024 .3254 m
.44004 .29685 L
.48697 .27385 L
.52057 .30236 L
F
.35 .5 .692 .1 k
.44004 .29685 m
.41506 .26819 L
.45917 .24404 L
.48697 .27385 L
F
.35 .5 .708 .1 k
.41506 .26819 m
.39639 .24272 L
.4384 .21653 L
.45917 .24404 L
F
.35 .5 .725 .1 k
.39639 .24272 m
.38485 .22465 L
.42556 .19634 L
.4384 .21653 L
F
.35 .5 .742 .1 k
.38485 .22465 m
.38095 .21804 L
.42122 .18878 L
.42556 .19634 L
F
.35 .5 .758 .1 k
.38095 .21804 m
.38485 .22465 L
.42556 .19634 L
.42122 .18878 L
F
.35 .5 .775 .1 k
.38485 .22465 m
.39639 .24272 L
.4384 .21653 L
.42556 .19634 L
F
.35 .5 .792 .1 k
.39639 .24272 m
.41506 .26819 L
.45917 .24404 L
.4384 .21653 L
F
.35 .5 .808 .1 k
.41506 .26819 m
.44004 .29685 L
.48697 .27385 L
.45917 .24404 L
F
.35 .5 .825 .1 k
.44004 .29685 m
.47024 .3254 L
.52057 .30236 L
.48697 .27385 L
F
.35 .5 .842 .1 k
.47024 .3254 m
.50434 .35159 L
.55852 .32723 L
.52057 .30236 L
F
.35 .5 .858 .1 k
.50434 .35159 m
.54086 .37401 L
.59916 .34712 L
.55852 .32723 L
F
.35 .5 .875 .1 k
.54086 .37401 m
.57819 .39197 L
.6407 .36145 L
.59916 .34712 L
F
.35 .5 .892 .1 k
.57819 .39197 m
.61471 .40534 L
.68133 .3703 L
.6407 .36145 L
F
.35 .5 .908 .1 k
.61471 .40534 m
.64881 .41445 L
.71928 .37428 L
.68133 .3703 L
F
.35 .5 .925 .1 k
.64881 .41445 m
.67901 .41998 L
.75289 .37447 L
.71928 .37428 L
F
.35 .5 .942 .1 k
.67901 .41998 m
.70399 .42282 L
.78068 .37226 L
.75289 .37447 L
F
.35 .5 .958 .1 k
.70399 .42282 m
.72266 .42394 L
.80145 .36919 L
.78068 .37226 L
F
.35 .5 .975 .1 k
.72266 .42394 m
.73419 .42421 L
.81429 .36668 L
.80145 .36919 L
F
.35 .5 .992 .1 k
.73419 .42421 m
.7381 .42423 L
.81863 .36572 L
.81429 .36668 L
F
.383 .5 .008 .1 k
.81863 .36572 m
.81429 .36668 L
.88054 .29416 L
.88525 .29174 L
F
.383 .5 .025 .1 k
.81429 .36668 m
.80145 .36919 L
.86663 .30076 L
.88054 .29416 L
F
.383 .5 .042 .1 k
.80145 .36919 m
.78068 .37226 L
.84412 .30976 L
.86663 .30076 L
F
.383 .5 .058 .1 k
.78068 .37226 m
.75289 .37447 L
.81399 .31882 L
.84412 .30976 L
F
.383 .5 .075 .1 k
.75289 .37447 m
.71928 .37428 L
.77757 .32559 L
.81399 .31882 L
F
.383 .5 .092 .1 k
.71928 .37428 m
.68133 .3703 L
.73644 .32806 L
.77757 .32559 L
F
.383 .5 .108 .1 k
.68133 .3703 m
.6407 .36145 L
.6924 .32474 L
.73644 .32806 L
F
.383 .5 .125 .1 k
.6407 .36145 m
.59916 .34712 L
.64738 .31477 L
.6924 .32474 L
F
.383 .5 .142 .1 k
.59916 .34712 m
.55852 .32723 L
.60334 .29791 L
.64738 .31477 L
F
.383 .5 .158 .1 k
.55852 .32723 m
.52057 .30236 L
.56221 .27463 L
.60334 .29791 L
F
.383 .5 .175 .1 k
.52057 .30236 m
.48697 .27385 L
.52578 .24619 L
.56221 .27463 L
F
.383 .5 .192 .1 k
.48697 .27385 m
.45917 .24404 L
.49566 .21487 L
.52578 .24619 L
F
.383 .5 .208 .1 k
.45917 .24404 m
.4384 .21653 L
.47315 .18446 L
.49566 .21487 L
F
.383 .5 .225 .1 k
.4384 .21653 m
.42556 .19634 L
.45923 .16095 L
.47315 .18446 L
F
.383 .5 .242 .1 k
.42556 .19634 m
.42122 .18878 L
.45453 .15179 L
.45923 .16095 L
F
.383 .5 .258 .1 k
.42122 .18878 m
.42556 .19634 L
.45923 .16095 L
.45453 .15179 L
F
.383 .5 .275 .1 k
.42556 .19634 m
.4384 .21653 L
.47315 .18446 L
.45923 .16095 L
F
.383 .5 .292 .1 k
.4384 .21653 m
.45917 .24404 L
.49566 .21487 L
.47315 .18446 L
F
.383 .5 .308 .1 k
.45917 .24404 m
.48697 .27385 L
.52578 .24619 L
.49566 .21487 L
F
.383 .5 .325 .1 k
.48697 .27385 m
.52057 .30236 L
.56221 .27463 L
.52578 .24619 L
F
.383 .5 .342 .1 k
.52057 .30236 m
.55852 .32723 L
.60334 .29791 L
.56221 .27463 L
F
.383 .5 .358 .1 k
.55852 .32723 m
.59916 .34712 L
.64738 .31477 L
.60334 .29791 L
F
.383 .5 .375 .1 k
.59916 .34712 m
.6407 .36145 L
.6924 .32474 L
.64738 .31477 L
F
.383 .5 .392 .1 k
.6407 .36145 m
.68133 .3703 L
.73644 .32806 L
.6924 .32474 L
F
.383 .5 .408 .1 k
.68133 .3703 m
.71928 .37428 L
.77757 .32559 L
.73644 .32806 L
F
.383 .5 .425 .1 k
.71928 .37428 m
.75289 .37447 L
.81399 .31882 L
.77757 .32559 L
F
.383 .5 .442 .1 k
.75289 .37447 m
.78068 .37226 L
.84412 .30976 L
.81399 .31882 L
F
.383 .5 .458 .1 k
.78068 .37226 m
.80145 .36919 L
.86663 .30076 L
.84412 .30976 L
F
.383 .5 .475 .1 k
.80145 .36919 m
.81429 .36668 L
.88054 .29416 L
.86663 .30076 L
F
.383 .5 .492 .1 k
.81429 .36668 m
.81863 .36572 L
.88525 .29174 L
.88054 .29416 L
F
.383 .5 .508 .1 k
.81863 .36572 m
.81429 .36668 L
.88054 .29416 L
.88525 .29174 L
F
.383 .5 .525 .1 k
.81429 .36668 m
.80145 .36919 L
.86663 .30076 L
.88054 .29416 L
F
.383 .5 .542 .1 k
.80145 .36919 m
.78068 .37226 L
.84412 .30976 L
.86663 .30076 L
F
.383 .5 .558 .1 k
.78068 .37226 m
.75289 .37447 L
.81399 .31882 L
.84412 .30976 L
F
.383 .5 .575 .1 k
.75289 .37447 m
.71928 .37428 L
.77757 .32559 L
.81399 .31882 L
F
.383 .5 .592 .1 k
.71928 .37428 m
.68133 .3703 L
.73644 .32806 L
.77757 .32559 L
F
.383 .5 .608 .1 k
.68133 .3703 m
.6407 .36145 L
.6924 .32474 L
.73644 .32806 L
F
.383 .5 .625 .1 k
.6407 .36145 m
.59916 .34712 L
.64738 .31477 L
.6924 .32474 L
F
.383 .5 .642 .1 k
.59916 .34712 m
.55852 .32723 L
.60334 .29791 L
.64738 .31477 L
F
.383 .5 .658 .1 k
.55852 .32723 m
.52057 .30236 L
.56221 .27463 L
.60334 .29791 L
F
.383 .5 .675 .1 k
.52057 .30236 m
.48697 .27385 L
.52578 .24619 L
.56221 .27463 L
F
.383 .5 .692 .1 k
.48697 .27385 m
.45917 .24404 L
.49566 .21487 L
.52578 .24619 L
F
.383 .5 .708 .1 k
.45917 .24404 m
.4384 .21653 L
.47315 .18446 L
.49566 .21487 L
F
.383 .5 .725 .1 k
.4384 .21653 m
.42556 .19634 L
.45923 .16095 L
.47315 .18446 L
F
.383 .5 .742 .1 k
.42556 .19634 m
.42122 .18878 L
.45453 .15179 L
.45923 .16095 L
F
.383 .5 .758 .1 k
.42122 .18878 m
.42556 .19634 L
.45923 .16095 L
.45453 .15179 L
F
.383 .5 .775 .1 k
.42556 .19634 m
.4384 .21653 L
.47315 .18446 L
.45923 .16095 L
F
.383 .5 .792 .1 k
.4384 .21653 m
.45917 .24404 L
.49566 .21487 L
.47315 .18446 L
F
.383 .5 .808 .1 k
.45917 .24404 m
.48697 .27385 L
.52578 .24619 L
.49566 .21487 L
F
.383 .5 .825 .1 k
.48697 .27385 m
.52057 .30236 L
.56221 .27463 L
.52578 .24619 L
F
.383 .5 .842 .1 k
.52057 .30236 m
.55852 .32723 L
.60334 .29791 L
.56221 .27463 L
F
.383 .5 .858 .1 k
.55852 .32723 m
.59916 .34712 L
.64738 .31477 L
.60334 .29791 L
F
.383 .5 .875 .1 k
.59916 .34712 m
.6407 .36145 L
.6924 .32474 L
.64738 .31477 L
F
.383 .5 .892 .1 k
.6407 .36145 m
.68133 .3703 L
.73644 .32806 L
.6924 .32474 L
F
.383 .5 .908 .1 k
.68133 .3703 m
.71928 .37428 L
.77757 .32559 L
.73644 .32806 L
F
.383 .5 .925 .1 k
.71928 .37428 m
.75289 .37447 L
.81399 .31882 L
.77757 .32559 L
F
.383 .5 .942 .1 k
.75289 .37447 m
.78068 .37226 L
.84412 .30976 L
.81399 .31882 L
F
.383 .5 .958 .1 k
.78068 .37226 m
.80145 .36919 L
.86663 .30076 L
.84412 .30976 L
F
.383 .5 .975 .1 k
.80145 .36919 m
.81429 .36668 L
.88054 .29416 L
.86663 .30076 L
F
.383 .5 .992 .1 k
.81429 .36668 m
.81863 .36572 L
.88525 .29174 L
.88054 .29416 L
F
.417 .5 .008 .1 k
.88525 .29174 m
.88054 .29416 L
.93004 .21046 L
.93502 .20552 L
F
.417 .5 .025 .1 k
.88054 .29416 m
.86663 .30076 L
.91533 .22369 L
.93004 .21046 L
F
.417 .5 .042 .1 k
.86663 .30076 m
.84412 .30976 L
.89152 .24153 L
.91533 .22369 L
F
.417 .5 .058 .1 k
.84412 .30976 m
.81399 .31882 L
.85965 .25987 L
.89152 .24153 L
F
.417 .5 .075 .1 k
.81399 .31882 m
.77757 .32559 L
.82112 .27528 L
.85965 .25987 L
F
.417 .5 .092 .1 k
.77757 .32559 m
.73644 .32806 L
.77761 .28521 L
.82112 .27528 L
F
.417 .5 .108 .1 k
.73644 .32806 m
.6924 .32474 L
.73103 .28796 L
.77761 .28521 L
F
.417 .5 .125 .1 k
.6924 .32474 m
.64738 .31477 L
.68341 .28258 L
.73103 .28796 L
F
.417 .5 .142 .1 k
.64738 .31477 m
.60334 .29791 L
.63682 .26882 L
.68341 .28258 L
F
.417 .5 .158 .1 k
.60334 .29791 m
.56221 .27463 L
.59332 .24707 L
.63682 .26882 L
F
.417 .5 .175 .1 k
.56221 .27463 m
.52578 .24619 L
.55479 .21846 L
.59332 .24707 L
F
.417 .5 .192 .1 k
.52578 .24619 m
.49566 .21487 L
.52292 .18503 L
.55479 .21846 L
F
.417 .5 .208 .1 k
.49566 .21487 m
.47315 .18446 L
.49911 .15033 L
.52292 .18503 L
F
.417 .5 .225 .1 k
.47315 .18446 m
.45923 .16095 L
.48439 .12106 L
.49911 .15033 L
F
.417 .5 .242 .1 k
.45923 .16095 m
.45453 .15179 L
.47942 .10868 L
.48439 .12106 L
F
.417 .5 .258 .1 k
.45453 .15179 m
.45923 .16095 L
.48439 .12106 L
.47942 .10868 L
F
.417 .5 .275 .1 k
.45923 .16095 m
.47315 .18446 L
.49911 .15033 L
.48439 .12106 L
F
.417 .5 .292 .1 k
.47315 .18446 m
.49566 .21487 L
.52292 .18503 L
.49911 .15033 L
F
.417 .5 .308 .1 k
.49566 .21487 m
.52578 .24619 L
.55479 .21846 L
.52292 .18503 L
F
.417 .5 .325 .1 k
.52578 .24619 m
.56221 .27463 L
.59332 .24707 L
.55479 .21846 L
F
.417 .5 .342 .1 k
.56221 .27463 m
.60334 .29791 L
.63682 .26882 L
.59332 .24707 L
F
.417 .5 .358 .1 k
.60334 .29791 m
.64738 .31477 L
.68341 .28258 L
.63682 .26882 L
F
.417 .5 .375 .1 k
.64738 .31477 m
.6924 .32474 L
.73103 .28796 L
.68341 .28258 L
F
.417 .5 .392 .1 k
.6924 .32474 m
.73644 .32806 L
.77761 .28521 L
.73103 .28796 L
F
.417 .5 .408 .1 k
.73644 .32806 m
.77757 .32559 L
.82112 .27528 L
.77761 .28521 L
F
.417 .5 .425 .1 k
.77757 .32559 m
.81399 .31882 L
.85965 .25987 L
.82112 .27528 L
F
.417 .5 .442 .1 k
.81399 .31882 m
.84412 .30976 L
.89152 .24153 L
.85965 .25987 L
F
.417 .5 .458 .1 k
.84412 .30976 m
.86663 .30076 L
.91533 .22369 L
.89152 .24153 L
F
.417 .5 .475 .1 k
.86663 .30076 m
.88054 .29416 L
.93004 .21046 L
.91533 .22369 L
F
.417 .5 .492 .1 k
.88054 .29416 m
.88525 .29174 L
.93502 .20552 L
.93004 .21046 L
F
.417 .5 .508 .1 k
.88525 .29174 m
.88054 .29416 L
.93004 .21046 L
.93502 .20552 L
F
.417 .5 .525 .1 k
.88054 .29416 m
.86663 .30076 L
.91533 .22369 L
.93004 .21046 L
F
.417 .5 .542 .1 k
.86663 .30076 m
.84412 .30976 L
.89152 .24153 L
.91533 .22369 L
F
.417 .5 .558 .1 k
.84412 .30976 m
.81399 .31882 L
.85965 .25987 L
.89152 .24153 L
F
.417 .5 .575 .1 k
.81399 .31882 m
.77757 .32559 L
.82112 .27528 L
.85965 .25987 L
F
.417 .5 .592 .1 k
.77757 .32559 m
.73644 .32806 L
.77761 .28521 L
.82112 .27528 L
F
.417 .5 .608 .1 k
.73644 .32806 m
.6924 .32474 L
.73103 .28796 L
.77761 .28521 L
F
.417 .5 .625 .1 k
.6924 .32474 m
.64738 .31477 L
.68341 .28258 L
.73103 .28796 L
F
.417 .5 .642 .1 k
.64738 .31477 m
.60334 .29791 L
.63682 .26882 L
.68341 .28258 L
F
.417 .5 .658 .1 k
.60334 .29791 m
.56221 .27463 L
.59332 .24707 L
.63682 .26882 L
F
.417 .5 .675 .1 k
.56221 .27463 m
.52578 .24619 L
.55479 .21846 L
.59332 .24707 L
F
.417 .5 .692 .1 k
.52578 .24619 m
.49566 .21487 L
.52292 .18503 L
.55479 .21846 L
F
.417 .5 .708 .1 k
.49566 .21487 m
.47315 .18446 L
.49911 .15033 L
.52292 .18503 L
F
.417 .5 .725 .1 k
.47315 .18446 m
.45923 .16095 L
.48439 .12106 L
.49911 .15033 L
F
.417 .5 .742 .1 k
.45923 .16095 m
.45453 .15179 L
.47942 .10868 L
.48439 .12106 L
F
.417 .5 .758 .1 k
.45453 .15179 m
.45923 .16095 L
.48439 .12106 L
.47942 .10868 L
F
.417 .5 .775 .1 k
.45923 .16095 m
.47315 .18446 L
.49911 .15033 L
.48439 .12106 L
F
.417 .5 .792 .1 k
.47315 .18446 m
.49566 .21487 L
.52292 .18503 L
.49911 .15033 L
F
.417 .5 .808 .1 k
.49566 .21487 m
.52578 .24619 L
.55479 .21846 L
.52292 .18503 L
F
.417 .5 .825 .1 k
.52578 .24619 m
.56221 .27463 L
.59332 .24707 L
.55479 .21846 L
F
.417 .5 .842 .1 k
.56221 .27463 m
.60334 .29791 L
.63682 .26882 L
.59332 .24707 L
F
.417 .5 .858 .1 k
.60334 .29791 m
.64738 .31477 L
.68341 .28258 L
.63682 .26882 L
F
.417 .5 .875 .1 k
.64738 .31477 m
.6924 .32474 L
.73103 .28796 L
.68341 .28258 L
F
.417 .5 .892 .1 k
.6924 .32474 m
.73644 .32806 L
.77761 .28521 L
.73103 .28796 L
F
.417 .5 .908 .1 k
.73644 .32806 m
.77757 .32559 L
.82112 .27528 L
.77761 .28521 L
F
.417 .5 .925 .1 k
.77757 .32559 m
.81399 .31882 L
.85965 .25987 L
.82112 .27528 L
F
.417 .5 .942 .1 k
.81399 .31882 m
.84412 .30976 L
.89152 .24153 L
.85965 .25987 L
F
.417 .5 .958 .1 k
.84412 .30976 m
.86663 .30076 L
.91533 .22369 L
.89152 .24153 L
F
.417 .5 .975 .1 k
.86663 .30076 m
.88054 .29416 L
.93004 .21046 L
.91533 .22369 L
F
.417 .5 .992 .1 k
.88054 .29416 m
.88525 .29174 L
.93502 .20552 L
.93004 .21046 L
F
.45 .5 .008 .1 k
.93502 .20552 m
.93004 .21046 L
.96064 .12193 L
.96578 .11085 L
F
.45 .5 .025 .1 k
.93004 .21046 m
.91533 .22369 L
.94543 .14844 L
.96064 .12193 L
F
.45 .5 .042 .1 k
.91533 .22369 m
.89152 .24153 L
.92081 .17995 L
.94543 .14844 L
F
.45 .5 .058 .1 k
.89152 .24153 m
.85965 .25987 L
.88787 .20986 L
.92081 .17995 L
F
.45 .5 .075 .1 k
.85965 .25987 m
.82112 .27528 L
.84804 .23445 L
.88787 .20986 L
F
.45 .5 .092 .1 k
.82112 .27528 m
.77761 .28521 L
.80306 .25147 L
.84804 .23445 L
F
.45 .5 .108 .1 k
.77761 .28521 m
.73103 .28796 L
.75491 .25955 L
.80306 .25147 L
F
.45 .5 .125 .1 k
.73103 .28796 m
.68341 .28258 L
.70568 .258 L
.75491 .25955 L
F
.45 .5 .142 .1 k
.68341 .28258 m
.63682 .26882 L
.65752 .24668 L
.70568 .258 L
F
.45 .5 .158 .1 k
.63682 .26882 m
.59332 .24707 L
.61254 .22604 L
.65752 .24668 L
F
.45 .5 .175 .1 k
.59332 .24707 m
.55479 .21846 L
.57271 .19703 L
.61254 .22604 L
F
.45 .5 .192 .1 k
.55479 .21846 m
.52292 .18503 L
.53977 .16121 L
.57271 .19703 L
F
.45 .5 .208 .1 k
.52292 .18503 m
.49911 .15033 L
.51516 .12112 L
.53977 .16121 L
F
.45 .5 .225 .1 k
.49911 .15033 m
.48439 .12106 L
.49994 .08204 L
.51516 .12112 L
F
.45 .5 .242 .1 k
.48439 .12106 m
.47942 .10868 L
.4948 .06134 L
.49994 .08204 L
F
.45 .5 .258 .1 k
.47942 .10868 m
.48439 .12106 L
.49994 .08204 L
.4948 .06134 L
F
.45 .5 .275 .1 k
.48439 .12106 m
.49911 .15033 L
.51516 .12112 L
.49994 .08204 L
F
.45 .5 .292 .1 k
.49911 .15033 m
.52292 .18503 L
.53977 .16121 L
.51516 .12112 L
F
.45 .5 .308 .1 k
.52292 .18503 m
.55479 .21846 L
.57271 .19703 L
.53977 .16121 L
F
.45 .5 .325 .1 k
.55479 .21846 m
.59332 .24707 L
.61254 .22604 L
.57271 .19703 L
F
.45 .5 .342 .1 k
.59332 .24707 m
.63682 .26882 L
.65752 .24668 L
.61254 .22604 L
F
.45 .5 .358 .1 k
.63682 .26882 m
.68341 .28258 L
.70568 .258 L
.65752 .24668 L
F
.45 .5 .375 .1 k
.68341 .28258 m
.73103 .28796 L
.75491 .25955 L
.70568 .258 L
F
.45 .5 .392 .1 k
.73103 .28796 m
.77761 .28521 L
.80306 .25147 L
.75491 .25955 L
F
.45 .5 .408 .1 k
.77761 .28521 m
.82112 .27528 L
.84804 .23445 L
.80306 .25147 L
F
.45 .5 .425 .1 k
.82112 .27528 m
.85965 .25987 L
.88787 .20986 L
.84804 .23445 L
F
.45 .5 .442 .1 k
.85965 .25987 m
.89152 .24153 L
.92081 .17995 L
.88787 .20986 L
F
.45 .5 .458 .1 k
.89152 .24153 m
.91533 .22369 L
.94543 .14844 L
.92081 .17995 L
F
.45 .5 .475 .1 k
.91533 .22369 m
.93004 .21046 L
.96064 .12193 L
.94543 .14844 L
F
.45 .5 .492 .1 k
.93004 .21046 m
.93502 .20552 L
.96578 .11085 L
.96064 .12193 L
F
.45 .5 .508 .1 k
.93502 .20552 m
.93004 .21046 L
.96064 .12193 L
.96578 .11085 L
F
.45 .5 .525 .1 k
.93004 .21046 m
.91533 .22369 L
.94543 .14844 L
.96064 .12193 L
F
.45 .5 .542 .1 k
.91533 .22369 m
.89152 .24153 L
.92081 .17995 L
.94543 .14844 L
F
.45 .5 .558 .1 k
.89152 .24153 m
.85965 .25987 L
.88787 .20986 L
.92081 .17995 L
F
.45 .5 .575 .1 k
.85965 .25987 m
.82112 .27528 L
.84804 .23445 L
.88787 .20986 L
F
.45 .5 .592 .1 k
.82112 .27528 m
.77761 .28521 L
.80306 .25147 L
.84804 .23445 L
F
.45 .5 .608 .1 k
.77761 .28521 m
.73103 .28796 L
.75491 .25955 L
.80306 .25147 L
F
.45 .5 .625 .1 k
.73103 .28796 m
.68341 .28258 L
.70568 .258 L
.75491 .25955 L
F
.45 .5 .642 .1 k
.68341 .28258 m
.63682 .26882 L
.65752 .24668 L
.70568 .258 L
F
.45 .5 .658 .1 k
.63682 .26882 m
.59332 .24707 L
.61254 .22604 L
.65752 .24668 L
F
.45 .5 .675 .1 k
.59332 .24707 m
.55479 .21846 L
.57271 .19703 L
.61254 .22604 L
F
.45 .5 .692 .1 k
.55479 .21846 m
.52292 .18503 L
.53977 .16121 L
.57271 .19703 L
F
.45 .5 .708 .1 k
.52292 .18503 m
.49911 .15033 L
.51516 .12112 L
.53977 .16121 L
F
.45 .5 .725 .1 k
.49911 .15033 m
.48439 .12106 L
.49994 .08204 L
.51516 .12112 L
F
.45 .5 .742 .1 k
.48439 .12106 m
.47942 .10868 L
.4948 .06134 L
.49994 .08204 L
F
.45 .5 .758 .1 k
.47942 .10868 m
.48439 .12106 L
.49994 .08204 L
.4948 .06134 L
F
.45 .5 .775 .1 k
.48439 .12106 m
.49911 .15033 L
.51516 .12112 L
.49994 .08204 L
F
.45 .5 .792 .1 k
.49911 .15033 m
.52292 .18503 L
.53977 .16121 L
.51516 .12112 L
F
.45 .5 .808 .1 k
.52292 .18503 m
.55479 .21846 L
.57271 .19703 L
.53977 .16121 L
F
.45 .5 .825 .1 k
.55479 .21846 m
.59332 .24707 L
.61254 .22604 L
.57271 .19703 L
F
.45 .5 .842 .1 k
.59332 .24707 m
.63682 .26882 L
.65752 .24668 L
.61254 .22604 L
F
.45 .5 .858 .1 k
.63682 .26882 m
.68341 .28258 L
.70568 .258 L
.65752 .24668 L
F
.45 .5 .875 .1 k
.68341 .28258 m
.73103 .28796 L
.75491 .25955 L
.70568 .258 L
F
.45 .5 .892 .1 k
.73103 .28796 m
.77761 .28521 L
.80306 .25147 L
.75491 .25955 L
F
.45 .5 .908 .1 k
.77761 .28521 m
.82112 .27528 L
.84804 .23445 L
.80306 .25147 L
F
.45 .5 .925 .1 k
.82112 .27528 m
.85965 .25987 L
.88787 .20986 L
.84804 .23445 L
F
.45 .5 .942 .1 k
.85965 .25987 m
.89152 .24153 L
.92081 .17995 L
.88787 .20986 L
F
.45 .5 .958 .1 k
.89152 .24153 m
.91533 .22369 L
.94543 .14844 L
.92081 .17995 L
F
.45 .5 .975 .1 k
.91533 .22369 m
.93004 .21046 L
.96064 .12193 L
.94543 .14844 L
F
.45 .5 .992 .1 k
.93004 .21046 m
.93502 .20552 L
.96578 .11085 L
.96064 .12193 L
F
.483 .5 .008 .1 k
.96578 .11085 m
.96064 .12193 L
.97099 .06134 L
.97619 .01184 L
F
.483 .5 .025 .1 k
.96064 .12193 m
.94543 .14844 L
.95561 .10868 L
.97099 .06134 L
F
.483 .5 .042 .1 k
.94543 .14844 m
.92081 .17995 L
.93072 .15179 L
.95561 .10868 L
F
.483 .5 .058 .1 k
.92081 .17995 m
.88787 .20986 L
.89741 .18878 L
.93072 .15179 L
F
.483 .5 .075 .1 k
.88787 .20986 m
.84804 .23445 L
.85714 .21804 L
.89741 .18878 L
F
.483 .5 .092 .1 k
.84804 .23445 m
.80306 .25147 L
.81167 .23828 L
.85714 .21804 L
F
.483 .5 .108 .1 k
.80306 .25147 m
.75491 .25955 L
.76298 .24863 L
.81167 .23828 L
F
.483 .5 .125 .1 k
.75491 .25955 m
.70568 .258 L
.71321 .24863 L
.76298 .24863 L
F
.483 .5 .142 .1 k
.70568 .258 m
.65752 .24668 L
.66452 .23828 L
.71321 .24863 L
F
.483 .5 .158 .1 k
.65752 .24668 m
.61254 .22604 L
.61905 .21804 L
.66452 .23828 L
F
.483 .5 .175 .1 k
.61254 .22604 m
.57271 .19703 L
.57878 .18878 L
.61905 .21804 L
F
.483 .5 .192 .1 k
.57271 .19703 m
.53977 .16121 L
.54547 .15179 L
.57878 .18878 L
F
.483 .5 .208 .1 k
.53977 .16121 m
.51516 .12112 L
.52058 .10868 L
.54547 .15179 L
F
.483 .5 .225 .1 k
.51516 .12112 m
.49994 .08204 L
.5052 .06134 L
.52058 .10868 L
F
.483 .5 .242 .1 k
.49994 .08204 m
.4948 .06134 L
.5 .01184 L
.5052 .06134 L
F
.483 .5 .258 .1 k
.4948 .06134 m
.49994 .08204 L
.5052 .06134 L
.5 .01184 L
F
.483 .5 .275 .1 k
.49994 .08204 m
.51516 .12112 L
.52058 .10868 L
.5052 .06134 L
F
.483 .5 .292 .1 k
.51516 .12112 m
.53977 .16121 L
.54547 .15179 L
.52058 .10868 L
F
.483 .5 .308 .1 k
.53977 .16121 m
.57271 .19703 L
.57878 .18878 L
.54547 .15179 L
F
.483 .5 .325 .1 k
.57271 .19703 m
.61254 .22604 L
.61905 .21804 L
.57878 .18878 L
F
.483 .5 .342 .1 k
.61254 .22604 m
.65752 .24668 L
.66452 .23828 L
.61905 .21804 L
F
.483 .5 .358 .1 k
.65752 .24668 m
.70568 .258 L
.71321 .24863 L
.66452 .23828 L
F
.483 .5 .375 .1 k
.70568 .258 m
.75491 .25955 L
.76298 .24863 L
.71321 .24863 L
F
.483 .5 .392 .1 k
.75491 .25955 m
.80306 .25147 L
.81167 .23828 L
.76298 .24863 L
F
.483 .5 .408 .1 k
.80306 .25147 m
.84804 .23445 L
.85714 .21804 L
.81167 .23828 L
F
.483 .5 .425 .1 k
.84804 .23445 m
.88787 .20986 L
.89741 .18878 L
.85714 .21804 L
F
.483 .5 .442 .1 k
.88787 .20986 m
.92081 .17995 L
.93072 .15179 L
.89741 .18878 L
F
.483 .5 .458 .1 k
.92081 .17995 m
.94543 .14844 L
.95561 .10868 L
.93072 .15179 L
F
.483 .5 .475 .1 k
.94543 .14844 m
.96064 .12193 L
.97099 .06134 L
.95561 .10868 L
F
.483 .5 .492 .1 k
.96064 .12193 m
.96578 .11085 L
.97619 .01184 L
.97099 .06134 L
F
.483 .5 .508 .1 k
.96578 .11085 m
.96064 .12193 L
.97099 .06134 L
.97619 .01184 L
F
.483 .5 .525 .1 k
.96064 .12193 m
.94543 .14844 L
.95561 .10868 L
.97099 .06134 L
F
.483 .5 .542 .1 k
.94543 .14844 m
.92081 .17995 L
.93072 .15179 L
.95561 .10868 L
F
.483 .5 .558 .1 k
.92081 .17995 m
.88787 .20986 L
.89741 .18878 L
.93072 .15179 L
F
.483 .5 .575 .1 k
.88787 .20986 m
.84804 .23445 L
.85714 .21804 L
.89741 .18878 L
F
.483 .5 .592 .1 k
.84804 .23445 m
.80306 .25147 L
.81167 .23828 L
.85714 .21804 L
F
.483 .5 .608 .1 k
.80306 .25147 m
.75491 .25955 L
.76298 .24863 L
.81167 .23828 L
F
.483 .5 .625 .1 k
.75491 .25955 m
.70568 .258 L
.71321 .24863 L
.76298 .24863 L
F
.483 .5 .642 .1 k
.70568 .258 m
.65752 .24668 L
.66452 .23828 L
.71321 .24863 L
F
.483 .5 .658 .1 k
.65752 .24668 m
.61254 .22604 L
.61905 .21804 L
.66452 .23828 L
F
.483 .5 .675 .1 k
.61254 .22604 m
.57271 .19703 L
.57878 .18878 L
.61905 .21804 L
F
.483 .5 .692 .1 k
.57271 .19703 m
.53977 .16121 L
.54547 .15179 L
.57878 .18878 L
F
.483 .5 .708 .1 k
.53977 .16121 m
.51516 .12112 L
.52058 .10868 L
.54547 .15179 L
F
.483 .5 .725 .1 k
.51516 .12112 m
.49994 .08204 L
.5052 .06134 L
.52058 .10868 L
F
.483 .5 .742 .1 k
.49994 .08204 m
.4948 .06134 L
.5 .01184 L
.5052 .06134 L
F
.483 .5 .758 .1 k
.4948 .06134 m
.49994 .08204 L
.5052 .06134 L
.5 .01184 L
F
.483 .5 .775 .1 k
.49994 .08204 m
.51516 .12112 L
.52058 .10868 L
.5052 .06134 L
F
.483 .5 .792 .1 k
.51516 .12112 m
.53977 .16121 L
.54547 .15179 L
.52058 .10868 L
F
.483 .5 .808 .1 k
.53977 .16121 m
.57271 .19703 L
.57878 .18878 L
.54547 .15179 L
F
.483 .5 .825 .1 k
.57271 .19703 m
.61254 .22604 L
.61905 .21804 L
.57878 .18878 L
F
.483 .5 .842 .1 k
.61254 .22604 m
.65752 .24668 L
.66452 .23828 L
.61905 .21804 L
F
.483 .5 .858 .1 k
.65752 .24668 m
.70568 .258 L
.71321 .24863 L
.66452 .23828 L
F
.483 .5 .875 .1 k
.70568 .258 m
.75491 .25955 L
.76298 .24863 L
.71321 .24863 L
F
.483 .5 .892 .1 k
.75491 .25955 m
.80306 .25147 L
.81167 .23828 L
.76298 .24863 L
F
.483 .5 .908 .1 k
.80306 .25147 m
.84804 .23445 L
.85714 .21804 L
.81167 .23828 L
F
.483 .5 .925 .1 k
.84804 .23445 m
.88787 .20986 L
.89741 .18878 L
.85714 .21804 L
F
.483 .5 .942 .1 k
.88787 .20986 m
.92081 .17995 L
.93072 .15179 L
.89741 .18878 L
F
.483 .5 .958 .1 k
.92081 .17995 m
.94543 .14844 L
.95561 .10868 L
.93072 .15179 L
F
.483 .5 .975 .1 k
.94543 .14844 m
.96064 .12193 L
.97099 .06134 L
.95561 .10868 L
F
.483 .5 .992 .1 k
.96064 .12193 m
.96578 .11085 L
.97619 .01184 L
.97099 .06134 L
F
.517 .5 .008 .1 k
.97619 .01184 m
.97099 .06134 L
.96064 .12193 L
.96578 .11085 L
F
.517 .5 .025 .1 k
.97099 .06134 m
.95561 .10868 L
.94543 .14844 L
.96064 .12193 L
F
.517 .5 .042 .1 k
.95561 .10868 m
.93072 .15179 L
.92081 .17995 L
.94543 .14844 L
F
.517 .5 .058 .1 k
.93072 .15179 m
.89741 .18878 L
.88787 .20986 L
.92081 .17995 L
F
.517 .5 .075 .1 k
.89741 .18878 m
.85714 .21804 L
.84804 .23445 L
.88787 .20986 L
F
.517 .5 .092 .1 k
.85714 .21804 m
.81167 .23828 L
.80306 .25147 L
.84804 .23445 L
F
.517 .5 .108 .1 k
.81167 .23828 m
.76298 .24863 L
.75491 .25955 L
.80306 .25147 L
F
.517 .5 .125 .1 k
.76298 .24863 m
.71321 .24863 L
.70568 .258 L
.75491 .25955 L
F
.517 .5 .142 .1 k
.71321 .24863 m
.66452 .23828 L
.65752 .24668 L
.70568 .258 L
F
.517 .5 .158 .1 k
.66452 .23828 m
.61905 .21804 L
.61254 .22604 L
.65752 .24668 L
F
.517 .5 .175 .1 k
.61905 .21804 m
.57878 .18878 L
.57271 .19703 L
.61254 .22604 L
F
.517 .5 .192 .1 k
.57878 .18878 m
.54547 .15179 L
.53977 .16121 L
.57271 .19703 L
F
.517 .5 .208 .1 k
.54547 .15179 m
.52058 .10868 L
.51516 .12112 L
.53977 .16121 L
F
.517 .5 .225 .1 k
.52058 .10868 m
.5052 .06134 L
.49994 .08204 L
.51516 .12112 L
F
.517 .5 .242 .1 k
.5052 .06134 m
.5 .01184 L
.4948 .06134 L
.49994 .08204 L
F
.517 .5 .258 .1 k
.5 .01184 m
.5052 .06134 L
.49994 .08204 L
.4948 .06134 L
F
.517 .5 .275 .1 k
.5052 .06134 m
.52058 .10868 L
.51516 .12112 L
.49994 .08204 L
F
.517 .5 .292 .1 k
.52058 .10868 m
.54547 .15179 L
.53977 .16121 L
.51516 .12112 L
F
.517 .5 .308 .1 k
.54547 .15179 m
.57878 .18878 L
.57271 .19703 L
.53977 .16121 L
F
.517 .5 .325 .1 k
.57878 .18878 m
.61905 .21804 L
.61254 .22604 L
.57271 .19703 L
F
.517 .5 .342 .1 k
.61905 .21804 m
.66452 .23828 L
.65752 .24668 L
.61254 .22604 L
F
.517 .5 .358 .1 k
.66452 .23828 m
.71321 .24863 L
.70568 .258 L
.65752 .24668 L
F
.517 .5 .375 .1 k
.71321 .24863 m
.76298 .24863 L
.75491 .25955 L
.70568 .258 L
F
.517 .5 .392 .1 k
.76298 .24863 m
.81167 .23828 L
.80306 .25147 L
.75491 .25955 L
F
.517 .5 .408 .1 k
.81167 .23828 m
.85714 .21804 L
.84804 .23445 L
.80306 .25147 L
F
.517 .5 .425 .1 k
.85714 .21804 m
.89741 .18878 L
.88787 .20986 L
.84804 .23445 L
F
.517 .5 .442 .1 k
.89741 .18878 m
.93072 .15179 L
.92081 .17995 L
.88787 .20986 L
F
.517 .5 .458 .1 k
.93072 .15179 m
.95561 .10868 L
.94543 .14844 L
.92081 .17995 L
F
.517 .5 .475 .1 k
.95561 .10868 m
.97099 .06134 L
.96064 .12193 L
.94543 .14844 L
F
.517 .5 .492 .1 k
.97099 .06134 m
.97619 .01184 L
.96578 .11085 L
.96064 .12193 L
F
.517 .5 .508 .1 k
.97619 .01184 m
.97099 .06134 L
.96064 .12193 L
.96578 .11085 L
F
.517 .5 .525 .1 k
.97099 .06134 m
.95561 .10868 L
.94543 .14844 L
.96064 .12193 L
F
.517 .5 .542 .1 k
.95561 .10868 m
.93072 .15179 L
.92081 .17995 L
.94543 .14844 L
F
.517 .5 .558 .1 k
.93072 .15179 m
.89741 .18878 L
.88787 .20986 L
.92081 .17995 L
F
.517 .5 .575 .1 k
.89741 .18878 m
.85714 .21804 L
.84804 .23445 L
.88787 .20986 L
F
.517 .5 .592 .1 k
.85714 .21804 m
.81167 .23828 L
.80306 .25147 L
.84804 .23445 L
F
.517 .5 .608 .1 k
.81167 .23828 m
.76298 .24863 L
.75491 .25955 L
.80306 .25147 L
F
.517 .5 .625 .1 k
.76298 .24863 m
.71321 .24863 L
.70568 .258 L
.75491 .25955 L
F
.517 .5 .642 .1 k
.71321 .24863 m
.66452 .23828 L
.65752 .24668 L
.70568 .258 L
F
.517 .5 .658 .1 k
.66452 .23828 m
.61905 .21804 L
.61254 .22604 L
.65752 .24668 L
F
.517 .5 .675 .1 k
.61905 .21804 m
.57878 .18878 L
.57271 .19703 L
.61254 .22604 L
F
.517 .5 .692 .1 k
.57878 .18878 m
.54547 .15179 L
.53977 .16121 L
.57271 .19703 L
F
.517 .5 .708 .1 k
.54547 .15179 m
.52058 .10868 L
.51516 .12112 L
.53977 .16121 L
F
.517 .5 .725 .1 k
.52058 .10868 m
.5052 .06134 L
.49994 .08204 L
.51516 .12112 L
F
.517 .5 .742 .1 k
.5052 .06134 m
.5 .01184 L
.4948 .06134 L
.49994 .08204 L
F
.517 .5 .758 .1 k
.5 .01184 m
.5052 .06134 L
.49994 .08204 L
.4948 .06134 L
F
.517 .5 .775 .1 k
.5052 .06134 m
.52058 .10868 L
.51516 .12112 L
.49994 .08204 L
F
.517 .5 .792 .1 k
.52058 .10868 m
.54547 .15179 L
.53977 .16121 L
.51516 .12112 L
F
.517 .5 .808 .1 k
.54547 .15179 m
.57878 .18878 L
.57271 .19703 L
.53977 .16121 L
F
.517 .5 .825 .1 k
.57878 .18878 m
.61905 .21804 L
.61254 .22604 L
.57271 .19703 L
F
.517 .5 .842 .1 k
.61905 .21804 m
.66452 .23828 L
.65752 .24668 L
.61254 .22604 L
F
.517 .5 .858 .1 k
.66452 .23828 m
.71321 .24863 L
.70568 .258 L
.65752 .24668 L
F
.517 .5 .875 .1 k
.71321 .24863 m
.76298 .24863 L
.75491 .25955 L
.70568 .258 L
F
.517 .5 .892 .1 k
.76298 .24863 m
.81167 .23828 L
.80306 .25147 L
.75491 .25955 L
F
.517 .5 .908 .1 k
.81167 .23828 m
.85714 .21804 L
.84804 .23445 L
.80306 .25147 L
F
.517 .5 .925 .1 k
.85714 .21804 m
.89741 .18878 L
.88787 .20986 L
.84804 .23445 L
F
.517 .5 .942 .1 k
.89741 .18878 m
.93072 .15179 L
.92081 .17995 L
.88787 .20986 L
F
.517 .5 .958 .1 k
.93072 .15179 m
.95561 .10868 L
.94543 .14844 L
.92081 .17995 L
F
.517 .5 .975 .1 k
.95561 .10868 m
.97099 .06134 L
.96064 .12193 L
.94543 .14844 L
F
.517 .5 .992 .1 k
.97099 .06134 m
.97619 .01184 L
.96578 .11085 L
.96064 .12193 L
F
.55 .5 .008 .1 k
.96578 .11085 m
.96064 .12193 L
.93004 .21046 L
.93502 .20552 L
F
.55 .5 .025 .1 k
.96064 .12193 m
.94543 .14844 L
.91533 .22369 L
.93004 .21046 L
F
.55 .5 .042 .1 k
.94543 .14844 m
.92081 .17995 L
.89152 .24153 L
.91533 .22369 L
F
.55 .5 .058 .1 k
.92081 .17995 m
.88787 .20986 L
.85965 .25987 L
.89152 .24153 L
F
.55 .5 .075 .1 k
.88787 .20986 m
.84804 .23445 L
.82112 .27528 L
.85965 .25987 L
F
.55 .5 .092 .1 k
.84804 .23445 m
.80306 .25147 L
.77761 .28521 L
.82112 .27528 L
F
.55 .5 .108 .1 k
.80306 .25147 m
.75491 .25955 L
.73103 .28796 L
.77761 .28521 L
F
.55 .5 .125 .1 k
.75491 .25955 m
.70568 .258 L
.68341 .28258 L
.73103 .28796 L
F
.55 .5 .142 .1 k
.70568 .258 m
.65752 .24668 L
.63682 .26882 L
.68341 .28258 L
F
.55 .5 .158 .1 k
.65752 .24668 m
.61254 .22604 L
.59332 .24707 L
.63682 .26882 L
F
.55 .5 .175 .1 k
.61254 .22604 m
.57271 .19703 L
.55479 .21846 L
.59332 .24707 L
F
.55 .5 .192 .1 k
.57271 .19703 m
.53977 .16121 L
.52292 .18503 L
.55479 .21846 L
F
.55 .5 .208 .1 k
.53977 .16121 m
.51516 .12112 L
.49911 .15033 L
.52292 .18503 L
F
.55 .5 .225 .1 k
.51516 .12112 m
.49994 .08204 L
.48439 .12106 L
.49911 .15033 L
F
.55 .5 .242 .1 k
.49994 .08204 m
.4948 .06134 L
.47942 .10868 L
.48439 .12106 L
F
.55 .5 .258 .1 k
.4948 .06134 m
.49994 .08204 L
.48439 .12106 L
.47942 .10868 L
F
.55 .5 .275 .1 k
.49994 .08204 m
.51516 .12112 L
.49911 .15033 L
.48439 .12106 L
F
.55 .5 .292 .1 k
.51516 .12112 m
.53977 .16121 L
.52292 .18503 L
.49911 .15033 L
F
.55 .5 .308 .1 k
.53977 .16121 m
.57271 .19703 L
.55479 .21846 L
.52292 .18503 L
F
.55 .5 .325 .1 k
.57271 .19703 m
.61254 .22604 L
.59332 .24707 L
.55479 .21846 L
F
.55 .5 .342 .1 k
.61254 .22604 m
.65752 .24668 L
.63682 .26882 L
.59332 .24707 L
F
.55 .5 .358 .1 k
.65752 .24668 m
.70568 .258 L
.68341 .28258 L
.63682 .26882 L
F
.55 .5 .375 .1 k
.70568 .258 m
.75491 .25955 L
.73103 .28796 L
.68341 .28258 L
F
.55 .5 .392 .1 k
.75491 .25955 m
.80306 .25147 L
.77761 .28521 L
.73103 .28796 L
F
.55 .5 .408 .1 k
.80306 .25147 m
.84804 .23445 L
.82112 .27528 L
.77761 .28521 L
F
.55 .5 .425 .1 k
.84804 .23445 m
.88787 .20986 L
.85965 .25987 L
.82112 .27528 L
F
.55 .5 .442 .1 k
.88787 .20986 m
.92081 .17995 L
.89152 .24153 L
.85965 .25987 L
F
.55 .5 .458 .1 k
.92081 .17995 m
.94543 .14844 L
.91533 .22369 L
.89152 .24153 L
F
.55 .5 .475 .1 k
.94543 .14844 m
.96064 .12193 L
.93004 .21046 L
.91533 .22369 L
F
.55 .5 .492 .1 k
.96064 .12193 m
.96578 .11085 L
.93502 .20552 L
.93004 .21046 L
F
.55 .5 .508 .1 k
.96578 .11085 m
.96064 .12193 L
.93004 .21046 L
.93502 .20552 L
F
.55 .5 .525 .1 k
.96064 .12193 m
.94543 .14844 L
.91533 .22369 L
.93004 .21046 L
F
.55 .5 .542 .1 k
.94543 .14844 m
.92081 .17995 L
.89152 .24153 L
.91533 .22369 L
F
.55 .5 .558 .1 k
.92081 .17995 m
.88787 .20986 L
.85965 .25987 L
.89152 .24153 L
F
.55 .5 .575 .1 k
.88787 .20986 m
.84804 .23445 L
.82112 .27528 L
.85965 .25987 L
F
.55 .5 .592 .1 k
.84804 .23445 m
.80306 .25147 L
.77761 .28521 L
.82112 .27528 L
F
.55 .5 .608 .1 k
.80306 .25147 m
.75491 .25955 L
.73103 .28796 L
.77761 .28521 L
F
.55 .5 .625 .1 k
.75491 .25955 m
.70568 .258 L
.68341 .28258 L
.73103 .28796 L
F
.55 .5 .642 .1 k
.70568 .258 m
.65752 .24668 L
.63682 .26882 L
.68341 .28258 L
F
.55 .5 .658 .1 k
.65752 .24668 m
.61254 .22604 L
.59332 .24707 L
.63682 .26882 L
F
.55 .5 .675 .1 k
.61254 .22604 m
.57271 .19703 L
.55479 .21846 L
.59332 .24707 L
F
.55 .5 .692 .1 k
.57271 .19703 m
.53977 .16121 L
.52292 .18503 L
.55479 .21846 L
F
.55 .5 .708 .1 k
.53977 .16121 m
.51516 .12112 L
.49911 .15033 L
.52292 .18503 L
F
.55 .5 .725 .1 k
.51516 .12112 m
.49994 .08204 L
.48439 .12106 L
.49911 .15033 L
F
.55 .5 .742 .1 k
.49994 .08204 m
.4948 .06134 L
.47942 .10868 L
.48439 .12106 L
F
.55 .5 .758 .1 k
.4948 .06134 m
.49994 .08204 L
.48439 .12106 L
.47942 .10868 L
F
.55 .5 .775 .1 k
.49994 .08204 m
.51516 .12112 L
.49911 .15033 L
.48439 .12106 L
F
.55 .5 .792 .1 k
.51516 .12112 m
.53977 .16121 L
.52292 .18503 L
.49911 .15033 L
F
.55 .5 .808 .1 k
.53977 .16121 m
.57271 .19703 L
.55479 .21846 L
.52292 .18503 L
F
.55 .5 .825 .1 k
.57271 .19703 m
.61254 .22604 L
.59332 .24707 L
.55479 .21846 L
F
.55 .5 .842 .1 k
.61254 .22604 m
.65752 .24668 L
.63682 .26882 L
.59332 .24707 L
F
.55 .5 .858 .1 k
.65752 .24668 m
.70568 .258 L
.68341 .28258 L
.63682 .26882 L
F
.55 .5 .875 .1 k
.70568 .258 m
.75491 .25955 L
.73103 .28796 L
.68341 .28258 L
F
.55 .5 .892 .1 k
.75491 .25955 m
.80306 .25147 L
.77761 .28521 L
.73103 .28796 L
F
.55 .5 .908 .1 k
.80306 .25147 m
.84804 .23445 L
.82112 .27528 L
.77761 .28521 L
F
.55 .5 .925 .1 k
.84804 .23445 m
.88787 .20986 L
.85965 .25987 L
.82112 .27528 L
F
.55 .5 .942 .1 k
.88787 .20986 m
.92081 .17995 L
.89152 .24153 L
.85965 .25987 L
F
.55 .5 .958 .1 k
.92081 .17995 m
.94543 .14844 L
.91533 .22369 L
.89152 .24153 L
F
.55 .5 .975 .1 k
.94543 .14844 m
.96064 .12193 L
.93004 .21046 L
.91533 .22369 L
F
.55 .5 .992 .1 k
.96064 .12193 m
.96578 .11085 L
.93502 .20552 L
.93004 .21046 L
F
.583 .5 .008 .1 k
.93502 .20552 m
.93004 .21046 L
.88054 .29416 L
.88525 .29174 L
F
.583 .5 .025 .1 k
.93004 .21046 m
.91533 .22369 L
.86663 .30076 L
.88054 .29416 L
F
.583 .5 .042 .1 k
.91533 .22369 m
.89152 .24153 L
.84412 .30976 L
.86663 .30076 L
F
.583 .5 .058 .1 k
.89152 .24153 m
.85965 .25987 L
.81399 .31882 L
.84412 .30976 L
F
.583 .5 .075 .1 k
.85965 .25987 m
.82112 .27528 L
.77757 .32559 L
.81399 .31882 L
F
.583 .5 .092 .1 k
.82112 .27528 m
.77761 .28521 L
.73644 .32806 L
.77757 .32559 L
F
.583 .5 .108 .1 k
.77761 .28521 m
.73103 .28796 L
.6924 .32474 L
.73644 .32806 L
F
.583 .5 .125 .1 k
.73103 .28796 m
.68341 .28258 L
.64738 .31477 L
.6924 .32474 L
F
.583 .5 .142 .1 k
.68341 .28258 m
.63682 .26882 L
.60334 .29791 L
.64738 .31477 L
F
.583 .5 .158 .1 k
.63682 .26882 m
.59332 .24707 L
.56221 .27463 L
.60334 .29791 L
F
.583 .5 .175 .1 k
.59332 .24707 m
.55479 .21846 L
.52578 .24619 L
.56221 .27463 L
F
.583 .5 .192 .1 k
.55479 .21846 m
.52292 .18503 L
.49566 .21487 L
.52578 .24619 L
F
.583 .5 .208 .1 k
.52292 .18503 m
.49911 .15033 L
.47315 .18446 L
.49566 .21487 L
F
.583 .5 .225 .1 k
.49911 .15033 m
.48439 .12106 L
.45923 .16095 L
.47315 .18446 L
F
.583 .5 .242 .1 k
.48439 .12106 m
.47942 .10868 L
.45453 .15179 L
.45923 .16095 L
F
.583 .5 .258 .1 k
.47942 .10868 m
.48439 .12106 L
.45923 .16095 L
.45453 .15179 L
F
.583 .5 .275 .1 k
.48439 .12106 m
.49911 .15033 L
.47315 .18446 L
.45923 .16095 L
F
.583 .5 .292 .1 k
.49911 .15033 m
.52292 .18503 L
.49566 .21487 L
.47315 .18446 L
F
.583 .5 .308 .1 k
.52292 .18503 m
.55479 .21846 L
.52578 .24619 L
.49566 .21487 L
F
.583 .5 .325 .1 k
.55479 .21846 m
.59332 .24707 L
.56221 .27463 L
.52578 .24619 L
F
.583 .5 .342 .1 k
.59332 .24707 m
.63682 .26882 L
.60334 .29791 L
.56221 .27463 L
F
.583 .5 .358 .1 k
.63682 .26882 m
.68341 .28258 L
.64738 .31477 L
.60334 .29791 L
F
.583 .5 .375 .1 k
.68341 .28258 m
.73103 .28796 L
.6924 .32474 L
.64738 .31477 L
F
.583 .5 .392 .1 k
.73103 .28796 m
.77761 .28521 L
.73644 .32806 L
.6924 .32474 L
F
.583 .5 .408 .1 k
.77761 .28521 m
.82112 .27528 L
.77757 .32559 L
.73644 .32806 L
F
.583 .5 .425 .1 k
.82112 .27528 m
.85965 .25987 L
.81399 .31882 L
.77757 .32559 L
F
.583 .5 .442 .1 k
.85965 .25987 m
.89152 .24153 L
.84412 .30976 L
.81399 .31882 L
F
.583 .5 .458 .1 k
.89152 .24153 m
.91533 .22369 L
.86663 .30076 L
.84412 .30976 L
F
.583 .5 .475 .1 k
.91533 .22369 m
.93004 .21046 L
.88054 .29416 L
.86663 .30076 L
F
.583 .5 .492 .1 k
.93004 .21046 m
.93502 .20552 L
.88525 .29174 L
.88054 .29416 L
F
.583 .5 .508 .1 k
.93502 .20552 m
.93004 .21046 L
.88054 .29416 L
.88525 .29174 L
F
.583 .5 .525 .1 k
.93004 .21046 m
.91533 .22369 L
.86663 .30076 L
.88054 .29416 L
F
.583 .5 .542 .1 k
.91533 .22369 m
.89152 .24153 L
.84412 .30976 L
.86663 .30076 L
F
.583 .5 .558 .1 k
.89152 .24153 m
.85965 .25987 L
.81399 .31882 L
.84412 .30976 L
F
.583 .5 .575 .1 k
.85965 .25987 m
.82112 .27528 L
.77757 .32559 L
.81399 .31882 L
F
.583 .5 .592 .1 k
.82112 .27528 m
.77761 .28521 L
.73644 .32806 L
.77757 .32559 L
F
.583 .5 .608 .1 k
.77761 .28521 m
.73103 .28796 L
.6924 .32474 L
.73644 .32806 L
F
.583 .5 .625 .1 k
.73103 .28796 m
.68341 .28258 L
.64738 .31477 L
.6924 .32474 L
F
.583 .5 .642 .1 k
.68341 .28258 m
.63682 .26882 L
.60334 .29791 L
.64738 .31477 L
F
.583 .5 .658 .1 k
.63682 .26882 m
.59332 .24707 L
.56221 .27463 L
.60334 .29791 L
F
.583 .5 .675 .1 k
.59332 .24707 m
.55479 .21846 L
.52578 .24619 L
.56221 .27463 L
F
.583 .5 .692 .1 k
.55479 .21846 m
.52292 .18503 L
.49566 .21487 L
.52578 .24619 L
F
.583 .5 .708 .1 k
.52292 .18503 m
.49911 .15033 L
.47315 .18446 L
.49566 .21487 L
F
.583 .5 .725 .1 k
.49911 .15033 m
.48439 .12106 L
.45923 .16095 L
.47315 .18446 L
F
.583 .5 .742 .1 k
.48439 .12106 m
.47942 .10868 L
.45453 .15179 L
.45923 .16095 L
F
.583 .5 .758 .1 k
.47942 .10868 m
.48439 .12106 L
.45923 .16095 L
.45453 .15179 L
F
.583 .5 .775 .1 k
.48439 .12106 m
.49911 .15033 L
.47315 .18446 L
.45923 .16095 L
F
.583 .5 .792 .1 k
.49911 .15033 m
.52292 .18503 L
.49566 .21487 L
.47315 .18446 L
F
.583 .5 .808 .1 k
.52292 .18503 m
.55479 .21846 L
.52578 .24619 L
.49566 .21487 L
F
.583 .5 .825 .1 k
.55479 .21846 m
.59332 .24707 L
.56221 .27463 L
.52578 .24619 L
F
.583 .5 .842 .1 k
.59332 .24707 m
.63682 .26882 L
.60334 .29791 L
.56221 .27463 L
F
.583 .5 .858 .1 k
.63682 .26882 m
.68341 .28258 L
.64738 .31477 L
.60334 .29791 L
F
.583 .5 .875 .1 k
.68341 .28258 m
.73103 .28796 L
.6924 .32474 L
.64738 .31477 L
F
.583 .5 .892 .1 k
.73103 .28796 m
.77761 .28521 L
.73644 .32806 L
.6924 .32474 L
F
.583 .5 .908 .1 k
.77761 .28521 m
.82112 .27528 L
.77757 .32559 L
.73644 .32806 L
F
.583 .5 .925 .1 k
.82112 .27528 m
.85965 .25987 L
.81399 .31882 L
.77757 .32559 L
F
.583 .5 .942 .1 k
.85965 .25987 m
.89152 .24153 L
.84412 .30976 L
.81399 .31882 L
F
.583 .5 .958 .1 k
.89152 .24153 m
.91533 .22369 L
.86663 .30076 L
.84412 .30976 L
F
.583 .5 .975 .1 k
.91533 .22369 m
.93004 .21046 L
.88054 .29416 L
.86663 .30076 L
F
.583 .5 .992 .1 k
.93004 .21046 m
.93502 .20552 L
.88525 .29174 L
.88054 .29416 L
F
.617 .5 .008 .1 k
.88525 .29174 m
.88054 .29416 L
.81429 .36668 L
.81863 .36572 L
F
.617 .5 .025 .1 k
.88054 .29416 m
.86663 .30076 L
.80145 .36919 L
.81429 .36668 L
F
.617 .5 .042 .1 k
.86663 .30076 m
.84412 .30976 L
.78068 .37226 L
.80145 .36919 L
F
.617 .5 .058 .1 k
.84412 .30976 m
.81399 .31882 L
.75289 .37447 L
.78068 .37226 L
F
.617 .5 .075 .1 k
.81399 .31882 m
.77757 .32559 L
.71928 .37428 L
.75289 .37447 L
F
.617 .5 .092 .1 k
.77757 .32559 m
.73644 .32806 L
.68133 .3703 L
.71928 .37428 L
F
.617 .5 .108 .1 k
.73644 .32806 m
.6924 .32474 L
.6407 .36145 L
.68133 .3703 L
F
.617 .5 .125 .1 k
.6924 .32474 m
.64738 .31477 L
.59916 .34712 L
.6407 .36145 L
F
.617 .5 .142 .1 k
.64738 .31477 m
.60334 .29791 L
.55852 .32723 L
.59916 .34712 L
F
.617 .5 .158 .1 k
.60334 .29791 m
.56221 .27463 L
.52057 .30236 L
.55852 .32723 L
F
.617 .5 .175 .1 k
.56221 .27463 m
.52578 .24619 L
.48697 .27385 L
.52057 .30236 L
F
.617 .5 .192 .1 k
.52578 .24619 m
.49566 .21487 L
.45917 .24404 L
.48697 .27385 L
F
.617 .5 .208 .1 k
.49566 .21487 m
.47315 .18446 L
.4384 .21653 L
.45917 .24404 L
F
.617 .5 .225 .1 k
.47315 .18446 m
.45923 .16095 L
.42556 .19634 L
.4384 .21653 L
F
.617 .5 .242 .1 k
.45923 .16095 m
.45453 .15179 L
.42122 .18878 L
.42556 .19634 L
F
.617 .5 .258 .1 k
.45453 .15179 m
.45923 .16095 L
.42556 .19634 L
.42122 .18878 L
F
.617 .5 .275 .1 k
.45923 .16095 m
.47315 .18446 L
.4384 .21653 L
.42556 .19634 L
F
.617 .5 .292 .1 k
.47315 .18446 m
.49566 .21487 L
.45917 .24404 L
.4384 .21653 L
F
.617 .5 .308 .1 k
.49566 .21487 m
.52578 .24619 L
.48697 .27385 L
.45917 .24404 L
F
.617 .5 .325 .1 k
.52578 .24619 m
.56221 .27463 L
.52057 .30236 L
.48697 .27385 L
F
.617 .5 .342 .1 k
.56221 .27463 m
.60334 .29791 L
.55852 .32723 L
.52057 .30236 L
F
.617 .5 .358 .1 k
.60334 .29791 m
.64738 .31477 L
.59916 .34712 L
.55852 .32723 L
F
.617 .5 .375 .1 k
.64738 .31477 m
.6924 .32474 L
.6407 .36145 L
.59916 .34712 L
F
.617 .5 .392 .1 k
.6924 .32474 m
.73644 .32806 L
.68133 .3703 L
.6407 .36145 L
F
.617 .5 .408 .1 k
.73644 .32806 m
.77757 .32559 L
.71928 .37428 L
.68133 .3703 L
F
.617 .5 .425 .1 k
.77757 .32559 m
.81399 .31882 L
.75289 .37447 L
.71928 .37428 L
F
.617 .5 .442 .1 k
.81399 .31882 m
.84412 .30976 L
.78068 .37226 L
.75289 .37447 L
F
.617 .5 .458 .1 k
.84412 .30976 m
.86663 .30076 L
.80145 .36919 L
.78068 .37226 L
F
.617 .5 .475 .1 k
.86663 .30076 m
.88054 .29416 L
.81429 .36668 L
.80145 .36919 L
F
.617 .5 .492 .1 k
.88054 .29416 m
.88525 .29174 L
.81863 .36572 L
.81429 .36668 L
F
.617 .5 .508 .1 k
.88525 .29174 m
.88054 .29416 L
.81429 .36668 L
.81863 .36572 L
F
.617 .5 .525 .1 k
.88054 .29416 m
.86663 .30076 L
.80145 .36919 L
.81429 .36668 L
F
.617 .5 .542 .1 k
.86663 .30076 m
.84412 .30976 L
.78068 .37226 L
.80145 .36919 L
F
.617 .5 .558 .1 k
.84412 .30976 m
.81399 .31882 L
.75289 .37447 L
.78068 .37226 L
F
.617 .5 .575 .1 k
.81399 .31882 m
.77757 .32559 L
.71928 .37428 L
.75289 .37447 L
F
.617 .5 .592 .1 k
.77757 .32559 m
.73644 .32806 L
.68133 .3703 L
.71928 .37428 L
F
.617 .5 .608 .1 k
.73644 .32806 m
.6924 .32474 L
.6407 .36145 L
.68133 .3703 L
F
.617 .5 .625 .1 k
.6924 .32474 m
.64738 .31477 L
.59916 .34712 L
.6407 .36145 L
F
.617 .5 .642 .1 k
.64738 .31477 m
.60334 .29791 L
.55852 .32723 L
.59916 .34712 L
F
.617 .5 .658 .1 k
.60334 .29791 m
.56221 .27463 L
.52057 .30236 L
.55852 .32723 L
F
.617 .5 .675 .1 k
.56221 .27463 m
.52578 .24619 L
.48697 .27385 L
.52057 .30236 L
F
.617 .5 .692 .1 k
.52578 .24619 m
.49566 .21487 L
.45917 .24404 L
.48697 .27385 L
F
.617 .5 .708 .1 k
.49566 .21487 m
.47315 .18446 L
.4384 .21653 L
.45917 .24404 L
F
.617 .5 .725 .1 k
.47315 .18446 m
.45923 .16095 L
.42556 .19634 L
.4384 .21653 L
F
.617 .5 .742 .1 k
.45923 .16095 m
.45453 .15179 L
.42122 .18878 L
.42556 .19634 L
F
.617 .5 .758 .1 k
.45453 .15179 m
.45923 .16095 L
.42556 .19634 L
.42122 .18878 L
F
.617 .5 .775 .1 k
.45923 .16095 m
.47315 .18446 L
.4384 .21653 L
.42556 .19634 L
F
.617 .5 .792 .1 k
.47315 .18446 m
.49566 .21487 L
.45917 .24404 L
.4384 .21653 L
F
.617 .5 .808 .1 k
.49566 .21487 m
.52578 .24619 L
.48697 .27385 L
.45917 .24404 L
F
.617 .5 .825 .1 k
.52578 .24619 m
.56221 .27463 L
.52057 .30236 L
.48697 .27385 L
F
.617 .5 .842 .1 k
.56221 .27463 m
.60334 .29791 L
.55852 .32723 L
.52057 .30236 L
F
.617 .5 .858 .1 k
.60334 .29791 m
.64738 .31477 L
.59916 .34712 L
.55852 .32723 L
F
.617 .5 .875 .1 k
.64738 .31477 m
.6924 .32474 L
.6407 .36145 L
.59916 .34712 L
F
.617 .5 .892 .1 k
.6924 .32474 m
.73644 .32806 L
.68133 .3703 L
.6407 .36145 L
F
.617 .5 .908 .1 k
.73644 .32806 m
.77757 .32559 L
.71928 .37428 L
.68133 .3703 L
F
.617 .5 .925 .1 k
.77757 .32559 m
.81399 .31882 L
.75289 .37447 L
.71928 .37428 L
F
.617 .5 .942 .1 k
.81399 .31882 m
.84412 .30976 L
.78068 .37226 L
.75289 .37447 L
F
.617 .5 .958 .1 k
.84412 .30976 m
.86663 .30076 L
.80145 .36919 L
.78068 .37226 L
F
.617 .5 .975 .1 k
.86663 .30076 m
.88054 .29416 L
.81429 .36668 L
.80145 .36919 L
F
.617 .5 .992 .1 k
.88054 .29416 m
.88525 .29174 L
.81863 .36572 L
.81429 .36668 L
F
.65 .5 .008 .1 k
.81863 .36572 m
.81429 .36668 L
.73419 .42421 L
.7381 .42423 L
F
.65 .5 .025 .1 k
.81429 .36668 m
.80145 .36919 L
.72266 .42394 L
.73419 .42421 L
F
.65 .5 .042 .1 k
.80145 .36919 m
.78068 .37226 L
.70399 .42282 L
.72266 .42394 L
F
.65 .5 .058 .1 k
.78068 .37226 m
.75289 .37447 L
.67901 .41998 L
.70399 .42282 L
F
.65 .5 .075 .1 k
.75289 .37447 m
.71928 .37428 L
.64881 .41445 L
.67901 .41998 L
F
.65 .5 .092 .1 k
.71928 .37428 m
.68133 .3703 L
.61471 .40534 L
.64881 .41445 L
F
.65 .5 .108 .1 k
.68133 .3703 m
.6407 .36145 L
.57819 .39197 L
.61471 .40534 L
F
.65 .5 .125 .1 k
.6407 .36145 m
.59916 .34712 L
.54086 .37401 L
.57819 .39197 L
F
.65 .5 .142 .1 k
.59916 .34712 m
.55852 .32723 L
.50434 .35159 L
.54086 .37401 L
F
.65 .5 .158 .1 k
.55852 .32723 m
.52057 .30236 L
.47024 .3254 L
.50434 .35159 L
F
.65 .5 .175 .1 k
.52057 .30236 m
.48697 .27385 L
.44004 .29685 L
.47024 .3254 L
F
.65 .5 .192 .1 k
.48697 .27385 m
.45917 .24404 L
.41506 .26819 L
.44004 .29685 L
F
.65 .5 .208 .1 k
.45917 .24404 m
.4384 .21653 L
.39639 .24272 L
.41506 .26819 L
F
.65 .5 .225 .1 k
.4384 .21653 m
.42556 .19634 L
.38485 .22465 L
.39639 .24272 L
F
.65 .5 .242 .1 k
.42556 .19634 m
.42122 .18878 L
.38095 .21804 L
.38485 .22465 L
F
.65 .5 .258 .1 k
.42122 .18878 m
.42556 .19634 L
.38485 .22465 L
.38095 .21804 L
F
.65 .5 .275 .1 k
.42556 .19634 m
.4384 .21653 L
.39639 .24272 L
.38485 .22465 L
F
.65 .5 .292 .1 k
.4384 .21653 m
.45917 .24404 L
.41506 .26819 L
.39639 .24272 L
F
.65 .5 .308 .1 k
.45917 .24404 m
.48697 .27385 L
.44004 .29685 L
.41506 .26819 L
F
.65 .5 .325 .1 k
.48697 .27385 m
.52057 .30236 L
.47024 .3254 L
.44004 .29685 L
F
.65 .5 .342 .1 k
.52057 .30236 m
.55852 .32723 L
.50434 .35159 L
.47024 .3254 L
F
.65 .5 .358 .1 k
.55852 .32723 m
.59916 .34712 L
.54086 .37401 L
.50434 .35159 L
F
.65 .5 .375 .1 k
.59916 .34712 m
.6407 .36145 L
.57819 .39197 L
.54086 .37401 L
F
.65 .5 .392 .1 k
.6407 .36145 m
.68133 .3703 L
.61471 .40534 L
.57819 .39197 L
F
.65 .5 .408 .1 k
.68133 .3703 m
.71928 .37428 L
.64881 .41445 L
.61471 .40534 L
F
.65 .5 .425 .1 k
.71928 .37428 m
.75289 .37447 L
.67901 .41998 L
.64881 .41445 L
F
.65 .5 .442 .1 k
.75289 .37447 m
.78068 .37226 L
.70399 .42282 L
.67901 .41998 L
F
.65 .5 .458 .1 k
.78068 .37226 m
.80145 .36919 L
.72266 .42394 L
.70399 .42282 L
F
.65 .5 .475 .1 k
.80145 .36919 m
.81429 .36668 L
.73419 .42421 L
.72266 .42394 L
F
.65 .5 .492 .1 k
.81429 .36668 m
.81863 .36572 L
.7381 .42423 L
.73419 .42421 L
F
.65 .5 .508 .1 k
.81863 .36572 m
.81429 .36668 L
.73419 .42421 L
.7381 .42423 L
F
.65 .5 .525 .1 k
.81429 .36668 m
.80145 .36919 L
.72266 .42394 L
.73419 .42421 L
F
.65 .5 .542 .1 k
.80145 .36919 m
.78068 .37226 L
.70399 .42282 L
.72266 .42394 L
F
.65 .5 .558 .1 k
.78068 .37226 m
.75289 .37447 L
.67901 .41998 L
.70399 .42282 L
F
.65 .5 .575 .1 k
.75289 .37447 m
.71928 .37428 L
.64881 .41445 L
.67901 .41998 L
F
.65 .5 .592 .1 k
.71928 .37428 m
.68133 .3703 L
.61471 .40534 L
.64881 .41445 L
F
.65 .5 .608 .1 k
.68133 .3703 m
.6407 .36145 L
.57819 .39197 L
.61471 .40534 L
F
.65 .5 .625 .1 k
.6407 .36145 m
.59916 .34712 L
.54086 .37401 L
.57819 .39197 L
F
.65 .5 .642 .1 k
.59916 .34712 m
.55852 .32723 L
.50434 .35159 L
.54086 .37401 L
F
.65 .5 .658 .1 k
.55852 .32723 m
.52057 .30236 L
.47024 .3254 L
.50434 .35159 L
F
.65 .5 .675 .1 k
.52057 .30236 m
.48697 .27385 L
.44004 .29685 L
.47024 .3254 L
F
.65 .5 .692 .1 k
.48697 .27385 m
.45917 .24404 L
.41506 .26819 L
.44004 .29685 L
F
.65 .5 .708 .1 k
.45917 .24404 m
.4384 .21653 L
.39639 .24272 L
.41506 .26819 L
F
.65 .5 .725 .1 k
.4384 .21653 m
.42556 .19634 L
.38485 .22465 L
.39639 .24272 L
F
.65 .5 .742 .1 k
.42556 .19634 m
.42122 .18878 L
.38095 .21804 L
.38485 .22465 L
F
.65 .5 .758 .1 k
.42122 .18878 m
.42556 .19634 L
.38485 .22465 L
.38095 .21804 L
F
.65 .5 .775 .1 k
.42556 .19634 m
.4384 .21653 L
.39639 .24272 L
.38485 .22465 L
F
.65 .5 .792 .1 k
.4384 .21653 m
.45917 .24404 L
.41506 .26819 L
.39639 .24272 L
F
.65 .5 .808 .1 k
.45917 .24404 m
.48697 .27385 L
.44004 .29685 L
.41506 .26819 L
F
.65 .5 .825 .1 k
.48697 .27385 m
.52057 .30236 L
.47024 .3254 L
.44004 .29685 L
F
.65 .5 .842 .1 k
.52057 .30236 m
.55852 .32723 L
.50434 .35159 L
.47024 .3254 L
F
.65 .5 .858 .1 k
.55852 .32723 m
.59916 .34712 L
.54086 .37401 L
.50434 .35159 L
F
.65 .5 .875 .1 k
.59916 .34712 m
.6407 .36145 L
.57819 .39197 L
.54086 .37401 L
F
.65 .5 .892 .1 k
.6407 .36145 m
.68133 .3703 L
.61471 .40534 L
.57819 .39197 L
F
.65 .5 .908 .1 k
.68133 .3703 m
.71928 .37428 L
.64881 .41445 L
.61471 .40534 L
F
.65 .5 .925 .1 k
.71928 .37428 m
.75289 .37447 L
.67901 .41998 L
.64881 .41445 L
F
.65 .5 .942 .1 k
.75289 .37447 m
.78068 .37226 L
.70399 .42282 L
.67901 .41998 L
F
.65 .5 .958 .1 k
.78068 .37226 m
.80145 .36919 L
.72266 .42394 L
.70399 .42282 L
F
.65 .5 .975 .1 k
.80145 .36919 m
.81429 .36668 L
.73419 .42421 L
.72266 .42394 L
F
.65 .5 .992 .1 k
.81429 .36668 m
.81863 .36572 L
.7381 .42423 L
.73419 .42421 L
F
.683 .5 .008 .1 k
.7381 .42423 m
.73419 .42421 L
.64375 .46403 L
.64715 .46472 L
F
.683 .5 .025 .1 k
.73419 .42421 m
.72266 .42394 L
.63368 .46181 L
.64375 .46403 L
F
.683 .5 .042 .1 k
.72266 .42394 m
.70399 .42282 L
.61739 .45771 L
.63368 .46181 L
F
.683 .5 .058 .1 k
.70399 .42282 m
.67901 .41998 L
.59559 .45123 L
.61739 .45771 L
F
.683 .5 .075 .1 k
.67901 .41998 m
.64881 .41445 L
.56923 .44179 L
.59559 .45123 L
F
.683 .5 .092 .1 k
.64881 .41445 m
.61471 .40534 L
.53947 .42888 L
.56923 .44179 L
F
.683 .5 .108 .1 k
.61471 .40534 m
.57819 .39197 L
.5076 .41215 L
.53947 .42888 L
F
.683 .5 .125 .1 k
.57819 .39197 m
.54086 .37401 L
.47503 .39154 L
.5076 .41215 L
F
.683 .5 .142 .1 k
.54086 .37401 m
.50434 .35159 L
.44316 .36735 L
.47503 .39154 L
F
.683 .5 .158 .1 k
.50434 .35159 m
.47024 .3254 L
.4134 .34039 L
.44316 .36735 L
F
.683 .5 .175 .1 k
.47024 .3254 m
.44004 .29685 L
.38704 .31207 L
.4134 .34039 L
F
.683 .5 .192 .1 k
.44004 .29685 m
.41506 .26819 L
.36524 .28452 L
.38704 .31207 L
F
.683 .5 .208 .1 k
.41506 .26819 m
.39639 .24272 L
.34895 .26072 L
.36524 .28452 L
F
.683 .5 .225 .1 k
.39639 .24272 m
.38485 .22465 L
.33889 .24423 L
.34895 .26072 L
F
.683 .5 .242 .1 k
.38485 .22465 m
.38095 .21804 L
.33548 .23828 L
.33889 .24423 L
F
.683 .5 .258 .1 k
.38095 .21804 m
.38485 .22465 L
.33889 .24423 L
.33548 .23828 L
F
.683 .5 .275 .1 k
.38485 .22465 m
.39639 .24272 L
.34895 .26072 L
.33889 .24423 L
F
.683 .5 .292 .1 k
.39639 .24272 m
.41506 .26819 L
.36524 .28452 L
.34895 .26072 L
F
.683 .5 .308 .1 k
.41506 .26819 m
.44004 .29685 L
.38704 .31207 L
.36524 .28452 L
F
.683 .5 .325 .1 k
.44004 .29685 m
.47024 .3254 L
.4134 .34039 L
.38704 .31207 L
F
.683 .5 .342 .1 k
.47024 .3254 m
.50434 .35159 L
.44316 .36735 L
.4134 .34039 L
F
.683 .5 .358 .1 k
.50434 .35159 m
.54086 .37401 L
.47503 .39154 L
.44316 .36735 L
F
.683 .5 .375 .1 k
.54086 .37401 m
.57819 .39197 L
.5076 .41215 L
.47503 .39154 L
F
.683 .5 .392 .1 k
.57819 .39197 m
.61471 .40534 L
.53947 .42888 L
.5076 .41215 L
F
.683 .5 .408 .1 k
.61471 .40534 m
.64881 .41445 L
.56923 .44179 L
.53947 .42888 L
F
.683 .5 .425 .1 k
.64881 .41445 m
.67901 .41998 L
.59559 .45123 L
.56923 .44179 L
F
.683 .5 .442 .1 k
.67901 .41998 m
.70399 .42282 L
.61739 .45771 L
.59559 .45123 L
F
.683 .5 .458 .1 k
.70399 .42282 m
.72266 .42394 L
.63368 .46181 L
.61739 .45771 L
F
.683 .5 .475 .1 k
.72266 .42394 m
.73419 .42421 L
.64375 .46403 L
.63368 .46181 L
F
.683 .5 .492 .1 k
.73419 .42421 m
.7381 .42423 L
.64715 .46472 L
.64375 .46403 L
F
.683 .5 .508 .1 k
.7381 .42423 m
.73419 .42421 L
.64375 .46403 L
.64715 .46472 L
F
.683 .5 .525 .1 k
.73419 .42421 m
.72266 .42394 L
.63368 .46181 L
.64375 .46403 L
F
.683 .5 .542 .1 k
.72266 .42394 m
.70399 .42282 L
.61739 .45771 L
.63368 .46181 L
F
.683 .5 .558 .1 k
.70399 .42282 m
.67901 .41998 L
.59559 .45123 L
.61739 .45771 L
F
.683 .5 .575 .1 k
.67901 .41998 m
.64881 .41445 L
.56923 .44179 L
.59559 .45123 L
F
.683 .5 .592 .1 k
.64881 .41445 m
.61471 .40534 L
.53947 .42888 L
.56923 .44179 L
F
.683 .5 .608 .1 k
.61471 .40534 m
.57819 .39197 L
.5076 .41215 L
.53947 .42888 L
F
.683 .5 .625 .1 k
.57819 .39197 m
.54086 .37401 L
.47503 .39154 L
.5076 .41215 L
F
.683 .5 .642 .1 k
.54086 .37401 m
.50434 .35159 L
.44316 .36735 L
.47503 .39154 L
F
.683 .5 .658 .1 k
.50434 .35159 m
.47024 .3254 L
.4134 .34039 L
.44316 .36735 L
F
.683 .5 .675 .1 k
.47024 .3254 m
.44004 .29685 L
.38704 .31207 L
.4134 .34039 L
F
.683 .5 .692 .1 k
.44004 .29685 m
.41506 .26819 L
.36524 .28452 L
.38704 .31207 L
F
.683 .5 .708 .1 k
.41506 .26819 m
.39639 .24272 L
.34895 .26072 L
.36524 .28452 L
F
.683 .5 .725 .1 k
.39639 .24272 m
.38485 .22465 L
.33889 .24423 L
.34895 .26072 L
F
.683 .5 .742 .1 k
.38485 .22465 m
.38095 .21804 L
.33548 .23828 L
.33889 .24423 L
F
.683 .5 .758 .1 k
.38095 .21804 m
.38485 .22465 L
.33889 .24423 L
.33548 .23828 L
F
.683 .5 .775 .1 k
.38485 .22465 m
.39639 .24272 L
.34895 .26072 L
.33889 .24423 L
F
.683 .5 .792 .1 k
.39639 .24272 m
.41506 .26819 L
.36524 .28452 L
.34895 .26072 L
F
.683 .5 .808 .1 k
.41506 .26819 m
.44004 .29685 L
.38704 .31207 L
.36524 .28452 L
F
.683 .5 .825 .1 k
.44004 .29685 m
.47024 .3254 L
.4134 .34039 L
.38704 .31207 L
F
.683 .5 .842 .1 k
.47024 .3254 m
.50434 .35159 L
.44316 .36735 L
.4134 .34039 L
F
.683 .5 .858 .1 k
.50434 .35159 m
.54086 .37401 L
.47503 .39154 L
.44316 .36735 L
F
.683 .5 .875 .1 k
.54086 .37401 m
.57819 .39197 L
.5076 .41215 L
.47503 .39154 L
F
.683 .5 .892 .1 k
.57819 .39197 m
.61471 .40534 L
.53947 .42888 L
.5076 .41215 L
F
.683 .5 .908 .1 k
.61471 .40534 m
.64881 .41445 L
.56923 .44179 L
.53947 .42888 L
F
.683 .5 .925 .1 k
.64881 .41445 m
.67901 .41998 L
.59559 .45123 L
.56923 .44179 L
F
.683 .5 .942 .1 k
.67901 .41998 m
.70399 .42282 L
.61739 .45771 L
.59559 .45123 L
F
.683 .5 .958 .1 k
.70399 .42282 m
.72266 .42394 L
.63368 .46181 L
.61739 .45771 L
F
.683 .5 .975 .1 k
.72266 .42394 m
.73419 .42421 L
.64375 .46403 L
.63368 .46181 L
F
.683 .5 .992 .1 k
.73419 .42421 m
.7381 .42423 L
.64715 .46472 L
.64375 .46403 L
F
.717 .5 .008 .1 k
.64715 .46472 m
.64375 .46403 L
.5469 .48427 L
.54978 .48542 L
F
.717 .5 .025 .1 k
.64375 .46403 m
.63368 .46181 L
.53841 .48074 L
.5469 .48427 L
F
.717 .5 .042 .1 k
.63368 .46181 m
.61739 .45771 L
.52466 .47465 L
.53841 .48074 L
F
.717 .5 .058 .1 k
.61739 .45771 m
.59559 .45123 L
.50627 .46571 L
.52466 .47465 L
F
.717 .5 .075 .1 k
.59559 .45123 m
.56923 .44179 L
.48403 .45365 L
.50627 .46571 L
F
.717 .5 .092 .1 k
.56923 .44179 m
.53947 .42888 L
.45892 .43822 L
.48403 .45365 L
F
.717 .5 .108 .1 k
.53947 .42888 m
.5076 .41215 L
.43203 .41935 L
.45892 .43822 L
F
.717 .5 .125 .1 k
.5076 .41215 m
.47503 .39154 L
.40454 .39718 L
.43203 .41935 L
F
.717 .5 .142 .1 k
.47503 .39154 m
.44316 .36735 L
.37765 .37215 L
.40454 .39718 L
F
.717 .5 .158 .1 k
.44316 .36735 m
.4134 .34039 L
.35254 .34514 L
.37765 .37215 L
F
.717 .5 .175 .1 k
.4134 .34039 m
.38704 .31207 L
.3303 .31753 L
.35254 .34514 L
F
.717 .5 .192 .1 k
.38704 .31207 m
.36524 .28452 L
.31191 .29131 L
.3303 .31753 L
F
.717 .5 .208 .1 k
.36524 .28452 m
.34895 .26072 L
.29816 .26914 L
.31191 .29131 L
F
.717 .5 .225 .1 k
.34895 .26072 m
.33889 .24423 L
.28967 .25403 L
.29816 .26914 L
F
.717 .5 .242 .1 k
.33889 .24423 m
.33548 .23828 L
.28679 .24863 L
.28967 .25403 L
F
.717 .5 .258 .1 k
.33548 .23828 m
.33889 .24423 L
.28967 .25403 L
.28679 .24863 L
F
.717 .5 .275 .1 k
.33889 .24423 m
.34895 .26072 L
.29816 .26914 L
.28967 .25403 L
F
.717 .5 .292 .1 k
.34895 .26072 m
.36524 .28452 L
.31191 .29131 L
.29816 .26914 L
F
.717 .5 .308 .1 k
.36524 .28452 m
.38704 .31207 L
.3303 .31753 L
.31191 .29131 L
F
.717 .5 .325 .1 k
.38704 .31207 m
.4134 .34039 L
.35254 .34514 L
.3303 .31753 L
F
.717 .5 .342 .1 k
.4134 .34039 m
.44316 .36735 L
.37765 .37215 L
.35254 .34514 L
F
.717 .5 .358 .1 k
.44316 .36735 m
.47503 .39154 L
.40454 .39718 L
.37765 .37215 L
F
.717 .5 .375 .1 k
.47503 .39154 m
.5076 .41215 L
.43203 .41935 L
.40454 .39718 L
F
.717 .5 .392 .1 k
.5076 .41215 m
.53947 .42888 L
.45892 .43822 L
.43203 .41935 L
F
.717 .5 .408 .1 k
.53947 .42888 m
.56923 .44179 L
.48403 .45365 L
.45892 .43822 L
F
.717 .5 .425 .1 k
.56923 .44179 m
.59559 .45123 L
.50627 .46571 L
.48403 .45365 L
F
.717 .5 .442 .1 k
.59559 .45123 m
.61739 .45771 L
.52466 .47465 L
.50627 .46571 L
F
.717 .5 .458 .1 k
.61739 .45771 m
.63368 .46181 L
.53841 .48074 L
.52466 .47465 L
F
.717 .5 .475 .1 k
.63368 .46181 m
.64375 .46403 L
.5469 .48427 L
.53841 .48074 L
F
.717 .5 .492 .1 k
.64375 .46403 m
.64715 .46472 L
.54978 .48542 L
.5469 .48427 L
F
.717 .5 .508 .1 k
.64715 .46472 m
.64375 .46403 L
.5469 .48427 L
.54978 .48542 L
F
.717 .5 .525 .1 k
.64375 .46403 m
.63368 .46181 L
.53841 .48074 L
.5469 .48427 L
F
.717 .5 .542 .1 k
.63368 .46181 m
.61739 .45771 L
.52466 .47465 L
.53841 .48074 L
F
.717 .5 .558 .1 k
.61739 .45771 m
.59559 .45123 L
.50627 .46571 L
.52466 .47465 L
F
.717 .5 .575 .1 k
.59559 .45123 m
.56923 .44179 L
.48403 .45365 L
.50627 .46571 L
F
.717 .5 .592 .1 k
.56923 .44179 m
.53947 .42888 L
.45892 .43822 L
.48403 .45365 L
F
.717 .5 .608 .1 k
.53947 .42888 m
.5076 .41215 L
.43203 .41935 L
.45892 .43822 L
F
.717 .5 .625 .1 k
.5076 .41215 m
.47503 .39154 L
.40454 .39718 L
.43203 .41935 L
F
.717 .5 .642 .1 k
.47503 .39154 m
.44316 .36735 L
.37765 .37215 L
.40454 .39718 L
F
.717 .5 .658 .1 k
.44316 .36735 m
.4134 .34039 L
.35254 .34514 L
.37765 .37215 L
F
.717 .5 .675 .1 k
.4134 .34039 m
.38704 .31207 L
.3303 .31753 L
.35254 .34514 L
F
.717 .5 .692 .1 k
.38704 .31207 m
.36524 .28452 L
.31191 .29131 L
.3303 .31753 L
F
.717 .5 .708 .1 k
.36524 .28452 m
.34895 .26072 L
.29816 .26914 L
.31191 .29131 L
F
.717 .5 .725 .1 k
.34895 .26072 m
.33889 .24423 L
.28967 .25403 L
.29816 .26914 L
F
.717 .5 .742 .1 k
.33889 .24423 m
.33548 .23828 L
.28679 .24863 L
.28967 .25403 L
F
.717 .5 .758 .1 k
.33548 .23828 m
.33889 .24423 L
.28967 .25403 L
.28679 .24863 L
F
.717 .5 .775 .1 k
.33889 .24423 m
.34895 .26072 L
.29816 .26914 L
.28967 .25403 L
F
.717 .5 .792 .1 k
.34895 .26072 m
.36524 .28452 L
.31191 .29131 L
.29816 .26914 L
F
.717 .5 .808 .1 k
.36524 .28452 m
.38704 .31207 L
.3303 .31753 L
.31191 .29131 L
F
.717 .5 .825 .1 k
.38704 .31207 m
.4134 .34039 L
.35254 .34514 L
.3303 .31753 L
F
.717 .5 .842 .1 k
.4134 .34039 m
.44316 .36735 L
.37765 .37215 L
.35254 .34514 L
F
.717 .5 .858 .1 k
.44316 .36735 m
.47503 .39154 L
.40454 .39718 L
.37765 .37215 L
F
.717 .5 .875 .1 k
.47503 .39154 m
.5076 .41215 L
.43203 .41935 L
.40454 .39718 L
F
.717 .5 .892 .1 k
.5076 .41215 m
.53947 .42888 L
.45892 .43822 L
.43203 .41935 L
F
.717 .5 .908 .1 k
.53947 .42888 m
.56923 .44179 L
.48403 .45365 L
.45892 .43822 L
F
.717 .5 .925 .1 k
.56923 .44179 m
.59559 .45123 L
.50627 .46571 L
.48403 .45365 L
F
.717 .5 .942 .1 k
.59559 .45123 m
.61739 .45771 L
.52466 .47465 L
.50627 .46571 L
F
.717 .5 .958 .1 k
.61739 .45771 m
.63368 .46181 L
.53841 .48074 L
.52466 .47465 L
F
.717 .5 .975 .1 k
.63368 .46181 m
.64375 .46403 L
.5469 .48427 L
.53841 .48074 L
F
.717 .5 .992 .1 k
.64375 .46403 m
.64715 .46472 L
.54978 .48542 L
.5469 .48427 L
F
.75 .5 .008 .1 k
.54978 .48542 m
.5469 .48427 L
.44789 .484 L
.45022 .48542 L
F
.75 .5 .025 .1 k
.5469 .48427 m
.53841 .48074 L
.44101 .47969 L
.44789 .484 L
F
.75 .5 .042 .1 k
.53841 .48074 m
.52466 .47465 L
.42987 .47243 L
.44101 .47969 L
F
.75 .5 .058 .1 k
.52466 .47465 m
.50627 .46571 L
.41495 .46209 L
.42987 .47243 L
F
.75 .5 .075 .1 k
.50627 .46571 m
.48403 .45365 L
.39692 .44859 L
.41495 .46209 L
F
.75 .5 .092 .1 k
.48403 .45365 m
.45892 .43822 L
.37656 .43189 L
.39692 .44859 L
F
.75 .5 .108 .1 k
.45892 .43822 m
.43203 .41935 L
.35476 .4121 L
.37656 .43189 L
F
.75 .5 .125 .1 k
.43203 .41935 m
.40454 .39718 L
.33248 .3895 L
.35476 .4121 L
F
.75 .5 .142 .1 k
.40454 .39718 m
.37765 .37215 L
.31068 .36463 L
.33248 .3895 L
F
.75 .5 .158 .1 k
.37765 .37215 m
.35254 .34514 L
.29032 .33841 L
.31068 .36463 L
F
.75 .5 .175 .1 k
.35254 .34514 m
.3303 .31753 L
.27229 .31213 L
.29032 .33841 L
F
.75 .5 .192 .1 k
.3303 .31753 m
.31191 .29131 L
.25738 .28763 L
.27229 .31213 L
F
.75 .5 .208 .1 k
.31191 .29131 m
.29816 .26914 L
.24623 .26722 L
.25738 .28763 L
F
.75 .5 .225 .1 k
.29816 .26914 m
.28967 .25403 L
.23935 .2535 L
.24623 .26722 L
F
.75 .5 .242 .1 k
.28967 .25403 m
.28679 .24863 L
.23702 .24863 L
.23935 .2535 L
F
.75 .5 .258 .1 k
.28679 .24863 m
.28967 .25403 L
.23935 .2535 L
.23702 .24863 L
F
.75 .5 .275 .1 k
.28967 .25403 m
.29816 .26914 L
.24623 .26722 L
.23935 .2535 L
F
.75 .5 .292 .1 k
.29816 .26914 m
.31191 .29131 L
.25738 .28763 L
.24623 .26722 L
F
.75 .5 .308 .1 k
.31191 .29131 m
.3303 .31753 L
.27229 .31213 L
.25738 .28763 L
F
.75 .5 .325 .1 k
.3303 .31753 m
.35254 .34514 L
.29032 .33841 L
.27229 .31213 L
F
.75 .5 .342 .1 k
.35254 .34514 m
.37765 .37215 L
.31068 .36463 L
.29032 .33841 L
F
.75 .5 .358 .1 k
.37765 .37215 m
.40454 .39718 L
.33248 .3895 L
.31068 .36463 L
F
.75 .5 .375 .1 k
.40454 .39718 m
.43203 .41935 L
.35476 .4121 L
.33248 .3895 L
F
.75 .5 .392 .1 k
.43203 .41935 m
.45892 .43822 L
.37656 .43189 L
.35476 .4121 L
F
.75 .5 .408 .1 k
.45892 .43822 m
.48403 .45365 L
.39692 .44859 L
.37656 .43189 L
F
.75 .5 .425 .1 k
.48403 .45365 m
.50627 .46571 L
.41495 .46209 L
.39692 .44859 L
F
.75 .5 .442 .1 k
.50627 .46571 m
.52466 .47465 L
.42987 .47243 L
.41495 .46209 L
F
.75 .5 .458 .1 k
.52466 .47465 m
.53841 .48074 L
.44101 .47969 L
.42987 .47243 L
F
.75 .5 .475 .1 k
.53841 .48074 m
.5469 .48427 L
.44789 .484 L
.44101 .47969 L
F
.75 .5 .492 .1 k
.5469 .48427 m
.54978 .48542 L
.45022 .48542 L
.44789 .484 L
F
.75 .5 .508 .1 k
.54978 .48542 m
.5469 .48427 L
.44789 .484 L
.45022 .48542 L
F
.75 .5 .525 .1 k
.5469 .48427 m
.53841 .48074 L
.44101 .47969 L
.44789 .484 L
F
.75 .5 .542 .1 k
.53841 .48074 m
.52466 .47465 L
.42987 .47243 L
.44101 .47969 L
F
.75 .5 .558 .1 k
.52466 .47465 m
.50627 .46571 L
.41495 .46209 L
.42987 .47243 L
F
.75 .5 .575 .1 k
.50627 .46571 m
.48403 .45365 L
.39692 .44859 L
.41495 .46209 L
F
.75 .5 .592 .1 k
.48403 .45365 m
.45892 .43822 L
.37656 .43189 L
.39692 .44859 L
F
.75 .5 .608 .1 k
.45892 .43822 m
.43203 .41935 L
.35476 .4121 L
.37656 .43189 L
F
.75 .5 .625 .1 k
.43203 .41935 m
.40454 .39718 L
.33248 .3895 L
.35476 .4121 L
F
.75 .5 .642 .1 k
.40454 .39718 m
.37765 .37215 L
.31068 .36463 L
.33248 .3895 L
F
.75 .5 .658 .1 k
.37765 .37215 m
.35254 .34514 L
.29032 .33841 L
.31068 .36463 L
F
.75 .5 .675 .1 k
.35254 .34514 m
.3303 .31753 L
.27229 .31213 L
.29032 .33841 L
F
.75 .5 .692 .1 k
.3303 .31753 m
.31191 .29131 L
.25738 .28763 L
.27229 .31213 L
F
.75 .5 .708 .1 k
.31191 .29131 m
.29816 .26914 L
.24623 .26722 L
.25738 .28763 L
F
.75 .5 .725 .1 k
.29816 .26914 m
.28967 .25403 L
.23935 .2535 L
.24623 .26722 L
F
.75 .5 .742 .1 k
.28967 .25403 m
.28679 .24863 L
.23702 .24863 L
.23935 .2535 L
F
.75 .5 .758 .1 k
.28679 .24863 m
.28967 .25403 L
.23935 .2535 L
.23702 .24863 L
F
.75 .5 .775 .1 k
.28967 .25403 m
.29816 .26914 L
.24623 .26722 L
.23935 .2535 L
F
.75 .5 .792 .1 k
.29816 .26914 m
.31191 .29131 L
.25738 .28763 L
.24623 .26722 L
F
.75 .5 .808 .1 k
.31191 .29131 m
.3303 .31753 L
.27229 .31213 L
.25738 .28763 L
F
.75 .5 .825 .1 k
.3303 .31753 m
.35254 .34514 L
.29032 .33841 L
.27229 .31213 L
F
.75 .5 .842 .1 k
.35254 .34514 m
.37765 .37215 L
.31068 .36463 L
.29032 .33841 L
F
.75 .5 .858 .1 k
.37765 .37215 m
.40454 .39718 L
.33248 .3895 L
.31068 .36463 L
F
.75 .5 .875 .1 k
.40454 .39718 m
.43203 .41935 L
.35476 .4121 L
.33248 .3895 L
F
.75 .5 .892 .1 k
.43203 .41935 m
.45892 .43822 L
.37656 .43189 L
.35476 .4121 L
F
.75 .5 .908 .1 k
.45892 .43822 m
.48403 .45365 L
.39692 .44859 L
.37656 .43189 L
F
.75 .5 .925 .1 k
.48403 .45365 m
.50627 .46571 L
.41495 .46209 L
.39692 .44859 L
F
.75 .5 .942 .1 k
.50627 .46571 m
.52466 .47465 L
.42987 .47243 L
.41495 .46209 L
F
.75 .5 .958 .1 k
.52466 .47465 m
.53841 .48074 L
.44101 .47969 L
.42987 .47243 L
F
.75 .5 .975 .1 k
.53841 .48074 m
.5469 .48427 L
.44789 .484 L
.44101 .47969 L
F
.75 .5 .992 .1 k
.5469 .48427 m
.54978 .48542 L
.45022 .48542 L
.44789 .484 L
F
.783 .5 .008 .1 k
.45022 .48542 m
.44789 .484 L
.35105 .46319 L
.35285 .46472 L
F
.783 .5 .025 .1 k
.44789 .484 m
.44101 .47969 L
.34574 .45858 L
.35105 .46319 L
F
.783 .5 .042 .1 k
.44101 .47969 m
.42987 .47243 L
.33714 .45088 L
.34574 .45858 L
F
.783 .5 .058 .1 k
.42987 .47243 m
.41495 .46209 L
.32563 .44008 L
.33714 .45088 L
F
.783 .5 .075 .1 k
.41495 .46209 m
.39692 .44859 L
.31172 .42623 L
.32563 .44008 L
F
.783 .5 .092 .1 k
.39692 .44859 m
.37656 .43189 L
.29601 .40943 L
.31172 .42623 L
F
.783 .5 .108 .1 k
.37656 .43189 m
.35476 .4121 L
.27919 .38989 L
.29601 .40943 L
F
.783 .5 .125 .1 k
.35476 .4121 m
.33248 .3895 L
.26199 .36799 L
.27919 .38989 L
F
.783 .5 .142 .1 k
.33248 .3895 m
.31068 .36463 L
.24517 .34432 L
.26199 .36799 L
F
.783 .5 .158 .1 k
.31068 .36463 m
.29032 .33841 L
.22946 .31975 L
.24517 .34432 L
F
.783 .5 .175 .1 k
.29032 .33841 m
.27229 .31213 L
.21555 .2955 L
.22946 .31975 L
F
.783 .5 .192 .1 k
.27229 .31213 m
.25738 .28763 L
.20404 .27319 L
.21555 .2955 L
F
.783 .5 .208 .1 k
.25738 .28763 m
.24623 .26722 L
.19544 .25483 L
.20404 .27319 L
F
.783 .5 .225 .1 k
.24623 .26722 m
.23935 .2535 L
.19013 .2426 L
.19544 .25483 L
F
.783 .5 .242 .1 k
.23935 .2535 m
.23702 .24863 L
.18833 .23828 L
.19013 .2426 L
F
.783 .5 .258 .1 k
.23702 .24863 m
.23935 .2535 L
.19013 .2426 L
.18833 .23828 L
F
.783 .5 .275 .1 k
.23935 .2535 m
.24623 .26722 L
.19544 .25483 L
.19013 .2426 L
F
.783 .5 .292 .1 k
.24623 .26722 m
.25738 .28763 L
.20404 .27319 L
.19544 .25483 L
F
.783 .5 .308 .1 k
.25738 .28763 m
.27229 .31213 L
.21555 .2955 L
.20404 .27319 L
F
.783 .5 .325 .1 k
.27229 .31213 m
.29032 .33841 L
.22946 .31975 L
.21555 .2955 L
F
.783 .5 .342 .1 k
.29032 .33841 m
.31068 .36463 L
.24517 .34432 L
.22946 .31975 L
F
.783 .5 .358 .1 k
.31068 .36463 m
.33248 .3895 L
.26199 .36799 L
.24517 .34432 L
F
.783 .5 .375 .1 k
.33248 .3895 m
.35476 .4121 L
.27919 .38989 L
.26199 .36799 L
F
.783 .5 .392 .1 k
.35476 .4121 m
.37656 .43189 L
.29601 .40943 L
.27919 .38989 L
F
.783 .5 .408 .1 k
.37656 .43189 m
.39692 .44859 L
.31172 .42623 L
.29601 .40943 L
F
.783 .5 .425 .1 k
.39692 .44859 m
.41495 .46209 L
.32563 .44008 L
.31172 .42623 L
F
.783 .5 .442 .1 k
.41495 .46209 m
.42987 .47243 L
.33714 .45088 L
.32563 .44008 L
F
.783 .5 .458 .1 k
.42987 .47243 m
.44101 .47969 L
.34574 .45858 L
.33714 .45088 L
F
.783 .5 .475 .1 k
.44101 .47969 m
.44789 .484 L
.35105 .46319 L
.34574 .45858 L
F
.783 .5 .492 .1 k
.44789 .484 m
.45022 .48542 L
.35285 .46472 L
.35105 .46319 L
F
.783 .5 .508 .1 k
.45022 .48542 m
.44789 .484 L
.35105 .46319 L
.35285 .46472 L
F
.783 .5 .525 .1 k
.44789 .484 m
.44101 .47969 L
.34574 .45858 L
.35105 .46319 L
F
.783 .5 .542 .1 k
.44101 .47969 m
.42987 .47243 L
.33714 .45088 L
.34574 .45858 L
F
.783 .5 .558 .1 k
.42987 .47243 m
.41495 .46209 L
.32563 .44008 L
.33714 .45088 L
F
.783 .5 .575 .1 k
.41495 .46209 m
.39692 .44859 L
.31172 .42623 L
.32563 .44008 L
F
.783 .5 .592 .1 k
.39692 .44859 m
.37656 .43189 L
.29601 .40943 L
.31172 .42623 L
F
.783 .5 .608 .1 k
.37656 .43189 m
.35476 .4121 L
.27919 .38989 L
.29601 .40943 L
F
.783 .5 .625 .1 k
.35476 .4121 m
.33248 .3895 L
.26199 .36799 L
.27919 .38989 L
F
.783 .5 .642 .1 k
.33248 .3895 m
.31068 .36463 L
.24517 .34432 L
.26199 .36799 L
F
.783 .5 .658 .1 k
.31068 .36463 m
.29032 .33841 L
.22946 .31975 L
.24517 .34432 L
F
.783 .5 .675 .1 k
.29032 .33841 m
.27229 .31213 L
.21555 .2955 L
.22946 .31975 L
F
.783 .5 .692 .1 k
.27229 .31213 m
.25738 .28763 L
.20404 .27319 L
.21555 .2955 L
F
.783 .5 .708 .1 k
.25738 .28763 m
.24623 .26722 L
.19544 .25483 L
.20404 .27319 L
F
.783 .5 .725 .1 k
.24623 .26722 m
.23935 .2535 L
.19013 .2426 L
.19544 .25483 L
F
.783 .5 .742 .1 k
.23935 .2535 m
.23702 .24863 L
.18833 .23828 L
.19013 .2426 L
F
.783 .5 .758 .1 k
.23702 .24863 m
.23935 .2535 L
.19013 .2426 L
.18833 .23828 L
F
.783 .5 .775 .1 k
.23935 .2535 m
.24623 .26722 L
.19544 .25483 L
.19013 .2426 L
F
.783 .5 .792 .1 k
.24623 .26722 m
.25738 .28763 L
.20404 .27319 L
.19544 .25483 L
F
.783 .5 .808 .1 k
.25738 .28763 m
.27229 .31213 L
.21555 .2955 L
.20404 .27319 L
F
.783 .5 .825 .1 k
.27229 .31213 m
.29032 .33841 L
.22946 .31975 L
.21555 .2955 L
F
.783 .5 .842 .1 k
.29032 .33841 m
.31068 .36463 L
.24517 .34432 L
.22946 .31975 L
F
.783 .5 .858 .1 k
.31068 .36463 m
.33248 .3895 L
.26199 .36799 L
.24517 .34432 L
F
.783 .5 .875 .1 k
.33248 .3895 m
.35476 .4121 L
.27919 .38989 L
.26199 .36799 L
F
.783 .5 .892 .1 k
.35476 .4121 m
.37656 .43189 L
.29601 .40943 L
.27919 .38989 L
F
.783 .5 .908 .1 k
.37656 .43189 m
.39692 .44859 L
.31172 .42623 L
.29601 .40943 L
F
.783 .5 .925 .1 k
.39692 .44859 m
.41495 .46209 L
.32563 .44008 L
.31172 .42623 L
F
.783 .5 .942 .1 k
.41495 .46209 m
.42987 .47243 L
.33714 .45088 L
.32563 .44008 L
F
.783 .5 .958 .1 k
.42987 .47243 m
.44101 .47969 L
.34574 .45858 L
.33714 .45088 L
F
.783 .5 .975 .1 k
.44101 .47969 m
.44789 .484 L
.35105 .46319 L
.34574 .45858 L
F
.783 .5 .992 .1 k
.44789 .484 m
.45022 .48542 L
.35285 .46472 L
.35105 .46319 L
F
.817 .5 .008 .1 k
.35285 .46472 m
.35105 .46319 L
.2606 .42273 L
.2619 .42423 L
F
.817 .5 .025 .1 k
.35105 .46319 m
.34574 .45858 L
.25676 .41821 L
.2606 .42273 L
F
.817 .5 .042 .1 k
.34574 .45858 m
.33714 .45088 L
.25054 .41073 L
.25676 .41821 L
F
.817 .5 .058 .1 k
.33714 .45088 m
.32563 .44008 L
.24221 .40033 L
.25054 .41073 L
F
.817 .5 .075 .1 k
.32563 .44008 m
.31172 .42623 L
.23214 .38712 L
.24221 .40033 L
F
.817 .5 .092 .1 k
.31172 .42623 m
.29601 .40943 L
.22077 .37129 L
.23214 .38712 L
F
.817 .5 .108 .1 k
.29601 .40943 m
.27919 .38989 L
.2086 .35311 L
.22077 .37129 L
F
.817 .5 .125 .1 k
.27919 .38989 m
.26199 .36799 L
.19616 .33298 L
.2086 .35311 L
F
.817 .5 .142 .1 k
.26199 .36799 m
.24517 .34432 L
.18399 .31149 L
.19616 .33298 L
F
.817 .5 .158 .1 k
.24517 .34432 m
.22946 .31975 L
.17262 .28944 L
.18399 .31149 L
F
.817 .5 .175 .1 k
.22946 .31975 m
.21555 .2955 L
.16255 .26792 L
.17262 .28944 L
F
.817 .5 .192 .1 k
.21555 .2955 m
.20404 .27319 L
.15423 .24832 L
.16255 .26792 L
F
.817 .5 .208 .1 k
.20404 .27319 m
.19544 .25483 L
.148 .23233 L
.15423 .24832 L
F
.817 .5 .225 .1 k
.19544 .25483 m
.19013 .2426 L
.14416 .22175 L
.148 .23233 L
F
.817 .5 .242 .1 k
.19013 .2426 m
.18833 .23828 L
.14286 .21804 L
.14416 .22175 L
F
.817 .5 .258 .1 k
.18833 .23828 m
.19013 .2426 L
.14416 .22175 L
.14286 .21804 L
F
.817 .5 .275 .1 k
.19013 .2426 m
.19544 .25483 L
.148 .23233 L
.14416 .22175 L
F
.817 .5 .292 .1 k
.19544 .25483 m
.20404 .27319 L
.15423 .24832 L
.148 .23233 L
F
.817 .5 .308 .1 k
.20404 .27319 m
.21555 .2955 L
.16255 .26792 L
.15423 .24832 L
F
.817 .5 .325 .1 k
.21555 .2955 m
.22946 .31975 L
.17262 .28944 L
.16255 .26792 L
F
.817 .5 .342 .1 k
.22946 .31975 m
.24517 .34432 L
.18399 .31149 L
.17262 .28944 L
F
.817 .5 .358 .1 k
.24517 .34432 m
.26199 .36799 L
.19616 .33298 L
.18399 .31149 L
F
.817 .5 .375 .1 k
.26199 .36799 m
.27919 .38989 L
.2086 .35311 L
.19616 .33298 L
F
.817 .5 .392 .1 k
.27919 .38989 m
.29601 .40943 L
.22077 .37129 L
.2086 .35311 L
F
.817 .5 .408 .1 k
.29601 .40943 m
.31172 .42623 L
.23214 .38712 L
.22077 .37129 L
F
.817 .5 .425 .1 k
.31172 .42623 m
.32563 .44008 L
.24221 .40033 L
.23214 .38712 L
F
.817 .5 .442 .1 k
.32563 .44008 m
.33714 .45088 L
.25054 .41073 L
.24221 .40033 L
F
.817 .5 .458 .1 k
.33714 .45088 m
.34574 .45858 L
.25676 .41821 L
.25054 .41073 L
F
.817 .5 .475 .1 k
.34574 .45858 m
.35105 .46319 L
.2606 .42273 L
.25676 .41821 L
F
.817 .5 .492 .1 k
.35105 .46319 m
.35285 .46472 L
.2619 .42423 L
.2606 .42273 L
F
.817 .5 .508 .1 k
.35285 .46472 m
.35105 .46319 L
.2606 .42273 L
.2619 .42423 L
F
.817 .5 .525 .1 k
.35105 .46319 m
.34574 .45858 L
.25676 .41821 L
.2606 .42273 L
F
.817 .5 .542 .1 k
.34574 .45858 m
.33714 .45088 L
.25054 .41073 L
.25676 .41821 L
F
.817 .5 .558 .1 k
.33714 .45088 m
.32563 .44008 L
.24221 .40033 L
.25054 .41073 L
F
.817 .5 .575 .1 k
.32563 .44008 m
.31172 .42623 L
.23214 .38712 L
.24221 .40033 L
F
.817 .5 .592 .1 k
.31172 .42623 m
.29601 .40943 L
.22077 .37129 L
.23214 .38712 L
F
.817 .5 .608 .1 k
.29601 .40943 m
.27919 .38989 L
.2086 .35311 L
.22077 .37129 L
F
.817 .5 .625 .1 k
.27919 .38989 m
.26199 .36799 L
.19616 .33298 L
.2086 .35311 L
F
.817 .5 .642 .1 k
.26199 .36799 m
.24517 .34432 L
.18399 .31149 L
.19616 .33298 L
F
.817 .5 .658 .1 k
.24517 .34432 m
.22946 .31975 L
.17262 .28944 L
.18399 .31149 L
F
.817 .5 .675 .1 k
.22946 .31975 m
.21555 .2955 L
.16255 .26792 L
.17262 .28944 L
F
.817 .5 .692 .1 k
.21555 .2955 m
.20404 .27319 L
.15423 .24832 L
.16255 .26792 L
F
.817 .5 .708 .1 k
.20404 .27319 m
.19544 .25483 L
.148 .23233 L
.15423 .24832 L
F
.817 .5 .725 .1 k
.19544 .25483 m
.19013 .2426 L
.14416 .22175 L
.148 .23233 L
F
.817 .5 .742 .1 k
.19013 .2426 m
.18833 .23828 L
.14286 .21804 L
.14416 .22175 L
F
.817 .5 .758 .1 k
.18833 .23828 m
.19013 .2426 L
.14416 .22175 L
.14286 .21804 L
F
.817 .5 .775 .1 k
.19013 .2426 m
.19544 .25483 L
.148 .23233 L
.14416 .22175 L
F
.817 .5 .792 .1 k
.19544 .25483 m
.20404 .27319 L
.15423 .24832 L
.148 .23233 L
F
.817 .5 .808 .1 k
.20404 .27319 m
.21555 .2955 L
.16255 .26792 L
.15423 .24832 L
F
.817 .5 .825 .1 k
.21555 .2955 m
.22946 .31975 L
.17262 .28944 L
.16255 .26792 L
F
.817 .5 .842 .1 k
.22946 .31975 m
.24517 .34432 L
.18399 .31149 L
.17262 .28944 L
F
.817 .5 .858 .1 k
.24517 .34432 m
.26199 .36799 L
.19616 .33298 L
.18399 .31149 L
F
.817 .5 .875 .1 k
.26199 .36799 m
.27919 .38989 L
.2086 .35311 L
.19616 .33298 L
F
.817 .5 .892 .1 k
.27919 .38989 m
.29601 .40943 L
.22077 .37129 L
.2086 .35311 L
F
.817 .5 .908 .1 k
.29601 .40943 m
.31172 .42623 L
.23214 .38712 L
.22077 .37129 L
F
.817 .5 .925 .1 k
.31172 .42623 m
.32563 .44008 L
.24221 .40033 L
.23214 .38712 L
F
.817 .5 .942 .1 k
.32563 .44008 m
.33714 .45088 L
.25054 .41073 L
.24221 .40033 L
F
.817 .5 .958 .1 k
.33714 .45088 m
.34574 .45858 L
.25676 .41821 L
.25054 .41073 L
F
.817 .5 .975 .1 k
.34574 .45858 m
.35105 .46319 L
.2606 .42273 L
.25676 .41821 L
F
.817 .5 .992 .1 k
.35105 .46319 m
.35285 .46472 L
.2619 .42423 L
.2606 .42273 L
F
.85 .5 .008 .1 k
.2619 .42423 m
.2606 .42273 L
.18051 .36436 L
.18137 .36572 L
F
.85 .5 .025 .1 k
.2606 .42273 m
.25676 .41821 L
.17796 .3603 L
.18051 .36436 L
F
.85 .5 .042 .1 k
.25676 .41821 m
.25054 .41073 L
.17384 .3536 L
.17796 .3603 L
F
.85 .5 .058 .1 k
.25054 .41073 m
.24221 .40033 L
.16833 .34433 L
.17384 .3536 L
F
.85 .5 .075 .1 k
.24221 .40033 m
.23214 .38712 L
.16167 .33264 L
.16833 .34433 L
F
.85 .5 .092 .1 k
.23214 .38712 m
.22077 .37129 L
.15415 .31873 L
.16167 .33264 L
F
.85 .5 .108 .1 k
.22077 .37129 m
.2086 .35311 L
.14609 .30289 L
.15415 .31873 L
F
.85 .5 .125 .1 k
.2086 .35311 m
.19616 .33298 L
.13786 .28551 L
.14609 .30289 L
F
.85 .5 .142 .1 k
.19616 .33298 m
.18399 .31149 L
.12981 .2671 L
.13786 .28551 L
F
.85 .5 .158 .1 k
.18399 .31149 m
.17262 .28944 L
.12228 .24838 L
.12981 .2671 L
F
.85 .5 .175 .1 k
.17262 .28944 m
.16255 .26792 L
.11562 .23025 L
.12228 .24838 L
F
.85 .5 .192 .1 k
.16255 .26792 m
.15423 .24832 L
.11011 .21386 L
.11562 .23025 L
F
.85 .5 .208 .1 k
.15423 .24832 m
.148 .23233 L
.10599 .20058 L
.11011 .21386 L
F
.85 .5 .225 .1 k
.148 .23233 m
.14416 .22175 L
.10345 .19184 L
.10599 .20058 L
F
.85 .5 .242 .1 k
.14416 .22175 m
.14286 .21804 L
.10259 .18878 L
.10345 .19184 L
F
.85 .5 .258 .1 k
.14286 .21804 m
.14416 .22175 L
.10345 .19184 L
.10259 .18878 L
F
.85 .5 .275 .1 k
.14416 .22175 m
.148 .23233 L
.10599 .20058 L
.10345 .19184 L
F
.85 .5 .292 .1 k
.148 .23233 m
.15423 .24832 L
.11011 .21386 L
.10599 .20058 L
F
.85 .5 .308 .1 k
.15423 .24832 m
.16255 .26792 L
.11562 .23025 L
.11011 .21386 L
F
.85 .5 .325 .1 k
.16255 .26792 m
.17262 .28944 L
.12228 .24838 L
.11562 .23025 L
F
.85 .5 .342 .1 k
.17262 .28944 m
.18399 .31149 L
.12981 .2671 L
.12228 .24838 L
F
.85 .5 .358 .1 k
.18399 .31149 m
.19616 .33298 L
.13786 .28551 L
.12981 .2671 L
F
.85 .5 .375 .1 k
.19616 .33298 m
.2086 .35311 L
.14609 .30289 L
.13786 .28551 L
F
.85 .5 .392 .1 k
.2086 .35311 m
.22077 .37129 L
.15415 .31873 L
.14609 .30289 L
F
.85 .5 .408 .1 k
.22077 .37129 m
.23214 .38712 L
.16167 .33264 L
.15415 .31873 L
F
.85 .5 .425 .1 k
.23214 .38712 m
.24221 .40033 L
.16833 .34433 L
.16167 .33264 L
F
.85 .5 .442 .1 k
.24221 .40033 m
.25054 .41073 L
.17384 .3536 L
.16833 .34433 L
F
.85 .5 .458 .1 k
.25054 .41073 m
.25676 .41821 L
.17796 .3603 L
.17384 .3536 L
F
.85 .5 .475 .1 k
.25676 .41821 m
.2606 .42273 L
.18051 .36436 L
.17796 .3603 L
F
.85 .5 .492 .1 k
.2606 .42273 m
.2619 .42423 L
.18137 .36572 L
.18051 .36436 L
F
.85 .5 .508 .1 k
.2619 .42423 m
.2606 .42273 L
.18051 .36436 L
.18137 .36572 L
F
.85 .5 .525 .1 k
.2606 .42273 m
.25676 .41821 L
.17796 .3603 L
.18051 .36436 L
F
.85 .5 .542 .1 k
.25676 .41821 m
.25054 .41073 L
.17384 .3536 L
.17796 .3603 L
F
.85 .5 .558 .1 k
.25054 .41073 m
.24221 .40033 L
.16833 .34433 L
.17384 .3536 L
F
.85 .5 .575 .1 k
.24221 .40033 m
.23214 .38712 L
.16167 .33264 L
.16833 .34433 L
F
.85 .5 .592 .1 k
.23214 .38712 m
.22077 .37129 L
.15415 .31873 L
.16167 .33264 L
F
.85 .5 .608 .1 k
.22077 .37129 m
.2086 .35311 L
.14609 .30289 L
.15415 .31873 L
F
.85 .5 .625 .1 k
.2086 .35311 m
.19616 .33298 L
.13786 .28551 L
.14609 .30289 L
F
.85 .5 .642 .1 k
.19616 .33298 m
.18399 .31149 L
.12981 .2671 L
.13786 .28551 L
F
.85 .5 .658 .1 k
.18399 .31149 m
.17262 .28944 L
.12228 .24838 L
.12981 .2671 L
F
.85 .5 .675 .1 k
.17262 .28944 m
.16255 .26792 L
.11562 .23025 L
.12228 .24838 L
F
.85 .5 .692 .1 k
.16255 .26792 m
.15423 .24832 L
.11011 .21386 L
.11562 .23025 L
F
.85 .5 .708 .1 k
.15423 .24832 m
.148 .23233 L
.10599 .20058 L
.11011 .21386 L
F
.85 .5 .725 .1 k
.148 .23233 m
.14416 .22175 L
.10345 .19184 L
.10599 .20058 L
F
.85 .5 .742 .1 k
.14416 .22175 m
.14286 .21804 L
.10259 .18878 L
.10345 .19184 L
F
.85 .5 .758 .1 k
.14286 .21804 m
.14416 .22175 L
.10345 .19184 L
.10259 .18878 L
F
.85 .5 .775 .1 k
.14416 .22175 m
.148 .23233 L
.10599 .20058 L
.10345 .19184 L
F
.85 .5 .792 .1 k
.148 .23233 m
.15423 .24832 L
.11011 .21386 L
.10599 .20058 L
F
.85 .5 .808 .1 k
.15423 .24832 m
.16255 .26792 L
.11562 .23025 L
.11011 .21386 L
F
.85 .5 .825 .1 k
.16255 .26792 m
.17262 .28944 L
.12228 .24838 L
.11562 .23025 L
F
.85 .5 .842 .1 k
.17262 .28944 m
.18399 .31149 L
.12981 .2671 L
.12228 .24838 L
F
.85 .5 .858 .1 k
.18399 .31149 m
.19616 .33298 L
.13786 .28551 L
.12981 .2671 L
F
.85 .5 .875 .1 k
.19616 .33298 m
.2086 .35311 L
.14609 .30289 L
.13786 .28551 L
F
.85 .5 .892 .1 k
.2086 .35311 m
.22077 .37129 L
.15415 .31873 L
.14609 .30289 L
F
.85 .5 .908 .1 k
.22077 .37129 m
.23214 .38712 L
.16167 .33264 L
.15415 .31873 L
F
.85 .5 .925 .1 k
.23214 .38712 m
.24221 .40033 L
.16833 .34433 L
.16167 .33264 L
F
.85 .5 .942 .1 k
.24221 .40033 m
.25054 .41073 L
.17384 .3536 L
.16833 .34433 L
F
.85 .5 .958 .1 k
.25054 .41073 m
.25676 .41821 L
.17796 .3603 L
.17384 .3536 L
F
.85 .5 .975 .1 k
.25676 .41821 m
.2606 .42273 L
.18051 .36436 L
.17796 .3603 L
F
.85 .5 .992 .1 k
.2606 .42273 m
.2619 .42423 L
.18137 .36572 L
.18051 .36436 L
F
.883 .5 .008 .1 k
.18137 .36572 m
.18051 .36436 L
.11426 .29063 L
.11475 .29174 L
F
.883 .5 .025 .1 k
.18051 .36436 m
.17796 .3603 L
.11279 .28732 L
.11426 .29063 L
F
.883 .5 .042 .1 k
.17796 .3603 m
.17384 .3536 L
.11041 .28186 L
.11279 .28732 L
F
.883 .5 .058 .1 k
.17384 .3536 m
.16833 .34433 L
.10723 .27434 L
.11041 .28186 L
F
.883 .5 .075 .1 k
.16833 .34433 m
.16167 .33264 L
.10339 .2649 L
.10723 .27434 L
F
.883 .5 .092 .1 k
.16167 .33264 m
.15415 .31873 L
.09904 .25373 L
.10339 .2649 L
F
.883 .5 .108 .1 k
.15415 .31873 m
.14609 .30289 L
.09439 .24107 L
.09904 .25373 L
F
.883 .5 .125 .1 k
.14609 .30289 m
.13786 .28551 L
.08964 .22726 L
.09439 .24107 L
F
.883 .5 .142 .1 k
.13786 .28551 m
.12981 .2671 L
.08499 .21272 L
.08964 .22726 L
F
.883 .5 .158 .1 k
.12981 .2671 m
.12228 .24838 L
.08065 .19802 L
.08499 .21272 L
F
.883 .5 .175 .1 k
.12228 .24838 m
.11562 .23025 L
.0768 .18386 L
.08065 .19802 L
F
.883 .5 .192 .1 k
.11562 .23025 m
.11011 .21386 L
.07362 .17114 L
.0768 .18386 L
F
.883 .5 .208 .1 k
.11011 .21386 m
.10599 .20058 L
.07125 .16087 L
.07362 .17114 L
F
.883 .5 .225 .1 k
.10599 .20058 m
.10345 .19184 L
.06978 .15414 L
.07125 .16087 L
F
.883 .5 .242 .1 k
.10345 .19184 m
.10259 .18878 L
.06928 .15179 L
.06978 .15414 L
F
.883 .5 .258 .1 k
.10259 .18878 m
.10345 .19184 L
.06978 .15414 L
.06928 .15179 L
F
.883 .5 .275 .1 k
.10345 .19184 m
.10599 .20058 L
.07125 .16087 L
.06978 .15414 L
F
.883 .5 .292 .1 k
.10599 .20058 m
.11011 .21386 L
.07362 .17114 L
.07125 .16087 L
F
.883 .5 .308 .1 k
.11011 .21386 m
.11562 .23025 L
.0768 .18386 L
.07362 .17114 L
F
.883 .5 .325 .1 k
.11562 .23025 m
.12228 .24838 L
.08065 .19802 L
.0768 .18386 L
F
.883 .5 .342 .1 k
.12228 .24838 m
.12981 .2671 L
.08499 .21272 L
.08065 .19802 L
F
.883 .5 .358 .1 k
.12981 .2671 m
.13786 .28551 L
.08964 .22726 L
.08499 .21272 L
F
.883 .5 .375 .1 k
.13786 .28551 m
.14609 .30289 L
.09439 .24107 L
.08964 .22726 L
F
.883 .5 .392 .1 k
.14609 .30289 m
.15415 .31873 L
.09904 .25373 L
.09439 .24107 L
F
.883 .5 .408 .1 k
.15415 .31873 m
.16167 .33264 L
.10339 .2649 L
.09904 .25373 L
F
.883 .5 .425 .1 k
.16167 .33264 m
.16833 .34433 L
.10723 .27434 L
.10339 .2649 L
F
.883 .5 .442 .1 k
.16833 .34433 m
.17384 .3536 L
.11041 .28186 L
.10723 .27434 L
F
.883 .5 .458 .1 k
.17384 .3536 m
.17796 .3603 L
.11279 .28732 L
.11041 .28186 L
F
.883 .5 .475 .1 k
.17796 .3603 m
.18051 .36436 L
.11426 .29063 L
.11279 .28732 L
F
.883 .5 .492 .1 k
.18051 .36436 m
.18137 .36572 L
.11475 .29174 L
.11426 .29063 L
F
.883 .5 .508 .1 k
.18137 .36572 m
.18051 .36436 L
.11426 .29063 L
.11475 .29174 L
F
.883 .5 .525 .1 k
.18051 .36436 m
.17796 .3603 L
.11279 .28732 L
.11426 .29063 L
F
.883 .5 .542 .1 k
.17796 .3603 m
.17384 .3536 L
.11041 .28186 L
.11279 .28732 L
F
.883 .5 .558 .1 k
.17384 .3536 m
.16833 .34433 L
.10723 .27434 L
.11041 .28186 L
F
.883 .5 .575 .1 k
.16833 .34433 m
.16167 .33264 L
.10339 .2649 L
.10723 .27434 L
F
.883 .5 .592 .1 k
.16167 .33264 m
.15415 .31873 L
.09904 .25373 L
.10339 .2649 L
F
.883 .5 .608 .1 k
.15415 .31873 m
.14609 .30289 L
.09439 .24107 L
.09904 .25373 L
F
.883 .5 .625 .1 k
.14609 .30289 m
.13786 .28551 L
.08964 .22726 L
.09439 .24107 L
F
.883 .5 .642 .1 k
.13786 .28551 m
.12981 .2671 L
.08499 .21272 L
.08964 .22726 L
F
.883 .5 .658 .1 k
.12981 .2671 m
.12228 .24838 L
.08065 .19802 L
.08499 .21272 L
F
.883 .5 .675 .1 k
.12228 .24838 m
.11562 .23025 L
.0768 .18386 L
.08065 .19802 L
F
.883 .5 .692 .1 k
.11562 .23025 m
.11011 .21386 L
.07362 .17114 L
.0768 .18386 L
F
.883 .5 .708 .1 k
.11011 .21386 m
.10599 .20058 L
.07125 .16087 L
.07362 .17114 L
F
.883 .5 .725 .1 k
.10599 .20058 m
.10345 .19184 L
.06978 .15414 L
.07125 .16087 L
F
.883 .5 .742 .1 k
.10345 .19184 m
.10259 .18878 L
.06928 .15179 L
.06978 .15414 L
F
.883 .5 .758 .1 k
.10259 .18878 m
.10345 .19184 L
.06978 .15414 L
.06928 .15179 L
F
.883 .5 .775 .1 k
.10345 .19184 m
.10599 .20058 L
.07125 .16087 L
.06978 .15414 L
F
.883 .5 .792 .1 k
.10599 .20058 m
.11011 .21386 L
.07362 .17114 L
.07125 .16087 L
F
.883 .5 .808 .1 k
.11011 .21386 m
.11562 .23025 L
.0768 .18386 L
.07362 .17114 L
F
.883 .5 .825 .1 k
.11562 .23025 m
.12228 .24838 L
.08065 .19802 L
.0768 .18386 L
F
.883 .5 .842 .1 k
.12228 .24838 m
.12981 .2671 L
.08499 .21272 L
.08065 .19802 L
F
.883 .5 .858 .1 k
.12981 .2671 m
.13786 .28551 L
.08964 .22726 L
.08499 .21272 L
F
.883 .5 .875 .1 k
.13786 .28551 m
.14609 .30289 L
.09439 .24107 L
.08964 .22726 L
F
.883 .5 .892 .1 k
.14609 .30289 m
.15415 .31873 L
.09904 .25373 L
.09439 .24107 L
F
.883 .5 .908 .1 k
.15415 .31873 m
.16167 .33264 L
.10339 .2649 L
.09904 .25373 L
F
.883 .5 .925 .1 k
.16167 .33264 m
.16833 .34433 L
.10723 .27434 L
.10339 .2649 L
F
.883 .5 .942 .1 k
.16833 .34433 m
.17384 .3536 L
.11041 .28186 L
.10723 .27434 L
F
.883 .5 .958 .1 k
.17384 .3536 m
.17796 .3603 L
.11279 .28732 L
.11041 .28186 L
F
.883 .5 .975 .1 k
.17796 .3603 m
.18051 .36436 L
.11426 .29063 L
.11279 .28732 L
F
.883 .5 .992 .1 k
.18051 .36436 m
.18137 .36572 L
.11475 .29174 L
.11426 .29063 L
F
.917 .5 .008 .1 k
.11475 .29174 m
.11426 .29063 L
.06475 .20474 L
.06498 .20552 L
F
.917 .5 .025 .1 k
.11426 .29063 m
.11279 .28732 L
.06409 .2024 L
.06475 .20474 L
F
.917 .5 .042 .1 k
.11279 .28732 m
.11041 .28186 L
.06301 .19856 L
.06409 .2024 L
F
.917 .5 .058 .1 k
.11041 .28186 m
.10723 .27434 L
.06157 .19327 L
.06301 .19856 L
F
.917 .5 .075 .1 k
.10723 .27434 m
.10339 .2649 L
.05983 .18665 L
.06157 .19327 L
F
.917 .5 .092 .1 k
.10339 .2649 m
.09904 .25373 L
.05787 .17884 L
.05983 .18665 L
F
.917 .5 .108 .1 k
.09904 .25373 m
.09439 .24107 L
.05576 .17002 L
.05787 .17884 L
F
.917 .5 .125 .1 k
.09439 .24107 m
.08964 .22726 L
.05361 .16043 L
.05576 .17002 L
F
.917 .5 .142 .1 k
.08964 .22726 m
.08499 .21272 L
.05151 .15038 L
.05361 .16043 L
F
.917 .5 .158 .1 k
.08499 .21272 m
.08065 .19802 L
.04954 .14026 L
.05151 .15038 L
F
.917 .5 .175 .1 k
.08065 .19802 m
.0768 .18386 L
.0478 .13055 L
.04954 .14026 L
F
.917 .5 .192 .1 k
.0768 .18386 m
.07362 .17114 L
.04636 .12185 L
.0478 .13055 L
F
.917 .5 .208 .1 k
.07362 .17114 m
.07125 .16087 L
.04528 .11485 L
.04636 .12185 L
F
.917 .5 .225 .1 k
.07125 .16087 m
.06978 .15414 L
.04462 .11028 L
.04528 .11485 L
F
.917 .5 .242 .1 k
.06978 .15414 m
.06928 .15179 L
.04439 .10868 L
.04462 .11028 L
F
.917 .5 .258 .1 k
.06928 .15179 m
.06978 .15414 L
.04462 .11028 L
.04439 .10868 L
F
.917 .5 .275 .1 k
.06978 .15414 m
.07125 .16087 L
.04528 .11485 L
.04462 .11028 L
F
.917 .5 .292 .1 k
.07125 .16087 m
.07362 .17114 L
.04636 .12185 L
.04528 .11485 L
F
.917 .5 .308 .1 k
.07362 .17114 m
.0768 .18386 L
.0478 .13055 L
.04636 .12185 L
F
.917 .5 .325 .1 k
.0768 .18386 m
.08065 .19802 L
.04954 .14026 L
.0478 .13055 L
F
.917 .5 .342 .1 k
.08065 .19802 m
.08499 .21272 L
.05151 .15038 L
.04954 .14026 L
F
.917 .5 .358 .1 k
.08499 .21272 m
.08964 .22726 L
.05361 .16043 L
.05151 .15038 L
F
.917 .5 .375 .1 k
.08964 .22726 m
.09439 .24107 L
.05576 .17002 L
.05361 .16043 L
F
.917 .5 .392 .1 k
.09439 .24107 m
.09904 .25373 L
.05787 .17884 L
.05576 .17002 L
F
.917 .5 .408 .1 k
.09904 .25373 m
.10339 .2649 L
.05983 .18665 L
.05787 .17884 L
F
.917 .5 .425 .1 k
.10339 .2649 m
.10723 .27434 L
.06157 .19327 L
.05983 .18665 L
F
.917 .5 .442 .1 k
.10723 .27434 m
.11041 .28186 L
.06301 .19856 L
.06157 .19327 L
F
.917 .5 .458 .1 k
.11041 .28186 m
.11279 .28732 L
.06409 .2024 L
.06301 .19856 L
F
.917 .5 .475 .1 k
.11279 .28732 m
.11426 .29063 L
.06475 .20474 L
.06409 .2024 L
F
.917 .5 .492 .1 k
.11426 .29063 m
.11475 .29174 L
.06498 .20552 L
.06475 .20474 L
F
.917 .5 .508 .1 k
.11475 .29174 m
.11426 .29063 L
.06475 .20474 L
.06498 .20552 L
F
.917 .5 .525 .1 k
.11426 .29063 m
.11279 .28732 L
.06409 .2024 L
.06475 .20474 L
F
.917 .5 .542 .1 k
.11279 .28732 m
.11041 .28186 L
.06301 .19856 L
.06409 .2024 L
F
.917 .5 .558 .1 k
.11041 .28186 m
.10723 .27434 L
.06157 .19327 L
.06301 .19856 L
F
.917 .5 .575 .1 k
.10723 .27434 m
.10339 .2649 L
.05983 .18665 L
.06157 .19327 L
F
.917 .5 .592 .1 k
.10339 .2649 m
.09904 .25373 L
.05787 .17884 L
.05983 .18665 L
F
.917 .5 .608 .1 k
.09904 .25373 m
.09439 .24107 L
.05576 .17002 L
.05787 .17884 L
F
.917 .5 .625 .1 k
.09439 .24107 m
.08964 .22726 L
.05361 .16043 L
.05576 .17002 L
F
.917 .5 .642 .1 k
.08964 .22726 m
.08499 .21272 L
.05151 .15038 L
.05361 .16043 L
F
.917 .5 .658 .1 k
.08499 .21272 m
.08065 .19802 L
.04954 .14026 L
.05151 .15038 L
F
.917 .5 .675 .1 k
.08065 .19802 m
.0768 .18386 L
.0478 .13055 L
.04954 .14026 L
F
.917 .5 .692 .1 k
.0768 .18386 m
.07362 .17114 L
.04636 .12185 L
.0478 .13055 L
F
.917 .5 .708 .1 k
.07362 .17114 m
.07125 .16087 L
.04528 .11485 L
.04636 .12185 L
F
.917 .5 .725 .1 k
.07125 .16087 m
.06978 .15414 L
.04462 .11028 L
.04528 .11485 L
F
.917 .5 .742 .1 k
.06978 .15414 m
.06928 .15179 L
.04439 .10868 L
.04462 .11028 L
F
.917 .5 .758 .1 k
.06928 .15179 m
.06978 .15414 L
.04462 .11028 L
.04439 .10868 L
F
.917 .5 .775 .1 k
.06978 .15414 m
.07125 .16087 L
.04528 .11485 L
.04462 .11028 L
F
.917 .5 .792 .1 k
.07125 .16087 m
.07362 .17114 L
.04636 .12185 L
.04528 .11485 L
F
.917 .5 .808 .1 k
.07362 .17114 m
.0768 .18386 L
.0478 .13055 L
.04636 .12185 L
F
.917 .5 .825 .1 k
.0768 .18386 m
.08065 .19802 L
.04954 .14026 L
.0478 .13055 L
F
.917 .5 .842 .1 k
.08065 .19802 m
.08499 .21272 L
.05151 .15038 L
.04954 .14026 L
F
.917 .5 .858 .1 k
.08499 .21272 m
.08964 .22726 L
.05361 .16043 L
.05151 .15038 L
F
.917 .5 .875 .1 k
.08964 .22726 m
.09439 .24107 L
.05576 .17002 L
.05361 .16043 L
F
.917 .5 .892 .1 k
.09439 .24107 m
.09904 .25373 L
.05787 .17884 L
.05576 .17002 L
F
.917 .5 .908 .1 k
.09904 .25373 m
.10339 .2649 L
.05983 .18665 L
.05787 .17884 L
F
.917 .5 .925 .1 k
.10339 .2649 m
.10723 .27434 L
.06157 .19327 L
.05983 .18665 L
F
.917 .5 .942 .1 k
.10723 .27434 m
.11041 .28186 L
.06301 .19856 L
.06157 .19327 L
F
.917 .5 .958 .1 k
.11041 .28186 m
.11279 .28732 L
.06409 .2024 L
.06301 .19856 L
F
.917 .5 .975 .1 k
.11279 .28732 m
.11426 .29063 L
.06475 .20474 L
.06409 .2024 L
F
.917 .5 .992 .1 k
.11426 .29063 m
.11475 .29174 L
.06498 .20552 L
.06475 .20474 L
F
.95 .5 .008 .1 k
.06498 .20552 m
.06475 .20474 L
.03416 .11044 L
.03422 .11085 L
F
.95 .5 .025 .1 k
.06475 .20474 m
.06409 .2024 L
.03399 .10923 L
.03416 .11044 L
F
.95 .5 .042 .1 k
.06409 .2024 m
.06301 .19856 L
.03372 .10725 L
.03399 .10923 L
F
.95 .5 .058 .1 k
.06301 .19856 m
.06157 .19327 L
.03335 .10452 L
.03372 .10725 L
F
.95 .5 .075 .1 k
.06157 .19327 m
.05983 .18665 L
.03291 .10111 L
.03335 .10452 L
F
.95 .5 .092 .1 k
.05983 .18665 m
.05787 .17884 L
.03242 .09709 L
.03291 .10111 L
F
.95 .5 .108 .1 k
.05787 .17884 m
.05576 .17002 L
.03189 .09257 L
.03242 .09709 L
F
.95 .5 .125 .1 k
.05576 .17002 m
.05361 .16043 L
.03134 .08766 L
.03189 .09257 L
F
.95 .5 .142 .1 k
.05361 .16043 m
.05151 .15038 L
.03081 .08253 L
.03134 .08766 L
F
.95 .5 .158 .1 k
.05151 .15038 m
.04954 .14026 L
.03031 .07736 L
.03081 .08253 L
F
.95 .5 .175 .1 k
.04954 .14026 m
.0478 .13055 L
.02987 .07242 L
.03031 .07736 L
F
.95 .5 .192 .1 k
.0478 .13055 m
.04636 .12185 L
.02951 .06801 L
.02987 .07242 L
F
.95 .5 .208 .1 k
.04636 .12185 m
.04528 .11485 L
.02924 .06446 L
.02951 .06801 L
F
.95 .5 .225 .1 k
.04528 .11485 m
.04462 .11028 L
.02907 .06215 L
.02924 .06446 L
F
.95 .5 .242 .1 k
.04462 .11028 m
.04439 .10868 L
.02901 .06134 L
.02907 .06215 L
F
.95 .5 .258 .1 k
.04439 .10868 m
.04462 .11028 L
.02907 .06215 L
.02901 .06134 L
F
.95 .5 .275 .1 k
.04462 .11028 m
.04528 .11485 L
.02924 .06446 L
.02907 .06215 L
F
.95 .5 .292 .1 k
.04528 .11485 m
.04636 .12185 L
.02951 .06801 L
.02924 .06446 L
F
.95 .5 .308 .1 k
.04636 .12185 m
.0478 .13055 L
.02987 .07242 L
.02951 .06801 L
F
.95 .5 .325 .1 k
.0478 .13055 m
.04954 .14026 L
.03031 .07736 L
.02987 .07242 L
F
.95 .5 .342 .1 k
.04954 .14026 m
.05151 .15038 L
.03081 .08253 L
.03031 .07736 L
F
.95 .5 .358 .1 k
.05151 .15038 m
.05361 .16043 L
.03134 .08766 L
.03081 .08253 L
F
.95 .5 .375 .1 k
.05361 .16043 m
.05576 .17002 L
.03189 .09257 L
.03134 .08766 L
F
.95 .5 .392 .1 k
.05576 .17002 m
.05787 .17884 L
.03242 .09709 L
.03189 .09257 L
F
.95 .5 .408 .1 k
.05787 .17884 m
.05983 .18665 L
.03291 .10111 L
.03242 .09709 L
F
.95 .5 .425 .1 k
.05983 .18665 m
.06157 .19327 L
.03335 .10452 L
.03291 .10111 L
F
.95 .5 .442 .1 k
.06157 .19327 m
.06301 .19856 L
.03372 .10725 L
.03335 .10452 L
F
.95 .5 .458 .1 k
.06301 .19856 m
.06409 .2024 L
.03399 .10923 L
.03372 .10725 L
F
.95 .5 .475 .1 k
.06409 .2024 m
.06475 .20474 L
.03416 .11044 L
.03399 .10923 L
F
.95 .5 .492 .1 k
.06475 .20474 m
.06498 .20552 L
.03422 .11085 L
.03416 .11044 L
F
.95 .5 .508 .1 k
.06498 .20552 m
.06475 .20474 L
.03416 .11044 L
.03422 .11085 L
F
.95 .5 .525 .1 k
.06475 .20474 m
.06409 .2024 L
.03399 .10923 L
.03416 .11044 L
F
.95 .5 .542 .1 k
.06409 .2024 m
.06301 .19856 L
.03372 .10725 L
.03399 .10923 L
F
.95 .5 .558 .1 k
.06301 .19856 m
.06157 .19327 L
.03335 .10452 L
.03372 .10725 L
F
.95 .5 .575 .1 k
.06157 .19327 m
.05983 .18665 L
.03291 .10111 L
.03335 .10452 L
F
.95 .5 .592 .1 k
.05983 .18665 m
.05787 .17884 L
.03242 .09709 L
.03291 .10111 L
F
.95 .5 .608 .1 k
.05787 .17884 m
.05576 .17002 L
.03189 .09257 L
.03242 .09709 L
F
.95 .5 .625 .1 k
.05576 .17002 m
.05361 .16043 L
.03134 .08766 L
.03189 .09257 L
F
.95 .5 .642 .1 k
.05361 .16043 m
.05151 .15038 L
.03081 .08253 L
.03134 .08766 L
F
.95 .5 .658 .1 k
.05151 .15038 m
.04954 .14026 L
.03031 .07736 L
.03081 .08253 L
F
.95 .5 .675 .1 k
.04954 .14026 m
.0478 .13055 L
.02987 .07242 L
.03031 .07736 L
F
.95 .5 .692 .1 k
.0478 .13055 m
.04636 .12185 L
.02951 .06801 L
.02987 .07242 L
F
.95 .5 .708 .1 k
.04636 .12185 m
.04528 .11485 L
.02924 .06446 L
.02951 .06801 L
F
.95 .5 .725 .1 k
.04528 .11485 m
.04462 .11028 L
.02907 .06215 L
.02924 .06446 L
F
.95 .5 .742 .1 k
.04462 .11028 m
.04439 .10868 L
.02901 .06134 L
.02907 .06215 L
F
.95 .5 .758 .1 k
.04439 .10868 m
.04462 .11028 L
.02907 .06215 L
.02901 .06134 L
F
.95 .5 .775 .1 k
.04462 .11028 m
.04528 .11485 L
.02924 .06446 L
.02907 .06215 L
F
.95 .5 .792 .1 k
.04528 .11485 m
.04636 .12185 L
.02951 .06801 L
.02924 .06446 L
F
.95 .5 .808 .1 k
.04636 .12185 m
.0478 .13055 L
.02987 .07242 L
.02951 .06801 L
F
.95 .5 .825 .1 k
.0478 .13055 m
.04954 .14026 L
.03031 .07736 L
.02987 .07242 L
F
.95 .5 .842 .1 k
.04954 .14026 m
.05151 .15038 L
.03081 .08253 L
.03031 .07736 L
F
.95 .5 .858 .1 k
.05151 .15038 m
.05361 .16043 L
.03134 .08766 L
.03081 .08253 L
F
.95 .5 .875 .1 k
.05361 .16043 m
.05576 .17002 L
.03189 .09257 L
.03134 .08766 L
F
.95 .5 .892 .1 k
.05576 .17002 m
.05787 .17884 L
.03242 .09709 L
.03189 .09257 L
F
.95 .5 .908 .1 k
.05787 .17884 m
.05983 .18665 L
.03291 .10111 L
.03242 .09709 L
F
.95 .5 .925 .1 k
.05983 .18665 m
.06157 .19327 L
.03335 .10452 L
.03291 .10111 L
F
.95 .5 .942 .1 k
.06157 .19327 m
.06301 .19856 L
.03372 .10725 L
.03335 .10452 L
F
.95 .5 .958 .1 k
.06301 .19856 m
.06409 .2024 L
.03399 .10923 L
.03372 .10725 L
F
.95 .5 .975 .1 k
.06409 .2024 m
.06475 .20474 L
.03416 .11044 L
.03399 .10923 L
F
.95 .5 .992 .1 k
.06475 .20474 m
.06498 .20552 L
.03422 .11085 L
.03416 .11044 L
F
.983 .5 .008 .1 k
.03422 .11085 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .025 .1 k
.03416 .11044 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .042 .1 k
.03399 .10923 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .058 .1 k
.03372 .10725 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .075 .1 k
.03335 .10452 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .092 .1 k
.03291 .10111 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .108 .1 k
.03242 .09709 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .125 .1 k
.03189 .09257 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .142 .1 k
.03134 .08766 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .158 .1 k
.03081 .08253 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .175 .1 k
.03031 .07736 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .192 .1 k
.02987 .07242 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .208 .1 k
.02951 .06801 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .225 .1 k
.02924 .06446 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .242 .1 k
.02907 .06215 m
.02901 .06134 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .258 .1 k
.02901 .06134 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .275 .1 k
.02907 .06215 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .292 .1 k
.02924 .06446 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .308 .1 k
.02951 .06801 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .325 .1 k
.02987 .07242 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .342 .1 k
.03031 .07736 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .358 .1 k
.03081 .08253 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .375 .1 k
.03134 .08766 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .392 .1 k
.03189 .09257 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .408 .1 k
.03242 .09709 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .425 .1 k
.03291 .10111 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .442 .1 k
.03335 .10452 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .458 .1 k
.03372 .10725 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .475 .1 k
.03399 .10923 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .492 .1 k
.03416 .11044 m
.03422 .11085 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .508 .1 k
.03422 .11085 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .525 .1 k
.03416 .11044 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .542 .1 k
.03399 .10923 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .558 .1 k
.03372 .10725 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .575 .1 k
.03335 .10452 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .592 .1 k
.03291 .10111 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .608 .1 k
.03242 .09709 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .625 .1 k
.03189 .09257 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .642 .1 k
.03134 .08766 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .658 .1 k
.03081 .08253 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .675 .1 k
.03031 .07736 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .692 .1 k
.02987 .07242 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .708 .1 k
.02951 .06801 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .725 .1 k
.02924 .06446 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .742 .1 k
.02907 .06215 m
.02901 .06134 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .758 .1 k
.02901 .06134 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .775 .1 k
.02907 .06215 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .792 .1 k
.02924 .06446 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .808 .1 k
.02951 .06801 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .825 .1 k
.02987 .07242 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .842 .1 k
.03031 .07736 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .858 .1 k
.03081 .08253 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .875 .1 k
.03134 .08766 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .892 .1 k
.03189 .09257 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .908 .1 k
.03242 .09709 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .925 .1 k
.03291 .10111 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .942 .1 k
.03335 .10452 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .958 .1 k
.03372 .10725 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .975 .1 k
.03399 .10923 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
F
.983 .5 .992 .1 k
.03416 .11044 m
.03422 .11085 L
.02381 .01184 L
.02381 .01184 L
F
0 g
.5 Mabswid
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03422 .11085 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03416 .11044 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03399 .10923 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03372 .10725 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03335 .10452 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03291 .10111 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03242 .09709 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03189 .09257 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03134 .08766 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.03081 .08253 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.03031 .07736 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02987 .07242 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02951 .06801 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02924 .06446 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02901 .06134 L
.02907 .06215 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02901 .06134 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02907 .06215 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02924 .06446 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.02951 .06801 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.02987 .07242 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03031 .07736 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03081 .08253 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03134 .08766 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03189 .09257 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03242 .09709 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03291 .10111 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03335 .10452 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03372 .10725 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03399 .10923 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03422 .11085 L
.03416 .11044 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03422 .11085 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03416 .11044 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03399 .10923 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03372 .10725 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03335 .10452 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03291 .10111 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03242 .09709 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03189 .09257 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03134 .08766 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.03081 .08253 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.03031 .07736 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02987 .07242 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02951 .06801 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02924 .06446 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02901 .06134 L
.02907 .06215 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02907 .06215 L
.02901 .06134 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02924 .06446 L
.02907 .06215 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02951 .06801 L
.02924 .06446 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.02987 .07242 L
.02951 .06801 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03031 .07736 L
.02987 .07242 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03081 .08253 L
.03031 .07736 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03134 .08766 L
.03081 .08253 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03189 .09257 L
.03134 .08766 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03242 .09709 L
.03189 .09257 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03291 .10111 L
.03242 .09709 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03335 .10452 L
.03291 .10111 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03372 .10725 L
.03335 .10452 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03399 .10923 L
.03372 .10725 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03416 .11044 L
.03399 .10923 L
.02381 .01184 L
s
.02381 .01184 m
.02381 .01184 L
.03422 .11085 L
.03416 .11044 L
.02381 .01184 L
s
.03422 .11085 m
.03416 .11044 L
.06475 .20474 L
.06498 .20552 L
.03422 .11085 L
s
.03416 .11044 m
.03399 .10923 L
.06409 .2024 L
.06475 .20474 L
.03416 .11044 L
s
.03399 .10923 m
.03372 .10725 L
.06301 .19856 L
.06409 .2024 L
.03399 .10923 L
s
.03372 .10725 m
.03335 .10452 L
.06157 .19327 L
.06301 .19856 L
.03372 .10725 L
s
.03335 .10452 m
.03291 .10111 L
.05983 .18665 L
.06157 .19327 L
.03335 .10452 L
s
.03291 .10111 m
.03242 .09709 L
.05787 .17884 L
.05983 .18665 L
.03291 .10111 L
s
.03242 .09709 m
.03189 .09257 L
.05576 .17002 L
.05787 .17884 L
.03242 .09709 L
s
.03189 .09257 m
.03134 .08766 L
.05361 .16043 L
.05576 .17002 L
.03189 .09257 L
s
.03134 .08766 m
.03081 .08253 L
.05151 .15038 L
.05361 .16043 L
.03134 .08766 L
s
.03081 .08253 m
.03031 .07736 L
.04954 .14026 L
.05151 .15038 L
.03081 .08253 L
s
.03031 .07736 m
.02987 .07242 L
.0478 .13055 L
.04954 .14026 L
.03031 .07736 L
s
.02987 .07242 m
.02951 .06801 L
.04636 .12185 L
.0478 .13055 L
.02987 .07242 L
s
.02951 .06801 m
.02924 .06446 L
.04528 .11485 L
.04636 .12185 L
.02951 .06801 L
s
.02924 .06446 m
.02907 .06215 L
.04462 .11028 L
.04528 .11485 L
.02924 .06446 L
s
.02907 .06215 m
.02901 .06134 L
.04439 .10868 L
.04462 .11028 L
.02907 .06215 L
s
.02901 .06134 m
.02907 .06215 L
.04462 .11028 L
.04439 .10868 L
.02901 .06134 L
s
.02907 .06215 m
.02924 .06446 L
.04528 .11485 L
.04462 .11028 L
.02907 .06215 L
s
.02924 .06446 m
.02951 .06801 L
.04636 .12185 L
.04528 .11485 L
.02924 .06446 L
s
.02951 .06801 m
.02987 .07242 L
.0478 .13055 L
.04636 .12185 L
.02951 .06801 L
s
.02987 .07242 m
.03031 .07736 L
.04954 .14026 L
.0478 .13055 L
.02987 .07242 L
s
.03031 .07736 m
.03081 .08253 L
.05151 .15038 L
.04954 .14026 L
.03031 .07736 L
s
.03081 .08253 m
.03134 .08766 L
.05361 .16043 L
.05151 .15038 L
.03081 .08253 L
s
.03134 .08766 m
.03189 .09257 L
.05576 .17002 L
.05361 .16043 L
.03134 .08766 L
s
.03189 .09257 m
.03242 .09709 L
.05787 .17884 L
.05576 .17002 L
.03189 .09257 L
s
.03242 .09709 m
.03291 .10111 L
.05983 .18665 L
.05787 .17884 L
.03242 .09709 L
s
.03291 .10111 m
.03335 .10452 L
.06157 .19327 L
.05983 .18665 L
.03291 .10111 L
s
.03335 .10452 m
.03372 .10725 L
.06301 .19856 L
.06157 .19327 L
.03335 .10452 L
s
.03372 .10725 m
.03399 .10923 L
.06409 .2024 L
.06301 .19856 L
.03372 .10725 L
s
.03399 .10923 m
.03416 .11044 L
.06475 .20474 L
.06409 .2024 L
.03399 .10923 L
s
.03416 .11044 m
.03422 .11085 L
.06498 .20552 L
.06475 .20474 L
.03416 .11044 L
s
.03422 .11085 m
.03416 .11044 L
.06475 .20474 L
.06498 .20552 L
.03422 .11085 L
s
.03416 .11044 m
.03399 .10923 L
.06409 .2024 L
.06475 .20474 L
.03416 .11044 L
s
.03399 .10923 m
.03372 .10725 L
.06301 .19856 L
.06409 .2024 L
.03399 .10923 L
s
.03372 .10725 m
.03335 .10452 L
.06157 .19327 L
.06301 .19856 L
.03372 .10725 L
s
.03335 .10452 m
.03291 .10111 L
.05983 .18665 L
.06157 .19327 L
.03335 .10452 L
s
.03291 .10111 m
.03242 .09709 L
.05787 .17884 L
.05983 .18665 L
.03291 .10111 L
s
.03242 .09709 m
.03189 .09257 L
.05576 .17002 L
.05787 .17884 L
.03242 .09709 L
s
.03189 .09257 m
.03134 .08766 L
.05361 .16043 L
.05576 .17002 L
.03189 .09257 L
s
.03134 .08766 m
.03081 .08253 L
.05151 .15038 L
.05361 .16043 L
.03134 .08766 L
s
.03081 .08253 m
.03031 .07736 L
.04954 .14026 L
.05151 .15038 L
.03081 .08253 L
s
.03031 .07736 m
.02987 .07242 L
.0478 .13055 L
.04954 .14026 L
.03031 .07736 L
s
.02987 .07242 m
.02951 .06801 L
.04636 .12185 L
.0478 .13055 L
.02987 .07242 L
s
.02951 .06801 m
.02924 .06446 L
.04528 .11485 L
.04636 .12185 L
.02951 .06801 L
s
.02924 .06446 m
.02907 .06215 L
.04462 .11028 L
.04528 .11485 L
.02924 .06446 L
s
.02907 .06215 m
.02901 .06134 L
.04439 .10868 L
.04462 .11028 L
.02907 .06215 L
s
.02901 .06134 m
.02907 .06215 L
.04462 .11028 L
.04439 .10868 L
.02901 .06134 L
s
.02907 .06215 m
.02924 .06446 L
.04528 .11485 L
.04462 .11028 L
.02907 .06215 L
s
.02924 .06446 m
.02951 .06801 L
.04636 .12185 L
.04528 .11485 L
.02924 .06446 L
s
.02951 .06801 m
.02987 .07242 L
.0478 .13055 L
.04636 .12185 L
.02951 .06801 L
s
.02987 .07242 m
.03031 .07736 L
.04954 .14026 L
.0478 .13055 L
.02987 .07242 L
s
.03031 .07736 m
.03081 .08253 L
.05151 .15038 L
.04954 .14026 L
.03031 .07736 L
s
.03081 .08253 m
.03134 .08766 L
.05361 .16043 L
.05151 .15038 L
.03081 .08253 L
s
.03134 .08766 m
.03189 .09257 L
.05576 .17002 L
.05361 .16043 L
.03134 .08766 L
s
.03189 .09257 m
.03242 .09709 L
.05787 .17884 L
.05576 .17002 L
.03189 .09257 L
s
.03242 .09709 m
.03291 .10111 L
.05983 .18665 L
.05787 .17884 L
.03242 .09709 L
s
.03291 .10111 m
.03335 .10452 L
.06157 .19327 L
.05983 .18665 L
.03291 .10111 L
s
.03335 .10452 m
.03372 .10725 L
.06301 .19856 L
.06157 .19327 L
.03335 .10452 L
s
.03372 .10725 m
.03399 .10923 L
.06409 .2024 L
.06301 .19856 L
.03372 .10725 L
s
.03399 .10923 m
.03416 .11044 L
.06475 .20474 L
.06409 .2024 L
.03399 .10923 L
s
.03416 .11044 m
.03422 .11085 L
.06498 .20552 L
.06475 .20474 L
.03416 .11044 L
s
.06498 .20552 m
.06475 .20474 L
.11426 .29063 L
.11475 .29174 L
.06498 .20552 L
s
.06475 .20474 m
.06409 .2024 L
.11279 .28732 L
.11426 .29063 L
.06475 .20474 L
s
.06409 .2024 m
.06301 .19856 L
.11041 .28186 L
.11279 .28732 L
.06409 .2024 L
s
.06301 .19856 m
.06157 .19327 L
.10723 .27434 L
.11041 .28186 L
.06301 .19856 L
s
.06157 .19327 m
.05983 .18665 L
.10339 .2649 L
.10723 .27434 L
.06157 .19327 L
s
.05983 .18665 m
.05787 .17884 L
.09904 .25373 L
.10339 .2649 L
.05983 .18665 L
s
.05787 .17884 m
.05576 .17002 L
.09439 .24107 L
.09904 .25373 L
.05787 .17884 L
s
.05576 .17002 m
.05361 .16043 L
.08964 .22726 L
.09439 .24107 L
.05576 .17002 L
s
.05361 .16043 m
.05151 .15038 L
.08499 .21272 L
.08964 .22726 L
.05361 .16043 L
s
.05151 .15038 m
.04954 .14026 L
.08065 .19802 L
.08499 .21272 L
.05151 .15038 L
s
.04954 .14026 m
.0478 .13055 L
.0768 .18386 L
.08065 .19802 L
.04954 .14026 L
s
.0478 .13055 m
.04636 .12185 L
.07362 .17114 L
.0768 .18386 L
.0478 .13055 L
s
.04636 .12185 m
.04528 .11485 L
.07125 .16087 L
.07362 .17114 L
.04636 .12185 L
s
.04528 .11485 m
.04462 .11028 L
.06978 .15414 L
.07125 .16087 L
.04528 .11485 L
s
.04462 .11028 m
.04439 .10868 L
.06928 .15179 L
.06978 .15414 L
.04462 .11028 L
s
.04439 .10868 m
.04462 .11028 L
.06978 .15414 L
.06928 .15179 L
.04439 .10868 L
s
.04462 .11028 m
.04528 .11485 L
.07125 .16087 L
.06978 .15414 L
.04462 .11028 L
s
.04528 .11485 m
.04636 .12185 L
.07362 .17114 L
.07125 .16087 L
.04528 .11485 L
s
.04636 .12185 m
.0478 .13055 L
.0768 .18386 L
.07362 .17114 L
.04636 .12185 L
s
.0478 .13055 m
.04954 .14026 L
.08065 .19802 L
.0768 .18386 L
.0478 .13055 L
s
.04954 .14026 m
.05151 .15038 L
.08499 .21272 L
.08065 .19802 L
.04954 .14026 L
s
.05151 .15038 m
.05361 .16043 L
.08964 .22726 L
.08499 .21272 L
.05151 .15038 L
s
.05361 .16043 m
.05576 .17002 L
.09439 .24107 L
.08964 .22726 L
.05361 .16043 L
s
.05576 .17002 m
.05787 .17884 L
.09904 .25373 L
.09439 .24107 L
.05576 .17002 L
s
.05787 .17884 m
.05983 .18665 L
.10339 .2649 L
.09904 .25373 L
.05787 .17884 L
s
.05983 .18665 m
.06157 .19327 L
.10723 .27434 L
.10339 .2649 L
.05983 .18665 L
s
.06157 .19327 m
.06301 .19856 L
.11041 .28186 L
.10723 .27434 L
.06157 .19327 L
s
.06301 .19856 m
.06409 .2024 L
.11279 .28732 L
.11041 .28186 L
.06301 .19856 L
s
.06409 .2024 m
.06475 .20474 L
.11426 .29063 L
.11279 .28732 L
.06409 .2024 L
s
.06475 .20474 m
.06498 .20552 L
.11475 .29174 L
.11426 .29063 L
.06475 .20474 L
s
.06498 .20552 m
.06475 .20474 L
.11426 .29063 L
.11475 .29174 L
.06498 .20552 L
s
.06475 .20474 m
.06409 .2024 L
.11279 .28732 L
.11426 .29063 L
.06475 .20474 L
s
.06409 .2024 m
.06301 .19856 L
.11041 .28186 L
.11279 .28732 L
.06409 .2024 L
s
.06301 .19856 m
.06157 .19327 L
.10723 .27434 L
.11041 .28186 L
.06301 .19856 L
s
.06157 .19327 m
.05983 .18665 L
.10339 .2649 L
.10723 .27434 L
.06157 .19327 L
s
.05983 .18665 m
.05787 .17884 L
.09904 .25373 L
.10339 .2649 L
.05983 .18665 L
s
.05787 .17884 m
.05576 .17002 L
.09439 .24107 L
.09904 .25373 L
.05787 .17884 L
s
.05576 .17002 m
.05361 .16043 L
.08964 .22726 L
.09439 .24107 L
.05576 .17002 L
s
.05361 .16043 m
.05151 .15038 L
.08499 .21272 L
.08964 .22726 L
.05361 .16043 L
s
.05151 .15038 m
.04954 .14026 L
.08065 .19802 L
.08499 .21272 L
.05151 .15038 L
s
.04954 .14026 m
.0478 .13055 L
.0768 .18386 L
.08065 .19802 L
.04954 .14026 L
s
.0478 .13055 m
.04636 .12185 L
.07362 .17114 L
.0768 .18386 L
.0478 .13055 L
s
.04636 .12185 m
.04528 .11485 L
.07125 .16087 L
.07362 .17114 L
.04636 .12185 L
s
.04528 .11485 m
.04462 .11028 L
.06978 .15414 L
.07125 .16087 L
.04528 .11485 L
s
.04462 .11028 m
.04439 .10868 L
.06928 .15179 L
.06978 .15414 L
.04462 .11028 L
s
.04439 .10868 m
.04462 .11028 L
.06978 .15414 L
.06928 .15179 L
.04439 .10868 L
s
.04462 .11028 m
.04528 .11485 L
.07125 .16087 L
.06978 .15414 L
.04462 .11028 L
s
.04528 .11485 m
.04636 .12185 L
.07362 .17114 L
.07125 .16087 L
.04528 .11485 L
s
.04636 .12185 m
.0478 .13055 L
.0768 .18386 L
.07362 .17114 L
.04636 .12185 L
s
.0478 .13055 m
.04954 .14026 L
.08065 .19802 L
.0768 .18386 L
.0478 .13055 L
s
.04954 .14026 m
.05151 .15038 L
.08499 .21272 L
.08065 .19802 L
.04954 .14026 L
s
.05151 .15038 m
.05361 .16043 L
.08964 .22726 L
.08499 .21272 L
.05151 .15038 L
s
.05361 .16043 m
.05576 .17002 L
.09439 .24107 L
.08964 .22726 L
.05361 .16043 L
s
.05576 .17002 m
.05787 .17884 L
.09904 .25373 L
.09439 .24107 L
.05576 .17002 L
s
.05787 .17884 m
.05983 .18665 L
.10339 .2649 L
.09904 .25373 L
.05787 .17884 L
s
.05983 .18665 m
.06157 .19327 L
.10723 .27434 L
.10339 .2649 L
.05983 .18665 L
s
.06157 .19327 m
.06301 .19856 L
.11041 .28186 L
.10723 .27434 L
.06157 .19327 L
s
.06301 .19856 m
.06409 .2024 L
.11279 .28732 L
.11041 .28186 L
.06301 .19856 L
s
.06409 .2024 m
.06475 .20474 L
.11426 .29063 L
.11279 .28732 L
.06409 .2024 L
s
.06475 .20474 m
.06498 .20552 L
.11475 .29174 L
.11426 .29063 L
.06475 .20474 L
s
.11475 .29174 m
.11426 .29063 L
.18051 .36436 L
.18137 .36572 L
.11475 .29174 L
s
.11426 .29063 m
.11279 .28732 L
.17796 .3603 L
.18051 .36436 L
.11426 .29063 L
s
.11279 .28732 m
.11041 .28186 L
.17384 .3536 L
.17796 .3603 L
.11279 .28732 L
s
.11041 .28186 m
.10723 .27434 L
.16833 .34433 L
.17384 .3536 L
.11041 .28186 L
s
.10723 .27434 m
.10339 .2649 L
.16167 .33264 L
.16833 .34433 L
.10723 .27434 L
s
.10339 .2649 m
.09904 .25373 L
.15415 .31873 L
.16167 .33264 L
.10339 .2649 L
s
.09904 .25373 m
.09439 .24107 L
.14609 .30289 L
.15415 .31873 L
.09904 .25373 L
s
.09439 .24107 m
.08964 .22726 L
.13786 .28551 L
.14609 .30289 L
.09439 .24107 L
s
.08964 .22726 m
.08499 .21272 L
.12981 .2671 L
.13786 .28551 L
.08964 .22726 L
s
.08499 .21272 m
.08065 .19802 L
.12228 .24838 L
.12981 .2671 L
.08499 .21272 L
s
.08065 .19802 m
.0768 .18386 L
.11562 .23025 L
.12228 .24838 L
.08065 .19802 L
s
.0768 .18386 m
.07362 .17114 L
.11011 .21386 L
.11562 .23025 L
.0768 .18386 L
s
.07362 .17114 m
.07125 .16087 L
.10599 .20058 L
.11011 .21386 L
.07362 .17114 L
s
.07125 .16087 m
.06978 .15414 L
.10345 .19184 L
.10599 .20058 L
.07125 .16087 L
s
.06978 .15414 m
.06928 .15179 L
.10259 .18878 L
.10345 .19184 L
.06978 .15414 L
s
.06928 .15179 m
.06978 .15414 L
.10345 .19184 L
.10259 .18878 L
.06928 .15179 L
s
.06978 .15414 m
.07125 .16087 L
.10599 .20058 L
.10345 .19184 L
.06978 .15414 L
s
.07125 .16087 m
.07362 .17114 L
.11011 .21386 L
.10599 .20058 L
.07125 .16087 L
s
.07362 .17114 m
.0768 .18386 L
.11562 .23025 L
.11011 .21386 L
.07362 .17114 L
s
.0768 .18386 m
.08065 .19802 L
.12228 .24838 L
.11562 .23025 L
.0768 .18386 L
s
.08065 .19802 m
.08499 .21272 L
.12981 .2671 L
.12228 .24838 L
.08065 .19802 L
s
.08499 .21272 m
.08964 .22726 L
.13786 .28551 L
.12981 .2671 L
.08499 .21272 L
s
.08964 .22726 m
.09439 .24107 L
.14609 .30289 L
.13786 .28551 L
.08964 .22726 L
s
.09439 .24107 m
.09904 .25373 L
.15415 .31873 L
.14609 .30289 L
.09439 .24107 L
s
.09904 .25373 m
.10339 .2649 L
.16167 .33264 L
.15415 .31873 L
.09904 .25373 L
s
.10339 .2649 m
.10723 .27434 L
.16833 .34433 L
.16167 .33264 L
.10339 .2649 L
s
.10723 .27434 m
.11041 .28186 L
.17384 .3536 L
.16833 .34433 L
.10723 .27434 L
s
.11041 .28186 m
.11279 .28732 L
.17796 .3603 L
.17384 .3536 L
.11041 .28186 L
s
.11279 .28732 m
.11426 .29063 L
.18051 .36436 L
.17796 .3603 L
.11279 .28732 L
s
.11426 .29063 m
.11475 .29174 L
.18137 .36572 L
.18051 .36436 L
.11426 .29063 L
s
.11475 .29174 m
.11426 .29063 L
.18051 .36436 L
.18137 .36572 L
.11475 .29174 L
s
.11426 .29063 m
.11279 .28732 L
.17796 .3603 L
.18051 .36436 L
.11426 .29063 L
s
.11279 .28732 m
.11041 .28186 L
.17384 .3536 L
.17796 .3603 L
.11279 .28732 L
s
.11041 .28186 m
.10723 .27434 L
.16833 .34433 L
.17384 .3536 L
.11041 .28186 L
s
.10723 .27434 m
.10339 .2649 L
.16167 .33264 L
.16833 .34433 L
.10723 .27434 L
s
.10339 .2649 m
.09904 .25373 L
.15415 .31873 L
.16167 .33264 L
.10339 .2649 L
s
.09904 .25373 m
.09439 .24107 L
.14609 .30289 L
.15415 .31873 L
.09904 .25373 L
s
.09439 .24107 m
.08964 .22726 L
.13786 .28551 L
.14609 .30289 L
.09439 .24107 L
s
.08964 .22726 m
.08499 .21272 L
.12981 .2671 L
.13786 .28551 L
.08964 .22726 L
s
.08499 .21272 m
.08065 .19802 L
.12228 .24838 L
.12981 .2671 L
.08499 .21272 L
s
.08065 .19802 m
.0768 .18386 L
.11562 .23025 L
.12228 .24838 L
.08065 .19802 L
s
.0768 .18386 m
.07362 .17114 L
.11011 .21386 L
.11562 .23025 L
.0768 .18386 L
s
.07362 .17114 m
.07125 .16087 L
.10599 .20058 L
.11011 .21386 L
.07362 .17114 L
s
.07125 .16087 m
.06978 .15414 L
.10345 .19184 L
.10599 .20058 L
.07125 .16087 L
s
.06978 .15414 m
.06928 .15179 L
.10259 .18878 L
.10345 .19184 L
.06978 .15414 L
s
.06928 .15179 m
.06978 .15414 L
.10345 .19184 L
.10259 .18878 L
.06928 .15179 L
s
.06978 .15414 m
.07125 .16087 L
.10599 .20058 L
.10345 .19184 L
.06978 .15414 L
s
.07125 .16087 m
.07362 .17114 L
.11011 .21386 L
.10599 .20058 L
.07125 .16087 L
s
.07362 .17114 m
.0768 .18386 L
.11562 .23025 L
.11011 .21386 L
.07362 .17114 L
s
.0768 .18386 m
.08065 .19802 L
.12228 .24838 L
.11562 .23025 L
.0768 .18386 L
s
.08065 .19802 m
.08499 .21272 L
.12981 .2671 L
.12228 .24838 L
.08065 .19802 L
s
.08499 .21272 m
.08964 .22726 L
.13786 .28551 L
.12981 .2671 L
.08499 .21272 L
s
.08964 .22726 m
.09439 .24107 L
.14609 .30289 L
.13786 .28551 L
.08964 .22726 L
s
.09439 .24107 m
.09904 .25373 L
.15415 .31873 L
.14609 .30289 L
.09439 .24107 L
s
.09904 .25373 m
.10339 .2649 L
.16167 .33264 L
.15415 .31873 L
.09904 .25373 L
s
.10339 .2649 m
.10723 .27434 L
.16833 .34433 L
.16167 .33264 L
.10339 .2649 L
s
.10723 .27434 m
.11041 .28186 L
.17384 .3536 L
.16833 .34433 L
.10723 .27434 L
s
.11041 .28186 m
.11279 .28732 L
.17796 .3603 L
.17384 .3536 L
.11041 .28186 L
s
.11279 .28732 m
.11426 .29063 L
.18051 .36436 L
.17796 .3603 L
.11279 .28732 L
s
.11426 .29063 m
.11475 .29174 L
.18137 .36572 L
.18051 .36436 L
.11426 .29063 L
s
.18137 .36572 m
.18051 .36436 L
.2606 .42273 L
.2619 .42423 L
.18137 .36572 L
s
.18051 .36436 m
.17796 .3603 L
.25676 .41821 L
.2606 .42273 L
.18051 .36436 L
s
.17796 .3603 m
.17384 .3536 L
.25054 .41073 L
.25676 .41821 L
.17796 .3603 L
s
.17384 .3536 m
.16833 .34433 L
.24221 .40033 L
.25054 .41073 L
.17384 .3536 L
s
.16833 .34433 m
.16167 .33264 L
.23214 .38712 L
.24221 .40033 L
.16833 .34433 L
s
.16167 .33264 m
.15415 .31873 L
.22077 .37129 L
.23214 .38712 L
.16167 .33264 L
s
.15415 .31873 m
.14609 .30289 L
.2086 .35311 L
.22077 .37129 L
.15415 .31873 L
s
.14609 .30289 m
.13786 .28551 L
.19616 .33298 L
.2086 .35311 L
.14609 .30289 L
s
.13786 .28551 m
.12981 .2671 L
.18399 .31149 L
.19616 .33298 L
.13786 .28551 L
s
.12981 .2671 m
.12228 .24838 L
.17262 .28944 L
.18399 .31149 L
.12981 .2671 L
s
.12228 .24838 m
.11562 .23025 L
.16255 .26792 L
.17262 .28944 L
.12228 .24838 L
s
.11562 .23025 m
.11011 .21386 L
.15423 .24832 L
.16255 .26792 L
.11562 .23025 L
s
.11011 .21386 m
.10599 .20058 L
.148 .23233 L
.15423 .24832 L
.11011 .21386 L
s
.10599 .20058 m
.10345 .19184 L
.14416 .22175 L
.148 .23233 L
.10599 .20058 L
s
.10345 .19184 m
.10259 .18878 L
.14286 .21804 L
.14416 .22175 L
.10345 .19184 L
s
.10259 .18878 m
.10345 .19184 L
.14416 .22175 L
.14286 .21804 L
.10259 .18878 L
s
.10345 .19184 m
.10599 .20058 L
.148 .23233 L
.14416 .22175 L
.10345 .19184 L
s
.10599 .20058 m
.11011 .21386 L
.15423 .24832 L
.148 .23233 L
.10599 .20058 L
s
.11011 .21386 m
.11562 .23025 L
.16255 .26792 L
.15423 .24832 L
.11011 .21386 L
s
.11562 .23025 m
.12228 .24838 L
.17262 .28944 L
.16255 .26792 L
.11562 .23025 L
s
.12228 .24838 m
.12981 .2671 L
.18399 .31149 L
.17262 .28944 L
.12228 .24838 L
s
.12981 .2671 m
.13786 .28551 L
.19616 .33298 L
.18399 .31149 L
.12981 .2671 L
s
.13786 .28551 m
.14609 .30289 L
.2086 .35311 L
.19616 .33298 L
.13786 .28551 L
s
.14609 .30289 m
.15415 .31873 L
.22077 .37129 L
.2086 .35311 L
.14609 .30289 L
s
.15415 .31873 m
.16167 .33264 L
.23214 .38712 L
.22077 .37129 L
.15415 .31873 L
s
.16167 .33264 m
.16833 .34433 L
.24221 .40033 L
.23214 .38712 L
.16167 .33264 L
s
.16833 .34433 m
.17384 .3536 L
.25054 .41073 L
.24221 .40033 L
.16833 .34433 L
s
.17384 .3536 m
.17796 .3603 L
.25676 .41821 L
.25054 .41073 L
.17384 .3536 L
s
.17796 .3603 m
.18051 .36436 L
.2606 .42273 L
.25676 .41821 L
.17796 .3603 L
s
.18051 .36436 m
.18137 .36572 L
.2619 .42423 L
.2606 .42273 L
.18051 .36436 L
s
.18137 .36572 m
.18051 .36436 L
.2606 .42273 L
.2619 .42423 L
.18137 .36572 L
s
.18051 .36436 m
.17796 .3603 L
.25676 .41821 L
.2606 .42273 L
.18051 .36436 L
s
.17796 .3603 m
.17384 .3536 L
.25054 .41073 L
.25676 .41821 L
.17796 .3603 L
s
.17384 .3536 m
.16833 .34433 L
.24221 .40033 L
.25054 .41073 L
.17384 .3536 L
s
.16833 .34433 m
.16167 .33264 L
.23214 .38712 L
.24221 .40033 L
.16833 .34433 L
s
.16167 .33264 m
.15415 .31873 L
.22077 .37129 L
.23214 .38712 L
.16167 .33264 L
s
.15415 .31873 m
.14609 .30289 L
.2086 .35311 L
.22077 .37129 L
.15415 .31873 L
s
.14609 .30289 m
.13786 .28551 L
.19616 .33298 L
.2086 .35311 L
.14609 .30289 L
s
.13786 .28551 m
.12981 .2671 L
.18399 .31149 L
.19616 .33298 L
.13786 .28551 L
s
.12981 .2671 m
.12228 .24838 L
.17262 .28944 L
.18399 .31149 L
.12981 .2671 L
s
.12228 .24838 m
.11562 .23025 L
.16255 .26792 L
.17262 .28944 L
.12228 .24838 L
s
.11562 .23025 m
.11011 .21386 L
.15423 .24832 L
.16255 .26792 L
.11562 .23025 L
s
.11011 .21386 m
.10599 .20058 L
.148 .23233 L
.15423 .24832 L
.11011 .21386 L
s
.10599 .20058 m
.10345 .19184 L
.14416 .22175 L
.148 .23233 L
.10599 .20058 L
s
.10345 .19184 m
.10259 .18878 L
.14286 .21804 L
.14416 .22175 L
.10345 .19184 L
s
.10259 .18878 m
.10345 .19184 L
.14416 .22175 L
.14286 .21804 L
.10259 .18878 L
s
.10345 .19184 m
.10599 .20058 L
.148 .23233 L
.14416 .22175 L
.10345 .19184 L
s
.10599 .20058 m
.11011 .21386 L
.15423 .24832 L
.148 .23233 L
.10599 .20058 L
s
.11011 .21386 m
.11562 .23025 L
.16255 .26792 L
.15423 .24832 L
.11011 .21386 L
s
.11562 .23025 m
.12228 .24838 L
.17262 .28944 L
.16255 .26792 L
.11562 .23025 L
s
.12228 .24838 m
.12981 .2671 L
.18399 .31149 L
.17262 .28944 L
.12228 .24838 L
s
.12981 .2671 m
.13786 .28551 L
.19616 .33298 L
.18399 .31149 L
.12981 .2671 L
s
.13786 .28551 m
.14609 .30289 L
.2086 .35311 L
.19616 .33298 L
.13786 .28551 L
s
.14609 .30289 m
.15415 .31873 L
.22077 .37129 L
.2086 .35311 L
.14609 .30289 L
s
.15415 .31873 m
.16167 .33264 L
.23214 .38712 L
.22077 .37129 L
.15415 .31873 L
s
.16167 .33264 m
.16833 .34433 L
.24221 .40033 L
.23214 .38712 L
.16167 .33264 L
s
.16833 .34433 m
.17384 .3536 L
.25054 .41073 L
.24221 .40033 L
.16833 .34433 L
s
.17384 .3536 m
.17796 .3603 L
.25676 .41821 L
.25054 .41073 L
.17384 .3536 L
s
.17796 .3603 m
.18051 .36436 L
.2606 .42273 L
.25676 .41821 L
.17796 .3603 L
s
.18051 .36436 m
.18137 .36572 L
.2619 .42423 L
.2606 .42273 L
.18051 .36436 L
s
.2619 .42423 m
.2606 .42273 L
.35105 .46319 L
.35285 .46472 L
.2619 .42423 L
s
.2606 .42273 m
.25676 .41821 L
.34574 .45858 L
.35105 .46319 L
.2606 .42273 L
s
.25676 .41821 m
.25054 .41073 L
.33714 .45088 L
.34574 .45858 L
.25676 .41821 L
s
.25054 .41073 m
.24221 .40033 L
.32563 .44008 L
.33714 .45088 L
.25054 .41073 L
s
.24221 .40033 m
.23214 .38712 L
.31172 .42623 L
.32563 .44008 L
.24221 .40033 L
s
.23214 .38712 m
.22077 .37129 L
.29601 .40943 L
.31172 .42623 L
.23214 .38712 L
s
.22077 .37129 m
.2086 .35311 L
.27919 .38989 L
.29601 .40943 L
.22077 .37129 L
s
.2086 .35311 m
.19616 .33298 L
.26199 .36799 L
.27919 .38989 L
.2086 .35311 L
s
.19616 .33298 m
.18399 .31149 L
.24517 .34432 L
.26199 .36799 L
.19616 .33298 L
s
.18399 .31149 m
.17262 .28944 L
.22946 .31975 L
.24517 .34432 L
.18399 .31149 L
s
.17262 .28944 m
.16255 .26792 L
.21555 .2955 L
.22946 .31975 L
.17262 .28944 L
s
.16255 .26792 m
.15423 .24832 L
.20404 .27319 L
.21555 .2955 L
.16255 .26792 L
s
.15423 .24832 m
.148 .23233 L
.19544 .25483 L
.20404 .27319 L
.15423 .24832 L
s
.148 .23233 m
.14416 .22175 L
.19013 .2426 L
.19544 .25483 L
.148 .23233 L
s
.14416 .22175 m
.14286 .21804 L
.18833 .23828 L
.19013 .2426 L
.14416 .22175 L
s
.14286 .21804 m
.14416 .22175 L
.19013 .2426 L
.18833 .23828 L
.14286 .21804 L
s
.14416 .22175 m
.148 .23233 L
.19544 .25483 L
.19013 .2426 L
.14416 .22175 L
s
.148 .23233 m
.15423 .24832 L
.20404 .27319 L
.19544 .25483 L
.148 .23233 L
s
.15423 .24832 m
.16255 .26792 L
.21555 .2955 L
.20404 .27319 L
.15423 .24832 L
s
.16255 .26792 m
.17262 .28944 L
.22946 .31975 L
.21555 .2955 L
.16255 .26792 L
s
.17262 .28944 m
.18399 .31149 L
.24517 .34432 L
.22946 .31975 L
.17262 .28944 L
s
.18399 .31149 m
.19616 .33298 L
.26199 .36799 L
.24517 .34432 L
.18399 .31149 L
s
.19616 .33298 m
.2086 .35311 L
.27919 .38989 L
.26199 .36799 L
.19616 .33298 L
s
.2086 .35311 m
.22077 .37129 L
.29601 .40943 L
.27919 .38989 L
.2086 .35311 L
s
.22077 .37129 m
.23214 .38712 L
.31172 .42623 L
.29601 .40943 L
.22077 .37129 L
s
.23214 .38712 m
.24221 .40033 L
.32563 .44008 L
.31172 .42623 L
.23214 .38712 L
s
.24221 .40033 m
.25054 .41073 L
.33714 .45088 L
.32563 .44008 L
.24221 .40033 L
s
.25054 .41073 m
.25676 .41821 L
.34574 .45858 L
.33714 .45088 L
.25054 .41073 L
s
.25676 .41821 m
.2606 .42273 L
.35105 .46319 L
.34574 .45858 L
.25676 .41821 L
s
.2606 .42273 m
.2619 .42423 L
.35285 .46472 L
.35105 .46319 L
.2606 .42273 L
s
.2619 .42423 m
.2606 .42273 L
.35105 .46319 L
.35285 .46472 L
.2619 .42423 L
s
.2606 .42273 m
.25676 .41821 L
.34574 .45858 L
.35105 .46319 L
.2606 .42273 L
s
.25676 .41821 m
.25054 .41073 L
.33714 .45088 L
.34574 .45858 L
.25676 .41821 L
s
.25054 .41073 m
.24221 .40033 L
.32563 .44008 L
.33714 .45088 L
.25054 .41073 L
s
.24221 .40033 m
.23214 .38712 L
.31172 .42623 L
.32563 .44008 L
.24221 .40033 L
s
.23214 .38712 m
.22077 .37129 L
.29601 .40943 L
.31172 .42623 L
.23214 .38712 L
s
.22077 .37129 m
.2086 .35311 L
.27919 .38989 L
.29601 .40943 L
.22077 .37129 L
s
.2086 .35311 m
.19616 .33298 L
.26199 .36799 L
.27919 .38989 L
.2086 .35311 L
s
.19616 .33298 m
.18399 .31149 L
.24517 .34432 L
.26199 .36799 L
.19616 .33298 L
s
.18399 .31149 m
.17262 .28944 L
.22946 .31975 L
.24517 .34432 L
.18399 .31149 L
s
.17262 .28944 m
.16255 .26792 L
.21555 .2955 L
.22946 .31975 L
.17262 .28944 L
s
.16255 .26792 m
.15423 .24832 L
.20404 .27319 L
.21555 .2955 L
.16255 .26792 L
s
.15423 .24832 m
.148 .23233 L
.19544 .25483 L
.20404 .27319 L
.15423 .24832 L
s
.148 .23233 m
.14416 .22175 L
.19013 .2426 L
.19544 .25483 L
.148 .23233 L
s
.14416 .22175 m
.14286 .21804 L
.18833 .23828 L
.19013 .2426 L
.14416 .22175 L
s
.14286 .21804 m
.14416 .22175 L
.19013 .2426 L
.18833 .23828 L
.14286 .21804 L
s
.14416 .22175 m
.148 .23233 L
.19544 .25483 L
.19013 .2426 L
.14416 .22175 L
s
.148 .23233 m
.15423 .24832 L
.20404 .27319 L
.19544 .25483 L
.148 .23233 L
s
.15423 .24832 m
.16255 .26792 L
.21555 .2955 L
.20404 .27319 L
.15423 .24832 L
s
.16255 .26792 m
.17262 .28944 L
.22946 .31975 L
.21555 .2955 L
.16255 .26792 L
s
.17262 .28944 m
.18399 .31149 L
.24517 .34432 L
.22946 .31975 L
.17262 .28944 L
s
.18399 .31149 m
.19616 .33298 L
.26199 .36799 L
.24517 .34432 L
.18399 .31149 L
s
.19616 .33298 m
.2086 .35311 L
.27919 .38989 L
.26199 .36799 L
.19616 .33298 L
s
.2086 .35311 m
.22077 .37129 L
.29601 .40943 L
.27919 .38989 L
.2086 .35311 L
s
.22077 .37129 m
.23214 .38712 L
.31172 .42623 L
.29601 .40943 L
.22077 .37129 L
s
.23214 .38712 m
.24221 .40033 L
.32563 .44008 L
.31172 .42623 L
.23214 .38712 L
s
.24221 .40033 m
.25054 .41073 L
.33714 .45088 L
.32563 .44008 L
.24221 .40033 L
s
.25054 .41073 m
.25676 .41821 L
.34574 .45858 L
.33714 .45088 L
.25054 .41073 L
s
.25676 .41821 m
.2606 .42273 L
.35105 .46319 L
.34574 .45858 L
.25676 .41821 L
s
.2606 .42273 m
.2619 .42423 L
.35285 .46472 L
.35105 .46319 L
.2606 .42273 L
s
.35285 .46472 m
.35105 .46319 L
.44789 .484 L
.45022 .48542 L
.35285 .46472 L
s
.35105 .46319 m
.34574 .45858 L
.44101 .47969 L
.44789 .484 L
.35105 .46319 L
s
.34574 .45858 m
.33714 .45088 L
.42987 .47243 L
.44101 .47969 L
.34574 .45858 L
s
.33714 .45088 m
.32563 .44008 L
.41495 .46209 L
.42987 .47243 L
.33714 .45088 L
s
.32563 .44008 m
.31172 .42623 L
.39692 .44859 L
.41495 .46209 L
.32563 .44008 L
s
.31172 .42623 m
.29601 .40943 L
.37656 .43189 L
.39692 .44859 L
.31172 .42623 L
s
.29601 .40943 m
.27919 .38989 L
.35476 .4121 L
.37656 .43189 L
.29601 .40943 L
s
.27919 .38989 m
.26199 .36799 L
.33248 .3895 L
.35476 .4121 L
.27919 .38989 L
s
.26199 .36799 m
.24517 .34432 L
.31068 .36463 L
.33248 .3895 L
.26199 .36799 L
s
.24517 .34432 m
.22946 .31975 L
.29032 .33841 L
.31068 .36463 L
.24517 .34432 L
s
.22946 .31975 m
.21555 .2955 L
.27229 .31213 L
.29032 .33841 L
.22946 .31975 L
s
.21555 .2955 m
.20404 .27319 L
.25738 .28763 L
.27229 .31213 L
.21555 .2955 L
s
.20404 .27319 m
.19544 .25483 L
.24623 .26722 L
.25738 .28763 L
.20404 .27319 L
s
.19544 .25483 m
.19013 .2426 L
.23935 .2535 L
.24623 .26722 L
.19544 .25483 L
s
.19013 .2426 m
.18833 .23828 L
.23702 .24863 L
.23935 .2535 L
.19013 .2426 L
s
.18833 .23828 m
.19013 .2426 L
.23935 .2535 L
.23702 .24863 L
.18833 .23828 L
s
.19013 .2426 m
.19544 .25483 L
.24623 .26722 L
.23935 .2535 L
.19013 .2426 L
s
.19544 .25483 m
.20404 .27319 L
.25738 .28763 L
.24623 .26722 L
.19544 .25483 L
s
.20404 .27319 m
.21555 .2955 L
.27229 .31213 L
.25738 .28763 L
.20404 .27319 L
s
.21555 .2955 m
.22946 .31975 L
.29032 .33841 L
.27229 .31213 L
.21555 .2955 L
s
.22946 .31975 m
.24517 .34432 L
.31068 .36463 L
.29032 .33841 L
.22946 .31975 L
s
.24517 .34432 m
.26199 .36799 L
.33248 .3895 L
.31068 .36463 L
.24517 .34432 L
s
.26199 .36799 m
.27919 .38989 L
.35476 .4121 L
.33248 .3895 L
.26199 .36799 L
s
.27919 .38989 m
.29601 .40943 L
.37656 .43189 L
.35476 .4121 L
.27919 .38989 L
s
.29601 .40943 m
.31172 .42623 L
.39692 .44859 L
.37656 .43189 L
.29601 .40943 L
s
.31172 .42623 m
.32563 .44008 L
.41495 .46209 L
.39692 .44859 L
.31172 .42623 L
s
.32563 .44008 m
.33714 .45088 L
.42987 .47243 L
.41495 .46209 L
.32563 .44008 L
s
.33714 .45088 m
.34574 .45858 L
.44101 .47969 L
.42987 .47243 L
.33714 .45088 L
s
.34574 .45858 m
.35105 .46319 L
.44789 .484 L
.44101 .47969 L
.34574 .45858 L
s
.35105 .46319 m
.35285 .46472 L
.45022 .48542 L
.44789 .484 L
.35105 .46319 L
s
.35285 .46472 m
.35105 .46319 L
.44789 .484 L
.45022 .48542 L
.35285 .46472 L
s
.35105 .46319 m
.34574 .45858 L
.44101 .47969 L
.44789 .484 L
.35105 .46319 L
s
.34574 .45858 m
.33714 .45088 L
.42987 .47243 L
.44101 .47969 L
.34574 .45858 L
s
.33714 .45088 m
.32563 .44008 L
.41495 .46209 L
.42987 .47243 L
.33714 .45088 L
s
.32563 .44008 m
.31172 .42623 L
.39692 .44859 L
.41495 .46209 L
.32563 .44008 L
s
.31172 .42623 m
.29601 .40943 L
.37656 .43189 L
.39692 .44859 L
.31172 .42623 L
s
.29601 .40943 m
.27919 .38989 L
.35476 .4121 L
.37656 .43189 L
.29601 .40943 L
s
.27919 .38989 m
.26199 .36799 L
.33248 .3895 L
.35476 .4121 L
.27919 .38989 L
s
.26199 .36799 m
.24517 .34432 L
.31068 .36463 L
.33248 .3895 L
.26199 .36799 L
s
.24517 .34432 m
.22946 .31975 L
.29032 .33841 L
.31068 .36463 L
.24517 .34432 L
s
.22946 .31975 m
.21555 .2955 L
.27229 .31213 L
.29032 .33841 L
.22946 .31975 L
s
.21555 .2955 m
.20404 .27319 L
.25738 .28763 L
.27229 .31213 L
.21555 .2955 L
s
.20404 .27319 m
.19544 .25483 L
.24623 .26722 L
.25738 .28763 L
.20404 .27319 L
s
.19544 .25483 m
.19013 .2426 L
.23935 .2535 L
.24623 .26722 L
.19544 .25483 L
s
.19013 .2426 m
.18833 .23828 L
.23702 .24863 L
.23935 .2535 L
.19013 .2426 L
s
.18833 .23828 m
.19013 .2426 L
.23935 .2535 L
.23702 .24863 L
.18833 .23828 L
s
.19013 .2426 m
.19544 .25483 L
.24623 .26722 L
.23935 .2535 L
.19013 .2426 L
s
.19544 .25483 m
.20404 .27319 L
.25738 .28763 L
.24623 .26722 L
.19544 .25483 L
s
.20404 .27319 m
.21555 .2955 L
.27229 .31213 L
.25738 .28763 L
.20404 .27319 L
s
.21555 .2955 m
.22946 .31975 L
.29032 .33841 L
.27229 .31213 L
.21555 .2955 L
s
.22946 .31975 m
.24517 .34432 L
.31068 .36463 L
.29032 .33841 L
.22946 .31975 L
s
.24517 .34432 m
.26199 .36799 L
.33248 .3895 L
.31068 .36463 L
.24517 .34432 L
s
.26199 .36799 m
.27919 .38989 L
.35476 .4121 L
.33248 .3895 L
.26199 .36799 L
s
.27919 .38989 m
.29601 .40943 L
.37656 .43189 L
.35476 .4121 L
.27919 .38989 L
s
.29601 .40943 m
.31172 .42623 L
.39692 .44859 L
.37656 .43189 L
.29601 .40943 L
s
.31172 .42623 m
.32563 .44008 L
.41495 .46209 L
.39692 .44859 L
.31172 .42623 L
s
.32563 .44008 m
.33714 .45088 L
.42987 .47243 L
.41495 .46209 L
.32563 .44008 L
s
.33714 .45088 m
.34574 .45858 L
.44101 .47969 L
.42987 .47243 L
.33714 .45088 L
s
.34574 .45858 m
.35105 .46319 L
.44789 .484 L
.44101 .47969 L
.34574 .45858 L
s
.35105 .46319 m
.35285 .46472 L
.45022 .48542 L
.44789 .484 L
.35105 .46319 L
s
.45022 .48542 m
.44789 .484 L
.5469 .48427 L
.54978 .48542 L
.45022 .48542 L
s
.44789 .484 m
.44101 .47969 L
.53841 .48074 L
.5469 .48427 L
.44789 .484 L
s
.44101 .47969 m
.42987 .47243 L
.52466 .47465 L
.53841 .48074 L
.44101 .47969 L
s
.42987 .47243 m
.41495 .46209 L
.50627 .46571 L
.52466 .47465 L
.42987 .47243 L
s
.41495 .46209 m
.39692 .44859 L
.48403 .45365 L
.50627 .46571 L
.41495 .46209 L
s
.39692 .44859 m
.37656 .43189 L
.45892 .43822 L
.48403 .45365 L
.39692 .44859 L
s
.37656 .43189 m
.35476 .4121 L
.43203 .41935 L
.45892 .43822 L
.37656 .43189 L
s
.35476 .4121 m
.33248 .3895 L
.40454 .39718 L
.43203 .41935 L
.35476 .4121 L
s
.33248 .3895 m
.31068 .36463 L
.37765 .37215 L
.40454 .39718 L
.33248 .3895 L
s
.31068 .36463 m
.29032 .33841 L
.35254 .34514 L
.37765 .37215 L
.31068 .36463 L
s
.29032 .33841 m
.27229 .31213 L
.3303 .31753 L
.35254 .34514 L
.29032 .33841 L
s
.27229 .31213 m
.25738 .28763 L
.31191 .29131 L
.3303 .31753 L
.27229 .31213 L
s
.25738 .28763 m
.24623 .26722 L
.29816 .26914 L
.31191 .29131 L
.25738 .28763 L
s
.24623 .26722 m
.23935 .2535 L
.28967 .25403 L
.29816 .26914 L
.24623 .26722 L
s
.23935 .2535 m
.23702 .24863 L
.28679 .24863 L
.28967 .25403 L
.23935 .2535 L
s
.23702 .24863 m
.23935 .2535 L
.28967 .25403 L
.28679 .24863 L
.23702 .24863 L
s
.23935 .2535 m
.24623 .26722 L
.29816 .26914 L
.28967 .25403 L
.23935 .2535 L
s
.24623 .26722 m
.25738 .28763 L
.31191 .29131 L
.29816 .26914 L
.24623 .26722 L
s
.25738 .28763 m
.27229 .31213 L
.3303 .31753 L
.31191 .29131 L
.25738 .28763 L
s
.27229 .31213 m
.29032 .33841 L
.35254 .34514 L
.3303 .31753 L
.27229 .31213 L
s
.29032 .33841 m
.31068 .36463 L
.37765 .37215 L
.35254 .34514 L
.29032 .33841 L
s
.31068 .36463 m
.33248 .3895 L
.40454 .39718 L
.37765 .37215 L
.31068 .36463 L
s
.33248 .3895 m
.35476 .4121 L
.43203 .41935 L
.40454 .39718 L
.33248 .3895 L
s
.35476 .4121 m
.37656 .43189 L
.45892 .43822 L
.43203 .41935 L
.35476 .4121 L
s
.37656 .43189 m
.39692 .44859 L
.48403 .45365 L
.45892 .43822 L
.37656 .43189 L
s
.39692 .44859 m
.41495 .46209 L
.50627 .46571 L
.48403 .45365 L
.39692 .44859 L
s
.41495 .46209 m
.42987 .47243 L
.52466 .47465 L
.50627 .46571 L
.41495 .46209 L
s
.42987 .47243 m
.44101 .47969 L
.53841 .48074 L
.52466 .47465 L
.42987 .47243 L
s
.44101 .47969 m
.44789 .484 L
.5469 .48427 L
.53841 .48074 L
.44101 .47969 L
s
.44789 .484 m
.45022 .48542 L
.54978 .48542 L
.5469 .48427 L
.44789 .484 L
s
.45022 .48542 m
.44789 .484 L
.5469 .48427 L
.54978 .48542 L
.45022 .48542 L
s
.44789 .484 m
.44101 .47969 L
.53841 .48074 L
.5469 .48427 L
.44789 .484 L
s
.44101 .47969 m
.42987 .47243 L
.52466 .47465 L
.53841 .48074 L
.44101 .47969 L
s
.42987 .47243 m
.41495 .46209 L
.50627 .46571 L
.52466 .47465 L
.42987 .47243 L
s
.41495 .46209 m
.39692 .44859 L
.48403 .45365 L
.50627 .46571 L
.41495 .46209 L
s
.39692 .44859 m
.37656 .43189 L
.45892 .43822 L
.48403 .45365 L
.39692 .44859 L
s
.37656 .43189 m
.35476 .4121 L
.43203 .41935 L
.45892 .43822 L
.37656 .43189 L
s
.35476 .4121 m
.33248 .3895 L
.40454 .39718 L
.43203 .41935 L
.35476 .4121 L
s
.33248 .3895 m
.31068 .36463 L
.37765 .37215 L
.40454 .39718 L
.33248 .3895 L
s
.31068 .36463 m
.29032 .33841 L
.35254 .34514 L
.37765 .37215 L
.31068 .36463 L
s
.29032 .33841 m
.27229 .31213 L
.3303 .31753 L
.35254 .34514 L
.29032 .33841 L
s
.27229 .31213 m
.25738 .28763 L
.31191 .29131 L
.3303 .31753 L
.27229 .31213 L
s
.25738 .28763 m
.24623 .26722 L
.29816 .26914 L
.31191 .29131 L
.25738 .28763 L
s
.24623 .26722 m
.23935 .2535 L
.28967 .25403 L
.29816 .26914 L
.24623 .26722 L
s
.23935 .2535 m
.23702 .24863 L
.28679 .24863 L
.28967 .25403 L
.23935 .2535 L
s
.23702 .24863 m
.23935 .2535 L
.28967 .25403 L
.28679 .24863 L
.23702 .24863 L
s
.23935 .2535 m
.24623 .26722 L
.29816 .26914 L
.28967 .25403 L
.23935 .2535 L
s
.24623 .26722 m
.25738 .28763 L
.31191 .29131 L
.29816 .26914 L
.24623 .26722 L
s
.25738 .28763 m
.27229 .31213 L
.3303 .31753 L
.31191 .29131 L
.25738 .28763 L
s
.27229 .31213 m
.29032 .33841 L
.35254 .34514 L
.3303 .31753 L
.27229 .31213 L
s
.29032 .33841 m
.31068 .36463 L
.37765 .37215 L
.35254 .34514 L
.29032 .33841 L
s
.31068 .36463 m
.33248 .3895 L
.40454 .39718 L
.37765 .37215 L
.31068 .36463 L
s
.33248 .3895 m
.35476 .4121 L
.43203 .41935 L
.40454 .39718 L
.33248 .3895 L
s
.35476 .4121 m
.37656 .43189 L
.45892 .43822 L
.43203 .41935 L
.35476 .4121 L
s
.37656 .43189 m
.39692 .44859 L
.48403 .45365 L
.45892 .43822 L
.37656 .43189 L
s
.39692 .44859 m
.41495 .46209 L
.50627 .46571 L
.48403 .45365 L
.39692 .44859 L
s
.41495 .46209 m
.42987 .47243 L
.52466 .47465 L
.50627 .46571 L
.41495 .46209 L
s
.42987 .47243 m
.44101 .47969 L
.53841 .48074 L
.52466 .47465 L
.42987 .47243 L
s
.44101 .47969 m
.44789 .484 L
.5469 .48427 L
.53841 .48074 L
.44101 .47969 L
s
.44789 .484 m
.45022 .48542 L
.54978 .48542 L
.5469 .48427 L
.44789 .484 L
s
.54978 .48542 m
.5469 .48427 L
.64375 .46403 L
.64715 .46472 L
.54978 .48542 L
s
.5469 .48427 m
.53841 .48074 L
.63368 .46181 L
.64375 .46403 L
.5469 .48427 L
s
.53841 .48074 m
.52466 .47465 L
.61739 .45771 L
.63368 .46181 L
.53841 .48074 L
s
.52466 .47465 m
.50627 .46571 L
.59559 .45123 L
.61739 .45771 L
.52466 .47465 L
s
.50627 .46571 m
.48403 .45365 L
.56923 .44179 L
.59559 .45123 L
.50627 .46571 L
s
.48403 .45365 m
.45892 .43822 L
.53947 .42888 L
.56923 .44179 L
.48403 .45365 L
s
.45892 .43822 m
.43203 .41935 L
.5076 .41215 L
.53947 .42888 L
.45892 .43822 L
s
.43203 .41935 m
.40454 .39718 L
.47503 .39154 L
.5076 .41215 L
.43203 .41935 L
s
.40454 .39718 m
.37765 .37215 L
.44316 .36735 L
.47503 .39154 L
.40454 .39718 L
s
.37765 .37215 m
.35254 .34514 L
.4134 .34039 L
.44316 .36735 L
.37765 .37215 L
s
.35254 .34514 m
.3303 .31753 L
.38704 .31207 L
.4134 .34039 L
.35254 .34514 L
s
.3303 .31753 m
.31191 .29131 L
.36524 .28452 L
.38704 .31207 L
.3303 .31753 L
s
.31191 .29131 m
.29816 .26914 L
.34895 .26072 L
.36524 .28452 L
.31191 .29131 L
s
.29816 .26914 m
.28967 .25403 L
.33889 .24423 L
.34895 .26072 L
.29816 .26914 L
s
.28967 .25403 m
.28679 .24863 L
.33548 .23828 L
.33889 .24423 L
.28967 .25403 L
s
.28679 .24863 m
.28967 .25403 L
.33889 .24423 L
.33548 .23828 L
.28679 .24863 L
s
.28967 .25403 m
.29816 .26914 L
.34895 .26072 L
.33889 .24423 L
.28967 .25403 L
s
.29816 .26914 m
.31191 .29131 L
.36524 .28452 L
.34895 .26072 L
.29816 .26914 L
s
.31191 .29131 m
.3303 .31753 L
.38704 .31207 L
.36524 .28452 L
.31191 .29131 L
s
.3303 .31753 m
.35254 .34514 L
.4134 .34039 L
.38704 .31207 L
.3303 .31753 L
s
.35254 .34514 m
.37765 .37215 L
.44316 .36735 L
.4134 .34039 L
.35254 .34514 L
s
.37765 .37215 m
.40454 .39718 L
.47503 .39154 L
.44316 .36735 L
.37765 .37215 L
s
.40454 .39718 m
.43203 .41935 L
.5076 .41215 L
.47503 .39154 L
.40454 .39718 L
s
.43203 .41935 m
.45892 .43822 L
.53947 .42888 L
.5076 .41215 L
.43203 .41935 L
s
.45892 .43822 m
.48403 .45365 L
.56923 .44179 L
.53947 .42888 L
.45892 .43822 L
s
.48403 .45365 m
.50627 .46571 L
.59559 .45123 L
.56923 .44179 L
.48403 .45365 L
s
.50627 .46571 m
.52466 .47465 L
.61739 .45771 L
.59559 .45123 L
.50627 .46571 L
s
.52466 .47465 m
.53841 .48074 L
.63368 .46181 L
.61739 .45771 L
.52466 .47465 L
s
.53841 .48074 m
.5469 .48427 L
.64375 .46403 L
.63368 .46181 L
.53841 .48074 L
s
.5469 .48427 m
.54978 .48542 L
.64715 .46472 L
.64375 .46403 L
.5469 .48427 L
s
.54978 .48542 m
.5469 .48427 L
.64375 .46403 L
.64715 .46472 L
.54978 .48542 L
s
.5469 .48427 m
.53841 .48074 L
.63368 .46181 L
.64375 .46403 L
.5469 .48427 L
s
.53841 .48074 m
.52466 .47465 L
.61739 .45771 L
.63368 .46181 L
.53841 .48074 L
s
.52466 .47465 m
.50627 .46571 L
.59559 .45123 L
.61739 .45771 L
.52466 .47465 L
s
.50627 .46571 m
.48403 .45365 L
.56923 .44179 L
.59559 .45123 L
.50627 .46571 L
s
.48403 .45365 m
.45892 .43822 L
.53947 .42888 L
.56923 .44179 L
.48403 .45365 L
s
.45892 .43822 m
.43203 .41935 L
.5076 .41215 L
.53947 .42888 L
.45892 .43822 L
s
.43203 .41935 m
.40454 .39718 L
.47503 .39154 L
.5076 .41215 L
.43203 .41935 L
s
.40454 .39718 m
.37765 .37215 L
.44316 .36735 L
.47503 .39154 L
.40454 .39718 L
s
.37765 .37215 m
.35254 .34514 L
.4134 .34039 L
.44316 .36735 L
.37765 .37215 L
s
.35254 .34514 m
.3303 .31753 L
.38704 .31207 L
.4134 .34039 L
.35254 .34514 L
s
.3303 .31753 m
.31191 .29131 L
.36524 .28452 L
.38704 .31207 L
.3303 .31753 L
s
.31191 .29131 m
.29816 .26914 L
.34895 .26072 L
.36524 .28452 L
.31191 .29131 L
s
.29816 .26914 m
.28967 .25403 L
.33889 .24423 L
.34895 .26072 L
.29816 .26914 L
s
.28967 .25403 m
.28679 .24863 L
.33548 .23828 L
.33889 .24423 L
.28967 .25403 L
s
.28679 .24863 m
.28967 .25403 L
.33889 .24423 L
.33548 .23828 L
.28679 .24863 L
s
.28967 .25403 m
.29816 .26914 L
.34895 .26072 L
.33889 .24423 L
.28967 .25403 L
s
.29816 .26914 m
.31191 .29131 L
.36524 .28452 L
.34895 .26072 L
.29816 .26914 L
s
.31191 .29131 m
.3303 .31753 L
.38704 .31207 L
.36524 .28452 L
.31191 .29131 L
s
.3303 .31753 m
.35254 .34514 L
.4134 .34039 L
.38704 .31207 L
.3303 .31753 L
s
.35254 .34514 m
.37765 .37215 L
.44316 .36735 L
.4134 .34039 L
.35254 .34514 L
s
.37765 .37215 m
.40454 .39718 L
.47503 .39154 L
.44316 .36735 L
.37765 .37215 L
s
.40454 .39718 m
.43203 .41935 L
.5076 .41215 L
.47503 .39154 L
.40454 .39718 L
s
.43203 .41935 m
.45892 .43822 L
.53947 .42888 L
.5076 .41215 L
.43203 .41935 L
s
.45892 .43822 m
.48403 .45365 L
.56923 .44179 L
.53947 .42888 L
.45892 .43822 L
s
.48403 .45365 m
.50627 .46571 L
.59559 .45123 L
.56923 .44179 L
.48403 .45365 L
s
.50627 .46571 m
.52466 .47465 L
.61739 .45771 L
.59559 .45123 L
.50627 .46571 L
s
.52466 .47465 m
.53841 .48074 L
.63368 .46181 L
.61739 .45771 L
.52466 .47465 L
s
.53841 .48074 m
.5469 .48427 L
.64375 .46403 L
.63368 .46181 L
.53841 .48074 L
s
.5469 .48427 m
.54978 .48542 L
.64715 .46472 L
.64375 .46403 L
.5469 .48427 L
s
.64715 .46472 m
.64375 .46403 L
.73419 .42421 L
.7381 .42423 L
.64715 .46472 L
s
.64375 .46403 m
.63368 .46181 L
.72266 .42394 L
.73419 .42421 L
.64375 .46403 L
s
.63368 .46181 m
.61739 .45771 L
.70399 .42282 L
.72266 .42394 L
.63368 .46181 L
s
.61739 .45771 m
.59559 .45123 L
.67901 .41998 L
.70399 .42282 L
.61739 .45771 L
s
.59559 .45123 m
.56923 .44179 L
.64881 .41445 L
.67901 .41998 L
.59559 .45123 L
s
.56923 .44179 m
.53947 .42888 L
.61471 .40534 L
.64881 .41445 L
.56923 .44179 L
s
.53947 .42888 m
.5076 .41215 L
.57819 .39197 L
.61471 .40534 L
.53947 .42888 L
s
.5076 .41215 m
.47503 .39154 L
.54086 .37401 L
.57819 .39197 L
.5076 .41215 L
s
.47503 .39154 m
.44316 .36735 L
.50434 .35159 L
.54086 .37401 L
.47503 .39154 L
s
.44316 .36735 m
.4134 .34039 L
.47024 .3254 L
.50434 .35159 L
.44316 .36735 L
s
.4134 .34039 m
.38704 .31207 L
.44004 .29685 L
.47024 .3254 L
.4134 .34039 L
s
.38704 .31207 m
.36524 .28452 L
.41506 .26819 L
.44004 .29685 L
.38704 .31207 L
s
.36524 .28452 m
.34895 .26072 L
.39639 .24272 L
.41506 .26819 L
.36524 .28452 L
s
.34895 .26072 m
.33889 .24423 L
.38485 .22465 L
.39639 .24272 L
.34895 .26072 L
s
.33889 .24423 m
.33548 .23828 L
.38095 .21804 L
.38485 .22465 L
.33889 .24423 L
s
.33548 .23828 m
.33889 .24423 L
.38485 .22465 L
.38095 .21804 L
.33548 .23828 L
s
.33889 .24423 m
.34895 .26072 L
.39639 .24272 L
.38485 .22465 L
.33889 .24423 L
s
.34895 .26072 m
.36524 .28452 L
.41506 .26819 L
.39639 .24272 L
.34895 .26072 L
s
.36524 .28452 m
.38704 .31207 L
.44004 .29685 L
.41506 .26819 L
.36524 .28452 L
s
.38704 .31207 m
.4134 .34039 L
.47024 .3254 L
.44004 .29685 L
.38704 .31207 L
s
.4134 .34039 m
.44316 .36735 L
.50434 .35159 L
.47024 .3254 L
.4134 .34039 L
s
.44316 .36735 m
.47503 .39154 L
.54086 .37401 L
.50434 .35159 L
.44316 .36735 L
s
.47503 .39154 m
.5076 .41215 L
.57819 .39197 L
.54086 .37401 L
.47503 .39154 L
s
.5076 .41215 m
.53947 .42888 L
.61471 .40534 L
.57819 .39197 L
.5076 .41215 L
s
.53947 .42888 m
.56923 .44179 L
.64881 .41445 L
.61471 .40534 L
.53947 .42888 L
s
.56923 .44179 m
.59559 .45123 L
.67901 .41998 L
.64881 .41445 L
.56923 .44179 L
s
.59559 .45123 m
.61739 .45771 L
.70399 .42282 L
.67901 .41998 L
.59559 .45123 L
s
.61739 .45771 m
.63368 .46181 L
.72266 .42394 L
.70399 .42282 L
.61739 .45771 L
s
.63368 .46181 m
.64375 .46403 L
.73419 .42421 L
.72266 .42394 L
.63368 .46181 L
s
.64375 .46403 m
.64715 .46472 L
.7381 .42423 L
.73419 .42421 L
.64375 .46403 L
s
.64715 .46472 m
.64375 .46403 L
.73419 .42421 L
.7381 .42423 L
.64715 .46472 L
s
.64375 .46403 m
.63368 .46181 L
.72266 .42394 L
.73419 .42421 L
.64375 .46403 L
s
.63368 .46181 m
.61739 .45771 L
.70399 .42282 L
.72266 .42394 L
.63368 .46181 L
s
.61739 .45771 m
.59559 .45123 L
.67901 .41998 L
.70399 .42282 L
.61739 .45771 L
s
.59559 .45123 m
.56923 .44179 L
.64881 .41445 L
.67901 .41998 L
.59559 .45123 L
s
.56923 .44179 m
.53947 .42888 L
.61471 .40534 L
.64881 .41445 L
.56923 .44179 L
s
.53947 .42888 m
.5076 .41215 L
.57819 .39197 L
.61471 .40534 L
.53947 .42888 L
s
.5076 .41215 m
.47503 .39154 L
.54086 .37401 L
.57819 .39197 L
.5076 .41215 L
s
.47503 .39154 m
.44316 .36735 L
.50434 .35159 L
.54086 .37401 L
.47503 .39154 L
s
.44316 .36735 m
.4134 .34039 L
.47024 .3254 L
.50434 .35159 L
.44316 .36735 L
s
.4134 .34039 m
.38704 .31207 L
.44004 .29685 L
.47024 .3254 L
.4134 .34039 L
s
.38704 .31207 m
.36524 .28452 L
.41506 .26819 L
.44004 .29685 L
.38704 .31207 L
s
.36524 .28452 m
.34895 .26072 L
.39639 .24272 L
.41506 .26819 L
.36524 .28452 L
s
.34895 .26072 m
.33889 .24423 L
.38485 .22465 L
.39639 .24272 L
.34895 .26072 L
s
.33889 .24423 m
.33548 .23828 L
.38095 .21804 L
.38485 .22465 L
.33889 .24423 L
s
.33548 .23828 m
.33889 .24423 L
.38485 .22465 L
.38095 .21804 L
.33548 .23828 L
s
.33889 .24423 m
.34895 .26072 L
.39639 .24272 L
.38485 .22465 L
.33889 .24423 L
s
.34895 .26072 m
.36524 .28452 L
.41506 .26819 L
.39639 .24272 L
.34895 .26072 L
s
.36524 .28452 m
.38704 .31207 L
.44004 .29685 L
.41506 .26819 L
.36524 .28452 L
s
.38704 .31207 m
.4134 .34039 L
.47024 .3254 L
.44004 .29685 L
.38704 .31207 L
s
.4134 .34039 m
.44316 .36735 L
.50434 .35159 L
.47024 .3254 L
.4134 .34039 L
s
.44316 .36735 m
.47503 .39154 L
.54086 .37401 L
.50434 .35159 L
.44316 .36735 L
s
.47503 .39154 m
.5076 .41215 L
.57819 .39197 L
.54086 .37401 L
.47503 .39154 L
s
.5076 .41215 m
.53947 .42888 L
.61471 .40534 L
.57819 .39197 L
.5076 .41215 L
s
.53947 .42888 m
.56923 .44179 L
.64881 .41445 L
.61471 .40534 L
.53947 .42888 L
s
.56923 .44179 m
.59559 .45123 L
.67901 .41998 L
.64881 .41445 L
.56923 .44179 L
s
.59559 .45123 m
.61739 .45771 L
.70399 .42282 L
.67901 .41998 L
.59559 .45123 L
s
.61739 .45771 m
.63368 .46181 L
.72266 .42394 L
.70399 .42282 L
.61739 .45771 L
s
.63368 .46181 m
.64375 .46403 L
.73419 .42421 L
.72266 .42394 L
.63368 .46181 L
s
.64375 .46403 m
.64715 .46472 L
.7381 .42423 L
.73419 .42421 L
.64375 .46403 L
s
.7381 .42423 m
.73419 .42421 L
.81429 .36668 L
.81863 .36572 L
.7381 .42423 L
s
.73419 .42421 m
.72266 .42394 L
.80145 .36919 L
.81429 .36668 L
.73419 .42421 L
s
.72266 .42394 m
.70399 .42282 L
.78068 .37226 L
.80145 .36919 L
.72266 .42394 L
s
.70399 .42282 m
.67901 .41998 L
.75289 .37447 L
.78068 .37226 L
.70399 .42282 L
s
.67901 .41998 m
.64881 .41445 L
.71928 .37428 L
.75289 .37447 L
.67901 .41998 L
s
.64881 .41445 m
.61471 .40534 L
.68133 .3703 L
.71928 .37428 L
.64881 .41445 L
s
.61471 .40534 m
.57819 .39197 L
.6407 .36145 L
.68133 .3703 L
.61471 .40534 L
s
.57819 .39197 m
.54086 .37401 L
.59916 .34712 L
.6407 .36145 L
.57819 .39197 L
s
.54086 .37401 m
.50434 .35159 L
.55852 .32723 L
.59916 .34712 L
.54086 .37401 L
s
.50434 .35159 m
.47024 .3254 L
.52057 .30236 L
.55852 .32723 L
.50434 .35159 L
s
.47024 .3254 m
.44004 .29685 L
.48697 .27385 L
.52057 .30236 L
.47024 .3254 L
s
.44004 .29685 m
.41506 .26819 L
.45917 .24404 L
.48697 .27385 L
.44004 .29685 L
s
.41506 .26819 m
.39639 .24272 L
.4384 .21653 L
.45917 .24404 L
.41506 .26819 L
s
.39639 .24272 m
.38485 .22465 L
.42556 .19634 L
.4384 .21653 L
.39639 .24272 L
s
.38485 .22465 m
.38095 .21804 L
.42122 .18878 L
.42556 .19634 L
.38485 .22465 L
s
.38095 .21804 m
.38485 .22465 L
.42556 .19634 L
.42122 .18878 L
.38095 .21804 L
s
.38485 .22465 m
.39639 .24272 L
.4384 .21653 L
.42556 .19634 L
.38485 .22465 L
s
.39639 .24272 m
.41506 .26819 L
.45917 .24404 L
.4384 .21653 L
.39639 .24272 L
s
.41506 .26819 m
.44004 .29685 L
.48697 .27385 L
.45917 .24404 L
.41506 .26819 L
s
.44004 .29685 m
.47024 .3254 L
.52057 .30236 L
.48697 .27385 L
.44004 .29685 L
s
.47024 .3254 m
.50434 .35159 L
.55852 .32723 L
.52057 .30236 L
.47024 .3254 L
s
.50434 .35159 m
.54086 .37401 L
.59916 .34712 L
.55852 .32723 L
.50434 .35159 L
s
.54086 .37401 m
.57819 .39197 L
.6407 .36145 L
.59916 .34712 L
.54086 .37401 L
s
.57819 .39197 m
.61471 .40534 L
.68133 .3703 L
.6407 .36145 L
.57819 .39197 L
s
.61471 .40534 m
.64881 .41445 L
.71928 .37428 L
.68133 .3703 L
.61471 .40534 L
s
.64881 .41445 m
.67901 .41998 L
.75289 .37447 L
.71928 .37428 L
.64881 .41445 L
s
.67901 .41998 m
.70399 .42282 L
.78068 .37226 L
.75289 .37447 L
.67901 .41998 L
s
.70399 .42282 m
.72266 .42394 L
.80145 .36919 L
.78068 .37226 L
.70399 .42282 L
s
.72266 .42394 m
.73419 .42421 L
.81429 .36668 L
.80145 .36919 L
.72266 .42394 L
s
.73419 .42421 m
.7381 .42423 L
.81863 .36572 L
.81429 .36668 L
.73419 .42421 L
s
.7381 .42423 m
.73419 .42421 L
.81429 .36668 L
.81863 .36572 L
.7381 .42423 L
s
.73419 .42421 m
.72266 .42394 L
.80145 .36919 L
.81429 .36668 L
.73419 .42421 L
s
.72266 .42394 m
.70399 .42282 L
.78068 .37226 L
.80145 .36919 L
.72266 .42394 L
s
.70399 .42282 m
.67901 .41998 L
.75289 .37447 L
.78068 .37226 L
.70399 .42282 L
s
.67901 .41998 m
.64881 .41445 L
.71928 .37428 L
.75289 .37447 L
.67901 .41998 L
s
.64881 .41445 m
.61471 .40534 L
.68133 .3703 L
.71928 .37428 L
.64881 .41445 L
s
.61471 .40534 m
.57819 .39197 L
.6407 .36145 L
.68133 .3703 L
.61471 .40534 L
s
.57819 .39197 m
.54086 .37401 L
.59916 .34712 L
.6407 .36145 L
.57819 .39197 L
s
.54086 .37401 m
.50434 .35159 L
.55852 .32723 L
.59916 .34712 L
.54086 .37401 L
s
.50434 .35159 m
.47024 .3254 L
.52057 .30236 L
.55852 .32723 L
.50434 .35159 L
s
.47024 .3254 m
.44004 .29685 L
.48697 .27385 L
.52057 .30236 L
.47024 .3254 L
s
.44004 .29685 m
.41506 .26819 L
.45917 .24404 L
.48697 .27385 L
.44004 .29685 L
s
.41506 .26819 m
.39639 .24272 L
.4384 .21653 L
.45917 .24404 L
.41506 .26819 L
s
.39639 .24272 m
.38485 .22465 L
.42556 .19634 L
.4384 .21653 L
.39639 .24272 L
s
.38485 .22465 m
.38095 .21804 L
.42122 .18878 L
.42556 .19634 L
.38485 .22465 L
s
.38095 .21804 m
.38485 .22465 L
.42556 .19634 L
.42122 .18878 L
.38095 .21804 L
s
.38485 .22465 m
.39639 .24272 L
.4384 .21653 L
.42556 .19634 L
.38485 .22465 L
s
.39639 .24272 m
.41506 .26819 L
.45917 .24404 L
.4384 .21653 L
.39639 .24272 L
s
.41506 .26819 m
.44004 .29685 L
.48697 .27385 L
.45917 .24404 L
.41506 .26819 L
s
.44004 .29685 m
.47024 .3254 L
.52057 .30236 L
.48697 .27385 L
.44004 .29685 L
s
.47024 .3254 m
.50434 .35159 L
.55852 .32723 L
.52057 .30236 L
.47024 .3254 L
s
.50434 .35159 m
.54086 .37401 L
.59916 .34712 L
.55852 .32723 L
.50434 .35159 L
s
.54086 .37401 m
.57819 .39197 L
.6407 .36145 L
.59916 .34712 L
.54086 .37401 L
s
.57819 .39197 m
.61471 .40534 L
.68133 .3703 L
.6407 .36145 L
.57819 .39197 L
s
.61471 .40534 m
.64881 .41445 L
.71928 .37428 L
.68133 .3703 L
.61471 .40534 L
s
.64881 .41445 m
.67901 .41998 L
.75289 .37447 L
.71928 .37428 L
.64881 .41445 L
s
.67901 .41998 m
.70399 .42282 L
.78068 .37226 L
.75289 .37447 L
.67901 .41998 L
s
.70399 .42282 m
.72266 .42394 L
.80145 .36919 L
.78068 .37226 L
.70399 .42282 L
s
.72266 .42394 m
.73419 .42421 L
.81429 .36668 L
.80145 .36919 L
.72266 .42394 L
s
.73419 .42421 m
.7381 .42423 L
.81863 .36572 L
.81429 .36668 L
.73419 .42421 L
s
.81863 .36572 m
.81429 .36668 L
.88054 .29416 L
.88525 .29174 L
.81863 .36572 L
s
.81429 .36668 m
.80145 .36919 L
.86663 .30076 L
.88054 .29416 L
.81429 .36668 L
s
.80145 .36919 m
.78068 .37226 L
.84412 .30976 L
.86663 .30076 L
.80145 .36919 L
s
.78068 .37226 m
.75289 .37447 L
.81399 .31882 L
.84412 .30976 L
.78068 .37226 L
s
.75289 .37447 m
.71928 .37428 L
.77757 .32559 L
.81399 .31882 L
.75289 .37447 L
s
.71928 .37428 m
.68133 .3703 L
.73644 .32806 L
.77757 .32559 L
.71928 .37428 L
s
.68133 .3703 m
.6407 .36145 L
.6924 .32474 L
.73644 .32806 L
.68133 .3703 L
s
.6407 .36145 m
.59916 .34712 L
.64738 .31477 L
.6924 .32474 L
.6407 .36145 L
s
.59916 .34712 m
.55852 .32723 L
.60334 .29791 L
.64738 .31477 L
.59916 .34712 L
s
.55852 .32723 m
.52057 .30236 L
.56221 .27463 L
.60334 .29791 L
.55852 .32723 L
s
.52057 .30236 m
.48697 .27385 L
.52578 .24619 L
.56221 .27463 L
.52057 .30236 L
s
.48697 .27385 m
.45917 .24404 L
.49566 .21487 L
.52578 .24619 L
.48697 .27385 L
s
.45917 .24404 m
.4384 .21653 L
.47315 .18446 L
.49566 .21487 L
.45917 .24404 L
s
.4384 .21653 m
.42556 .19634 L
.45923 .16095 L
.47315 .18446 L
.4384 .21653 L
s
.42556 .19634 m
.42122 .18878 L
.45453 .15179 L
.45923 .16095 L
.42556 .19634 L
s
.42122 .18878 m
.42556 .19634 L
.45923 .16095 L
.45453 .15179 L
.42122 .18878 L
s
.42556 .19634 m
.4384 .21653 L
.47315 .18446 L
.45923 .16095 L
.42556 .19634 L
s
.4384 .21653 m
.45917 .24404 L
.49566 .21487 L
.47315 .18446 L
.4384 .21653 L
s
.45917 .24404 m
.48697 .27385 L
.52578 .24619 L
.49566 .21487 L
.45917 .24404 L
s
.48697 .27385 m
.52057 .30236 L
.56221 .27463 L
.52578 .24619 L
.48697 .27385 L
s
.52057 .30236 m
.55852 .32723 L
.60334 .29791 L
.56221 .27463 L
.52057 .30236 L
s
.55852 .32723 m
.59916 .34712 L
.64738 .31477 L
.60334 .29791 L
.55852 .32723 L
s
.59916 .34712 m
.6407 .36145 L
.6924 .32474 L
.64738 .31477 L
.59916 .34712 L
s
.6407 .36145 m
.68133 .3703 L
.73644 .32806 L
.6924 .32474 L
.6407 .36145 L
s
.68133 .3703 m
.71928 .37428 L
.77757 .32559 L
.73644 .32806 L
.68133 .3703 L
s
.71928 .37428 m
.75289 .37447 L
.81399 .31882 L
.77757 .32559 L
.71928 .37428 L
s
.75289 .37447 m
.78068 .37226 L
.84412 .30976 L
.81399 .31882 L
.75289 .37447 L
s
.78068 .37226 m
.80145 .36919 L
.86663 .30076 L
.84412 .30976 L
.78068 .37226 L
s
.80145 .36919 m
.81429 .36668 L
.88054 .29416 L
.86663 .30076 L
.80145 .36919 L
s
.81429 .36668 m
.81863 .36572 L
.88525 .29174 L
.88054 .29416 L
.81429 .36668 L
s
.81863 .36572 m
.81429 .36668 L
.88054 .29416 L
.88525 .29174 L
.81863 .36572 L
s
.81429 .36668 m
.80145 .36919 L
.86663 .30076 L
.88054 .29416 L
.81429 .36668 L
s
.80145 .36919 m
.78068 .37226 L
.84412 .30976 L
.86663 .30076 L
.80145 .36919 L
s
.78068 .37226 m
.75289 .37447 L
.81399 .31882 L
.84412 .30976 L
.78068 .37226 L
s
.75289 .37447 m
.71928 .37428 L
.77757 .32559 L
.81399 .31882 L
.75289 .37447 L
s
.71928 .37428 m
.68133 .3703 L
.73644 .32806 L
.77757 .32559 L
.71928 .37428 L
s
.68133 .3703 m
.6407 .36145 L
.6924 .32474 L
.73644 .32806 L
.68133 .3703 L
s
.6407 .36145 m
.59916 .34712 L
.64738 .31477 L
.6924 .32474 L
.6407 .36145 L
s
.59916 .34712 m
.55852 .32723 L
.60334 .29791 L
.64738 .31477 L
.59916 .34712 L
s
.55852 .32723 m
.52057 .30236 L
.56221 .27463 L
.60334 .29791 L
.55852 .32723 L
s
.52057 .30236 m
.48697 .27385 L
.52578 .24619 L
.56221 .27463 L
.52057 .30236 L
s
.48697 .27385 m
.45917 .24404 L
.49566 .21487 L
.52578 .24619 L
.48697 .27385 L
s
.45917 .24404 m
.4384 .21653 L
.47315 .18446 L
.49566 .21487 L
.45917 .24404 L
s
.4384 .21653 m
.42556 .19634 L
.45923 .16095 L
.47315 .18446 L
.4384 .21653 L
s
.42556 .19634 m
.42122 .18878 L
.45453 .15179 L
.45923 .16095 L
.42556 .19634 L
s
.42122 .18878 m
.42556 .19634 L
.45923 .16095 L
.45453 .15179 L
.42122 .18878 L
s
.42556 .19634 m
.4384 .21653 L
.47315 .18446 L
.45923 .16095 L
.42556 .19634 L
s
.4384 .21653 m
.45917 .24404 L
.49566 .21487 L
.47315 .18446 L
.4384 .21653 L
s
.45917 .24404 m
.48697 .27385 L
.52578 .24619 L
.49566 .21487 L
.45917 .24404 L
s
.48697 .27385 m
.52057 .30236 L
.56221 .27463 L
.52578 .24619 L
.48697 .27385 L
s
.52057 .30236 m
.55852 .32723 L
.60334 .29791 L
.56221 .27463 L
.52057 .30236 L
s
.55852 .32723 m
.59916 .34712 L
.64738 .31477 L
.60334 .29791 L
.55852 .32723 L
s
.59916 .34712 m
.6407 .36145 L
.6924 .32474 L
.64738 .31477 L
.59916 .34712 L
s
.6407 .36145 m
.68133 .3703 L
.73644 .32806 L
.6924 .32474 L
.6407 .36145 L
s
.68133 .3703 m
.71928 .37428 L
.77757 .32559 L
.73644 .32806 L
.68133 .3703 L
s
.71928 .37428 m
.75289 .37447 L
.81399 .31882 L
.77757 .32559 L
.71928 .37428 L
s
.75289 .37447 m
.78068 .37226 L
.84412 .30976 L
.81399 .31882 L
.75289 .37447 L
s
.78068 .37226 m
.80145 .36919 L
.86663 .30076 L
.84412 .30976 L
.78068 .37226 L
s
.80145 .36919 m
.81429 .36668 L
.88054 .29416 L
.86663 .30076 L
.80145 .36919 L
s
.81429 .36668 m
.81863 .36572 L
.88525 .29174 L
.88054 .29416 L
.81429 .36668 L
s
.88525 .29174 m
.88054 .29416 L
.93004 .21046 L
.93502 .20552 L
.88525 .29174 L
s
.88054 .29416 m
.86663 .30076 L
.91533 .22369 L
.93004 .21046 L
.88054 .29416 L
s
.86663 .30076 m
.84412 .30976 L
.89152 .24153 L
.91533 .22369 L
.86663 .30076 L
s
.84412 .30976 m
.81399 .31882 L
.85965 .25987 L
.89152 .24153 L
.84412 .30976 L
s
.81399 .31882 m
.77757 .32559 L
.82112 .27528 L
.85965 .25987 L
.81399 .31882 L
s
.77757 .32559 m
.73644 .32806 L
.77761 .28521 L
.82112 .27528 L
.77757 .32559 L
s
.73644 .32806 m
.6924 .32474 L
.73103 .28796 L
.77761 .28521 L
.73644 .32806 L
s
.6924 .32474 m
.64738 .31477 L
.68341 .28258 L
.73103 .28796 L
.6924 .32474 L
s
.64738 .31477 m
.60334 .29791 L
.63682 .26882 L
.68341 .28258 L
.64738 .31477 L
s
.60334 .29791 m
.56221 .27463 L
.59332 .24707 L
.63682 .26882 L
.60334 .29791 L
s
.56221 .27463 m
.52578 .24619 L
.55479 .21846 L
.59332 .24707 L
.56221 .27463 L
s
.52578 .24619 m
.49566 .21487 L
.52292 .18503 L
.55479 .21846 L
.52578 .24619 L
s
.49566 .21487 m
.47315 .18446 L
.49911 .15033 L
.52292 .18503 L
.49566 .21487 L
s
.47315 .18446 m
.45923 .16095 L
.48439 .12106 L
.49911 .15033 L
.47315 .18446 L
s
.45923 .16095 m
.45453 .15179 L
.47942 .10868 L
.48439 .12106 L
.45923 .16095 L
s
.45453 .15179 m
.45923 .16095 L
.48439 .12106 L
.47942 .10868 L
.45453 .15179 L
s
.45923 .16095 m
.47315 .18446 L
.49911 .15033 L
.48439 .12106 L
.45923 .16095 L
s
.47315 .18446 m
.49566 .21487 L
.52292 .18503 L
.49911 .15033 L
.47315 .18446 L
s
.49566 .21487 m
.52578 .24619 L
.55479 .21846 L
.52292 .18503 L
.49566 .21487 L
s
.52578 .24619 m
.56221 .27463 L
.59332 .24707 L
.55479 .21846 L
.52578 .24619 L
s
.56221 .27463 m
.60334 .29791 L
.63682 .26882 L
.59332 .24707 L
.56221 .27463 L
s
.60334 .29791 m
.64738 .31477 L
.68341 .28258 L
.63682 .26882 L
.60334 .29791 L
s
.64738 .31477 m
.6924 .32474 L
.73103 .28796 L
.68341 .28258 L
.64738 .31477 L
s
.6924 .32474 m
.73644 .32806 L
.77761 .28521 L
.73103 .28796 L
.6924 .32474 L
s
.73644 .32806 m
.77757 .32559 L
.82112 .27528 L
.77761 .28521 L
.73644 .32806 L
s
.77757 .32559 m
.81399 .31882 L
.85965 .25987 L
.82112 .27528 L
.77757 .32559 L
s
.81399 .31882 m
.84412 .30976 L
.89152 .24153 L
.85965 .25987 L
.81399 .31882 L
s
.84412 .30976 m
.86663 .30076 L
.91533 .22369 L
.89152 .24153 L
.84412 .30976 L
s
.86663 .30076 m
.88054 .29416 L
.93004 .21046 L
.91533 .22369 L
.86663 .30076 L
s
.88054 .29416 m
.88525 .29174 L
.93502 .20552 L
.93004 .21046 L
.88054 .29416 L
s
.88525 .29174 m
.88054 .29416 L
.93004 .21046 L
.93502 .20552 L
.88525 .29174 L
s
.88054 .29416 m
.86663 .30076 L
.91533 .22369 L
.93004 .21046 L
.88054 .29416 L
s
.86663 .30076 m
.84412 .30976 L
.89152 .24153 L
.91533 .22369 L
.86663 .30076 L
s
.84412 .30976 m
.81399 .31882 L
.85965 .25987 L
.89152 .24153 L
.84412 .30976 L
s
.81399 .31882 m
.77757 .32559 L
.82112 .27528 L
.85965 .25987 L
.81399 .31882 L
s
.77757 .32559 m
.73644 .32806 L
.77761 .28521 L
.82112 .27528 L
.77757 .32559 L
s
.73644 .32806 m
.6924 .32474 L
.73103 .28796 L
.77761 .28521 L
.73644 .32806 L
s
.6924 .32474 m
.64738 .31477 L
.68341 .28258 L
.73103 .28796 L
.6924 .32474 L
s
.64738 .31477 m
.60334 .29791 L
.63682 .26882 L
.68341 .28258 L
.64738 .31477 L
s
.60334 .29791 m
.56221 .27463 L
.59332 .24707 L
.63682 .26882 L
.60334 .29791 L
s
.56221 .27463 m
.52578 .24619 L
.55479 .21846 L
.59332 .24707 L
.56221 .27463 L
s
.52578 .24619 m
.49566 .21487 L
.52292 .18503 L
.55479 .21846 L
.52578 .24619 L
s
.49566 .21487 m
.47315 .18446 L
.49911 .15033 L
.52292 .18503 L
.49566 .21487 L
s
.47315 .18446 m
.45923 .16095 L
.48439 .12106 L
.49911 .15033 L
.47315 .18446 L
s
.45923 .16095 m
.45453 .15179 L
.47942 .10868 L
.48439 .12106 L
.45923 .16095 L
s
.45453 .15179 m
.45923 .16095 L
.48439 .12106 L
.47942 .10868 L
.45453 .15179 L
s
.45923 .16095 m
.47315 .18446 L
.49911 .15033 L
.48439 .12106 L
.45923 .16095 L
s
.47315 .18446 m
.49566 .21487 L
.52292 .18503 L
.49911 .15033 L
.47315 .18446 L
s
.49566 .21487 m
.52578 .24619 L
.55479 .21846 L
.52292 .18503 L
.49566 .21487 L
s
.52578 .24619 m
.56221 .27463 L
.59332 .24707 L
.55479 .21846 L
.52578 .24619 L
s
.56221 .27463 m
.60334 .29791 L
.63682 .26882 L
.59332 .24707 L
.56221 .27463 L
s
.60334 .29791 m
.64738 .31477 L
.68341 .28258 L
.63682 .26882 L
.60334 .29791 L
s
.64738 .31477 m
.6924 .32474 L
.73103 .28796 L
.68341 .28258 L
.64738 .31477 L
s
.6924 .32474 m
.73644 .32806 L
.77761 .28521 L
.73103 .28796 L
.6924 .32474 L
s
.73644 .32806 m
.77757 .32559 L
.82112 .27528 L
.77761 .28521 L
.73644 .32806 L
s
.77757 .32559 m
.81399 .31882 L
.85965 .25987 L
.82112 .27528 L
.77757 .32559 L
s
.81399 .31882 m
.84412 .30976 L
.89152 .24153 L
.85965 .25987 L
.81399 .31882 L
s
.84412 .30976 m
.86663 .30076 L
.91533 .22369 L
.89152 .24153 L
.84412 .30976 L
s
.86663 .30076 m
.88054 .29416 L
.93004 .21046 L
.91533 .22369 L
.86663 .30076 L
s
.88054 .29416 m
.88525 .29174 L
.93502 .20552 L
.93004 .21046 L
.88054 .29416 L
s
.93502 .20552 m
.93004 .21046 L
.96064 .12193 L
.96578 .11085 L
.93502 .20552 L
s
.93004 .21046 m
.91533 .22369 L
.94543 .14844 L
.96064 .12193 L
.93004 .21046 L
s
.91533 .22369 m
.89152 .24153 L
.92081 .17995 L
.94543 .14844 L
.91533 .22369 L
s
.89152 .24153 m
.85965 .25987 L
.88787 .20986 L
.92081 .17995 L
.89152 .24153 L
s
.85965 .25987 m
.82112 .27528 L
.84804 .23445 L
.88787 .20986 L
.85965 .25987 L
s
.82112 .27528 m
.77761 .28521 L
.80306 .25147 L
.84804 .23445 L
.82112 .27528 L
s
.77761 .28521 m
.73103 .28796 L
.75491 .25955 L
.80306 .25147 L
.77761 .28521 L
s
.73103 .28796 m
.68341 .28258 L
.70568 .258 L
.75491 .25955 L
.73103 .28796 L
s
.68341 .28258 m
.63682 .26882 L
.65752 .24668 L
.70568 .258 L
.68341 .28258 L
s
.63682 .26882 m
.59332 .24707 L
.61254 .22604 L
.65752 .24668 L
.63682 .26882 L
s
.59332 .24707 m
.55479 .21846 L
.57271 .19703 L
.61254 .22604 L
.59332 .24707 L
s
.55479 .21846 m
.52292 .18503 L
.53977 .16121 L
.57271 .19703 L
.55479 .21846 L
s
.52292 .18503 m
.49911 .15033 L
.51516 .12112 L
.53977 .16121 L
.52292 .18503 L
s
.49911 .15033 m
.48439 .12106 L
.49994 .08204 L
.51516 .12112 L
.49911 .15033 L
s
.48439 .12106 m
.47942 .10868 L
.4948 .06134 L
.49994 .08204 L
.48439 .12106 L
s
.47942 .10868 m
.48439 .12106 L
.49994 .08204 L
.4948 .06134 L
.47942 .10868 L
s
.48439 .12106 m
.49911 .15033 L
.51516 .12112 L
.49994 .08204 L
.48439 .12106 L
s
.49911 .15033 m
.52292 .18503 L
.53977 .16121 L
.51516 .12112 L
.49911 .15033 L
s
.52292 .18503 m
.55479 .21846 L
.57271 .19703 L
.53977 .16121 L
.52292 .18503 L
s
.55479 .21846 m
.59332 .24707 L
.61254 .22604 L
.57271 .19703 L
.55479 .21846 L
s
.59332 .24707 m
.63682 .26882 L
.65752 .24668 L
.61254 .22604 L
.59332 .24707 L
s
.63682 .26882 m
.68341 .28258 L
.70568 .258 L
.65752 .24668 L
.63682 .26882 L
s
.68341 .28258 m
.73103 .28796 L
.75491 .25955 L
.70568 .258 L
.68341 .28258 L
s
.73103 .28796 m
.77761 .28521 L
.80306 .25147 L
.75491 .25955 L
.73103 .28796 L
s
.77761 .28521 m
.82112 .27528 L
.84804 .23445 L
.80306 .25147 L
.77761 .28521 L
s
.82112 .27528 m
.85965 .25987 L
.88787 .20986 L
.84804 .23445 L
.82112 .27528 L
s
.85965 .25987 m
.89152 .24153 L
.92081 .17995 L
.88787 .20986 L
.85965 .25987 L
s
.89152 .24153 m
.91533 .22369 L
.94543 .14844 L
.92081 .17995 L
.89152 .24153 L
s
.91533 .22369 m
.93004 .21046 L
.96064 .12193 L
.94543 .14844 L
.91533 .22369 L
s
.93004 .21046 m
.93502 .20552 L
.96578 .11085 L
.96064 .12193 L
.93004 .21046 L
s
.93502 .20552 m
.93004 .21046 L
.96064 .12193 L
.96578 .11085 L
.93502 .20552 L
s
.93004 .21046 m
.91533 .22369 L
.94543 .14844 L
.96064 .12193 L
.93004 .21046 L
s
.91533 .22369 m
.89152 .24153 L
.92081 .17995 L
.94543 .14844 L
.91533 .22369 L
s
.89152 .24153 m
.85965 .25987 L
.88787 .20986 L
.92081 .17995 L
.89152 .24153 L
s
.85965 .25987 m
.82112 .27528 L
.84804 .23445 L
.88787 .20986 L
.85965 .25987 L
s
.82112 .27528 m
.77761 .28521 L
.80306 .25147 L
.84804 .23445 L
.82112 .27528 L
s
.77761 .28521 m
.73103 .28796 L
.75491 .25955 L
.80306 .25147 L
.77761 .28521 L
s
.73103 .28796 m
.68341 .28258 L
.70568 .258 L
.75491 .25955 L
.73103 .28796 L
s
.68341 .28258 m
.63682 .26882 L
.65752 .24668 L
.70568 .258 L
.68341 .28258 L
s
.63682 .26882 m
.59332 .24707 L
.61254 .22604 L
.65752 .24668 L
.63682 .26882 L
s
.59332 .24707 m
.55479 .21846 L
.57271 .19703 L
.61254 .22604 L
.59332 .24707 L
s
.55479 .21846 m
.52292 .18503 L
.53977 .16121 L
.57271 .19703 L
.55479 .21846 L
s
.52292 .18503 m
.49911 .15033 L
.51516 .12112 L
.53977 .16121 L
.52292 .18503 L
s
.49911 .15033 m
.48439 .12106 L
.49994 .08204 L
.51516 .12112 L
.49911 .15033 L
s
.48439 .12106 m
.47942 .10868 L
.4948 .06134 L
.49994 .08204 L
.48439 .12106 L
s
.47942 .10868 m
.48439 .12106 L
.49994 .08204 L
.4948 .06134 L
.47942 .10868 L
s
.48439 .12106 m
.49911 .15033 L
.51516 .12112 L
.49994 .08204 L
.48439 .12106 L
s
.49911 .15033 m
.52292 .18503 L
.53977 .16121 L
.51516 .12112 L
.49911 .15033 L
s
.52292 .18503 m
.55479 .21846 L
.57271 .19703 L
.53977 .16121 L
.52292 .18503 L
s
.55479 .21846 m
.59332 .24707 L
.61254 .22604 L
.57271 .19703 L
.55479 .21846 L
s
.59332 .24707 m
.63682 .26882 L
.65752 .24668 L
.61254 .22604 L
.59332 .24707 L
s
.63682 .26882 m
.68341 .28258 L
.70568 .258 L
.65752 .24668 L
.63682 .26882 L
s
.68341 .28258 m
.73103 .28796 L
.75491 .25955 L
.70568 .258 L
.68341 .28258 L
s
.73103 .28796 m
.77761 .28521 L
.80306 .25147 L
.75491 .25955 L
.73103 .28796 L
s
.77761 .28521 m
.82112 .27528 L
.84804 .23445 L
.80306 .25147 L
.77761 .28521 L
s
.82112 .27528 m
.85965 .25987 L
.88787 .20986 L
.84804 .23445 L
.82112 .27528 L
s
.85965 .25987 m
.89152 .24153 L
.92081 .17995 L
.88787 .20986 L
.85965 .25987 L
s
.89152 .24153 m
.91533 .22369 L
.94543 .14844 L
.92081 .17995 L
.89152 .24153 L
s
.91533 .22369 m
.93004 .21046 L
.96064 .12193 L
.94543 .14844 L
.91533 .22369 L
s
.93004 .21046 m
.93502 .20552 L
.96578 .11085 L
.96064 .12193 L
.93004 .21046 L
s
.96578 .11085 m
.96064 .12193 L
.97099 .06134 L
.97619 .01184 L
.96578 .11085 L
s
.96064 .12193 m
.94543 .14844 L
.95561 .10868 L
.97099 .06134 L
.96064 .12193 L
s
.94543 .14844 m
.92081 .17995 L
.93072 .15179 L
.95561 .10868 L
.94543 .14844 L
s
.92081 .17995 m
.88787 .20986 L
.89741 .18878 L
.93072 .15179 L
.92081 .17995 L
s
.88787 .20986 m
.84804 .23445 L
.85714 .21804 L
.89741 .18878 L
.88787 .20986 L
s
.84804 .23445 m
.80306 .25147 L
.81167 .23828 L
.85714 .21804 L
.84804 .23445 L
s
.80306 .25147 m
.75491 .25955 L
.76298 .24863 L
.81167 .23828 L
.80306 .25147 L
s
.75491 .25955 m
.70568 .258 L
.71321 .24863 L
.76298 .24863 L
.75491 .25955 L
s
.70568 .258 m
.65752 .24668 L
.66452 .23828 L
.71321 .24863 L
.70568 .258 L
s
.65752 .24668 m
.61254 .22604 L
.61905 .21804 L
.66452 .23828 L
.65752 .24668 L
s
.61254 .22604 m
.57271 .19703 L
.57878 .18878 L
.61905 .21804 L
.61254 .22604 L
s
.57271 .19703 m
.53977 .16121 L
.54547 .15179 L
.57878 .18878 L
.57271 .19703 L
s
.53977 .16121 m
.51516 .12112 L
.52058 .10868 L
.54547 .15179 L
.53977 .16121 L
s
.51516 .12112 m
.49994 .08204 L
.5052 .06134 L
.52058 .10868 L
.51516 .12112 L
s
.49994 .08204 m
.4948 .06134 L
.5 .01184 L
.5052 .06134 L
.49994 .08204 L
s
.4948 .06134 m
.49994 .08204 L
.5052 .06134 L
.5 .01184 L
.4948 .06134 L
s
.49994 .08204 m
.51516 .12112 L
.52058 .10868 L
.5052 .06134 L
.49994 .08204 L
s
.51516 .12112 m
.53977 .16121 L
.54547 .15179 L
.52058 .10868 L
.51516 .12112 L
s
.53977 .16121 m
.57271 .19703 L
.57878 .18878 L
.54547 .15179 L
.53977 .16121 L
s
.57271 .19703 m
.61254 .22604 L
.61905 .21804 L
.57878 .18878 L
.57271 .19703 L
s
.61254 .22604 m
.65752 .24668 L
.66452 .23828 L
.61905 .21804 L
.61254 .22604 L
s
.65752 .24668 m
.70568 .258 L
.71321 .24863 L
.66452 .23828 L
.65752 .24668 L
s
.70568 .258 m
.75491 .25955 L
.76298 .24863 L
.71321 .24863 L
.70568 .258 L
s
.75491 .25955 m
.80306 .25147 L
.81167 .23828 L
.76298 .24863 L
.75491 .25955 L
s
.80306 .25147 m
.84804 .23445 L
.85714 .21804 L
.81167 .23828 L
.80306 .25147 L
s
.84804 .23445 m
.88787 .20986 L
.89741 .18878 L
.85714 .21804 L
.84804 .23445 L
s
.88787 .20986 m
.92081 .17995 L
.93072 .15179 L
.89741 .18878 L
.88787 .20986 L
s
.92081 .17995 m
.94543 .14844 L
.95561 .10868 L
.93072 .15179 L
.92081 .17995 L
s
.94543 .14844 m
.96064 .12193 L
.97099 .06134 L
.95561 .10868 L
.94543 .14844 L
s
.96064 .12193 m
.96578 .11085 L
.97619 .01184 L
.97099 .06134 L
.96064 .12193 L
s
.96578 .11085 m
.96064 .12193 L
.97099 .06134 L
.97619 .01184 L
.96578 .11085 L
s
.96064 .12193 m
.94543 .14844 L
.95561 .10868 L
.97099 .06134 L
.96064 .12193 L
s
.94543 .14844 m
.92081 .17995 L
.93072 .15179 L
.95561 .10868 L
.94543 .14844 L
s
.92081 .17995 m
.88787 .20986 L
.89741 .18878 L
.93072 .15179 L
.92081 .17995 L
s
.88787 .20986 m
.84804 .23445 L
.85714 .21804 L
.89741 .18878 L
.88787 .20986 L
s
.84804 .23445 m
.80306 .25147 L
.81167 .23828 L
.85714 .21804 L
.84804 .23445 L
s
.80306 .25147 m
.75491 .25955 L
.76298 .24863 L
.81167 .23828 L
.80306 .25147 L
s
.75491 .25955 m
.70568 .258 L
.71321 .24863 L
.76298 .24863 L
.75491 .25955 L
s
.70568 .258 m
.65752 .24668 L
.66452 .23828 L
.71321 .24863 L
.70568 .258 L
s
.65752 .24668 m
.61254 .22604 L
.61905 .21804 L
.66452 .23828 L
.65752 .24668 L
s
.61254 .22604 m
.57271 .19703 L
.57878 .18878 L
.61905 .21804 L
.61254 .22604 L
s
.57271 .19703 m
.53977 .16121 L
.54547 .15179 L
.57878 .18878 L
.57271 .19703 L
s
.53977 .16121 m
.51516 .12112 L
.52058 .10868 L
.54547 .15179 L
.53977 .16121 L
s
.51516 .12112 m
.49994 .08204 L
.5052 .06134 L
.52058 .10868 L
.51516 .12112 L
s
.49994 .08204 m
.4948 .06134 L
.5 .01184 L
.5052 .06134 L
.49994 .08204 L
s
.4948 .06134 m
.49994 .08204 L
.5052 .06134 L
.5 .01184 L
.4948 .06134 L
s
.49994 .08204 m
.51516 .12112 L
.52058 .10868 L
.5052 .06134 L
.49994 .08204 L
s
.51516 .12112 m
.53977 .16121 L
.54547 .15179 L
.52058 .10868 L
.51516 .12112 L
s
.53977 .16121 m
.57271 .19703 L
.57878 .18878 L
.54547 .15179 L
.53977 .16121 L
s
.57271 .19703 m
.61254 .22604 L
.61905 .21804 L
.57878 .18878 L
.57271 .19703 L
s
.61254 .22604 m
.65752 .24668 L
.66452 .23828 L
.61905 .21804 L
.61254 .22604 L
s
.65752 .24668 m
.70568 .258 L
.71321 .24863 L
.66452 .23828 L
.65752 .24668 L
s
.70568 .258 m
.75491 .25955 L
.76298 .24863 L
.71321 .24863 L
.70568 .258 L
s
.75491 .25955 m
.80306 .25147 L
.81167 .23828 L
.76298 .24863 L
.75491 .25955 L
s
.80306 .25147 m
.84804 .23445 L
.85714 .21804 L
.81167 .23828 L
.80306 .25147 L
s
.84804 .23445 m
.88787 .20986 L
.89741 .18878 L
.85714 .21804 L
.84804 .23445 L
s
.88787 .20986 m
.92081 .17995 L
.93072 .15179 L
.89741 .18878 L
.88787 .20986 L
s
.92081 .17995 m
.94543 .14844 L
.95561 .10868 L
.93072 .15179 L
.92081 .17995 L
s
.94543 .14844 m
.96064 .12193 L
.97099 .06134 L
.95561 .10868 L
.94543 .14844 L
s
.96064 .12193 m
.96578 .11085 L
.97619 .01184 L
.97099 .06134 L
.96064 .12193 L
s
.97619 .01184 m
.97099 .06134 L
.96064 .12193 L
.96578 .11085 L
.97619 .01184 L
s
.97099 .06134 m
.95561 .10868 L
.94543 .14844 L
.96064 .12193 L
.97099 .06134 L
s
.95561 .10868 m
.93072 .15179 L
.92081 .17995 L
.94543 .14844 L
.95561 .10868 L
s
.93072 .15179 m
.89741 .18878 L
.88787 .20986 L
.92081 .17995 L
.93072 .15179 L
s
.89741 .18878 m
.85714 .21804 L
.84804 .23445 L
.88787 .20986 L
.89741 .18878 L
s
.85714 .21804 m
.81167 .23828 L
.80306 .25147 L
.84804 .23445 L
.85714 .21804 L
s
.81167 .23828 m
.76298 .24863 L
.75491 .25955 L
.80306 .25147 L
.81167 .23828 L
s
.76298 .24863 m
.71321 .24863 L
.70568 .258 L
.75491 .25955 L
.76298 .24863 L
s
.71321 .24863 m
.66452 .23828 L
.65752 .24668 L
.70568 .258 L
.71321 .24863 L
s
.66452 .23828 m
.61905 .21804 L
.61254 .22604 L
.65752 .24668 L
.66452 .23828 L
s
.61905 .21804 m
.57878 .18878 L
.57271 .19703 L
.61254 .22604 L
.61905 .21804 L
s
.57878 .18878 m
.54547 .15179 L
.53977 .16121 L
.57271 .19703 L
.57878 .18878 L
s
.54547 .15179 m
.52058 .10868 L
.51516 .12112 L
.53977 .16121 L
.54547 .15179 L
s
.52058 .10868 m
.5052 .06134 L
.49994 .08204 L
.51516 .12112 L
.52058 .10868 L
s
.5052 .06134 m
.5 .01184 L
.4948 .06134 L
.49994 .08204 L
.5052 .06134 L
s
.5 .01184 m
.5052 .06134 L
.49994 .08204 L
.4948 .06134 L
.5 .01184 L
s
.5052 .06134 m
.52058 .10868 L
.51516 .12112 L
.49994 .08204 L
.5052 .06134 L
s
.52058 .10868 m
.54547 .15179 L
.53977 .16121 L
.51516 .12112 L
.52058 .10868 L
s
.54547 .15179 m
.57878 .18878 L
.57271 .19703 L
.53977 .16121 L
.54547 .15179 L
s
.57878 .18878 m
.61905 .21804 L
.61254 .22604 L
.57271 .19703 L
.57878 .18878 L
s
.61905 .21804 m
.66452 .23828 L
.65752 .24668 L
.61254 .22604 L
.61905 .21804 L
s
.66452 .23828 m
.71321 .24863 L
.70568 .258 L
.65752 .24668 L
.66452 .23828 L
s
.71321 .24863 m
.76298 .24863 L
.75491 .25955 L
.70568 .258 L
.71321 .24863 L
s
.76298 .24863 m
.81167 .23828 L
.80306 .25147 L
.75491 .25955 L
.76298 .24863 L
s
.81167 .23828 m
.85714 .21804 L
.84804 .23445 L
.80306 .25147 L
.81167 .23828 L
s
.85714 .21804 m
.89741 .18878 L
.88787 .20986 L
.84804 .23445 L
.85714 .21804 L
s
.89741 .18878 m
.93072 .15179 L
.92081 .17995 L
.88787 .20986 L
.89741 .18878 L
s
.93072 .15179 m
.95561 .10868 L
.94543 .14844 L
.92081 .17995 L
.93072 .15179 L
s
.95561 .10868 m
.97099 .06134 L
.96064 .12193 L
.94543 .14844 L
.95561 .10868 L
s
.97099 .06134 m
.97619 .01184 L
.96578 .11085 L
.96064 .12193 L
.97099 .06134 L
s
.97619 .01184 m
.97099 .06134 L
.96064 .12193 L
.96578 .11085 L
.97619 .01184 L
s
.97099 .06134 m
.95561 .10868 L
.94543 .14844 L
.96064 .12193 L
.97099 .06134 L
s
.95561 .10868 m
.93072 .15179 L
.92081 .17995 L
.94543 .14844 L
.95561 .10868 L
s
.93072 .15179 m
.89741 .18878 L
.88787 .20986 L
.92081 .17995 L
.93072 .15179 L
s
.89741 .18878 m
.85714 .21804 L
.84804 .23445 L
.88787 .20986 L
.89741 .18878 L
s
.85714 .21804 m
.81167 .23828 L
.80306 .25147 L
.84804 .23445 L
.85714 .21804 L
s
.81167 .23828 m
.76298 .24863 L
.75491 .25955 L
.80306 .25147 L
.81167 .23828 L
s
.76298 .24863 m
.71321 .24863 L
.70568 .258 L
.75491 .25955 L
.76298 .24863 L
s
.71321 .24863 m
.66452 .23828 L
.65752 .24668 L
.70568 .258 L
.71321 .24863 L
s
.66452 .23828 m
.61905 .21804 L
.61254 .22604 L
.65752 .24668 L
.66452 .23828 L
s
.61905 .21804 m
.57878 .18878 L
.57271 .19703 L
.61254 .22604 L
.61905 .21804 L
s
.57878 .18878 m
.54547 .15179 L
.53977 .16121 L
.57271 .19703 L
.57878 .18878 L
s
.54547 .15179 m
.52058 .10868 L
.51516 .12112 L
.53977 .16121 L
.54547 .15179 L
s
.52058 .10868 m
.5052 .06134 L
.49994 .08204 L
.51516 .12112 L
.52058 .10868 L
s
.5052 .06134 m
.5 .01184 L
.4948 .06134 L
.49994 .08204 L
.5052 .06134 L
s
.5 .01184 m
.5052 .06134 L
.49994 .08204 L
.4948 .06134 L
.5 .01184 L
s
.5052 .06134 m
.52058 .10868 L
.51516 .12112 L
.49994 .08204 L
.5052 .06134 L
s
.52058 .10868 m
.54547 .15179 L
.53977 .16121 L
.51516 .12112 L
.52058 .10868 L
s
.54547 .15179 m
.57878 .18878 L
.57271 .19703 L
.53977 .16121 L
.54547 .15179 L
s
.57878 .18878 m
.61905 .21804 L
.61254 .22604 L
.57271 .19703 L
.57878 .18878 L
s
.61905 .21804 m
.66452 .23828 L
.65752 .24668 L
.61254 .22604 L
.61905 .21804 L
s
.66452 .23828 m
.71321 .24863 L
.70568 .258 L
.65752 .24668 L
.66452 .23828 L
s
.71321 .24863 m
.76298 .24863 L
.75491 .25955 L
.70568 .258 L
.71321 .24863 L
s
.76298 .24863 m
.81167 .23828 L
.80306 .25147 L
.75491 .25955 L
.76298 .24863 L
s
.81167 .23828 m
.85714 .21804 L
.84804 .23445 L
.80306 .25147 L
.81167 .23828 L
s
.85714 .21804 m
.89741 .18878 L
.88787 .20986 L
.84804 .23445 L
.85714 .21804 L
s
.89741 .18878 m
.93072 .15179 L
.92081 .17995 L
.88787 .20986 L
.89741 .18878 L
s
.93072 .15179 m
.95561 .10868 L
.94543 .14844 L
.92081 .17995 L
.93072 .15179 L
s
.95561 .10868 m
.97099 .06134 L
.96064 .12193 L
.94543 .14844 L
.95561 .10868 L
s
.97099 .06134 m
.97619 .01184 L
.96578 .11085 L
.96064 .12193 L
.97099 .06134 L
s
.96578 .11085 m
.96064 .12193 L
.93004 .21046 L
.93502 .20552 L
.96578 .11085 L
s
.96064 .12193 m
.94543 .14844 L
.91533 .22369 L
.93004 .21046 L
.96064 .12193 L
s
.94543 .14844 m
.92081 .17995 L
.89152 .24153 L
.91533 .22369 L
.94543 .14844 L
s
.92081 .17995 m
.88787 .20986 L
.85965 .25987 L
.89152 .24153 L
.92081 .17995 L
s
.88787 .20986 m
.84804 .23445 L
.82112 .27528 L
.85965 .25987 L
.88787 .20986 L
s
.84804 .23445 m
.80306 .25147 L
.77761 .28521 L
.82112 .27528 L
.84804 .23445 L
s
.80306 .25147 m
.75491 .25955 L
.73103 .28796 L
.77761 .28521 L
.80306 .25147 L
s
.75491 .25955 m
.70568 .258 L
.68341 .28258 L
.73103 .28796 L
.75491 .25955 L
s
.70568 .258 m
.65752 .24668 L
.63682 .26882 L
.68341 .28258 L
.70568 .258 L
s
.65752 .24668 m
.61254 .22604 L
.59332 .24707 L
.63682 .26882 L
.65752 .24668 L
s
.61254 .22604 m
.57271 .19703 L
.55479 .21846 L
.59332 .24707 L
.61254 .22604 L
s
.57271 .19703 m
.53977 .16121 L
.52292 .18503 L
.55479 .21846 L
.57271 .19703 L
s
.53977 .16121 m
.51516 .12112 L
.49911 .15033 L
.52292 .18503 L
.53977 .16121 L
s
.51516 .12112 m
.49994 .08204 L
.48439 .12106 L
.49911 .15033 L
.51516 .12112 L
s
.49994 .08204 m
.4948 .06134 L
.47942 .10868 L
.48439 .12106 L
.49994 .08204 L
s
.4948 .06134 m
.49994 .08204 L
.48439 .12106 L
.47942 .10868 L
.4948 .06134 L
s
.49994 .08204 m
.51516 .12112 L
.49911 .15033 L
.48439 .12106 L
.49994 .08204 L
s
.51516 .12112 m
.53977 .16121 L
.52292 .18503 L
.49911 .15033 L
.51516 .12112 L
s
.53977 .16121 m
.57271 .19703 L
.55479 .21846 L
.52292 .18503 L
.53977 .16121 L
s
.57271 .19703 m
.61254 .22604 L
.59332 .24707 L
.55479 .21846 L
.57271 .19703 L
s
.61254 .22604 m
.65752 .24668 L
.63682 .26882 L
.59332 .24707 L
.61254 .22604 L
s
.65752 .24668 m
.70568 .258 L
.68341 .28258 L
.63682 .26882 L
.65752 .24668 L
s
.70568 .258 m
.75491 .25955 L
.73103 .28796 L
.68341 .28258 L
.70568 .258 L
s
.75491 .25955 m
.80306 .25147 L
.77761 .28521 L
.73103 .28796 L
.75491 .25955 L
s
.80306 .25147 m
.84804 .23445 L
.82112 .27528 L
.77761 .28521 L
.80306 .25147 L
s
.84804 .23445 m
.88787 .20986 L
.85965 .25987 L
.82112 .27528 L
.84804 .23445 L
s
.88787 .20986 m
.92081 .17995 L
.89152 .24153 L
.85965 .25987 L
.88787 .20986 L
s
.92081 .17995 m
.94543 .14844 L
.91533 .22369 L
.89152 .24153 L
.92081 .17995 L
s
.94543 .14844 m
.96064 .12193 L
.93004 .21046 L
.91533 .22369 L
.94543 .14844 L
s
.96064 .12193 m
.96578 .11085 L
.93502 .20552 L
.93004 .21046 L
.96064 .12193 L
s
.96578 .11085 m
.96064 .12193 L
.93004 .21046 L
.93502 .20552 L
.96578 .11085 L
s
.96064 .12193 m
.94543 .14844 L
.91533 .22369 L
.93004 .21046 L
.96064 .12193 L
s
.94543 .14844 m
.92081 .17995 L
.89152 .24153 L
.91533 .22369 L
.94543 .14844 L
s
.92081 .17995 m
.88787 .20986 L
.85965 .25987 L
.89152 .24153 L
.92081 .17995 L
s
.88787 .20986 m
.84804 .23445 L
.82112 .27528 L
.85965 .25987 L
.88787 .20986 L
s
.84804 .23445 m
.80306 .25147 L
.77761 .28521 L
.82112 .27528 L
.84804 .23445 L
s
.80306 .25147 m
.75491 .25955 L
.73103 .28796 L
.77761 .28521 L
.80306 .25147 L
s
.75491 .25955 m
.70568 .258 L
.68341 .28258 L
.73103 .28796 L
.75491 .25955 L
s
.70568 .258 m
.65752 .24668 L
.63682 .26882 L
.68341 .28258 L
.70568 .258 L
s
.65752 .24668 m
.61254 .22604 L
.59332 .24707 L
.63682 .26882 L
.65752 .24668 L
s
.61254 .22604 m
.57271 .19703 L
.55479 .21846 L
.59332 .24707 L
.61254 .22604 L
s
.57271 .19703 m
.53977 .16121 L
.52292 .18503 L
.55479 .21846 L
.57271 .19703 L
s
.53977 .16121 m
.51516 .12112 L
.49911 .15033 L
.52292 .18503 L
.53977 .16121 L
s
.51516 .12112 m
.49994 .08204 L
.48439 .12106 L
.49911 .15033 L
.51516 .12112 L
s
.49994 .08204 m
.4948 .06134 L
.47942 .10868 L
.48439 .12106 L
.49994 .08204 L
s
.4948 .06134 m
.49994 .08204 L
.48439 .12106 L
.47942 .10868 L
.4948 .06134 L
s
.49994 .08204 m
.51516 .12112 L
.49911 .15033 L
.48439 .12106 L
.49994 .08204 L
s
.51516 .12112 m
.53977 .16121 L
.52292 .18503 L
.49911 .15033 L
.51516 .12112 L
s
.53977 .16121 m
.57271 .19703 L
.55479 .21846 L
.52292 .18503 L
.53977 .16121 L
s
.57271 .19703 m
.61254 .22604 L
.59332 .24707 L
.55479 .21846 L
.57271 .19703 L
s
.61254 .22604 m
.65752 .24668 L
.63682 .26882 L
.59332 .24707 L
.61254 .22604 L
s
.65752 .24668 m
.70568 .258 L
.68341 .28258 L
.63682 .26882 L
.65752 .24668 L
s
.70568 .258 m
.75491 .25955 L
.73103 .28796 L
.68341 .28258 L
.70568 .258 L
s
.75491 .25955 m
.80306 .25147 L
.77761 .28521 L
.73103 .28796 L
.75491 .25955 L
s
.80306 .25147 m
.84804 .23445 L
.82112 .27528 L
.77761 .28521 L
.80306 .25147 L
s
.84804 .23445 m
.88787 .20986 L
.85965 .25987 L
.82112 .27528 L
.84804 .23445 L
s
.88787 .20986 m
.92081 .17995 L
.89152 .24153 L
.85965 .25987 L
.88787 .20986 L
s
.92081 .17995 m
.94543 .14844 L
.91533 .22369 L
.89152 .24153 L
.92081 .17995 L
s
.94543 .14844 m
.96064 .12193 L
.93004 .21046 L
.91533 .22369 L
.94543 .14844 L
s
.96064 .12193 m
.96578 .11085 L
.93502 .20552 L
.93004 .21046 L
.96064 .12193 L
s
.93502 .20552 m
.93004 .21046 L
.88054 .29416 L
.88525 .29174 L
.93502 .20552 L
s
.93004 .21046 m
.91533 .22369 L
.86663 .30076 L
.88054 .29416 L
.93004 .21046 L
s
.91533 .22369 m
.89152 .24153 L
.84412 .30976 L
.86663 .30076 L
.91533 .22369 L
s
.89152 .24153 m
.85965 .25987 L
.81399 .31882 L
.84412 .30976 L
.89152 .24153 L
s
.85965 .25987 m
.82112 .27528 L
.77757 .32559 L
.81399 .31882 L
.85965 .25987 L
s
.82112 .27528 m
.77761 .28521 L
.73644 .32806 L
.77757 .32559 L
.82112 .27528 L
s
.77761 .28521 m
.73103 .28796 L
.6924 .32474 L
.73644 .32806 L
.77761 .28521 L
s
.73103 .28796 m
.68341 .28258 L
.64738 .31477 L
.6924 .32474 L
.73103 .28796 L
s
.68341 .28258 m
.63682 .26882 L
.60334 .29791 L
.64738 .31477 L
.68341 .28258 L
s
.63682 .26882 m
.59332 .24707 L
.56221 .27463 L
.60334 .29791 L
.63682 .26882 L
s
.59332 .24707 m
.55479 .21846 L
.52578 .24619 L
.56221 .27463 L
.59332 .24707 L
s
.55479 .21846 m
.52292 .18503 L
.49566 .21487 L
.52578 .24619 L
.55479 .21846 L
s
.52292 .18503 m
.49911 .15033 L
.47315 .18446 L
.49566 .21487 L
.52292 .18503 L
s
.49911 .15033 m
.48439 .12106 L
.45923 .16095 L
.47315 .18446 L
.49911 .15033 L
s
.48439 .12106 m
.47942 .10868 L
.45453 .15179 L
.45923 .16095 L
.48439 .12106 L
s
.47942 .10868 m
.48439 .12106 L
.45923 .16095 L
.45453 .15179 L
.47942 .10868 L
s
.48439 .12106 m
.49911 .15033 L
.47315 .18446 L
.45923 .16095 L
.48439 .12106 L
s
.49911 .15033 m
.52292 .18503 L
.49566 .21487 L
.47315 .18446 L
.49911 .15033 L
s
.52292 .18503 m
.55479 .21846 L
.52578 .24619 L
.49566 .21487 L
.52292 .18503 L
s
.55479 .21846 m
.59332 .24707 L
.56221 .27463 L
.52578 .24619 L
.55479 .21846 L
s
.59332 .24707 m
.63682 .26882 L
.60334 .29791 L
.56221 .27463 L
.59332 .24707 L
s
.63682 .26882 m
.68341 .28258 L
.64738 .31477 L
.60334 .29791 L
.63682 .26882 L
s
.68341 .28258 m
.73103 .28796 L
.6924 .32474 L
.64738 .31477 L
.68341 .28258 L
s
.73103 .28796 m
.77761 .28521 L
.73644 .32806 L
.6924 .32474 L
.73103 .28796 L
s
.77761 .28521 m
.82112 .27528 L
.77757 .32559 L
.73644 .32806 L
.77761 .28521 L
s
.82112 .27528 m
.85965 .25987 L
.81399 .31882 L
.77757 .32559 L
.82112 .27528 L
s
.85965 .25987 m
.89152 .24153 L
.84412 .30976 L
.81399 .31882 L
.85965 .25987 L
s
.89152 .24153 m
.91533 .22369 L
.86663 .30076 L
.84412 .30976 L
.89152 .24153 L
s
.91533 .22369 m
.93004 .21046 L
.88054 .29416 L
.86663 .30076 L
.91533 .22369 L
s
.93004 .21046 m
.93502 .20552 L
.88525 .29174 L
.88054 .29416 L
.93004 .21046 L
s
.93502 .20552 m
.93004 .21046 L
.88054 .29416 L
.88525 .29174 L
.93502 .20552 L
s
.93004 .21046 m
.91533 .22369 L
.86663 .30076 L
.88054 .29416 L
.93004 .21046 L
s
.91533 .22369 m
.89152 .24153 L
.84412 .30976 L
.86663 .30076 L
.91533 .22369 L
s
.89152 .24153 m
.85965 .25987 L
.81399 .31882 L
.84412 .30976 L
.89152 .24153 L
s
.85965 .25987 m
.82112 .27528 L
.77757 .32559 L
.81399 .31882 L
.85965 .25987 L
s
.82112 .27528 m
.77761 .28521 L
.73644 .32806 L
.77757 .32559 L
.82112 .27528 L
s
.77761 .28521 m
.73103 .28796 L
.6924 .32474 L
.73644 .32806 L
.77761 .28521 L
s
.73103 .28796 m
.68341 .28258 L
.64738 .31477 L
.6924 .32474 L
.73103 .28796 L
s
.68341 .28258 m
.63682 .26882 L
.60334 .29791 L
.64738 .31477 L
.68341 .28258 L
s
.63682 .26882 m
.59332 .24707 L
.56221 .27463 L
.60334 .29791 L
.63682 .26882 L
s
.59332 .24707 m
.55479 .21846 L
.52578 .24619 L
.56221 .27463 L
.59332 .24707 L
s
.55479 .21846 m
.52292 .18503 L
.49566 .21487 L
.52578 .24619 L
.55479 .21846 L
s
.52292 .18503 m
.49911 .15033 L
.47315 .18446 L
.49566 .21487 L
.52292 .18503 L
s
.49911 .15033 m
.48439 .12106 L
.45923 .16095 L
.47315 .18446 L
.49911 .15033 L
s
.48439 .12106 m
.47942 .10868 L
.45453 .15179 L
.45923 .16095 L
.48439 .12106 L
s
.47942 .10868 m
.48439 .12106 L
.45923 .16095 L
.45453 .15179 L
.47942 .10868 L
s
.48439 .12106 m
.49911 .15033 L
.47315 .18446 L
.45923 .16095 L
.48439 .12106 L
s
.49911 .15033 m
.52292 .18503 L
.49566 .21487 L
.47315 .18446 L
.49911 .15033 L
s
.52292 .18503 m
.55479 .21846 L
.52578 .24619 L
.49566 .21487 L
.52292 .18503 L
s
.55479 .21846 m
.59332 .24707 L
.56221 .27463 L
.52578 .24619 L
.55479 .21846 L
s
.59332 .24707 m
.63682 .26882 L
.60334 .29791 L
.56221 .27463 L
.59332 .24707 L
s
.63682 .26882 m
.68341 .28258 L
.64738 .31477 L
.60334 .29791 L
.63682 .26882 L
s
.68341 .28258 m
.73103 .28796 L
.6924 .32474 L
.64738 .31477 L
.68341 .28258 L
s
.73103 .28796 m
.77761 .28521 L
.73644 .32806 L
.6924 .32474 L
.73103 .28796 L
s
.77761 .28521 m
.82112 .27528 L
.77757 .32559 L
.73644 .32806 L
.77761 .28521 L
s
.82112 .27528 m
.85965 .25987 L
.81399 .31882 L
.77757 .32559 L
.82112 .27528 L
s
.85965 .25987 m
.89152 .24153 L
.84412 .30976 L
.81399 .31882 L
.85965 .25987 L
s
.89152 .24153 m
.91533 .22369 L
.86663 .30076 L
.84412 .30976 L
.89152 .24153 L
s
.91533 .22369 m
.93004 .21046 L
.88054 .29416 L
.86663 .30076 L
.91533 .22369 L
s
.93004 .21046 m
.93502 .20552 L
.88525 .29174 L
.88054 .29416 L
.93004 .21046 L
s
.88525 .29174 m
.88054 .29416 L
.81429 .36668 L
.81863 .36572 L
.88525 .29174 L
s
.88054 .29416 m
.86663 .30076 L
.80145 .36919 L
.81429 .36668 L
.88054 .29416 L
s
.86663 .30076 m
.84412 .30976 L
.78068 .37226 L
.80145 .36919 L
.86663 .30076 L
s
.84412 .30976 m
.81399 .31882 L
.75289 .37447 L
.78068 .37226 L
.84412 .30976 L
s
.81399 .31882 m
.77757 .32559 L
.71928 .37428 L
.75289 .37447 L
.81399 .31882 L
s
.77757 .32559 m
.73644 .32806 L
.68133 .3703 L
.71928 .37428 L
.77757 .32559 L
s
.73644 .32806 m
.6924 .32474 L
.6407 .36145 L
.68133 .3703 L
.73644 .32806 L
s
.6924 .32474 m
.64738 .31477 L
.59916 .34712 L
.6407 .36145 L
.6924 .32474 L
s
.64738 .31477 m
.60334 .29791 L
.55852 .32723 L
.59916 .34712 L
.64738 .31477 L
s
.60334 .29791 m
.56221 .27463 L
.52057 .30236 L
.55852 .32723 L
.60334 .29791 L
s
.56221 .27463 m
.52578 .24619 L
.48697 .27385 L
.52057 .30236 L
.56221 .27463 L
s
.52578 .24619 m
.49566 .21487 L
.45917 .24404 L
.48697 .27385 L
.52578 .24619 L
s
.49566 .21487 m
.47315 .18446 L
.4384 .21653 L
.45917 .24404 L
.49566 .21487 L
s
.47315 .18446 m
.45923 .16095 L
.42556 .19634 L
.4384 .21653 L
.47315 .18446 L
s
.45923 .16095 m
.45453 .15179 L
.42122 .18878 L
.42556 .19634 L
.45923 .16095 L
s
.45453 .15179 m
.45923 .16095 L
.42556 .19634 L
.42122 .18878 L
.45453 .15179 L
s
.45923 .16095 m
.47315 .18446 L
.4384 .21653 L
.42556 .19634 L
.45923 .16095 L
s
.47315 .18446 m
.49566 .21487 L
.45917 .24404 L
.4384 .21653 L
.47315 .18446 L
s
.49566 .21487 m
.52578 .24619 L
.48697 .27385 L
.45917 .24404 L
.49566 .21487 L
s
.52578 .24619 m
.56221 .27463 L
.52057 .30236 L
.48697 .27385 L
.52578 .24619 L
s
.56221 .27463 m
.60334 .29791 L
.55852 .32723 L
.52057 .30236 L
.56221 .27463 L
s
.60334 .29791 m
.64738 .31477 L
.59916 .34712 L
.55852 .32723 L
.60334 .29791 L
s
.64738 .31477 m
.6924 .32474 L
.6407 .36145 L
.59916 .34712 L
.64738 .31477 L
s
.6924 .32474 m
.73644 .32806 L
.68133 .3703 L
.6407 .36145 L
.6924 .32474 L
s
.73644 .32806 m
.77757 .32559 L
.71928 .37428 L
.68133 .3703 L
.73644 .32806 L
s
.77757 .32559 m
.81399 .31882 L
.75289 .37447 L
.71928 .37428 L
.77757 .32559 L
s
.81399 .31882 m
.84412 .30976 L
.78068 .37226 L
.75289 .37447 L
.81399 .31882 L
s
.84412 .30976 m
.86663 .30076 L
.80145 .36919 L
.78068 .37226 L
.84412 .30976 L
s
.86663 .30076 m
.88054 .29416 L
.81429 .36668 L
.80145 .36919 L
.86663 .30076 L
s
.88054 .29416 m
.88525 .29174 L
.81863 .36572 L
.81429 .36668 L
.88054 .29416 L
s
.88525 .29174 m
.88054 .29416 L
.81429 .36668 L
.81863 .36572 L
.88525 .29174 L
s
.88054 .29416 m
.86663 .30076 L
.80145 .36919 L
.81429 .36668 L
.88054 .29416 L
s
.86663 .30076 m
.84412 .30976 L
.78068 .37226 L
.80145 .36919 L
.86663 .30076 L
s
.84412 .30976 m
.81399 .31882 L
.75289 .37447 L
.78068 .37226 L
.84412 .30976 L
s
.81399 .31882 m
.77757 .32559 L
.71928 .37428 L
.75289 .37447 L
.81399 .31882 L
s
.77757 .32559 m
.73644 .32806 L
.68133 .3703 L
.71928 .37428 L
.77757 .32559 L
s
.73644 .32806 m
.6924 .32474 L
.6407 .36145 L
.68133 .3703 L
.73644 .32806 L
s
.6924 .32474 m
.64738 .31477 L
.59916 .34712 L
.6407 .36145 L
.6924 .32474 L
s
.64738 .31477 m
.60334 .29791 L
.55852 .32723 L
.59916 .34712 L
.64738 .31477 L
s
.60334 .29791 m
.56221 .27463 L
.52057 .30236 L
.55852 .32723 L
.60334 .29791 L
s
.56221 .27463 m
.52578 .24619 L
.48697 .27385 L
.52057 .30236 L
.56221 .27463 L
s
.52578 .24619 m
.49566 .21487 L
.45917 .24404 L
.48697 .27385 L
.52578 .24619 L
s
.49566 .21487 m
.47315 .18446 L
.4384 .21653 L
.45917 .24404 L
.49566 .21487 L
s
.47315 .18446 m
.45923 .16095 L
.42556 .19634 L
.4384 .21653 L
.47315 .18446 L
s
.45923 .16095 m
.45453 .15179 L
.42122 .18878 L
.42556 .19634 L
.45923 .16095 L
s
.45453 .15179 m
.45923 .16095 L
.42556 .19634 L
.42122 .18878 L
.45453 .15179 L
s
.45923 .16095 m
.47315 .18446 L
.4384 .21653 L
.42556 .19634 L
.45923 .16095 L
s
.47315 .18446 m
.49566 .21487 L
.45917 .24404 L
.4384 .21653 L
.47315 .18446 L
s
.49566 .21487 m
.52578 .24619 L
.48697 .27385 L
.45917 .24404 L
.49566 .21487 L
s
.52578 .24619 m
.56221 .27463 L
.52057 .30236 L
.48697 .27385 L
.52578 .24619 L
s
.56221 .27463 m
.60334 .29791 L
.55852 .32723 L
.52057 .30236 L
.56221 .27463 L
s
.60334 .29791 m
.64738 .31477 L
.59916 .34712 L
.55852 .32723 L
.60334 .29791 L
s
.64738 .31477 m
.6924 .32474 L
.6407 .36145 L
.59916 .34712 L
.64738 .31477 L
s
.6924 .32474 m
.73644 .32806 L
.68133 .3703 L
.6407 .36145 L
.6924 .32474 L
s
.73644 .32806 m
.77757 .32559 L
.71928 .37428 L
.68133 .3703 L
.73644 .32806 L
s
.77757 .32559 m
.81399 .31882 L
.75289 .37447 L
.71928 .37428 L
.77757 .32559 L
s
.81399 .31882 m
.84412 .30976 L
.78068 .37226 L
.75289 .37447 L
.81399 .31882 L
s
.84412 .30976 m
.86663 .30076 L
.80145 .36919 L
.78068 .37226 L
.84412 .30976 L
s
.86663 .30076 m
.88054 .29416 L
.81429 .36668 L
.80145 .36919 L
.86663 .30076 L
s
.88054 .29416 m
.88525 .29174 L
.81863 .36572 L
.81429 .36668 L
.88054 .29416 L
s
.81863 .36572 m
.81429 .36668 L
.73419 .42421 L
.7381 .42423 L
.81863 .36572 L
s
.81429 .36668 m
.80145 .36919 L
.72266 .42394 L
.73419 .42421 L
.81429 .36668 L
s
.80145 .36919 m
.78068 .37226 L
.70399 .42282 L
.72266 .42394 L
.80145 .36919 L
s
.78068 .37226 m
.75289 .37447 L
.67901 .41998 L
.70399 .42282 L
.78068 .37226 L
s
.75289 .37447 m
.71928 .37428 L
.64881 .41445 L
.67901 .41998 L
.75289 .37447 L
s
.71928 .37428 m
.68133 .3703 L
.61471 .40534 L
.64881 .41445 L
.71928 .37428 L
s
.68133 .3703 m
.6407 .36145 L
.57819 .39197 L
.61471 .40534 L
.68133 .3703 L
s
.6407 .36145 m
.59916 .34712 L
.54086 .37401 L
.57819 .39197 L
.6407 .36145 L
s
.59916 .34712 m
.55852 .32723 L
.50434 .35159 L
.54086 .37401 L
.59916 .34712 L
s
.55852 .32723 m
.52057 .30236 L
.47024 .3254 L
.50434 .35159 L
.55852 .32723 L
s
.52057 .30236 m
.48697 .27385 L
.44004 .29685 L
.47024 .3254 L
.52057 .30236 L
s
.48697 .27385 m
.45917 .24404 L
.41506 .26819 L
.44004 .29685 L
.48697 .27385 L
s
.45917 .24404 m
.4384 .21653 L
.39639 .24272 L
.41506 .26819 L
.45917 .24404 L
s
.4384 .21653 m
.42556 .19634 L
.38485 .22465 L
.39639 .24272 L
.4384 .21653 L
s
.42556 .19634 m
.42122 .18878 L
.38095 .21804 L
.38485 .22465 L
.42556 .19634 L
s
.42122 .18878 m
.42556 .19634 L
.38485 .22465 L
.38095 .21804 L
.42122 .18878 L
s
.42556 .19634 m
.4384 .21653 L
.39639 .24272 L
.38485 .22465 L
.42556 .19634 L
s
.4384 .21653 m
.45917 .24404 L
.41506 .26819 L
.39639 .24272 L
.4384 .21653 L
s
.45917 .24404 m
.48697 .27385 L
.44004 .29685 L
.41506 .26819 L
.45917 .24404 L
s
.48697 .27385 m
.52057 .30236 L
.47024 .3254 L
.44004 .29685 L
.48697 .27385 L
s
.52057 .30236 m
.55852 .32723 L
.50434 .35159 L
.47024 .3254 L
.52057 .30236 L
s
.55852 .32723 m
.59916 .34712 L
.54086 .37401 L
.50434 .35159 L
.55852 .32723 L
s
.59916 .34712 m
.6407 .36145 L
.57819 .39197 L
.54086 .37401 L
.59916 .34712 L
s
.6407 .36145 m
.68133 .3703 L
.61471 .40534 L
.57819 .39197 L
.6407 .36145 L
s
.68133 .3703 m
.71928 .37428 L
.64881 .41445 L
.61471 .40534 L
.68133 .3703 L
s
.71928 .37428 m
.75289 .37447 L
.67901 .41998 L
.64881 .41445 L
.71928 .37428 L
s
.75289 .37447 m
.78068 .37226 L
.70399 .42282 L
.67901 .41998 L
.75289 .37447 L
s
.78068 .37226 m
.80145 .36919 L
.72266 .42394 L
.70399 .42282 L
.78068 .37226 L
s
.80145 .36919 m
.81429 .36668 L
.73419 .42421 L
.72266 .42394 L
.80145 .36919 L
s
.81429 .36668 m
.81863 .36572 L
.7381 .42423 L
.73419 .42421 L
.81429 .36668 L
s
.81863 .36572 m
.81429 .36668 L
.73419 .42421 L
.7381 .42423 L
.81863 .36572 L
s
.81429 .36668 m
.80145 .36919 L
.72266 .42394 L
.73419 .42421 L
.81429 .36668 L
s
.80145 .36919 m
.78068 .37226 L
.70399 .42282 L
.72266 .42394 L
.80145 .36919 L
s
.78068 .37226 m
.75289 .37447 L
.67901 .41998 L
.70399 .42282 L
.78068 .37226 L
s
.75289 .37447 m
.71928 .37428 L
.64881 .41445 L
.67901 .41998 L
.75289 .37447 L
s
.71928 .37428 m
.68133 .3703 L
.61471 .40534 L
.64881 .41445 L
.71928 .37428 L
s
.68133 .3703 m
.6407 .36145 L
.57819 .39197 L
.61471 .40534 L
.68133 .3703 L
s
.6407 .36145 m
.59916 .34712 L
.54086 .37401 L
.57819 .39197 L
.6407 .36145 L
s
.59916 .34712 m
.55852 .32723 L
.50434 .35159 L
.54086 .37401 L
.59916 .34712 L
s
.55852 .32723 m
.52057 .30236 L
.47024 .3254 L
.50434 .35159 L
.55852 .32723 L
s
.52057 .30236 m
.48697 .27385 L
.44004 .29685 L
.47024 .3254 L
.52057 .30236 L
s
.48697 .27385 m
.45917 .24404 L
.41506 .26819 L
.44004 .29685 L
.48697 .27385 L
s
.45917 .24404 m
.4384 .21653 L
.39639 .24272 L
.41506 .26819 L
.45917 .24404 L
s
.4384 .21653 m
.42556 .19634 L
.38485 .22465 L
.39639 .24272 L
.4384 .21653 L
s
.42556 .19634 m
.42122 .18878 L
.38095 .21804 L
.38485 .22465 L
.42556 .19634 L
s
.42122 .18878 m
.42556 .19634 L
.38485 .22465 L
.38095 .21804 L
.42122 .18878 L
s
.42556 .19634 m
.4384 .21653 L
.39639 .24272 L
.38485 .22465 L
.42556 .19634 L
s
.4384 .21653 m
.45917 .24404 L
.41506 .26819 L
.39639 .24272 L
.4384 .21653 L
s
.45917 .24404 m
.48697 .27385 L
.44004 .29685 L
.41506 .26819 L
.45917 .24404 L
s
.48697 .27385 m
.52057 .30236 L
.47024 .3254 L
.44004 .29685 L
.48697 .27385 L
s
.52057 .30236 m
.55852 .32723 L
.50434 .35159 L
.47024 .3254 L
.52057 .30236 L
s
.55852 .32723 m
.59916 .34712 L
.54086 .37401 L
.50434 .35159 L
.55852 .32723 L
s
.59916 .34712 m
.6407 .36145 L
.57819 .39197 L
.54086 .37401 L
.59916 .34712 L
s
.6407 .36145 m
.68133 .3703 L
.61471 .40534 L
.57819 .39197 L
.6407 .36145 L
s
.68133 .3703 m
.71928 .37428 L
.64881 .41445 L
.61471 .40534 L
.68133 .3703 L
s
.71928 .37428 m
.75289 .37447 L
.67901 .41998 L
.64881 .41445 L
.71928 .37428 L
s
.75289 .37447 m
.78068 .37226 L
.70399 .42282 L
.67901 .41998 L
.75289 .37447 L
s
.78068 .37226 m
.80145 .36919 L
.72266 .42394 L
.70399 .42282 L
.78068 .37226 L
s
.80145 .36919 m
.81429 .36668 L
.73419 .42421 L
.72266 .42394 L
.80145 .36919 L
s
.81429 .36668 m
.81863 .36572 L
.7381 .42423 L
.73419 .42421 L
.81429 .36668 L
s
.7381 .42423 m
.73419 .42421 L
.64375 .46403 L
.64715 .46472 L
.7381 .42423 L
s
.73419 .42421 m
.72266 .42394 L
.63368 .46181 L
.64375 .46403 L
.73419 .42421 L
s
.72266 .42394 m
.70399 .42282 L
.61739 .45771 L
.63368 .46181 L
.72266 .42394 L
s
.70399 .42282 m
.67901 .41998 L
.59559 .45123 L
.61739 .45771 L
.70399 .42282 L
s
.67901 .41998 m
.64881 .41445 L
.56923 .44179 L
.59559 .45123 L
.67901 .41998 L
s
.64881 .41445 m
.61471 .40534 L
.53947 .42888 L
.56923 .44179 L
.64881 .41445 L
s
.61471 .40534 m
.57819 .39197 L
.5076 .41215 L
.53947 .42888 L
.61471 .40534 L
s
.57819 .39197 m
.54086 .37401 L
.47503 .39154 L
.5076 .41215 L
.57819 .39197 L
s
.54086 .37401 m
.50434 .35159 L
.44316 .36735 L
.47503 .39154 L
.54086 .37401 L
s
.50434 .35159 m
.47024 .3254 L
.4134 .34039 L
.44316 .36735 L
.50434 .35159 L
s
.47024 .3254 m
.44004 .29685 L
.38704 .31207 L
.4134 .34039 L
.47024 .3254 L
s
.44004 .29685 m
.41506 .26819 L
.36524 .28452 L
.38704 .31207 L
.44004 .29685 L
s
.41506 .26819 m
.39639 .24272 L
.34895 .26072 L
.36524 .28452 L
.41506 .26819 L
s
.39639 .24272 m
.38485 .22465 L
.33889 .24423 L
.34895 .26072 L
.39639 .24272 L
s
.38485 .22465 m
.38095 .21804 L
.33548 .23828 L
.33889 .24423 L
.38485 .22465 L
s
.38095 .21804 m
.38485 .22465 L
.33889 .24423 L
.33548 .23828 L
.38095 .21804 L
s
.38485 .22465 m
.39639 .24272 L
.34895 .26072 L
.33889 .24423 L
.38485 .22465 L
s
.39639 .24272 m
.41506 .26819 L
.36524 .28452 L
.34895 .26072 L
.39639 .24272 L
s
.41506 .26819 m
.44004 .29685 L
.38704 .31207 L
.36524 .28452 L
.41506 .26819 L
s
.44004 .29685 m
.47024 .3254 L
.4134 .34039 L
.38704 .31207 L
.44004 .29685 L
s
.47024 .3254 m
.50434 .35159 L
.44316 .36735 L
.4134 .34039 L
.47024 .3254 L
s
.50434 .35159 m
.54086 .37401 L
.47503 .39154 L
.44316 .36735 L
.50434 .35159 L
s
.54086 .37401 m
.57819 .39197 L
.5076 .41215 L
.47503 .39154 L
.54086 .37401 L
s
.57819 .39197 m
.61471 .40534 L
.53947 .42888 L
.5076 .41215 L
.57819 .39197 L
s
.61471 .40534 m
.64881 .41445 L
.56923 .44179 L
.53947 .42888 L
.61471 .40534 L
s
.64881 .41445 m
.67901 .41998 L
.59559 .45123 L
.56923 .44179 L
.64881 .41445 L
s
.67901 .41998 m
.70399 .42282 L
.61739 .45771 L
.59559 .45123 L
.67901 .41998 L
s
.70399 .42282 m
.72266 .42394 L
.63368 .46181 L
.61739 .45771 L
.70399 .42282 L
s
.72266 .42394 m
.73419 .42421 L
.64375 .46403 L
.63368 .46181 L
.72266 .42394 L
s
.73419 .42421 m
.7381 .42423 L
.64715 .46472 L
.64375 .46403 L
.73419 .42421 L
s
.7381 .42423 m
.73419 .42421 L
.64375 .46403 L
.64715 .46472 L
.7381 .42423 L
s
.73419 .42421 m
.72266 .42394 L
.63368 .46181 L
.64375 .46403 L
.73419 .42421 L
s
.72266 .42394 m
.70399 .42282 L
.61739 .45771 L
.63368 .46181 L
.72266 .42394 L
s
.70399 .42282 m
.67901 .41998 L
.59559 .45123 L
.61739 .45771 L
.70399 .42282 L
s
.67901 .41998 m
.64881 .41445 L
.56923 .44179 L
.59559 .45123 L
.67901 .41998 L
s
.64881 .41445 m
.61471 .40534 L
.53947 .42888 L
.56923 .44179 L
.64881 .41445 L
s
.61471 .40534 m
.57819 .39197 L
.5076 .41215 L
.53947 .42888 L
.61471 .40534 L
s
.57819 .39197 m
.54086 .37401 L
.47503 .39154 L
.5076 .41215 L
.57819 .39197 L
s
.54086 .37401 m
.50434 .35159 L
.44316 .36735 L
.47503 .39154 L
.54086 .37401 L
s
.50434 .35159 m
.47024 .3254 L
.4134 .34039 L
.44316 .36735 L
.50434 .35159 L
s
.47024 .3254 m
.44004 .29685 L
.38704 .31207 L
.4134 .34039 L
.47024 .3254 L
s
.44004 .29685 m
.41506 .26819 L
.36524 .28452 L
.38704 .31207 L
.44004 .29685 L
s
.41506 .26819 m
.39639 .24272 L
.34895 .26072 L
.36524 .28452 L
.41506 .26819 L
s
.39639 .24272 m
.38485 .22465 L
.33889 .24423 L
.34895 .26072 L
.39639 .24272 L
s
.38485 .22465 m
.38095 .21804 L
.33548 .23828 L
.33889 .24423 L
.38485 .22465 L
s
.38095 .21804 m
.38485 .22465 L
.33889 .24423 L
.33548 .23828 L
.38095 .21804 L
s
.38485 .22465 m
.39639 .24272 L
.34895 .26072 L
.33889 .24423 L
.38485 .22465 L
s
.39639 .24272 m
.41506 .26819 L
.36524 .28452 L
.34895 .26072 L
.39639 .24272 L
s
.41506 .26819 m
.44004 .29685 L
.38704 .31207 L
.36524 .28452 L
.41506 .26819 L
s
.44004 .29685 m
.47024 .3254 L
.4134 .34039 L
.38704 .31207 L
.44004 .29685 L
s
.47024 .3254 m
.50434 .35159 L
.44316 .36735 L
.4134 .34039 L
.47024 .3254 L
s
.50434 .35159 m
.54086 .37401 L
.47503 .39154 L
.44316 .36735 L
.50434 .35159 L
s
.54086 .37401 m
.57819 .39197 L
.5076 .41215 L
.47503 .39154 L
.54086 .37401 L
s
.57819 .39197 m
.61471 .40534 L
.53947 .42888 L
.5076 .41215 L
.57819 .39197 L
s
.61471 .40534 m
.64881 .41445 L
.56923 .44179 L
.53947 .42888 L
.61471 .40534 L
s
.64881 .41445 m
.67901 .41998 L
.59559 .45123 L
.56923 .44179 L
.64881 .41445 L
s
.67901 .41998 m
.70399 .42282 L
.61739 .45771 L
.59559 .45123 L
.67901 .41998 L
s
.70399 .42282 m
.72266 .42394 L
.63368 .46181 L
.61739 .45771 L
.70399 .42282 L
s
.72266 .42394 m
.73419 .42421 L
.64375 .46403 L
.63368 .46181 L
.72266 .42394 L
s
.73419 .42421 m
.7381 .42423 L
.64715 .46472 L
.64375 .46403 L
.73419 .42421 L
s
.64715 .46472 m
.64375 .46403 L
.5469 .48427 L
.54978 .48542 L
.64715 .46472 L
s
.64375 .46403 m
.63368 .46181 L
.53841 .48074 L
.5469 .48427 L
.64375 .46403 L
s
.63368 .46181 m
.61739 .45771 L
.52466 .47465 L
.53841 .48074 L
.63368 .46181 L
s
.61739 .45771 m
.59559 .45123 L
.50627 .46571 L
.52466 .47465 L
.61739 .45771 L
s
.59559 .45123 m
.56923 .44179 L
.48403 .45365 L
.50627 .46571 L
.59559 .45123 L
s
.56923 .44179 m
.53947 .42888 L
.45892 .43822 L
.48403 .45365 L
.56923 .44179 L
s
.53947 .42888 m
.5076 .41215 L
.43203 .41935 L
.45892 .43822 L
.53947 .42888 L
s
.5076 .41215 m
.47503 .39154 L
.40454 .39718 L
.43203 .41935 L
.5076 .41215 L
s
.47503 .39154 m
.44316 .36735 L
.37765 .37215 L
.40454 .39718 L
.47503 .39154 L
s
.44316 .36735 m
.4134 .34039 L
.35254 .34514 L
.37765 .37215 L
.44316 .36735 L
s
.4134 .34039 m
.38704 .31207 L
.3303 .31753 L
.35254 .34514 L
.4134 .34039 L
s
.38704 .31207 m
.36524 .28452 L
.31191 .29131 L
.3303 .31753 L
.38704 .31207 L
s
.36524 .28452 m
.34895 .26072 L
.29816 .26914 L
.31191 .29131 L
.36524 .28452 L
s
.34895 .26072 m
.33889 .24423 L
.28967 .25403 L
.29816 .26914 L
.34895 .26072 L
s
.33889 .24423 m
.33548 .23828 L
.28679 .24863 L
.28967 .25403 L
.33889 .24423 L
s
.33548 .23828 m
.33889 .24423 L
.28967 .25403 L
.28679 .24863 L
.33548 .23828 L
s
.33889 .24423 m
.34895 .26072 L
.29816 .26914 L
.28967 .25403 L
.33889 .24423 L
s
.34895 .26072 m
.36524 .28452 L
.31191 .29131 L
.29816 .26914 L
.34895 .26072 L
s
.36524 .28452 m
.38704 .31207 L
.3303 .31753 L
.31191 .29131 L
.36524 .28452 L
s
.38704 .31207 m
.4134 .34039 L
.35254 .34514 L
.3303 .31753 L
.38704 .31207 L
s
.4134 .34039 m
.44316 .36735 L
.37765 .37215 L
.35254 .34514 L
.4134 .34039 L
s
.44316 .36735 m
.47503 .39154 L
.40454 .39718 L
.37765 .37215 L
.44316 .36735 L
s
.47503 .39154 m
.5076 .41215 L
.43203 .41935 L
.40454 .39718 L
.47503 .39154 L
s
.5076 .41215 m
.53947 .42888 L
.45892 .43822 L
.43203 .41935 L
.5076 .41215 L
s
.53947 .42888 m
.56923 .44179 L
.48403 .45365 L
.45892 .43822 L
.53947 .42888 L
s
.56923 .44179 m
.59559 .45123 L
.50627 .46571 L
.48403 .45365 L
.56923 .44179 L
s
.59559 .45123 m
.61739 .45771 L
.52466 .47465 L
.50627 .46571 L
.59559 .45123 L
s
.61739 .45771 m
.63368 .46181 L
.53841 .48074 L
.52466 .47465 L
.61739 .45771 L
s
.63368 .46181 m
.64375 .46403 L
.5469 .48427 L
.53841 .48074 L
.63368 .46181 L
s
.64375 .46403 m
.64715 .46472 L
.54978 .48542 L
.5469 .48427 L
.64375 .46403 L
s
.64715 .46472 m
.64375 .46403 L
.5469 .48427 L
.54978 .48542 L
.64715 .46472 L
s
.64375 .46403 m
.63368 .46181 L
.53841 .48074 L
.5469 .48427 L
.64375 .46403 L
s
.63368 .46181 m
.61739 .45771 L
.52466 .47465 L
.53841 .48074 L
.63368 .46181 L
s
.61739 .45771 m
.59559 .45123 L
.50627 .46571 L
.52466 .47465 L
.61739 .45771 L
s
.59559 .45123 m
.56923 .44179 L
.48403 .45365 L
.50627 .46571 L
.59559 .45123 L
s
.56923 .44179 m
.53947 .42888 L
.45892 .43822 L
.48403 .45365 L
.56923 .44179 L
s
.53947 .42888 m
.5076 .41215 L
.43203 .41935 L
.45892 .43822 L
.53947 .42888 L
s
.5076 .41215 m
.47503 .39154 L
.40454 .39718 L
.43203 .41935 L
.5076 .41215 L
s
.47503 .39154 m
.44316 .36735 L
.37765 .37215 L
.40454 .39718 L
.47503 .39154 L
s
.44316 .36735 m
.4134 .34039 L
.35254 .34514 L
.37765 .37215 L
.44316 .36735 L
s
.4134 .34039 m
.38704 .31207 L
.3303 .31753 L
.35254 .34514 L
.4134 .34039 L
s
.38704 .31207 m
.36524 .28452 L
.31191 .29131 L
.3303 .31753 L
.38704 .31207 L
s
.36524 .28452 m
.34895 .26072 L
.29816 .26914 L
.31191 .29131 L
.36524 .28452 L
s
.34895 .26072 m
.33889 .24423 L
.28967 .25403 L
.29816 .26914 L
.34895 .26072 L
s
.33889 .24423 m
.33548 .23828 L
.28679 .24863 L
.28967 .25403 L
.33889 .24423 L
s
.33548 .23828 m
.33889 .24423 L
.28967 .25403 L
.28679 .24863 L
.33548 .23828 L
s
.33889 .24423 m
.34895 .26072 L
.29816 .26914 L
.28967 .25403 L
.33889 .24423 L
s
.34895 .26072 m
.36524 .28452 L
.31191 .29131 L
.29816 .26914 L
.34895 .26072 L
s
.36524 .28452 m
.38704 .31207 L
.3303 .31753 L
.31191 .29131 L
.36524 .28452 L
s
.38704 .31207 m
.4134 .34039 L
.35254 .34514 L
.3303 .31753 L
.38704 .31207 L
s
.4134 .34039 m
.44316 .36735 L
.37765 .37215 L
.35254 .34514 L
.4134 .34039 L
s
.44316 .36735 m
.47503 .39154 L
.40454 .39718 L
.37765 .37215 L
.44316 .36735 L
s
.47503 .39154 m
.5076 .41215 L
.43203 .41935 L
.40454 .39718 L
.47503 .39154 L
s
.5076 .41215 m
.53947 .42888 L
.45892 .43822 L
.43203 .41935 L
.5076 .41215 L
s
.53947 .42888 m
.56923 .44179 L
.48403 .45365 L
.45892 .43822 L
.53947 .42888 L
s
.56923 .44179 m
.59559 .45123 L
.50627 .46571 L
.48403 .45365 L
.56923 .44179 L
s
.59559 .45123 m
.61739 .45771 L
.52466 .47465 L
.50627 .46571 L
.59559 .45123 L
s
.61739 .45771 m
.63368 .46181 L
.53841 .48074 L
.52466 .47465 L
.61739 .45771 L
s
.63368 .46181 m
.64375 .46403 L
.5469 .48427 L
.53841 .48074 L
.63368 .46181 L
s
.64375 .46403 m
.64715 .46472 L
.54978 .48542 L
.5469 .48427 L
.64375 .46403 L
s
.54978 .48542 m
.5469 .48427 L
.44789 .484 L
.45022 .48542 L
.54978 .48542 L
s
.5469 .48427 m
.53841 .48074 L
.44101 .47969 L
.44789 .484 L
.5469 .48427 L
s
.53841 .48074 m
.52466 .47465 L
.42987 .47243 L
.44101 .47969 L
.53841 .48074 L
s
.52466 .47465 m
.50627 .46571 L
.41495 .46209 L
.42987 .47243 L
.52466 .47465 L
s
.50627 .46571 m
.48403 .45365 L
.39692 .44859 L
.41495 .46209 L
.50627 .46571 L
s
.48403 .45365 m
.45892 .43822 L
.37656 .43189 L
.39692 .44859 L
.48403 .45365 L
s
.45892 .43822 m
.43203 .41935 L
.35476 .4121 L
.37656 .43189 L
.45892 .43822 L
s
.43203 .41935 m
.40454 .39718 L
.33248 .3895 L
.35476 .4121 L
.43203 .41935 L
s
.40454 .39718 m
.37765 .37215 L
.31068 .36463 L
.33248 .3895 L
.40454 .39718 L
s
.37765 .37215 m
.35254 .34514 L
.29032 .33841 L
.31068 .36463 L
.37765 .37215 L
s
.35254 .34514 m
.3303 .31753 L
.27229 .31213 L
.29032 .33841 L
.35254 .34514 L
s
.3303 .31753 m
.31191 .29131 L
.25738 .28763 L
.27229 .31213 L
.3303 .31753 L
s
.31191 .29131 m
.29816 .26914 L
.24623 .26722 L
.25738 .28763 L
.31191 .29131 L
s
.29816 .26914 m
.28967 .25403 L
.23935 .2535 L
.24623 .26722 L
.29816 .26914 L
s
.28967 .25403 m
.28679 .24863 L
.23702 .24863 L
.23935 .2535 L
.28967 .25403 L
s
.28679 .24863 m
.28967 .25403 L
.23935 .2535 L
.23702 .24863 L
.28679 .24863 L
s
.28967 .25403 m
.29816 .26914 L
.24623 .26722 L
.23935 .2535 L
.28967 .25403 L
s
.29816 .26914 m
.31191 .29131 L
.25738 .28763 L
.24623 .26722 L
.29816 .26914 L
s
.31191 .29131 m
.3303 .31753 L
.27229 .31213 L
.25738 .28763 L
.31191 .29131 L
s
.3303 .31753 m
.35254 .34514 L
.29032 .33841 L
.27229 .31213 L
.3303 .31753 L
s
.35254 .34514 m
.37765 .37215 L
.31068 .36463 L
.29032 .33841 L
.35254 .34514 L
s
.37765 .37215 m
.40454 .39718 L
.33248 .3895 L
.31068 .36463 L
.37765 .37215 L
s
.40454 .39718 m
.43203 .41935 L
.35476 .4121 L
.33248 .3895 L
.40454 .39718 L
s
.43203 .41935 m
.45892 .43822 L
.37656 .43189 L
.35476 .4121 L
.43203 .41935 L
s
.45892 .43822 m
.48403 .45365 L
.39692 .44859 L
.37656 .43189 L
.45892 .43822 L
s
.48403 .45365 m
.50627 .46571 L
.41495 .46209 L
.39692 .44859 L
.48403 .45365 L
s
.50627 .46571 m
.52466 .47465 L
.42987 .47243 L
.41495 .46209 L
.50627 .46571 L
s
.52466 .47465 m
.53841 .48074 L
.44101 .47969 L
.42987 .47243 L
.52466 .47465 L
s
.53841 .48074 m
.5469 .48427 L
.44789 .484 L
.44101 .47969 L
.53841 .48074 L
s
.5469 .48427 m
.54978 .48542 L
.45022 .48542 L
.44789 .484 L
.5469 .48427 L
s
.54978 .48542 m
.5469 .48427 L
.44789 .484 L
.45022 .48542 L
.54978 .48542 L
s
.5469 .48427 m
.53841 .48074 L
.44101 .47969 L
.44789 .484 L
.5469 .48427 L
s
.53841 .48074 m
.52466 .47465 L
.42987 .47243 L
.44101 .47969 L
.53841 .48074 L
s
.52466 .47465 m
.50627 .46571 L
.41495 .46209 L
.42987 .47243 L
.52466 .47465 L
s
.50627 .46571 m
.48403 .45365 L
.39692 .44859 L
.41495 .46209 L
.50627 .46571 L
s
.48403 .45365 m
.45892 .43822 L
.37656 .43189 L
.39692 .44859 L
.48403 .45365 L
s
.45892 .43822 m
.43203 .41935 L
.35476 .4121 L
.37656 .43189 L
.45892 .43822 L
s
.43203 .41935 m
.40454 .39718 L
.33248 .3895 L
.35476 .4121 L
.43203 .41935 L
s
.40454 .39718 m
.37765 .37215 L
.31068 .36463 L
.33248 .3895 L
.40454 .39718 L
s
.37765 .37215 m
.35254 .34514 L
.29032 .33841 L
.31068 .36463 L
.37765 .37215 L
s
.35254 .34514 m
.3303 .31753 L
.27229 .31213 L
.29032 .33841 L
.35254 .34514 L
s
.3303 .31753 m
.31191 .29131 L
.25738 .28763 L
.27229 .31213 L
.3303 .31753 L
s
.31191 .29131 m
.29816 .26914 L
.24623 .26722 L
.25738 .28763 L
.31191 .29131 L
s
.29816 .26914 m
.28967 .25403 L
.23935 .2535 L
.24623 .26722 L
.29816 .26914 L
s
.28967 .25403 m
.28679 .24863 L
.23702 .24863 L
.23935 .2535 L
.28967 .25403 L
s
.28679 .24863 m
.28967 .25403 L
.23935 .2535 L
.23702 .24863 L
.28679 .24863 L
s
.28967 .25403 m
.29816 .26914 L
.24623 .26722 L
.23935 .2535 L
.28967 .25403 L
s
.29816 .26914 m
.31191 .29131 L
.25738 .28763 L
.24623 .26722 L
.29816 .26914 L
s
.31191 .29131 m
.3303 .31753 L
.27229 .31213 L
.25738 .28763 L
.31191 .29131 L
s
.3303 .31753 m
.35254 .34514 L
.29032 .33841 L
.27229 .31213 L
.3303 .31753 L
s
.35254 .34514 m
.37765 .37215 L
.31068 .36463 L
.29032 .33841 L
.35254 .34514 L
s
.37765 .37215 m
.40454 .39718 L
.33248 .3895 L
.31068 .36463 L
.37765 .37215 L
s
.40454 .39718 m
.43203 .41935 L
.35476 .4121 L
.33248 .3895 L
.40454 .39718 L
s
.43203 .41935 m
.45892 .43822 L
.37656 .43189 L
.35476 .4121 L
.43203 .41935 L
s
.45892 .43822 m
.48403 .45365 L
.39692 .44859 L
.37656 .43189 L
.45892 .43822 L
s
.48403 .45365 m
.50627 .46571 L
.41495 .46209 L
.39692 .44859 L
.48403 .45365 L
s
.50627 .46571 m
.52466 .47465 L
.42987 .47243 L
.41495 .46209 L
.50627 .46571 L
s
.52466 .47465 m
.53841 .48074 L
.44101 .47969 L
.42987 .47243 L
.52466 .47465 L
s
.53841 .48074 m
.5469 .48427 L
.44789 .484 L
.44101 .47969 L
.53841 .48074 L
s
.5469 .48427 m
.54978 .48542 L
.45022 .48542 L
.44789 .484 L
.5469 .48427 L
s
.45022 .48542 m
.44789 .484 L
.35105 .46319 L
.35285 .46472 L
.45022 .48542 L
s
.44789 .484 m
.44101 .47969 L
.34574 .45858 L
.35105 .46319 L
.44789 .484 L
s
.44101 .47969 m
.42987 .47243 L
.33714 .45088 L
.34574 .45858 L
.44101 .47969 L
s
.42987 .47243 m
.41495 .46209 L
.32563 .44008 L
.33714 .45088 L
.42987 .47243 L
s
.41495 .46209 m
.39692 .44859 L
.31172 .42623 L
.32563 .44008 L
.41495 .46209 L
s
.39692 .44859 m
.37656 .43189 L
.29601 .40943 L
.31172 .42623 L
.39692 .44859 L
s
.37656 .43189 m
.35476 .4121 L
.27919 .38989 L
.29601 .40943 L
.37656 .43189 L
s
.35476 .4121 m
.33248 .3895 L
.26199 .36799 L
.27919 .38989 L
.35476 .4121 L
s
.33248 .3895 m
.31068 .36463 L
.24517 .34432 L
.26199 .36799 L
.33248 .3895 L
s
.31068 .36463 m
.29032 .33841 L
.22946 .31975 L
.24517 .34432 L
.31068 .36463 L
s
.29032 .33841 m
.27229 .31213 L
.21555 .2955 L
.22946 .31975 L
.29032 .33841 L
s
.27229 .31213 m
.25738 .28763 L
.20404 .27319 L
.21555 .2955 L
.27229 .31213 L
s
.25738 .28763 m
.24623 .26722 L
.19544 .25483 L
.20404 .27319 L
.25738 .28763 L
s
.24623 .26722 m
.23935 .2535 L
.19013 .2426 L
.19544 .25483 L
.24623 .26722 L
s
.23935 .2535 m
.23702 .24863 L
.18833 .23828 L
.19013 .2426 L
.23935 .2535 L
s
.23702 .24863 m
.23935 .2535 L
.19013 .2426 L
.18833 .23828 L
.23702 .24863 L
s
.23935 .2535 m
.24623 .26722 L
.19544 .25483 L
.19013 .2426 L
.23935 .2535 L
s
.24623 .26722 m
.25738 .28763 L
.20404 .27319 L
.19544 .25483 L
.24623 .26722 L
s
.25738 .28763 m
.27229 .31213 L
.21555 .2955 L
.20404 .27319 L
.25738 .28763 L
s
.27229 .31213 m
.29032 .33841 L
.22946 .31975 L
.21555 .2955 L
.27229 .31213 L
s
.29032 .33841 m
.31068 .36463 L
.24517 .34432 L
.22946 .31975 L
.29032 .33841 L
s
.31068 .36463 m
.33248 .3895 L
.26199 .36799 L
.24517 .34432 L
.31068 .36463 L
s
.33248 .3895 m
.35476 .4121 L
.27919 .38989 L
.26199 .36799 L
.33248 .3895 L
s
.35476 .4121 m
.37656 .43189 L
.29601 .40943 L
.27919 .38989 L
.35476 .4121 L
s
.37656 .43189 m
.39692 .44859 L
.31172 .42623 L
.29601 .40943 L
.37656 .43189 L
s
.39692 .44859 m
.41495 .46209 L
.32563 .44008 L
.31172 .42623 L
.39692 .44859 L
s
.41495 .46209 m
.42987 .47243 L
.33714 .45088 L
.32563 .44008 L
.41495 .46209 L
s
.42987 .47243 m
.44101 .47969 L
.34574 .45858 L
.33714 .45088 L
.42987 .47243 L
s
.44101 .47969 m
.44789 .484 L
.35105 .46319 L
.34574 .45858 L
.44101 .47969 L
s
.44789 .484 m
.45022 .48542 L
.35285 .46472 L
.35105 .46319 L
.44789 .484 L
s
.45022 .48542 m
.44789 .484 L
.35105 .46319 L
.35285 .46472 L
.45022 .48542 L
s
.44789 .484 m
.44101 .47969 L
.34574 .45858 L
.35105 .46319 L
.44789 .484 L
s
.44101 .47969 m
.42987 .47243 L
.33714 .45088 L
.34574 .45858 L
.44101 .47969 L
s
.42987 .47243 m
.41495 .46209 L
.32563 .44008 L
.33714 .45088 L
.42987 .47243 L
s
.41495 .46209 m
.39692 .44859 L
.31172 .42623 L
.32563 .44008 L
.41495 .46209 L
s
.39692 .44859 m
.37656 .43189 L
.29601 .40943 L
.31172 .42623 L
.39692 .44859 L
s
.37656 .43189 m
.35476 .4121 L
.27919 .38989 L
.29601 .40943 L
.37656 .43189 L
s
.35476 .4121 m
.33248 .3895 L
.26199 .36799 L
.27919 .38989 L
.35476 .4121 L
s
.33248 .3895 m
.31068 .36463 L
.24517 .34432 L
.26199 .36799 L
.33248 .3895 L
s
.31068 .36463 m
.29032 .33841 L
.22946 .31975 L
.24517 .34432 L
.31068 .36463 L
s
.29032 .33841 m
.27229 .31213 L
.21555 .2955 L
.22946 .31975 L
.29032 .33841 L
s
.27229 .31213 m
.25738 .28763 L
.20404 .27319 L
.21555 .2955 L
.27229 .31213 L
s
.25738 .28763 m
.24623 .26722 L
.19544 .25483 L
.20404 .27319 L
.25738 .28763 L
s
.24623 .26722 m
.23935 .2535 L
.19013 .2426 L
.19544 .25483 L
.24623 .26722 L
s
.23935 .2535 m
.23702 .24863 L
.18833 .23828 L
.19013 .2426 L
.23935 .2535 L
s
.23702 .24863 m
.23935 .2535 L
.19013 .2426 L
.18833 .23828 L
.23702 .24863 L
s
.23935 .2535 m
.24623 .26722 L
.19544 .25483 L
.19013 .2426 L
.23935 .2535 L
s
.24623 .26722 m
.25738 .28763 L
.20404 .27319 L
.19544 .25483 L
.24623 .26722 L
s
.25738 .28763 m
.27229 .31213 L
.21555 .2955 L
.20404 .27319 L
.25738 .28763 L
s
.27229 .31213 m
.29032 .33841 L
.22946 .31975 L
.21555 .2955 L
.27229 .31213 L
s
.29032 .33841 m
.31068 .36463 L
.24517 .34432 L
.22946 .31975 L
.29032 .33841 L
s
.31068 .36463 m
.33248 .3895 L
.26199 .36799 L
.24517 .34432 L
.31068 .36463 L
s
.33248 .3895 m
.35476 .4121 L
.27919 .38989 L
.26199 .36799 L
.33248 .3895 L
s
.35476 .4121 m
.37656 .43189 L
.29601 .40943 L
.27919 .38989 L
.35476 .4121 L
s
.37656 .43189 m
.39692 .44859 L
.31172 .42623 L
.29601 .40943 L
.37656 .43189 L
s
.39692 .44859 m
.41495 .46209 L
.32563 .44008 L
.31172 .42623 L
.39692 .44859 L
s
.41495 .46209 m
.42987 .47243 L
.33714 .45088 L
.32563 .44008 L
.41495 .46209 L
s
.42987 .47243 m
.44101 .47969 L
.34574 .45858 L
.33714 .45088 L
.42987 .47243 L
s
.44101 .47969 m
.44789 .484 L
.35105 .46319 L
.34574 .45858 L
.44101 .47969 L
s
.44789 .484 m
.45022 .48542 L
.35285 .46472 L
.35105 .46319 L
.44789 .484 L
s
.35285 .46472 m
.35105 .46319 L
.2606 .42273 L
.2619 .42423 L
.35285 .46472 L
s
.35105 .46319 m
.34574 .45858 L
.25676 .41821 L
.2606 .42273 L
.35105 .46319 L
s
.34574 .45858 m
.33714 .45088 L
.25054 .41073 L
.25676 .41821 L
.34574 .45858 L
s
.33714 .45088 m
.32563 .44008 L
.24221 .40033 L
.25054 .41073 L
.33714 .45088 L
s
.32563 .44008 m
.31172 .42623 L
.23214 .38712 L
.24221 .40033 L
.32563 .44008 L
s
.31172 .42623 m
.29601 .40943 L
.22077 .37129 L
.23214 .38712 L
.31172 .42623 L
s
.29601 .40943 m
.27919 .38989 L
.2086 .35311 L
.22077 .37129 L
.29601 .40943 L
s
.27919 .38989 m
.26199 .36799 L
.19616 .33298 L
.2086 .35311 L
.27919 .38989 L
s
.26199 .36799 m
.24517 .34432 L
.18399 .31149 L
.19616 .33298 L
.26199 .36799 L
s
.24517 .34432 m
.22946 .31975 L
.17262 .28944 L
.18399 .31149 L
.24517 .34432 L
s
.22946 .31975 m
.21555 .2955 L
.16255 .26792 L
.17262 .28944 L
.22946 .31975 L
s
.21555 .2955 m
.20404 .27319 L
.15423 .24832 L
.16255 .26792 L
.21555 .2955 L
s
.20404 .27319 m
.19544 .25483 L
.148 .23233 L
.15423 .24832 L
.20404 .27319 L
s
.19544 .25483 m
.19013 .2426 L
.14416 .22175 L
.148 .23233 L
.19544 .25483 L
s
.19013 .2426 m
.18833 .23828 L
.14286 .21804 L
.14416 .22175 L
.19013 .2426 L
s
.18833 .23828 m
.19013 .2426 L
.14416 .22175 L
.14286 .21804 L
.18833 .23828 L
s
.19013 .2426 m
.19544 .25483 L
.148 .23233 L
.14416 .22175 L
.19013 .2426 L
s
.19544 .25483 m
.20404 .27319 L
.15423 .24832 L
.148 .23233 L
.19544 .25483 L
s
.20404 .27319 m
.21555 .2955 L
.16255 .26792 L
.15423 .24832 L
.20404 .27319 L
s
.21555 .2955 m
.22946 .31975 L
.17262 .28944 L
.16255 .26792 L
.21555 .2955 L
s
.22946 .31975 m
.24517 .34432 L
.18399 .31149 L
.17262 .28944 L
.22946 .31975 L
s
.24517 .34432 m
.26199 .36799 L
.19616 .33298 L
.18399 .31149 L
.24517 .34432 L
s
.26199 .36799 m
.27919 .38989 L
.2086 .35311 L
.19616 .33298 L
.26199 .36799 L
s
.27919 .38989 m
.29601 .40943 L
.22077 .37129 L
.2086 .35311 L
.27919 .38989 L
s
.29601 .40943 m
.31172 .42623 L
.23214 .38712 L
.22077 .37129 L
.29601 .40943 L
s
.31172 .42623 m
.32563 .44008 L
.24221 .40033 L
.23214 .38712 L
.31172 .42623 L
s
.32563 .44008 m
.33714 .45088 L
.25054 .41073 L
.24221 .40033 L
.32563 .44008 L
s
.33714 .45088 m
.34574 .45858 L
.25676 .41821 L
.25054 .41073 L
.33714 .45088 L
s
.34574 .45858 m
.35105 .46319 L
.2606 .42273 L
.25676 .41821 L
.34574 .45858 L
s
.35105 .46319 m
.35285 .46472 L
.2619 .42423 L
.2606 .42273 L
.35105 .46319 L
s
.35285 .46472 m
.35105 .46319 L
.2606 .42273 L
.2619 .42423 L
.35285 .46472 L
s
.35105 .46319 m
.34574 .45858 L
.25676 .41821 L
.2606 .42273 L
.35105 .46319 L
s
.34574 .45858 m
.33714 .45088 L
.25054 .41073 L
.25676 .41821 L
.34574 .45858 L
s
.33714 .45088 m
.32563 .44008 L
.24221 .40033 L
.25054 .41073 L
.33714 .45088 L
s
.32563 .44008 m
.31172 .42623 L
.23214 .38712 L
.24221 .40033 L
.32563 .44008 L
s
.31172 .42623 m
.29601 .40943 L
.22077 .37129 L
.23214 .38712 L
.31172 .42623 L
s
.29601 .40943 m
.27919 .38989 L
.2086 .35311 L
.22077 .37129 L
.29601 .40943 L
s
.27919 .38989 m
.26199 .36799 L
.19616 .33298 L
.2086 .35311 L
.27919 .38989 L
s
.26199 .36799 m
.24517 .34432 L
.18399 .31149 L
.19616 .33298 L
.26199 .36799 L
s
.24517 .34432 m
.22946 .31975 L
.17262 .28944 L
.18399 .31149 L
.24517 .34432 L
s
.22946 .31975 m
.21555 .2955 L
.16255 .26792 L
.17262 .28944 L
.22946 .31975 L
s
.21555 .2955 m
.20404 .27319 L
.15423 .24832 L
.16255 .26792 L
.21555 .2955 L
s
.20404 .27319 m
.19544 .25483 L
.148 .23233 L
.15423 .24832 L
.20404 .27319 L
s
.19544 .25483 m
.19013 .2426 L
.14416 .22175 L
.148 .23233 L
.19544 .25483 L
s
.19013 .2426 m
.18833 .23828 L
.14286 .21804 L
.14416 .22175 L
.19013 .2426 L
s
.18833 .23828 m
.19013 .2426 L
.14416 .22175 L
.14286 .21804 L
.18833 .23828 L
s
.19013 .2426 m
.19544 .25483 L
.148 .23233 L
.14416 .22175 L
.19013 .2426 L
s
.19544 .25483 m
.20404 .27319 L
.15423 .24832 L
.148 .23233 L
.19544 .25483 L
s
.20404 .27319 m
.21555 .2955 L
.16255 .26792 L
.15423 .24832 L
.20404 .27319 L
s
.21555 .2955 m
.22946 .31975 L
.17262 .28944 L
.16255 .26792 L
.21555 .2955 L
s
.22946 .31975 m
.24517 .34432 L
.18399 .31149 L
.17262 .28944 L
.22946 .31975 L
s
.24517 .34432 m
.26199 .36799 L
.19616 .33298 L
.18399 .31149 L
.24517 .34432 L
s
.26199 .36799 m
.27919 .38989 L
.2086 .35311 L
.19616 .33298 L
.26199 .36799 L
s
.27919 .38989 m
.29601 .40943 L
.22077 .37129 L
.2086 .35311 L
.27919 .38989 L
s
.29601 .40943 m
.31172 .42623 L
.23214 .38712 L
.22077 .37129 L
.29601 .40943 L
s
.31172 .42623 m
.32563 .44008 L
.24221 .40033 L
.23214 .38712 L
.31172 .42623 L
s
.32563 .44008 m
.33714 .45088 L
.25054 .41073 L
.24221 .40033 L
.32563 .44008 L
s
.33714 .45088 m
.34574 .45858 L
.25676 .41821 L
.25054 .41073 L
.33714 .45088 L
s
.34574 .45858 m
.35105 .46319 L
.2606 .42273 L
.25676 .41821 L
.34574 .45858 L
s
.35105 .46319 m
.35285 .46472 L
.2619 .42423 L
.2606 .42273 L
.35105 .46319 L
s
.2619 .42423 m
.2606 .42273 L
.18051 .36436 L
.18137 .36572 L
.2619 .42423 L
s
.2606 .42273 m
.25676 .41821 L
.17796 .3603 L
.18051 .36436 L
.2606 .42273 L
s
.25676 .41821 m
.25054 .41073 L
.17384 .3536 L
.17796 .3603 L
.25676 .41821 L
s
.25054 .41073 m
.24221 .40033 L
.16833 .34433 L
.17384 .3536 L
.25054 .41073 L
s
.24221 .40033 m
.23214 .38712 L
.16167 .33264 L
.16833 .34433 L
.24221 .40033 L
s
.23214 .38712 m
.22077 .37129 L
.15415 .31873 L
.16167 .33264 L
.23214 .38712 L
s
.22077 .37129 m
.2086 .35311 L
.14609 .30289 L
.15415 .31873 L
.22077 .37129 L
s
.2086 .35311 m
.19616 .33298 L
.13786 .28551 L
.14609 .30289 L
.2086 .35311 L
s
.19616 .33298 m
.18399 .31149 L
.12981 .2671 L
.13786 .28551 L
.19616 .33298 L
s
.18399 .31149 m
.17262 .28944 L
.12228 .24838 L
.12981 .2671 L
.18399 .31149 L
s
.17262 .28944 m
.16255 .26792 L
.11562 .23025 L
.12228 .24838 L
.17262 .28944 L
s
.16255 .26792 m
.15423 .24832 L
.11011 .21386 L
.11562 .23025 L
.16255 .26792 L
s
.15423 .24832 m
.148 .23233 L
.10599 .20058 L
.11011 .21386 L
.15423 .24832 L
s
.148 .23233 m
.14416 .22175 L
.10345 .19184 L
.10599 .20058 L
.148 .23233 L
s
.14416 .22175 m
.14286 .21804 L
.10259 .18878 L
.10345 .19184 L
.14416 .22175 L
s
.14286 .21804 m
.14416 .22175 L
.10345 .19184 L
.10259 .18878 L
.14286 .21804 L
s
.14416 .22175 m
.148 .23233 L
.10599 .20058 L
.10345 .19184 L
.14416 .22175 L
s
.148 .23233 m
.15423 .24832 L
.11011 .21386 L
.10599 .20058 L
.148 .23233 L
s
.15423 .24832 m
.16255 .26792 L
.11562 .23025 L
.11011 .21386 L
.15423 .24832 L
s
.16255 .26792 m
.17262 .28944 L
.12228 .24838 L
.11562 .23025 L
.16255 .26792 L
s
.17262 .28944 m
.18399 .31149 L
.12981 .2671 L
.12228 .24838 L
.17262 .28944 L
s
.18399 .31149 m
.19616 .33298 L
.13786 .28551 L
.12981 .2671 L
.18399 .31149 L
s
.19616 .33298 m
.2086 .35311 L
.14609 .30289 L
.13786 .28551 L
.19616 .33298 L
s
.2086 .35311 m
.22077 .37129 L
.15415 .31873 L
.14609 .30289 L
.2086 .35311 L
s
.22077 .37129 m
.23214 .38712 L
.16167 .33264 L
.15415 .31873 L
.22077 .37129 L
s
.23214 .38712 m
.24221 .40033 L
.16833 .34433 L
.16167 .33264 L
.23214 .38712 L
s
.24221 .40033 m
.25054 .41073 L
.17384 .3536 L
.16833 .34433 L
.24221 .40033 L
s
.25054 .41073 m
.25676 .41821 L
.17796 .3603 L
.17384 .3536 L
.25054 .41073 L
s
.25676 .41821 m
.2606 .42273 L
.18051 .36436 L
.17796 .3603 L
.25676 .41821 L
s
.2606 .42273 m
.2619 .42423 L
.18137 .36572 L
.18051 .36436 L
.2606 .42273 L
s
.2619 .42423 m
.2606 .42273 L
.18051 .36436 L
.18137 .36572 L
.2619 .42423 L
s
.2606 .42273 m
.25676 .41821 L
.17796 .3603 L
.18051 .36436 L
.2606 .42273 L
s
.25676 .41821 m
.25054 .41073 L
.17384 .3536 L
.17796 .3603 L
.25676 .41821 L
s
.25054 .41073 m
.24221 .40033 L
.16833 .34433 L
.17384 .3536 L
.25054 .41073 L
s
.24221 .40033 m
.23214 .38712 L
.16167 .33264 L
.16833 .34433 L
.24221 .40033 L
s
.23214 .38712 m
.22077 .37129 L
.15415 .31873 L
.16167 .33264 L
.23214 .38712 L
s
.22077 .37129 m
.2086 .35311 L
.14609 .30289 L
.15415 .31873 L
.22077 .37129 L
s
.2086 .35311 m
.19616 .33298 L
.13786 .28551 L
.14609 .30289 L
.2086 .35311 L
s
.19616 .33298 m
.18399 .31149 L
.12981 .2671 L
.13786 .28551 L
.19616 .33298 L
s
.18399 .31149 m
.17262 .28944 L
.12228 .24838 L
.12981 .2671 L
.18399 .31149 L
s
.17262 .28944 m
.16255 .26792 L
.11562 .23025 L
.12228 .24838 L
.17262 .28944 L
s
.16255 .26792 m
.15423 .24832 L
.11011 .21386 L
.11562 .23025 L
.16255 .26792 L
s
.15423 .24832 m
.148 .23233 L
.10599 .20058 L
.11011 .21386 L
.15423 .24832 L
s
.148 .23233 m
.14416 .22175 L
.10345 .19184 L
.10599 .20058 L
.148 .23233 L
s
.14416 .22175 m
.14286 .21804 L
.10259 .18878 L
.10345 .19184 L
.14416 .22175 L
s
.14286 .21804 m
.14416 .22175 L
.10345 .19184 L
.10259 .18878 L
.14286 .21804 L
s
.14416 .22175 m
.148 .23233 L
.10599 .20058 L
.10345 .19184 L
.14416 .22175 L
s
.148 .23233 m
.15423 .24832 L
.11011 .21386 L
.10599 .20058 L
.148 .23233 L
s
.15423 .24832 m
.16255 .26792 L
.11562 .23025 L
.11011 .21386 L
.15423 .24832 L
s
.16255 .26792 m
.17262 .28944 L
.12228 .24838 L
.11562 .23025 L
.16255 .26792 L
s
.17262 .28944 m
.18399 .31149 L
.12981 .2671 L
.12228 .24838 L
.17262 .28944 L
s
.18399 .31149 m
.19616 .33298 L
.13786 .28551 L
.12981 .2671 L
.18399 .31149 L
s
.19616 .33298 m
.2086 .35311 L
.14609 .30289 L
.13786 .28551 L
.19616 .33298 L
s
.2086 .35311 m
.22077 .37129 L
.15415 .31873 L
.14609 .30289 L
.2086 .35311 L
s
.22077 .37129 m
.23214 .38712 L
.16167 .33264 L
.15415 .31873 L
.22077 .37129 L
s
.23214 .38712 m
.24221 .40033 L
.16833 .34433 L
.16167 .33264 L
.23214 .38712 L
s
.24221 .40033 m
.25054 .41073 L
.17384 .3536 L
.16833 .34433 L
.24221 .40033 L
s
.25054 .41073 m
.25676 .41821 L
.17796 .3603 L
.17384 .3536 L
.25054 .41073 L
s
.25676 .41821 m
.2606 .42273 L
.18051 .36436 L
.17796 .3603 L
.25676 .41821 L
s
.2606 .42273 m
.2619 .42423 L
.18137 .36572 L
.18051 .36436 L
.2606 .42273 L
s
.18137 .36572 m
.18051 .36436 L
.11426 .29063 L
.11475 .29174 L
.18137 .36572 L
s
.18051 .36436 m
.17796 .3603 L
.11279 .28732 L
.11426 .29063 L
.18051 .36436 L
s
.17796 .3603 m
.17384 .3536 L
.11041 .28186 L
.11279 .28732 L
.17796 .3603 L
s
.17384 .3536 m
.16833 .34433 L
.10723 .27434 L
.11041 .28186 L
.17384 .3536 L
s
.16833 .34433 m
.16167 .33264 L
.10339 .2649 L
.10723 .27434 L
.16833 .34433 L
s
.16167 .33264 m
.15415 .31873 L
.09904 .25373 L
.10339 .2649 L
.16167 .33264 L
s
.15415 .31873 m
.14609 .30289 L
.09439 .24107 L
.09904 .25373 L
.15415 .31873 L
s
.14609 .30289 m
.13786 .28551 L
.08964 .22726 L
.09439 .24107 L
.14609 .30289 L
s
.13786 .28551 m
.12981 .2671 L
.08499 .21272 L
.08964 .22726 L
.13786 .28551 L
s
.12981 .2671 m
.12228 .24838 L
.08065 .19802 L
.08499 .21272 L
.12981 .2671 L
s
.12228 .24838 m
.11562 .23025 L
.0768 .18386 L
.08065 .19802 L
.12228 .24838 L
s
.11562 .23025 m
.11011 .21386 L
.07362 .17114 L
.0768 .18386 L
.11562 .23025 L
s
.11011 .21386 m
.10599 .20058 L
.07125 .16087 L
.07362 .17114 L
.11011 .21386 L
s
.10599 .20058 m
.10345 .19184 L
.06978 .15414 L
.07125 .16087 L
.10599 .20058 L
s
.10345 .19184 m
.10259 .18878 L
.06928 .15179 L
.06978 .15414 L
.10345 .19184 L
s
.10259 .18878 m
.10345 .19184 L
.06978 .15414 L
.06928 .15179 L
.10259 .18878 L
s
.10345 .19184 m
.10599 .20058 L
.07125 .16087 L
.06978 .15414 L
.10345 .19184 L
s
.10599 .20058 m
.11011 .21386 L
.07362 .17114 L
.07125 .16087 L
.10599 .20058 L
s
.11011 .21386 m
.11562 .23025 L
.0768 .18386 L
.07362 .17114 L
.11011 .21386 L
s
.11562 .23025 m
.12228 .24838 L
.08065 .19802 L
.0768 .18386 L
.11562 .23025 L
s
.12228 .24838 m
.12981 .2671 L
.08499 .21272 L
.08065 .19802 L
.12228 .24838 L
s
.12981 .2671 m
.13786 .28551 L
.08964 .22726 L
.08499 .21272 L
.12981 .2671 L
s
.13786 .28551 m
.14609 .30289 L
.09439 .24107 L
.08964 .22726 L
.13786 .28551 L
s
.14609 .30289 m
.15415 .31873 L
.09904 .25373 L
.09439 .24107 L
.14609 .30289 L
s
.15415 .31873 m
.16167 .33264 L
.10339 .2649 L
.09904 .25373 L
.15415 .31873 L
s
.16167 .33264 m
.16833 .34433 L
.10723 .27434 L
.10339 .2649 L
.16167 .33264 L
s
.16833 .34433 m
.17384 .3536 L
.11041 .28186 L
.10723 .27434 L
.16833 .34433 L
s
.17384 .3536 m
.17796 .3603 L
.11279 .28732 L
.11041 .28186 L
.17384 .3536 L
s
.17796 .3603 m
.18051 .36436 L
.11426 .29063 L
.11279 .28732 L
.17796 .3603 L
s
.18051 .36436 m
.18137 .36572 L
.11475 .29174 L
.11426 .29063 L
.18051 .36436 L
s
.18137 .36572 m
.18051 .36436 L
.11426 .29063 L
.11475 .29174 L
.18137 .36572 L
s
.18051 .36436 m
.17796 .3603 L
.11279 .28732 L
.11426 .29063 L
.18051 .36436 L
s
.17796 .3603 m
.17384 .3536 L
.11041 .28186 L
.11279 .28732 L
.17796 .3603 L
s
.17384 .3536 m
.16833 .34433 L
.10723 .27434 L
.11041 .28186 L
.17384 .3536 L
s
.16833 .34433 m
.16167 .33264 L
.10339 .2649 L
.10723 .27434 L
.16833 .34433 L
s
.16167 .33264 m
.15415 .31873 L
.09904 .25373 L
.10339 .2649 L
.16167 .33264 L
s
.15415 .31873 m
.14609 .30289 L
.09439 .24107 L
.09904 .25373 L
.15415 .31873 L
s
.14609 .30289 m
.13786 .28551 L
.08964 .22726 L
.09439 .24107 L
.14609 .30289 L
s
.13786 .28551 m
.12981 .2671 L
.08499 .21272 L
.08964 .22726 L
.13786 .28551 L
s
.12981 .2671 m
.12228 .24838 L
.08065 .19802 L
.08499 .21272 L
.12981 .2671 L
s
.12228 .24838 m
.11562 .23025 L
.0768 .18386 L
.08065 .19802 L
.12228 .24838 L
s
.11562 .23025 m
.11011 .21386 L
.07362 .17114 L
.0768 .18386 L
.11562 .23025 L
s
.11011 .21386 m
.10599 .20058 L
.07125 .16087 L
.07362 .17114 L
.11011 .21386 L
s
.10599 .20058 m
.10345 .19184 L
.06978 .15414 L
.07125 .16087 L
.10599 .20058 L
s
.10345 .19184 m
.10259 .18878 L
.06928 .15179 L
.06978 .15414 L
.10345 .19184 L
s
.10259 .18878 m
.10345 .19184 L
.06978 .15414 L
.06928 .15179 L
.10259 .18878 L
s
.10345 .19184 m
.10599 .20058 L
.07125 .16087 L
.06978 .15414 L
.10345 .19184 L
s
.10599 .20058 m
.11011 .21386 L
.07362 .17114 L
.07125 .16087 L
.10599 .20058 L
s
.11011 .21386 m
.11562 .23025 L
.0768 .18386 L
.07362 .17114 L
.11011 .21386 L
s
.11562 .23025 m
.12228 .24838 L
.08065 .19802 L
.0768 .18386 L
.11562 .23025 L
s
.12228 .24838 m
.12981 .2671 L
.08499 .21272 L
.08065 .19802 L
.12228 .24838 L
s
.12981 .2671 m
.13786 .28551 L
.08964 .22726 L
.08499 .21272 L
.12981 .2671 L
s
.13786 .28551 m
.14609 .30289 L
.09439 .24107 L
.08964 .22726 L
.13786 .28551 L
s
.14609 .30289 m
.15415 .31873 L
.09904 .25373 L
.09439 .24107 L
.14609 .30289 L
s
.15415 .31873 m
.16167 .33264 L
.10339 .2649 L
.09904 .25373 L
.15415 .31873 L
s
.16167 .33264 m
.16833 .34433 L
.10723 .27434 L
.10339 .2649 L
.16167 .33264 L
s
.16833 .34433 m
.17384 .3536 L
.11041 .28186 L
.10723 .27434 L
.16833 .34433 L
s
.17384 .3536 m
.17796 .3603 L
.11279 .28732 L
.11041 .28186 L
.17384 .3536 L
s
.17796 .3603 m
.18051 .36436 L
.11426 .29063 L
.11279 .28732 L
.17796 .3603 L
s
.18051 .36436 m
.18137 .36572 L
.11475 .29174 L
.11426 .29063 L
.18051 .36436 L
s
.11475 .29174 m
.11426 .29063 L
.06475 .20474 L
.06498 .20552 L
.11475 .29174 L
s
.11426 .29063 m
.11279 .28732 L
.06409 .2024 L
.06475 .20474 L
.11426 .29063 L
s
.11279 .28732 m
.11041 .28186 L
.06301 .19856 L
.06409 .2024 L
.11279 .28732 L
s
.11041 .28186 m
.10723 .27434 L
.06157 .19327 L
.06301 .19856 L
.11041 .28186 L
s
.10723 .27434 m
.10339 .2649 L
.05983 .18665 L
.06157 .19327 L
.10723 .27434 L
s
.10339 .2649 m
.09904 .25373 L
.05787 .17884 L
.05983 .18665 L
.10339 .2649 L
s
.09904 .25373 m
.09439 .24107 L
.05576 .17002 L
.05787 .17884 L
.09904 .25373 L
s
.09439 .24107 m
.08964 .22726 L
.05361 .16043 L
.05576 .17002 L
.09439 .24107 L
s
.08964 .22726 m
.08499 .21272 L
.05151 .15038 L
.05361 .16043 L
.08964 .22726 L
s
.08499 .21272 m
.08065 .19802 L
.04954 .14026 L
.05151 .15038 L
.08499 .21272 L
s
.08065 .19802 m
.0768 .18386 L
.0478 .13055 L
.04954 .14026 L
.08065 .19802 L
s
.0768 .18386 m
.07362 .17114 L
.04636 .12185 L
.0478 .13055 L
.0768 .18386 L
s
.07362 .17114 m
.07125 .16087 L
.04528 .11485 L
.04636 .12185 L
.07362 .17114 L
s
.07125 .16087 m
.06978 .15414 L
.04462 .11028 L
.04528 .11485 L
.07125 .16087 L
s
.06978 .15414 m
.06928 .15179 L
.04439 .10868 L
.04462 .11028 L
.06978 .15414 L
s
.06928 .15179 m
.06978 .15414 L
.04462 .11028 L
.04439 .10868 L
.06928 .15179 L
s
.06978 .15414 m
.07125 .16087 L
.04528 .11485 L
.04462 .11028 L
.06978 .15414 L
s
.07125 .16087 m
.07362 .17114 L
.04636 .12185 L
.04528 .11485 L
.07125 .16087 L
s
.07362 .17114 m
.0768 .18386 L
.0478 .13055 L
.04636 .12185 L
.07362 .17114 L
s
.0768 .18386 m
.08065 .19802 L
.04954 .14026 L
.0478 .13055 L
.0768 .18386 L
s
.08065 .19802 m
.08499 .21272 L
.05151 .15038 L
.04954 .14026 L
.08065 .19802 L
s
.08499 .21272 m
.08964 .22726 L
.05361 .16043 L
.05151 .15038 L
.08499 .21272 L
s
.08964 .22726 m
.09439 .24107 L
.05576 .17002 L
.05361 .16043 L
.08964 .22726 L
s
.09439 .24107 m
.09904 .25373 L
.05787 .17884 L
.05576 .17002 L
.09439 .24107 L
s
.09904 .25373 m
.10339 .2649 L
.05983 .18665 L
.05787 .17884 L
.09904 .25373 L
s
.10339 .2649 m
.10723 .27434 L
.06157 .19327 L
.05983 .18665 L
.10339 .2649 L
s
.10723 .27434 m
.11041 .28186 L
.06301 .19856 L
.06157 .19327 L
.10723 .27434 L
s
.11041 .28186 m
.11279 .28732 L
.06409 .2024 L
.06301 .19856 L
.11041 .28186 L
s
.11279 .28732 m
.11426 .29063 L
.06475 .20474 L
.06409 .2024 L
.11279 .28732 L
s
.11426 .29063 m
.11475 .29174 L
.06498 .20552 L
.06475 .20474 L
.11426 .29063 L
s
.11475 .29174 m
.11426 .29063 L
.06475 .20474 L
.06498 .20552 L
.11475 .29174 L
s
.11426 .29063 m
.11279 .28732 L
.06409 .2024 L
.06475 .20474 L
.11426 .29063 L
s
.11279 .28732 m
.11041 .28186 L
.06301 .19856 L
.06409 .2024 L
.11279 .28732 L
s
.11041 .28186 m
.10723 .27434 L
.06157 .19327 L
.06301 .19856 L
.11041 .28186 L
s
.10723 .27434 m
.10339 .2649 L
.05983 .18665 L
.06157 .19327 L
.10723 .27434 L
s
.10339 .2649 m
.09904 .25373 L
.05787 .17884 L
.05983 .18665 L
.10339 .2649 L
s
.09904 .25373 m
.09439 .24107 L
.05576 .17002 L
.05787 .17884 L
.09904 .25373 L
s
.09439 .24107 m
.08964 .22726 L
.05361 .16043 L
.05576 .17002 L
.09439 .24107 L
s
.08964 .22726 m
.08499 .21272 L
.05151 .15038 L
.05361 .16043 L
.08964 .22726 L
s
.08499 .21272 m
.08065 .19802 L
.04954 .14026 L
.05151 .15038 L
.08499 .21272 L
s
.08065 .19802 m
.0768 .18386 L
.0478 .13055 L
.04954 .14026 L
.08065 .19802 L
s
.0768 .18386 m
.07362 .17114 L
.04636 .12185 L
.0478 .13055 L
.0768 .18386 L
s
.07362 .17114 m
.07125 .16087 L
.04528 .11485 L
.04636 .12185 L
.07362 .17114 L
s
.07125 .16087 m
.06978 .15414 L
.04462 .11028 L
.04528 .11485 L
.07125 .16087 L
s
.06978 .15414 m
.06928 .15179 L
.04439 .10868 L
.04462 .11028 L
.06978 .15414 L
s
.06928 .15179 m
.06978 .15414 L
.04462 .11028 L
.04439 .10868 L
.06928 .15179 L
s
.06978 .15414 m
.07125 .16087 L
.04528 .11485 L
.04462 .11028 L
.06978 .15414 L
s
.07125 .16087 m
.07362 .17114 L
.04636 .12185 L
.04528 .11485 L
.07125 .16087 L
s
.07362 .17114 m
.0768 .18386 L
.0478 .13055 L
.04636 .12185 L
.07362 .17114 L
s
.0768 .18386 m
.08065 .19802 L
.04954 .14026 L
.0478 .13055 L
.0768 .18386 L
s
.08065 .19802 m
.08499 .21272 L
.05151 .15038 L
.04954 .14026 L
.08065 .19802 L
s
.08499 .21272 m
.08964 .22726 L
.05361 .16043 L
.05151 .15038 L
.08499 .21272 L
s
.08964 .22726 m
.09439 .24107 L
.05576 .17002 L
.05361 .16043 L
.08964 .22726 L
s
.09439 .24107 m
.09904 .25373 L
.05787 .17884 L
.05576 .17002 L
.09439 .24107 L
s
.09904 .25373 m
.10339 .2649 L
.05983 .18665 L
.05787 .17884 L
.09904 .25373 L
s
.10339 .2649 m
.10723 .27434 L
.06157 .19327 L
.05983 .18665 L
.10339 .2649 L
s
.10723 .27434 m
.11041 .28186 L
.06301 .19856 L
.06157 .19327 L
.10723 .27434 L
s
.11041 .28186 m
.11279 .28732 L
.06409 .2024 L
.06301 .19856 L
.11041 .28186 L
s
.11279 .28732 m
.11426 .29063 L
.06475 .20474 L
.06409 .2024 L
.11279 .28732 L
s
.11426 .29063 m
.11475 .29174 L
.06498 .20552 L
.06475 .20474 L
.11426 .29063 L
s
.06498 .20552 m
.06475 .20474 L
.03416 .11044 L
.03422 .11085 L
.06498 .20552 L
s
.06475 .20474 m
.06409 .2024 L
.03399 .10923 L
.03416 .11044 L
.06475 .20474 L
s
.06409 .2024 m
.06301 .19856 L
.03372 .10725 L
.03399 .10923 L
.06409 .2024 L
s
.06301 .19856 m
.06157 .19327 L
.03335 .10452 L
.03372 .10725 L
.06301 .19856 L
s
.06157 .19327 m
.05983 .18665 L
.03291 .10111 L
.03335 .10452 L
.06157 .19327 L
s
.05983 .18665 m
.05787 .17884 L
.03242 .09709 L
.03291 .10111 L
.05983 .18665 L
s
.05787 .17884 m
.05576 .17002 L
.03189 .09257 L
.03242 .09709 L
.05787 .17884 L
s
.05576 .17002 m
.05361 .16043 L
.03134 .08766 L
.03189 .09257 L
.05576 .17002 L
s
.05361 .16043 m
.05151 .15038 L
.03081 .08253 L
.03134 .08766 L
.05361 .16043 L
s
.05151 .15038 m
.04954 .14026 L
.03031 .07736 L
.03081 .08253 L
.05151 .15038 L
s
.04954 .14026 m
.0478 .13055 L
.02987 .07242 L
.03031 .07736 L
.04954 .14026 L
s
.0478 .13055 m
.04636 .12185 L
.02951 .06801 L
.02987 .07242 L
.0478 .13055 L
s
.04636 .12185 m
.04528 .11485 L
.02924 .06446 L
.02951 .06801 L
.04636 .12185 L
s
.04528 .11485 m
.04462 .11028 L
.02907 .06215 L
.02924 .06446 L
.04528 .11485 L
s
.04462 .11028 m
.04439 .10868 L
.02901 .06134 L
.02907 .06215 L
.04462 .11028 L
s
.04439 .10868 m
.04462 .11028 L
.02907 .06215 L
.02901 .06134 L
.04439 .10868 L
s
.04462 .11028 m
.04528 .11485 L
.02924 .06446 L
.02907 .06215 L
.04462 .11028 L
s
.04528 .11485 m
.04636 .12185 L
.02951 .06801 L
.02924 .06446 L
.04528 .11485 L
s
.04636 .12185 m
.0478 .13055 L
.02987 .07242 L
.02951 .06801 L
.04636 .12185 L
s
.0478 .13055 m
.04954 .14026 L
.03031 .07736 L
.02987 .07242 L
.0478 .13055 L
s
.04954 .14026 m
.05151 .15038 L
.03081 .08253 L
.03031 .07736 L
.04954 .14026 L
s
.05151 .15038 m
.05361 .16043 L
.03134 .08766 L
.03081 .08253 L
.05151 .15038 L
s
.05361 .16043 m
.05576 .17002 L
.03189 .09257 L
.03134 .08766 L
.05361 .16043 L
s
.05576 .17002 m
.05787 .17884 L
.03242 .09709 L
.03189 .09257 L
.05576 .17002 L
s
.05787 .17884 m
.05983 .18665 L
.03291 .10111 L
.03242 .09709 L
.05787 .17884 L
s
.05983 .18665 m
.06157 .19327 L
.03335 .10452 L
.03291 .10111 L
.05983 .18665 L
s
.06157 .19327 m
.06301 .19856 L
.03372 .10725 L
.03335 .10452 L
.06157 .19327 L
s
.06301 .19856 m
.06409 .2024 L
.03399 .10923 L
.03372 .10725 L
.06301 .19856 L
s
.06409 .2024 m
.06475 .20474 L
.03416 .11044 L
.03399 .10923 L
.06409 .2024 L
s
.06475 .20474 m
.06498 .20552 L
.03422 .11085 L
.03416 .11044 L
.06475 .20474 L
s
.06498 .20552 m
.06475 .20474 L
.03416 .11044 L
.03422 .11085 L
.06498 .20552 L
s
.06475 .20474 m
.06409 .2024 L
.03399 .10923 L
.03416 .11044 L
.06475 .20474 L
s
.06409 .2024 m
.06301 .19856 L
.03372 .10725 L
.03399 .10923 L
.06409 .2024 L
s
.06301 .19856 m
.06157 .19327 L
.03335 .10452 L
.03372 .10725 L
.06301 .19856 L
s
.06157 .19327 m
.05983 .18665 L
.03291 .10111 L
.03335 .10452 L
.06157 .19327 L
s
.05983 .18665 m
.05787 .17884 L
.03242 .09709 L
.03291 .10111 L
.05983 .18665 L
s
.05787 .17884 m
.05576 .17002 L
.03189 .09257 L
.03242 .09709 L
.05787 .17884 L
s
.05576 .17002 m
.05361 .16043 L
.03134 .08766 L
.03189 .09257 L
.05576 .17002 L
s
.05361 .16043 m
.05151 .15038 L
.03081 .08253 L
.03134 .08766 L
.05361 .16043 L
s
.05151 .15038 m
.04954 .14026 L
.03031 .07736 L
.03081 .08253 L
.05151 .15038 L
s
.04954 .14026 m
.0478 .13055 L
.02987 .07242 L
.03031 .07736 L
.04954 .14026 L
s
.0478 .13055 m
.04636 .12185 L
.02951 .06801 L
.02987 .07242 L
.0478 .13055 L
s
.04636 .12185 m
.04528 .11485 L
.02924 .06446 L
.02951 .06801 L
.04636 .12185 L
s
.04528 .11485 m
.04462 .11028 L
.02907 .06215 L
.02924 .06446 L
.04528 .11485 L
s
.04462 .11028 m
.04439 .10868 L
.02901 .06134 L
.02907 .06215 L
.04462 .11028 L
s
.04439 .10868 m
.04462 .11028 L
.02907 .06215 L
.02901 .06134 L
.04439 .10868 L
s
.04462 .11028 m
.04528 .11485 L
.02924 .06446 L
.02907 .06215 L
.04462 .11028 L
s
.04528 .11485 m
.04636 .12185 L
.02951 .06801 L
.02924 .06446 L
.04528 .11485 L
s
.04636 .12185 m
.0478 .13055 L
.02987 .07242 L
.02951 .06801 L
.04636 .12185 L
s
.0478 .13055 m
.04954 .14026 L
.03031 .07736 L
.02987 .07242 L
.0478 .13055 L
s
.04954 .14026 m
.05151 .15038 L
.03081 .08253 L
.03031 .07736 L
.04954 .14026 L
s
.05151 .15038 m
.05361 .16043 L
.03134 .08766 L
.03081 .08253 L
.05151 .15038 L
s
.05361 .16043 m
.05576 .17002 L
.03189 .09257 L
.03134 .08766 L
.05361 .16043 L
s
.05576 .17002 m
.05787 .17884 L
.03242 .09709 L
.03189 .09257 L
.05576 .17002 L
s
.05787 .17884 m
.05983 .18665 L
.03291 .10111 L
.03242 .09709 L
.05787 .17884 L
s
.05983 .18665 m
.06157 .19327 L
.03335 .10452 L
.03291 .10111 L
.05983 .18665 L
s
.06157 .19327 m
.06301 .19856 L
.03372 .10725 L
.03335 .10452 L
.06157 .19327 L
s
.06301 .19856 m
.06409 .2024 L
.03399 .10923 L
.03372 .10725 L
.06301 .19856 L
s
.06409 .2024 m
.06475 .20474 L
.03416 .11044 L
.03399 .10923 L
.06409 .2024 L
s
.06475 .20474 m
.06498 .20552 L
.03422 .11085 L
.03416 .11044 L
.06475 .20474 L
s
.03422 .11085 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
.03422 .11085 L
s
.03416 .11044 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
.03416 .11044 L
s
.03399 .10923 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
.03399 .10923 L
s
.03372 .10725 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
.03372 .10725 L
s
.03335 .10452 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
.03335 .10452 L
s
.03291 .10111 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
.03291 .10111 L
s
.03242 .09709 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
.03242 .09709 L
s
.03189 .09257 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
.03189 .09257 L
s
.03134 .08766 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
.03134 .08766 L
s
.03081 .08253 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
.03081 .08253 L
s
.03031 .07736 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
.03031 .07736 L
s
.02987 .07242 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
.02987 .07242 L
s
.02951 .06801 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
.02951 .06801 L
s
.02924 .06446 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
.02924 .06446 L
s
.02907 .06215 m
.02901 .06134 L
.02381 .01184 L
.02381 .01184 L
.02907 .06215 L
s
.02901 .06134 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
.02901 .06134 L
s
.02907 .06215 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
.02907 .06215 L
s
.02924 .06446 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
.02924 .06446 L
s
.02951 .06801 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
.02951 .06801 L
s
.02987 .07242 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
.02987 .07242 L
s
.03031 .07736 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
.03031 .07736 L
s
.03081 .08253 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
.03081 .08253 L
s
.03134 .08766 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
.03134 .08766 L
s
.03189 .09257 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
.03189 .09257 L
s
.03242 .09709 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
.03242 .09709 L
s
.03291 .10111 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
.03291 .10111 L
s
.03335 .10452 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
.03335 .10452 L
s
.03372 .10725 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
.03372 .10725 L
s
.03399 .10923 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
.03399 .10923 L
s
.03416 .11044 m
.03422 .11085 L
.02381 .01184 L
.02381 .01184 L
.03416 .11044 L
s
.03422 .11085 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
.03422 .11085 L
s
.03416 .11044 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
.03416 .11044 L
s
.03399 .10923 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
.03399 .10923 L
s
.03372 .10725 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
.03372 .10725 L
s
.03335 .10452 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
.03335 .10452 L
s
.03291 .10111 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
.03291 .10111 L
s
.03242 .09709 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
.03242 .09709 L
s
.03189 .09257 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
.03189 .09257 L
s
.03134 .08766 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
.03134 .08766 L
s
.03081 .08253 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
.03081 .08253 L
s
.03031 .07736 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
.03031 .07736 L
s
.02987 .07242 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
.02987 .07242 L
s
.02951 .06801 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
.02951 .06801 L
s
.02924 .06446 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
.02924 .06446 L
s
.02907 .06215 m
.02901 .06134 L
.02381 .01184 L
.02381 .01184 L
.02907 .06215 L
s
.02901 .06134 m
.02907 .06215 L
.02381 .01184 L
.02381 .01184 L
.02901 .06134 L
s
.02907 .06215 m
.02924 .06446 L
.02381 .01184 L
.02381 .01184 L
.02907 .06215 L
s
.02924 .06446 m
.02951 .06801 L
.02381 .01184 L
.02381 .01184 L
.02924 .06446 L
s
.02951 .06801 m
.02987 .07242 L
.02381 .01184 L
.02381 .01184 L
.02951 .06801 L
s
.02987 .07242 m
.03031 .07736 L
.02381 .01184 L
.02381 .01184 L
.02987 .07242 L
s
.03031 .07736 m
.03081 .08253 L
.02381 .01184 L
.02381 .01184 L
.03031 .07736 L
s
.03081 .08253 m
.03134 .08766 L
.02381 .01184 L
.02381 .01184 L
.03081 .08253 L
s
.03134 .08766 m
.03189 .09257 L
.02381 .01184 L
.02381 .01184 L
.03134 .08766 L
s
.03189 .09257 m
.03242 .09709 L
.02381 .01184 L
.02381 .01184 L
.03189 .09257 L
s
.03242 .09709 m
.03291 .10111 L
.02381 .01184 L
.02381 .01184 L
.03242 .09709 L
s
.03291 .10111 m
.03335 .10452 L
.02381 .01184 L
.02381 .01184 L
.03291 .10111 L
s
.03335 .10452 m
.03372 .10725 L
.02381 .01184 L
.02381 .01184 L
.03335 .10452 L
s
.03372 .10725 m
.03399 .10923 L
.02381 .01184 L
.02381 .01184 L
.03372 .10725 L
s
.03399 .10923 m
.03416 .11044 L
.02381 .01184 L
.02381 .01184 L
.03399 .10923 L
s
.03416 .11044 m
.03422 .11085 L
.02381 .01184 L
.02381 .01184 L
.03416 .11044 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 143.188},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 287}, {142.188, 0}} -> {-1.43316, -0.294083, \
0.0239245, 0.0239245}}],

Cell[OutputFormData["\<\
Graphics[{{CMYKColor[0.016666666666666666, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9344428022014168, 0.623735072453278}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.025, 0.1], Polygon[{{-1., 0.}, \
{-1., 0.}, {-0.9358597315848943, 0.613577092391689}, 
     {-0.9348009477166837, 0.6211835161491764}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721149}, \
{-0.9358597315848943, 0.613577092391689}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.058333333333333334, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279119}, 
     {-0.9375728798703992, 0.6010618457721149}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.075, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196118}, \
{-0.9398655197725243, 0.5838857533279119}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.09166666666666666, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, 
     {-0.9426374519262397, 0.5624063276196118}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.508595070176279}, \
{-0.945767529595222, 0.5371028573756114}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.125, 0.1], Polygon[{{-1., 0.}, \
{-1., 0.}, {-0.9525452499365675, 0.4776706018498101}, 
     {-0.9491189533655577, 0.508595070176279}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.4453237472356564}, \
{-0.9525452499365675, 0.4776706018498101}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.15833333333333333, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9590267513758856, 0.4128060526669478}, 
     {-0.9558966737069031, 0.4453237472356564}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.175, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.961798683529601, 0.3816816923272188}, \
{-0.9590267513758856, 0.4128060526669478}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.19166666666666665, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, 
     {-0.961798683529601, 0.3816816923272188}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9658044717172308, 0.33154008354139414}, \
{-0.964091323431726, 0.35386023041001824}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.225, 0.1], Polygon[{{-1., 0.}, \
{-1., 0.}, {-0.9668632555854415, 0.31695593148714024}, 
     {-0.9658044717172308, 0.33154008354139414}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9672214011007084, 0.311867536226639}, \
{-0.9668632555854415, 0.31695593148714024}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.2583333333333333, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9668632555854415, 0.31695593148714024}, 
     {-0.9672214011007084, 0.311867536226639}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.275, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9658044717172308, 0.33154008354139414}, \
{-0.9668632555854415, 0.31695593148714024}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.2916666666666667, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, 
     {-0.9658044717172308, 0.33154008354139414}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.961798683529601, 0.38168169232721855}, \
{-0.964091323431726, 0.35386023041001824}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.325, 0.1], Polygon[{{-1., 0.}, \
{-1., 0.}, {-0.9590267513758856, 0.4128060526669478}, 
     {-0.961798683529601, 0.38168169232721855}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.4453237472356564}, \
{-0.9590267513758856, 0.4128060526669478}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.35833333333333334, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9525452499365675, 0.47767060184980986}, 
     {-0.9558966737069031, 0.4453237472356564}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.375, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.508595070176279}, \
{-0.9525452499365675, 0.47767060184980986}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.39166666666666666, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, 
     {-0.9491189533655577, 0.508595070176279}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196116}, \
{-0.945767529595222, 0.5371028573756114}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.425, 0.1], Polygon[{{-1., 0.}, \
{-1., 0.}, {-0.9398655197725243, 0.5838857533279119}, 
     {-0.9426374519262397, 0.5624063276196116}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721149}, \
{-0.9398655197725243, 0.5838857533279119}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.4583333333333333, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9358597315848944, 0.6135770923916888}, 
     {-0.9375728798703992, 0.6010618457721149}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.475, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9358597315848944, 0.6135770923916888}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.49166666666666664, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9344428022014168, 0.623735072453278}, 
     {-0.9348009477166837, 0.6211835161491764}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9344428022014168, 0.623735072453278}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.525, 0.1], Polygon[{{-1., 0.}, \
{-1., 0.}, {-0.9358597315848943, 0.613577092391689}, 
     {-0.9348009477166837, 0.6211835161491764}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721151}, \
{-0.9358597315848943, 0.613577092391689}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.5583333333333333, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279119}, 
     {-0.9375728798703992, 0.6010618457721151}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.575, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196118}, \
{-0.9398655197725243, 0.5838857533279119}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.5916666666666667, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, 
     {-0.9426374519262397, 0.5624063276196118}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.508595070176279}, \
{-0.945767529595222, 0.5371028573756114}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.625, 0.1], Polygon[{{-1., 0.}, \
{-1., 0.}, {-0.9525452499365675, 0.4776706018498101}, 
     {-0.9491189533655577, 0.508595070176279}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.4453237472356564}, \
{-0.9525452499365675, 0.4776706018498101}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.6583333333333333, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9590267513758856, 0.4128060526669481}, 
     {-0.9558966737069031, 0.4453237472356564}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.675, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.961798683529601, 0.3816816923272188}, \
{-0.9590267513758856, 0.4128060526669481}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.6916666666666667, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, 
     {-0.961798683529601, 0.3816816923272188}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9658044717172308, 0.33154008354139414}, \
{-0.964091323431726, 0.35386023041001824}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.725, 0.1], Polygon[{{-1., 0.}, \
{-1., 0.}, {-0.9668632555854414, 0.31695593148714096}, 
     {-0.9658044717172308, 0.33154008354139414}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9672214011007084, 0.311867536226639}, \
{-0.9668632555854414, 0.31695593148714096}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.7583333333333333, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9668632555854415, 0.31695593148714024}, 
     {-0.9672214011007084, 0.311867536226639}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.775, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9658044717172309, 0.33154008354139347}, \
{-0.9668632555854415, 0.31695593148714024}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.7916666666666666, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, 
     {-0.9658044717172309, 0.33154008354139347}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9617986835296011, 0.38168169232721827}, \
{-0.964091323431726, 0.35386023041001824}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.825, 0.1], Polygon[{{-1., 0.}, \
{-1., 0.}, {-0.9590267513758856, 0.41280605266694753}, 
     {-0.9617986835296011, 0.38168169232721827}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.44532374723565615}, \
{-0.9590267513758856, 0.41280605266694753}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.8583333333333333, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9525452499365675, 0.47767060184980986}, 
     {-0.9558966737069031, 0.44532374723565615}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.875, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.5085950701762788}, \
{-0.9525452499365675, 0.47767060184980986}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.8916666666666666, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, 
     {-0.9491189533655577, 0.5085950701762788}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196116}, \
{-0.945767529595222, 0.5371028573756114}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.9249999999999999, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279117}, 
     {-0.9426374519262397, 0.5624063276196116}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721149}, \
{-0.9398655197725243, 0.5838857533279117}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.9583333333333334, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9358597315848944, 0.6135770923916888}, 
     {-0.9375728798703992, 0.6010618457721149}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.975, 0.1], 
   Polygon[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9358597315848944, 0.6135770923916888}}]}, 
  {CMYKColor[0.016666666666666666, 0.5, 0.9916666666666667, 0.1], \
Polygon[{{-1., 0.}, {-1., 0.}, {-0.9344428022014168, 0.623735072453278}, 
     {-0.9348009477166837, 0.6211835161491764}}]}, {CMYKColor[0.05, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{-0.9344428022014168, 0.623735072453278}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112804, 1.2152748245287444}, 
     {-0.7406363729278029, 1.2202099292274005}}]}, {CMYKColor[0.05, 0.5, \
0.025, 0.1], 
   Polygon[{{-0.9348009477166837, 0.6211835161491764}, {-0.9358597315848943, \
0.613577092391689}, {-0.7462421638484733, 1.2005567894684717}, 
     {-0.7420533023112804, 1.2152748245287444}}]}, {CMYKColor[0.05, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{-0.9358597315848943, 0.613577092391689}, {-0.9375728798703992, \
0.6010618457721149}, {-0.7530198841898188, 1.1763209525760518}, 
     {-0.7462421638484733, 1.2005567894684717}}]}, {CMYKColor[0.05, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{-0.9375728798703992, 0.6010618457721149}, {-0.9398655197725243, \
0.5838857533279119}, {-0.7620902444332892, 1.143020501605284}, 
     {-0.7530198841898188, 1.1763209525760518}}]}, {CMYKColor[0.05, 0.5, \
0.075, 0.1], 
   Polygon[{{-0.9398655197725243, 0.5838857533279119}, {-0.9426374519262397, \
0.5624063276196118}, {-0.7730568263118275, 1.1013148858947208}, 
     {-0.7620902444332892, 1.143020501605284}}]}, {CMYKColor[0.05, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{-0.9426374519262397, 0.5624063276196118}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738435, 1.0520980143876293}, 
     {-0.7730568263118275, 1.1013148858947208}}]}, {CMYKColor[0.05, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{-0.945767529595222, 0.5371028573756114}, {-0.9491189533655577, \
0.508595070176279}, {-0.7986995593545068, 0.9965396214846545}, 
     {-0.7854403375738435, 1.0520980143876293}}]}, {CMYKColor[0.05, 0.5, \
0.125, 0.1], 
   Polygon[{{-0.9491189533655577, 0.508595070176279}, {-0.9525452499365675, \
0.4776706018498101}, {-0.8122550000371975, 0.9361441841071271}, 
     {-0.7986995593545068, 0.9965396214846545}}]}, {CMYKColor[0.05, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{-0.9525452499365675, 0.4776706018498101}, {-0.9558966737069031, \
0.4453237472356564}, {-0.8255142218178609, 0.8728320775698118}, 
     {-0.8122550000371975, 0.9361441841071271}}]}, {CMYKColor[0.05, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{-0.9558966737069031, 0.4453237472356564}, {-0.9590267513758856, \
0.4128060526669478}, {-0.8378977330798768, 0.8090441125945328}, 
     {-0.8255142218178609, 0.8728320775698118}}]}, {CMYKColor[0.05, 0.5, \
0.175, 0.1], 
   Polygon[{{-0.9590267513758856, 0.4128060526669478}, {-0.961798683529601, \
0.3816816923272188}, {-0.8488643149584152, 0.7478557941640108}, 
     {-0.8378977330798768, 0.8090441125945328}}]}, {CMYKColor[0.05, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{-0.961798683529601, 0.3816816923272188}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018857, 0.6930472461935369}, 
     {-0.8488643149584152, 0.7478557941640108}}]}, {CMYKColor[0.05, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{-0.964091323431726, 0.35386023041001824}, {-0.9658044717172308, \
0.33154008354139414}, {-0.864712395543231, 0.6489952411032603}, 
     {-0.8579346752018857, 0.6930472461935369}}]}, {CMYKColor[0.05, 0.5, \
0.225, 0.1], 
   Polygon[{{-0.9658044717172308, 0.33154008354139414}, {-0.9668632555854415, \
0.31695593148714024}, {-0.868901257080424, 0.6201700772082609}, 
     {-0.864712395543231, 0.6489952411032603}}]}, {CMYKColor[0.05, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{-0.9668632555854415, 0.31695593148714024}, {-0.9672214011007084, \
0.311867536226639}, {-0.8703181864639015, 0.6101049646137003}, 
     {-0.868901257080424, 0.6201700772082609}}]}, {CMYKColor[0.05, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{-0.9672214011007084, 0.311867536226639}, {-0.9668632555854415, \
0.31695593148714024}, {-0.8689012570804241, 0.6201700772082606}, 
     {-0.8703181864639015, 0.6101049646137003}}]}, {CMYKColor[0.05, 0.5, \
0.275, 0.1], 
   Polygon[{{-0.9668632555854415, 0.31695593148714024}, {-0.9658044717172308, \
0.33154008354139414}, {-0.864712395543231, 0.6489952411032603}, 
     {-0.8689012570804241, 0.6201700772082606}}]}, {CMYKColor[0.05, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{-0.9658044717172308, 0.33154008354139414}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018857, 0.6930472461935366}, 
     {-0.864712395543231, 0.6489952411032603}}]}, {CMYKColor[0.05, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{-0.964091323431726, 0.35386023041001824}, {-0.961798683529601, \
0.38168169232721855}, {-0.8488643149584152, 0.7478557941640107}, 
     {-0.8579346752018857, 0.6930472461935366}}]}, {CMYKColor[0.05, 0.5, \
0.325, 0.1], 
   Polygon[{{-0.961798683529601, 0.38168169232721855}, {-0.9590267513758856, \
0.4128060526669478}, {-0.8378977330798769, 0.8090441125945326}, 
     {-0.8488643149584152, 0.7478557941640107}}]}, {CMYKColor[0.05, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{-0.9590267513758856, 0.4128060526669478}, {-0.9558966737069031, \
0.4453237472356564}, {-0.8255142218178609, 0.8728320775698117}, 
     {-0.8378977330798769, 0.8090441125945326}}]}, {CMYKColor[0.05, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{-0.9558966737069031, 0.4453237472356564}, {-0.9525452499365675, \
0.47767060184980986}, {-0.8122550000371976, 0.9361441841071267}, 
     {-0.8255142218178609, 0.8728320775698117}}]}, {CMYKColor[0.05, 0.5, \
0.375, 0.1], 
   Polygon[{{-0.9525452499365675, 0.47767060184980986}, {-0.9491189533655577, \
0.508595070176279}, {-0.7986995593545069, 0.9965396214846542}, 
     {-0.8122550000371976, 0.9361441841071267}}]}, {CMYKColor[0.05, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{-0.9491189533655577, 0.508595070176279}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738435, 1.0520980143876293}, 
     {-0.7986995593545069, 0.9965396214846542}}]}, {CMYKColor[0.05, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{-0.945767529595222, 0.5371028573756114}, {-0.9426374519262397, \
0.5624063276196116}, {-0.7730568263118276, 1.1013148858947206}, 
     {-0.7854403375738435, 1.0520980143876293}}]}, {CMYKColor[0.05, 0.5, \
0.425, 0.1], 
   Polygon[{{-0.9426374519262397, 0.5624063276196116}, {-0.9398655197725243, \
0.5838857533279119}, {-0.7620902444332892, 1.1430205016052837}, 
     {-0.7730568263118276, 1.1013148858947206}}]}, {CMYKColor[0.05, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{-0.9398655197725243, 0.5838857533279119}, {-0.9375728798703992, \
0.6010618457721149}, {-0.7530198841898188, 1.1763209525760518}, 
     {-0.7620902444332892, 1.1430205016052837}}]}, {CMYKColor[0.05, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{-0.9375728798703992, 0.6010618457721149}, {-0.9358597315848944, \
0.6135770923916888}, {-0.7462421638484733, 1.2005567894684717}, 
     {-0.7530198841898188, 1.1763209525760518}}]}, {CMYKColor[0.05, 0.5, \
0.475, 0.1], 
   Polygon[{{-0.9358597315848944, 0.6135770923916888}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112804, 1.2152748245287444}, 
     {-0.7462421638484733, 1.2005567894684717}}]}, {CMYKColor[0.05, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{-0.9348009477166837, 0.6211835161491764}, {-0.9344428022014168, \
0.623735072453278}, {-0.7406363729278029, 1.2202099292274005}, 
     {-0.7420533023112804, 1.2152748245287444}}]}, {CMYKColor[0.05, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{-0.9344428022014168, 0.623735072453278}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112804, 1.2152748245287444}, 
     {-0.7406363729278029, 1.2202099292274005}}]}, {CMYKColor[0.05, 0.5, \
0.525, 0.1], 
   Polygon[{{-0.9348009477166837, 0.6211835161491764}, {-0.9358597315848943, \
0.613577092391689}, {-0.7462421638484733, 1.2005567894684717}, 
     {-0.7420533023112804, 1.2152748245287444}}]}, {CMYKColor[0.05, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{-0.9358597315848943, 0.613577092391689}, {-0.9375728798703992, \
0.6010618457721151}, {-0.7530198841898188, 1.1763209525760518}, 
     {-0.7462421638484733, 1.2005567894684717}}]}, {CMYKColor[0.05, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{-0.9375728798703992, 0.6010618457721151}, {-0.9398655197725243, \
0.5838857533279119}, {-0.7620902444332891, 1.1430205016052841}, 
     {-0.7530198841898188, 1.1763209525760518}}]}, {CMYKColor[0.05, 0.5, \
0.575, 0.1], 
   Polygon[{{-0.9398655197725243, 0.5838857533279119}, {-0.9426374519262397, \
0.5624063276196118}, {-0.7730568263118276, 1.1013148858947208}, 
     {-0.7620902444332891, 1.1430205016052841}}]}, {CMYKColor[0.05, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{-0.9426374519262397, 0.5624063276196118}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738434, 1.0520980143876295}, 
     {-0.7730568263118276, 1.1013148858947208}}]}, {CMYKColor[0.05, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{-0.945767529595222, 0.5371028573756114}, {-0.9491189533655577, \
0.508595070176279}, {-0.7986995593545068, 0.9965396214846547}, 
     {-0.7854403375738434, 1.0520980143876295}}]}, {CMYKColor[0.05, 0.5, \
0.625, 0.1], 
   Polygon[{{-0.9491189533655577, 0.508595070176279}, {-0.9525452499365675, \
0.4776706018498101}, {-0.8122550000371975, 0.9361441841071272}, 
     {-0.7986995593545068, 0.9965396214846547}}]}, {CMYKColor[0.05, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{-0.9525452499365675, 0.4776706018498101}, {-0.9558966737069031, \
0.4453237472356564}, {-0.825514221817861, 0.8728320775698117}, 
     {-0.8122550000371975, 0.9361441841071272}}]}, {CMYKColor[0.05, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{-0.9558966737069031, 0.4453237472356564}, {-0.9590267513758856, \
0.4128060526669481}, {-0.8378977330798767, 0.8090441125945331}, 
     {-0.825514221817861, 0.8728320775698117}}]}, {CMYKColor[0.05, 0.5, \
0.675, 0.1], 
   Polygon[{{-0.9590267513758856, 0.4128060526669481}, {-0.961798683529601, \
0.3816816923272188}, {-0.8488643149584152, 0.747855794164011}, 
     {-0.8378977330798767, 0.8090441125945331}}]}, {CMYKColor[0.05, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{-0.961798683529601, 0.3816816923272188}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018856, 0.6930472461935369}, 
     {-0.8488643149584152, 0.747855794164011}}]}, {CMYKColor[0.05, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{-0.964091323431726, 0.35386023041001824}, {-0.9658044717172308, \
0.33154008354139414}, {-0.864712395543231, 0.6489952411032606}, 
     {-0.8579346752018856, 0.6930472461935369}}]}, {CMYKColor[0.05, 0.5, \
0.725, 0.1], 
   Polygon[{{-0.9658044717172308, 0.33154008354139414}, {-0.9668632555854414, \
0.31695593148714096}, {-0.868901257080424, 0.6201700772082609}, 
     {-0.864712395543231, 0.6489952411032606}}]}, {CMYKColor[0.05, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{-0.9668632555854414, 0.31695593148714096}, {-0.9672214011007084, \
0.311867536226639}, {-0.8703181864639015, 0.6101049646137003}, 
     {-0.868901257080424, 0.6201700772082609}}]}, {CMYKColor[0.05, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{-0.9672214011007084, 0.311867536226639}, {-0.9668632555854415, \
0.31695593148714024}, {-0.8689012570804241, 0.6201700772082606}, 
     {-0.8703181864639015, 0.6101049646137003}}]}, {CMYKColor[0.05, 0.5, \
0.775, 0.1], 
   Polygon[{{-0.9668632555854415, 0.31695593148714024}, {-0.9658044717172309, \
0.33154008354139347}, {-0.8647123955432311, 0.64899524110326}, 
     {-0.8689012570804241, 0.6201700772082606}}]}, {CMYKColor[0.05, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{-0.9658044717172309, 0.33154008354139347}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018857, 0.6930472461935366}, 
     {-0.8647123955432311, 0.64899524110326}}]}, {CMYKColor[0.05, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{-0.964091323431726, 0.35386023041001824}, {-0.9617986835296011, \
0.38168169232721827}, {-0.8488643149584153, 0.7478557941640104}, 
     {-0.8579346752018857, 0.6930472461935366}}]}, {CMYKColor[0.05, 0.5, \
0.825, 0.1], 
   Polygon[{{-0.9617986835296011, 0.38168169232721827}, {-0.9590267513758856, \
0.41280605266694753}, {-0.8378977330798769, 0.8090441125945322}, 
     {-0.8488643149584153, 0.7478557941640104}}]}, {CMYKColor[0.05, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{-0.9590267513758856, 0.41280605266694753}, {-0.9558966737069031, \
0.44532374723565615}, {-0.8255142218178609, 0.8728320775698117}, 
     {-0.8378977330798769, 0.8090441125945322}}]}, {CMYKColor[0.05, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{-0.9558966737069031, 0.44532374723565615}, {-0.9525452499365675, \
0.47767060184980986}, {-0.8122550000371977, 0.9361441841071265}, 
     {-0.8255142218178609, 0.8728320775698117}}]}, {CMYKColor[0.05, 0.5, \
0.875, 0.1], 
   Polygon[{{-0.9525452499365675, 0.47767060184980986}, {-0.9491189533655577, \
0.5085950701762788}, {-0.798699559354507, 0.9965396214846538}, 
     {-0.8122550000371977, 0.9361441841071265}}]}, {CMYKColor[0.05, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{-0.9491189533655577, 0.5085950701762788}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738435, 1.0520980143876293}, 
     {-0.798699559354507, 0.9965396214846538}}]}, {CMYKColor[0.05, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{-0.945767529595222, 0.5371028573756114}, {-0.9426374519262397, \
0.5624063276196116}, {-0.7730568263118276, 1.1013148858947206}, 
     {-0.7854403375738435, 1.0520980143876293}}]}, {CMYKColor[0.05, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{-0.9426374519262397, 0.5624063276196116}, {-0.9398655197725243, \
0.5838857533279117}, {-0.7620902444332892, 1.1430205016052835}, 
     {-0.7730568263118276, 1.1013148858947206}}]}, {CMYKColor[0.05, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{-0.9398655197725243, 0.5838857533279117}, {-0.9375728798703992, \
0.6010618457721149}, {-0.7530198841898188, 1.1763209525760518}, 
     {-0.7620902444332892, 1.1430205016052835}}]}, {CMYKColor[0.05, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{-0.9375728798703992, 0.6010618457721149}, {-0.9358597315848944, \
0.6135770923916888}, {-0.7462421638484733, 1.2005567894684717}, 
     {-0.7530198841898188, 1.1763209525760518}}]}, {CMYKColor[0.05, 0.5, \
0.975, 0.1], 
   Polygon[{{-0.9358597315848944, 0.6135770923916888}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112803, 1.2152748245287444}, 
     {-0.7462421638484733, 1.2005567894684717}}]}, {CMYKColor[0.05, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{-0.9348009477166837, 0.6211835161491764}, {-0.9344428022014168, \
0.623735072453278}, {-0.7406363729278029, 1.2202099292274005}, 
     {-0.7420533023112803, 1.2152748245287444}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{-0.7406363729278029, 1.2202099292274005}, {-0.7420533023112804, \
1.2152748245287444}, {-0.4301810607938247, 1.7563683493937294}, 
     {-0.42705098312484224, 1.7633557568774194}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{-0.7420533023112804, 1.2152748245287444}, {-0.7462421638484733, \
1.2005567894684717}, {-0.43943449438685805, 1.7355139912456732}, 
     {-0.4301810607938247, 1.7563683493937294}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{-0.7462421638484733, 1.2005567894684717}, {-0.7530198841898188, \
1.1763209525760518}, {-0.45440686445302647, 1.7011229525643672}, 
     {-0.43943449438685805, 1.7355139912456732}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{-0.7530198841898188, 1.1763209525760518}, {-0.7620902444332892, \
1.143020501605284}, {-0.4744438065750352, 1.653768235803273}, 
     {-0.45440686445302647, 1.7011229525643672}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{-0.7620902444332892, 1.143020501605284}, {-0.7730568263118275, \
1.1013148858947208}, {-0.49866961023423695, 1.5943005668830774}, 
     {-0.4744438065750352, 1.653768235803273}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{-0.7730568263118275, 1.1013148858947208}, {-0.7854403375738435, \
1.0520980143876293}, {-0.5260254915624212, 1.523900157708533}, 
     {-0.49866961023423695, 1.5943005668830774}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{-0.7854403375738435, 1.0520980143876293}, {-0.7986995593545068, \
0.9965396214846545}, {-0.5553158672774633, 1.444148941758488}, 
     {-0.5260254915624212, 1.523900157708533}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{-0.7986995593545068, 0.9965396214846545}, {-0.8122550000371975, \
0.9361441841071271}, {-0.5852606074097999, 1.3571288512592452}, 
     {-0.5553158672774633, 1.444148941758488}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{-0.8122550000371975, 0.9361441841071271}, {-0.8255142218178609, \
0.8728320775698118}, {-0.6145509831248422, 1.2655525104241707}, 
     {-0.5852606074097999, 1.3571288512592452}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{-0.8255142218178609, 0.8728320775698118}, {-0.8378977330798768, \
0.8090441125945328}, {-0.6419068644530264, 1.1729281630054869}, 
     {-0.6145509831248422, 1.2655525104241707}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{-0.8378977330798768, 0.8090441125945328}, {-0.8488643149584152, \
0.7478557941640108}, {-0.6661326681122282, 1.0837396094369778}, 
     {-0.6419068644530264, 1.1729281630054869}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{-0.8488643149584152, 0.7478557941640108}, {-0.8579346752018857, \
0.6930472461935369}, {-0.686169610234237, 1.0035621274868154}, 
     {-0.6661326681122282, 1.0837396094369778}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{-0.8579346752018857, 0.6930472461935369}, {-0.864712395543231, \
0.6489952411032603}, {-0.7011419803004051, 0.9389137397717197}, 
     {-0.686169610234237, 1.0035621274868154}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{-0.864712395543231, 0.6489952411032603}, {-0.868901257080424, \
0.6201700772082609}, {-0.7103954138934387, 0.8965062230902947}, 
     {-0.7011419803004051, 0.9389137397717197}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{-0.868901257080424, 0.6201700772082609}, {-0.8703181864639015, \
0.6101049646137003}, {-0.7135254915624211, 0.8816778784387097}, 
     {-0.7103954138934387, 0.8965062230902947}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{-0.8703181864639015, 0.6101049646137003}, {-0.8689012570804241, \
0.6201700772082606}, {-0.7103954138934387, 0.8965062230902947}, 
     {-0.7135254915624211, 0.8816778784387097}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{-0.8689012570804241, 0.6201700772082606}, {-0.864712395543231, \
0.6489952411032603}, {-0.7011419803004052, 0.9389137397717193}, 
     {-0.7103954138934387, 0.8965062230902947}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.864712395543231, 0.6489952411032603}, {-0.8579346752018857, \
0.6930472461935366}, {-0.686169610234237, 1.0035621274868152}, 
     {-0.7011419803004052, 0.9389137397717193}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.8579346752018857, 0.6930472461935366}, {-0.8488643149584152, \
0.7478557941640107}, {-0.6661326681122282, 1.0837396094369778}, 
     {-0.686169610234237, 1.0035621274868152}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{-0.8488643149584152, 0.7478557941640107}, {-0.8378977330798769, \
0.8090441125945326}, {-0.6419068644530265, 1.1729281630054864}, 
     {-0.6661326681122282, 1.0837396094369778}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.8378977330798769, 0.8090441125945326}, {-0.8255142218178609, \
0.8728320775698117}, {-0.6145509831248422, 1.2655525104241705}, 
     {-0.6419068644530265, 1.1729281630054864}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.8255142218178609, 0.8728320775698117}, {-0.8122550000371976, \
0.9361441841071267}, {-0.5852606074098001, 1.357128851259245}, 
     {-0.6145509831248422, 1.2655525104241705}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{-0.8122550000371976, 0.9361441841071267}, {-0.7986995593545069, \
0.9965396214846542}, {-0.5553158672774634, 1.4441489417584878}, 
     {-0.5852606074098001, 1.357128851259245}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.7986995593545069, 0.9965396214846542}, {-0.7854403375738435, \
1.0520980143876293}, {-0.5260254915624212, 1.523900157708533}, 
     {-0.5553158672774634, 1.4441489417584878}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.7854403375738435, 1.0520980143876293}, {-0.7730568263118276, \
1.1013148858947206}, {-0.4986696102342371, 1.594300566883077}, 
     {-0.5260254915624212, 1.523900157708533}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{-0.7730568263118276, 1.1013148858947206}, {-0.7620902444332892, \
1.1430205016052837}, {-0.47444380657503515, 1.653768235803273}, 
     {-0.4986696102342371, 1.594300566883077}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.7620902444332892, 1.1430205016052837}, {-0.7530198841898188, \
1.1763209525760518}, {-0.45440686445302647, 1.7011229525643672}, 
     {-0.47444380657503515, 1.653768235803273}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.7530198841898188, 1.1763209525760518}, {-0.7462421638484733, \
1.2005567894684717}, {-0.4394344943868581, 1.735513991245673}, 
     {-0.45440686445302647, 1.7011229525643672}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{-0.7462421638484733, 1.2005567894684717}, {-0.7420533023112804, \
1.2152748245287444}, {-0.4301810607938247, 1.7563683493937294}, 
     {-0.4394344943868581, 1.735513991245673}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.7420533023112804, 1.2152748245287444}, {-0.7406363729278029, \
1.2202099292274005}, {-0.42705098312484224, 1.7633557568774194}, 
     {-0.4301810607938247, 1.7563683493937294}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.7406363729278029, 1.2202099292274005}, {-0.7420533023112804, \
1.2152748245287444}, {-0.43018106079382457, 1.7563683493937297}, 
     {-0.42705098312484224, 1.7633557568774194}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{-0.7420533023112804, 1.2152748245287444}, {-0.7462421638484733, \
1.2005567894684717}, {-0.4394344943868581, 1.7355139912456732}, 
     {-0.43018106079382457, 1.7563683493937297}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-0.7462421638484733, 1.2005567894684717}, {-0.7530198841898188, \
1.1763209525760518}, {-0.45440686445302636, 1.7011229525643672}, 
     {-0.4394344943868581, 1.7355139912456732}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.7530198841898188, 1.1763209525760518}, {-0.7620902444332891, \
1.1430205016052841}, {-0.47444380657503504, 1.6537682358032735}, 
     {-0.45440686445302636, 1.7011229525643672}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{-0.7620902444332891, 1.1430205016052841}, {-0.7730568263118276, \
1.1013148858947208}, {-0.4986696102342368, 1.5943005668830776}, 
     {-0.47444380657503504, 1.6537682358032735}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.7730568263118276, 1.1013148858947208}, {-0.7854403375738434, \
1.0520980143876295}, {-0.526025491562421, 1.5239001577085334}, 
     {-0.4986696102342368, 1.5943005668830776}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-0.7854403375738434, 1.0520980143876295}, {-0.7986995593545068, \
0.9965396214846547}, {-0.5553158672774632, 1.4441489417584885}, 
     {-0.526025491562421, 1.5239001577085334}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{-0.7986995593545068, 0.9965396214846547}, {-0.8122550000371975, \
0.9361441841071272}, {-0.5852606074097999, 1.3571288512592454}, 
     {-0.5553158672774632, 1.4441489417584885}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{-0.8122550000371975, 0.9361441841071272}, {-0.825514221817861, \
0.8728320775698117}, {-0.6145509831248421, 1.265552510424171}, 
     {-0.5852606074097999, 1.3571288512592454}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.825514221817861, 0.8728320775698117}, {-0.8378977330798767, \
0.8090441125945331}, {-0.6419068644530262, 1.1729281630054873}, 
     {-0.6145509831248421, 1.265552510424171}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{-0.8378977330798767, 0.8090441125945331}, {-0.8488643149584152, \
0.747855794164011}, {-0.6661326681122279, 1.0837396094369784}, 
     {-0.6419068644530262, 1.1729281630054873}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.8488643149584152, 0.747855794164011}, {-0.8579346752018856, \
0.6930472461935369}, {-0.6861696102342368, 1.0035621274868156}, 
     {-0.6661326681122279, 1.0837396094369784}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.8579346752018856, 0.6930472461935369}, {-0.864712395543231, \
0.6489952411032606}, {-0.7011419803004051, 0.9389137397717197}, 
     {-0.6861696102342368, 1.0035621274868156}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{-0.864712395543231, 0.6489952411032606}, {-0.868901257080424, \
0.6201700772082609}, {-0.7103954138934386, 0.8965062230902949}, 
     {-0.7011419803004051, 0.9389137397717197}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.868901257080424, 0.6201700772082609}, {-0.8703181864639015, \
0.6101049646137003}, {-0.7135254915624211, 0.8816778784387097}, 
     {-0.7103954138934386, 0.8965062230902949}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-0.8703181864639015, 0.6101049646137003}, {-0.8689012570804241, \
0.6201700772082606}, {-0.7103954138934387, 0.8965062230902945}, 
     {-0.7135254915624211, 0.8816778784387097}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{-0.8689012570804241, 0.6201700772082606}, {-0.8647123955432311, \
0.64899524110326}, {-0.7011419803004053, 0.938913739771719}, 
     {-0.7103954138934387, 0.8965062230902945}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{-0.8647123955432311, 0.64899524110326}, {-0.8579346752018857, \
0.6930472461935366}, {-0.686169610234237, 1.0035621274868152}, 
     {-0.7011419803004053, 0.938913739771719}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{-0.8579346752018857, 0.6930472461935366}, {-0.8488643149584153, \
0.7478557941640104}, {-0.6661326681122283, 1.0837396094369776}, 
     {-0.686169610234237, 1.0035621274868152}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{-0.8488643149584153, 0.7478557941640104}, {-0.8378977330798769, \
0.8090441125945322}, {-0.6419068644530266, 1.172928163005486}, 
     {-0.6661326681122283, 1.0837396094369776}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{-0.8378977330798769, 0.8090441125945322}, {-0.8255142218178609, \
0.8728320775698117}, {-0.6145509831248424, 1.2655525104241703}, 
     {-0.6419068644530266, 1.172928163005486}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{-0.8255142218178609, 0.8728320775698117}, {-0.8122550000371977, \
0.9361441841071265}, {-0.5852606074098001, 1.357128851259245}, 
     {-0.6145509831248424, 1.2655525104241703}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{-0.8122550000371977, 0.9361441841071265}, {-0.798699559354507, \
0.9965396214846538}, {-0.5553158672774636, 1.4441489417584874}, 
     {-0.5852606074098001, 1.357128851259245}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{-0.798699559354507, 0.9965396214846538}, {-0.7854403375738435, \
1.0520980143876293}, {-0.5260254915624211, 1.5239001577085332}, 
     {-0.5553158672774636, 1.4441489417584874}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{-0.7854403375738435, 1.0520980143876293}, {-0.7730568263118276, \
1.1013148858947206}, {-0.49866961023423706, 1.594300566883077}, 
     {-0.5260254915624211, 1.5239001577085332}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{-0.7730568263118276, 1.1013148858947206}, {-0.7620902444332892, \
1.1430205016052835}, {-0.4744438065750353, 1.6537682358032726}, 
     {-0.49866961023423706, 1.594300566883077}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{-0.7620902444332892, 1.1430205016052835}, {-0.7530198841898188, \
1.1763209525760518}, {-0.4544068644530264, 1.7011229525643672}, 
     {-0.4744438065750353, 1.6537682358032726}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{-0.7530198841898188, 1.1763209525760518}, {-0.7462421638484733, \
1.2005567894684717}, {-0.4394344943868581, 1.735513991245673}, 
     {-0.4544068644530264, 1.7011229525643672}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{-0.7462421638484733, 1.2005567894684717}, {-0.7420533023112803, \
1.2152748245287444}, {-0.4301810607938246, 1.7563683493937294}, 
     {-0.4394344943868581, 1.735513991245673}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{-0.7420533023112803, 1.2152748245287444}, {-0.7406363729278029, \
1.2202099292274005}, {-0.42705098312484224, 1.7633557568774194}, 
     {-0.4301810607938246, 1.7563683493937294}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{-0.42705098312484224, 1.7633557568774194}, {-0.4301810607938247, \
1.7563683493937294}, {-0.012814536647682145, 2.2208803408437956}, 
     {-0.007391819076574713, 2.2294344764321825}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{-0.4301810607938247, 1.7563683493937294}, {-0.43943449438685805, \
1.7355139912456732}, {-0.028845690582060914, 2.195318553032826}, 
     {-0.012814536647682145, 2.2208803408437956}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{-0.43943449438685805, 1.7355139912456732}, \
{-0.45440686445302647, 1.7011229525643672}, {-0.05478464252676769, \
2.1530633066599703}, 
     {-0.028845690582060914, 2.195318553032826}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{-0.45440686445302647, 1.7011229525643672}, {-0.4744438065750352, \
1.653768235803273}, {-0.08949773581291746, 2.0946793219544757}, 
     {-0.05478464252676769, 2.1530633066599703}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{-0.4744438065750352, 1.653768235803273}, {-0.49866961023423695, \
1.5943005668830774}, {-0.1314678416920028, 2.0210434859217035}, 
     {-0.08949773581291746, 2.0946793219544757}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{-0.49866961023423695, 1.5943005668830774}, {-0.5260254915624212, \
1.523900157708533}, {-0.17886066514219576, 1.933432094411191}, 
     {-0.1314678416920028, 2.0210434859217035}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{-0.5260254915624212, 1.523900157708533}, {-0.5553158672774633, \
1.444148941758488}, {-0.2296049123627243, 1.833636456582809}, 
     {-0.17886066514219576, 1.933432094411191}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{-0.5553158672774633, 1.444148941758488}, {-0.5852606074097999, \
1.3571288512592452}, {-0.28148281625213767, 1.7241122839361493}, 
     {-0.2296049123627243, 1.833636456582809}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{-0.5852606074097999, 1.3571288512592452}, {-0.6145509831248422, \
1.2655525104241707}, {-0.3322270634726663, 1.6081701375219566}, 
     {-0.28148281625213767, 1.7241122839361493}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{-0.6145509831248422, 1.2655525104241707}, {-0.6419068644530264, \
1.1729281630054869}, {-0.3796198869228592, 1.490209713504239}, 
     {-0.3322270634726663, 1.6081701375219566}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{-0.6419068644530264, 1.1729281630054869}, {-0.6661326681122282, \
1.0837396094369778}, {-0.4215899928019446, 1.3759750672106554}, 
     {-0.3796198869228592, 1.490209713504239}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{-0.6661326681122282, 1.0837396094369778}, {-0.686169610234237, \
1.0035621274868154}, {-0.45630308608809433, 1.2727298803122147}, 
     {-0.4215899928019446, 1.3759750672106554}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{-0.686169610234237, 1.0035621274868154}, {-0.7011419803004051, \
0.9389137397717197}, {-0.482242038032801, 1.189085281951672}, 
     {-0.45630308608809433, 1.2727298803122147}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{-0.7011419803004051, 0.9389137397717197}, {-0.7103954138934387, \
0.8965062230902947}, {-0.4982731919671799, 1.1340136417284856}, 
     {-0.482242038032801, 1.189085281951672}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{-0.7103954138934387, 0.8965062230902947}, {-0.7135254915624211, \
0.8816778784387097}, {-0.5036959095382874, 1.1147172382160913}, 
     {-0.4982731919671799, 1.1340136417284856}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{-0.7135254915624211, 0.8816778784387097}, {-0.7103954138934387, \
0.8965062230902947}, {-0.49827319196717995, 1.1340136417284856}, 
     {-0.5036959095382874, 1.1147172382160913}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{-0.7103954138934387, 0.8965062230902947}, {-0.7011419803004052, \
0.9389137397717193}, {-0.482242038032801, 1.1890852819516717}, 
     {-0.49827319196717995, 1.1340136417284856}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.7011419803004052, 0.9389137397717193}, {-0.686169610234237, \
1.0035621274868152}, {-0.4563030860880944, 1.2727298803122145}, 
     {-0.482242038032801, 1.1890852819516717}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.686169610234237, 1.0035621274868152}, {-0.6661326681122282, \
1.0837396094369778}, {-0.42158999280194476, 1.375975067210655}, 
     {-0.4563030860880944, 1.2727298803122145}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{-0.6661326681122282, 1.0837396094369778}, {-0.6419068644530265, \
1.1729281630054864}, {-0.3796198869228593, 1.4902097135042385}, 
     {-0.42158999280194476, 1.375975067210655}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.6419068644530265, 1.1729281630054864}, {-0.6145509831248422, \
1.2655525104241705}, {-0.3322270634726663, 1.6081701375219564}, 
     {-0.3796198869228593, 1.4902097135042385}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.6145509831248422, 1.2655525104241705}, {-0.5852606074098001, \
1.357128851259245}, {-0.2814828162521379, 1.724112283936149}, 
     {-0.3322270634726663, 1.6081701375219564}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{-0.5852606074098001, 1.357128851259245}, {-0.5553158672774634, \
1.4441489417584878}, {-0.22960491236272457, 1.8336364565828085}, 
     {-0.2814828162521379, 1.724112283936149}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.5553158672774634, 1.4441489417584878}, {-0.5260254915624212, \
1.523900157708533}, {-0.1788606651421958, 1.933432094411191}, 
     {-0.22960491236272457, 1.8336364565828085}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.5260254915624212, 1.523900157708533}, {-0.4986696102342371, \
1.594300566883077}, {-0.13146784169200298, 2.021043485921703}, 
     {-0.1788606651421958, 1.933432094411191}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{-0.4986696102342371, 1.594300566883077}, {-0.47444380657503515, \
1.653768235803273}, {-0.0894977358129174, 2.0946793219544757}, 
     {-0.13146784169200298, 2.021043485921703}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.47444380657503515, 1.653768235803273}, {-0.45440686445302647, \
1.7011229525643672}, {-0.05478464252676767, 2.1530633066599703}, 
     {-0.0894977358129174, 2.0946793219544757}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.45440686445302647, 1.7011229525643672}, {-0.4394344943868581, \
1.735513991245673}, {-0.02884569058206097, 2.1953185530328256}, 
     {-0.05478464252676767, 2.1530633066599703}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{-0.4394344943868581, 1.735513991245673}, {-0.4301810607938247, \
1.7563683493937294}, {-0.012814536647682125, 2.2208803408437956}, 
     {-0.02884569058206097, 2.1953185530328256}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.4301810607938247, 1.7563683493937294}, {-0.42705098312484224, \
1.7633557568774194}, {-0.007391819076574713, 2.2294344764321825}, 
     {-0.012814536647682125, 2.2208803408437956}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.42705098312484224, 1.7633557568774194}, \
{-0.43018106079382457, 1.7563683493937297}, {-0.012814536647682062, \
2.2208803408437956}, 
     {-0.007391819076574713, 2.2294344764321825}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{-0.43018106079382457, 1.7563683493937297}, {-0.4394344943868581, \
1.7355139912456732}, {-0.02884569058206095, 2.195318553032826}, 
     {-0.012814536647682062, 2.2208803408437956}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-0.4394344943868581, 1.7355139912456732}, {-0.45440686445302636, \
1.7011229525643672}, {-0.0547846425267676, 2.1530633066599703}, 
     {-0.02884569058206095, 2.195318553032826}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.45440686445302636, 1.7011229525643672}, \
{-0.47444380657503504, 1.6537682358032735}, {-0.08949773581291712, \
2.094679321954476}, 
     {-0.0547846425267676, 2.1530633066599703}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{-0.47444380657503504, 1.6537682358032735}, {-0.4986696102342368, \
1.5943005668830776}, {-0.13146784169200265, 2.0210434859217035}, 
     {-0.08949773581291712, 2.094679321954476}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.4986696102342368, 1.5943005668830776}, {-0.526025491562421, \
1.5239001577085334}, {-0.17886066514219567, 1.9334320944111911}, 
     {-0.13146784169200265, 2.0210434859217035}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-0.526025491562421, 1.5239001577085334}, {-0.5553158672774632, \
1.4441489417584885}, {-0.2296049123627241, 1.8336364565828094}, 
     {-0.17886066514219567, 1.9334320944111911}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{-0.5553158672774632, 1.4441489417584885}, {-0.5852606074097999, \
1.3571288512592454}, {-0.2814828162521375, 1.7241122839361496}, 
     {-0.2296049123627241, 1.8336364565828094}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{-0.5852606074097999, 1.3571288512592454}, {-0.6145509831248421, \
1.265552510424171}, {-0.33222706347266606, 1.6081701375219568}, 
     {-0.2814828162521375, 1.7241122839361496}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.6145509831248421, 1.265552510424171}, {-0.6419068644530262, \
1.1729281630054873}, {-0.379619886922859, 1.4902097135042394}, 
     {-0.33222706347266606, 1.6081701375219568}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{-0.6419068644530262, 1.1729281630054873}, {-0.6661326681122279, \
1.0837396094369784}, {-0.4215899928019444, 1.3759750672106559}, 
     {-0.379619886922859, 1.4902097135042394}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.6661326681122279, 1.0837396094369784}, {-0.6861696102342368, \
1.0035621274868156}, {-0.45630308608809433, 1.2727298803122147}, 
     {-0.4215899928019444, 1.3759750672106559}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.6861696102342368, 1.0035621274868156}, {-0.7011419803004051, \
0.9389137397717197}, {-0.4822420380328009, 1.1890852819516722}, 
     {-0.45630308608809433, 1.2727298803122147}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{-0.7011419803004051, 0.9389137397717197}, {-0.7103954138934386, \
0.8965062230902949}, {-0.4982731919671798, 1.1340136417284858}, 
     {-0.4822420380328009, 1.1890852819516722}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.7103954138934386, 0.8965062230902949}, {-0.7135254915624211, \
0.8816778784387097}, {-0.5036959095382874, 1.1147172382160913}, 
     {-0.4982731919671798, 1.1340136417284858}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-0.7135254915624211, 0.8816778784387097}, {-0.7103954138934387, \
0.8965062230902945}, {-0.49827319196717995, 1.1340136417284854}, 
     {-0.5036959095382874, 1.1147172382160913}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.775, 0.1], 
   Polygon[{{-0.7103954138934387, 0.8965062230902945}, {-0.7011419803004053, \
0.938913739771719}, {-0.48224203803280125, 1.1890852819516713}, 
     {-0.49827319196717995, 1.1340136417284854}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{-0.7011419803004053, 0.938913739771719}, {-0.686169610234237, \
1.0035621274868152}, {-0.4563030860880944, 1.2727298803122145}, 
     {-0.48224203803280125, 1.1890852819516713}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{-0.686169610234237, 1.0035621274868152}, {-0.6661326681122283, \
1.0837396094369776}, {-0.42158999280194487, 1.3759750672106545}, 
     {-0.4563030860880944, 1.2727298803122145}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{-0.6661326681122283, 1.0837396094369776}, {-0.6419068644530266, \
1.172928163005486}, {-0.3796198869228595, 1.490209713504238}, 
     {-0.42158999280194487, 1.3759750672106545}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{-0.6419068644530266, 1.172928163005486}, {-0.6145509831248424, \
1.2655525104241703}, {-0.3322270634726664, 1.6081701375219564}, 
     {-0.3796198869228595, 1.490209713504238}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{-0.6145509831248424, 1.2655525104241703}, {-0.5852606074098001, \
1.357128851259245}, {-0.28148281625213795, 1.7241122839361487}, 
     {-0.3322270634726664, 1.6081701375219564}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{-0.5852606074098001, 1.357128851259245}, {-0.5553158672774636, \
1.4441489417584874}, {-0.22960491236272482, 1.833636456582808}, 
     {-0.28148281625213795, 1.7241122839361487}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{-0.5553158672774636, 1.4441489417584874}, {-0.5260254915624211, \
1.5239001577085332}, {-0.17886066514219578, 1.933432094411191}, 
     {-0.22960491236272482, 1.833636456582808}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{-0.5260254915624211, 1.5239001577085332}, {-0.49866961023423706, \
1.594300566883077}, {-0.13146784169200307, 2.021043485921703}, 
     {-0.17886066514219578, 1.933432094411191}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{-0.49866961023423706, 1.594300566883077}, {-0.4744438065750353, \
1.6537682358032726}, {-0.0894977358129177, 2.0946793219544753}, 
     {-0.13146784169200307, 2.021043485921703}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{-0.4744438065750353, 1.6537682358032726}, {-0.4544068644530264, \
1.7011229525643672}, {-0.054784642526767645, 2.1530633066599703}, 
     {-0.0894977358129177, 2.0946793219544753}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{-0.4544068644530264, 1.7011229525643672}, {-0.4394344943868581, \
1.735513991245673}, {-0.02884569058206095, 2.1953185530328256}, 
     {-0.054784642526767645, 2.1530633066599703}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{-0.4394344943868581, 1.735513991245673}, {-0.4301810607938246, \
1.7563683493937294}, {-0.012814536647682086, 2.2208803408437956}, 
     {-0.02884569058206095, 2.1953185530328256}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{-0.4301810607938246, 1.7563683493937294}, {-0.42705098312484224, \
1.7633557568774194}, {-0.007391819076574713, 2.2294344764321825}, 
     {-0.012814536647682086, 2.2208803408437956}}]}, {CMYKColor[0.15, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{-0.007391819076574713, 2.2294344764321825}, \
{-0.012814536647682145, 2.2208803408437956}, {0.4918053502751766, \
2.588583579753018}, 
     {0.49999999999999967, 2.5980762113533156}}]}, {CMYKColor[0.15, 0.5, \
0.025, 0.1], 
   Polygon[{{-0.012814536647682145, 2.2208803408437956}, \
{-0.028845690582060914, 2.195318553032826}, {0.4675795466159753, \
2.5601613609103286}, 
     {0.4918053502751766, 2.588583579753018}}]}, {CMYKColor[0.15, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{-0.028845690582060914, 2.195318553032826}, \
{-0.05478464252676769, 2.1530633066599703}, {0.42838137289060485, \
2.512998012254406}, 
     {0.4675795466159753, 2.5601613609103286}}]}, {CMYKColor[0.15, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{-0.05478464252676769, 2.1530633066599703}, \
{-0.08949773581291746, 2.0946793219544757}, {0.3759239773845714, \
2.4474780907945557}, 
     {0.42838137289060485, 2.512998012254406}}]}, {CMYKColor[0.15, 0.5, \
0.075, 0.1], 
   Polygon[{{-0.08949773581291746, 2.0946793219544757}, {-0.1314678416920028, \
2.0210434859217035}, {0.31249999999999983, 2.364285039922217}, 
     {0.3759239773845714, 2.4474780907945557}}]}, {CMYKColor[0.15, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{-0.1314678416920028, 2.0210434859217035}, {-0.17886066514219576, \
1.933432094411191}, {0.24088137289060504, 2.2645409632922457}, 
     {0.31249999999999983, 2.364285039922217}}]}, {CMYKColor[0.15, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{-0.17886066514219576, 1.933432094411191}, {-0.2296049123627243, \
1.833636456582809}, {0.16419817372536988, 2.1499828315181597}, 
     {0.24088137289060504, 2.2645409632922457}}]}, {CMYKColor[0.15, 0.5, \
0.125, 0.1], 
   Polygon[{{-0.2296049123627243, 1.833636456582809}, {-0.28148281625213767, \
1.7241122839361493}, {0.08580182627462962, 2.0231783980979894}, 
     {0.16419817372536988, 2.1499828315181597}}]}, {CMYKColor[0.15, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{-0.28148281625213767, 1.7241122839361493}, {-0.3322270634726663, \
1.6081701375219566}, {0.009118627109394484, 1.8877889819588953}, 
     {0.08580182627462962, 2.0231783980979894}}]}, {CMYKColor[0.15, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{-0.3322270634726663, 1.6081701375219566}, {-0.3796198869228592, \
1.490209713504239}, {-0.06250000000000011, 1.7488835724541527}, 
     {0.009118627109394484, 1.8877889819588953}}]}, {CMYKColor[0.15, 0.5, \
0.175, 0.1], 
   Polygon[{{-0.3796198869228592, 1.490209713504239}, {-0.4215899928019446, \
1.3759750672106554}, {-0.125923977384572, 1.6132809148526015}, 
     {-0.06250000000000011, 1.7488835724541527}}]}, {CMYKColor[0.15, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{-0.4215899928019446, 1.3759750672106554}, {-0.45630308608809433, \
1.2727298803122147}, {-0.17838137289060557, 1.4898021598760776}, 
     {-0.125923977384572, 1.6132809148526015}}]}, {CMYKColor[0.15, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{-0.45630308608809433, 1.2727298803122147}, {-0.482242038032801, \
1.189085281951672}, {-0.21757954661597556, 1.389101261457407}, 
     {-0.17838137289060557, 1.4898021598760776}}]}, {CMYKColor[0.15, 0.5, \
0.225, 0.1], 
   Polygon[{{-0.482242038032801, 1.189085281951672}, {-0.4982731919671799, \
1.1340136417284856}, {-0.2418053502751773, 1.3224570770546993}, 
     {-0.21757954661597556, 1.389101261457407}}]}, {CMYKColor[0.15, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{-0.4982731919671799, 1.1340136417284856}, {-0.5036959095382874, \
1.1147172382160913}, {-0.2500000000000002, 1.299038105676658}, 
     {-0.2418053502751773, 1.3224570770546993}}]}, {CMYKColor[0.15, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{-0.5036959095382874, 1.1147172382160913}, {-0.49827319196717995, \
1.1340136417284856}, {-0.2418053502751773, 1.3224570770546993}, 
     {-0.2500000000000002, 1.299038105676658}}]}, {CMYKColor[0.15, 0.5, \
0.275, 0.1], 
   Polygon[{{-0.49827319196717995, 1.1340136417284856}, {-0.482242038032801, \
1.1890852819516717}, {-0.21757954661597556, 1.3891012614574068}, 
     {-0.2418053502751773, 1.3224570770546993}}]}, {CMYKColor[0.15, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{-0.482242038032801, 1.1890852819516717}, {-0.4563030860880944, \
1.2727298803122145}, {-0.17838137289060557, 1.4898021598760776}, 
     {-0.21757954661597556, 1.3891012614574068}}]}, {CMYKColor[0.15, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{-0.4563030860880944, 1.2727298803122145}, {-0.42158999280194476, \
1.375975067210655}, {-0.12592397738457223, 1.6132809148526013}, 
     {-0.17838137289060557, 1.4898021598760776}}]}, {CMYKColor[0.15, 0.5, \
0.325, 0.1], 
   Polygon[{{-0.42158999280194476, 1.375975067210655}, {-0.3796198869228593, \
1.4902097135042385}, {-0.06250000000000044, 1.7488835724541523}, 
     {-0.12592397738457223, 1.6132809148526013}}]}, {CMYKColor[0.15, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{-0.3796198869228593, 1.4902097135042385}, {-0.3322270634726663, \
1.6081701375219564}, {0.009118627109394317, 1.887788981958895}, 
     {-0.06250000000000044, 1.7488835724541523}}]}, {CMYKColor[0.15, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{-0.3322270634726663, 1.6081701375219564}, {-0.2814828162521379, \
1.724112283936149}, {0.08580182627462934, 2.023178398097989}, 
     {0.009118627109394317, 1.887788981958895}}]}, {CMYKColor[0.15, 0.5, \
0.375, 0.1], 
   Polygon[{{-0.2814828162521379, 1.724112283936149}, {-0.22960491236272457, \
1.8336364565828085}, {0.1641981737253695, 2.1499828315181593}, 
     {0.08580182627462934, 2.023178398097989}}]}, {CMYKColor[0.15, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{-0.22960491236272457, 1.8336364565828085}, {-0.1788606651421958, \
1.933432094411191}, {0.2408813728906049, 2.264540963292246}, 
     {0.1641981737253695, 2.1499828315181593}}]}, {CMYKColor[0.15, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{-0.1788606651421958, 1.933432094411191}, {-0.13146784169200298, \
2.021043485921703}, {0.31249999999999944, 2.3642850399222164}, 
     {0.2408813728906049, 2.264540963292246}}]}, {CMYKColor[0.15, 0.5, 0.425, \
0.1], 
   Polygon[{{-0.13146784169200298, 2.021043485921703}, {-0.0894977358129174, \
2.0946793219544757}, {0.3759239773845713, 2.447478090794556}, 
     {0.31249999999999944, 2.3642850399222164}}]}, {CMYKColor[0.15, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{-0.0894977358129174, 2.0946793219544757}, {-0.05478464252676767, \
2.1530633066599703}, {0.42838137289060485, 2.512998012254406}, 
     {0.3759239773845713, 2.447478090794556}}]}, {CMYKColor[0.15, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{-0.05478464252676767, 2.1530633066599703}, \
{-0.02884569058206097, 2.1953185530328256}, {0.46757954661597495, \
2.560161360910328}, 
     {0.42838137289060485, 2.512998012254406}}]}, {CMYKColor[0.15, 0.5, \
0.475, 0.1], 
   Polygon[{{-0.02884569058206097, 2.1953185530328256}, \
{-0.012814536647682125, 2.2208803408437956}, {0.49180535027517663, \
2.588583579753018}, 
     {0.46757954661597495, 2.560161360910328}}]}, {CMYKColor[0.15, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{-0.012814536647682125, 2.2208803408437956}, \
{-0.007391819076574713, 2.2294344764321825}, {0.49999999999999967, \
2.5980762113533156}, 
     {0.49180535027517663, 2.588583579753018}}]}, {CMYKColor[0.15, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{-0.007391819076574713, 2.2294344764321825}, \
{-0.012814536647682062, 2.2208803408437956}, {0.49180535027517697, \
2.588583579753018}, 
     {0.49999999999999967, 2.5980762113533156}}]}, {CMYKColor[0.15, 0.5, \
0.525, 0.1], 
   Polygon[{{-0.012814536647682062, 2.2208803408437956}, \
{-0.02884569058206095, 2.195318553032826}, {0.46757954661597523, \
2.5601613609103286}, 
     {0.49180535027517697, 2.588583579753018}}]}, {CMYKColor[0.15, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{-0.02884569058206095, 2.195318553032826}, {-0.0547846425267676, \
2.1530633066599703}, {0.428381372890605, 2.512998012254406}, 
     {0.46757954661597523, 2.5601613609103286}}]}, {CMYKColor[0.15, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{-0.0547846425267676, 2.1530633066599703}, {-0.08949773581291712, \
2.094679321954476}, {0.3759239773845719, 2.4474780907945566}, 
     {0.428381372890605, 2.512998012254406}}]}, {CMYKColor[0.15, 0.5, 0.575, \
0.1], 
   Polygon[{{-0.08949773581291712, 2.094679321954476}, {-0.13146784169200265, \
2.0210434859217035}, {0.31249999999999994, 2.3642850399222173}, 
     {0.3759239773845719, 2.4474780907945566}}]}, {CMYKColor[0.15, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{-0.13146784169200265, 2.0210434859217035}, \
{-0.17886066514219567, 1.9334320944111911}, {0.2408813728906052, \
2.264540963292246}, 
     {0.31249999999999994, 2.3642850399222173}}]}, {CMYKColor[0.15, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{-0.17886066514219567, 1.9334320944111911}, {-0.2296049123627241, \
1.8336364565828094}, {0.16419817372537018, 2.14998283151816}, 
     {0.2408813728906052, 2.264540963292246}}]}, {CMYKColor[0.15, 0.5, 0.625, \
0.1], 
   Polygon[{{-0.2296049123627241, 1.8336364565828094}, {-0.2814828162521375, \
1.7241122839361496}, {0.0858018262746299, 2.02317839809799}, 
     {0.16419817372537018, 2.14998283151816}}]}, {CMYKColor[0.15, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{-0.2814828162521375, 1.7241122839361496}, {-0.33222706347266606, \
1.6081701375219568}, {0.009118627109394595, 1.8877889819588956}, 
     {0.0858018262746299, 2.02317839809799}}]}, {CMYKColor[0.15, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{-0.33222706347266606, 1.6081701375219568}, {-0.379619886922859, \
1.4902097135042394}, {-0.062499999999999944, 1.7488835724541534}, 
     {0.009118627109394595, 1.8877889819588956}}]}, {CMYKColor[0.15, 0.5, \
0.675, 0.1], 
   Polygon[{{-0.379619886922859, 1.4902097135042394}, {-0.4215899928019444, \
1.3759750672106559}, {-0.12592397738457173, 1.6132809148526024}, 
     {-0.062499999999999944, 1.7488835724541534}}]}, {CMYKColor[0.15, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{-0.4215899928019444, 1.3759750672106559}, {-0.45630308608809433, \
1.2727298803122147}, {-0.17838137289060546, 1.4898021598760776}, 
     {-0.12592397738457173, 1.6132809148526024}}]}, {CMYKColor[0.15, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{-0.45630308608809433, 1.2727298803122147}, {-0.4822420380328009, \
1.1890852819516722}, {-0.21757954661597534, 1.3891012614574072}, 
     {-0.17838137289060546, 1.4898021598760776}}]}, {CMYKColor[0.15, 0.5, \
0.725, 0.1], 
   Polygon[{{-0.4822420380328009, 1.1890852819516722}, {-0.4982731919671798, \
1.1340136417284858}, {-0.2418053502751772, 1.3224570770546997}, 
     {-0.21757954661597534, 1.3891012614574072}}]}, {CMYKColor[0.15, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{-0.4982731919671798, 1.1340136417284858}, {-0.5036959095382874, \
1.1147172382160913}, {-0.2500000000000002, 1.299038105676658}, 
     {-0.2418053502751772, 1.3224570770546997}}]}, {CMYKColor[0.15, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{-0.5036959095382874, 1.1147172382160913}, {-0.49827319196717995, \
1.1340136417284854}, {-0.2418053502751774, 1.322457077054699}, 
     {-0.2500000000000002, 1.299038105676658}}]}, {CMYKColor[0.15, 0.5, \
0.775, 0.1], 
   Polygon[{{-0.49827319196717995, 1.1340136417284854}, \
{-0.48224203803280125, 1.1890852819516713}, {-0.21757954661597584, \
1.389101261457406}, 
     {-0.2418053502751774, 1.322457077054699}}]}, {CMYKColor[0.15, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{-0.48224203803280125, 1.1890852819516713}, {-0.4563030860880944, \
1.2727298803122145}, {-0.17838137289060568, 1.4898021598760773}, 
     {-0.21757954661597584, 1.389101261457406}}]}, {CMYKColor[0.15, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{-0.4563030860880944, 1.2727298803122145}, {-0.42158999280194487, \
1.3759750672106545}, {-0.12592397738457234, 1.6132809148526008}, 
     {-0.17838137289060568, 1.4898021598760773}}]}, {CMYKColor[0.15, 0.5, \
0.825, 0.1], 
   Polygon[{{-0.42158999280194487, 1.3759750672106545}, {-0.3796198869228595, \
1.490209713504238}, {-0.06250000000000078, 1.7488835724541516}, 
     {-0.12592397738457234, 1.6132809148526008}}]}, {CMYKColor[0.15, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{-0.3796198869228595, 1.490209713504238}, {-0.3322270634726664, \
1.6081701375219564}, {0.009118627109394317, 1.8877889819588949}, 
     {-0.06250000000000078, 1.7488835724541516}}]}, {CMYKColor[0.15, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{-0.3322270634726664, 1.6081701375219564}, {-0.28148281625213795, \
1.7241122839361487}, {0.08580182627462918, 2.0231783980979885}, 
     {0.009118627109394317, 1.8877889819588949}}]}, {CMYKColor[0.15, 0.5, \
0.875, 0.1], 
   Polygon[{{-0.28148281625213795, 1.7241122839361487}, \
{-0.22960491236272482, 1.833636456582808}, {0.1641981737253691, \
2.149982831518159}, 
     {0.08580182627462918, 2.0231783980979885}}]}, {CMYKColor[0.15, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{-0.22960491236272482, 1.833636456582808}, {-0.17886066514219578, \
1.933432094411191}, {0.24088137289060496, 2.264540963292246}, 
     {0.1641981737253691, 2.149982831518159}}]}, {CMYKColor[0.15, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{-0.17886066514219578, 1.933432094411191}, {-0.13146784169200307, \
2.021043485921703}, {0.31249999999999944, 2.3642850399222164}, 
     {0.24088137289060496, 2.264540963292246}}]}, {CMYKColor[0.15, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{-0.13146784169200307, 2.021043485921703}, {-0.0894977358129177, \
2.0946793219544753}, {0.375923977384571, 2.4474780907945557}, 
     {0.31249999999999944, 2.3642850399222164}}]}, {CMYKColor[0.15, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{-0.0894977358129177, 2.0946793219544753}, \
{-0.054784642526767645, 2.1530633066599703}, {0.4283813728906049, \
2.512998012254406}, 
     {0.375923977384571, 2.4474780907945557}}]}, {CMYKColor[0.15, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{-0.054784642526767645, 2.1530633066599703}, \
{-0.02884569058206095, 2.1953185530328256}, {0.46757954661597495, \
2.560161360910328}, 
     {0.4283813728906049, 2.512998012254406}}]}, {CMYKColor[0.15, 0.5, 0.975, \
0.1], 
   Polygon[{{-0.02884569058206095, 2.1953185530328256}, \
{-0.012814536647682086, 2.2208803408437956}, {0.4918053502751767, \
2.588583579753018}, 
     {0.46757954661597495, 2.560161360910328}}]}, {CMYKColor[0.15, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{-0.012814536647682086, 2.2208803408437956}, \
{-0.007391819076574713, 2.2294344764321825}, {0.49999999999999967, \
2.5980762113533156}, 
     {0.4918053502751767, 2.588583579753018}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.49999999999999967, 2.5980762113533156}, {0.4918053502751766, \
2.588583579753018}, {1.0616242894813523, 2.8434972909653364}, 
     {1.0729490168751576, 2.8531695488854605}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.025, 0.1], 
   Polygon[{{0.4918053502751766, 2.588583579753018}, {0.4675795466159753, \
2.5601613609103286}, {1.0281450522291173, 2.8144424077524013}, 
     {1.0616242894813523, 2.8434972909653364}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.4675795466159753, 2.5601613609103286}, {0.42838137289060485, \
2.512998012254406}, {0.9739745084375786, 2.7659262761959793}, 
     {1.0281450522291173, 2.8144424077524013}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.42838137289060485, 2.512998012254406}, {0.3759239773845714, \
2.4474780907945557}, {0.9014801708095362, 2.697933958917173}, 
     {0.9739745084375786, 2.7659262761959793}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.075, 0.1], 
   Polygon[{{0.3759239773845714, 2.4474780907945557}, {0.31249999999999983, \
2.364285039922217}, {0.813830389765763, 2.6106791787633683}, 
     {0.9014801708095362, 2.697933958917173}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.31249999999999983, 2.364285039922217}, {0.24088137289060504, \
2.2645409632922457}, {0.714855881328184, 2.504820390287959}, 
     {0.813830389765763, 2.6106791787633683}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.24088137289060504, 2.2645409632922457}, {0.16419817372536988, \
2.1499828315181597}, {0.6088823064479068, 2.381720267244781}, 
     {0.714855881328184, 2.504820390287959}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.125, 0.1], 
   Polygon[{{0.16419817372536988, 2.1499828315181597}, {0.08580182627462962, \
2.0231783980979894}, {0.5005412188648298, 2.2437468595288657}, 
     {0.6088823064479068, 2.381720267244781}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.08580182627462962, 2.0231783980979894}, {0.009118627109394484, \
1.8877889819588953}, {0.39456764398455235, 2.0946223601372336}, 
     {0.5005412188648298, 2.2437468595288657}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.009118627109394484, 1.8877889819588953}, \
{-0.06250000000000011, 1.7488835724541527}, {0.2955931355469736, \
1.9398272078772507}, 
     {0.39456764398455235, 2.0946223601372336}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.175, 0.1], 
   Polygon[{{-0.06250000000000011, 1.7488835724541527}, {-0.125923977384572, \
1.6132809148526015}, {0.20794335450320006, 1.7870411277345812}, 
     {0.2955931355469736, 1.9398272078772507}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{-0.125923977384572, 1.6132809148526015}, {-0.17838137289060557, \
1.4898021598760776}, {0.13544901687515765, 1.6464961680271788}, 
     {0.20794335450320006, 1.7870411277345812}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{-0.17838137289060557, 1.4898021598760776}, \
{-0.21757954661597556, 1.389101261457407}, {0.08127847308361946, \
1.5308481540548229}, 
     {0.13544901687515765, 1.6464961680271788}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.225, 0.1], 
   Polygon[{{-0.21757954661597556, 1.389101261457407}, {-0.2418053502751773, \
1.3224570770546993}, {0.047799235831384124, 1.4537753723488893}, 
     {0.08127847308361946, 1.5308481540548229}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{-0.2418053502751773, 1.3224570770546993}, {-0.2500000000000002, \
1.299038105676658}, {0.03647450843757882, 1.4265847744427302}, 
     {0.047799235831384124, 1.4537753723488893}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{-0.2500000000000002, 1.299038105676658}, {-0.2418053502751773, \
1.3224570770546993}, {0.047799235831384124, 1.453775372348889}, 
     {0.03647450843757882, 1.4265847744427302}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.275, 0.1], 
   Polygon[{{-0.2418053502751773, 1.3224570770546993}, {-0.21757954661597556, \
1.3891012614574068}, {0.08127847308361935, 1.5308481540548224}, 
     {0.047799235831384124, 1.453775372348889}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.21757954661597556, 1.3891012614574068}, \
{-0.17838137289060557, 1.4898021598760776}, {0.13544901687515776, \
1.6464961680271788}, 
     {0.08127847308361935, 1.5308481540548224}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.17838137289060557, 1.4898021598760776}, \
{-0.12592397738457223, 1.6132809148526013}, {0.20794335450319978, \
1.7870411277345808}, 
     {0.13544901687515776, 1.6464961680271788}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.325, 0.1], 
   Polygon[{{-0.12592397738457223, 1.6132809148526013}, \
{-0.06250000000000044, 1.7488835724541523}, {0.29559313554697325, \
1.9398272078772505}, 
     {0.20794335450319978, 1.7870411277345808}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.06250000000000044, 1.7488835724541523}, \
{0.009118627109394317, 1.887788981958895}, {0.39456764398455224, \
2.094622360137233}, 
     {0.29559313554697325, 1.9398272078772505}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0.009118627109394317, 1.887788981958895}, {0.08580182627462934, \
2.023178398097989}, {0.5005412188648295, 2.243746859528865}, 
     {0.39456764398455224, 2.094622360137233}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.375, 0.1], 
   Polygon[{{0.08580182627462934, 2.023178398097989}, {0.1641981737253695, \
2.1499828315181593}, {0.6088823064479062, 2.3817202672447806}, 
     {0.5005412188648295, 2.243746859528865}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{0.1641981737253695, 2.1499828315181593}, {0.2408813728906049, \
2.264540963292246}, {0.7148558813281839, 2.504820390287959}, 
     {0.6088823064479062, 2.3817202672447806}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{0.2408813728906049, 2.264540963292246}, {0.31249999999999944, \
2.3642850399222164}, {0.8138303897657626, 2.610679178763368}, 
     {0.7148558813281839, 2.504820390287959}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.425, 0.1], 
   Polygon[{{0.31249999999999944, 2.3642850399222164}, {0.3759239773845713, \
2.447478090794556}, {0.9014801708095362, 2.697933958917173}, 
     {0.8138303897657626, 2.610679178763368}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{0.3759239773845713, 2.447478090794556}, {0.42838137289060485, \
2.512998012254406}, {0.9739745084375787, 2.765926276195979}, 
     {0.9014801708095362, 2.697933958917173}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{0.42838137289060485, 2.512998012254406}, {0.46757954661597495, \
2.560161360910328}, {1.0281450522291171, 2.8144424077524013}, 
     {0.9739745084375787, 2.765926276195979}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.475, 0.1], 
   Polygon[{{0.46757954661597495, 2.560161360910328}, {0.49180535027517663, \
2.588583579753018}, {1.0616242894813523, 2.8434972909653364}, 
     {1.0281450522291171, 2.8144424077524013}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{0.49180535027517663, 2.588583579753018}, {0.49999999999999967, \
2.5980762113533156}, {1.0729490168751576, 2.8531695488854605}, 
     {1.0616242894813523, 2.8434972909653364}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{0.49999999999999967, 2.5980762113533156}, {0.49180535027517697, \
2.588583579753018}, {1.0616242894813526, 2.843497290965337}, 
     {1.0729490168751576, 2.8531695488854605}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.525, 0.1], 
   Polygon[{{0.49180535027517697, 2.588583579753018}, {0.46757954661597523, \
2.5601613609103286}, {1.0281450522291173, 2.8144424077524013}, 
     {1.0616242894813526, 2.843497290965337}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{0.46757954661597523, 2.5601613609103286}, {0.428381372890605, \
2.512998012254406}, {0.973974508437579, 2.7659262761959793}, 
     {1.0281450522291173, 2.8144424077524013}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{0.428381372890605, 2.512998012254406}, {0.3759239773845719, \
2.4474780907945566}, {0.901480170809537, 2.6979339589171736}, 
     {0.973974508437579, 2.7659262761959793}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.575, 0.1], 
   Polygon[{{0.3759239773845719, 2.4474780907945566}, {0.31249999999999994, \
2.3642850399222173}, {0.8138303897657633, 2.6106791787633687}, 
     {0.901480170809537, 2.6979339589171736}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{0.31249999999999994, 2.3642850399222173}, {0.2408813728906052, \
2.264540963292246}, {0.7148558813281845, 2.504820390287959}, 
     {0.8138303897657633, 2.6106791787633687}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{0.2408813728906052, 2.264540963292246}, {0.16419817372537018, \
2.14998283151816}, {0.6088823064479071, 2.3817202672447815}, 
     {0.7148558813281845, 2.504820390287959}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.625, 0.1], 
   Polygon[{{0.16419817372537018, 2.14998283151816}, {0.0858018262746299, \
2.02317839809799}, {0.5005412188648302, 2.243746859528866}, 
     {0.6088823064479071, 2.3817202672447815}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0.0858018262746299, 2.02317839809799}, {0.009118627109394595, \
1.8877889819588956}, {0.3945676439845526, 2.0946223601372336}, 
     {0.5005412188648302, 2.243746859528866}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0.009118627109394595, 1.8877889819588956}, \
{-0.062499999999999944, 1.7488835724541534}, {0.295593135546974, \
1.9398272078772514}, 
     {0.3945676439845526, 2.0946223601372336}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.675, 0.1], 
   Polygon[{{-0.062499999999999944, 1.7488835724541534}, \
{-0.12592397738457173, 1.6132809148526024}, {0.20794335450320034, \
1.7870411277345821}, 
     {0.295593135546974, 1.9398272078772514}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.12592397738457173, 1.6132809148526024}, \
{-0.17838137289060546, 1.4898021598760776}, {0.13544901687515776, \
1.646496168027179}, 
     {0.20794335450320034, 1.7870411277345821}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.17838137289060546, 1.4898021598760776}, \
{-0.21757954661597534, 1.3891012614574072}, {0.08127847308361968, \
1.530848154054823}, 
     {0.13544901687515776, 1.646496168027179}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.725, 0.1], 
   Polygon[{{-0.21757954661597534, 1.3891012614574072}, {-0.2418053502751772, \
1.3224570770546997}, {0.047799235831384346, 1.4537753723488895}, 
     {0.08127847308361968, 1.530848154054823}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.2418053502751772, 1.3224570770546997}, {-0.2500000000000002, \
1.299038105676658}, {0.03647450843757882, 1.4265847744427302}, 
     {0.047799235831384346, 1.4537753723488895}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-0.2500000000000002, 1.299038105676658}, {-0.2418053502751774, \
1.322457077054699}, {0.04779923583138401, 1.4537753723488889}, 
     {0.03647450843757882, 1.4265847744427302}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.775, 0.1], 
   Polygon[{{-0.2418053502751774, 1.322457077054699}, {-0.21757954661597584, \
1.389101261457406}, {0.08127847308361902, 1.530848154054822}, 
     {0.04779923583138401, 1.4537753723488889}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{-0.21757954661597584, 1.389101261457406}, {-0.17838137289060568, \
1.4898021598760773}, {0.1354490168751576, 1.6464961680271786}, 
     {0.08127847308361902, 1.530848154054822}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{-0.17838137289060568, 1.4898021598760773}, \
{-0.12592397738457234, 1.6132809148526008}, {0.20794335450319956, \
1.7870411277345803}, 
     {0.1354490168751576, 1.6464961680271786}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.825, 0.1], 
   Polygon[{{-0.12592397738457234, 1.6132809148526008}, \
{-0.06250000000000078, 1.7488835724541516}, {0.2955931355469728, \
1.9398272078772496}, 
     {0.20794335450319956, 1.7870411277345803}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{-0.06250000000000078, 1.7488835724541516}, \
{0.009118627109394317, 1.8877889819588949}, {0.39456764398455213, \
2.0946223601372327}, 
     {0.2955931355469728, 1.9398272078772496}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.009118627109394317, 1.8877889819588949}, {0.08580182627462918, \
2.0231783980979885}, {0.5005412188648293, 2.2437468595288648}, 
     {0.39456764398455213, 2.0946223601372327}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.875, 0.1], 
   Polygon[{{0.08580182627462918, 2.0231783980979885}, {0.1641981737253691, \
2.149982831518159}, {0.6088823064479056, 2.38172026724478}, 
     {0.5005412188648293, 2.2437468595288648}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.1641981737253691, 2.149982831518159}, {0.24088137289060496, \
2.264540963292246}, {0.714855881328184, 2.504820390287959}, 
     {0.6088823064479056, 2.38172026724478}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.24088137289060496, 2.264540963292246}, {0.31249999999999944, \
2.3642850399222164}, {0.8138303897657625, 2.610679178763368}, 
     {0.714855881328184, 2.504820390287959}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.31249999999999944, 2.3642850399222164}, {0.375923977384571, \
2.4474780907945557}, {0.9014801708095358, 2.6979339589171727}, 
     {0.8138303897657625, 2.610679178763368}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.375923977384571, 2.4474780907945557}, {0.4283813728906049, \
2.512998012254406}, {0.9739745084375787, 2.765926276195979}, 
     {0.9014801708095358, 2.6979339589171727}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.4283813728906049, 2.512998012254406}, {0.46757954661597495, \
2.560161360910328}, {1.0281450522291171, 2.8144424077524013}, 
     {0.9739745084375787, 2.765926276195979}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.975, 0.1], 
   Polygon[{{0.46757954661597495, 2.560161360910328}, {0.4918053502751767, \
2.588583579753018}, {1.0616242894813523, 2.8434972909653364}, 
     {1.0281450522291171, 2.8144424077524013}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.4918053502751767, 2.588583579753018}, {0.49999999999999967, \
2.5980762113533156}, {1.0729490168751576, 2.8531695488854605}, 
     {1.0616242894813523, 2.8434972909653364}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{1.0729490168751576, 2.8531695488854605}, {1.0616242894813523, \
2.8434972909653364}, {1.6717384590328979, 2.9745950829027943}, 
     {1.6864146101970388, 2.98356568610482}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{1.0616242894813523, 2.8434972909653364}, {1.0281450522291173, \
2.8144424077524013}, {1.6283514237703351, 2.9474883844565616}, 
     {1.6717384590328979, 2.9745950829027943}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{1.0281450522291173, 2.8144424077524013}, {0.9739745084375786, \
2.7659262761959793}, {1.5581497260444177, 2.9017190909782276}, 
     {1.6283514237703351, 2.9474883844565616}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.9739745084375786, 2.7659262761959793}, {0.9014801708095362, \
2.697933958917173}, {1.4642015169108888, 2.836596676593442}, 
     {1.5581497260444177, 2.9017190909782276}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{0.9014801708095362, 2.697933958917173}, {0.813830389765763, \
2.6106791787633683}, {1.3506127839224091, 2.751525170659194}, 
     {1.4642015169108888, 2.836596676593442}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.813830389765763, 2.6106791787633683}, {0.714855881328184, \
2.504820390287959}, {1.2223478997697876, 2.646328981764321}, 
     {1.3506127839224091, 2.751525170659194}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.714855881328184, 2.504820390287959}, {0.6088823064479068, \
2.381720267244781}, {1.0850126553736965, 2.5216249314090464}, 
     {1.2223478997697876, 2.646328981764321}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{0.6088823064479068, 2.381720267244781}, {0.5005412188648298, \
2.2437468595288657}, {0.9446092599218617, 2.3792297776658287}, 
     {1.0850126553736965, 2.5216249314090464}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.5005412188648298, 2.2437468595288657}, {0.39456764398455235, \
2.0946223601372336}, {0.8072740155257703, 2.222607239695348}, 
     {0.9446092599218617, 2.3792297776658287}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.39456764398455235, 2.0946223601372336}, {0.2955931355469736, \
1.9398272078772507}, {0.6790091313731493, 2.0573688751735335}, 
     {0.8072740155257703, 2.222607239695348}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{0.2955931355469736, 1.9398272078772507}, {0.20794335450320006, \
1.7870411277345812}, {0.5654203983846692, 1.8918241808350187}, 
     {0.6790091313731493, 2.0573688751735335}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.20794335450320006, 1.7870411277345812}, {0.13544901687515765, \
1.6464961680271788}, {0.47147218925114043, 1.7374623647519978}, 
     {0.5654203983846692, 1.8918241808350187}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.13544901687515765, 1.6464961680271788}, {0.08127847308361946, \
1.5308481540548229}, {0.40127049152522337, 1.6089224974238359}, 
     {0.47147218925114043, 1.7374623647519978}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{0.08127847308361946, 1.5308481540548229}, {0.047799235831384124, \
1.4537753723488893}, {0.35788345626266027, 1.5224519023538965}, 
     {0.40127049152522337, 1.6089224974238359}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.047799235831384124, 1.4537753723488893}, {0.03647450843757882, \
1.4265847744427302}, {0.3432073050985194, 1.49178284305241}, 
     {0.35788345626266027, 1.5224519023538965}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.03647450843757882, 1.4265847744427302}, {0.047799235831384124, \
1.453775372348889}, {0.35788345626266027, 1.5224519023538965}, 
     {0.3432073050985194, 1.49178284305241}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{0.047799235831384124, 1.453775372348889}, {0.08127847308361935, \
1.5308481540548224}, {0.40127049152522326, 1.6089224974238354}, 
     {0.35788345626266027, 1.5224519023538965}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0.08127847308361935, 1.5308481540548224}, {0.13544901687515776, \
1.6464961680271788}, {0.4714721892511405, 1.7374623647519976}, 
     {0.40127049152522326, 1.6089224974238354}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0.13544901687515776, 1.6464961680271788}, {0.20794335450319978, \
1.7870411277345808}, {0.5654203983846688, 1.8918241808350182}, 
     {0.4714721892511405, 1.7374623647519976}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{0.20794335450319978, 1.7870411277345808}, {0.29559313554697325, \
1.9398272078772505}, {0.6790091313731489, 2.0573688751735326}, 
     {0.5654203983846688, 1.8918241808350182}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{0.29559313554697325, 1.9398272078772505}, {0.39456764398455224, \
2.094622360137233}, {0.80727401552577, 2.2226072396953476}, 
     {0.6790091313731489, 2.0573688751735326}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0.39456764398455224, 2.094622360137233}, {0.5005412188648295, \
2.243746859528865}, {0.9446092599218614, 2.379229777665828}, 
     {0.80727401552577, 2.2226072396953476}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{0.5005412188648295, 2.243746859528865}, {0.6088823064479062, \
2.3817202672447806}, {1.0850126553736956, 2.521624931409046}, 
     {0.9446092599218614, 2.379229777665828}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{0.6088823064479062, 2.3817202672447806}, {0.7148558813281839, \
2.504820390287959}, {1.2223478997697876, 2.646328981764321}, 
     {1.0850126553736956, 2.521624931409046}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{0.7148558813281839, 2.504820390287959}, {0.8138303897657626, \
2.610679178763368}, {1.3506127839224085, 2.7515251706591934}, 
     {1.2223478997697876, 2.646328981764321}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{0.8138303897657626, 2.610679178763368}, {0.9014801708095362, \
2.697933958917173}, {1.4642015169108888, 2.836596676593442}, 
     {1.3506127839224085, 2.7515251706591934}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{0.9014801708095362, 2.697933958917173}, {0.9739745084375787, \
2.765926276195979}, {1.5581497260444177, 2.9017190909782276}, 
     {1.4642015169108888, 2.836596676593442}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{0.9739745084375787, 2.765926276195979}, {1.0281450522291171, \
2.8144424077524013}, {1.628351423770335, 2.9474883844565616}, 
     {1.5581497260444177, 2.9017190909782276}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{1.0281450522291171, 2.8144424077524013}, {1.0616242894813523, \
2.8434972909653364}, {1.6717384590328979, 2.9745950829027943}, 
     {1.628351423770335, 2.9474883844565616}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{1.0616242894813523, 2.8434972909653364}, {1.0729490168751576, \
2.8531695488854605}, {1.6864146101970388, 2.98356568610482}, 
     {1.6717384590328979, 2.9745950829027943}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{1.0729490168751576, 2.8531695488854605}, {1.0616242894813526, \
2.843497290965337}, {1.6717384590328983, 2.974595082902794}, 
     {1.6864146101970388, 2.98356568610482}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{1.0616242894813526, 2.843497290965337}, {1.0281450522291173, \
2.8144424077524013}, {1.6283514237703351, 2.947488384456561}, 
     {1.6717384590328983, 2.974595082902794}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{1.0281450522291173, 2.8144424077524013}, {0.973974508437579, \
2.7659262761959793}, {1.558149726044418, 2.9017190909782276}, 
     {1.6283514237703351, 2.947488384456561}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{0.973974508437579, 2.7659262761959793}, {0.901480170809537, \
2.6979339589171736}, {1.4642015169108895, 2.836596676593442}, 
     {1.558149726044418, 2.9017190909782276}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{0.901480170809537, 2.6979339589171736}, {0.8138303897657633, \
2.6106791787633687}, {1.3506127839224094, 2.751525170659194}, 
     {1.4642015169108895, 2.836596676593442}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{0.8138303897657633, 2.6106791787633687}, {0.7148558813281845, \
2.504820390287959}, {1.2223478997697883, 2.646328981764321}, 
     {1.3506127839224094, 2.751525170659194}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{0.7148558813281845, 2.504820390287959}, {0.6088823064479071, \
2.3817202672447815}, {1.085012655373697, 2.521624931409047}, 
     {1.2223478997697883, 2.646328981764321}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{0.6088823064479071, 2.3817202672447815}, {0.5005412188648302, \
2.243746859528866}, {0.9446092599218623, 2.379229777665829}, 
     {1.085012655373697, 2.521624931409047}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0.5005412188648302, 2.243746859528866}, {0.3945676439845526, \
2.0946223601372336}, {0.8072740155257706, 2.222607239695348}, 
     {0.9446092599218623, 2.379229777665829}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0.3945676439845526, 2.0946223601372336}, {0.295593135546974, \
1.9398272078772514}, {0.6790091313731498, 2.057368875173534}, 
     {0.8072740155257706, 2.222607239695348}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{0.295593135546974, 1.9398272078772514}, {0.20794335450320034, \
1.7870411277345821}, {0.5654203983846697, 1.8918241808350196}, 
     {0.6790091313731498, 2.057368875173534}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0.20794335450320034, 1.7870411277345821}, {0.13544901687515776, \
1.646496168027179}, {0.4714721892511406, 1.7374623647519978}, 
     {0.5654203983846697, 1.8918241808350196}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0.13544901687515776, 1.646496168027179}, {0.08127847308361968, \
1.530848154054823}, {0.40127049152522365, 1.608922497423836}, 
     {0.4714721892511406, 1.7374623647519978}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{0.08127847308361968, 1.530848154054823}, {0.047799235831384346, \
1.4537753723488895}, {0.3578834562626605, 1.5224519023538967}, 
     {0.40127049152522365, 1.608922497423836}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.047799235831384346, 1.4537753723488895}, {0.03647450843757882, \
1.4265847744427302}, {0.3432073050985194, 1.49178284305241}, 
     {0.3578834562626605, 1.5224519023538967}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.03647450843757882, 1.4265847744427302}, {0.04779923583138401, \
1.4537753723488889}, {0.35788345626266016, 1.5224519023538963}, 
     {0.3432073050985194, 1.49178284305241}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.775, 0.1], 
   Polygon[{{0.04779923583138401, 1.4537753723488889}, {0.08127847308361902, \
1.530848154054822}, {0.40127049152522287, 1.608922497423835}, 
     {0.35788345626266016, 1.5224519023538963}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.08127847308361902, 1.530848154054822}, {0.1354490168751576, \
1.6464961680271786}, {0.4714721892511403, 1.7374623647519973}, 
     {0.40127049152522287, 1.608922497423835}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.1354490168751576, 1.6464961680271786}, {0.20794335450319956, \
1.7870411277345803}, {0.5654203983846685, 1.8918241808350178}, 
     {0.4714721892511403, 1.7374623647519973}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{0.20794335450319956, 1.7870411277345803}, {0.2955931355469728, \
1.9398272078772496}, {0.6790091313731483, 2.057368875173532}, 
     {0.5654203983846685, 1.8918241808350178}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.2955931355469728, 1.9398272078772496}, {0.39456764398455213, \
2.0946223601372327}, {0.80727401552577, 2.2226072396953476}, 
     {0.6790091313731483, 2.057368875173532}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.39456764398455213, 2.0946223601372327}, {0.5005412188648293, \
2.2437468595288648}, {0.944609259921861, 2.379229777665828}, 
     {0.80727401552577, 2.2226072396953476}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{0.5005412188648293, 2.2437468595288648}, {0.6088823064479056, \
2.38172026724478}, {1.085012655373695, 2.521624931409045}, 
     {0.944609259921861, 2.379229777665828}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.6088823064479056, 2.38172026724478}, {0.714855881328184, \
2.504820390287959}, {1.2223478997697876, 2.646328981764321}, 
     {1.085012655373695, 2.521624931409045}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.714855881328184, 2.504820390287959}, {0.8138303897657625, \
2.610679178763368}, {1.3506127839224085, 2.7515251706591934}, 
     {1.2223478997697876, 2.646328981764321}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.8138303897657625, 2.610679178763368}, {0.9014801708095358, \
2.6979339589171727}, {1.4642015169108882, 2.836596676593441}, 
     {1.3506127839224085, 2.7515251706591934}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.9014801708095358, 2.6979339589171727}, {0.9739745084375787, \
2.765926276195979}, {1.5581497260444177, 2.901719090978228}, 
     {1.4642015169108882, 2.836596676593441}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.9739745084375787, 2.765926276195979}, {1.0281450522291171, \
2.8144424077524013}, {1.628351423770335, 2.9474883844565616}, 
     {1.5581497260444177, 2.901719090978228}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{1.0281450522291171, 2.8144424077524013}, {1.0616242894813523, \
2.8434972909653364}, {1.671738459032898, 2.9745950829027943}, 
     {1.628351423770335, 2.9474883844565616}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{1.0616242894813523, 2.8434972909653364}, {1.0729490168751576, \
2.8531695488854605}, {1.6864146101970388, 2.98356568610482}, 
     {1.671738459032898, 2.9745950829027943}}]}, {CMYKColor[0.25, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{1.6864146101970388, 2.98356568610482}, {1.6717384590328979, \
2.9745950829027943}, {2.2954829420678085, 2.9763034938899464}, 
     {2.3135853898029595, 2.98356568610482}}]}, {CMYKColor[0.25, 0.5, 0.025, \
0.1], 
   Polygon[{{1.6717384590328979, 2.9745950829027943}, {1.6283514237703351, \
2.9474883844565616}, {2.241966762693565, 2.9540812792513704}, 
     {2.2954829420678085, 2.9763034938899464}}]}, {CMYKColor[0.25, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{1.6283514237703351, 2.9474883844565616}, {1.5581497260444177, \
2.9017190909782276}, {2.1553757655180017, 2.9156867970745455}, 
     {2.241966762693565, 2.9540812792513704}}]}, {CMYKColor[0.25, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{1.5581497260444177, 2.9017190909782276}, {1.4642015169108888, \
2.836596676593442}, {2.039494392627396, 2.859399797409293}, 
     {2.1553757655180017, 2.9156867970745455}}]}, {CMYKColor[0.25, 0.5, \
0.075, 0.1], 
   Polygon[{{1.4642015169108888, 2.836596676593442}, {1.3506127839224091, \
2.751525170659194}, {1.8993872160775895, 2.7833940695732022}, 
     {2.039494392627396, 2.859399797409293}}]}, {CMYKColor[0.25, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{1.3506127839224091, 2.751525170659194}, {1.2223478997697876, \
2.646328981764321}, {1.7411775917926318, 2.686221801523239}, 
     {1.8993872160775895, 2.7833940695732022}}]}, {CMYKColor[0.25, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{1.2223478997697876, 2.646328981764321}, {1.0850126553736965, \
2.5216249314090464}, {1.5717800395277828, 2.567335508777075}, 
     {1.7411775917926318, 2.686221801523239}}]}, {CMYKColor[0.25, 0.5, 0.125, \
0.1], 
   Polygon[{{1.0850126553736965, 2.5216249314090464}, {0.9446092599218617, \
2.3792297776658287}, {1.3985980451766564, 2.427623046285348}, 
     {1.5717800395277828, 2.567335508777075}}]}, {CMYKColor[0.25, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{0.9446092599218617, 2.3792297776658287}, {0.8072740155257703, \
2.222607239695348}, {1.2292004929118074, 2.2699589047379565}, 
     {1.3985980451766564, 2.427623046285348}}]}, {CMYKColor[0.25, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{0.8072740155257703, 2.222607239695348}, {0.6790091313731493, \
2.0573688751735335}, {1.07099086862685, 2.099799626225554}, 
     {1.2292004929118074, 2.2699589047379565}}]}, {CMYKColor[0.25, 0.5, \
0.175, 0.1], 
   Polygon[{{0.6790091313731493, 2.0573688751735335}, {0.5654203983846692, \
1.8918241808350187}, {0.9308836920770429, 1.9258466260207312}, 
     {1.07099086862685, 2.099799626225554}}]}, {CMYKColor[0.25, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{0.5654203983846692, 1.8918241808350187}, {0.47147218925114043, \
1.7374623647519978}, {0.8150023191864373, 1.760690570377689}, 
     {0.9308836920770429, 1.9258466260207312}}]}, {CMYKColor[0.25, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{0.47147218925114043, 1.7374623647519978}, {0.40127049152522337, \
1.6089224974238359}, {0.7284113220108746, 1.6209688555409116}, 
     {0.8150023191864373, 1.760690570377689}}]}, {CMYKColor[0.25, 0.5, 0.225, \
0.1], 
   Polygon[{{0.40127049152522337, 1.6089224974238359}, {0.35788345626266027, \
1.5224519023538965}, {0.6748951426366303, 1.525787133086728}, 
     {0.7284113220108746, 1.6209688555409116}}]}, {CMYKColor[0.25, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{0.35788345626266027, 1.5224519023538965}, {0.3432073050985194, \
1.49178284305241}, {0.6567926949014797, 1.4917828430524098}, 
     {0.6748951426366303, 1.525787133086728}}]}, {CMYKColor[0.25, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{0.3432073050985194, 1.49178284305241}, {0.35788345626266027, \
1.5224519023538965}, {0.6748951426366303, 1.5257871330867279}, 
     {0.6567926949014797, 1.4917828430524098}}]}, {CMYKColor[0.25, 0.5, \
0.275, 0.1], 
   Polygon[{{0.35788345626266027, 1.5224519023538965}, {0.40127049152522326, \
1.6089224974238354}, {0.7284113220108744, 1.6209688555409114}, 
     {0.6748951426366303, 1.5257871330867279}}]}, {CMYKColor[0.25, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{0.40127049152522326, 1.6089224974238354}, {0.4714721892511405, \
1.7374623647519976}, {0.8150023191864375, 1.7606905703776887}, 
     {0.7284113220108744, 1.6209688555409114}}]}, {CMYKColor[0.25, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{0.4714721892511405, 1.7374623647519976}, {0.5654203983846688, \
1.8918241808350182}, {0.9308836920770425, 1.9258466260207305}, 
     {0.8150023191864375, 1.7606905703776887}}]}, {CMYKColor[0.25, 0.5, \
0.325, 0.1], 
   Polygon[{{0.5654203983846688, 1.8918241808350182}, {0.6790091313731489, \
2.0573688751735326}, {1.0709908686268492, 2.099799626225553}, 
     {0.9308836920770425, 1.9258466260207305}}]}, {CMYKColor[0.25, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{0.6790091313731489, 2.0573688751735326}, {0.80727401552577, \
2.2226072396953476}, {1.229200492911807, 2.269958904737956}, 
     {1.0709908686268492, 2.099799626225553}}]}, {CMYKColor[0.25, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{0.80727401552577, 2.2226072396953476}, {0.9446092599218614, \
2.379229777665828}, {1.3985980451766555, 2.4276230462853476}, 
     {1.229200492911807, 2.269958904737956}}]}, {CMYKColor[0.25, 0.5, 0.375, \
0.1], 
   Polygon[{{0.9446092599218614, 2.379229777665828}, {1.0850126553736956, \
2.521624931409046}, {1.571780039527782, 2.5673355087770746}, 
     {1.3985980451766555, 2.4276230462853476}}]}, {CMYKColor[0.25, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{1.0850126553736956, 2.521624931409046}, {1.2223478997697876, \
2.646328981764321}, {1.7411775917926315, 2.686221801523239}, 
     {1.571780039527782, 2.5673355087770746}}]}, {CMYKColor[0.25, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{1.2223478997697876, 2.646328981764321}, {1.3506127839224085, \
2.7515251706591934}, {1.8993872160775886, 2.7833940695732022}, 
     {1.7411775917926315, 2.686221801523239}}]}, {CMYKColor[0.25, 0.5, 0.425, \
0.1], 
   Polygon[{{1.3506127839224085, 2.7515251706591934}, {1.4642015169108888, \
2.836596676593442}, {2.039494392627396, 2.859399797409293}, 
     {1.8993872160775886, 2.7833940695732022}}]}, {CMYKColor[0.25, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{1.4642015169108888, 2.836596676593442}, {1.5581497260444177, \
2.9017190909782276}, {2.1553757655180017, 2.9156867970745455}, 
     {2.039494392627396, 2.859399797409293}}]}, {CMYKColor[0.25, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{1.5581497260444177, 2.9017190909782276}, {1.628351423770335, \
2.9474883844565616}, {2.241966762693565, 2.95408127925137}, 
     {2.1553757655180017, 2.9156867970745455}}]}, {CMYKColor[0.25, 0.5, \
0.475, 0.1], 
   Polygon[{{1.628351423770335, 2.9474883844565616}, {1.6717384590328979, \
2.9745950829027943}, {2.2954829420678085, 2.9763034938899464}, 
     {2.241966762693565, 2.95408127925137}}]}, {CMYKColor[0.25, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{1.6717384590328979, 2.9745950829027943}, {1.6864146101970388, \
2.98356568610482}, {2.3135853898029595, 2.98356568610482}, 
     {2.2954829420678085, 2.9763034938899464}}]}, {CMYKColor[0.25, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{1.6864146101970388, 2.98356568610482}, {1.6717384590328983, \
2.974595082902794}, {2.2954829420678093, 2.9763034938899464}, 
     {2.3135853898029595, 2.98356568610482}}]}, {CMYKColor[0.25, 0.5, 0.525, \
0.1], 
   Polygon[{{1.6717384590328983, 2.974595082902794}, {1.6283514237703351, \
2.947488384456561}, {2.241966762693565, 2.9540812792513704}, 
     {2.2954829420678093, 2.9763034938899464}}]}, {CMYKColor[0.25, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{1.6283514237703351, 2.947488384456561}, {1.558149726044418, \
2.9017190909782276}, {2.155375765518002, 2.9156867970745455}, 
     {2.241966762693565, 2.9540812792513704}}]}, {CMYKColor[0.25, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{1.558149726044418, 2.9017190909782276}, {1.4642015169108895, \
2.836596676593442}, {2.0394943926273967, 2.859399797409293}, 
     {2.155375765518002, 2.9156867970745455}}]}, {CMYKColor[0.25, 0.5, 0.575, \
0.1], 
   Polygon[{{1.4642015169108895, 2.836596676593442}, {1.3506127839224094, \
2.751525170659194}, {1.8993872160775902, 2.7833940695732027}, 
     {2.0394943926273967, 2.859399797409293}}]}, {CMYKColor[0.25, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{1.3506127839224094, 2.751525170659194}, {1.2223478997697883, \
2.646328981764321}, {1.7411775917926322, 2.6862218015232395}, 
     {1.8993872160775902, 2.7833940695732027}}]}, {CMYKColor[0.25, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{1.2223478997697883, 2.646328981764321}, {1.085012655373697, \
2.521624931409047}, {1.5717800395277832, 2.5673355087770755}, 
     {1.7411775917926322, 2.6862218015232395}}]}, {CMYKColor[0.25, 0.5, \
0.625, 0.1], 
   Polygon[{{1.085012655373697, 2.521624931409047}, {0.9446092599218623, \
2.379229777665829}, {1.3985980451766569, 2.4276230462853485}, 
     {1.5717800395277832, 2.5673355087770755}}]}, {CMYKColor[0.25, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{0.9446092599218623, 2.379229777665829}, {0.8072740155257706, \
2.222607239695348}, {1.2292004929118077, 2.269958904737957}, 
     {1.3985980451766569, 2.4276230462853485}}]}, {CMYKColor[0.25, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{0.8072740155257706, 2.222607239695348}, {0.6790091313731498, \
2.057368875173534}, {1.0709908686268503, 2.0997996262255545}, 
     {1.2292004929118077, 2.269958904737957}}]}, {CMYKColor[0.25, 0.5, 0.675, \
0.1], 
   Polygon[{{0.6790091313731498, 2.057368875173534}, {0.5654203983846697, \
1.8918241808350196}, {0.9308836920770434, 1.9258466260207323}, 
     {1.0709908686268503, 2.0997996262255545}}]}, {CMYKColor[0.25, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{0.5654203983846697, 1.8918241808350196}, {0.4714721892511406, \
1.7374623647519978}, {0.8150023191864375, 1.760690570377689}, 
     {0.9308836920770434, 1.9258466260207323}}]}, {CMYKColor[0.25, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{0.4714721892511406, 1.7374623647519978}, {0.40127049152522365, \
1.608922497423836}, {0.728411322010875, 1.620968855540912}, 
     {0.8150023191864375, 1.760690570377689}}]}, {CMYKColor[0.25, 0.5, 0.725, \
0.1], 
   Polygon[{{0.40127049152522365, 1.608922497423836}, {0.3578834562626605, \
1.5224519023538967}, {0.6748951426366308, 1.5257871330867285}, 
     {0.728411322010875, 1.620968855540912}}]}, {CMYKColor[0.25, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{0.3578834562626605, 1.5224519023538967}, {0.3432073050985194, \
1.49178284305241}, {0.6567926949014797, 1.4917828430524098}, 
     {0.6748951426366308, 1.5257871330867285}}]}, {CMYKColor[0.25, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{0.3432073050985194, 1.49178284305241}, {0.35788345626266016, \
1.5224519023538963}, {0.6748951426366302, 1.5257871330867274}, 
     {0.6567926949014797, 1.4917828430524098}}]}, {CMYKColor[0.25, 0.5, \
0.775, 0.1], 
   Polygon[{{0.35788345626266016, 1.5224519023538963}, {0.40127049152522287, \
1.608922497423835}, {0.7284113220108738, 1.6209688555409107}, 
     {0.6748951426366302, 1.5257871330867274}}]}, {CMYKColor[0.25, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{0.40127049152522287, 1.608922497423835}, {0.4714721892511403, \
1.7374623647519973}, {0.8150023191864373, 1.7606905703776887}, 
     {0.7284113220108738, 1.6209688555409107}}]}, {CMYKColor[0.25, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{0.4714721892511403, 1.7374623647519973}, {0.5654203983846685, \
1.8918241808350178}, {0.930883692077042, 1.92584662602073}, 
     {0.8150023191864373, 1.7606905703776887}}]}, {CMYKColor[0.25, 0.5, \
0.825, 0.1], 
   Polygon[{{0.5654203983846685, 1.8918241808350178}, {0.6790091313731483, \
2.057368875173532}, {1.0709908686268486, 2.0997996262255523}, 
     {0.930883692077042, 1.92584662602073}}]}, {CMYKColor[0.25, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{0.6790091313731483, 2.057368875173532}, {0.80727401552577, \
2.2226072396953476}, {1.229200492911807, 2.269958904737956}, 
     {1.0709908686268486, 2.0997996262255523}}]}, {CMYKColor[0.25, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{0.80727401552577, 2.2226072396953476}, {0.944609259921861, \
2.379229777665828}, {1.3985980451766553, 2.427623046285347}, 
     {1.229200492911807, 2.269958904737956}}]}, {CMYKColor[0.25, 0.5, 0.875, \
0.1], 
   Polygon[{{0.944609259921861, 2.379229777665828}, {1.085012655373695, \
2.521624931409045}, {1.571780039527781, 2.5673355087770737}, 
     {1.3985980451766553, 2.427623046285347}}]}, {CMYKColor[0.25, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{1.085012655373695, 2.521624931409045}, {1.2223478997697876, \
2.646328981764321}, {1.7411775917926318, 2.686221801523239}, 
     {1.571780039527781, 2.5673355087770737}}]}, {CMYKColor[0.25, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{1.2223478997697876, 2.646328981764321}, {1.3506127839224085, \
2.7515251706591934}, {1.8993872160775886, 2.7833940695732022}, 
     {1.7411775917926318, 2.686221801523239}}]}, {CMYKColor[0.25, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{1.3506127839224085, 2.7515251706591934}, {1.4642015169108882, \
2.836596676593441}, {2.0394943926273954, 2.8593997974092926}, 
     {1.8993872160775886, 2.7833940695732022}}]}, {CMYKColor[0.25, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{1.4642015169108882, 2.836596676593441}, {1.5581497260444177, \
2.901719090978228}, {2.1553757655180017, 2.9156867970745455}, 
     {2.0394943926273954, 2.8593997974092926}}]}, {CMYKColor[0.25, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{1.5581497260444177, 2.901719090978228}, {1.628351423770335, \
2.9474883844565616}, {2.241966762693565, 2.95408127925137}, 
     {2.1553757655180017, 2.9156867970745455}}]}, {CMYKColor[0.25, 0.5, \
0.975, 0.1], 
   Polygon[{{1.628351423770335, 2.9474883844565616}, {1.671738459032898, \
2.9745950829027943}, {2.295482942067809, 2.9763034938899455}, 
     {2.241966762693565, 2.95408127925137}}]}, {CMYKColor[0.25, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{1.671738459032898, 2.9745950829027943}, {1.6864146101970388, \
2.98356568610482}, {2.3135853898029595, 2.98356568610482}, 
     {2.295482942067809, 2.9763034938899455}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{2.3135853898029595, 2.98356568610482}, {2.2954829420678085, \
2.9763034938899464}, {2.9055971116193557, 2.8487773266631815}, 
     {2.9270509831248424, 2.8531695488854605}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{2.2954829420678085, 2.9763034938899464}, {2.241966762693565, \
2.9540812792513704}, {2.842173134234785, 2.834803496770629}, 
     {2.9055971116193557, 2.8487773266631815}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{2.241966762693565, 2.9540812792513704}, {2.1553757655180017, \
2.9156867970745455}, {2.739550983124842, 2.809014835019403}, 
     {2.842173134234785, 2.834803496770629}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{2.1553757655180017, 2.9156867970745455}, {2.039494392627396, \
2.859399797409293}, {2.602215738728751, 2.768181798733441}, 
     {2.739550983124842, 2.809014835019403}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{2.039494392627396, 2.859399797409293}, {1.8993872160775895, \
2.7833940695732022}, {2.4361696102342374, 2.7087103854853694}, 
     {2.602215738728751, 2.768181798733441}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{1.8993872160775895, 2.7833940695732022}, {1.7411775917926318, \
2.686221801523239}, {2.248669610234237, 2.6273597595826383}, 
     {2.4361696102342374, 2.7087103854853694}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{1.7411775917926318, 2.686221801523239}, {1.5717800395277828, \
2.567335508777075}, {2.047910388453574, 2.521960112821855}, 
     {2.248669610234237, 2.6273597595826383}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{1.5717800395277828, 2.567335508777075}, {1.3985980451766564, \
2.427623046285348}, {1.8426660862336899, 2.392089327116677}, 
     {2.047910388453574, 2.521960112821855}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{1.3985980451766564, 2.427623046285348}, {1.2292004929118074, \
2.2699589047379565}, {1.6419068644530264, 2.239718051509763}, 
     {1.8426660862336899, 2.392089327116677}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{1.2292004929118074, 2.2699589047379565}, {1.07099086862685, \
2.099799626225554}, {1.4544068644530266, 2.0698782028004876}, 
     {1.6419068644530264, 2.239718051509763}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{1.07099086862685, 2.099799626225554}, {0.9308836920770429, \
1.9258466260207312}, {1.2883607359585132, 1.8914277190459865}, 
     {1.4544068644530266, 2.0698782028004876}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.9308836920770429, 1.9258466260207312}, {0.8150023191864373, \
1.760690570377689}, {1.151025491562421, 1.7178957504272223}, 
     {1.2883607359585132, 1.8914277190459865}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.8150023191864373, 1.760690570377689}, {0.7284113220108746, \
1.6209688555409116}, {1.0484033404524793, 1.5679671136605229}, 
     {1.151025491562421, 1.7178957504272223}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{0.7284113220108746, 1.6209688555409116}, {0.6748951426366303, \
1.525787133086728}, {0.9849793630679075, 1.464075901868194}, 
     {1.0484033404524793, 1.5679671136605229}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.6748951426366303, 1.525787133086728}, {0.6567926949014797, \
1.4917828430524098}, {0.9635254915624212, 1.4265847744427302}, 
     {0.9849793630679075, 1.464075901868194}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.6567926949014797, 1.4917828430524098}, {0.6748951426366303, \
1.5257871330867279}, {0.9849793630679075, 1.4640759018681935}, 
     {0.9635254915624212, 1.4265847744427302}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{0.6748951426366303, 1.5257871330867279}, {0.7284113220108744, \
1.6209688555409114}, {1.0484033404524793, 1.5679671136605227}, 
     {0.9849793630679075, 1.4640759018681935}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0.7284113220108744, 1.6209688555409114}, {0.8150023191864375, \
1.7606905703776887}, {1.1510254915624212, 1.7178957504272216}, 
     {1.0484033404524793, 1.5679671136605227}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0.8150023191864375, 1.7606905703776887}, {0.9308836920770425, \
1.9258466260207305}, {1.2883607359585123, 1.8914277190459858}, 
     {1.1510254915624212, 1.7178957504272216}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{0.9308836920770425, 1.9258466260207305}, {1.0709908686268492, \
2.099799626225553}, {1.4544068644530257, 2.069878202800487}, 
     {1.2883607359585123, 1.8914277190459858}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{1.0709908686268492, 2.099799626225553}, {1.229200492911807, \
2.269958904737956}, {1.6419068644530261, 2.239718051509763}, 
     {1.4544068644530257, 2.069878202800487}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{1.229200492911807, 2.269958904737956}, {1.3985980451766555, \
2.4276230462853476}, {1.842666086233689, 2.3920893271166768}, 
     {1.6419068644530261, 2.239718051509763}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{1.3985980451766555, 2.4276230462853476}, {1.571780039527782, \
2.5673355087770746}, {2.0479103884535728, 2.521960112821855}, 
     {1.842666086233689, 2.3920893271166768}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{1.571780039527782, 2.5673355087770746}, {1.7411775917926315, \
2.686221801523239}, {2.248669610234237, 2.627359759582638}, 
     {2.0479103884535728, 2.521960112821855}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{1.7411775917926315, 2.686221801523239}, {1.8993872160775886, \
2.7833940695732022}, {2.436169610234236, 2.70871038548537}, 
     {2.248669610234237, 2.627359759582638}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{1.8993872160775886, 2.7833940695732022}, {2.039494392627396, \
2.859399797409293}, {2.6022157387287503, 2.7681817987334414}, 
     {2.436169610234236, 2.70871038548537}}]}, {CMYKColor[0.2833333333333333, \
0.5, 0.44166666666666665, 0.1], 
   Polygon[{{2.039494392627396, 2.859399797409293}, {2.1553757655180017, \
2.9156867970745455}, {2.739550983124842, 2.809014835019403}, 
     {2.6022157387287503, 2.7681817987334414}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{2.1553757655180017, 2.9156867970745455}, {2.241966762693565, \
2.95408127925137}, {2.842173134234784, 2.834803496770629}, 
     {2.739550983124842, 2.809014835019403}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{2.241966762693565, 2.95408127925137}, {2.2954829420678085, \
2.9763034938899464}, {2.9055971116193557, 2.8487773266631815}, 
     {2.842173134234784, 2.834803496770629}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{2.2954829420678085, 2.9763034938899464}, {2.3135853898029595, \
2.98356568610482}, {2.9270509831248424, 2.8531695488854605}, 
     {2.9055971116193557, 2.8487773266631815}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{2.3135853898029595, 2.98356568610482}, {2.2954829420678093, \
2.9763034938899464}, {2.9055971116193566, 2.8487773266631806}, 
     {2.9270509831248424, 2.8531695488854605}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{2.2954829420678093, 2.9763034938899464}, {2.241966762693565, \
2.9540812792513704}, {2.8421731342347845, 2.8348034967706295}, 
     {2.9055971116193566, 2.8487773266631806}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{2.241966762693565, 2.9540812792513704}, {2.155375765518002, \
2.9156867970745455}, {2.739550983124843, 2.8090148350194024}, 
     {2.8421731342347845, 2.8348034967706295}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{2.155375765518002, 2.9156867970745455}, {2.0394943926273967, \
2.859399797409293}, {2.6022157387287517, 2.7681817987334414}, 
     {2.739550983124843, 2.8090148350194024}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{2.0394943926273967, 2.859399797409293}, {1.8993872160775902, \
2.7833940695732027}, {2.436169610234238, 2.70871038548537}, 
     {2.6022157387287517, 2.7681817987334414}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{1.8993872160775902, 2.7833940695732027}, {1.7411775917926322, \
2.6862218015232395}, {2.2486696102342374, 2.6273597595826383}, 
     {2.436169610234238, 2.70871038548537}}]}, {CMYKColor[0.2833333333333333, \
0.5, 0.6083333333333333, 0.1], 
   Polygon[{{1.7411775917926322, 2.6862218015232395}, {1.5717800395277832, \
2.5673355087770755}, {2.047910388453575, 2.521960112821855}, 
     {2.2486696102342374, 2.6273597595826383}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{1.5717800395277832, 2.5673355087770755}, {1.3985980451766569, \
2.4276230462853485}, {1.8426660862336905, 2.3920893271166777}, 
     {2.047910388453575, 2.521960112821855}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{1.3985980451766569, 2.4276230462853485}, {1.2292004929118077, \
2.269958904737957}, {1.641906864453027, 2.239718051509763}, 
     {1.8426660862336905, 2.3920893271166777}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{1.2292004929118077, 2.269958904737957}, {1.0709908686268503, \
2.0997996262255545}, {1.4544068644530275, 2.069878202800488}, 
     {1.641906864453027, 2.239718051509763}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{1.0709908686268503, 2.0997996262255545}, {0.9308836920770434, \
1.9258466260207323}, {1.2883607359585136, 1.8914277190459876}, 
     {1.4544068644530275, 2.069878202800488}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0.9308836920770434, 1.9258466260207323}, {0.8150023191864375, \
1.760690570377689}, {1.1510254915624212, 1.7178957504272223}, 
     {1.2883607359585136, 1.8914277190459876}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0.8150023191864375, 1.760690570377689}, {0.728411322010875, \
1.620968855540912}, {1.0484033404524797, 1.5679671136605233}, 
     {1.1510254915624212, 1.7178957504272223}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{0.728411322010875, 1.620968855540912}, {0.6748951426366308, \
1.5257871330867285}, {0.9849793630679078, 1.4640759018681944}, 
     {1.0484033404524797, 1.5679671136605233}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.6748951426366308, 1.5257871330867285}, {0.6567926949014797, \
1.4917828430524098}, {0.9635254915624212, 1.4265847744427302}, 
     {0.9849793630679078, 1.4640759018681944}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.6567926949014797, 1.4917828430524098}, {0.6748951426366302, \
1.5257871330867274}, {0.9849793630679072, 1.4640759018681933}, 
     {0.9635254915624212, 1.4265847744427302}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{0.6748951426366302, 1.5257871330867274}, {0.7284113220108738, \
1.6209688555409107}, {1.0484033404524786, 1.5679671136605218}, 
     {0.9849793630679072, 1.4640759018681933}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.7284113220108738, 1.6209688555409107}, {0.8150023191864373, \
1.7606905703776887}, {1.151025491562421, 1.7178957504272216}, 
     {1.0484033404524786, 1.5679671136605218}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.8150023191864373, 1.7606905703776887}, {0.930883692077042, \
1.92584662602073}, {1.288360735958512, 1.8914277190459854}, 
     {1.151025491562421, 1.7178957504272216}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{0.930883692077042, 1.92584662602073}, {1.0709908686268486, \
2.0997996262255523}, {1.4544068644530252, 2.069878202800486}, 
     {1.288360735958512, 1.8914277190459854}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{1.0709908686268486, 2.0997996262255523}, {1.229200492911807, \
2.269958904737956}, {1.6419068644530261, 2.239718051509763}, 
     {1.4544068644530252, 2.069878202800486}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{1.229200492911807, 2.269958904737956}, {1.3985980451766553, \
2.427623046285347}, {1.8426660862336885, 2.3920893271166768}, 
     {1.6419068644530261, 2.239718051509763}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{1.3985980451766553, 2.427623046285347}, {1.571780039527781, \
2.5673355087770737}, {2.047910388453572, 2.521960112821854}, 
     {1.8426660862336885, 2.3920893271166768}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{1.571780039527781, 2.5673355087770737}, {1.7411775917926318, \
2.686221801523239}, {2.248669610234237, 2.6273597595826383}, 
     {2.047910388453572, 2.521960112821854}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{1.7411775917926318, 2.686221801523239}, {1.8993872160775886, \
2.7833940695732022}, {2.436169610234236, 2.7087103854853694}, 
     {2.248669610234237, 2.6273597595826383}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{1.8993872160775886, 2.7833940695732022}, {2.0394943926273954, \
2.8593997974092926}, {2.602215738728749, 2.7681817987334414}, 
     {2.436169610234236, 2.7087103854853694}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{2.0394943926273954, 2.8593997974092926}, {2.1553757655180017, \
2.9156867970745455}, {2.739550983124842, 2.809014835019403}, 
     {2.602215738728749, 2.7681817987334414}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{2.1553757655180017, 2.9156867970745455}, {2.241966762693565, \
2.95408127925137}, {2.842173134234784, 2.834803496770629}, 
     {2.739550983124842, 2.809014835019403}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{2.241966762693565, 2.95408127925137}, {2.295482942067809, \
2.9763034938899455}, {2.905597111619356, 2.848777326663181}, 
     {2.842173134234784, 2.834803496770629}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{2.295482942067809, 2.9763034938899455}, {2.3135853898029595, \
2.98356568610482}, {2.9270509831248424, 2.8531695488854605}, 
     {2.905597111619356, 2.848777326663181}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193557, \
2.8487773266631815}, {3.4754160508255305, 2.5979598975817524}, 
     {3.4999999999999996, 2.598076211353316}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.025, 0.1], 
   Polygon[{{2.9055971116193557, 2.8487773266631815}, {2.842173134234785, \
2.834803496770629}, {3.402738639847926, 2.5962550390555568}, 
     {3.4754160508255305, 2.5979598975817524}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{2.842173134234785, 2.834803496770629}, {2.739550983124842, \
2.809014835019403}, {3.285144118671815, 2.5891768866299363}, 
     {3.402738639847926, 2.5962550390555568}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{2.739550983124842, 2.809014835019403}, {2.602215738728751, \
2.768181798733441}, {3.1277719321537143, 2.5712732770958877}, 
     {3.285144118671815, 2.5891768866299363}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.075, 0.1], 
   Polygon[{{2.602215738728751, 2.768181798733441}, {2.4361696102342374, \
2.7087103854853694}, {2.9375, 2.536452985962878}, 
     {3.1277719321537143, 2.5712732770958877}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{2.4361696102342374, 2.7087103854853694}, {2.248669610234237, \
2.6273597595826383}, {2.7226441186718153, 2.479055835144598}, 
     {2.9375, 2.536452985962878}}]}, {CMYKColor[0.31666666666666665, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{2.248669610234237, 2.6273597595826383}, {2.047910388453574, \
2.521960112821855}, {2.4925945211761102, 2.394814022264695}, 
     {2.7226441186718153, 2.479055835144598}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.125, 0.1], 
   Polygon[{{2.047910388453574, 2.521960112821855}, {1.8426660862336899, \
2.392089327116677}, {2.2574054788238893, 2.281657041700859}, 
     {2.4925945211761102, 2.394814022264695}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{1.8426660862336899, 2.392089327116677}, {1.6419068644530264, \
2.239718051509763}, {2.027355881328184, 2.14040166785146}, 
     {2.2574054788238893, 2.281657041700859}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{1.6419068644530264, 2.239718051509763}, {1.4544068644530266, \
2.0698782028004876}, {1.8124999999999998, 1.9754350786598887}, 
     {2.027355881328184, 2.14040166785146}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.175, 0.1], 
   Polygon[{{1.4544068644530266, 2.0698782028004876}, {1.2883607359585132, \
1.8914277190459865}, {1.6222280678462844, 1.7955424168801202}, 
     {1.8124999999999998, 1.9754350786598887}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{1.2883607359585132, 1.8914277190459865}, {1.151025491562421, \
1.7178957504272223}, {1.4648558813281836, 1.61498867371741}, 
     {1.6222280678462844, 1.7955424168801202}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.151025491562421, 1.7178957504272223}, {1.0484033404524793, \
1.5679671136605229}, {1.3472613601520738, 1.4545502220637494}, 
     {1.4648558813281836, 1.61498867371741}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.225, 0.1], 
   Polygon[{{1.0484033404524793, 1.5679671136605229}, {0.9849793630679075, \
1.464075901868194}, {1.2745839491744684, 1.340717494749769}, 
     {1.3472613601520738, 1.4545502220637494}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.9849793630679075, 1.464075901868194}, {0.9635254915624212, \
1.4265847744427302}, {1.2499999999999996, 1.2990381056766582}, 
     {1.2745839491744684, 1.340717494749769}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.9635254915624212, 1.4265847744427302}, {0.9849793630679075, \
1.4640759018681935}, {1.2745839491744684, 1.3407174947497689}, 
     {1.2499999999999996, 1.2990381056766582}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.275, 0.1], 
   Polygon[{{0.9849793630679075, 1.4640759018681935}, {1.0484033404524793, \
1.5679671136605227}, {1.3472613601520735, 1.4545502220637487}, 
     {1.2745839491744684, 1.3407174947497689}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.0484033404524793, 1.5679671136605227}, {1.1510254915624212, \
1.7178957504272216}, {1.4648558813281838, 1.6149886737174097}, 
     {1.3472613601520735, 1.4545502220637487}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.1510254915624212, 1.7178957504272216}, {1.2883607359585123, \
1.8914277190459858}, {1.622228067846284, 1.7955424168801195}, 
     {1.4648558813281838, 1.6149886737174097}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.325, 0.1], 
   Polygon[{{1.2883607359585123, 1.8914277190459858}, {1.4544068644530257, \
2.069878202800487}, {1.8124999999999991, 1.975435078659888}, 
     {1.622228067846284, 1.7955424168801195}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{1.4544068644530257, 2.069878202800487}, {1.6419068644530261, \
2.239718051509763}, {2.0273558813281833, 2.1404016678514597}, 
     {1.8124999999999991, 1.975435078659888}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{1.6419068644530261, 2.239718051509763}, {1.842666086233689, \
2.3920893271166768}, {2.2574054788238884, 2.2816570417008584}, 
     {2.0273558813281833, 2.1404016678514597}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.375, 0.1], 
   Polygon[{{1.842666086233689, 2.3920893271166768}, {2.0479103884535728, \
2.521960112821855}, {2.492594521176109, 2.394814022264695}, 
     {2.2574054788238884, 2.2816570417008584}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{2.0479103884535728, 2.521960112821855}, {2.248669610234237, \
2.627359759582638}, {2.7226441186718153, 2.479055835144598}, 
     {2.492594521176109, 2.394814022264695}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{2.248669610234237, 2.627359759582638}, {2.436169610234236, \
2.70871038548537}, {2.9374999999999987, 2.536452985962878}, 
     {2.7226441186718153, 2.479055835144598}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.425, 0.1], 
   Polygon[{{2.436169610234236, 2.70871038548537}, {2.6022157387287503, \
2.7681817987334414}, {3.1277719321537147, 2.5712732770958873}, 
     {2.9374999999999987, 2.536452985962878}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{2.6022157387287503, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {3.2851441186718153, 2.589176886629936}, 
     {3.1277719321537147, 2.5712732770958873}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {3.4027386398479256, 2.5962550390555554}, 
     {3.2851441186718153, 2.589176886629936}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.475, 0.1], 
   Polygon[{{2.842173134234784, 2.834803496770629}, {2.9055971116193557, \
2.8487773266631815}, {3.4754160508255305, 2.5979598975817524}, 
     {3.4027386398479256, 2.5962550390555554}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{2.9055971116193557, 2.8487773266631815}, {2.9270509831248424, \
2.8531695488854605}, {3.4999999999999996, 2.598076211353316}, 
     {3.4754160508255305, 2.5979598975817524}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193566, \
2.8487773266631806}, {3.4754160508255314, 2.5979598975817515}, 
     {3.4999999999999996, 2.598076211353316}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.525, 0.1], 
   Polygon[{{2.9055971116193566, 2.8487773266631806}, {2.8421731342347845, \
2.8348034967706295}, {3.402738639847926, 2.5962550390555568}, 
     {3.4754160508255314, 2.5979598975817515}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{2.8421731342347845, 2.8348034967706295}, {2.739550983124843, \
2.8090148350194024}, {3.2851441186718158, 2.589176886629936}, 
     {3.402738639847926, 2.5962550390555568}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{2.739550983124843, 2.8090148350194024}, {2.6022157387287517, \
2.7681817987334414}, {3.1277719321537156, 2.5712732770958877}, 
     {3.2851441186718158, 2.589176886629936}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.575, 0.1], 
   Polygon[{{2.6022157387287517, 2.7681817987334414}, {2.436169610234238, \
2.70871038548537}, {2.9375000000000004, 2.5364529859628786}, 
     {3.1277719321537156, 2.5712732770958877}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{2.436169610234238, 2.70871038548537}, {2.2486696102342374, \
2.6273597595826383}, {2.722644118671816, 2.479055835144598}, 
     {2.9375000000000004, 2.5364529859628786}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{2.2486696102342374, 2.6273597595826383}, {2.047910388453575, \
2.521960112821855}, {2.492594521176111, 2.3948140222646956}, 
     {2.722644118671816, 2.479055835144598}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.625, 0.1], 
   Polygon[{{2.047910388453575, 2.521960112821855}, {1.8426660862336905, \
2.3920893271166777}, {2.25740547882389, 2.281657041700859}, 
     {2.492594521176111, 2.3948140222646956}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{1.8426660862336905, 2.3920893271166777}, {1.641906864453027, \
2.239718051509763}, {2.0273558813281842, 2.14040166785146}, 
     {2.25740547882389, 2.281657041700859}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{1.641906864453027, 2.239718051509763}, {1.4544068644530275, \
2.069878202800488}, {1.8125000000000004, 1.9754350786598895}, 
     {2.0273558813281842, 2.14040166785146}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.675, 0.1], 
   Polygon[{{1.4544068644530275, 2.069878202800488}, {1.2883607359585136, \
1.8914277190459876}, {1.6222280678462853, 1.7955424168801213}, 
     {1.8125000000000004, 1.9754350786598895}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{1.2883607359585136, 1.8914277190459876}, {1.1510254915624212, \
1.7178957504272223}, {1.4648558813281838, 1.6149886737174104}, 
     {1.6222280678462853, 1.7955424168801213}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.1510254915624212, 1.7178957504272223}, {1.0484033404524797, \
1.5679671136605233}, {1.3472613601520744, 1.4545502220637496}, 
     {1.4648558813281838, 1.6149886737174104}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.725, 0.1], 
   Polygon[{{1.0484033404524797, 1.5679671136605233}, {0.9849793630679078, \
1.4640759018681944}, {1.2745839491744688, 1.3407174947497695}, 
     {1.3472613601520744, 1.4545502220637496}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.9849793630679078, 1.4640759018681944}, {0.9635254915624212, \
1.4265847744427302}, {1.2499999999999996, 1.2990381056766582}, 
     {1.2745839491744688, 1.3407174947497695}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.9635254915624212, 1.4265847744427302}, {0.9849793630679072, \
1.4640759018681933}, {1.2745839491744682, 1.3407174947497684}, 
     {1.2499999999999996, 1.2990381056766582}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.775, 0.1], 
   Polygon[{{0.9849793630679072, 1.4640759018681933}, {1.0484033404524786, \
1.5679671136605218}, {1.3472613601520729, 1.454550222063748}, 
     {1.2745839491744682, 1.3407174947497684}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.0484033404524786, 1.5679671136605218}, {1.151025491562421, \
1.7178957504272216}, {1.4648558813281836, 1.6149886737174093}, 
     {1.3472613601520729, 1.454550222063748}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.151025491562421, 1.7178957504272216}, {1.288360735958512, \
1.8914277190459854}, {1.622228067846283, 1.7955424168801193}, 
     {1.4648558813281836, 1.6149886737174093}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.825, 0.1], 
   Polygon[{{1.288360735958512, 1.8914277190459854}, {1.4544068644530252, \
2.069878202800486}, {1.8124999999999982, 1.975435078659887}, 
     {1.622228067846283, 1.7955424168801193}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{1.4544068644530252, 2.069878202800486}, {1.6419068644530261, \
2.239718051509763}, {2.0273558813281833, 2.1404016678514592}, 
     {1.8124999999999982, 1.975435078659887}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{1.6419068644530261, 2.239718051509763}, {1.8426660862336885, \
2.3920893271166768}, {2.257405478823888, 2.281657041700858}, 
     {2.0273558813281833, 2.1404016678514592}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.875, 0.1], 
   Polygon[{{1.8426660862336885, 2.3920893271166768}, {2.047910388453572, \
2.521960112821854}, {2.492594521176108, 2.3948140222646943}, 
     {2.257405478823888, 2.281657041700858}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{2.047910388453572, 2.521960112821854}, {2.248669610234237, \
2.6273597595826383}, {2.7226441186718153, 2.479055835144598}, 
     {2.492594521176108, 2.3948140222646943}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{2.248669610234237, 2.6273597595826383}, {2.436169610234236, \
2.7087103854853694}, {2.9374999999999987, 2.5364529859628777}, 
     {2.7226441186718153, 2.479055835144598}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{2.436169610234236, 2.7087103854853694}, {2.602215738728749, \
2.7681817987334414}, {3.1277719321537134, 2.5712732770958864}, 
     {2.9374999999999987, 2.5364529859628777}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{2.602215738728749, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {3.2851441186718153, 2.589176886629936}, 
     {3.1277719321537134, 2.5712732770958864}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {3.4027386398479256, 2.5962550390555554}, 
     {3.2851441186718153, 2.589176886629936}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.975, 0.1], 
   Polygon[{{2.842173134234784, 2.834803496770629}, {2.905597111619356, \
2.848777326663181}, {3.475416050825531, 2.5979598975817515}, 
     {3.4027386398479256, 2.5962550390555554}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{2.905597111619356, 2.848777326663181}, {2.9270509831248424, \
2.8531695488854605}, {3.4999999999999996, 2.598076211353316}, 
     {3.475416050825531, 2.5979598975817515}}]}, {CMYKColor[0.35, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{3.4999999999999996, 2.598076211353316}, {3.4754160508255305, \
2.5979598975817524}, {3.98003593774839, 2.235484296800204}, 
     {4.007391819076574, 2.229434476432184}}]}, {CMYKColor[0.35, 0.5, 0.025, \
0.1], 
   Polygon[{{3.4754160508255305, 2.5979598975817524}, {3.402738639847926, \
2.5962550390555568}, {3.8991638770459622, 2.251331326578102}, 
     {3.98003593774839, 2.235484296800204}}]}, {CMYKColor[0.35, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{3.402738639847926, 2.5962550390555568}, {3.285144118671815, \
2.5891768866299363}, {3.768310134089188, 2.270646210820903}, 
     {3.8991638770459622, 2.251331326578102}}]}, {CMYKColor[0.35, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{3.285144118671815, 2.5891768866299363}, {3.1277719321537143, \
2.5712732770958877}, {3.593193645351204, 2.284543605895154}, 
     {3.768310134089188, 2.270646210820903}}]}, {CMYKColor[0.35, 0.5, 0.075, \
0.1], 
   Polygon[{{3.1277719321537143, 2.5712732770958877}, {2.9375, \
2.536452985962878}, {3.381467841692003, 2.283369148915068}, 
     {3.593193645351204, 2.284543605895154}}]}, {CMYKColor[0.35, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{2.9375, 2.536452985962878}, {2.7226441186718153, \
2.479055835144598}, {3.1423861567046165, 2.2583039834915453}, 
     {3.381467841692003, 2.283369148915068}}]}, {CMYKColor[0.35, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{2.7226441186718153, 2.479055835144598}, {2.4925945211761102, \
2.394814022264695}, {2.886397607264205, 2.202570463435661}, 
     {3.1423861567046165, 2.2583039834915453}}]}, {CMYKColor[0.35, 0.5, \
0.125, 0.1], 
   Polygon[{{2.4925945211761102, 2.394814022264695}, {2.2574054788238893, \
2.281657041700859}, {2.624690121350657, 2.112263515546569}, 
     {2.886397607264205, 2.202570463435661}}]}, {CMYKColor[0.35, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{2.2574054788238893, 2.281657041700859}, {2.027355881328184, \
2.14040166785146}, {2.3687015719102447, 1.9869545564435858}, 
     {2.624690121350657, 2.112263515546569}}]}, {CMYKColor[0.35, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{2.027355881328184, 2.14040166785146}, {1.8124999999999998, \
1.9754350786598887}, {2.129619886922859, 1.83026852905604}, 
     {2.3687015719102447, 1.9869545564435858}}]}, {CMYKColor[0.35, 0.5, \
0.175, 0.1], 
   Polygon[{{1.8124999999999998, 1.9754350786598887}, {1.6222280678462844, \
1.7955424168801202}, {1.9178940832636575, 1.6506863454327518}, 
     {2.129619886922859, 1.83026852905604}}]}, {CMYKColor[0.35, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{1.6222280678462844, 1.7955424168801202}, {1.4648558813281836, \
1.61498867371741}, {1.7427775945256727, 1.4628718195622261}, 
     {1.9178940832636575, 1.6506863454327518}}]}, {CMYKColor[0.35, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{1.4648558813281836, 1.61498867371741}, {1.3472613601520738, \
1.4545502220637494}, {1.6119238515688996, 1.2895708590441468}, 
     {1.7427775945256727, 1.4628718195622261}}]}, {CMYKColor[0.35, 0.5, \
0.225, 0.1], 
   Polygon[{{1.3472613601520738, 1.4545502220637494}, {1.2745839491744684, \
1.340717494749769}, {1.5310517908664711, 1.162354288726182}, 
     {1.6119238515688996, 1.2895708590441468}}]}, {CMYKColor[0.35, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{1.2745839491744684, 1.340717494749769}, {1.2499999999999996, \
1.2990381056766582}, {1.503695909538287, 1.1147172382160917}, 
     {1.5310517908664711, 1.162354288726182}}]}, {CMYKColor[0.35, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{1.2499999999999996, 1.2990381056766582}, {1.2745839491744684, \
1.3407174947497689}, {1.5310517908664711, 1.1623542887261817}, 
     {1.503695909538287, 1.1147172382160917}}]}, {CMYKColor[0.35, 0.5, 0.275, \
0.1], 
   Polygon[{{1.2745839491744684, 1.3407174947497689}, {1.3472613601520735, \
1.4545502220637487}, {1.6119238515688992, 1.2895708590441464}, 
     {1.5310517908664711, 1.1623542887261817}}]}, {CMYKColor[0.35, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{1.3472613601520735, 1.4545502220637487}, {1.4648558813281838, \
1.6149886737174097}, {1.742777594525673, 1.4628718195622257}, 
     {1.6119238515688992, 1.2895708590441464}}]}, {CMYKColor[0.35, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{1.4648558813281838, 1.6149886737174097}, {1.622228067846284, \
1.7955424168801195}, {1.9178940832636566, 1.6506863454327514}, 
     {1.742777594525673, 1.4628718195622257}}]}, {CMYKColor[0.35, 0.5, 0.325, \
0.1], 
   Polygon[{{1.622228067846284, 1.7955424168801195}, {1.8124999999999991, \
1.975435078659888}, {2.129619886922858, 1.8302685290560394}, 
     {1.9178940832636566, 1.6506863454327514}}]}, {CMYKColor[0.35, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{1.8124999999999991, 1.975435078659888}, {2.0273558813281833, \
2.1404016678514597}, {2.368701571910244, 1.9869545564435858}, 
     {2.129619886922858, 1.8302685290560394}}]}, {CMYKColor[0.35, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{2.0273558813281833, 2.1404016678514597}, {2.2574054788238884, \
2.2816570417008584}, {2.624690121350656, 2.112263515546568}, 
     {2.368701571910244, 1.9869545564435858}}]}, {CMYKColor[0.35, 0.5, 0.375, \
0.1], 
   Polygon[{{2.2574054788238884, 2.2816570417008584}, {2.492594521176109, \
2.394814022264695}, {2.8863976072642035, 2.202570463435661}, 
     {2.624690121350656, 2.112263515546568}}]}, {CMYKColor[0.35, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{2.492594521176109, 2.394814022264695}, {2.7226441186718153, \
2.479055835144598}, {3.1423861567046165, 2.258303983491545}, 
     {2.8863976072642035, 2.202570463435661}}]}, {CMYKColor[0.35, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{2.7226441186718153, 2.479055835144598}, {2.9374999999999987, \
2.536452985962878}, {3.3814678416920017, 2.2833691489150683}, 
     {3.1423861567046165, 2.258303983491545}}]}, {CMYKColor[0.35, 0.5, 0.425, \
0.1], 
   Polygon[{{2.9374999999999987, 2.536452985962878}, {3.1277719321537147, \
2.5712732770958873}, {3.593193645351204, 2.284543605895154}, 
     {3.3814678416920017, 2.2833691489150683}}]}, {CMYKColor[0.35, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{3.1277719321537147, 2.5712732770958873}, {3.2851441186718153, \
2.589176886629936}, {3.768310134089188, 2.270646210820903}, 
     {3.593193645351204, 2.284543605895154}}]}, {CMYKColor[0.35, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{3.2851441186718153, 2.589176886629936}, {3.4027386398479256, \
2.5962550390555554}, {3.899163877045962, 2.251331326578102}, 
     {3.768310134089188, 2.270646210820903}}]}, {CMYKColor[0.35, 0.5, 0.475, \
0.1], 
   Polygon[{{3.4027386398479256, 2.5962550390555554}, {3.4754160508255305, \
2.5979598975817524}, {3.98003593774839, 2.235484296800204}, 
     {3.899163877045962, 2.251331326578102}}]}, {CMYKColor[0.35, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{3.4754160508255305, 2.5979598975817524}, {3.4999999999999996, \
2.598076211353316}, {4.007391819076574, 2.229434476432184}, 
     {3.98003593774839, 2.235484296800204}}]}, {CMYKColor[0.35, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{3.4999999999999996, 2.598076211353316}, {3.4754160508255314, \
2.5979598975817515}, {3.9800359377483905, 2.235484296800204}, 
     {4.007391819076574, 2.229434476432184}}]}, {CMYKColor[0.35, 0.5, 0.525, \
0.1], 
   Polygon[{{3.4754160508255314, 2.5979598975817515}, {3.402738639847926, \
2.5962550390555568}, {3.8991638770459622, 2.251331326578102}, 
     {3.9800359377483905, 2.235484296800204}}]}, {CMYKColor[0.35, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{3.402738639847926, 2.5962550390555568}, {3.2851441186718158, \
2.589176886629936}, {3.7683101340891887, 2.2706462108209022}, 
     {3.8991638770459622, 2.251331326578102}}]}, {CMYKColor[0.35, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{3.2851441186718158, 2.589176886629936}, {3.1277719321537156, \
2.5712732770958877}, {3.5931936453512052, 2.284543605895154}, 
     {3.7683101340891887, 2.2706462108209022}}]}, {CMYKColor[0.35, 0.5, \
0.575, 0.1], 
   Polygon[{{3.1277719321537156, 2.5712732770958877}, {2.9375000000000004, \
2.5364529859628786}, {3.3814678416920034, 2.2833691489150687}, 
     {3.5931936453512052, 2.284543605895154}}]}, {CMYKColor[0.35, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{2.9375000000000004, 2.5364529859628786}, {2.722644118671816, \
2.479055835144598}, {3.1423861567046174, 2.2583039834915453}, 
     {3.3814678416920034, 2.2833691489150687}}]}, {CMYKColor[0.35, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{2.722644118671816, 2.479055835144598}, {2.492594521176111, \
2.3948140222646956}, {2.8863976072642057, 2.202570463435661}, 
     {3.1423861567046174, 2.2583039834915453}}]}, {CMYKColor[0.35, 0.5, \
0.625, 0.1], 
   Polygon[{{2.492594521176111, 2.3948140222646956}, {2.25740547882389, \
2.281657041700859}, {2.6246901213506577, 2.112263515546569}, 
     {2.8863976072642057, 2.202570463435661}}]}, {CMYKColor[0.35, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{2.25740547882389, 2.281657041700859}, {2.0273558813281842, \
2.14040166785146}, {2.368701571910245, 1.9869545564435862}, 
     {2.6246901213506577, 2.112263515546569}}]}, {CMYKColor[0.35, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{2.0273558813281842, 2.14040166785146}, {1.8125000000000004, \
1.9754350786598895}, {2.12961988692286, 1.8302685290560408}, 
     {2.368701571910245, 1.9869545564435862}}]}, {CMYKColor[0.35, 0.5, 0.675, \
0.1], 
   Polygon[{{1.8125000000000004, 1.9754350786598895}, {1.6222280678462853, \
1.7955424168801213}, {1.9178940832636582, 1.6506863454327532}, 
     {2.12961988692286, 1.8302685290560408}}]}, {CMYKColor[0.35, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{1.6222280678462853, 1.7955424168801213}, {1.4648558813281838, \
1.6149886737174104}, {1.7427775945256732, 1.4628718195622263}, 
     {1.9178940832636582, 1.6506863454327532}}]}, {CMYKColor[0.35, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{1.4648558813281838, 1.6149886737174104}, {1.3472613601520744, \
1.4545502220637496}, {1.6119238515689, 1.2895708590441473}, 
     {1.7427775945256732, 1.4628718195622263}}]}, {CMYKColor[0.35, 0.5, \
0.725, 0.1], 
   Polygon[{{1.3472613601520744, 1.4545502220637496}, {1.2745839491744688, \
1.3407174947497695}, {1.5310517908664716, 1.1623542887261822}, 
     {1.6119238515689, 1.2895708590441473}}]}, {CMYKColor[0.35, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{1.2745839491744688, 1.3407174947497695}, {1.2499999999999996, \
1.2990381056766582}, {1.503695909538287, 1.1147172382160917}, 
     {1.5310517908664716, 1.1623542887261822}}]}, {CMYKColor[0.35, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{1.2499999999999996, 1.2990381056766582}, {1.2745839491744682, \
1.3407174947497684}, {1.531051790866471, 1.162354288726181}, 
     {1.503695909538287, 1.1147172382160917}}]}, {CMYKColor[0.35, 0.5, 0.775, \
0.1], 
   Polygon[{{1.2745839491744682, 1.3407174947497684}, {1.3472613601520729, \
1.454550222063748}, {1.6119238515688985, 1.2895708590441455}, 
     {1.531051790866471, 1.162354288726181}}]}, {CMYKColor[0.35, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{1.3472613601520729, 1.454550222063748}, {1.4648558813281836, \
1.6149886737174093}, {1.7427775945256727, 1.4628718195622255}, 
     {1.6119238515688985, 1.2895708590441455}}]}, {CMYKColor[0.35, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{1.4648558813281836, 1.6149886737174093}, {1.622228067846283, \
1.7955424168801193}, {1.917894083263656, 1.6506863454327507}, 
     {1.7427775945256727, 1.4628718195622255}}]}, {CMYKColor[0.35, 0.5, \
0.825, 0.1], 
   Polygon[{{1.622228067846283, 1.7955424168801193}, {1.8124999999999982, \
1.975435078659887}, {2.129619886922857, 1.830268529056039}, 
     {1.917894083263656, 1.6506863454327507}}]}, {CMYKColor[0.35, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{1.8124999999999982, 1.975435078659887}, {2.0273558813281833, \
2.1404016678514592}, {2.368701571910244, 1.9869545564435853}, 
     {2.129619886922857, 1.830268529056039}}]}, {CMYKColor[0.35, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{2.0273558813281833, 2.1404016678514592}, {2.257405478823888, \
2.281657041700858}, {2.6246901213506555, 2.1122635155465685}, 
     {2.368701571910244, 1.9869545564435853}}]}, {CMYKColor[0.35, 0.5, 0.875, \
0.1], 
   Polygon[{{2.257405478823888, 2.281657041700858}, {2.492594521176108, \
2.3948140222646943}, {2.886397607264202, 2.2025704634356607}, 
     {2.6246901213506555, 2.1122635155465685}}]}, {CMYKColor[0.35, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{2.492594521176108, 2.3948140222646943}, {2.7226441186718153, \
2.479055835144598}, {3.1423861567046165, 2.2583039834915453}, 
     {2.886397607264202, 2.2025704634356607}}]}, {CMYKColor[0.35, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{2.7226441186718153, 2.479055835144598}, {2.9374999999999987, \
2.5364529859628777}, {3.381467841692001, 2.283369148915069}, 
     {3.1423861567046165, 2.2583039834915453}}]}, {CMYKColor[0.35, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{2.9374999999999987, 2.5364529859628777}, {3.1277719321537134, \
2.5712732770958864}, {3.5931936453512026, 2.284543605895154}, 
     {3.381467841692001, 2.283369148915069}}]}, {CMYKColor[0.35, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{3.1277719321537134, 2.5712732770958864}, {3.2851441186718153, \
2.589176886629936}, {3.7683101340891882, 2.2706462108209022}, 
     {3.5931936453512026, 2.284543605895154}}]}, {CMYKColor[0.35, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{3.2851441186718153, 2.589176886629936}, {3.4027386398479256, \
2.5962550390555554}, {3.899163877045962, 2.251331326578102}, 
     {3.7683101340891882, 2.2706462108209022}}]}, {CMYKColor[0.35, 0.5, \
0.975, 0.1], 
   Polygon[{{3.4027386398479256, 2.5962550390555554}, {3.475416050825531, \
2.5979598975817515}, {3.98003593774839, 2.235484296800204}, 
     {3.899163877045962, 2.251331326578102}}]}, {CMYKColor[0.35, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{3.475416050825531, 2.5979598975817515}, {3.4999999999999996, \
2.598076211353316}, {4.007391819076574, 2.229434476432184}, 
     {3.98003593774839, 2.235484296800204}}]}, {CMYKColor[0.3833333333333333, \
0.5, 0.008333333333333333, 0.1], 
   Polygon[{{4.007391819076574, 2.229434476432184}, {3.98003593774839, \
2.235484296800204}, {4.397402461894532, 1.7786275248098211}, 
     {4.4270509831248415, 1.763355756877421}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{3.98003593774839, 2.235484296800204}, {3.8991638770459622, \
2.251331326578102}, {4.309752680850759, 1.8202053857959228}, 
     {4.397402461894532, 1.7786275248098211}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{3.8991638770459622, 2.251331326578102}, {3.768310134089188, \
2.270646210820903}, {4.167932356015447, 1.8768892930626264}, 
     {4.309752680850759, 1.8202053857959228}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{3.768310134089188, 2.270646210820903}, {3.593193645351204, \
2.284543605895154}, {3.9781397161133216, 1.9339672857886054}, 
     {4.167932356015447, 1.8768892930626264}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{3.593193645351204, 2.284543605895154}, {3.381467841692003, \
2.283369148915068}, {3.748669610234237, 1.976615915035449}, 
     {3.9781397161133216, 1.9339672857886054}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{3.381467841692003, 2.283369148915068}, {3.1423861567046165, \
2.2583039834915453}, {3.489550983124842, 1.99216913656241}, 
     {3.748669610234237, 1.976615915035449}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{3.1423861567046165, 2.2583039834915453}, {2.886397607264205, \
2.202570463435661}, {3.2121085621789436, 1.9712852585698504}, 
     {3.489550983124842, 1.99216913656241}}]}, {CMYKColor[0.3833333333333333, \
0.5, 0.125, 0.1], 
   Polygon[{{2.886397607264205, 2.202570463435661}, {2.624690121350657, \
2.112263515546569}, {2.928467912508319, 1.9084543807995193}, 
     {3.2121085621789436, 1.9712852585698504}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{2.624690121350657, 2.112263515546569}, {2.3687015719102447, \
1.9869545564435858}, {2.6510254915624207, 1.802245636601361}, 
     {2.928467912508319, 1.9084543807995193}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.3687015719102447, 1.9869545564435858}, {2.129619886922859, \
1.83026852905604}, {2.391906864453026, 1.65558951844325}, 
     {2.6510254915624207, 1.802245636601361}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{2.129619886922859, 1.83026852905604}, {1.9178940832636575, \
1.6506863454327518}, {2.162436758573941, 1.4764049667388985}, 
     {2.391906864453026, 1.65558951844325}}]}, {CMYKColor[0.3833333333333333, \
0.5, 0.19166666666666665, 0.1], 
   Polygon[{{1.9178940832636575, 1.6506863454327518}, {1.7427775945256727, \
1.4628718195622261}, {1.9726441186718153, 1.2790742990138144}, 
     {2.162436758573941, 1.4764049667388985}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.7427775945256727, 1.4628718195622261}, {1.6119238515688996, \
1.2895708590441468}, {1.8308237938365037, 1.0875191232355925}, 
     {1.9726441186718153, 1.2790742990138144}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{1.6119238515688996, 1.2895708590441468}, {1.5310517908664711, \
1.162354288726182}, {1.7431740127927302, 0.9393665425693404}, 
     {1.8308237938365037, 1.0875191232355925}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.5310517908664711, 1.162354288726182}, {1.503695909538287, \
1.1147172382160917}, {1.713525491562421, 0.8816778784387097}, 
     {1.7431740127927302, 0.9393665425693404}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.503695909538287, 1.1147172382160917}, {1.5310517908664711, \
1.1623542887261817}, {1.7431740127927302, 0.9393665425693399}, 
     {1.713525491562421, 0.8816778784387097}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{1.5310517908664711, 1.1623542887261817}, {1.6119238515688992, \
1.2895708590441464}, {1.8308237938365037, 1.0875191232355916}, 
     {1.7431740127927302, 0.9393665425693399}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.6119238515688992, 1.2895708590441464}, {1.742777594525673, \
1.4628718195622257}, {1.9726441186718155, 1.2790742990138138}, 
     {1.8308237938365037, 1.0875191232355916}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.742777594525673, 1.4628718195622257}, {1.9178940832636566, \
1.6506863454327514}, {2.16243675857394, 1.4764049667388985}, 
     {1.9726441186718155, 1.2790742990138138}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{1.9178940832636566, 1.6506863454327514}, {2.129619886922858, \
1.8302685290560394}, {2.3919068644530252, 1.6555895184432492}, 
     {2.16243675857394, 1.4764049667388985}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.129619886922858, 1.8302685290560394}, {2.368701571910244, \
1.9869545564435858}, {2.6510254915624203, 1.8022456366013613}, 
     {2.3919068644530252, 1.6555895184432492}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.368701571910244, 1.9869545564435858}, {2.624690121350656, \
2.112263515546568}, {2.928467912508318, 1.9084543807995193}, 
     {2.6510254915624203, 1.8022456366013613}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{2.624690121350656, 2.112263515546568}, {2.8863976072642035, \
2.202570463435661}, {3.2121085621789423, 1.97128525856985}, 
     {2.928467912508318, 1.9084543807995193}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{2.8863976072642035, 2.202570463435661}, {3.1423861567046165, \
2.258303983491545}, {3.4895509831248415, 1.99216913656241}, 
     {3.2121085621789423, 1.97128525856985}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{3.1423861567046165, 2.258303983491545}, {3.3814678416920017, \
2.2833691489150683}, {3.748669610234236, 1.976615915035449}, 
     {3.4895509831248415, 1.99216913656241}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{3.3814678416920017, 2.2833691489150683}, {3.593193645351204, \
2.284543605895154}, {3.9781397161133216, 1.9339672857886054}, 
     {3.748669610234236, 1.976615915035449}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{3.593193645351204, 2.284543605895154}, {3.768310134089188, \
2.270646210820903}, {4.167932356015447, 1.8768892930626264}, 
     {3.9781397161133216, 1.9339672857886054}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{3.768310134089188, 2.270646210820903}, {3.899163877045962, \
2.251331326578102}, {4.3097526808507585, 1.8202053857959228}, 
     {4.167932356015447, 1.8768892930626264}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{3.899163877045962, 2.251331326578102}, {3.98003593774839, \
2.235484296800204}, {4.397402461894532, 1.7786275248098211}, 
     {4.3097526808507585, 1.8202053857959228}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{3.98003593774839, 2.235484296800204}, {4.007391819076574, \
2.229434476432184}, {4.4270509831248415, 1.763355756877421}, 
     {4.397402461894532, 1.7786275248098211}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{4.007391819076574, 2.229434476432184}, {3.9800359377483905, \
2.235484296800204}, {4.397402461894533, 1.7786275248098191}, 
     {4.4270509831248415, 1.763355756877421}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{3.9800359377483905, 2.235484296800204}, {3.8991638770459622, \
2.251331326578102}, {4.309752680850759, 1.8202053857959217}, 
     {4.397402461894533, 1.7786275248098191}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{3.8991638770459622, 2.251331326578102}, {3.7683101340891887, \
2.2706462108209022}, {4.167932356015448, 1.8768892930626255}, 
     {4.309752680850759, 1.8202053857959217}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{3.7683101340891887, 2.2706462108209022}, {3.5931936453512052, \
2.284543605895154}, {3.9781397161133234, 1.9339672857886037}, 
     {4.167932356015448, 1.8768892930626255}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{3.5931936453512052, 2.284543605895154}, {3.3814678416920034, \
2.2833691489150687}, {3.7486696102342374, 1.976615915035449}, 
     {3.9781397161133234, 1.9339672857886037}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{3.3814678416920034, 2.2833691489150687}, {3.1423861567046174, \
2.2583039834915453}, {3.489550983124843, 1.9921691365624095}, 
     {3.7486696102342374, 1.976615915035449}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{3.1423861567046174, 2.2583039834915453}, {2.8863976072642057, \
2.202570463435661}, {3.212108562178945, 1.9712852585698495}, 
     {3.489550983124843, 1.9921691365624095}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{2.8863976072642057, 2.202570463435661}, {2.6246901213506577, \
2.112263515546569}, {2.9284679125083204, 1.9084543807995193}, 
     {3.212108562178945, 1.9712852585698495}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{2.6246901213506577, 2.112263515546569}, {2.368701571910245, \
1.9869545564435862}, {2.6510254915624216, 1.8022456366013608}, 
     {2.9284679125083204, 1.9084543807995193}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.368701571910245, 1.9869545564435862}, {2.12961988692286, \
1.8302685290560408}, {2.3919068644530275, 1.6555895184432503}, 
     {2.6510254915624216, 1.8022456366013608}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{2.12961988692286, 1.8302685290560408}, {1.9178940832636582, \
1.6506863454327532}, {2.162436758573942, 1.4764049667388996}, 
     {2.3919068644530275, 1.6555895184432503}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{1.9178940832636582, 1.6506863454327532}, {1.7427775945256732, \
1.4628718195622263}, {1.9726441186718158, 1.2790742990138144}, 
     {2.162436758573942, 1.4764049667388996}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.7427775945256732, 1.4628718195622263}, {1.6119238515689, \
1.2895708590441473}, {1.8308237938365044, 1.0875191232355932}, 
     {1.9726441186718158, 1.2790742990138144}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{1.6119238515689, 1.2895708590441473}, {1.5310517908664716, \
1.1623542887261822}, {1.7431740127927307, 0.9393665425693408}, 
     {1.8308237938365044, 1.0875191232355932}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.5310517908664716, 1.1623542887261822}, {1.503695909538287, \
1.1147172382160917}, {1.713525491562421, 0.8816778784387097}, 
     {1.7431740127927307, 0.9393665425693408}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.503695909538287, 1.1147172382160917}, {1.531051790866471, \
1.162354288726181}, {1.74317401279273, 0.9393665425693394}, 
     {1.713525491562421, 0.8816778784387097}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{1.531051790866471, 1.162354288726181}, {1.6119238515688985, \
1.2895708590441455}, {1.8308237938365028, 1.087519123235591}, 
     {1.74317401279273, 0.9393665425693394}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.6119238515688985, 1.2895708590441455}, {1.7427775945256727, \
1.4628718195622255}, {1.9726441186718153, 1.2790742990138133}, 
     {1.8308237938365028, 1.087519123235591}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.7427775945256727, 1.4628718195622255}, {1.917894083263656, \
1.6506863454327507}, {2.1624367585739397, 1.4764049667388974}, 
     {1.9726441186718153, 1.2790742990138133}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{1.917894083263656, 1.6506863454327507}, {2.129619886922857, \
1.830268529056039}, {2.3919068644530244, 1.655589518443248}, 
     {2.1624367585739397, 1.4764049667388974}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.129619886922857, 1.830268529056039}, {2.368701571910244, \
1.9869545564435853}, {2.6510254915624203, 1.8022456366013608}, 
     {2.3919068644530244, 1.655589518443248}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.368701571910244, 1.9869545564435853}, {2.6246901213506555, \
2.1122635155465685}, {2.9284679125083177, 1.9084543807995193}, 
     {2.6510254915624203, 1.8022456366013608}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{2.6246901213506555, 2.1122635155465685}, {2.886397607264202, \
2.2025704634356607}, {3.212108562178941, 1.971285258569849}, 
     {2.9284679125083177, 1.9084543807995193}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{2.886397607264202, 2.2025704634356607}, {3.1423861567046165, \
2.2583039834915453}, {3.489550983124842, 1.992169136562409}, 
     {3.212108562178941, 1.971285258569849}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{3.1423861567046165, 2.2583039834915453}, {3.381467841692001, \
2.283369148915069}, {3.748669610234235, 1.9766159150354499}, 
     {3.489550983124842, 1.992169136562409}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{3.381467841692001, 2.283369148915069}, {3.5931936453512026, \
2.284543605895154}, {3.9781397161133203, 1.9339672857886054}, 
     {3.748669610234235, 1.9766159150354499}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{3.5931936453512026, 2.284543605895154}, {3.7683101340891882, \
2.2706462108209022}, {4.167932356015447, 1.8768892930626275}, 
     {3.9781397161133203, 1.9339672857886054}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{3.7683101340891882, 2.2706462108209022}, {3.899163877045962, \
2.251331326578102}, {4.309752680850759, 1.8202053857959208}, 
     {4.167932356015447, 1.8768892930626275}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{3.899163877045962, 2.251331326578102}, {3.98003593774839, \
2.235484296800204}, {4.397402461894532, 1.7786275248098211}, 
     {4.309752680850759, 1.8202053857959208}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{3.98003593774839, 2.235484296800204}, {4.007391819076574, \
2.229434476432184}, {4.4270509831248415, 1.763355756877421}, 
     {4.397402461894532, 1.7786275248098211}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{4.4270509831248415, 1.763355756877421}, {4.397402461894532, \
1.7786275248098211}, {4.709274703411987, 1.251297555701461}, 
     {4.740636372927802, 1.220209929227404}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{4.397402461894532, 1.7786275248098211}, {4.309752680850759, \
1.8202053857959228}, {4.616560350312374, 1.334684931108052}, 
     {4.709274703411987, 1.251297555701461}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{4.309752680850759, 1.8202053857959228}, {4.167932356015447, \
1.8768892930626264}, {4.466545375752238, 1.4470248504530114}, 
     {4.616560350312374, 1.334684931108052}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{4.167932356015447, 1.8768892930626264}, {3.9781397161133216, \
1.9339672857886054}, {4.265786153971575, 1.5625819810819581}, 
     {4.466545375752238, 1.4470248504530114}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{3.9781397161133216, 1.9339672857886054}, {3.748669610234237, \
1.976615915035449}, {4.023056826311827, 1.6596693760099304}, 
     {4.265786153971575, 1.5625819810819581}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{3.748669610234237, 1.976615915035449}, {3.489550983124842, \
1.99216913656241}, {3.748965829136264, 1.7222389198769967}, 
     {4.023056826311827, 1.6596693760099304}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{3.489550983124842, 1.99216913656241}, {3.2121085621789436, \
1.9712852585698504}, {3.455492254255987, 1.7395717696563653}, 
     {3.748965829136264, 1.7222389198769967}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{3.2121085621789436, 1.9712852585698504}, {2.928467912508319, \
1.9084543807995193}, {3.1554623051357167, 1.705691841463223}, 
     {3.455492254255987, 1.7395717696563653}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{2.928467912508319, 1.9084543807995193}, {2.6510254915624207, \
1.802245636601361}, {2.8619887302554394, 1.6189603147994474}, 
     {3.1554623051357167, 1.705691841463223}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.6510254915624207, 1.802245636601361}, {2.391906864453026, \
1.65558951844325}, {2.5878977330798767, 1.4819447816621802}, 
     {2.8619887302554394, 1.6189603147994474}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{2.391906864453026, 1.65558951844325}, {2.162436758573941, \
1.4764049667388985}, {2.345168405420128, 1.3017122836390165}, 
     {2.5878977330798767, 1.4819447816621802}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{2.162436758573941, 1.4764049667388985}, {1.9726441186718153, \
1.2790742990138144}, {2.144409183639464, 1.0910840571723013}, 
     {2.345168405420128, 1.3017122836390165}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.9726441186718153, 1.2790742990138144}, {1.8308237938365037, \
1.0875191232355925}, {1.9943942090793294, 0.8724918816600732}, 
     {2.144409183639464, 1.0910840571723013}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{1.8308237938365037, 1.0875191232355925}, {1.7431740127927302, \
0.9393665425693404}, {1.9016798559797152, 0.6880869119781089}, 
     {1.9943942090793294, 0.8724918816600732}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.7431740127927302, 0.9393665425693404}, {1.713525491562421, \
0.8816778784387097}, {1.8703181864639011, 0.6101049646137006}, 
     {1.9016798559797152, 0.6880869119781089}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.713525491562421, 0.8816778784387097}, {1.7431740127927302, \
0.9393665425693399}, {1.9016798559797154, 0.6880869119781076}, 
     {1.8703181864639011, 0.6101049646137006}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{1.7431740127927302, 0.9393665425693399}, {1.8308237938365037, \
1.0875191232355916}, {1.9943942090793292, 0.8724918816600722}, 
     {1.9016798559797154, 0.6880869119781076}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.8308237938365037, 1.0875191232355916}, {1.9726441186718155, \
1.2790742990138138}, {2.144409183639464, 1.0910840571723004}, 
     {1.9943942090793292, 0.8724918816600722}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.9726441186718155, 1.2790742990138138}, {2.16243675857394, \
1.4764049667388985}, {2.345168405420127, 1.3017122836390158}, 
     {2.144409183639464, 1.0910840571723004}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{2.16243675857394, 1.4764049667388985}, {2.3919068644530252, \
1.6555895184432492}, {2.5878977330798754, 1.48194478166218}, 
     {2.345168405420127, 1.3017122836390158}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.3919068644530252, 1.6555895184432492}, {2.6510254915624203, \
1.8022456366013613}, {2.8619887302554385, 1.6189603147994478}, 
     {2.5878977330798754, 1.48194478166218}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.6510254915624203, 1.8022456366013613}, {2.928467912508318, \
1.9084543807995193}, {3.155462305135716, 1.7056918414632214}, 
     {2.8619887302554385, 1.6189603147994478}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{2.928467912508318, 1.9084543807995193}, {3.2121085621789423, \
1.97128525856985}, {3.4554922542559856, 1.7395717696563653}, 
     {3.155462305135716, 1.7056918414632214}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{3.2121085621789423, 1.97128525856985}, {3.4895509831248415, \
1.99216913656241}, {3.7489658291362637, 1.7222389198769967}, 
     {3.4554922542559856, 1.7395717696563653}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{3.4895509831248415, 1.99216913656241}, {3.748669610234236, \
1.976615915035449}, {4.023056826311826, 1.6596693760099326}, 
     {3.7489658291362637, 1.7222389198769967}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{3.748669610234236, 1.976615915035449}, {3.9781397161133216, \
1.9339672857886054}, {4.265786153971575, 1.5625819810819581}, 
     {4.023056826311826, 1.6596693760099326}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{3.9781397161133216, 1.9339672857886054}, {4.167932356015447, \
1.8768892930626264}, {4.466545375752238, 1.4470248504530114}, 
     {4.265786153971575, 1.5625819810819581}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{4.167932356015447, 1.8768892930626264}, {4.3097526808507585, \
1.8202053857959228}, {4.616560350312374, 1.3346849311080506}, 
     {4.466545375752238, 1.4470248504530114}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{4.3097526808507585, 1.8202053857959228}, {4.397402461894532, \
1.7786275248098211}, {4.709274703411987, 1.251297555701461}, 
     {4.616560350312374, 1.3346849311080506}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{4.397402461894532, 1.7786275248098211}, {4.4270509831248415, \
1.763355756877421}, {4.740636372927802, 1.220209929227404}, 
     {4.709274703411987, 1.251297555701461}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{4.4270509831248415, 1.763355756877421}, {4.397402461894533, \
1.7786275248098191}, {4.709274703411988, 1.251297555701461}, 
     {4.740636372927802, 1.220209929227404}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{4.397402461894533, 1.7786275248098191}, {4.309752680850759, \
1.8202053857959217}, {4.616560350312374, 1.334684931108052}, 
     {4.709274703411988, 1.251297555701461}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{4.309752680850759, 1.8202053857959217}, {4.167932356015448, \
1.8768892930626255}, {4.46654537575224, 1.447024850453009}, 
     {4.616560350312374, 1.334684931108052}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{4.167932356015448, 1.8768892930626255}, {3.9781397161133234, \
1.9339672857886037}, {4.265786153971577, 1.562581981081957}, 
     {4.46654537575224, 1.447024850453009}}]}, {CMYKColor[0.4166666666666667, \
0.5, 0.575, 0.1], 
   Polygon[{{3.9781397161133234, 1.9339672857886037}, {3.7486696102342374, \
1.976615915035449}, {4.023056826311828, 1.6596693760099304}, 
     {4.265786153971577, 1.562581981081957}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{3.7486696102342374, 1.976615915035449}, {3.489550983124843, \
1.9921691365624095}, {3.7489658291362646, 1.7222389198769967}, 
     {4.023056826311828, 1.6596693760099304}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{3.489550983124843, 1.9921691365624095}, {3.212108562178945, \
1.9712852585698495}, {3.4554922542559883, 1.7395717696563648}, 
     {3.7489658291362646, 1.7222389198769967}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{3.212108562178945, 1.9712852585698495}, {2.9284679125083204, \
1.9084543807995193}, {3.1554623051357176, 1.705691841463223}, 
     {3.4554922542559883, 1.7395717696563648}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{2.9284679125083204, 1.9084543807995193}, {2.6510254915624216, \
1.8022456366013608}, {2.86198873025544, 1.6189603147994478}, 
     {3.1554623051357176, 1.705691841463223}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.6510254915624216, 1.8022456366013608}, {2.3919068644530275, \
1.6555895184432503}, {2.5878977330798776, 1.481944781662181}, 
     {2.86198873025544, 1.6189603147994478}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{2.3919068644530275, 1.6555895184432503}, {2.162436758573942, \
1.4764049667388996}, {2.3451684054201287, 1.3017122836390178}, 
     {2.5878977330798776, 1.481944781662181}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.162436758573942, 1.4764049667388996}, {1.9726441186718158, \
1.2790742990138144}, {2.1444091836394645, 1.0910840571723013}, 
     {2.3451684054201287, 1.3017122836390178}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.9726441186718158, 1.2790742990138144}, {1.8308237938365044, \
1.0875191232355932}, {1.99439420907933, 0.872491881660074}, 
     {2.1444091836394645, 1.0910840571723013}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{1.8308237938365044, 1.0875191232355932}, {1.7431740127927307, \
0.9393665425693408}, {1.901679855979716, 0.6880869119781089}, 
     {1.99439420907933, 0.872491881660074}}]}, {CMYKColor[0.4166666666666667, \
0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.7431740127927307, 0.9393665425693408}, {1.713525491562421, \
0.8816778784387097}, {1.8703181864639011, 0.6101049646137006}, 
     {1.901679855979716, 0.6880869119781089}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.713525491562421, 0.8816778784387097}, {1.74317401279273, \
0.9393665425693394}, {1.901679855979715, 0.6880869119781076}, 
     {1.8703181864639011, 0.6101049646137006}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.775, 0.1], 
   Polygon[{{1.74317401279273, 0.9393665425693394}, {1.8308237938365028, \
1.087519123235591}, {1.9943942090793283, 0.8724918816600712}, 
     {1.901679855979715, 0.6880869119781076}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.8308237938365028, 1.087519123235591}, {1.9726441186718153, \
1.2790742990138133}, {2.1444091836394636, 1.0910840571723008}, 
     {1.9943942090793283, 0.8724918816600712}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.9726441186718153, 1.2790742990138133}, {2.1624367585739397, \
1.4764049667388974}, {2.345168405420126, 1.3017122836390158}, 
     {2.1444091836394636, 1.0910840571723008}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{2.1624367585739397, 1.4764049667388974}, {2.3919068644530244, \
1.655589518443248}, {2.5878977330798745, 1.4819447816621785}, 
     {2.345168405420126, 1.3017122836390158}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.3919068644530244, 1.655589518443248}, {2.6510254915624203, \
1.8022456366013608}, {2.8619887302554385, 1.6189603147994474}, 
     {2.5878977330798745, 1.4819447816621785}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.6510254915624203, 1.8022456366013608}, {2.9284679125083177, \
1.9084543807995193}, {3.155462305135715, 1.7056918414632225}, 
     {2.8619887302554385, 1.6189603147994474}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{2.9284679125083177, 1.9084543807995193}, {3.212108562178941, \
1.971285258569849}, {3.455492254255984, 1.7395717696563653}, 
     {3.155462305135715, 1.7056918414632225}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{3.212108562178941, 1.971285258569849}, {3.489550983124842, \
1.992169136562409}, {3.748965829136264, 1.7222389198769967}, 
     {3.455492254255984, 1.7395717696563653}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{3.489550983124842, 1.992169136562409}, {3.748669610234235, \
1.9766159150354499}, {4.023056826311826, 1.6596693760099326}, 
     {3.748965829136264, 1.7222389198769967}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{3.748669610234235, 1.9766159150354499}, {3.9781397161133203, \
1.9339672857886054}, {4.265786153971574, 1.5625819810819614}, 
     {4.023056826311826, 1.6596693760099326}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{3.9781397161133203, 1.9339672857886054}, {4.167932356015447, \
1.8768892930626275}, {4.466545375752238, 1.4470248504530128}, 
     {4.265786153971574, 1.5625819810819614}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{4.167932356015447, 1.8768892930626275}, {4.309752680850759, \
1.8202053857959208}, {4.616560350312374, 1.3346849311080506}, 
     {4.466545375752238, 1.4470248504530128}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{4.309752680850759, 1.8202053857959208}, {4.397402461894532, \
1.7786275248098211}, {4.709274703411988, 1.251297555701458}, 
     {4.616560350312374, 1.3346849311080506}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{4.397402461894532, 1.7786275248098211}, {4.4270509831248415, \
1.763355756877421}, {4.740636372927802, 1.220209929227404}, 
     {4.709274703411988, 1.251297555701458}}]}, {CMYKColor[0.45, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{4.740636372927802, 1.220209929227404}, {4.709274703411987, \
1.251297555701461}, {4.902022348817391, 0.693545187289426}, 
     {4.934442802201416, 0.6237350724532809}}]}, {CMYKColor[0.45, 0.5, 0.025, \
0.1], 
   Polygon[{{4.709274703411987, 1.251297555701461}, {4.616560350312374, \
1.334684931108052}, {4.806177918048795, 0.8605642566348376}, 
     {4.902022348817391, 0.693545187289426}}]}, {CMYKColor[0.45, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{4.616560350312374, 1.334684931108052}, {4.466545375752238, \
1.4470248504530114}, {4.651098371432819, 1.0590770192391419}, 
     {4.806177918048795, 0.8605642566348376}}]}, {CMYKColor[0.45, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{4.466545375752238, 1.4470248504530114}, {4.265786153971575, \
1.5625819810819581}, {4.44356142931081, 1.2475429541754062}, 
     {4.651098371432819, 1.0590770192391419}}]}, {CMYKColor[0.45, 0.5, 0.075, \
0.1], 
   Polygon[{{4.265786153971575, 1.5625819810819581}, {4.023056826311827, \
1.6596693760099304}, {4.19263745192624, 1.4024710170213415}, 
     {4.44356142931081, 1.2475429541754062}}]}, {CMYKColor[0.45, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{4.023056826311827, 1.6596693760099304}, {3.748965829136264, \
1.7222389198769967}, {3.9092930211576427, 1.5096856680207968}, 
     {4.19263745192624, 1.4024710170213415}}]}, {CMYKColor[0.45, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{3.748965829136264, 1.7222389198769967}, {3.455492254255987, \
1.7395717696563653}, {3.605911648267038, 1.560594218929799}, 
     {3.9092930211576427, 1.5096856680207968}}]}, {CMYKColor[0.45, 0.5, \
0.125, 0.1], 
   Polygon[{{3.455492254255987, 1.7395717696563653}, {3.1554623051357167, \
1.705691841463223}, {3.2957525550350866, 1.5507915961279441}, 
     {3.605911648267038, 1.560594218929799}}]}, {CMYKColor[0.45, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{3.1554623051357167, 1.705691841463223}, {2.8619887302554394, \
1.6189603147994474}, {2.9923711821444816, 1.4795217391705875}, 
     {3.2957525550350866, 1.5507915961279441}}]}, {CMYKColor[0.45, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{2.8619887302554394, 1.6189603147994474}, {2.5878977330798767, \
1.4819447816621802}, {2.7090267513758857, 1.3494565251821808}, 
     {2.9923711821444816, 1.4795217391705875}}]}, {CMYKColor[0.45, 0.5, \
0.175, 0.1], 
   Polygon[{{2.5878977330798767, 1.4819447816621802}, {2.345168405420128, \
1.3017122836390165}, {2.458102773991314, 1.1666712321091814}, 
     {2.7090267513758857, 1.3494565251821808}}]}, {CMYKColor[0.45, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{2.345168405420128, 1.3017122836390165}, {2.144409183639464, \
1.0910840571723013}, {2.2505658318693045, 0.9410557119019621}, 
     {2.458102773991314, 1.1666712321091814}}]}, {CMYKColor[0.45, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{2.144409183639464, 1.0910840571723013}, {1.9943942090793294, \
0.8724918816600732}, {2.0954862852533296, 0.688485888369732}, 
     {2.2505658318693045, 0.9410557119019621}}]}, {CMYKColor[0.45, 0.5, \
0.225, 0.1], 
   Polygon[{{1.9943942090793294, 0.8724918816600732}, {1.9016798559797152, \
0.6880869119781089}, {1.999641854484733, 0.442263528432697}, 
     {2.0954862852533296, 0.688485888369732}}]}, {CMYKColor[0.45, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{1.9016798559797152, 0.6880869119781089}, {1.8703181864639011, \
0.6101049646137006}, {1.9672214011007083, 0.311867536226639}, 
     {1.999641854484733, 0.442263528432697}}]}, {CMYKColor[0.45, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{1.8703181864639011, 0.6101049646137006}, {1.9016798559797154, \
0.6880869119781076}, {1.999641854484733, 0.442263528432696}, 
     {1.9672214011007083, 0.311867536226639}}]}, {CMYKColor[0.45, 0.5, 0.275, \
0.1], 
   Polygon[{{1.9016798559797154, 0.6880869119781076}, {1.9943942090793292, \
0.8724918816600722}, {2.095486285253329, 0.6884858883697308}, 
     {1.999641854484733, 0.442263528432696}}]}, {CMYKColor[0.45, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{1.9943942090793292, 0.8724918816600722}, {2.144409183639464, \
1.0910840571723004}, {2.250565831869305, 0.9410557119019607}, 
     {2.095486285253329, 0.6884858883697308}}]}, {CMYKColor[0.45, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{2.144409183639464, 1.0910840571723004}, {2.345168405420127, \
1.3017122836390158}, {2.458102773991313, 1.166671232109181}, 
     {2.250565831869305, 0.9410557119019607}}]}, {CMYKColor[0.45, 0.5, 0.325, \
0.1], 
   Polygon[{{2.345168405420127, 1.3017122836390158}, {2.5878977330798754, \
1.48194478166218}, {2.7090267513758843, 1.3494565251821808}, 
     {2.458102773991313, 1.166671232109181}}]}, {CMYKColor[0.45, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{2.5878977330798754, 1.48194478166218}, {2.8619887302554385, \
1.6189603147994478}, {2.992371182144481, 1.479521739170588}, 
     {2.7090267513758843, 1.3494565251821808}}]}, {CMYKColor[0.45, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{2.8619887302554385, 1.6189603147994478}, {3.155462305135716, \
1.7056918414632214}, {3.2957525550350857, 1.5507915961279435}, 
     {2.992371182144481, 1.479521739170588}}]}, {CMYKColor[0.45, 0.5, 0.375, \
0.1], 
   Polygon[{{3.155462305135716, 1.7056918414632214}, {3.4554922542559856, \
1.7395717696563653}, {3.6059116482670364, 1.5605942189298}, 
     {3.2957525550350857, 1.5507915961279435}}]}, {CMYKColor[0.45, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{3.4554922542559856, 1.7395717696563653}, {3.7489658291362637, \
1.7222389198769967}, {3.9092930211576427, 1.5096856680207968}, 
     {3.6059116482670364, 1.5605942189298}}]}, {CMYKColor[0.45, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{3.7489658291362637, 1.7222389198769967}, {4.023056826311826, \
1.6596693760099326}, {4.192637451926238, 1.4024710170213415}, 
     {3.9092930211576427, 1.5096856680207968}}]}, {CMYKColor[0.45, 0.5, \
0.425, 0.1], 
   Polygon[{{4.023056826311826, 1.6596693760099326}, {4.265786153971575, \
1.5625819810819581}, {4.443561429310811, 1.247542954175402}, 
     {4.192637451926238, 1.4024710170213415}}]}, {CMYKColor[0.45, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{4.265786153971575, 1.5625819810819581}, {4.466545375752238, \
1.4470248504530114}, {4.651098371432819, 1.0590770192391419}, 
     {4.443561429310811, 1.247542954175402}}]}, {CMYKColor[0.45, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{4.466545375752238, 1.4470248504530114}, {4.616560350312374, \
1.3346849311080506}, {4.806177918048795, 0.8605642566348355}, 
     {4.651098371432819, 1.0590770192391419}}]}, {CMYKColor[0.45, 0.5, 0.475, \
0.1], 
   Polygon[{{4.616560350312374, 1.3346849311080506}, {4.709274703411987, \
1.251297555701461}, {4.902022348817391, 0.693545187289426}, 
     {4.806177918048795, 0.8605642566348355}}]}, {CMYKColor[0.45, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{4.709274703411987, 1.251297555701461}, {4.740636372927802, \
1.220209929227404}, {4.934442802201416, 0.6237350724532809}, 
     {4.902022348817391, 0.693545187289426}}]}, {CMYKColor[0.45, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{4.740636372927802, 1.220209929227404}, {4.709274703411988, \
1.251297555701461}, {4.9020223488173915, 0.6935451872894235}, 
     {4.934442802201416, 0.6237350724532809}}]}, {CMYKColor[0.45, 0.5, 0.525, \
0.1], 
   Polygon[{{4.709274703411988, 1.251297555701461}, {4.616560350312374, \
1.334684931108052}, {4.806177918048795, 0.8605642566348376}, 
     {4.9020223488173915, 0.6935451872894235}}]}, {CMYKColor[0.45, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{4.616560350312374, 1.334684931108052}, {4.46654537575224, \
1.447024850453009}, {4.651098371432821, 1.0590770192391368}, 
     {4.806177918048795, 0.8605642566348376}}]}, {CMYKColor[0.45, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{4.46654537575224, 1.447024850453009}, {4.265786153971577, \
1.562581981081957}, {4.443561429310812, 1.247542954175402}, 
     {4.651098371432821, 1.0590770192391368}}]}, {CMYKColor[0.45, 0.5, 0.575, \
0.1], 
   Polygon[{{4.265786153971577, 1.562581981081957}, {4.023056826311828, \
1.6596693760099304}, {4.19263745192624, 1.4024710170213426}, 
     {4.443561429310812, 1.247542954175402}}]}, {CMYKColor[0.45, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{4.023056826311828, 1.6596693760099304}, {3.7489658291362646, \
1.7222389198769967}, {3.9092930211576435, 1.5096856680207968}, 
     {4.19263745192624, 1.4024710170213426}}]}, {CMYKColor[0.45, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{3.7489658291362646, 1.7222389198769967}, {3.4554922542559883, \
1.7395717696563648}, {3.605911648267039, 1.560594218929799}, 
     {3.9092930211576435, 1.5096856680207968}}]}, {CMYKColor[0.45, 0.5, \
0.625, 0.1], 
   Polygon[{{3.4554922542559883, 1.7395717696563648}, {3.1554623051357176, \
1.705691841463223}, {3.2957525550350875, 1.5507915961279446}, 
     {3.605911648267039, 1.560594218929799}}]}, {CMYKColor[0.45, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{3.1554623051357176, 1.705691841463223}, {2.86198873025544, \
1.6189603147994478}, {2.992371182144482, 1.4795217391705875}, 
     {3.2957525550350875, 1.5507915961279446}}]}, {CMYKColor[0.45, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{2.86198873025544, 1.6189603147994478}, {2.5878977330798776, \
1.481944781662181}, {2.7090267513758866, 1.3494565251821808}, 
     {2.992371182144482, 1.4795217391705875}}]}, {CMYKColor[0.45, 0.5, 0.675, \
0.1], 
   Polygon[{{2.5878977330798776, 1.481944781662181}, {2.3451684054201287, \
1.3017122836390178}, {2.458102773991315, 1.1666712321091826}, 
     {2.7090267513758866, 1.3494565251821808}}]}, {CMYKColor[0.45, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{2.3451684054201287, 1.3017122836390178}, {2.1444091836394645, \
1.0910840571723013}, {2.250565831869305, 0.9410557119019621}, 
     {2.458102773991315, 1.1666712321091826}}]}, {CMYKColor[0.45, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{2.1444091836394645, 1.0910840571723013}, {1.99439420907933, \
0.872491881660074}, {2.09548628525333, 0.6884858883697327}, 
     {2.250565831869305, 0.9410557119019621}}]}, {CMYKColor[0.45, 0.5, 0.725, \
0.1], 
   Polygon[{{1.99439420907933, 0.872491881660074}, {1.901679855979716, \
0.6880869119781089}, {1.9996418544847336, 0.442263528432698}, 
     {2.09548628525333, 0.6884858883697327}}]}, {CMYKColor[0.45, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{1.901679855979716, 0.6880869119781089}, {1.8703181864639011, \
0.6101049646137006}, {1.9672214011007083, 0.311867536226639}, 
     {1.9996418544847336, 0.442263528432698}}]}, {CMYKColor[0.45, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{1.8703181864639011, 0.6101049646137006}, {1.901679855979715, \
0.6880869119781076}, {1.9996418544847328, 0.442263528432695}, 
     {1.9672214011007083, 0.311867536226639}}]}, {CMYKColor[0.45, 0.5, 0.775, \
0.1], 
   Polygon[{{1.901679855979715, 0.6880869119781076}, {1.9943942090793283, \
0.8724918816600712}, {2.0954862852533283, 0.6884858883697301}, 
     {1.9996418544847328, 0.442263528432695}}]}, {CMYKColor[0.45, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{1.9943942090793283, 0.8724918816600712}, {2.1444091836394636, \
1.0910840571723008}, {2.2505658318693045, 0.9410557119019607}, 
     {2.0954862852533283, 0.6884858883697301}}]}, {CMYKColor[0.45, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{2.1444091836394636, 1.0910840571723008}, {2.345168405420126, \
1.3017122836390158}, {2.458102773991312, 1.1666712321091806}, 
     {2.2505658318693045, 0.9410557119019607}}]}, {CMYKColor[0.45, 0.5, \
0.825, 0.1], 
   Polygon[{{2.345168405420126, 1.3017122836390158}, {2.5878977330798745, \
1.4819447816621785}, {2.709026751375883, 1.3494565251821795}, 
     {2.458102773991312, 1.1666712321091806}}]}, {CMYKColor[0.45, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{2.5878977330798745, 1.4819447816621785}, {2.8619887302554385, \
1.6189603147994474}, {2.992371182144481, 1.4795217391705868}, 
     {2.709026751375883, 1.3494565251821795}}]}, {CMYKColor[0.45, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{2.8619887302554385, 1.6189603147994474}, {3.155462305135715, \
1.7056918414632225}, {3.295752555035085, 1.5507915961279446}, 
     {2.992371182144481, 1.4795217391705868}}]}, {CMYKColor[0.45, 0.5, 0.875, \
0.1], 
   Polygon[{{3.155462305135715, 1.7056918414632225}, {3.455492254255984, \
1.7395717696563653}, {3.605911648267035, 1.560594218929799}, 
     {3.295752555035085, 1.5507915961279446}}]}, {CMYKColor[0.45, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{3.455492254255984, 1.7395717696563653}, {3.748965829136264, \
1.7222389198769967}, {3.9092930211576427, 1.5096856680207968}, 
     {3.605911648267035, 1.560594218929799}}]}, {CMYKColor[0.45, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{3.748965829136264, 1.7222389198769967}, {4.023056826311826, \
1.6596693760099326}, {4.192637451926238, 1.4024710170213415}, 
     {3.9092930211576427, 1.5096856680207968}}]}, {CMYKColor[0.45, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{4.023056826311826, 1.6596693760099326}, {4.265786153971574, \
1.5625819810819614}, {4.443561429310809, 1.2475429541754033}, 
     {4.192637451926238, 1.4024710170213415}}]}, {CMYKColor[0.45, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{4.265786153971574, 1.5625819810819614}, {4.466545375752238, \
1.4470248504530128}, {4.651098371432819, 1.0590770192391419}, 
     {4.443561429310809, 1.2475429541754033}}]}, {CMYKColor[0.45, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{4.466545375752238, 1.4470248504530128}, {4.616560350312374, \
1.3346849311080506}, {4.806177918048795, 0.8605642566348355}, 
     {4.651098371432819, 1.0590770192391419}}]}, {CMYKColor[0.45, 0.5, 0.975, \
0.1], 
   Polygon[{{4.616560350312374, 1.3346849311080506}, {4.709274703411988, \
1.251297555701458}, {4.9020223488173915, 0.6935451872894184}, 
     {4.806177918048795, 0.8605642566348355}}]}, {CMYKColor[0.45, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{4.709274703411988, 1.251297555701458}, {4.740636372927802, \
1.220209929227404}, {4.934442802201416, 0.6237350724532809}, 
     {4.9020223488173915, 0.6935451872894184}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{4.934442802201416, 0.6237350724532809}, {4.902022348817391, \
0.693545187289426}, {4.967221401100708, 0.3118675362266461}, {5., 0.}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.025, 0.1], \
Polygon[{{4.902022348817391, 0.693545187289426}, {4.806177918048795, \
0.8605642566348376}, 
     {4.870318186463902, 0.6101049646136962}, {4.967221401100708, \
0.3118675362266461}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{4.806177918048795, 0.8605642566348376}, {4.651098371432819, \
1.0590770192391419}, {4.713525491562421, 0.8816778784387095}, 
     {4.870318186463902, 0.6101049646136962}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{4.651098371432819, 1.0590770192391419}, {4.44356142931081, \
1.2475429541754062}, {4.503695909538287, 1.1147172382160924}, 
     {4.713525491562421, 0.8816778784387095}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.075, 0.1], 
   Polygon[{{4.44356142931081, 1.2475429541754062}, {4.19263745192624, \
1.4024710170213415}, {4.25, 1.2990381056766593}, 
     {4.503695909538287, 1.1147172382160924}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{4.19263745192624, 1.4024710170213415}, {3.9092930211576427, \
1.5096856680207968}, {3.963525491562421, 1.4265847744427318}, 
     {4.25, 1.2990381056766593}}]}, {CMYKColor[0.48333333333333334, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{3.9092930211576427, 1.5096856680207968}, {3.605911648267038, \
1.560594218929799}, {3.6567926949014806, 1.49178284305241}, 
     {3.963525491562421, 1.4265847744427318}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.125, 0.1], 
   Polygon[{{3.605911648267038, 1.560594218929799}, {3.2957525550350866, \
1.5507915961279441}, {3.3432073050985194, 1.4917828430524107}, 
     {3.6567926949014806, 1.49178284305241}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{3.2957525550350866, 1.5507915961279441}, {2.9923711821444816, \
1.4795217391705875}, {3.036474508437579, 1.4265847744427305}, 
     {3.3432073050985194, 1.4917828430524107}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.9923711821444816, 1.4795217391705875}, {2.7090267513758857, \
1.3494565251821808}, {2.75, 1.2990381056766587}, 
     {3.036474508437579, 1.4265847744427305}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.175, 0.1], 
   Polygon[{{2.7090267513758857, 1.3494565251821808}, {2.458102773991314, \
1.1666712321091814}, {2.496304090461713, 1.1147172382160917}, 
     {2.75, 1.2990381056766587}}]}, {CMYKColor[0.48333333333333334, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{2.458102773991314, 1.1666712321091814}, {2.2505658318693045, \
0.9410557119019621}, {2.286474508437579, 0.88167787843871}, 
     {2.496304090461713, 1.1147172382160917}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{2.2505658318693045, 0.9410557119019621}, {2.0954862852533296, \
0.688485888369732}, {2.1296818135360986, 0.6101049646137013}, 
     {2.286474508437579, 0.88167787843871}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.225, 0.1], 
   Polygon[{{2.0954862852533296, 0.688485888369732}, {1.999641854484733, \
0.442263528432697}, {2.0327785988992915, 0.31186753622664043}, 
     {2.1296818135360986, 0.6101049646137013}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.999641854484733, 0.442263528432697}, {1.9672214011007083, \
0.311867536226639}, {2., 0.}, 
     {2.0327785988992915, 0.31186753622664043}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.9672214011007083, 0.311867536226639}, {1.999641854484733, \
0.442263528432696}, {2.0327785988992915, 0.311867536226639}, {2., 0.}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.275, 0.1], \
Polygon[{{1.999641854484733, 0.442263528432696}, {2.095486285253329, \
0.6884858883697308}, 
     {2.1296818135360986, 0.6101049646136991}, {2.0327785988992915, \
0.311867536226639}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.2916666666666667, 0.1], \
Polygon[{{2.095486285253329, 0.6884858883697308}, 
     {2.250565831869305, 0.9410557119019607}, {2.286474508437579, \
0.8816778784387095}, {2.1296818135360986, 0.6101049646136991}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{2.250565831869305, 0.9410557119019607}, {2.458102773991313, \
1.166671232109181}, {2.496304090461712, 1.1147172382160913}, 
     {2.286474508437579, 0.8816778784387095}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.325, 0.1], 
   Polygon[{{2.458102773991313, 1.166671232109181}, {2.7090267513758843, \
1.3494565251821808}, {2.749999999999999, 1.299038105676658}, 
     {2.496304090461712, 1.1147172382160913}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.7090267513758843, 1.3494565251821808}, {2.992371182144481, \
1.479521739170588}, {3.0364745084375784, 1.4265847744427305}, 
     {2.749999999999999, 1.299038105676658}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.992371182144481, 1.479521739170588}, {3.2957525550350857, \
1.5507915961279435}, {3.3432073050985185, 1.4917828430524107}, 
     {3.0364745084375784, 1.4265847744427305}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.375, 0.1], 
   Polygon[{{3.2957525550350857, 1.5507915961279435}, {3.6059116482670364, \
1.5605942189298}, {3.656792694901479, 1.4917828430524112}, 
     {3.3432073050985185, 1.4917828430524107}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{3.6059116482670364, 1.5605942189298}, {3.9092930211576427, \
1.5096856680207968}, {3.963525491562421, 1.4265847744427305}, 
     {3.656792694901479, 1.4917828430524112}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{3.9092930211576427, 1.5096856680207968}, {4.192637451926238, \
1.4024710170213415}, {4.249999999999999, 1.299038105676658}, 
     {3.963525491562421, 1.4265847744427305}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.425, 0.1], 
   Polygon[{{4.192637451926238, 1.4024710170213415}, {4.443561429310811, \
1.247542954175402}, {4.503695909538286, 1.1147172382160955}, 
     {4.249999999999999, 1.299038105676658}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{4.443561429310811, 1.247542954175402}, {4.651098371432819, \
1.0590770192391419}, {4.713525491562421, 0.8816778784387115}, 
     {4.503695909538286, 1.1147172382160955}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{4.651098371432819, 1.0590770192391419}, {4.806177918048795, \
0.8605642566348355}, {4.870318186463901, 0.6101049646136991}, 
     {4.713525491562421, 0.8816778784387115}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.475, 0.1], 
   Polygon[{{4.806177918048795, 0.8605642566348355}, {4.902022348817391, \
0.693545187289426}, {4.967221401100708, 0.3118675362266461}, 
     {4.870318186463901, 0.6101049646136991}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{4.902022348817391, 0.693545187289426}, {4.934442802201416, \
0.6237350724532809}, {5., 0.}, {4.967221401100708, 0.3118675362266461}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{4.934442802201416, 0.6237350724532809}, 
     {4.9020223488173915, 0.6935451872894235}, {4.967221401100709, \
0.31186753622662905}, {5., 0.}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.525, 0.1], \
Polygon[{{4.9020223488173915, 0.6935451872894235}, {4.806177918048795, \
0.8605642566348376}, 
     {4.870318186463902, 0.6101049646136962}, {4.967221401100709, \
0.31186753622662905}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{4.806177918048795, 0.8605642566348376}, 
     {4.651098371432821, 1.0590770192391368}, {4.713525491562422, \
0.8816778784387075}, {4.870318186463902, 0.6101049646136962}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.5583333333333333, 0.1], \
Polygon[{{4.651098371432821, 1.0590770192391368}, 
     {4.443561429310812, 1.247542954175402}, {4.503695909538288, \
1.1147172382160924}, {4.713525491562422, 0.8816778784387075}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.575, 0.1], \
Polygon[{{4.443561429310812, 1.247542954175402}, {4.19263745192624, \
1.4024710170213426}, 
     {4.250000000000001, 1.299038105676658}, {4.503695909538288, \
1.1147172382160924}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{4.19263745192624, 1.4024710170213426}, {3.9092930211576435, \
1.5096856680207968}, {3.9635254915624225, 1.426584774442728}, 
     {4.250000000000001, 1.299038105676658}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{3.9092930211576435, 1.5096856680207968}, {3.605911648267039, \
1.560594218929799}, {3.656792694901482, 1.491782843052409}, 
     {3.9635254915624225, 1.426584774442728}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.625, 0.1], 
   Polygon[{{3.605911648267039, 1.560594218929799}, {3.2957525550350875, \
1.5507915961279446}, {3.3432073050985207, 1.49178284305241}, 
     {3.656792694901482, 1.491782843052409}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{3.2957525550350875, 1.5507915961279446}, {2.992371182144482, \
1.4795217391705875}, {3.0364745084375793, 1.4265847744427311}, 
     {3.3432073050985207, 1.49178284305241}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.992371182144482, 1.4795217391705875}, {2.7090267513758866, \
1.3494565251821808}, {2.7500000000000013, 1.2990381056766587}, 
     {3.0364745084375793, 1.4265847744427311}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.675, 0.1], 
   Polygon[{{2.7090267513758866, 1.3494565251821808}, {2.458102773991315, \
1.1666712321091826}, {2.496304090461714, 1.1147172382160933}, 
     {2.7500000000000013, 1.2990381056766587}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.458102773991315, 1.1666712321091826}, {2.250565831869305, \
0.9410557119019621}, {2.2864745084375793, 0.88167787843871}, 
     {2.496304090461714, 1.1147172382160933}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{2.250565831869305, 0.9410557119019621}, {2.09548628525333, \
0.6884858883697327}, {2.1296818135360995, 0.6101049646137006}, 
     {2.2864745084375793, 0.88167787843871}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.725, 0.1], 
   Polygon[{{2.09548628525333, 0.6884858883697327}, {1.9996418544847336, \
0.442263528432698}, {2.0327785988992924, 0.31186753622664043}, 
     {2.1296818135360995, 0.6101049646137006}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.9996418544847336, 0.442263528432698}, {1.9672214011007083, \
0.311867536226639}, {2., 0.}, 
     {2.0327785988992924, 0.31186753622664043}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.9672214011007083, 0.311867536226639}, {1.9996418544847328, \
0.442263528432695}, {2.0327785988992915, 0.31186753622663616}, 
     {2., 0.}}]}, {CMYKColor[0.48333333333333334, 0.5, 0.775, 0.1], 
   Polygon[{{1.9996418544847328, 0.442263528432695}, {2.0954862852533283, \
0.6884858883697301}, {2.1296818135360978, 0.6101049646136977}, 
     {2.0327785988992915, 0.31186753622663616}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{2.0954862852533283, 0.6884858883697301}, {2.2505658318693045, \
0.9410557119019607}, {2.2864745084375784, 0.8816778784387095}, 
     {2.1296818135360978, 0.6101049646136977}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{2.2505658318693045, 0.9410557119019607}, {2.458102773991312, \
1.1666712321091806}, {2.4963040904617113, 1.1147172382160908}, 
     {2.2864745084375784, 0.8816778784387095}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.825, 0.1], 
   Polygon[{{2.458102773991312, 1.1666712321091806}, {2.709026751375883, \
1.3494565251821795}, {2.7499999999999982, 1.2990381056766562}, 
     {2.4963040904617113, 1.1147172382160908}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.709026751375883, 1.3494565251821795}, {2.992371182144481, \
1.4795217391705868}, {3.0364745084375784, 1.4265847744427305}, 
     {2.7499999999999982, 1.2990381056766562}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.992371182144481, 1.4795217391705868}, {3.295752555035085, \
1.5507915961279446}, {3.3432073050985176, 1.4917828430524107}, 
     {3.0364745084375784, 1.4265847744427305}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.875, 0.1], 
   Polygon[{{3.295752555035085, 1.5507915961279446}, {3.605911648267035, \
1.560594218929799}, {3.6567926949014775, 1.49178284305241}, 
     {3.3432073050985176, 1.4917828430524107}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{3.605911648267035, 1.560594218929799}, {3.9092930211576427, \
1.5096856680207968}, {3.963525491562421, 1.4265847744427305}, 
     {3.6567926949014775, 1.49178284305241}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{3.9092930211576427, 1.5096856680207968}, {4.192637451926238, \
1.4024710170213415}, {4.249999999999998, 1.2990381056766607}, 
     {3.963525491562421, 1.4265847744427305}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{4.192637451926238, 1.4024710170213415}, {4.443561429310809, \
1.2475429541754033}, {4.503695909538285, 1.114717238216094}, 
     {4.249999999999998, 1.2990381056766607}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{4.443561429310809, 1.2475429541754033}, {4.651098371432819, \
1.0590770192391419}, {4.713525491562421, 0.8816778784387115}, 
     {4.503695909538285, 1.114717238216094}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{4.651098371432819, 1.0590770192391419}, {4.806177918048795, \
0.8605642566348355}, {4.870318186463901, 0.6101049646136991}, 
     {4.713525491562421, 0.8816778784387115}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.975, 0.1], 
   Polygon[{{4.806177918048795, 0.8605642566348355}, {4.9020223488173915, \
0.6935451872894184}, {4.967221401100708, 0.3118675362266461}, 
     {4.870318186463901, 0.6101049646136991}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{4.9020223488173915, 0.6935451872894184}, {4.934442802201416, \
0.6237350724532809}, {5., 0.}, 
     {4.967221401100708, 0.3118675362266461}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{5., 0.}, {4.967221401100708, 0.3118675362266461}, \
{4.902022348817392, 0.6935451872894184}, 
     {4.934442802201418, 0.6237350724532723}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.025, 0.1], 
   Polygon[{{4.967221401100708, 0.3118675362266461}, {4.870318186463902, \
0.6101049646136962}, {4.806177918048797, 0.8605642566348314}, 
     {4.902022348817392, 0.6935451872894184}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{4.870318186463902, 0.6101049646136962}, {4.713525491562421, \
0.8816778784387095}, {4.651098371432821, 1.0590770192391386}, 
     {4.806177918048797, 0.8605642566348314}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{4.713525491562421, 0.8816778784387095}, {4.503695909538287, \
1.1147172382160924}, {4.443561429310812, 1.247542954175402}, 
     {4.651098371432821, 1.0590770192391386}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.075, 0.1], 
   Polygon[{{4.503695909538287, 1.1147172382160924}, {4.25, \
1.2990381056766593}, {4.192637451926241, 1.4024710170213401}, 
     {4.443561429310812, 1.247542954175402}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{4.25, 1.2990381056766593}, {3.963525491562421, \
1.4265847744427318}, {3.909293021157644, 1.5096856680207957}, 
     {4.192637451926241, 1.4024710170213401}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{3.963525491562421, 1.4265847744427318}, {3.6567926949014806, \
1.49178284305241}, {3.605911648267039, 1.5605942189297979}, 
     {3.909293021157644, 1.5096856680207957}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.125, 0.1], 
   Polygon[{{3.6567926949014806, 1.49178284305241}, {3.3432073050985194, \
1.4917828430524107}, {3.2957525550350875, 1.5507915961279435}, 
     {3.605911648267039, 1.5605942189297979}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{3.3432073050985194, 1.4917828430524107}, {3.036474508437579, \
1.4265847744427305}, {2.9923711821444825, 1.4795217391705868}, 
     {3.2957525550350875, 1.5507915961279435}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{3.036474508437579, 1.4265847744427305}, {2.75, \
1.2990381056766587}, {2.7090267513758866, 1.3494565251821795}, 
     {2.9923711821444825, 1.4795217391705868}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.175, 0.1], 
   Polygon[{{2.75, 1.2990381056766587}, {2.496304090461713, \
1.1147172382160917}, {2.458102773991315, 1.1666712321091803}, 
     {2.7090267513758866, 1.3494565251821795}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{2.496304090461713, 1.1147172382160917}, {2.286474508437579, \
0.88167787843871}, {2.2505658318693054, 0.9410557119019611}, 
     {2.458102773991315, 1.1666712321091803}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{2.286474508437579, 0.88167787843871}, {2.1296818135360986, \
0.6101049646137013}, {2.09548628525333, 0.6884858883697313}, 
     {2.2505658318693054, 0.9410557119019611}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.225, 0.1], 
   Polygon[{{2.1296818135360986, 0.6101049646137013}, {2.0327785988992915, \
0.31186753622664043}, {1.9996418544847334, 0.442263528432696}, 
     {2.09548628525333, 0.6884858883697313}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{2.0327785988992915, 0.31186753622664043}, {2., 0.}, \
{1.9672214011007088, 0.31186753622663826}, 
     {1.9996418544847334, 0.442263528432696}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{2., 0.}, {2.0327785988992915, 0.311867536226639}, \
{1.9996418544847336, 0.442263528432694}, 
     {1.9672214011007088, 0.31186753622663826}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.275, 0.1], 
   Polygon[{{2.0327785988992915, 0.311867536226639}, {2.1296818135360986, \
0.6101049646136991}, {2.09548628525333, 0.6884858883697295}, 
     {1.9996418544847336, 0.442263528432694}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{2.1296818135360986, 0.6101049646136991}, {2.286474508437579, \
0.8816778784387095}, {2.2505658318693054, 0.9410557119019607}, 
     {2.09548628525333, 0.6884858883697295}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{2.286474508437579, 0.8816778784387095}, {2.496304090461712, \
1.1147172382160913}, {2.458102773991314, 1.16667123210918}, 
     {2.2505658318693054, 0.9410557119019607}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.325, 0.1], 
   Polygon[{{2.496304090461712, 1.1147172382160913}, {2.749999999999999, \
1.299038105676658}, {2.7090267513758852, 1.3494565251821795}, 
     {2.458102773991314, 1.16667123210918}}]}, {CMYKColor[0.5166666666666666, \
0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.749999999999999, 1.299038105676658}, {3.0364745084375784, \
1.4265847744427305}, {2.992371182144482, 1.4795217391705868}, 
     {2.7090267513758852, 1.3494565251821795}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{3.0364745084375784, 1.4265847744427305}, {3.3432073050985185, \
1.4917828430524107}, {3.2957525550350866, 1.550791596127943}, 
     {2.992371182144482, 1.4795217391705868}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.375, 0.1], 
   Polygon[{{3.3432073050985185, 1.4917828430524107}, {3.656792694901479, \
1.4917828430524112}, {3.6059116482670377, 1.5605942189297983}, 
     {3.2957525550350866, 1.550791596127943}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{3.656792694901479, 1.4917828430524112}, {3.963525491562421, \
1.4265847744427305}, {3.909293021157644, 1.5096856680207946}, 
     {3.6059116482670377, 1.5605942189297983}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{3.963525491562421, 1.4265847744427305}, {4.249999999999999, \
1.299038105676658}, {4.19263745192624, 1.4024710170213388}, 
     {3.909293021157644, 1.5096856680207946}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.425, 0.1], 
   Polygon[{{4.249999999999999, 1.299038105676658}, {4.503695909538286, \
1.1147172382160955}, {4.4435614293108125, 1.2475429541753977}, 
     {4.19263745192624, 1.4024710170213388}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{4.503695909538286, 1.1147172382160955}, {4.713525491562421, \
0.8816778784387115}, {4.651098371432821, 1.0590770192391386}, 
     {4.4435614293108125, 1.2475429541753977}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{4.713525491562421, 0.8816778784387115}, {4.870318186463901, \
0.6101049646136991}, {4.806177918048797, 0.8605642566348294}, 
     {4.651098371432821, 1.0590770192391386}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.475, 0.1], 
   Polygon[{{4.870318186463901, 0.6101049646136991}, {4.967221401100708, \
0.3118675362266461}, {4.902022348817392, 0.6935451872894184}, 
     {4.806177918048797, 0.8605642566348294}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{4.967221401100708, 0.3118675362266461}, {5., 0.}, \
{4.934442802201418, 0.6237350724532723}, 
     {4.902022348817392, 0.6935451872894184}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{5., 0.}, {4.967221401100709, 0.31186753622662905}, \
{4.902022348817393, 0.6935451872894158}, 
     {4.934442802201418, 0.6237350724532723}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.525, 0.1], 
   Polygon[{{4.967221401100709, 0.31186753622662905}, {4.870318186463902, \
0.6101049646136962}, {4.806177918048797, 0.8605642566348314}, 
     {4.902022348817393, 0.6935451872894158}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{4.870318186463902, 0.6101049646136962}, {4.713525491562422, \
0.8816778784387075}, {4.651098371432822, 1.0590770192391352}, 
     {4.806177918048797, 0.8605642566348314}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{4.713525491562422, 0.8816778784387075}, {4.503695909538288, \
1.1147172382160924}, {4.443561429310814, 1.2475429541753962}, 
     {4.651098371432822, 1.0590770192391352}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.575, 0.1], 
   Polygon[{{4.503695909538288, 1.1147172382160924}, {4.250000000000001, \
1.299038105676658}, {4.192637451926242, 1.4024710170213401}, 
     {4.443561429310814, 1.2475429541753962}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{4.250000000000001, 1.299038105676658}, {3.9635254915624225, \
1.426584774442728}, {3.9092930211576453, 1.5096856680207935}, 
     {4.192637451926242, 1.4024710170213401}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{3.9635254915624225, 1.426584774442728}, {3.656792694901482, \
1.491782843052409}, {3.6059116482670404, 1.5605942189297979}, 
     {3.9092930211576453, 1.5096856680207935}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.625, 0.1], 
   Polygon[{{3.656792694901482, 1.491782843052409}, {3.3432073050985207, \
1.49178284305241}, {3.295752555035089, 1.550791596127943}, 
     {3.6059116482670404, 1.5605942189297979}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{3.3432073050985207, 1.49178284305241}, {3.0364745084375793, \
1.4265847744427311}, {2.992371182144483, 1.4795217391705875}, 
     {3.295752555035089, 1.550791596127943}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{3.0364745084375793, 1.4265847744427311}, {2.7500000000000013, \
1.2990381056766587}, {2.7090267513758874, 1.3494565251821806}, 
     {2.992371182144483, 1.4795217391705875}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.675, 0.1], 
   Polygon[{{2.7500000000000013, 1.2990381056766587}, {2.496304090461714, \
1.1147172382160933}, {2.4581027739913157, 1.1666712321091814}, 
     {2.7090267513758874, 1.3494565251821806}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.496304090461714, 1.1147172382160933}, {2.2864745084375793, \
0.88167787843871}, {2.250565831869306, 0.9410557119019607}, 
     {2.4581027739913157, 1.1666712321091814}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{2.2864745084375793, 0.88167787843871}, {2.1296818135360995, \
0.6101049646137006}, {2.095486285253331, 0.6884858883697308}, 
     {2.250565831869306, 0.9410557119019607}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.725, 0.1], 
   Polygon[{{2.1296818135360995, 0.6101049646137006}, {2.0327785988992924, \
0.31186753622664043}, {1.999641854484734, 0.442263528432697}, 
     {2.095486285253331, 0.6884858883697308}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{2.0327785988992924, 0.31186753622664043}, {2., 0.}, \
{1.9672214011007088, 0.31186753622663826}, 
     {1.999641854484734, 0.442263528432697}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{2., 0.}, {2.0327785988992915, 0.31186753622663616}, \
{1.9996418544847332, 0.442263528432694}, 
     {1.9672214011007088, 0.31186753622663826}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.775, 0.1], 
   Polygon[{{2.0327785988992915, 0.31186753622663616}, {2.1296818135360978, \
0.6101049646136977}, {2.095486285253329, 0.6884858883697281}, 
     {1.9996418544847332, 0.442263528432694}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{2.1296818135360978, 0.6101049646136977}, {2.2864745084375784, \
0.8816778784387095}, {2.250565831869305, 0.9410557119019607}, 
     {2.095486285253329, 0.6884858883697281}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{2.2864745084375784, 0.8816778784387095}, {2.4963040904617113, \
1.1147172382160908}, {2.458102773991313, 1.1666712321091794}, 
     {2.250565831869305, 0.9410557119019607}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.825, 0.1], 
   Polygon[{{2.4963040904617113, 1.1147172382160908}, {2.7499999999999982, \
1.2990381056766562}, {2.709026751375884, 1.3494565251821788}, 
     {2.458102773991313, 1.1666712321091794}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.7499999999999982, 1.2990381056766562}, {3.0364745084375784, \
1.4265847744427305}, {2.992371182144482, 1.4795217391705862}, 
     {2.709026751375884, 1.3494565251821788}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{3.0364745084375784, 1.4265847744427305}, {3.3432073050985176, \
1.4917828430524107}, {3.2957525550350857, 1.5507915961279441}, 
     {2.992371182144482, 1.4795217391705862}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.875, 0.1], 
   Polygon[{{3.3432073050985176, 1.4917828430524107}, {3.6567926949014775, \
1.49178284305241}, {3.605911648267036, 1.5605942189297983}, 
     {3.2957525550350857, 1.5507915961279441}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{3.6567926949014775, 1.49178284305241}, {3.963525491562421, \
1.4265847744427305}, {3.9092930211576444, 1.5096856680207935}, 
     {3.605911648267036, 1.5605942189297983}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{3.963525491562421, 1.4265847744427305}, {4.249999999999998, \
1.2990381056766607}, {4.19263745192624, 1.4024710170213388}, 
     {3.9092930211576444, 1.5096856680207935}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{4.249999999999998, 1.2990381056766607}, {4.503695909538285, \
1.114717238216094}, {4.443561429310811, 1.2475429541754004}, 
     {4.19263745192624, 1.4024710170213388}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{4.503695909538285, 1.114717238216094}, {4.713525491562421, \
0.8816778784387115}, {4.651098371432821, 1.0590770192391386}, 
     {4.443561429310811, 1.2475429541754004}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{4.713525491562421, 0.8816778784387115}, {4.870318186463901, \
0.6101049646136991}, {4.806177918048797, 0.8605642566348294}, 
     {4.651098371432821, 1.0590770192391386}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.975, 0.1], 
   Polygon[{{4.870318186463901, 0.6101049646136991}, {4.967221401100708, \
0.3118675362266461}, {4.902022348817393, 0.6935451872894107}, 
     {4.806177918048797, 0.8605642566348294}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{4.967221401100708, 0.3118675362266461}, {5., 0.}, \
{4.934442802201418, 0.6237350724532723}, 
     {4.902022348817393, 0.6935451872894107}}]}, {CMYKColor[0.55, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{4.934442802201418, 0.6237350724532723}, {4.902022348817392, \
0.6935451872894184}, {4.709274703411989, 1.2512975557014567}, 
     {4.740636372927804, 1.2202099292273982}}]}, {CMYKColor[0.55, 0.5, 0.025, \
0.1], 
   Polygon[{{4.902022348817392, 0.6935451872894184}, {4.806177918048797, \
0.8605642566348314}, {4.616560350312376, 1.3346849311080466}, 
     {4.709274703411989, 1.2512975557014567}}]}, {CMYKColor[0.55, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{4.806177918048797, 0.8605642566348314}, {4.651098371432821, \
1.0590770192391386}, {4.46654537575224, 1.4470248504530079}, 
     {4.616560350312376, 1.3346849311080466}}]}, {CMYKColor[0.55, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{4.651098371432821, 1.0590770192391386}, {4.443561429310812, \
1.247542954175402}, {4.265786153971577, 1.5625819810819546}, 
     {4.46654537575224, 1.4470248504530079}}]}, {CMYKColor[0.55, 0.5, 0.075, \
0.1], 
   Polygon[{{4.443561429310812, 1.247542954175402}, {4.192637451926241, \
1.4024710170213401}, {4.023056826311829, 1.6596693760099273}, 
     {4.265786153971577, 1.5625819810819546}}]}, {CMYKColor[0.55, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{4.192637451926241, 1.4024710170213401}, {3.909293021157644, \
1.5096856680207957}, {3.7489658291362655, 1.7222389198769947}, 
     {4.023056826311829, 1.6596693760099273}}]}, {CMYKColor[0.55, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{3.909293021157644, 1.5096856680207957}, {3.605911648267039, \
1.5605942189297979}, {3.4554922542559883, 1.7395717696563637}, 
     {3.7489658291362655, 1.7222389198769947}}]}, {CMYKColor[0.55, 0.5, \
0.125, 0.1], 
   Polygon[{{3.605911648267039, 1.5605942189297979}, {3.2957525550350875, \
1.5507915961279435}, {3.1554623051357176, 1.705691841463222}, 
     {3.4554922542559883, 1.7395717696563637}}]}, {CMYKColor[0.55, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{3.2957525550350875, 1.5507915961279435}, {2.9923711821444825, \
1.4795217391705868}, {2.8619887302554403, 1.6189603147994467}, 
     {3.1554623051357176, 1.705691841463222}}]}, {CMYKColor[0.55, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{2.9923711821444825, 1.4795217391705868}, {2.7090267513758866, \
1.3494565251821795}, {2.5878977330798776, 1.4819447816621785}, 
     {2.8619887302554403, 1.6189603147994467}}]}, {CMYKColor[0.55, 0.5, \
0.175, 0.1], 
   Polygon[{{2.7090267513758866, 1.3494565251821795}, {2.458102773991315, \
1.1666712321091803}, {2.3451684054201287, 1.3017122836390151}, 
     {2.5878977330798776, 1.4819447816621785}}]}, {CMYKColor[0.55, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{2.458102773991315, 1.1666712321091803}, {2.2505658318693054, \
0.9410557119019611}, {2.144409183639465, 1.0910840571723}, 
     {2.3451684054201287, 1.3017122836390151}}]}, {CMYKColor[0.55, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{2.2505658318693054, 0.9410557119019611}, {2.09548628525333, \
0.6884858883697313}, {1.99439420907933, 0.8724918816600724}, 
     {2.144409183639465, 1.0910840571723}}]}, {CMYKColor[0.55, 0.5, 0.225, \
0.1], 
   Polygon[{{2.09548628525333, 0.6884858883697313}, {1.9996418544847334, \
0.442263528432696}, {1.901679855979716, 0.6880869119781076}, 
     {1.99439420907933, 0.8724918816600724}}]}, {CMYKColor[0.55, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{1.9996418544847334, 0.442263528432696}, {1.9672214011007088, \
0.31186753622663826}, {1.8703181864639018, 0.6101049646136991}, 
     {1.901679855979716, 0.6880869119781076}}]}, {CMYKColor[0.55, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{1.9672214011007088, 0.31186753622663826}, {1.9996418544847336, \
0.442263528432694}, {1.901679855979716, 0.6880869119781069}, 
     {1.8703181864639018, 0.6101049646136991}}]}, {CMYKColor[0.55, 0.5, \
0.275, 0.1], 
   Polygon[{{1.9996418544847336, 0.442263528432694}, {2.09548628525333, \
0.6884858883697295}, {1.9943942090793298, 0.8724918816600712}, 
     {1.901679855979716, 0.6880869119781069}}]}, {CMYKColor[0.55, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{2.09548628525333, 0.6884858883697295}, {2.2505658318693054, \
0.9410557119019607}, {2.144409183639465, 1.0910840571722995}, 
     {1.9943942090793298, 0.8724918816600712}}]}, {CMYKColor[0.55, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{2.2505658318693054, 0.9410557119019607}, {2.458102773991314, \
1.16667123210918}, {2.345168405420128, 1.301712283639015}, 
     {2.144409183639465, 1.0910840571722995}}]}, {CMYKColor[0.55, 0.5, 0.325, \
0.1], 
   Polygon[{{2.458102773991314, 1.16667123210918}, {2.7090267513758852, \
1.3494565251821795}, {2.5878977330798767, 1.4819447816621778}, 
     {2.345168405420128, 1.301712283639015}}]}, {CMYKColor[0.55, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{2.7090267513758852, 1.3494565251821795}, {2.992371182144482, \
1.4795217391705868}, {2.86198873025544, 1.6189603147994462}, 
     {2.5878977330798767, 1.4819447816621778}}]}, {CMYKColor[0.55, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{2.992371182144482, 1.4795217391705868}, {3.2957525550350866, \
1.550791596127943}, {3.1554623051357167, 1.705691841463221}, 
     {2.86198873025544, 1.6189603147994462}}]}, {CMYKColor[0.55, 0.5, 0.375, \
0.1], 
   Polygon[{{3.2957525550350866, 1.550791596127943}, {3.6059116482670377, \
1.5605942189297983}, {3.4554922542559865, 1.7395717696563644}, 
     {3.1554623051357167, 1.705691841463221}}]}, {CMYKColor[0.55, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{3.6059116482670377, 1.5605942189297983}, {3.909293021157644, \
1.5096856680207946}, {3.748965829136265, 1.7222389198769947}, 
     {3.4554922542559865, 1.7395717696563644}}]}, {CMYKColor[0.55, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{3.909293021157644, 1.5096856680207946}, {4.19263745192624, \
1.4024710170213388}, {4.023056826311827, 1.6596693760099293}, 
     {3.748965829136265, 1.7222389198769947}}]}, {CMYKColor[0.55, 0.5, 0.425, \
0.1], 
   Polygon[{{4.19263745192624, 1.4024710170213388}, {4.4435614293108125, \
1.2475429541753977}, {4.265786153971577, 1.5625819810819535}, 
     {4.023056826311827, 1.6596693760099293}}]}, {CMYKColor[0.55, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{4.4435614293108125, 1.2475429541753977}, {4.651098371432821, \
1.0590770192391386}, {4.46654537575224, 1.447024850453009}, 
     {4.265786153971577, 1.5625819810819535}}]}, {CMYKColor[0.55, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{4.651098371432821, 1.0590770192391386}, {4.806177918048797, \
0.8605642566348294}, {4.616560350312375, 1.3346849311080493}, 
     {4.46654537575224, 1.447024850453009}}]}, {CMYKColor[0.55, 0.5, 0.475, \
0.1], 
   Polygon[{{4.806177918048797, 0.8605642566348294}, {4.902022348817392, \
0.6935451872894184}, {4.709274703411989, 1.2512975557014567}, 
     {4.616560350312375, 1.3346849311080493}}]}, {CMYKColor[0.55, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{4.902022348817392, 0.6935451872894184}, {4.934442802201418, \
0.6237350724532723}, {4.740636372927804, 1.2202099292273982}, 
     {4.709274703411989, 1.2512975557014567}}]}, {CMYKColor[0.55, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{4.934442802201418, 0.6237350724532723}, {4.902022348817393, \
0.6935451872894158}, {4.70927470341199, 1.2512975557014552}, 
     {4.740636372927804, 1.2202099292273982}}]}, {CMYKColor[0.55, 0.5, 0.525, \
0.1], 
   Polygon[{{4.902022348817393, 0.6935451872894158}, {4.806177918048797, \
0.8605642566348314}, {4.616560350312376, 1.3346849311080466}, 
     {4.70927470341199, 1.2512975557014552}}]}, {CMYKColor[0.55, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{4.806177918048797, 0.8605642566348314}, {4.651098371432822, \
1.0590770192391352}, {4.466545375752241, 1.4470248504530079}, 
     {4.616560350312376, 1.3346849311080466}}]}, {CMYKColor[0.55, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{4.651098371432822, 1.0590770192391352}, {4.443561429310814, \
1.2475429541753962}, {4.265786153971579, 1.5625819810819535}, 
     {4.466545375752241, 1.4470248504530079}}]}, {CMYKColor[0.55, 0.5, 0.575, \
0.1], 
   Polygon[{{4.443561429310814, 1.2475429541753962}, {4.192637451926242, \
1.4024710170213401}, {4.02305682631183, 1.6596693760099261}, 
     {4.265786153971579, 1.5625819810819535}}]}, {CMYKColor[0.55, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{4.192637451926242, 1.4024710170213401}, {3.9092930211576453, \
1.5096856680207935}, {3.7489658291362664, 1.7222389198769943}, 
     {4.02305682631183, 1.6596693760099261}}]}, {CMYKColor[0.55, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{3.9092930211576453, 1.5096856680207935}, {3.6059116482670404, \
1.5605942189297979}, {3.455492254255989, 1.7395717696563633}, 
     {3.7489658291362664, 1.7222389198769943}}]}, {CMYKColor[0.55, 0.5, \
0.625, 0.1], 
   Polygon[{{3.6059116482670404, 1.5605942189297979}, {3.295752555035089, \
1.550791596127943}, {3.155462305135719, 1.705691841463221}, 
     {3.455492254255989, 1.7395717696563633}}]}, {CMYKColor[0.55, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{3.295752555035089, 1.550791596127943}, {2.992371182144483, \
1.4795217391705875}, {2.861988730255441, 1.6189603147994462}, 
     {3.155462305135719, 1.705691841463221}}]}, {CMYKColor[0.55, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{2.992371182144483, 1.4795217391705875}, {2.7090267513758874, \
1.3494565251821806}, {2.5878977330798785, 1.4819447816621794}, 
     {2.861988730255441, 1.6189603147994462}}]}, {CMYKColor[0.55, 0.5, 0.675, \
0.1], 
   Polygon[{{2.7090267513758874, 1.3494565251821806}, {2.4581027739913157, \
1.1666712321091814}, {2.3451684054201296, 1.301712283639017}, 
     {2.5878977330798785, 1.4819447816621794}}]}, {CMYKColor[0.55, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{2.4581027739913157, 1.1666712321091814}, {2.250565831869306, \
0.9410557119019607}, {2.144409183639465, 1.0910840571723004}, 
     {2.3451684054201296, 1.301712283639017}}]}, {CMYKColor[0.55, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{2.250565831869306, 0.9410557119019607}, {2.095486285253331, \
0.6884858883697308}, {1.9943942090793307, 0.8724918816600724}, 
     {2.144409183639465, 1.0910840571723004}}]}, {CMYKColor[0.55, 0.5, 0.725, \
0.1], 
   Polygon[{{2.095486285253331, 0.6884858883697308}, {1.999641854484734, \
0.442263528432697}, {1.9016798559797166, 0.6880869119781079}, 
     {1.9943942090793307, 0.8724918816600724}}]}, {CMYKColor[0.55, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{1.999641854484734, 0.442263528432697}, {1.9672214011007088, \
0.31186753622663826}, {1.8703181864639018, 0.6101049646136991}, 
     {1.9016798559797166, 0.6880869119781079}}]}, {CMYKColor[0.55, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{1.9672214011007088, 0.31186753622663826}, {1.9996418544847332, \
0.442263528432694}, {1.9016798559797157, 0.6880869119781062}, 
     {1.8703181864639018, 0.6101049646136991}}]}, {CMYKColor[0.55, 0.5, \
0.775, 0.1], 
   Polygon[{{1.9996418544847332, 0.442263528432694}, {2.095486285253329, \
0.6884858883697281}, {1.994394209079329, 0.8724918816600701}, 
     {1.9016798559797157, 0.6880869119781062}}]}, {CMYKColor[0.55, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{2.095486285253329, 0.6884858883697281}, {2.250565831869305, \
0.9410557119019607}, {2.1444091836394645, 1.0910840571722995}, 
     {1.994394209079329, 0.8724918816600701}}]}, {CMYKColor[0.55, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{2.250565831869305, 0.9410557119019607}, {2.458102773991313, \
1.1666712321091794}, {2.345168405420127, 1.3017122836390145}, 
     {2.1444091836394645, 1.0910840571722995}}]}, {CMYKColor[0.55, 0.5, \
0.825, 0.1], 
   Polygon[{{2.458102773991313, 1.1666712321091794}, {2.709026751375884, \
1.3494565251821788}, {2.587897733079876, 1.481944781662177}, 
     {2.345168405420127, 1.3017122836390145}}]}, {CMYKColor[0.55, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{2.709026751375884, 1.3494565251821788}, {2.992371182144482, \
1.4795217391705862}, {2.8619887302554394, 1.6189603147994462}, 
     {2.587897733079876, 1.481944781662177}}]}, {CMYKColor[0.55, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{2.992371182144482, 1.4795217391705862}, {3.2957525550350857, \
1.5507915961279441}, {3.1554623051357167, 1.7056918414632198}, 
     {2.8619887302554394, 1.6189603147994462}}]}, {CMYKColor[0.55, 0.5, \
0.875, 0.1], 
   Polygon[{{3.2957525550350857, 1.5507915961279441}, {3.605911648267036, \
1.5605942189297983}, {3.455492254255985, 1.7395717696563637}, 
     {3.1554623051357167, 1.7056918414632198}}]}, {CMYKColor[0.55, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{3.605911648267036, 1.5605942189297983}, {3.9092930211576444, \
1.5096856680207935}, {3.7489658291362655, 1.7222389198769938}, 
     {3.455492254255985, 1.7395717696563637}}]}, {CMYKColor[0.55, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{3.9092930211576444, 1.5096856680207935}, {4.19263745192624, \
1.4024710170213388}, {4.023056826311827, 1.6596693760099281}, 
     {3.7489658291362655, 1.7222389198769938}}]}, {CMYKColor[0.55, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{4.19263745192624, 1.4024710170213388}, {4.443561429310811, \
1.2475429541754004}, {4.265786153971575, 1.562581981081956}, 
     {4.023056826311827, 1.6596693760099281}}]}, {CMYKColor[0.55, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{4.443561429310811, 1.2475429541754004}, {4.651098371432821, \
1.0590770192391386}, {4.46654537575224, 1.447024850453009}, 
     {4.265786153971575, 1.562581981081956}}]}, {CMYKColor[0.55, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{4.651098371432821, 1.0590770192391386}, {4.806177918048797, \
0.8605642566348294}, {4.616560350312375, 1.3346849311080493}, 
     {4.46654537575224, 1.447024850453009}}]}, {CMYKColor[0.55, 0.5, 0.975, \
0.1], 
   Polygon[{{4.806177918048797, 0.8605642566348294}, {4.902022348817393, \
0.6935451872894107}, {4.70927470341199, 1.2512975557014525}, 
     {4.616560350312375, 1.3346849311080493}}]}, {CMYKColor[0.55, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{4.902022348817393, 0.6935451872894107}, {4.934442802201418, \
0.6237350724532723}, {4.740636372927804, 1.2202099292273982}, 
     {4.70927470341199, 1.2512975557014525}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{4.740636372927804, 1.2202099292273982}, {4.709274703411989, \
1.2512975557014567}, {4.397402461894534, 1.7786275248098171}, 
     {4.427050983124843, 1.763355756877417}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.025, 0.1], 
   Polygon[{{4.709274703411989, 1.2512975557014567}, {4.616560350312376, \
1.3346849311080466}, {4.309752680850761, 1.82020538579592}, 
     {4.397402461894534, 1.7786275248098171}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{4.616560350312376, 1.3346849311080466}, {4.46654537575224, \
1.4470248504530079}, {4.167932356015448, 1.8768892930626255}, 
     {4.309752680850761, 1.82020538579592}}]}, {CMYKColor[0.5833333333333334, \
0.5, 0.058333333333333334, 0.1], 
   Polygon[{{4.46654537575224, 1.4470248504530079}, {4.265786153971577, \
1.5625819810819546}, {3.9781397161133225, 1.9339672857886046}, 
     {4.167932356015448, 1.8768892930626255}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.075, 0.1], 
   Polygon[{{4.265786153971577, 1.5625819810819546}, {4.023056826311829, \
1.6596693760099273}, {3.748669610234238, 1.976615915035448}, 
     {3.9781397161133225, 1.9339672857886046}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{4.023056826311829, 1.6596693760099273}, {3.7489658291362655, \
1.7222389198769947}, {3.489550983124843, 1.9921691365624095}, 
     {3.748669610234238, 1.976615915035448}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{3.7489658291362655, 1.7222389198769947}, {3.4554922542559883, \
1.7395717696563637}, {3.212108562178944, 1.97128525856985}, 
     {3.489550983124843, 1.9921691365624095}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.125, 0.1], 
   Polygon[{{3.4554922542559883, 1.7395717696563637}, {3.1554623051357176, \
1.705691841463222}, {2.92846791250832, 1.908454380799519}, 
     {3.212108562178944, 1.97128525856985}}]}, {CMYKColor[0.5833333333333334, \
0.5, 0.14166666666666666, 0.1], 
   Polygon[{{3.1554623051357176, 1.705691841463222}, {2.8619887302554403, \
1.6189603147994467}, {2.6510254915624216, 1.8022456366013602}, 
     {2.92846791250832, 1.908454380799519}}]}, {CMYKColor[0.5833333333333334, \
0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.8619887302554403, 1.6189603147994467}, {2.5878977330798776, \
1.4819447816621785}, {2.391906864453027, 1.6555895184432492}, 
     {2.6510254915624216, 1.8022456366013602}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.175, 0.1], 
   Polygon[{{2.5878977330798776, 1.4819447816621785}, {2.3451684054201287, \
1.3017122836390151}, {2.162436758573942, 1.4764049667388979}, 
     {2.391906864453027, 1.6555895184432492}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{2.3451684054201287, 1.3017122836390151}, {2.144409183639465, \
1.0910840571723}, {1.972644118671816, 1.2790742990138138}, 
     {2.162436758573942, 1.4764049667388979}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{2.144409183639465, 1.0910840571723}, {1.99439420907933, \
0.8724918816600724}, {1.8308237938365044, 1.0875191232355923}, 
     {1.972644118671816, 1.2790742990138138}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.225, 0.1], 
   Polygon[{{1.99439420907933, 0.8724918816600724}, {1.901679855979716, \
0.6880869119781076}, {1.7431740127927307, 0.9393665425693399}, 
     {1.8308237938365044, 1.0875191232355923}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.901679855979716, 0.6880869119781076}, {1.8703181864639018, \
0.6101049646136991}, {1.7135254915624214, 0.8816778784387095}, 
     {1.7431740127927307, 0.9393665425693399}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.8703181864639018, 0.6101049646136991}, {1.901679855979716, \
0.6880869119781069}, {1.7431740127927309, 0.9393665425693389}, 
     {1.7135254915624214, 0.8816778784387095}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.275, 0.1], 
   Polygon[{{1.901679855979716, 0.6880869119781069}, {1.9943942090793298, \
0.8724918816600712}, {1.8308237938365042, 1.0875191232355914}, 
     {1.7431740127927309, 0.9393665425693389}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.9943942090793298, 0.8724918816600712}, {2.144409183639465, \
1.0910840571722995}, {1.9726441186718162, 1.279074299013813}, 
     {1.8308237938365042, 1.0875191232355914}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{2.144409183639465, 1.0910840571722995}, {2.345168405420128, \
1.301712283639015}, {2.162436758573941, 1.4764049667388972}, 
     {1.9726441186718162, 1.279074299013813}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.325, 0.1], 
   Polygon[{{2.345168405420128, 1.301712283639015}, {2.5878977330798767, \
1.4819447816621778}, {2.391906864453026, 1.6555895184432483}, 
     {2.162436758573941, 1.4764049667388972}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.5878977330798767, 1.4819447816621778}, {2.86198873025544, \
1.6189603147994462}, {2.6510254915624207, 1.8022456366013606}, 
     {2.391906864453026, 1.6555895184432483}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.86198873025544, 1.6189603147994462}, {3.1554623051357167, \
1.705691841463221}, {2.928467912508319, 1.9084543807995185}, 
     {2.6510254915624207, 1.8022456366013606}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.375, 0.1], 
   Polygon[{{3.1554623051357167, 1.705691841463221}, {3.4554922542559865, \
1.7395717696563644}, {3.212108562178943, 1.9712852585698486}, 
     {2.928467912508319, 1.9084543807995185}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{3.4554922542559865, 1.7395717696563644}, {3.748965829136265, \
1.7222389198769947}, {3.489550983124843, 1.9921691365624086}, 
     {3.212108562178943, 1.9712852585698486}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{3.748965829136265, 1.7222389198769947}, {4.023056826311827, \
1.6596693760099293}, {3.7486696102342365, 1.976615915035448}, 
     {3.489550983124843, 1.9921691365624086}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.425, 0.1], 
   Polygon[{{4.023056826311827, 1.6596693760099293}, {4.265786153971577, \
1.5625819810819535}, {3.9781397161133225, 1.9339672857886046}, 
     {3.7486696102342365, 1.976615915035448}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{4.265786153971577, 1.5625819810819535}, {4.46654537575224, \
1.447024850453009}, {4.167932356015448, 1.8768892930626255}, 
     {3.9781397161133225, 1.9339672857886046}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{4.46654537575224, 1.447024850453009}, {4.616560350312375, \
1.3346849311080493}, {4.309752680850761, 1.820205385795918}, 
     {4.167932356015448, 1.8768892930626255}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.475, 0.1], 
   Polygon[{{4.616560350312375, 1.3346849311080493}, {4.709274703411989, \
1.2512975557014567}, {4.397402461894534, 1.7786275248098171}, 
     {4.309752680850761, 1.820205385795918}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{4.709274703411989, 1.2512975557014567}, {4.740636372927804, \
1.2202099292273982}, {4.427050983124843, 1.763355756877417}, 
     {4.397402461894534, 1.7786275248098171}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{4.740636372927804, 1.2202099292273982}, {4.70927470341199, \
1.2512975557014552}, {4.397402461894535, 1.778627524809816}, 
     {4.427050983124843, 1.763355756877417}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.525, 0.1], 
   Polygon[{{4.70927470341199, 1.2512975557014552}, {4.616560350312376, \
1.3346849311080466}, {4.309752680850761, 1.8202053857959188}, 
     {4.397402461894535, 1.778627524809816}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{4.616560350312376, 1.3346849311080466}, {4.466545375752241, \
1.4470248504530079}, {4.167932356015449, 1.8768892930626246}, 
     {4.309752680850761, 1.8202053857959188}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{4.466545375752241, 1.4470248504530079}, {4.265786153971579, \
1.5625819810819535}, {3.978139716113324, 1.9339672857886037}, 
     {4.167932356015449, 1.8768892930626246}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.575, 0.1], 
   Polygon[{{4.265786153971579, 1.5625819810819535}, {4.02305682631183, \
1.6596693760099261}, {3.7486696102342387, 1.9766159150354476}, 
     {3.978139716113324, 1.9339672857886037}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{4.02305682631183, 1.6596693760099261}, {3.7489658291362664, \
1.7222389198769943}, {3.4895509831248437, 1.9921691365624086}, 
     {3.7486696102342387, 1.9766159150354476}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{3.7489658291362664, 1.7222389198769943}, {3.455492254255989, \
1.7395717696563633}, {3.2121085621789454, 1.971285258569849}, 
     {3.4895509831248437, 1.9921691365624086}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.625, 0.1], 
   Polygon[{{3.455492254255989, 1.7395717696563633}, {3.155462305135719, \
1.705691841463221}, {2.928467912508321, 1.9084543807995193}, 
     {3.2121085621789454, 1.971285258569849}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{3.155462305135719, 1.705691841463221}, {2.861988730255441, \
1.6189603147994462}, {2.651025491562422, 1.8022456366013606}, 
     {2.928467912508321, 1.9084543807995193}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.861988730255441, 1.6189603147994462}, {2.5878977330798785, \
1.4819447816621794}, {2.391906864453028, 1.6555895184432494}, 
     {2.651025491562422, 1.8022456366013606}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.675, 0.1], 
   Polygon[{{2.5878977330798785, 1.4819447816621794}, {2.3451684054201296, \
1.301712283639017}, {2.1624367585739424, 1.4764049667388996}, 
     {2.391906864453028, 1.6555895184432494}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.3451684054201296, 1.301712283639017}, {2.144409183639465, \
1.0910840571723004}, {1.9726441186718164, 1.2790742990138138}, 
     {2.1624367585739424, 1.4764049667388996}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{2.144409183639465, 1.0910840571723004}, {1.9943942090793307, \
0.8724918816600724}, {1.830823793836505, 1.0875191232355925}, 
     {1.9726441186718164, 1.2790742990138138}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.725, 0.1], 
   Polygon[{{1.9943942090793307, 0.8724918816600724}, {1.9016798559797166, \
0.6880869119781079}, {1.7431740127927313, 0.9393665425693402}, 
     {1.830823793836505, 1.0875191232355925}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.9016798559797166, 0.6880869119781079}, {1.8703181864639018, \
0.6101049646136991}, {1.7135254915624214, 0.8816778784387095}, 
     {1.7431740127927313, 0.9393665425693402}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.8703181864639018, 0.6101049646136991}, {1.9016798559797157, \
0.6880869119781062}, {1.7431740127927304, 0.9393665425693389}, 
     {1.7135254915624214, 0.8816778784387095}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.775, 0.1], 
   Polygon[{{1.9016798559797157, 0.6880869119781062}, {1.994394209079329, \
0.8724918816600701}, {1.8308237938365033, 1.0875191232355905}, 
     {1.7431740127927304, 0.9393665425693389}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.994394209079329, 0.8724918816600701}, {2.1444091836394645, \
1.0910840571722995}, {1.9726441186718158, 1.279074299013813}, 
     {1.8308237938365033, 1.0875191232355905}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{2.1444091836394645, 1.0910840571722995}, {2.345168405420127, \
1.3017122836390145}, {2.16243675857394, 1.476404966738897}, 
     {1.9726441186718158, 1.279074299013813}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.825, 0.1], 
   Polygon[{{2.345168405420127, 1.3017122836390145}, {2.587897733079876, \
1.481944781662177}, {2.391906864453025, 1.6555895184432476}, 
     {2.16243675857394, 1.476404966738897}}]}, {CMYKColor[0.5833333333333334, \
0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.587897733079876, 1.481944781662177}, {2.8619887302554394, \
1.6189603147994462}, {2.6510254915624207, 1.8022456366013606}, 
     {2.391906864453025, 1.6555895184432476}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.8619887302554394, 1.6189603147994462}, {3.1554623051357167, \
1.7056918414632198}, {2.928467912508318, 1.908454380799519}, 
     {2.6510254915624207, 1.8022456366013606}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.875, 0.1], 
   Polygon[{{3.1554623051357167, 1.7056918414632198}, {3.455492254255985, \
1.7395717696563637}, {3.2121085621789414, 1.9712852585698495}, 
     {2.928467912508318, 1.908454380799519}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{3.455492254255985, 1.7395717696563637}, {3.7489658291362655, \
1.7222389198769938}, {3.489550983124843, 1.9921691365624086}, 
     {3.2121085621789414, 1.9712852585698495}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{3.7489658291362655, 1.7222389198769938}, {4.023056826311827, \
1.6596693760099281}, {3.748669610234236, 1.976615915035449}, 
     {3.489550983124843, 1.9921691365624086}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{4.023056826311827, 1.6596693760099281}, {4.265786153971575, \
1.562581981081956}, {3.978139716113321, 1.9339672857886046}, 
     {3.748669610234236, 1.976615915035449}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{4.265786153971575, 1.562581981081956}, {4.46654537575224, \
1.447024850453009}, {4.167932356015449, 1.8768892930626246}, 
     {3.978139716113321, 1.9339672857886046}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{4.46654537575224, 1.447024850453009}, {4.616560350312375, \
1.3346849311080493}, {4.309752680850761, 1.820205385795918}, 
     {4.167932356015449, 1.8768892930626246}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.975, 0.1], 
   Polygon[{{4.616560350312375, 1.3346849311080493}, {4.70927470341199, \
1.2512975557014525}, {4.397402461894534, 1.7786275248098171}, 
     {4.309752680850761, 1.820205385795918}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{4.70927470341199, 1.2512975557014525}, {4.740636372927804, \
1.2202099292273982}, {4.427050983124843, 1.763355756877417}, 
     {4.397402461894534, 1.7786275248098171}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{4.427050983124843, 1.763355756877417}, {4.397402461894534, \
1.7786275248098171}, {3.980035937748391, 2.235484296800203}, 
     {4.007391819076576, 2.2294344764321816}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{4.397402461894534, 1.7786275248098171}, {4.309752680850761, \
1.82020538579592}, {3.8991638770459636, 2.2513313265781}, 
     {3.980035937748391, 2.235484296800203}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{4.309752680850761, 1.82020538579592}, {4.167932356015448, \
1.8768892930626255}, {3.7683101340891887, 2.2706462108209022}, 
     {3.8991638770459636, 2.2513313265781}}]}, {CMYKColor[0.6166666666666667, \
0.5, 0.058333333333333334, 0.1], 
   Polygon[{{4.167932356015448, 1.8768892930626255}, {3.9781397161133225, \
1.9339672857886046}, {3.593193645351205, 2.284543605895154}, 
     {3.7683101340891887, 2.2706462108209022}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{3.9781397161133225, 1.9339672857886046}, {3.748669610234238, \
1.976615915035448}, {3.3814678416920034, 2.283369148915068}, 
     {3.593193645351205, 2.284543605895154}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{3.748669610234238, 1.976615915035448}, {3.489550983124843, \
1.9921691365624095}, {3.1423861567046174, 2.258303983491545}, 
     {3.3814678416920034, 2.283369148915068}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{3.489550983124843, 1.9921691365624095}, {3.212108562178944, \
1.97128525856985}, {2.8863976072642052, 2.202570463435661}, 
     {3.1423861567046174, 2.258303983491545}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{3.212108562178944, 1.97128525856985}, {2.92846791250832, \
1.908454380799519}, {2.6246901213506577, 2.1122635155465685}, 
     {2.8863976072642052, 2.202570463435661}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{2.92846791250832, 1.908454380799519}, {2.6510254915624216, \
1.8022456366013602}, {2.368701571910245, 1.9869545564435855}, 
     {2.6246901213506577, 2.1122635155465685}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.6510254915624216, 1.8022456366013602}, {2.391906864453027, \
1.6555895184432492}, {2.12961988692286, 1.8302685290560392}, 
     {2.368701571910245, 1.9869545564435855}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{2.391906864453027, 1.6555895184432492}, {2.162436758573942, \
1.4764049667388979}, {1.9178940832636582, 1.6506863454327514}, 
     {2.12961988692286, 1.8302685290560392}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{2.162436758573942, 1.4764049667388979}, {1.972644118671816, \
1.2790742990138138}, {1.7427775945256736, 1.4628718195622255}, 
     {1.9178940832636582, 1.6506863454327514}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.972644118671816, 1.2790742990138138}, {1.8308237938365044, \
1.0875191232355923}, {1.6119238515689, 1.2895708590441461}, 
     {1.7427775945256736, 1.4628718195622255}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{1.8308237938365044, 1.0875191232355923}, {1.7431740127927307, \
0.9393665425693399}, {1.5310517908664718, 1.1623542887261813}, 
     {1.6119238515689, 1.2895708590441461}}]}, {CMYKColor[0.6166666666666667, \
0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.7431740127927307, 0.9393665425693399}, {1.7135254915624214, \
0.8816778784387095}, {1.5036959095382878, 1.114717238216091}, 
     {1.5310517908664718, 1.1623542887261813}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.7135254915624214, 0.8816778784387095}, {1.7431740127927309, \
0.9393665425693389}, {1.531051790866472, 1.1623542887261806}, 
     {1.5036959095382878, 1.114717238216091}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{1.7431740127927309, 0.9393665425693389}, {1.8308237938365042, \
1.0875191232355914}, {1.6119238515688998, 1.289570859044146}, 
     {1.531051790866472, 1.1623542887261806}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.8308237938365042, 1.0875191232355914}, {1.9726441186718162, \
1.279074299013813}, {1.7427775945256734, 1.4628718195622255}, 
     {1.6119238515688998, 1.289570859044146}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.9726441186718162, 1.279074299013813}, {2.162436758573941, \
1.4764049667388972}, {1.9178940832636575, 1.650686345432751}, 
     {1.7427775945256734, 1.4628718195622255}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{2.162436758573941, 1.4764049667388972}, {2.391906864453026, \
1.6555895184432483}, {2.129619886922859, 1.8302685290560388}, 
     {1.9178940832636575, 1.650686345432751}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{2.391906864453026, 1.6555895184432483}, {2.6510254915624207, \
1.8022456366013606}, {2.368701571910245, 1.9869545564435847}, 
     {2.129619886922859, 1.8302685290560388}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.6510254915624207, 1.8022456366013606}, {2.928467912508319, \
1.9084543807995185}, {2.624690121350657, 2.112263515546568}, 
     {2.368701571910245, 1.9869545564435847}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{2.928467912508319, 1.9084543807995185}, {3.212108562178943, \
1.9712852585698486}, {2.886397607264204, 2.202570463435661}, 
     {2.624690121350657, 2.112263515546568}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{3.212108562178943, 1.9712852585698486}, {3.489550983124843, \
1.9921691365624086}, {3.1423861567046174, 2.258303983491545}, 
     {2.886397607264204, 2.202570463435661}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{3.489550983124843, 1.9921691365624086}, {3.7486696102342365, \
1.976615915035448}, {3.3814678416920025, 2.283369148915068}, 
     {3.1423861567046174, 2.258303983491545}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{3.7486696102342365, 1.976615915035448}, {3.9781397161133225, \
1.9339672857886046}, {3.593193645351205, 2.284543605895153}, 
     {3.3814678416920025, 2.283369148915068}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{3.9781397161133225, 1.9339672857886046}, {4.167932356015448, \
1.8768892930626255}, {3.7683101340891887, 2.2706462108209022}, 
     {3.593193645351205, 2.284543605895153}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{4.167932356015448, 1.8768892930626255}, {4.309752680850761, \
1.820205385795918}, {3.8991638770459627, 2.251331326578101}, 
     {3.7683101340891887, 2.2706462108209022}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{4.309752680850761, 1.820205385795918}, {4.397402461894534, \
1.7786275248098171}, {3.980035937748391, 2.235484296800203}, 
     {3.8991638770459627, 2.251331326578101}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{4.397402461894534, 1.7786275248098171}, {4.427050983124843, \
1.763355756877417}, {4.007391819076576, 2.2294344764321816}, 
     {3.980035937748391, 2.235484296800203}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{4.427050983124843, 1.763355756877417}, {4.397402461894535, \
1.778627524809816}, {3.9800359377483914, 2.235484296800203}, 
     {4.007391819076576, 2.2294344764321816}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{4.397402461894535, 1.778627524809816}, {4.309752680850761, \
1.8202053857959188}, {3.899163877045963, 2.251331326578101}, 
     {3.9800359377483914, 2.235484296800203}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{4.309752680850761, 1.8202053857959188}, {4.167932356015449, \
1.8768892930626246}, {3.7683101340891896, 2.2706462108209013}, 
     {3.899163877045963, 2.251331326578101}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{4.167932356015449, 1.8768892930626246}, {3.978139716113324, \
1.9339672857886037}, {3.593193645351206, 2.284543605895153}, 
     {3.7683101340891896, 2.2706462108209013}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{3.978139716113324, 1.9339672857886037}, {3.7486696102342387, \
1.9766159150354476}, {3.3814678416920043, 2.2833691489150674}, 
     {3.593193645351206, 2.284543605895153}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{3.7486696102342387, 1.9766159150354476}, {3.4895509831248437, \
1.9921691365624086}, {3.1423861567046183, 2.258303983491545}, 
     {3.3814678416920043, 2.2833691489150674}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{3.4895509831248437, 1.9921691365624086}, {3.2121085621789454, \
1.971285258569849}, {2.886397607264206, 2.202570463435661}, 
     {3.1423861567046183, 2.258303983491545}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{3.2121085621789454, 1.971285258569849}, {2.928467912508321, \
1.9084543807995193}, {2.6246901213506586, 2.1122635155465685}, 
     {2.886397607264206, 2.202570463435661}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{2.928467912508321, 1.9084543807995193}, {2.651025491562422, \
1.8022456366013606}, {2.368701571910246, 1.9869545564435855}, 
     {2.6246901213506586, 2.1122635155465685}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.651025491562422, 1.8022456366013606}, {2.391906864453028, \
1.6555895184432494}, {2.1296198869228604, 1.83026852905604}, 
     {2.368701571910246, 1.9869545564435855}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{2.391906864453028, 1.6555895184432494}, {2.1624367585739424, \
1.4764049667388996}, {1.917894083263659, 1.6506863454327527}, 
     {2.1296198869228604, 1.83026852905604}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{2.1624367585739424, 1.4764049667388996}, {1.9726441186718164, \
1.2790742990138138}, {1.7427775945256738, 1.4628718195622255}, 
     {1.917894083263659, 1.6506863454327527}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.9726441186718164, 1.2790742990138138}, {1.830823793836505, \
1.0875191232355925}, {1.6119238515689007, 1.2895708590441464}, 
     {1.7427775945256738, 1.4628718195622255}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{1.830823793836505, 1.0875191232355925}, {1.7431740127927313, \
0.9393665425693402}, {1.5310517908664723, 1.1623542887261817}, 
     {1.6119238515689007, 1.2895708590441464}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.7431740127927313, 0.9393665425693402}, {1.7135254915624214, \
0.8816778784387095}, {1.5036959095382878, 1.114717238216091}, 
     {1.5310517908664723, 1.1623542887261817}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.7135254915624214, 0.8816778784387095}, {1.7431740127927304, \
0.9393665425693389}, {1.5310517908664716, 1.1623542887261806}, 
     {1.5036959095382878, 1.114717238216091}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.775, 0.1], 
   Polygon[{{1.7431740127927304, 0.9393665425693389}, {1.8308237938365033, \
1.0875191232355905}, {1.6119238515688992, 1.289570859044145}, 
     {1.5310517908664716, 1.1623542887261806}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.8308237938365033, 1.0875191232355905}, {1.9726441186718158, \
1.279074299013813}, {1.7427775945256732, 1.462871819562225}, 
     {1.6119238515688992, 1.289570859044145}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.9726441186718158, 1.279074299013813}, {2.16243675857394, \
1.476404966738897}, {1.9178940832636568, 1.6506863454327505}, 
     {1.7427775945256732, 1.462871819562225}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{2.16243675857394, 1.476404966738897}, {2.391906864453025, \
1.6555895184432476}, {2.1296198869228578, 1.830268529056038}, 
     {1.9178940832636568, 1.6506863454327505}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{2.391906864453025, 1.6555895184432476}, {2.6510254915624207, \
1.8022456366013606}, {2.368701571910245, 1.9869545564435847}, 
     {2.1296198869228578, 1.830268529056038}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.6510254915624207, 1.8022456366013606}, {2.928467912508318, \
1.908454380799519}, {2.6246901213506564, 2.112263515546568}, 
     {2.368701571910245, 1.9869545564435847}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{2.928467912508318, 1.908454380799519}, {3.2121085621789414, \
1.9712852585698495}, {2.8863976072642026, 2.2025704634356607}, 
     {2.6246901213506564, 2.112263515546568}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{3.2121085621789414, 1.9712852585698495}, {3.489550983124843, \
1.9921691365624086}, {3.1423861567046174, 2.258303983491545}, 
     {2.8863976072642026, 2.2025704634356607}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{3.489550983124843, 1.9921691365624086}, {3.748669610234236, \
1.976615915035449}, {3.381467841692002, 2.283369148915068}, 
     {3.1423861567046174, 2.258303983491545}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{3.748669610234236, 1.976615915035449}, {3.978139716113321, \
1.9339672857886046}, {3.5931936453512034, 2.2845436058951534}, 
     {3.381467841692002, 2.283369148915068}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{3.978139716113321, 1.9339672857886046}, {4.167932356015449, \
1.8768892930626246}, {3.768310134089189, 2.2706462108209013}, 
     {3.5931936453512034, 2.2845436058951534}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{4.167932356015449, 1.8768892930626246}, {4.309752680850761, \
1.820205385795918}, {3.8991638770459627, 2.251331326578101}, 
     {3.768310134089189, 2.2706462108209013}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{4.309752680850761, 1.820205385795918}, {4.397402461894534, \
1.7786275248098171}, {3.980035937748391, 2.235484296800203}, 
     {3.8991638770459627, 2.251331326578101}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{4.397402461894534, 1.7786275248098171}, {4.427050983124843, \
1.763355756877417}, {4.007391819076576, 2.2294344764321816}, 
     {3.980035937748391, 2.235484296800203}}]}, {CMYKColor[0.65, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{4.007391819076576, 2.2294344764321816}, {3.980035937748391, \
2.235484296800203}, {3.4754160508255314, 2.5979598975817524}, 
     {3.500000000000001, 2.598076211353315}}]}, {CMYKColor[0.65, 0.5, 0.025, \
0.1], 
   Polygon[{{3.980035937748391, 2.235484296800203}, {3.8991638770459636, \
2.2513313265781}, {3.402738639847927, 2.596255039055556}, 
     {3.4754160508255314, 2.5979598975817524}}]}, {CMYKColor[0.65, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{3.8991638770459636, 2.2513313265781}, {3.7683101340891887, \
2.2706462108209022}, {3.2851441186718167, 2.589176886629936}, 
     {3.402738639847927, 2.596255039055556}}]}, {CMYKColor[0.65, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{3.7683101340891887, 2.2706462108209022}, {3.593193645351205, \
2.284543605895154}, {3.127771932153716, 2.5712732770958864}, 
     {3.2851441186718167, 2.589176886629936}}]}, {CMYKColor[0.65, 0.5, 0.075, \
0.1], 
   Polygon[{{3.593193645351205, 2.284543605895154}, {3.3814678416920034, \
2.283369148915068}, {2.937500000000001, 2.536452985962878}, 
     {3.127771932153716, 2.5712732770958864}}]}, {CMYKColor[0.65, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{3.3814678416920034, 2.283369148915068}, {3.1423861567046174, \
2.258303983491545}, {2.7226441186718167, 2.479055835144598}, 
     {2.937500000000001, 2.536452985962878}}]}, {CMYKColor[0.65, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{3.1423861567046174, 2.258303983491545}, {2.8863976072642052, \
2.202570463435661}, {2.492594521176111, 2.3948140222646956}, 
     {2.7226441186718167, 2.479055835144598}}]}, {CMYKColor[0.65, 0.5, 0.125, \
0.1], 
   Polygon[{{2.8863976072642052, 2.202570463435661}, {2.6246901213506577, \
2.1122635155465685}, {2.25740547882389, 2.281657041700859}, 
     {2.492594521176111, 2.3948140222646956}}]}, {CMYKColor[0.65, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{2.6246901213506577, 2.1122635155465685}, {2.368701571910245, \
1.9869545564435855}, {2.0273558813281847, 2.1404016678514597}, 
     {2.25740547882389, 2.281657041700859}}]}, {CMYKColor[0.65, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{2.368701571910245, 1.9869545564435855}, {2.12961988692286, \
1.8302685290560392}, {1.8125000000000009, 1.9754350786598884}, 
     {2.0273558813281847, 2.1404016678514597}}]}, {CMYKColor[0.65, 0.5, \
0.175, 0.1], 
   Polygon[{{2.12961988692286, 1.8302685290560392}, {1.9178940832636582, \
1.6506863454327514}, {1.6222280678462853, 1.7955424168801197}, 
     {1.8125000000000009, 1.9754350786598884}}]}, {CMYKColor[0.65, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{1.9178940832636582, 1.6506863454327514}, {1.7427775945256736, \
1.4628718195622255}, {1.4648558813281845, 1.6149886737174097}, 
     {1.6222280678462853, 1.7955424168801197}}]}, {CMYKColor[0.65, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{1.7427775945256736, 1.4628718195622255}, {1.6119238515689, \
1.2895708590441461}, {1.3472613601520744, 1.454550222063749}, 
     {1.4648558813281845, 1.6149886737174097}}]}, {CMYKColor[0.65, 0.5, \
0.225, 0.1], 
   Polygon[{{1.6119238515689, 1.2895708590441461}, {1.5310517908664718, \
1.1623542887261813}, {1.274583949174469, 1.3407174947497684}, 
     {1.3472613601520744, 1.454550222063749}}]}, {CMYKColor[0.65, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{1.5310517908664718, 1.1623542887261813}, {1.5036959095382878, \
1.114717238216091}, {1.2500000000000004, 1.2990381056766576}, 
     {1.274583949174469, 1.3407174947497684}}]}, {CMYKColor[0.65, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{1.5036959095382878, 1.114717238216091}, {1.531051790866472, \
1.1623542887261806}, {1.2745839491744693, 1.3407174947497684}, 
     {1.2500000000000004, 1.2990381056766576}}]}, {CMYKColor[0.65, 0.5, \
0.275, 0.1], 
   Polygon[{{1.531051790866472, 1.1623542887261806}, {1.6119238515688998, \
1.289570859044146}, {1.3472613601520744, 1.4545502220637483}, 
     {1.2745839491744693, 1.3407174947497684}}]}, {CMYKColor[0.65, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{1.6119238515688998, 1.289570859044146}, {1.7427775945256734, \
1.4628718195622255}, {1.4648558813281847, 1.6149886737174093}, 
     {1.3472613601520744, 1.4545502220637483}}]}, {CMYKColor[0.65, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{1.7427775945256734, 1.4628718195622255}, {1.9178940832636575, \
1.650686345432751}, {1.6222280678462848, 1.7955424168801193}, 
     {1.4648558813281847, 1.6149886737174093}}]}, {CMYKColor[0.65, 0.5, \
0.325, 0.1], 
   Polygon[{{1.9178940832636575, 1.650686345432751}, {2.129619886922859, \
1.8302685290560388}, {1.8125, 1.9754350786598878}, 
     {1.6222280678462848, 1.7955424168801193}}]}, {CMYKColor[0.65, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{2.129619886922859, 1.8302685290560388}, {2.368701571910245, \
1.9869545564435847}, {2.0273558813281842, 2.1404016678514597}, 
     {1.8125, 1.9754350786598878}}]}, {CMYKColor[0.65, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{2.368701571910245, 1.9869545564435847}, {2.624690121350657, \
2.112263515546568}, {2.2574054788238893, 2.281657041700858}, 
     {2.0273558813281842, 2.1404016678514597}}]}, {CMYKColor[0.65, 0.5, \
0.375, 0.1], 
   Polygon[{{2.624690121350657, 2.112263515546568}, {2.886397607264204, \
2.202570463435661}, {2.49259452117611, 2.394814022264695}, 
     {2.2574054788238893, 2.281657041700858}}]}, {CMYKColor[0.65, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{2.886397607264204, 2.202570463435661}, {3.1423861567046174, \
2.258303983491545}, {2.7226441186718158, 2.479055835144599}, 
     {2.49259452117611, 2.394814022264695}}]}, {CMYKColor[0.65, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{3.1423861567046174, 2.258303983491545}, {3.3814678416920025, \
2.283369148915068}, {2.9374999999999996, 2.536452985962878}, 
     {2.7226441186718158, 2.479055835144599}}]}, {CMYKColor[0.65, 0.5, 0.425, \
0.1], 
   Polygon[{{3.3814678416920025, 2.283369148915068}, {3.593193645351205, \
2.284543605895153}, {3.127771932153715, 2.5712732770958873}, 
     {2.9374999999999996, 2.536452985962878}}]}, {CMYKColor[0.65, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{3.593193645351205, 2.284543605895153}, {3.7683101340891887, \
2.2706462108209022}, {3.2851441186718167, 2.589176886629936}, 
     {3.127771932153715, 2.5712732770958873}}]}, {CMYKColor[0.65, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{3.7683101340891887, 2.2706462108209022}, {3.8991638770459627, \
2.251331326578101}, {3.4027386398479265, 2.596255039055556}, 
     {3.2851441186718167, 2.589176886629936}}]}, {CMYKColor[0.65, 0.5, 0.475, \
0.1], 
   Polygon[{{3.8991638770459627, 2.251331326578101}, {3.980035937748391, \
2.235484296800203}, {3.4754160508255314, 2.5979598975817524}, 
     {3.4027386398479265, 2.596255039055556}}]}, {CMYKColor[0.65, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{3.980035937748391, 2.235484296800203}, {4.007391819076576, \
2.2294344764321816}, {3.500000000000001, 2.598076211353315}, 
     {3.4754160508255314, 2.5979598975817524}}]}, {CMYKColor[0.65, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{4.007391819076576, 2.2294344764321816}, {3.9800359377483914, \
2.235484296800203}, {3.4754160508255323, 2.597959897581752}, 
     {3.500000000000001, 2.598076211353315}}]}, {CMYKColor[0.65, 0.5, 0.525, \
0.1], 
   Polygon[{{3.9800359377483914, 2.235484296800203}, {3.899163877045963, \
2.251331326578101}, {3.402738639847927, 2.596255039055556}, 
     {3.4754160508255323, 2.597959897581752}}]}, {CMYKColor[0.65, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{3.899163877045963, 2.251331326578101}, {3.7683101340891896, \
2.2706462108209013}, {3.285144118671817, 2.589176886629936}, 
     {3.402738639847927, 2.596255039055556}}]}, {CMYKColor[0.65, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{3.7683101340891896, 2.2706462108209013}, {3.593193645351206, \
2.284543605895153}, {3.1277719321537174, 2.5712732770958864}, 
     {3.285144118671817, 2.589176886629936}}]}, {CMYKColor[0.65, 0.5, 0.575, \
0.1], 
   Polygon[{{3.593193645351206, 2.284543605895153}, {3.3814678416920043, \
2.2833691489150674}, {2.9375000000000013, 2.5364529859628786}, 
     {3.1277719321537174, 2.5712732770958864}}]}, {CMYKColor[0.65, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{3.3814678416920043, 2.2833691489150674}, {3.1423861567046183, \
2.258303983491545}, {2.722644118671817, 2.479055835144598}, 
     {2.9375000000000013, 2.5364529859628786}}]}, {CMYKColor[0.65, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{3.1423861567046183, 2.258303983491545}, {2.886397607264206, \
2.202570463435661}, {2.492594521176112, 2.394814022264695}, 
     {2.722644118671817, 2.479055835144598}}]}, {CMYKColor[0.65, 0.5, 0.625, \
0.1], 
   Polygon[{{2.886397607264206, 2.202570463435661}, {2.6246901213506586, \
2.1122635155465685}, {2.257405478823891, 2.281657041700859}, 
     {2.492594521176112, 2.394814022264695}}]}, {CMYKColor[0.65, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{2.6246901213506586, 2.1122635155465685}, {2.368701571910246, \
1.9869545564435855}, {2.027355881328185, 2.14040166785146}, 
     {2.257405478823891, 2.281657041700859}}]}, {CMYKColor[0.65, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{2.368701571910246, 1.9869545564435855}, {2.1296198869228604, \
1.83026852905604}, {1.8125000000000016, 1.975435078659889}, 
     {2.027355881328185, 2.14040166785146}}]}, {CMYKColor[0.65, 0.5, 0.675, \
0.1], 
   Polygon[{{2.1296198869228604, 1.83026852905604}, {1.917894083263659, \
1.6506863454327527}, {1.622228067846286, 1.7955424168801213}, 
     {1.8125000000000016, 1.975435078659889}}]}, {CMYKColor[0.65, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{1.917894083263659, 1.6506863454327527}, {1.7427775945256738, \
1.4628718195622255}, {1.4648558813281847, 1.6149886737174095}, 
     {1.622228067846286, 1.7955424168801213}}]}, {CMYKColor[0.65, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{1.7427775945256738, 1.4628718195622255}, {1.6119238515689007, \
1.2895708590441464}, {1.3472613601520749, 1.4545502220637494}, 
     {1.4648558813281847, 1.6149886737174095}}]}, {CMYKColor[0.65, 0.5, \
0.725, 0.1], 
   Polygon[{{1.6119238515689007, 1.2895708590441464}, {1.5310517908664723, \
1.1623542887261817}, {1.2745839491744695, 1.340717494749769}, 
     {1.3472613601520749, 1.4545502220637494}}]}, {CMYKColor[0.65, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{1.5310517908664723, 1.1623542887261817}, {1.5036959095382878, \
1.114717238216091}, {1.2500000000000004, 1.2990381056766576}, 
     {1.2745839491744695, 1.340717494749769}}]}, {CMYKColor[0.65, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{1.5036959095382878, 1.114717238216091}, {1.5310517908664716, \
1.1623542887261806}, {1.274583949174469, 1.3407174947497678}, 
     {1.2500000000000004, 1.2990381056766576}}]}, {CMYKColor[0.65, 0.5, \
0.775, 0.1], 
   Polygon[{{1.5310517908664716, 1.1623542887261806}, {1.6119238515688992, \
1.289570859044145}, {1.3472613601520738, 1.4545502220637476}, 
     {1.274583949174469, 1.3407174947497678}}]}, {CMYKColor[0.65, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{1.6119238515688992, 1.289570859044145}, {1.7427775945256732, \
1.462871819562225}, {1.4648558813281845, 1.6149886737174093}, 
     {1.3472613601520738, 1.4545502220637476}}]}, {CMYKColor[0.65, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{1.7427775945256732, 1.462871819562225}, {1.9178940832636568, \
1.6506863454327505}, {1.622228067846284, 1.795542416880119}, 
     {1.4648558813281845, 1.6149886737174093}}]}, {CMYKColor[0.65, 0.5, \
0.825, 0.1], 
   Polygon[{{1.9178940832636568, 1.6506863454327505}, {2.1296198869228578, \
1.830268529056038}, {1.812499999999999, 1.9754350786598873}, 
     {1.622228067846284, 1.795542416880119}}]}, {CMYKColor[0.65, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{2.1296198869228578, 1.830268529056038}, {2.368701571910245, \
1.9869545564435847}, {2.027355881328184, 2.1404016678514597}, 
     {1.812499999999999, 1.9754350786598873}}]}, {CMYKColor[0.65, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{2.368701571910245, 1.9869545564435847}, {2.6246901213506564, \
2.112263515546568}, {2.257405478823889, 2.281657041700858}, 
     {2.027355881328184, 2.1404016678514597}}]}, {CMYKColor[0.65, 0.5, 0.875, \
0.1], 
   Polygon[{{2.6246901213506564, 2.112263515546568}, {2.8863976072642026, \
2.2025704634356607}, {2.492594521176109, 2.3948140222646943}, 
     {2.257405478823889, 2.281657041700858}}]}, {CMYKColor[0.65, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{2.8863976072642026, 2.2025704634356607}, {3.1423861567046174, \
2.258303983491545}, {2.722644118671816, 2.4790558351445986}, 
     {2.492594521176109, 2.3948140222646943}}]}, {CMYKColor[0.65, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{3.1423861567046174, 2.258303983491545}, {3.381467841692002, \
2.283369148915068}, {2.9375, 2.5364529859628773}, 
     {2.722644118671816, 2.4790558351445986}}]}, {CMYKColor[0.65, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{3.381467841692002, 2.283369148915068}, {3.5931936453512034, \
2.2845436058951534}, {3.1277719321537143, 2.571273277095887}, 
     {2.9375, 2.5364529859628773}}]}, {CMYKColor[0.65, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{3.5931936453512034, 2.2845436058951534}, {3.768310134089189, \
2.2706462108209013}, {3.2851441186718167, 2.589176886629936}, 
     {3.1277719321537143, 2.571273277095887}}]}, {CMYKColor[0.65, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{3.768310134089189, 2.2706462108209013}, {3.8991638770459627, \
2.251331326578101}, {3.4027386398479265, 2.596255039055556}, 
     {3.2851441186718167, 2.589176886629936}}]}, {CMYKColor[0.65, 0.5, 0.975, \
0.1], 
   Polygon[{{3.8991638770459627, 2.251331326578101}, {3.980035937748391, \
2.235484296800203}, {3.475416050825532, 2.597959897581752}, 
     {3.4027386398479265, 2.596255039055556}}]}, {CMYKColor[0.65, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{3.980035937748391, 2.235484296800203}, {4.007391819076576, \
2.2294344764321816}, {3.500000000000001, 2.598076211353315}, 
     {3.475416050825532, 2.597959897581752}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{3.500000000000001, 2.598076211353315}, {3.4754160508255314, \
2.5979598975817524}, {2.9055971116193557, 2.8487773266631815}, 
     {2.9270509831248424, 2.8531695488854605}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{3.4754160508255314, 2.5979598975817524}, {3.402738639847927, \
2.596255039055556}, {2.842173134234785, 2.834803496770629}, 
     {2.9055971116193557, 2.8487773266631815}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{3.402738639847927, 2.596255039055556}, {3.2851441186718167, \
2.589176886629936}, {2.739550983124842, 2.809014835019403}, 
     {2.842173134234785, 2.834803496770629}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{3.2851441186718167, 2.589176886629936}, {3.127771932153716, \
2.5712732770958864}, {2.602215738728751, 2.768181798733441}, 
     {2.739550983124842, 2.809014835019403}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{3.127771932153716, 2.5712732770958864}, {2.937500000000001, \
2.536452985962878}, {2.4361696102342374, 2.7087103854853694}, 
     {2.602215738728751, 2.768181798733441}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{2.937500000000001, 2.536452985962878}, {2.7226441186718167, \
2.479055835144598}, {2.248669610234237, 2.6273597595826383}, 
     {2.4361696102342374, 2.7087103854853694}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{2.7226441186718167, 2.479055835144598}, {2.492594521176111, \
2.3948140222646956}, {2.047910388453574, 2.521960112821855}, 
     {2.248669610234237, 2.6273597595826383}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{2.492594521176111, 2.3948140222646956}, {2.25740547882389, \
2.281657041700859}, {1.8426660862336899, 2.392089327116677}, 
     {2.047910388453574, 2.521960112821855}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{2.25740547882389, 2.281657041700859}, {2.0273558813281847, \
2.1404016678514597}, {1.6419068644530266, 2.239718051509763}, 
     {1.8426660862336899, 2.392089327116677}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{2.0273558813281847, 2.1404016678514597}, {1.8125000000000009, \
1.9754350786598884}, {1.4544068644530268, 2.069878202800487}, 
     {1.6419068644530266, 2.239718051509763}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{1.8125000000000009, 1.9754350786598884}, {1.6222280678462853, \
1.7955424168801197}, {1.2883607359585132, 1.8914277190459865}, 
     {1.4544068644530268, 2.069878202800487}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{1.6222280678462853, 1.7955424168801197}, {1.4648558813281845, \
1.6149886737174097}, {1.1510254915624212, 1.7178957504272219}, 
     {1.2883607359585132, 1.8914277190459865}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.4648558813281845, 1.6149886737174097}, {1.3472613601520744, \
1.454550222063749}, {1.0484033404524795, 1.5679671136605227}, 
     {1.1510254915624212, 1.7178957504272219}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{1.3472613601520744, 1.454550222063749}, {1.274583949174469, \
1.3407174947497684}, {0.9849793630679076, 1.4640759018681937}, 
     {1.0484033404524795, 1.5679671136605227}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{1.274583949174469, 1.3407174947497684}, {1.2500000000000004, \
1.2990381056766576}, {0.9635254915624213, 1.4265847744427302}, 
     {0.9849793630679076, 1.4640759018681937}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.2500000000000004, 1.2990381056766576}, {1.2745839491744693, \
1.3407174947497684}, {0.9849793630679076, 1.4640759018681933}, 
     {0.9635254915624213, 1.4265847744427302}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{1.2745839491744693, 1.3407174947497684}, {1.3472613601520744, \
1.4545502220637483}, {1.0484033404524795, 1.5679671136605224}, 
     {0.9849793630679076, 1.4640759018681933}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.3472613601520744, 1.4545502220637483}, {1.4648558813281847, \
1.6149886737174093}, {1.1510254915624214, 1.7178957504272216}, 
     {1.0484033404524795, 1.5679671136605224}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.4648558813281847, 1.6149886737174093}, {1.6222280678462848, \
1.7955424168801193}, {1.2883607359585125, 1.8914277190459858}, 
     {1.1510254915624214, 1.7178957504272216}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{1.6222280678462848, 1.7955424168801193}, {1.8125, \
1.9754350786598878}, {1.454406864453026, 2.0698782028004867}, 
     {1.2883607359585125, 1.8914277190459858}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{1.8125, 1.9754350786598878}, {2.0273558813281842, \
2.1404016678514597}, {1.6419068644530261, 2.239718051509763}, 
     {1.454406864453026, 2.0698782028004867}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{2.0273558813281842, 2.1404016678514597}, {2.2574054788238893, \
2.281657041700858}, {1.8426660862336892, 2.3920893271166763}, 
     {1.6419068644530261, 2.239718051509763}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{2.2574054788238893, 2.281657041700858}, {2.49259452117611, \
2.394814022264695}, {2.0479103884535728, 2.521960112821855}, 
     {1.8426660862336892, 2.3920893271166763}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{2.49259452117611, 2.394814022264695}, {2.7226441186718158, \
2.479055835144599}, {2.248669610234237, 2.627359759582638}, 
     {2.0479103884535728, 2.521960112821855}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{2.7226441186718158, 2.479055835144599}, {2.9374999999999996, \
2.536452985962878}, {2.436169610234236, 2.70871038548537}, 
     {2.248669610234237, 2.627359759582638}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{2.9374999999999996, 2.536452985962878}, {3.127771932153715, \
2.5712732770958873}, {2.6022157387287503, 2.7681817987334414}, 
     {2.436169610234236, 2.70871038548537}}]}, {CMYKColor[0.6833333333333333, \
0.5, 0.44166666666666665, 0.1], 
   Polygon[{{3.127771932153715, 2.5712732770958873}, {3.2851441186718167, \
2.589176886629936}, {2.739550983124842, 2.809014835019403}, 
     {2.6022157387287503, 2.7681817987334414}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{3.2851441186718167, 2.589176886629936}, {3.4027386398479265, \
2.596255039055556}, {2.842173134234784, 2.834803496770629}, 
     {2.739550983124842, 2.809014835019403}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{3.4027386398479265, 2.596255039055556}, {3.4754160508255314, \
2.5979598975817524}, {2.9055971116193557, 2.8487773266631815}, 
     {2.842173134234784, 2.834803496770629}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{3.4754160508255314, 2.5979598975817524}, {3.500000000000001, \
2.598076211353315}, {2.9270509831248424, 2.8531695488854605}, 
     {2.9055971116193557, 2.8487773266631815}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{3.500000000000001, 2.598076211353315}, {3.4754160508255323, \
2.597959897581752}, {2.9055971116193566, 2.8487773266631806}, 
     {2.9270509831248424, 2.8531695488854605}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{3.4754160508255323, 2.597959897581752}, {3.402738639847927, \
2.596255039055556}, {2.8421731342347845, 2.8348034967706295}, 
     {2.9055971116193566, 2.8487773266631806}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{3.402738639847927, 2.596255039055556}, {3.285144118671817, \
2.589176886629936}, {2.739550983124843, 2.8090148350194024}, 
     {2.8421731342347845, 2.8348034967706295}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{3.285144118671817, 2.589176886629936}, {3.1277719321537174, \
2.5712732770958864}, {2.6022157387287517, 2.7681817987334414}, 
     {2.739550983124843, 2.8090148350194024}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{3.1277719321537174, 2.5712732770958864}, {2.9375000000000013, \
2.5364529859628786}, {2.436169610234238, 2.70871038548537}, 
     {2.6022157387287517, 2.7681817987334414}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{2.9375000000000013, 2.5364529859628786}, {2.722644118671817, \
2.479055835144598}, {2.2486696102342374, 2.6273597595826383}, 
     {2.436169610234238, 2.70871038548537}}]}, {CMYKColor[0.6833333333333333, \
0.5, 0.6083333333333333, 0.1], 
   Polygon[{{2.722644118671817, 2.479055835144598}, {2.492594521176112, \
2.394814022264695}, {2.047910388453575, 2.521960112821855}, 
     {2.2486696102342374, 2.6273597595826383}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{2.492594521176112, 2.394814022264695}, {2.257405478823891, \
2.281657041700859}, {1.8426660862336905, 2.3920893271166777}, 
     {2.047910388453575, 2.521960112821855}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{2.257405478823891, 2.281657041700859}, {2.027355881328185, \
2.14040166785146}, {1.641906864453027, 2.239718051509763}, 
     {1.8426660862336905, 2.3920893271166777}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{2.027355881328185, 2.14040166785146}, {1.8125000000000016, \
1.975435078659889}, {1.4544068644530275, 2.0698782028004876}, 
     {1.641906864453027, 2.239718051509763}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{1.8125000000000016, 1.975435078659889}, {1.622228067846286, \
1.7955424168801213}, {1.2883607359585139, 1.8914277190459874}, 
     {1.4544068644530275, 2.0698782028004876}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{1.622228067846286, 1.7955424168801213}, {1.4648558813281847, \
1.6149886737174095}, {1.1510254915624214, 1.7178957504272219}, 
     {1.2883607359585139, 1.8914277190459874}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.4648558813281847, 1.6149886737174095}, {1.3472613601520749, \
1.4545502220637494}, {1.04840334045248, 1.5679671136605233}, 
     {1.1510254915624214, 1.7178957504272219}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{1.3472613601520749, 1.4545502220637494}, {1.2745839491744695, \
1.340717494749769}, {0.984979363067908, 1.464075901868194}, 
     {1.04840334045248, 1.5679671136605233}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{1.2745839491744695, 1.340717494749769}, {1.2500000000000004, \
1.2990381056766576}, {0.9635254915624213, 1.4265847744427302}, 
     {0.984979363067908, 1.464075901868194}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{1.2500000000000004, 1.2990381056766576}, {1.274583949174469, \
1.3407174947497678}, {0.9849793630679073, 1.464075901868193}, 
     {0.9635254915624213, 1.4265847744427302}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{1.274583949174469, 1.3407174947497678}, {1.3472613601520738, \
1.4545502220637476}, {1.0484033404524786, 1.5679671136605218}, 
     {0.9849793630679073, 1.464075901868193}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.3472613601520738, 1.4545502220637476}, {1.4648558813281845, \
1.6149886737174093}, {1.1510254915624212, 1.7178957504272214}, 
     {1.0484033404524786, 1.5679671136605218}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.4648558813281845, 1.6149886737174093}, {1.622228067846284, \
1.795542416880119}, {1.2883607359585123, 1.8914277190459852}, 
     {1.1510254915624212, 1.7178957504272214}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{1.622228067846284, 1.795542416880119}, {1.812499999999999, \
1.9754350786598873}, {1.4544068644530252, 2.069878202800486}, 
     {1.2883607359585123, 1.8914277190459852}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{1.812499999999999, 1.9754350786598873}, {2.027355881328184, \
2.1404016678514597}, {1.6419068644530261, 2.2397180515097626}, 
     {1.4544068644530252, 2.069878202800486}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{2.027355881328184, 2.1404016678514597}, {2.257405478823889, \
2.281657041700858}, {1.842666086233689, 2.3920893271166763}, 
     {1.6419068644530261, 2.2397180515097626}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{2.257405478823889, 2.281657041700858}, {2.492594521176109, \
2.3948140222646943}, {2.047910388453572, 2.521960112821854}, 
     {1.842666086233689, 2.3920893271166763}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{2.492594521176109, 2.3948140222646943}, {2.722644118671816, \
2.4790558351445986}, {2.248669610234237, 2.6273597595826383}, 
     {2.047910388453572, 2.521960112821854}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{2.722644118671816, 2.4790558351445986}, {2.9375, \
2.5364529859628773}, {2.436169610234236, 2.7087103854853694}, 
     {2.248669610234237, 2.6273597595826383}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{2.9375, 2.5364529859628773}, {3.1277719321537143, \
2.571273277095887}, {2.602215738728749, 2.7681817987334414}, 
     {2.436169610234236, 2.7087103854853694}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{3.1277719321537143, 2.571273277095887}, {3.2851441186718167, \
2.589176886629936}, {2.739550983124842, 2.809014835019403}, 
     {2.602215738728749, 2.7681817987334414}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{3.2851441186718167, 2.589176886629936}, {3.4027386398479265, \
2.596255039055556}, {2.842173134234784, 2.834803496770629}, 
     {2.739550983124842, 2.809014835019403}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{3.4027386398479265, 2.596255039055556}, {3.475416050825532, \
2.597959897581752}, {2.905597111619356, 2.848777326663181}, 
     {2.842173134234784, 2.834803496770629}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{3.475416050825532, 2.597959897581752}, {3.500000000000001, \
2.598076211353315}, {2.9270509831248424, 2.8531695488854605}, 
     {2.905597111619356, 2.848777326663181}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193557, \
2.8487773266631815}, {2.2954829420678116, 2.976303493889946}, 
     {2.3135853898029626, 2.9835656861048196}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{2.9055971116193557, 2.8487773266631815}, {2.842173134234785, \
2.834803496770629}, {2.2419667626935684, 2.95408127925137}, 
     {2.2954829420678116, 2.976303493889946}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{2.842173134234785, 2.834803496770629}, {2.739550983124842, \
2.809014835019403}, {2.1553757655180044, 2.9156867970745455}, 
     {2.2419667626935684, 2.95408127925137}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{2.739550983124842, 2.809014835019403}, {2.602215738728751, \
2.768181798733441}, {2.039494392627399, 2.8593997974092926}, 
     {2.1553757655180044, 2.9156867970745455}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{2.602215738728751, 2.768181798733441}, {2.4361696102342374, \
2.7087103854853694}, {1.8993872160775924, 2.7833940695732022}, 
     {2.039494392627399, 2.8593997974092926}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{2.4361696102342374, 2.7087103854853694}, {2.248669610234237, \
2.6273597595826383}, {1.7411775917926342, 2.686221801523239}, 
     {1.8993872160775924, 2.7833940695732022}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{2.248669610234237, 2.6273597595826383}, {2.047910388453574, \
2.521960112821855}, {1.5717800395277852, 2.567335508777075}, 
     {1.7411775917926342, 2.686221801523239}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{2.047910388453574, 2.521960112821855}, {1.8426660862336899, \
2.392089327116677}, {1.3985980451766586, 2.427623046285348}, 
     {1.5717800395277852, 2.567335508777075}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{1.8426660862336899, 2.392089327116677}, {1.6419068644530266, \
2.239718051509763}, {1.2292004929118094, 2.2699589047379565}, 
     {1.3985980451766586, 2.427623046285348}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{1.6419068644530266, 2.239718051509763}, {1.4544068644530268, \
2.069878202800487}, {1.0709908686268519, 2.099799626225554}, 
     {1.2292004929118094, 2.2699589047379565}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{1.4544068644530268, 2.069878202800487}, {1.2883607359585132, \
1.8914277190459865}, {0.9308836920770447, 1.9258466260207314}, 
     {1.0709908686268519, 2.099799626225554}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{1.2883607359585132, 1.8914277190459865}, {1.1510254915624212, \
1.7178957504272219}, {0.8150023191864391, 1.760690570377689}, 
     {0.9308836920770447, 1.9258466260207314}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{1.1510254915624212, 1.7178957504272219}, {1.0484033404524795, \
1.5679671136605227}, {0.7284113220108761, 1.6209688555409116}, 
     {0.8150023191864391, 1.760690570377689}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{1.0484033404524795, 1.5679671136605227}, {0.9849793630679076, \
1.4640759018681937}, {0.674895142636632, 1.5257871330867279}, 
     {0.7284113220108761, 1.6209688555409116}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.9849793630679076, 1.4640759018681937}, {0.9635254915624213, \
1.4265847744427302}, {0.6567926949014813, 1.4917828430524098}, 
     {0.674895142636632, 1.5257871330867279}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.9635254915624213, 1.4265847744427302}, {0.9849793630679076, \
1.4640759018681933}, {0.674895142636632, 1.5257871330867276}, 
     {0.6567926949014813, 1.4917828430524098}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{0.9849793630679076, 1.4640759018681933}, {1.0484033404524795, \
1.5679671136605224}, {0.7284113220108761, 1.6209688555409112}, 
     {0.674895142636632, 1.5257871330867276}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{1.0484033404524795, 1.5679671136605224}, {1.1510254915624214, \
1.7178957504272216}, {0.8150023191864392, 1.7606905703776887}, 
     {0.7284113220108761, 1.6209688555409112}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{1.1510254915624214, 1.7178957504272216}, {1.2883607359585125, \
1.8914277190459858}, {0.9308836920770442, 1.9258466260207308}, 
     {0.8150023191864392, 1.7606905703776887}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{1.2883607359585125, 1.8914277190459858}, {1.454406864453026, \
2.0698782028004867}, {1.070990868626851, 2.099799626225553}, 
     {0.9308836920770442, 1.9258466260207308}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{1.454406864453026, 2.0698782028004867}, {1.6419068644530261, \
2.239718051509763}, {1.2292004929118092, 2.2699589047379565}, 
     {1.070990868626851, 2.099799626225553}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{1.6419068644530261, 2.239718051509763}, {1.8426660862336892, \
2.3920893271166763}, {1.3985980451766582, 2.427623046285347}, 
     {1.2292004929118092, 2.2699589047379565}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{1.8426660862336892, 2.3920893271166763}, {2.0479103884535728, \
2.521960112821855}, {1.5717800395277841, 2.567335508777075}, 
     {1.3985980451766582, 2.427623046285347}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{2.0479103884535728, 2.521960112821855}, {2.248669610234237, \
2.627359759582638}, {1.7411775917926342, 2.6862218015232386}, 
     {1.5717800395277841, 2.567335508777075}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{2.248669610234237, 2.627359759582638}, {2.436169610234236, \
2.70871038548537}, {1.8993872160775915, 2.783394069573202}, 
     {1.7411775917926342, 2.6862218015232386}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{2.436169610234236, 2.70871038548537}, {2.6022157387287503, \
2.7681817987334414}, {2.039494392627399, 2.8593997974092926}, 
     {1.8993872160775915, 2.783394069573202}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{2.6022157387287503, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {2.155375765518005, 2.9156867970745455}, 
     {2.039494392627399, 2.8593997974092926}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {2.241966762693568, 2.9540812792513695}, 
     {2.155375765518005, 2.9156867970745455}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{2.842173134234784, 2.834803496770629}, {2.9055971116193557, \
2.8487773266631815}, {2.2954829420678116, 2.976303493889946}, 
     {2.241966762693568, 2.9540812792513695}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{2.9055971116193557, 2.8487773266631815}, {2.9270509831248424, \
2.8531695488854605}, {2.3135853898029626, 2.9835656861048196}, 
     {2.2954829420678116, 2.976303493889946}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193566, \
2.8487773266631806}, {2.2954829420678124, 2.9763034938899455}, 
     {2.3135853898029626, 2.9835656861048196}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{2.9055971116193566, 2.8487773266631806}, {2.8421731342347845, \
2.8348034967706295}, {2.241966762693568, 2.9540812792513704}, 
     {2.2954829420678124, 2.9763034938899455}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{2.8421731342347845, 2.8348034967706295}, {2.739550983124843, \
2.8090148350194024}, {2.155375765518005, 2.9156867970745455}, 
     {2.241966762693568, 2.9540812792513704}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{2.739550983124843, 2.8090148350194024}, {2.6022157387287517, \
2.7681817987334414}, {2.0394943926274, 2.859399797409293}, 
     {2.155375765518005, 2.9156867970745455}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{2.6022157387287517, 2.7681817987334414}, {2.436169610234238, \
2.70871038548537}, {1.8993872160775926, 2.7833940695732027}, 
     {2.0394943926274, 2.859399797409293}}]}, {CMYKColor[0.7166666666666667, \
0.5, 0.5916666666666667, 0.1], 
   Polygon[{{2.436169610234238, 2.70871038548537}, {2.2486696102342374, \
2.6273597595826383}, {1.7411775917926349, 2.686221801523239}, 
     {1.8993872160775926, 2.7833940695732027}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{2.2486696102342374, 2.6273597595826383}, {2.047910388453575, \
2.521960112821855}, {1.5717800395277857, 2.5673355087770755}, 
     {1.7411775917926349, 2.686221801523239}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{2.047910388453575, 2.521960112821855}, {1.8426660862336905, \
2.3920893271166777}, {1.3985980451766593, 2.4276230462853485}, 
     {1.5717800395277857, 2.5673355087770755}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{1.8426660862336905, 2.3920893271166777}, {1.641906864453027, \
2.239718051509763}, {1.2292004929118097, 2.269958904737957}, 
     {1.3985980451766593, 2.4276230462853485}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{1.641906864453027, 2.239718051509763}, {1.4544068644530275, \
2.0698782028004876}, {1.0709908686268523, 2.099799626225555}, 
     {1.2292004929118097, 2.269958904737957}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{1.4544068644530275, 2.0698782028004876}, {1.2883607359585139, \
1.8914277190459874}, {0.9308836920770454, 1.9258466260207323}, 
     {1.0709908686268523, 2.099799626225555}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{1.2883607359585139, 1.8914277190459874}, {1.1510254915624214, \
1.7178957504272219}, {0.8150023191864393, 1.7606905703776892}, 
     {0.9308836920770454, 1.9258466260207323}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{1.1510254915624214, 1.7178957504272219}, {1.04840334045248, \
1.5679671136605233}, {0.7284113220108764, 1.620968855540912}, 
     {0.8150023191864393, 1.7606905703776892}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{1.04840334045248, 1.5679671136605233}, {0.984979363067908, \
1.464075901868194}, {0.6748951426366323, 1.5257871330867283}, 
     {0.7284113220108764, 1.620968855540912}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.984979363067908, 1.464075901868194}, {0.9635254915624213, \
1.4265847744427302}, {0.6567926949014813, 1.4917828430524098}, 
     {0.6748951426366323, 1.5257871330867283}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.9635254915624213, 1.4265847744427302}, {0.9849793630679073, \
1.464075901868193}, {0.6748951426366318, 1.5257871330867276}, 
     {0.6567926949014813, 1.4917828430524098}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.775, 0.1], 
   Polygon[{{0.9849793630679073, 1.464075901868193}, {1.0484033404524786, \
1.5679671136605218}, {0.7284113220108754, 1.6209688555409107}, 
     {0.6748951426366318, 1.5257871330867276}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{1.0484033404524786, 1.5679671136605218}, {1.1510254915624212, \
1.7178957504272214}, {0.815002319186439, 1.7606905703776887}, 
     {0.7284113220108754, 1.6209688555409107}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{1.1510254915624212, 1.7178957504272214}, {1.2883607359585123, \
1.8914277190459852}, {0.9308836920770438, 1.9258466260207303}, 
     {0.815002319186439, 1.7606905703776887}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{1.2883607359585123, 1.8914277190459852}, {1.4544068644530252, \
2.069878202800486}, {1.0709908686268506, 2.0997996262255523}, 
     {0.9308836920770438, 1.9258466260207303}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{1.4544068644530252, 2.069878202800486}, {1.6419068644530261, \
2.2397180515097626}, {1.229200492911809, 2.269958904737956}, 
     {1.0709908686268506, 2.0997996262255523}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{1.6419068644530261, 2.2397180515097626}, {1.842666086233689, \
2.3920893271166763}, {1.3985980451766578, 2.427623046285347}, 
     {1.229200492911809, 2.269958904737956}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{1.842666086233689, 2.3920893271166763}, {2.047910388453572, \
2.521960112821854}, {1.5717800395277832, 2.5673355087770737}, 
     {1.3985980451766578, 2.427623046285347}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{2.047910388453572, 2.521960112821854}, {2.248669610234237, \
2.6273597595826383}, {1.7411775917926344, 2.686221801523239}, 
     {1.5717800395277832, 2.5673355087770737}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{2.248669610234237, 2.6273597595826383}, {2.436169610234236, \
2.7087103854853694}, {1.8993872160775913, 2.783394069573202}, 
     {1.7411775917926344, 2.686221801523239}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{2.436169610234236, 2.7087103854853694}, {2.602215738728749, \
2.7681817987334414}, {2.039494392627398, 2.859399797409292}, 
     {1.8993872160775913, 2.783394069573202}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{2.602215738728749, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {2.155375765518005, 2.9156867970745455}, 
     {2.039494392627398, 2.859399797409292}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {2.241966762693568, 2.9540812792513695}, 
     {2.155375765518005, 2.9156867970745455}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{2.842173134234784, 2.834803496770629}, {2.905597111619356, \
2.848777326663181}, {2.295482942067812, 2.9763034938899455}, 
     {2.241966762693568, 2.9540812792513695}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{2.905597111619356, 2.848777326663181}, {2.9270509831248424, \
2.8531695488854605}, {2.3135853898029626, 2.9835656861048196}, 
     {2.295482942067812, 2.9763034938899455}}]}, {CMYKColor[0.75, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{2.3135853898029626, 2.9835656861048196}, {2.2954829420678116, \
2.976303493889946}, {1.6717384590329, 2.9745950829027943}, 
     {1.686414610197041, 2.9835656861048196}}]}, {CMYKColor[0.75, 0.5, 0.025, \
0.1], 
   Polygon[{{2.2954829420678116, 2.976303493889946}, {2.2419667626935684, \
2.95408127925137}, {1.6283514237703374, 2.947488384456562}, 
     {1.6717384590329, 2.9745950829027943}}]}, {CMYKColor[0.75, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{2.2419667626935684, 2.95408127925137}, {2.1553757655180044, \
2.9156867970745455}, {1.5581497260444195, 2.9017190909782276}, 
     {1.6283514237703374, 2.947488384456562}}]}, {CMYKColor[0.75, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{2.1553757655180044, 2.9156867970745455}, {2.039494392627399, \
2.8593997974092926}, {1.464201516910891, 2.8365966765934414}, 
     {1.5581497260444195, 2.9017190909782276}}]}, {CMYKColor[0.75, 0.5, \
0.075, 0.1], 
   Polygon[{{2.039494392627399, 2.8593997974092926}, {1.8993872160775924, \
2.7833940695732022}, {1.350612783922411, 2.751525170659194}, 
     {1.464201516910891, 2.8365966765934414}}]}, {CMYKColor[0.75, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{1.8993872160775924, 2.7833940695732022}, {1.7411775917926342, \
2.686221801523239}, {1.2223478997697899, 2.646328981764321}, 
     {1.350612783922411, 2.751525170659194}}]}, {CMYKColor[0.75, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{1.7411775917926342, 2.686221801523239}, {1.5717800395277852, \
2.567335508777075}, {1.0850126553736983, 2.5216249314090464}, 
     {1.2223478997697899, 2.646328981764321}}]}, {CMYKColor[0.75, 0.5, 0.125, \
0.1], 
   Polygon[{{1.5717800395277852, 2.567335508777075}, {1.3985980451766586, \
2.427623046285348}, {0.9446092599218634, 2.379229777665829}, 
     {1.0850126553736983, 2.5216249314090464}}]}, {CMYKColor[0.75, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{1.3985980451766586, 2.427623046285348}, {1.2292004929118094, \
2.2699589047379565}, {0.8072740155257718, 2.222607239695348}, 
     {0.9446092599218634, 2.379229777665829}}]}, {CMYKColor[0.75, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{1.2292004929118094, 2.2699589047379565}, {1.0709908686268519, \
2.099799626225554}, {0.6790091313731508, 2.0573688751735335}, 
     {0.8072740155257718, 2.222607239695348}}]}, {CMYKColor[0.75, 0.5, 0.175, \
0.1], 
   Polygon[{{1.0709908686268519, 2.099799626225554}, {0.9308836920770447, \
1.9258466260207314}, {0.5654203983846704, 1.8918241808350191}, 
     {0.6790091313731508, 2.0573688751735335}}]}, {CMYKColor[0.75, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{0.9308836920770447, 1.9258466260207314}, {0.8150023191864391, \
1.760690570377689}, {0.4714721892511417, 1.7374623647519978}, 
     {0.5654203983846704, 1.8918241808350191}}]}, {CMYKColor[0.75, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{0.8150023191864391, 1.760690570377689}, {0.7284113220108761, \
1.6209688555409116}, {0.40127049152522454, 1.6089224974238359}, 
     {0.4714721892511417, 1.7374623647519978}}]}, {CMYKColor[0.75, 0.5, \
0.225, 0.1], 
   Polygon[{{0.7284113220108761, 1.6209688555409116}, {0.674895142636632, \
1.5257871330867279}, {0.3578834562626614, 1.5224519023538965}, 
     {0.40127049152522454, 1.6089224974238359}}]}, {CMYKColor[0.75, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{0.674895142636632, 1.5257871330867279}, {0.6567926949014813, \
1.4917828430524098}, {0.3432073050985205, 1.49178284305241}, 
     {0.3578834562626614, 1.5224519023538965}}]}, {CMYKColor[0.75, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{0.6567926949014813, 1.4917828430524098}, {0.674895142636632, \
1.5257871330867276}, {0.3578834562626615, 1.5224519023538965}, 
     {0.3432073050985205, 1.49178284305241}}]}, {CMYKColor[0.75, 0.5, 0.275, \
0.1], 
   Polygon[{{0.674895142636632, 1.5257871330867276}, {0.7284113220108761, \
1.6209688555409112}, {0.4012704915252243, 1.6089224974238356}, 
     {0.3578834562626615, 1.5224519023538965}}]}, {CMYKColor[0.75, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{0.7284113220108761, 1.6209688555409112}, {0.8150023191864392, \
1.7606905703776887}, {0.47147218925114165, 1.7374623647519978}, 
     {0.4012704915252243, 1.6089224974238356}}]}, {CMYKColor[0.75, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{0.8150023191864392, 1.7606905703776887}, {0.9308836920770442, \
1.9258466260207308}, {0.5654203983846702, 1.8918241808350182}, 
     {0.47147218925114165, 1.7374623647519978}}]}, {CMYKColor[0.75, 0.5, \
0.325, 0.1], 
   Polygon[{{0.9308836920770442, 1.9258466260207308}, {1.070990868626851, \
2.099799626225553}, {0.6790091313731502, 2.057368875173533}, 
     {0.5654203983846702, 1.8918241808350182}}]}, {CMYKColor[0.75, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{1.070990868626851, 2.099799626225553}, {1.2292004929118092, \
2.2699589047379565}, {0.8072740155257716, 2.222607239695348}, 
     {0.6790091313731502, 2.057368875173533}}]}, {CMYKColor[0.75, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{1.2292004929118092, 2.2699589047379565}, {1.3985980451766582, \
2.427623046285347}, {0.9446092599218627, 2.379229777665828}, 
     {0.8072740155257716, 2.222607239695348}}]}, {CMYKColor[0.75, 0.5, 0.375, \
0.1], 
   Polygon[{{1.3985980451766582, 2.427623046285347}, {1.5717800395277841, \
2.567335508777075}, {1.0850126553736974, 2.5216249314090464}, 
     {0.9446092599218627, 2.379229777665828}}]}, {CMYKColor[0.75, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{1.5717800395277841, 2.567335508777075}, {1.7411775917926342, \
2.6862218015232386}, {1.2223478997697894, 2.646328981764321}, 
     {1.0850126553736974, 2.5216249314090464}}]}, {CMYKColor[0.75, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{1.7411775917926342, 2.6862218015232386}, {1.8993872160775915, \
2.783394069573202}, {1.3506127839224105, 2.751525170659194}, 
     {1.2223478997697894, 2.646328981764321}}]}, {CMYKColor[0.75, 0.5, 0.425, \
0.1], 
   Polygon[{{1.8993872160775915, 2.783394069573202}, {2.039494392627399, \
2.8593997974092926}, {1.4642015169108908, 2.836596676593442}, 
     {1.3506127839224105, 2.751525170659194}}]}, {CMYKColor[0.75, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{2.039494392627399, 2.8593997974092926}, {2.155375765518005, \
2.9156867970745455}, {1.5581497260444195, 2.901719090978228}, 
     {1.4642015169108908, 2.836596676593442}}]}, {CMYKColor[0.75, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{2.155375765518005, 2.9156867970745455}, {2.241966762693568, \
2.9540812792513695}, {1.6283514237703371, 2.947488384456561}, 
     {1.5581497260444195, 2.901719090978228}}]}, {CMYKColor[0.75, 0.5, 0.475, \
0.1], 
   Polygon[{{2.241966762693568, 2.9540812792513695}, {2.2954829420678116, \
2.976303493889946}, {1.6717384590329, 2.9745950829027943}, 
     {1.6283514237703371, 2.947488384456561}}]}, {CMYKColor[0.75, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{2.2954829420678116, 2.976303493889946}, {2.3135853898029626, \
2.9835656861048196}, {1.686414610197041, 2.9835656861048196}, 
     {1.6717384590329, 2.9745950829027943}}]}, {CMYKColor[0.75, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{2.3135853898029626, 2.9835656861048196}, {2.2954829420678124, \
2.9763034938899455}, {1.6717384590329005, 2.9745950829027943}, 
     {1.686414610197041, 2.9835656861048196}}]}, {CMYKColor[0.75, 0.5, 0.525, \
0.1], 
   Polygon[{{2.2954829420678124, 2.9763034938899455}, {2.241966762693568, \
2.9540812792513704}, {1.6283514237703374, 2.9474883844565616}, 
     {1.6717384590329005, 2.9745950829027943}}]}, {CMYKColor[0.75, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{2.241966762693568, 2.9540812792513704}, {2.155375765518005, \
2.9156867970745455}, {1.55814972604442, 2.901719090978228}, 
     {1.6283514237703374, 2.9474883844565616}}]}, {CMYKColor[0.75, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{2.155375765518005, 2.9156867970745455}, {2.0394943926274, \
2.859399797409293}, {1.4642015169108917, 2.836596676593442}, 
     {1.55814972604442, 2.901719090978228}}]}, {CMYKColor[0.75, 0.5, 0.575, \
0.1], 
   Polygon[{{2.0394943926274, 2.859399797409293}, {1.8993872160775926, \
2.7833940695732027}, {1.3506127839224114, 2.7515251706591943}, 
     {1.4642015169108917, 2.836596676593442}}]}, {CMYKColor[0.75, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{1.8993872160775926, 2.7833940695732027}, {1.7411775917926349, \
2.686221801523239}, {1.22234789976979, 2.646328981764321}, 
     {1.3506127839224114, 2.7515251706591943}}]}, {CMYKColor[0.75, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{1.7411775917926349, 2.686221801523239}, {1.5717800395277857, \
2.5673355087770755}, {1.0850126553736987, 2.5216249314090473}, 
     {1.22234789976979, 2.646328981764321}}]}, {CMYKColor[0.75, 0.5, 0.625, \
0.1], 
   Polygon[{{1.5717800395277857, 2.5673355087770755}, {1.3985980451766593, \
2.4276230462853485}, {0.9446092599218641, 2.3792297776658295}, 
     {1.0850126553736987, 2.5216249314090473}}]}, {CMYKColor[0.75, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{1.3985980451766593, 2.4276230462853485}, {1.2292004929118097, \
2.269958904737957}, {0.807274015525772, 2.2226072396953485}, 
     {0.9446092599218641, 2.3792297776658295}}]}, {CMYKColor[0.75, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{1.2292004929118097, 2.269958904737957}, {1.0709908686268523, \
2.099799626225555}, {0.6790091313731512, 2.0573688751735344}, 
     {0.807274015525772, 2.2226072396953485}}]}, {CMYKColor[0.75, 0.5, 0.675, \
0.1], 
   Polygon[{{1.0709908686268523, 2.099799626225555}, {0.9308836920770454, \
1.9258466260207323}, {0.565420398384671, 1.8918241808350198}, 
     {0.6790091313731512, 2.0573688751735344}}]}, {CMYKColor[0.75, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{0.9308836920770454, 1.9258466260207323}, {0.8150023191864393, \
1.7606905703776892}, {0.47147218925114187, 1.737462364751998}, 
     {0.565420398384671, 1.8918241808350198}}]}, {CMYKColor[0.75, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{0.8150023191864393, 1.7606905703776892}, {0.7284113220108764, \
1.620968855540912}, {0.40127049152522487, 1.6089224974238363}, 
     {0.47147218925114187, 1.737462364751998}}]}, {CMYKColor[0.75, 0.5, \
0.725, 0.1], 
   Polygon[{{0.7284113220108764, 1.620968855540912}, {0.6748951426366323, \
1.5257871330867283}, {0.3578834562626616, 1.522451902353897}, 
     {0.40127049152522487, 1.6089224974238363}}]}, {CMYKColor[0.75, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{0.6748951426366323, 1.5257871330867283}, {0.6567926949014813, \
1.4917828430524098}, {0.3432073050985205, 1.49178284305241}, 
     {0.3578834562626616, 1.522451902353897}}]}, {CMYKColor[0.75, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{0.6567926949014813, 1.4917828430524098}, {0.6748951426366318, \
1.5257871330867276}, {0.35788345626266127, 1.5224519023538963}, 
     {0.3432073050985205, 1.49178284305241}}]}, {CMYKColor[0.75, 0.5, 0.775, \
0.1], 
   Polygon[{{0.6748951426366318, 1.5257871330867276}, {0.7284113220108754, \
1.6209688555409107}, {0.401270491525224, 1.608922497423835}, 
     {0.35788345626266127, 1.5224519023538963}}]}, {CMYKColor[0.75, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{0.7284113220108754, 1.6209688555409107}, {0.815002319186439, \
1.7606905703776887}, {0.47147218925114154, 1.7374623647519976}, 
     {0.401270491525224, 1.608922497423835}}]}, {CMYKColor[0.75, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{0.815002319186439, 1.7606905703776887}, {0.9308836920770438, \
1.9258466260207303}, {0.5654203983846697, 1.891824180835018}, 
     {0.47147218925114154, 1.7374623647519976}}]}, {CMYKColor[0.75, 0.5, \
0.825, 0.1], 
   Polygon[{{0.9308836920770438, 1.9258466260207303}, {1.0709908686268506, \
2.0997996262255523}, {0.6790091313731498, 2.057368875173532}, 
     {0.5654203983846697, 1.891824180835018}}]}, {CMYKColor[0.75, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{1.0709908686268506, 2.0997996262255523}, {1.229200492911809, \
2.269958904737956}, {0.8072740155257715, 2.2226072396953476}, 
     {0.6790091313731498, 2.057368875173532}}]}, {CMYKColor[0.75, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{1.229200492911809, 2.269958904737956}, {1.3985980451766578, \
2.427623046285347}, {0.9446092599218627, 2.3792297776658278}, 
     {0.8072740155257715, 2.2226072396953476}}]}, {CMYKColor[0.75, 0.5, \
0.875, 0.1], 
   Polygon[{{1.3985980451766578, 2.427623046285347}, {1.5717800395277832, \
2.5673355087770737}, {1.0850126553736967, 2.5216249314090455}, 
     {0.9446092599218627, 2.3792297776658278}}]}, {CMYKColor[0.75, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{1.5717800395277832, 2.5673355087770737}, {1.7411775917926344, \
2.686221801523239}, {1.2223478997697896, 2.6463289817643205}, 
     {1.0850126553736967, 2.5216249314090455}}]}, {CMYKColor[0.75, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{1.7411775917926344, 2.686221801523239}, {1.8993872160775913, \
2.783394069573202}, {1.3506127839224105, 2.7515251706591934}, 
     {1.2223478997697896, 2.6463289817643205}}]}, {CMYKColor[0.75, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{1.8993872160775913, 2.783394069573202}, {2.039494392627398, \
2.859399797409292}, {1.4642015169108902, 2.8365966765934414}, 
     {1.3506127839224105, 2.7515251706591934}}]}, {CMYKColor[0.75, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{2.039494392627398, 2.859399797409292}, {2.155375765518005, \
2.9156867970745455}, {1.5581497260444195, 2.901719090978228}, 
     {1.4642015169108902, 2.8365966765934414}}]}, {CMYKColor[0.75, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{2.155375765518005, 2.9156867970745455}, {2.241966762693568, \
2.9540812792513695}, {1.6283514237703371, 2.947488384456561}, 
     {1.5581497260444195, 2.901719090978228}}]}, {CMYKColor[0.75, 0.5, 0.975, \
0.1], 
   Polygon[{{2.241966762693568, 2.9540812792513695}, {2.295482942067812, \
2.9763034938899455}, {1.6717384590329003, 2.974595082902794}, 
     {1.6283514237703371, 2.947488384456561}}]}, {CMYKColor[0.75, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{2.295482942067812, 2.9763034938899455}, {2.3135853898029626, \
2.9835656861048196}, {1.686414610197041, 2.9835656861048196}, 
     {1.6717384590329003, 2.974595082902794}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{1.686414610197041, 2.9835656861048196}, {1.6717384590329, \
2.9745950829027943}, {1.0616242894813532, 2.843497290965337}, 
     {1.0729490168751585, 2.853169548885461}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{1.6717384590329, 2.9745950829027943}, {1.6283514237703374, \
2.947488384456562}, {1.0281450522291185, 2.8144424077524017}, 
     {1.0616242894813532, 2.843497290965337}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{1.6283514237703374, 2.947488384456562}, {1.5581497260444195, \
2.9017190909782276}, {0.9739745084375796, 2.7659262761959793}, 
     {1.0281450522291185, 2.8144424077524017}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{1.5581497260444195, 2.9017190909782276}, {1.464201516910891, \
2.8365966765934414}, {0.9014801708095374, 2.6979339589171736}, 
     {0.9739745084375796, 2.7659262761959793}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{1.464201516910891, 2.8365966765934414}, {1.350612783922411, \
2.751525170659194}, {0.8138303897657639, 2.6106791787633687}, 
     {0.9014801708095374, 2.6979339589171736}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{1.350612783922411, 2.751525170659194}, {1.2223478997697899, \
2.646328981764321}, {0.7148558813281849, 2.504820390287959}, 
     {0.8138303897657639, 2.6106791787633687}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{1.2223478997697899, 2.646328981764321}, {1.0850126553736983, \
2.5216249314090464}, {0.6088823064479074, 2.3817202672447815}, 
     {0.7148558813281849, 2.504820390287959}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{1.0850126553736983, 2.5216249314090464}, {0.9446092599218634, \
2.379229777665829}, {0.5005412188648306, 2.2437468595288657}, 
     {0.6088823064479074, 2.3817202672447815}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.9446092599218634, 2.379229777665829}, {0.8072740155257718, \
2.222607239695348}, {0.394567643984553, 2.0946223601372336}, 
     {0.5005412188648306, 2.2437468595288657}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.8072740155257718, 2.222607239695348}, {0.6790091313731508, \
2.0573688751735335}, {0.29559313554697425, 1.9398272078772512}, 
     {0.394567643984553, 2.0946223601372336}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{0.6790091313731508, 2.0573688751735335}, {0.5654203983846704, \
1.8918241808350191}, {0.20794335450320056, 1.7870411277345815}, 
     {0.29559313554697425, 1.9398272078772512}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.5654203983846704, 1.8918241808350191}, {0.4714721892511417, \
1.7374623647519978}, {0.13544901687515815, 1.646496168027179}, 
     {0.20794335450320056, 1.7870411277345815}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.4714721892511417, 1.7374623647519978}, {0.40127049152522454, \
1.6089224974238359}, {0.0812784730836198, 1.5308481540548229}, 
     {0.13544901687515815, 1.646496168027179}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{0.40127049152522454, 1.6089224974238359}, {0.3578834562626614, \
1.5224519023538965}, {0.04779923583138457, 1.4537753723488893}, 
     {0.0812784730836198, 1.5308481540548229}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.3578834562626614, 1.5224519023538965}, {0.3432073050985205, \
1.49178284305241}, {0.03647450843757927, 1.4265847744427305}, 
     {0.04779923583138457, 1.4537753723488893}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.3432073050985205, 1.49178284305241}, {0.3578834562626615, \
1.5224519023538965}, {0.04779923583138457, 1.4537753723488893}, 
     {0.03647450843757927, 1.4265847744427305}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{0.3578834562626615, 1.5224519023538965}, {0.4012704915252243, \
1.6089224974238356}, {0.0812784730836198, 1.5308481540548227}, 
     {0.04779923583138457, 1.4537753723488893}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0.4012704915252243, 1.6089224974238356}, {0.47147218925114165, \
1.7374623647519978}, {0.13544901687515815, 1.646496168027179}, 
     {0.0812784730836198, 1.5308481540548227}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0.47147218925114165, 1.7374623647519978}, {0.5654203983846702, \
1.8918241808350182}, {0.20794335450320034, 1.787041127734581}, 
     {0.13544901687515815, 1.646496168027179}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{0.5654203983846702, 1.8918241808350182}, {0.6790091313731502, \
2.057368875173533}, {0.2955931355469738, 1.9398272078772505}, 
     {0.20794335450320034, 1.787041127734581}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{0.6790091313731502, 2.057368875173533}, {0.8072740155257716, \
2.222607239695348}, {0.3945676439845528, 2.0946223601372336}, 
     {0.2955931355469738, 1.9398272078772505}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0.8072740155257716, 2.222607239695348}, {0.9446092599218627, \
2.379229777665828}, {0.5005412188648302, 2.243746859528865}, 
     {0.3945676439845528, 2.0946223601372336}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{0.9446092599218627, 2.379229777665828}, {1.0850126553736974, \
2.5216249314090464}, {0.608882306447907, 2.3817202672447806}, 
     {0.5005412188648302, 2.243746859528865}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{1.0850126553736974, 2.5216249314090464}, {1.2223478997697894, \
2.646328981764321}, {0.7148558813281848, 2.5048203902879584}, 
     {0.608882306447907, 2.3817202672447806}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{1.2223478997697894, 2.646328981764321}, {1.3506127839224105, \
2.751525170659194}, {0.8138303897657635, 2.610679178763368}, 
     {0.7148558813281848, 2.5048203902879584}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{1.3506127839224105, 2.751525170659194}, {1.4642015169108908, \
2.836596676593442}, {0.9014801708095372, 2.697933958917173}, 
     {0.8138303897657635, 2.610679178763368}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{1.4642015169108908, 2.836596676593442}, {1.5581497260444195, \
2.901719090978228}, {0.9739745084375797, 2.7659262761959793}, 
     {0.9014801708095372, 2.697933958917173}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{1.5581497260444195, 2.901719090978228}, {1.6283514237703371, \
2.947488384456561}, {1.028145052229118, 2.8144424077524017}, 
     {0.9739745084375797, 2.7659262761959793}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{1.6283514237703371, 2.947488384456561}, {1.6717384590329, \
2.9745950829027943}, {1.0616242894813532, 2.843497290965337}, 
     {1.028145052229118, 2.8144424077524017}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{1.6717384590329, 2.9745950829027943}, {1.686414610197041, \
2.9835656861048196}, {1.0729490168751585, 2.853169548885461}, 
     {1.0616242894813532, 2.843497290965337}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{1.686414610197041, 2.9835656861048196}, {1.6717384590329005, \
2.9745950829027943}, {1.0616242894813537, 2.843497290965337}, 
     {1.0729490168751585, 2.853169548885461}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{1.6717384590329005, 2.9745950829027943}, {1.6283514237703374, \
2.9474883844565616}, {1.0281450522291182, 2.8144424077524013}, 
     {1.0616242894813537, 2.843497290965337}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{1.6283514237703374, 2.9474883844565616}, {1.55814972604442, \
2.901719090978228}, {0.9739745084375798, 2.7659262761959797}, 
     {1.0281450522291182, 2.8144424077524013}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{1.55814972604442, 2.901719090978228}, {1.4642015169108917, \
2.836596676593442}, {0.9014801708095378, 2.6979339589171736}, 
     {0.9739745084375798, 2.7659262761959797}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{1.4642015169108917, 2.836596676593442}, {1.3506127839224114, \
2.7515251706591943}, {0.8138303897657642, 2.6106791787633687}, 
     {0.9014801708095378, 2.6979339589171736}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{1.3506127839224114, 2.7515251706591943}, {1.22234789976979, \
2.646328981764321}, {0.7148558813281853, 2.5048203902879593}, 
     {0.8138303897657642, 2.6106791787633687}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{1.22234789976979, 2.646328981764321}, {1.0850126553736987, \
2.5216249314090473}, {0.6088823064479079, 2.381720267244782}, 
     {0.7148558813281853, 2.5048203902879593}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{1.0850126553736987, 2.5216249314090473}, {0.9446092599218641, \
2.3792297776658295}, {0.5005412188648309, 2.243746859528866}, 
     {0.6088823064479079, 2.381720267244782}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0.9446092599218641, 2.3792297776658295}, {0.807274015525772, \
2.2226072396953485}, {0.39456764398455324, 2.094622360137234}, 
     {0.5005412188648309, 2.243746859528866}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0.807274015525772, 2.2226072396953485}, {0.6790091313731512, \
2.0573688751735344}, {0.29559313554697453, 1.9398272078772518}, 
     {0.39456764398455324, 2.094622360137234}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{0.6790091313731512, 2.0573688751735344}, {0.565420398384671, \
1.8918241808350198}, {0.20794335450320095, 1.7870411277345821}, 
     {0.29559313554697453, 1.9398272078772518}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0.565420398384671, 1.8918241808350198}, {0.47147218925114187, \
1.737462364751998}, {0.13544901687515826, 1.6464961680271792}, 
     {0.20794335450320095, 1.7870411277345821}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0.47147218925114187, 1.737462364751998}, {0.40127049152522487, \
1.6089224974238363}, {0.08127847308362002, 1.5308481540548233}, 
     {0.13544901687515826, 1.6464961680271792}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{0.40127049152522487, 1.6089224974238363}, {0.3578834562626616, \
1.522451902353897}, {0.04779923583138479, 1.4537753723488898}, 
     {0.08127847308362002, 1.5308481540548233}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.3578834562626616, 1.522451902353897}, {0.3432073050985205, \
1.49178284305241}, {0.03647450843757927, 1.4265847744427305}, 
     {0.04779923583138479, 1.4537753723488898}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.3432073050985205, 1.49178284305241}, {0.35788345626266127, \
1.5224519023538963}, {0.04779923583138446, 1.453775372348889}, 
     {0.03647450843757927, 1.4265847744427305}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{0.35788345626266127, 1.5224519023538963}, {0.401270491525224, \
1.608922497423835}, {0.08127847308361935, 1.530848154054822}, 
     {0.04779923583138446, 1.453775372348889}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.401270491525224, 1.608922497423835}, {0.47147218925114154, \
1.7374623647519976}, {0.13544901687515803, 1.6464961680271788}, 
     {0.08127847308361935, 1.530848154054822}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.47147218925114154, 1.7374623647519976}, {0.5654203983846697, \
1.891824180835018}, {0.20794335450320006, 1.7870411277345806}, 
     {0.13544901687515803, 1.6464961680271788}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{0.5654203983846697, 1.891824180835018}, {0.6790091313731498, \
2.057368875173532}, {0.29559313554697336, 1.9398272078772498}, 
     {0.20794335450320006, 1.7870411277345806}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.6790091313731498, 2.057368875173532}, {0.8072740155257715, \
2.2226072396953476}, {0.3945676439845528, 2.094622360137233}, 
     {0.29559313554697336, 1.9398272078772498}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.8072740155257715, 2.2226072396953476}, {0.9446092599218627, \
2.3792297776658278}, {0.5005412188648299, 2.243746859528865}, 
     {0.3945676439845528, 2.094622360137233}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{0.9446092599218627, 2.3792297776658278}, {1.0850126553736967, \
2.5216249314090455}, {0.6088823064479063, 2.38172026724478}, 
     {0.5005412188648299, 2.243746859528865}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{1.0850126553736967, 2.5216249314090455}, {1.2223478997697896, \
2.6463289817643205}, {0.7148558813281849, 2.5048203902879584}, 
     {0.6088823064479063, 2.38172026724478}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{1.2223478997697896, 2.6463289817643205}, {1.3506127839224105, \
2.7515251706591934}, {0.8138303897657633, 2.610679178763368}, 
     {0.7148558813281849, 2.5048203902879584}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{1.3506127839224105, 2.7515251706591934}, {1.4642015169108902, \
2.8365966765934414}, {0.9014801708095367, 2.6979339589171727}, 
     {0.8138303897657633, 2.610679178763368}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{1.4642015169108902, 2.8365966765934414}, {1.5581497260444195, \
2.901719090978228}, {0.9739745084375797, 2.7659262761959793}, 
     {0.9014801708095367, 2.6979339589171727}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{1.5581497260444195, 2.901719090978228}, {1.6283514237703371, \
2.947488384456561}, {1.028145052229118, 2.8144424077524017}, 
     {0.9739745084375797, 2.7659262761959793}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{1.6283514237703371, 2.947488384456561}, {1.6717384590329003, \
2.974595082902794}, {1.0616242894813532, 2.843497290965337}, 
     {1.028145052229118, 2.8144424077524017}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{1.6717384590329003, 2.974595082902794}, {1.686414610197041, \
2.9835656861048196}, {1.0729490168751585, 2.853169548885461}, 
     {1.0616242894813532, 2.843497290965337}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{1.0729490168751585, 2.853169548885461}, {1.0616242894813532, \
2.843497290965337}, {0.491805350275179, 2.5885835797530192}, 
     {0.5000000000000021, 2.5980762113533173}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{1.0616242894813532, 2.843497290965337}, {1.0281450522291185, \
2.8144424077524017}, {0.46757954661597756, 2.56016136091033}, 
     {0.491805350275179, 2.5885835797530192}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{1.0281450522291185, 2.8144424077524017}, {0.9739745084375796, \
2.7659262761959793}, {0.4283813728906071, 2.5129980122544073}, 
     {0.46757954661597756, 2.56016136091033}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.9739745084375796, 2.7659262761959793}, {0.9014801708095374, \
2.6979339589171736}, {0.3759239773845737, 2.4474780907945575}, 
     {0.4283813728906071, 2.5129980122544073}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{0.9014801708095374, 2.6979339589171736}, {0.8138303897657639, \
2.6106791787633687}, {0.3125000000000019, 2.3642850399222186}, 
     {0.3759239773845737, 2.4474780907945575}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.8138303897657639, 2.6106791787633687}, {0.7148558813281849, \
2.504820390287959}, {0.24088137289060696, 2.2645409632922475}, 
     {0.3125000000000019, 2.3642850399222186}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.7148558813281849, 2.504820390287959}, {0.6088823064479074, \
2.3817202672447815}, {0.1641981737253718, 2.149982831518161}, 
     {0.24088137289060696, 2.2645409632922475}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{0.6088823064479074, 2.3817202672447815}, {0.5005412188648306, \
2.2437468595288657}, {0.0858018262746314, 2.0231783980979907}, 
     {0.1641981737253718, 2.149982831518161}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.5005412188648306, 2.2437468595288657}, {0.394567643984553, \
2.0946223601372336}, {0.009118627109396094, 1.8877889819588962}, 
     {0.0858018262746314, 2.0231783980979907}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.394567643984553, 2.0946223601372336}, {0.29559313554697425, \
1.9398272078772512}, {-0.06249999999999867, 1.7488835724541536}, 
     {0.009118627109396094, 1.8877889819588962}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{0.29559313554697425, 1.9398272078772512}, {0.20794335450320056, \
1.7870411277345815}, {-0.12592397738457056, 1.6132809148526024}, 
     {-0.06249999999999867, 1.7488835724541536}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.20794335450320056, 1.7870411277345815}, {0.13544901687515815, \
1.646496168027179}, {-0.17838137289060418, 1.4898021598760784}, 
     {-0.12592397738457056, 1.6132809148526024}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.13544901687515815, 1.646496168027179}, {0.0812784730836198, \
1.5308481540548229}, {-0.21757954661597428, 1.3891012614574076}, 
     {-0.17838137289060418, 1.4898021598760784}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{0.0812784730836198, 1.5308481540548229}, {0.04779923583138457, \
1.4537753723488893}, {-0.24180535027517608, 1.3224570770547}, 
     {-0.21757954661597428, 1.3891012614574076}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.04779923583138457, 1.4537753723488893}, {0.03647450843757927, \
1.4265847744427305}, {-0.249999999999999, 1.2990381056766584}, 
     {-0.24180535027517608, 1.3224570770547}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0.03647450843757927, 1.4265847744427305}, {0.04779923583138457, \
1.4537753723488893}, {-0.24180535027517608, 1.3224570770547}, 
     {-0.249999999999999, 1.2990381056766584}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{0.04779923583138457, 1.4537753723488893}, {0.0812784730836198, \
1.5308481540548227}, {-0.2175795466159744, 1.3891012614574074}, 
     {-0.24180535027517608, 1.3224570770547}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0.0812784730836198, 1.5308481540548227}, {0.13544901687515815, \
1.646496168027179}, {-0.17838137289060418, 1.4898021598760782}, 
     {-0.2175795466159744, 1.3891012614574074}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0.13544901687515815, 1.646496168027179}, {0.20794335450320034, \
1.787041127734581}, {-0.12592397738457067, 1.6132809148526022}, 
     {-0.17838137289060418, 1.4898021598760782}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{0.20794335450320034, 1.787041127734581}, {0.2955931355469738, \
1.9398272078772505}, {-0.062499999999998945, 1.7488835724541534}, 
     {-0.12592397738457067, 1.6132809148526022}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{0.2955931355469738, 1.9398272078772505}, {0.3945676439845528, \
2.0946223601372336}, {0.009118627109395983, 1.887788981958896}, 
     {-0.062499999999998945, 1.7488835724541534}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0.3945676439845528, 2.0946223601372336}, {0.5005412188648302, \
2.243746859528865}, {0.08580182627463112, 2.0231783980979903}, 
     {0.009118627109395983, 1.887788981958896}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{0.5005412188648302, 2.243746859528865}, {0.608882306447907, \
2.3817202672447806}, {0.1641981737253714, 2.14998283151816}, 
     {0.08580182627463112, 2.0231783980979903}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{0.608882306447907, 2.3817202672447806}, {0.7148558813281848, \
2.5048203902879584}, {0.24088137289060693, 2.264540963292247}, 
     {0.1641981737253714, 2.14998283151816}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{0.7148558813281848, 2.5048203902879584}, {0.8138303897657635, \
2.610679178763368}, {0.31250000000000155, 2.3642850399222177}, 
     {0.24088137289060693, 2.264540963292247}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{0.8138303897657635, 2.610679178763368}, {0.9014801708095372, \
2.697933958917173}, {0.3759239773845736, 2.4474780907945575}, 
     {0.31250000000000155, 2.3642850399222177}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{0.9014801708095372, 2.697933958917173}, {0.9739745084375797, \
2.7659262761959793}, {0.4283813728906072, 2.5129980122544073}, 
     {0.3759239773845736, 2.4474780907945575}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{0.9739745084375797, 2.7659262761959793}, {1.028145052229118, \
2.8144424077524017}, {0.4675795466159774, 2.5601613609103295}, 
     {0.4283813728906072, 2.5129980122544073}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{1.028145052229118, 2.8144424077524017}, {1.0616242894813532, \
2.843497290965337}, {0.4918053502751791, 2.5885835797530192}, 
     {0.4675795466159774, 2.5601613609103295}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{1.0616242894813532, 2.843497290965337}, {1.0729490168751585, \
2.853169548885461}, {0.5000000000000021, 2.5980762113533173}, 
     {0.4918053502751791, 2.5885835797530192}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{1.0729490168751585, 2.853169548885461}, {1.0616242894813537, \
2.843497290965337}, {0.49180535027517946, 2.5885835797530197}, 
     {0.5000000000000021, 2.5980762113533173}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{1.0616242894813537, 2.843497290965337}, {1.0281450522291182, \
2.8144424077524013}, {0.4675795466159775, 2.56016136091033}, 
     {0.49180535027517946, 2.5885835797530197}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{1.0281450522291182, 2.8144424077524013}, {0.9739745084375798, \
2.7659262761959797}, {0.4283813728906073, 2.5129980122544078}, 
     {0.4675795466159775, 2.56016136091033}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{0.9739745084375798, 2.7659262761959797}, {0.9014801708095378, \
2.6979339589171736}, {0.375923977384574, 2.4474780907945575}, 
     {0.4283813728906073, 2.5129980122544078}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.575, 0.1], 
   Polygon[{{0.9014801708095378, 2.6979339589171736}, {0.8138303897657642, \
2.6106791787633687}, {0.3125000000000021, 2.3642850399222186}, 
     {0.375923977384574, 2.4474780907945575}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{0.8138303897657642, 2.6106791787633687}, {0.7148558813281853, \
2.5048203902879593}, {0.24088137289060724, 2.2645409632922475}, 
     {0.3125000000000021, 2.3642850399222186}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{0.7148558813281853, 2.5048203902879593}, {0.6088823064479079, \
2.381720267244782}, {0.1641981737253721, 2.1499828315181615}, 
     {0.24088137289060724, 2.2645409632922475}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{0.6088823064479079, 2.381720267244782}, {0.5005412188648309, \
2.243746859528866}, {0.08580182627463168, 2.023178398097991}, 
     {0.1641981737253721, 2.1499828315181615}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0.5005412188648309, 2.243746859528866}, {0.39456764398455324, \
2.094622360137234}, {0.00911862710939626, 1.8877889819588964}, 
     {0.08580182627463168, 2.023178398097991}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0.39456764398455324, 2.094622360137234}, {0.29559313554697453, \
1.9398272078772518}, {-0.06249999999999839, 1.7488835724541543}, 
     {0.00911862710939626, 1.8877889819588964}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.675, 0.1], 
   Polygon[{{0.29559313554697453, 1.9398272078772518}, {0.20794335450320095, \
1.7870411277345821}, {-0.12592397738457028, 1.613280914852603}, 
     {-0.06249999999999839, 1.7488835724541543}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0.20794335450320095, 1.7870411277345821}, {0.13544901687515826, \
1.6464961680271792}, {-0.17838137289060407, 1.4898021598760784}, 
     {-0.12592397738457028, 1.613280914852603}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0.13544901687515826, 1.6464961680271792}, {0.08127847308362002, \
1.5308481540548233}, {-0.21757954661597417, 1.3891012614574079}, 
     {-0.17838137289060407, 1.4898021598760784}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{0.08127847308362002, 1.5308481540548233}, {0.04779923583138479, \
1.4537753723488898}, {-0.24180535027517597, 1.3224570770547004}, 
     {-0.21757954661597417, 1.3891012614574079}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0.04779923583138479, 1.4537753723488898}, {0.03647450843757927, \
1.4265847744427305}, {-0.249999999999999, 1.2990381056766584}, 
     {-0.24180535027517597, 1.3224570770547004}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0.03647450843757927, 1.4265847744427305}, {0.04779923583138446, \
1.453775372348889}, {-0.2418053502751762, 1.3224570770547}, 
     {-0.249999999999999, 1.2990381056766584}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.775, 0.1], 
   Polygon[{{0.04779923583138446, 1.453775372348889}, {0.08127847308361935, \
1.530848154054822}, {-0.21757954661597456, 1.389101261457407}, 
     {-0.2418053502751762, 1.3224570770547}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.08127847308361935, 1.530848154054822}, {0.13544901687515803, \
1.6464961680271788}, {-0.1783813728906043, 1.489802159876078}, 
     {-0.21757954661597456, 1.389101261457407}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.13544901687515803, 1.6464961680271788}, {0.20794335450320006, \
1.7870411277345806}, {-0.125923977384571, 1.6132809148526015}, 
     {-0.1783813728906043, 1.489802159876078}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{0.20794335450320006, 1.7870411277345806}, {0.29559313554697336, \
1.9398272078772498}, {-0.06249999999999922, 1.7488835724541525}, 
     {-0.125923977384571, 1.6132809148526015}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.29559313554697336, 1.9398272078772498}, {0.3945676439845528, \
2.094622360137233}, {0.009118627109395927, 1.887788981958896}, 
     {-0.06249999999999922, 1.7488835724541525}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.3945676439845528, 2.094622360137233}, {0.5005412188648299, \
2.243746859528865}, {0.08580182627463095, 2.02317839809799}, 
     {0.009118627109395927, 1.887788981958896}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{0.5005412188648299, 2.243746859528865}, {0.6088823064479063, \
2.38172026724478}, {0.16419817372537102, 2.1499828315181597}, 
     {0.08580182627463095, 2.02317839809799}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.6088823064479063, 2.38172026724478}, {0.7148558813281849, \
2.5048203902879584}, {0.240881372890607, 2.264540963292247}, 
     {0.16419817372537102, 2.1499828315181597}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.7148558813281849, 2.5048203902879584}, {0.8138303897657633, \
2.610679178763368}, {0.3125000000000015, 2.3642850399222177}, 
     {0.240881372890607, 2.264540963292247}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.8138303897657633, 2.610679178763368}, {0.9014801708095367, \
2.6979339589171727}, {0.37592397738457317, 2.4474780907945566}, 
     {0.3125000000000015, 2.3642850399222177}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.9014801708095367, 2.6979339589171727}, {0.9739745084375797, \
2.7659262761959793}, {0.4283813728906072, 2.5129980122544073}, 
     {0.37592397738457317, 2.4474780907945566}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.9739745084375797, 2.7659262761959793}, {1.028145052229118, \
2.8144424077524017}, {0.46757954661597745, 2.5601613609103295}, 
     {0.4283813728906072, 2.5129980122544073}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{1.028145052229118, 2.8144424077524017}, {1.0616242894813532, \
2.843497290965337}, {0.49180535027517913, 2.5885835797530192}, 
     {0.46757954661597745, 2.5601613609103295}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{1.0616242894813532, 2.843497290965337}, {1.0729490168751585, \
2.853169548885461}, {0.5000000000000021, 2.5980762113533173}, 
     {0.49180535027517913, 2.5885835797530192}}]}, {CMYKColor[0.85, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{0.5000000000000021, 2.5980762113533173}, {0.491805350275179, \
2.5885835797530192}, {-0.012814536647680919, 2.2208803408437965}, 
     {-0.0073918190765734915, 2.2294344764321834}}]}, {CMYKColor[0.85, 0.5, \
0.025, 0.1], 
   Polygon[{{0.491805350275179, 2.5885835797530192}, {0.46757954661597756, \
2.56016136091033}, {-0.02884569058205967, 2.1953185530328274}, 
     {-0.012814536647680919, 2.2208803408437965}}]}, {CMYKColor[0.85, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{0.46757954661597756, 2.56016136091033}, {0.4283813728906071, \
2.5129980122544073}, {-0.05478464252676654, 2.153063306659971}, 
     {-0.02884569058205967, 2.1953185530328274}}]}, {CMYKColor[0.85, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{0.4283813728906071, 2.5129980122544073}, {0.3759239773845737, \
2.4474780907945575}, {-0.08949773581291628, 2.094679321954477}, 
     {-0.05478464252676654, 2.153063306659971}}]}, {CMYKColor[0.85, 0.5, \
0.075, 0.1], 
   Polygon[{{0.3759239773845737, 2.4474780907945575}, {0.3125000000000019, \
2.3642850399222186}, {-0.13146784169200168, 2.0210434859217044}, 
     {-0.08949773581291628, 2.094679321954477}}]}, {CMYKColor[0.85, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{0.3125000000000019, 2.3642850399222186}, {0.24088137289060696, \
2.2645409632922475}, {-0.17886066514219484, 1.933432094411192}, 
     {-0.13146784169200168, 2.0210434859217044}}]}, {CMYKColor[0.85, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{0.24088137289060696, 2.2645409632922475}, {0.1641981737253718, \
2.149982831518161}, {-0.22960491236272335, 1.8336364565828096}, 
     {-0.17886066514219484, 1.933432094411192}}]}, {CMYKColor[0.85, 0.5, \
0.125, 0.1], 
   Polygon[{{0.1641981737253718, 2.149982831518161}, {0.0858018262746314, \
2.0231783980979907}, {-0.28148281625213684, 1.7241122839361502}, 
     {-0.22960491236272335, 1.8336364565828096}}]}, {CMYKColor[0.85, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{0.0858018262746314, 2.0231783980979907}, {0.009118627109396094, \
1.8877889819588962}, {-0.3322270634726655, 1.6081701375219575}, 
     {-0.28148281625213684, 1.7241122839361502}}]}, {CMYKColor[0.85, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{0.009118627109396094, 1.8877889819588962}, \
{-0.06249999999999867, 1.7488835724541536}, {-0.3796198869228584, \
1.4902097135042398}, 
     {-0.3322270634726655, 1.6081701375219575}}]}, {CMYKColor[0.85, 0.5, \
0.175, 0.1], 
   Polygon[{{-0.06249999999999867, 1.7488835724541536}, \
{-0.12592397738457056, 1.6132809148526024}, {-0.421589992801944, \
1.3759750672106559}, 
     {-0.3796198869228584, 1.4902097135042398}}]}, {CMYKColor[0.85, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{-0.12592397738457056, 1.6132809148526024}, \
{-0.17838137289060418, 1.4898021598760784}, {-0.4563030860880937, \
1.2727298803122153}, 
     {-0.421589992801944, 1.3759750672106559}}]}, {CMYKColor[0.85, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{-0.17838137289060418, 1.4898021598760784}, \
{-0.21757954661597428, 1.3891012614574076}, {-0.48224203803280036, \
1.1890852819516726}, 
     {-0.4563030860880937, 1.2727298803122153}}]}, {CMYKColor[0.85, 0.5, \
0.225, 0.1], 
   Polygon[{{-0.21757954661597428, 1.3891012614574076}, \
{-0.24180535027517608, 1.3224570770547}, {-0.49827319196717934, \
1.1340136417284863}, 
     {-0.48224203803280036, 1.1890852819516726}}]}, {CMYKColor[0.85, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{-0.24180535027517608, 1.3224570770547}, {-0.249999999999999, \
1.2990381056766584}, {-0.5036959095382867, 1.1147172382160917}, 
     {-0.49827319196717934, 1.1340136417284863}}]}, {CMYKColor[0.85, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{-0.249999999999999, 1.2990381056766584}, {-0.24180535027517608, \
1.3224570770547}, {-0.4982731919671793, 1.1340136417284863}, 
     {-0.5036959095382867, 1.1147172382160917}}]}, {CMYKColor[0.85, 0.5, \
0.275, 0.1], 
   Polygon[{{-0.24180535027517608, 1.3224570770547}, {-0.2175795466159744, \
1.3891012614574074}, {-0.4822420380328004, 1.1890852819516724}, 
     {-0.4982731919671793, 1.1340136417284863}}]}, {CMYKColor[0.85, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{-0.2175795466159744, 1.3891012614574074}, {-0.17838137289060418, \
1.4898021598760782}, {-0.4563030860880938, 1.2727298803122153}, 
     {-0.4822420380328004, 1.1890852819516724}}]}, {CMYKColor[0.85, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{-0.17838137289060418, 1.4898021598760782}, \
{-0.12592397738457067, 1.6132809148526022}, {-0.42158999280194415, \
1.3759750672106557}, 
     {-0.4563030860880938, 1.2727298803122153}}]}, {CMYKColor[0.85, 0.5, \
0.325, 0.1], 
   Polygon[{{-0.12592397738457067, 1.6132809148526022}, \
{-0.062499999999998945, 1.7488835724541534}, {-0.37961988692285853, \
1.4902097135042391}, 
     {-0.42158999280194415, 1.3759750672106557}}]}, {CMYKColor[0.85, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{-0.062499999999998945, 1.7488835724541534}, \
{0.009118627109395983, 1.887788981958896}, {-0.3322270634726655, \
1.6081701375219573}, 
     {-0.37961988692285853, 1.4902097135042391}}]}, {CMYKColor[0.85, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{0.009118627109395983, 1.887788981958896}, {0.08580182627463112, \
2.0231783980979903}, {-0.281482816252137, 1.72411228393615}, 
     {-0.3322270634726655, 1.6081701375219573}}]}, {CMYKColor[0.85, 0.5, \
0.375, 0.1], 
   Polygon[{{0.08580182627463112, 2.0231783980979903}, {0.1641981737253714, \
2.14998283151816}, {-0.22960491236272362, 1.8336364565828094}, 
     {-0.281482816252137, 1.72411228393615}}]}, {CMYKColor[0.85, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{0.1641981737253714, 2.14998283151816}, {0.24088137289060693, \
2.264540963292247}, {-0.1788606651421949, 1.9334320944111918}, 
     {-0.22960491236272362, 1.8336364565828094}}]}, {CMYKColor[0.85, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{0.24088137289060693, 2.264540963292247}, {0.31250000000000155, \
2.3642850399222177}, {-0.13146784169200199, 2.021043485921704}, 
     {-0.1788606651421949, 1.9334320944111918}}]}, {CMYKColor[0.85, 0.5, \
0.425, 0.1], 
   Polygon[{{0.31250000000000155, 2.3642850399222177}, {0.3759239773845736, \
2.4474780907945575}, {-0.08949773581291631, 2.094679321954477}, 
     {-0.13146784169200199, 2.021043485921704}}]}, {CMYKColor[0.85, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{0.3759239773845736, 2.4474780907945575}, {0.4283813728906072, \
2.5129980122544073}, {-0.054784642526766514, 2.153063306659971}, 
     {-0.08949773581291631, 2.094679321954477}}]}, {CMYKColor[0.85, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{0.4283813728906072, 2.5129980122544073}, {0.4675795466159774, \
2.5601613609103295}, {-0.028845690582059838, 2.195318553032827}, 
     {-0.054784642526766514, 2.153063306659971}}]}, {CMYKColor[0.85, 0.5, \
0.475, 0.1], 
   Polygon[{{0.4675795466159774, 2.5601613609103295}, {0.4918053502751791, \
2.5885835797530192}, {-0.0128145366476809, 2.2208803408437965}, 
     {-0.028845690582059838, 2.195318553032827}}]}, {CMYKColor[0.85, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{0.4918053502751791, 2.5885835797530192}, {0.5000000000000021, \
2.5980762113533173}, {-0.0073918190765734915, 2.2294344764321834}, 
     {-0.0128145366476809, 2.2208803408437965}}]}, {CMYKColor[0.85, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{0.5000000000000021, 2.5980762113533173}, {0.49180535027517946, \
2.5885835797530197}, {-0.012814536647680836, 2.220880340843797}, 
     {-0.0073918190765734915, 2.2294344764321834}}]}, {CMYKColor[0.85, 0.5, \
0.525, 0.1], 
   Polygon[{{0.49180535027517946, 2.5885835797530197}, {0.4675795466159775, \
2.56016136091033}, {-0.028845690582059706, 2.1953185530328274}, 
     {-0.012814536647680836, 2.220880340843797}}]}, {CMYKColor[0.85, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{0.4675795466159775, 2.56016136091033}, {0.4283813728906073, \
2.5129980122544078}, {-0.05478464252676645, 2.153063306659971}, 
     {-0.028845690582059706, 2.1953185530328274}}]}, {CMYKColor[0.85, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{0.4283813728906073, 2.5129980122544078}, {0.375923977384574, \
2.4474780907945575}, {-0.08949773581291603, 2.0946793219544775}, 
     {-0.05478464252676645, 2.153063306659971}}]}, {CMYKColor[0.85, 0.5, \
0.575, 0.1], 
   Polygon[{{0.375923977384574, 2.4474780907945575}, {0.3125000000000021, \
2.3642850399222186}, {-0.13146784169200165, 2.0210434859217044}, 
     {-0.08949773581291603, 2.0946793219544775}}]}, {CMYKColor[0.85, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{0.3125000000000021, 2.3642850399222186}, {0.24088137289060724, \
2.2645409632922475}, {-0.17886066514219465, 1.9334320944111922}, 
     {-0.13146784169200165, 2.0210434859217044}}]}, {CMYKColor[0.85, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{0.24088137289060724, 2.2645409632922475}, {0.1641981737253721, \
2.1499828315181615}, {-0.22960491236272318, 1.8336364565828103}, 
     {-0.17886066514219465, 1.9334320944111922}}]}, {CMYKColor[0.85, 0.5, \
0.625, 0.1], 
   Polygon[{{0.1641981737253721, 2.1499828315181615}, {0.08580182627463168, \
2.023178398097991}, {-0.28148281625213667, 1.7241122839361507}, 
     {-0.22960491236272318, 1.8336364565828103}}]}, {CMYKColor[0.85, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{0.08580182627463168, 2.023178398097991}, {0.00911862710939626, \
1.8877889819588964}, {-0.33222706347266534, 1.6081701375219577}, 
     {-0.28148281625213667, 1.7241122839361507}}]}, {CMYKColor[0.85, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{0.00911862710939626, 1.8877889819588964}, {-0.06249999999999839, \
1.7488835724541543}, {-0.3796198869228583, 1.49020971350424}, 
     {-0.33222706347266534, 1.6081701375219577}}]}, {CMYKColor[0.85, 0.5, \
0.675, 0.1], 
   Polygon[{{-0.06249999999999839, 1.7488835724541543}, \
{-0.12592397738457028, 1.613280914852603}, {-0.42158999280194376, \
1.3759750672106568}, 
     {-0.3796198869228583, 1.49020971350424}}]}, {CMYKColor[0.85, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{-0.12592397738457028, 1.613280914852603}, {-0.17838137289060407, \
1.4898021598760784}, {-0.4563030860880937, 1.2727298803122153}, 
     {-0.42158999280194376, 1.3759750672106568}}]}, {CMYKColor[0.85, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{-0.17838137289060407, 1.4898021598760784}, \
{-0.21757954661597417, 1.3891012614574079}, {-0.48224203803280025, \
1.1890852819516728}, 
     {-0.4563030860880937, 1.2727298803122153}}]}, {CMYKColor[0.85, 0.5, \
0.725, 0.1], 
   Polygon[{{-0.21757954661597417, 1.3891012614574079}, \
{-0.24180535027517597, 1.3224570770547004}, {-0.49827319196717923, \
1.1340136417284865}, 
     {-0.48224203803280025, 1.1890852819516728}}]}, {CMYKColor[0.85, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{-0.24180535027517597, 1.3224570770547004}, {-0.249999999999999, \
1.2990381056766584}, {-0.5036959095382867, 1.1147172382160917}, 
     {-0.49827319196717923, 1.1340136417284865}}]}, {CMYKColor[0.85, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{-0.249999999999999, 1.2990381056766584}, {-0.2418053502751762, \
1.3224570770547}, {-0.4982731919671794, 1.134013641728486}, 
     {-0.5036959095382867, 1.1147172382160917}}]}, {CMYKColor[0.85, 0.5, \
0.775, 0.1], 
   Polygon[{{-0.2418053502751762, 1.3224570770547}, {-0.21757954661597456, \
1.389101261457407}, {-0.4822420380328006, 1.189085281951672}, 
     {-0.4982731919671794, 1.134013641728486}}]}, {CMYKColor[0.85, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{-0.21757954661597456, 1.389101261457407}, {-0.1783813728906043, \
1.489802159876078}, {-0.4563030860880938, 1.2727298803122151}, 
     {-0.4822420380328006, 1.189085281951672}}]}, {CMYKColor[0.85, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{-0.1783813728906043, 1.489802159876078}, {-0.125923977384571, \
1.6132809148526015}, {-0.4215899928019442, 1.3759750672106552}, 
     {-0.4563030860880938, 1.2727298803122151}}]}, {CMYKColor[0.85, 0.5, \
0.825, 0.1], 
   Polygon[{{-0.125923977384571, 1.6132809148526015}, {-0.06249999999999922, \
1.7488835724541525}, {-0.3796198869228588, 1.4902097135042387}, 
     {-0.4215899928019442, 1.3759750672106552}}]}, {CMYKColor[0.85, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{-0.06249999999999922, 1.7488835724541525}, \
{0.009118627109395927, 1.887788981958896}, {-0.33222706347266556, \
1.6081701375219573}, 
     {-0.3796198869228588, 1.4902097135042387}}]}, {CMYKColor[0.85, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{0.009118627109395927, 1.887788981958896}, {0.08580182627463095, \
2.02317839809799}, {-0.2814828162521371, 1.7241122839361496}, 
     {-0.33222706347266556, 1.6081701375219573}}]}, {CMYKColor[0.85, 0.5, \
0.875, 0.1], 
   Polygon[{{0.08580182627463095, 2.02317839809799}, {0.16419817372537102, \
2.1499828315181597}, {-0.2296049123627239, 1.833636456582809}, 
     {-0.2814828162521371, 1.7241122839361496}}]}, {CMYKColor[0.85, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{0.16419817372537102, 2.1499828315181597}, {0.240881372890607, \
2.264540963292247}, {-0.17886066514219484, 1.9334320944111918}, 
     {-0.2296049123627239, 1.833636456582809}}]}, {CMYKColor[0.85, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{0.240881372890607, 2.264540963292247}, {0.3125000000000015, \
2.3642850399222177}, {-0.13146784169200207, 2.021043485921704}, 
     {-0.17886066514219484, 1.9334320944111918}}]}, {CMYKColor[0.85, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{0.3125000000000015, 2.3642850399222177}, {0.37592397738457317, \
2.4474780907945566}, {-0.0894977358129165, 2.0946793219544766}, 
     {-0.13146784169200207, 2.021043485921704}}]}, {CMYKColor[0.85, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{0.37592397738457317, 2.4474780907945566}, {0.4283813728906072, \
2.5129980122544073}, {-0.05478464252676649, 2.153063306659971}, 
     {-0.0894977358129165, 2.0946793219544766}}]}, {CMYKColor[0.85, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{0.4283813728906072, 2.5129980122544073}, {0.46757954661597745, \
2.5601613609103295}, {-0.02884569058205982, 2.195318553032827}, 
     {-0.05478464252676649, 2.153063306659971}}]}, {CMYKColor[0.85, 0.5, \
0.975, 0.1], 
   Polygon[{{0.46757954661597745, 2.5601613609103295}, {0.49180535027517913, \
2.5885835797530192}, {-0.01281453664768086, 2.2208803408437965}, 
     {-0.02884569058205982, 2.195318553032827}}]}, {CMYKColor[0.85, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{0.49180535027517913, 2.5885835797530192}, {0.5000000000000021, \
2.5980762113533173}, {-0.0073918190765734915, 2.2294344764321834}, 
     {-0.01281453664768086, 2.2208803408437965}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{-0.0073918190765734915, 2.2294344764321834}, \
{-0.012814536647680919, 2.2208803408437965}, {-0.43018106079382434, \
1.75636834939373}, 
     {-0.4270509831248419, 1.7633557568774199}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{-0.012814536647680919, 2.2208803408437965}, \
{-0.02884569058205967, 2.1953185530328274}, {-0.4394344943868577, \
1.7355139912456736}, 
     {-0.43018106079382434, 1.75636834939373}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{-0.02884569058205967, 2.1953185530328274}, \
{-0.05478464252676654, 2.153063306659971}, {-0.45440686445302614, \
1.7011229525643676}, 
     {-0.4394344943868577, 1.7355139912456736}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{-0.05478464252676654, 2.153063306659971}, {-0.08949773581291628, \
2.094679321954477}, {-0.474443806575035, 1.6537682358032737}, 
     {-0.45440686445302614, 1.7011229525643676}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{-0.08949773581291628, 2.094679321954477}, {-0.13146784169200168, \
2.0210434859217044}, {-0.4986696102342367, 1.594300566883078}, 
     {-0.474443806575035, 1.6537682358032737}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{-0.13146784169200168, 2.0210434859217044}, \
{-0.17886066514219484, 1.933432094411192}, {-0.5260254915624208, \
1.5239001577085334}, 
     {-0.4986696102342367, 1.594300566883078}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{-0.17886066514219484, 1.933432094411192}, {-0.22960491236272335, \
1.8336364565828096}, {-0.5553158672774632, 1.4441489417584887}, 
     {-0.5260254915624208, 1.5239001577085334}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{-0.22960491236272335, 1.8336364565828096}, \
{-0.28148281625213684, 1.7241122839361502}, {-0.5852606074097998, \
1.3571288512592459}, 
     {-0.5553158672774632, 1.4441489417584887}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{-0.28148281625213684, 1.7241122839361502}, {-0.3322270634726655, \
1.6081701375219575}, {-0.614550983124842, 1.2655525104241712}, 
     {-0.5852606074097998, 1.3571288512592459}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{-0.3322270634726655, 1.6081701375219575}, {-0.3796198869228584, \
1.4902097135042398}, {-0.6419068644530261, 1.1729281630054873}, 
     {-0.614550983124842, 1.2655525104241712}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{-0.3796198869228584, 1.4902097135042398}, {-0.421589992801944, \
1.3759750672106559}, {-0.6661326681122279, 1.0837396094369784}, 
     {-0.6419068644530261, 1.1729281630054873}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{-0.421589992801944, 1.3759750672106559}, {-0.4563030860880937, \
1.2727298803122153}, {-0.6861696102342367, 1.0035621274868158}, 
     {-0.6661326681122279, 1.0837396094369784}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{-0.4563030860880937, 1.2727298803122153}, {-0.48224203803280036, \
1.1890852819516726}, {-0.701141980300405, 0.9389137397717199}, 
     {-0.6861696102342367, 1.0035621274868158}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{-0.48224203803280036, 1.1890852819516726}, \
{-0.49827319196717934, 1.1340136417284863}, {-0.7103954138934385, \
0.896506223090295}, 
     {-0.701141980300405, 0.9389137397717199}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{-0.49827319196717934, 1.1340136417284863}, {-0.5036959095382867, \
1.1147172382160917}, {-0.713525491562421, 0.8816778784387099}, 
     {-0.7103954138934385, 0.896506223090295}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{-0.5036959095382867, 1.1147172382160917}, {-0.4982731919671793, \
1.1340136417284863}, {-0.7103954138934385, 0.896506223090295}, 
     {-0.713525491562421, 0.8816778784387099}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{-0.4982731919671793, 1.1340136417284863}, {-0.4822420380328004, \
1.1890852819516724}, {-0.7011419803004051, 0.9389137397717195}, 
     {-0.7103954138934385, 0.896506223090295}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.4822420380328004, 1.1890852819516724}, {-0.4563030860880938, \
1.2727298803122153}, {-0.6861696102342368, 1.0035621274868156}, 
     {-0.7011419803004051, 0.9389137397717195}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.4563030860880938, 1.2727298803122153}, {-0.42158999280194415, \
1.3759750672106557}, {-0.6661326681122279, 1.0837396094369782}, 
     {-0.6861696102342368, 1.0035621274868156}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{-0.42158999280194415, 1.3759750672106557}, \
{-0.37961988692285853, 1.4902097135042391}, {-0.6419068644530262, \
1.1729281630054869}, 
     {-0.6661326681122279, 1.0837396094369782}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.37961988692285853, 1.4902097135042391}, {-0.3322270634726655, \
1.6081701375219573}, {-0.614550983124842, 1.265552510424171}, 
     {-0.6419068644530262, 1.1729281630054869}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.3322270634726655, 1.6081701375219573}, {-0.281482816252137, \
1.72411228393615}, {-0.5852606074097999, 1.3571288512592452}, 
     {-0.614550983124842, 1.265552510424171}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{-0.281482816252137, 1.72411228393615}, {-0.22960491236272362, \
1.8336364565828094}, {-0.5553158672774632, 1.4441489417584883}, 
     {-0.5852606074097999, 1.3571288512592452}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.22960491236272362, 1.8336364565828094}, {-0.1788606651421949, \
1.9334320944111918}, {-0.5260254915624208, 1.5239001577085334}, 
     {-0.5553158672774632, 1.4441489417584883}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.1788606651421949, 1.9334320944111918}, {-0.13146784169200199, \
2.021043485921704}, {-0.4986696102342367, 1.5943005668830776}, 
     {-0.5260254915624208, 1.5239001577085334}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{-0.13146784169200199, 2.021043485921704}, {-0.08949773581291631, \
2.094679321954477}, {-0.47444380657503493, 1.6537682358032735}, 
     {-0.4986696102342367, 1.5943005668830776}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.08949773581291631, 2.094679321954477}, \
{-0.054784642526766514, 2.153063306659971}, {-0.4544068644530261, \
1.7011229525643676}, 
     {-0.47444380657503493, 1.6537682358032735}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.054784642526766514, 2.153063306659971}, \
{-0.028845690582059838, 2.195318553032827}, {-0.43943449438685783, \
1.7355139912456734}, 
     {-0.4544068644530261, 1.7011229525643676}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{-0.028845690582059838, 2.195318553032827}, {-0.0128145366476809, \
2.2208803408437965}, {-0.43018106079382434, 1.75636834939373}, 
     {-0.43943449438685783, 1.7355139912456734}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.0128145366476809, 2.2208803408437965}, \
{-0.0073918190765734915, 2.2294344764321834}, {-0.4270509831248419, \
1.7633557568774199}, 
     {-0.43018106079382434, 1.75636834939373}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.0073918190765734915, 2.2294344764321834}, \
{-0.012814536647680836, 2.220880340843797}, {-0.43018106079382423, \
1.75636834939373}, 
     {-0.4270509831248419, 1.7633557568774199}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{-0.012814536647680836, 2.220880340843797}, \
{-0.028845690582059706, 2.1953185530328274}, {-0.4394344943868578, \
1.7355139912456736}, 
     {-0.43018106079382423, 1.75636834939373}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-0.028845690582059706, 2.1953185530328274}, \
{-0.05478464252676645, 2.153063306659971}, {-0.454406864453026, \
1.7011229525643679}, 
     {-0.4394344943868578, 1.7355139912456736}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.05478464252676645, 2.153063306659971}, {-0.08949773581291603, \
2.0946793219544775}, {-0.4744438065750348, 1.653768235803274}, 
     {-0.454406864453026, 1.7011229525643679}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{-0.08949773581291603, 2.0946793219544775}, \
{-0.13146784169200165, 2.0210434859217044}, {-0.4986696102342365, \
1.594300566883078}, 
     {-0.4744438065750348, 1.653768235803274}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.13146784169200165, 2.0210434859217044}, \
{-0.17886066514219465, 1.9334320944111922}, {-0.5260254915624207, \
1.5239001577085336}, 
     {-0.4986696102342365, 1.594300566883078}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-0.17886066514219465, 1.9334320944111922}, \
{-0.22960491236272318, 1.8336364565828103}, {-0.5553158672774631, \
1.4441489417584887}, 
     {-0.5260254915624207, 1.5239001577085336}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{-0.22960491236272318, 1.8336364565828103}, \
{-0.28148281625213667, 1.7241122839361507}, {-0.5852606074097996, \
1.357128851259246}, 
     {-0.5553158672774631, 1.4441489417584887}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{-0.28148281625213667, 1.7241122839361507}, \
{-0.33222706347266534, 1.6081701375219577}, {-0.6145509831248419, \
1.2655525104241714}, 
     {-0.5852606074097996, 1.357128851259246}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.33222706347266534, 1.6081701375219577}, {-0.3796198869228583, \
1.49020971350424}, {-0.641906864453026, 1.1729281630054875}, 
     {-0.6145509831248419, 1.2655525104241714}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{-0.3796198869228583, 1.49020971350424}, {-0.42158999280194376, \
1.3759750672106568}, {-0.6661326681122279, 1.0837396094369787}, 
     {-0.641906864453026, 1.1729281630054875}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.42158999280194376, 1.3759750672106568}, {-0.4563030860880937, \
1.2727298803122153}, {-0.6861696102342367, 1.0035621274868158}, 
     {-0.6661326681122279, 1.0837396094369787}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.4563030860880937, 1.2727298803122153}, {-0.48224203803280025, \
1.1890852819516728}, {-0.701141980300405, 0.93891373977172}, 
     {-0.6861696102342367, 1.0035621274868158}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{-0.48224203803280025, 1.1890852819516728}, \
{-0.49827319196717923, 1.1340136417284865}, {-0.7103954138934385, \
0.8965062230902952}, 
     {-0.701141980300405, 0.93891373977172}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.49827319196717923, 1.1340136417284865}, {-0.5036959095382867, \
1.1147172382160917}, {-0.713525491562421, 0.8816778784387099}, 
     {-0.7103954138934385, 0.8965062230902952}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-0.5036959095382867, 1.1147172382160917}, {-0.4982731919671794, \
1.134013641728486}, {-0.7103954138934385, 0.8965062230902949}, 
     {-0.713525491562421, 0.8816778784387099}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{-0.4982731919671794, 1.134013641728486}, {-0.4822420380328006, \
1.189085281951672}, {-0.7011419803004052, 0.9389137397717192}, 
     {-0.7103954138934385, 0.8965062230902949}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{-0.4822420380328006, 1.189085281951672}, {-0.4563030860880938, \
1.2727298803122151}, {-0.6861696102342368, 1.0035621274868154}, 
     {-0.7011419803004052, 0.9389137397717192}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{-0.4563030860880938, 1.2727298803122151}, {-0.4215899928019442, \
1.3759750672106552}, {-0.6661326681122282, 1.0837396094369776}, 
     {-0.6861696102342368, 1.0035621274868154}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{-0.4215899928019442, 1.3759750672106552}, {-0.3796198869228588, \
1.4902097135042387}, {-0.6419068644530264, 1.1729281630054864}, 
     {-0.6661326681122282, 1.0837396094369776}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{-0.3796198869228588, 1.4902097135042387}, {-0.33222706347266556, \
1.6081701375219573}, {-0.614550983124842, 1.2655525104241707}, 
     {-0.6419068644530264, 1.1729281630054864}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{-0.33222706347266556, 1.6081701375219573}, {-0.2814828162521371, \
1.7241122839361496}, {-0.5852606074097999, 1.3571288512592452}, 
     {-0.614550983124842, 1.2655525104241707}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{-0.2814828162521371, 1.7241122839361496}, {-0.2296049123627239, \
1.833636456582809}, {-0.5553158672774634, 1.4441489417584878}, 
     {-0.5852606074097999, 1.3571288512592452}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{-0.2296049123627239, 1.833636456582809}, {-0.17886066514219484, \
1.9334320944111918}, {-0.5260254915624208, 1.5239001577085334}, 
     {-0.5553158672774634, 1.4441489417584878}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{-0.17886066514219484, 1.9334320944111918}, \
{-0.13146784169200207, 2.021043485921704}, {-0.49866961023423684, \
1.5943005668830776}, 
     {-0.5260254915624208, 1.5239001577085334}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{-0.13146784169200207, 2.021043485921704}, {-0.0894977358129165, \
2.0946793219544766}, {-0.4744438065750351, 1.6537682358032733}, 
     {-0.49866961023423684, 1.5943005668830776}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{-0.0894977358129165, 2.0946793219544766}, {-0.05478464252676649, \
2.153063306659971}, {-0.4544068644530261, 1.7011229525643676}, 
     {-0.4744438065750351, 1.6537682358032733}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{-0.05478464252676649, 2.153063306659971}, {-0.02884569058205982, \
2.195318553032827}, {-0.4394344943868578, 1.7355139912456734}, 
     {-0.4544068644530261, 1.7011229525643676}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{-0.02884569058205982, 2.195318553032827}, {-0.01281453664768086, \
2.2208803408437965}, {-0.4301810607938243, 1.75636834939373}, 
     {-0.4394344943868578, 1.7355139912456734}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{-0.01281453664768086, 2.2208803408437965}, \
{-0.0073918190765734915, 2.2294344764321834}, {-0.4270509831248419, \
1.7633557568774199}, 
     {-0.4301810607938243, 1.75636834939373}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{-0.4270509831248419, 1.7633557568774199}, {-0.43018106079382434, \
1.75636834939373}, {-0.7420533023112793, 1.2152748245287468}, 
     {-0.7406363729278018, 1.220209929227403}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.025, 0.1], 
   Polygon[{{-0.43018106079382434, 1.75636834939373}, {-0.4394344943868577, \
1.7355139912456736}, {-0.7462421638484722, 1.200556789468474}, 
     {-0.7420533023112793, 1.2152748245287468}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{-0.4394344943868577, 1.7355139912456736}, {-0.45440686445302614, \
1.7011229525643676}, {-0.7530198841898177, 1.1763209525760543}, 
     {-0.7462421638484722, 1.200556789468474}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{-0.45440686445302614, 1.7011229525643676}, {-0.474443806575035, \
1.6537682358032737}, {-0.7620902444332882, 1.1430205016052861}, 
     {-0.7530198841898177, 1.1763209525760543}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.075, 0.1], 
   Polygon[{{-0.474443806575035, 1.6537682358032737}, {-0.4986696102342367, \
1.594300566883078}, {-0.7730568263118266, 1.1013148858947228}, 
     {-0.7620902444332882, 1.1430205016052861}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{-0.4986696102342367, 1.594300566883078}, {-0.5260254915624208, \
1.5239001577085334}, {-0.7854403375738425, 1.0520980143876315}, 
     {-0.7730568263118266, 1.1013148858947228}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{-0.5260254915624208, 1.5239001577085334}, {-0.5553158672774632, \
1.4441489417584887}, {-0.7986995593545059, 0.9965396214846565}, 
     {-0.7854403375738425, 1.0520980143876315}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.125, 0.1], 
   Polygon[{{-0.5553158672774632, 1.4441489417584887}, {-0.5852606074097998, \
1.3571288512592459}, {-0.8122550000371968, 0.9361441841071289}, 
     {-0.7986995593545059, 0.9965396214846565}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{-0.5852606074097998, 1.3571288512592459}, {-0.614550983124842, \
1.2655525104241712}, {-0.8255142218178602, 0.8728320775698136}, 
     {-0.8122550000371968, 0.9361441841071289}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{-0.614550983124842, 1.2655525104241712}, {-0.6419068644530261, \
1.1729281630054873}, {-0.8378977330798761, 0.8090441125945343}, 
     {-0.8255142218178602, 0.8728320775698136}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.175, 0.1], 
   Polygon[{{-0.6419068644530261, 1.1729281630054873}, {-0.6661326681122279, \
1.0837396094369784}, {-0.8488643149584145, 0.7478557941640124}, 
     {-0.8378977330798761, 0.8090441125945343}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{-0.6661326681122279, 1.0837396094369784}, {-0.6861696102342367, \
1.0035621274868158}, {-0.857934675201885, 0.6930472461935383}, 
     {-0.8488643149584145, 0.7478557941640124}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{-0.6861696102342367, 1.0035621274868158}, {-0.701141980300405, \
0.9389137397717199}, {-0.8647123955432304, 0.6489952411032616}, 
     {-0.857934675201885, 0.6930472461935383}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.225, 0.1], 
   Polygon[{{-0.701141980300405, 0.9389137397717199}, {-0.7103954138934385, \
0.896506223090295}, {-0.8689012570804234, 0.6201700772082621}, 
     {-0.8647123955432304, 0.6489952411032616}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{-0.7103954138934385, 0.896506223090295}, {-0.713525491562421, \
0.8816778784387099}, {-0.8703181864639009, 0.6101049646137015}, 
     {-0.8689012570804234, 0.6201700772082621}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{-0.713525491562421, 0.8816778784387099}, {-0.7103954138934385, \
0.896506223090295}, {-0.8689012570804234, 0.6201700772082621}, 
     {-0.8703181864639009, 0.6101049646137015}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.275, 0.1], 
   Polygon[{{-0.7103954138934385, 0.896506223090295}, {-0.7011419803004051, \
0.9389137397717195}, {-0.8647123955432304, 0.6489952411032616}, 
     {-0.8689012570804234, 0.6201700772082621}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.7011419803004051, 0.9389137397717195}, {-0.6861696102342368, \
1.0035621274868156}, {-0.857934675201885, 0.6930472461935381}, 
     {-0.8647123955432304, 0.6489952411032616}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.6861696102342368, 1.0035621274868156}, {-0.6661326681122279, \
1.0837396094369782}, {-0.8488643149584145, 0.7478557941640123}, 
     {-0.857934675201885, 0.6930472461935381}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.325, 0.1], 
   Polygon[{{-0.6661326681122279, 1.0837396094369782}, {-0.6419068644530262, \
1.1729281630054869}, {-0.8378977330798763, 0.809044112594534}, 
     {-0.8488643149584145, 0.7478557941640123}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.6419068644530262, 1.1729281630054869}, {-0.614550983124842, \
1.265552510424171}, {-0.8255142218178603, 0.8728320775698134}, 
     {-0.8378977330798763, 0.809044112594534}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.614550983124842, 1.265552510424171}, {-0.5852606074097999, \
1.3571288512592452}, {-0.8122550000371969, 0.9361441841071285}, 
     {-0.8255142218178603, 0.8728320775698134}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.375, 0.1], 
   Polygon[{{-0.5852606074097999, 1.3571288512592452}, {-0.5553158672774632, \
1.4441489417584883}, {-0.798699559354506, 0.9965396214846562}, 
     {-0.8122550000371969, 0.9361441841071285}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.5553158672774632, 1.4441489417584883}, {-0.5260254915624208, \
1.5239001577085334}, {-0.7854403375738425, 1.0520980143876313}, 
     {-0.798699559354506, 0.9965396214846562}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.5260254915624208, 1.5239001577085334}, {-0.4986696102342367, \
1.5943005668830776}, {-0.7730568263118266, 1.1013148858947226}, 
     {-0.7854403375738425, 1.0520980143876313}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.425, 0.1], 
   Polygon[{{-0.4986696102342367, 1.5943005668830776}, {-0.47444380657503493, \
1.6537682358032735}, {-0.7620902444332882, 1.143020501605286}, 
     {-0.7730568263118266, 1.1013148858947226}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.47444380657503493, 1.6537682358032735}, {-0.4544068644530261, \
1.7011229525643676}, {-0.7530198841898177, 1.1763209525760543}, 
     {-0.7620902444332882, 1.143020501605286}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.4544068644530261, 1.7011229525643676}, {-0.43943449438685783, \
1.7355139912456734}, {-0.7462421638484723, 1.200556789468474}, 
     {-0.7530198841898177, 1.1763209525760543}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.475, 0.1], 
   Polygon[{{-0.43943449438685783, 1.7355139912456734}, \
{-0.43018106079382434, 1.75636834939373}, {-0.7420533023112793, \
1.2152748245287468}, 
     {-0.7462421638484723, 1.200556789468474}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.43018106079382434, 1.75636834939373}, {-0.4270509831248419, \
1.7633557568774199}, {-0.7406363729278018, 1.220209929227403}, 
     {-0.7420533023112793, 1.2152748245287468}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.4270509831248419, 1.7633557568774199}, {-0.43018106079382423, \
1.75636834939373}, {-0.7420533023112793, 1.2152748245287468}, 
     {-0.7406363729278018, 1.220209929227403}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.525, 0.1], 
   Polygon[{{-0.43018106079382423, 1.75636834939373}, {-0.4394344943868578, \
1.7355139912456736}, {-0.7462421638484722, 1.200556789468474}, 
     {-0.7420533023112793, 1.2152748245287468}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-0.4394344943868578, 1.7355139912456736}, {-0.454406864453026, \
1.7011229525643679}, {-0.7530198841898177, 1.1763209525760543}, 
     {-0.7462421638484722, 1.200556789468474}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.454406864453026, 1.7011229525643679}, {-0.4744438065750348, \
1.653768235803274}, {-0.7620902444332881, 1.1430205016052863}, 
     {-0.7530198841898177, 1.1763209525760543}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.575, 0.1], 
   Polygon[{{-0.4744438065750348, 1.653768235803274}, {-0.4986696102342365, \
1.594300566883078}, {-0.7730568263118266, 1.1013148858947228}, 
     {-0.7620902444332881, 1.1430205016052863}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.4986696102342365, 1.594300566883078}, {-0.5260254915624207, \
1.5239001577085336}, {-0.7854403375738425, 1.0520980143876315}, 
     {-0.7730568263118266, 1.1013148858947228}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-0.5260254915624207, 1.5239001577085336}, {-0.5553158672774631, \
1.4441489417584887}, {-0.7986995593545059, 0.9965396214846567}, 
     {-0.7854403375738425, 1.0520980143876315}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.625, 0.1], 
   Polygon[{{-0.5553158672774631, 1.4441489417584887}, {-0.5852606074097996, \
1.357128851259246}, {-0.8122550000371966, 0.9361441841071292}, 
     {-0.7986995593545059, 0.9965396214846567}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{-0.5852606074097996, 1.357128851259246}, {-0.6145509831248419, \
1.2655525104241714}, {-0.8255142218178602, 0.8728320775698137}, 
     {-0.8122550000371966, 0.9361441841071292}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.6145509831248419, 1.2655525104241714}, {-0.641906864453026, \
1.1729281630054875}, {-0.837897733079876, 0.8090441125945347}, 
     {-0.8255142218178602, 0.8728320775698137}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.675, 0.1], 
   Polygon[{{-0.641906864453026, 1.1729281630054875}, {-0.6661326681122279, \
1.0837396094369787}, {-0.8488643149584145, 0.7478557941640125}, 
     {-0.837897733079876, 0.8090441125945347}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.6661326681122279, 1.0837396094369787}, {-0.6861696102342367, \
1.0035621274868158}, {-0.857934675201885, 0.6930472461935383}, 
     {-0.8488643149584145, 0.7478557941640125}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.6861696102342367, 1.0035621274868158}, {-0.701141980300405, \
0.93891373977172}, {-0.8647123955432304, 0.6489952411032617}, 
     {-0.857934675201885, 0.6930472461935383}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.725, 0.1], 
   Polygon[{{-0.701141980300405, 0.93891373977172}, {-0.7103954138934385, \
0.8965062230902952}, {-0.8689012570804234, 0.6201700772082622}, 
     {-0.8647123955432304, 0.6489952411032617}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.7103954138934385, 0.8965062230902952}, {-0.713525491562421, \
0.8816778784387099}, {-0.8703181864639009, 0.6101049646137015}, 
     {-0.8689012570804234, 0.6201700772082622}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-0.713525491562421, 0.8816778784387099}, {-0.7103954138934385, \
0.8965062230902949}, {-0.8689012570804235, 0.6201700772082617}, 
     {-0.8703181864639009, 0.6101049646137015}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.775, 0.1], 
   Polygon[{{-0.7103954138934385, 0.8965062230902949}, {-0.7011419803004052, \
0.9389137397717192}, {-0.8647123955432305, 0.6489952411032612}, 
     {-0.8689012570804235, 0.6201700772082617}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{-0.7011419803004052, 0.9389137397717192}, {-0.6861696102342368, \
1.0035621274868154}, {-0.857934675201885, 0.6930472461935381}, 
     {-0.8647123955432305, 0.6489952411032612}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{-0.6861696102342368, 1.0035621274868154}, {-0.6661326681122282, \
1.0837396094369776}, {-0.8488643149584146, 0.7478557941640119}, 
     {-0.857934675201885, 0.6930472461935381}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.825, 0.1], 
   Polygon[{{-0.6661326681122282, 1.0837396094369776}, {-0.6419068644530264, \
1.1729281630054864}, {-0.8378977330798763, 0.8090441125945338}, 
     {-0.8488643149584146, 0.7478557941640119}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{-0.6419068644530264, 1.1729281630054864}, {-0.614550983124842, \
1.2655525104241707}, {-0.8255142218178603, 0.8728320775698134}, 
     {-0.8378977330798763, 0.8090441125945338}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{-0.614550983124842, 1.2655525104241707}, {-0.5852606074097999, \
1.3571288512592452}, {-0.8122550000371969, 0.9361441841071284}, 
     {-0.8255142218178603, 0.8728320775698134}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.875, 0.1], 
   Polygon[{{-0.5852606074097999, 1.3571288512592452}, {-0.5553158672774634, \
1.4441489417584878}, {-0.798699559354506, 0.996539621484656}, 
     {-0.8122550000371969, 0.9361441841071284}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{-0.5553158672774634, 1.4441489417584878}, {-0.5260254915624208, \
1.5239001577085334}, {-0.7854403375738425, 1.0520980143876313}, 
     {-0.798699559354506, 0.996539621484656}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{-0.5260254915624208, 1.5239001577085334}, {-0.49866961023423684, \
1.5943005668830776}, {-0.7730568263118266, 1.1013148858947226}, 
     {-0.7854403375738425, 1.0520980143876313}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{-0.49866961023423684, 1.5943005668830776}, {-0.4744438065750351, \
1.6537682358032733}, {-0.7620902444332882, 1.143020501605286}, 
     {-0.7730568263118266, 1.1013148858947226}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{-0.4744438065750351, 1.6537682358032733}, {-0.4544068644530261, \
1.7011229525643676}, {-0.7530198841898177, 1.1763209525760543}, 
     {-0.7620902444332882, 1.143020501605286}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{-0.4544068644530261, 1.7011229525643676}, {-0.4394344943868578, \
1.7355139912456734}, {-0.7462421638484723, 1.200556789468474}, 
     {-0.7530198841898177, 1.1763209525760543}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.975, 0.1], 
   Polygon[{{-0.4394344943868578, 1.7355139912456734}, {-0.4301810607938243, \
1.75636834939373}, {-0.7420533023112792, 1.2152748245287468}, 
     {-0.7462421638484723, 1.200556789468474}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{-0.4301810607938243, 1.75636834939373}, {-0.4270509831248419, \
1.7633557568774199}, {-0.7406363729278018, 1.220209929227403}, 
     {-0.7420533023112792, 1.2152748245287468}}]}, {CMYKColor[0.95, 0.5, \
0.008333333333333333, 0.1], 
   Polygon[{{-0.7406363729278018, 1.220209929227403}, {-0.7420533023112793, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
     {-0.9344428022014165, 0.6237350724532796}}]}, {CMYKColor[0.95, 0.5, \
0.025, 0.1], 
   Polygon[{{-0.7420533023112793, 1.2152748245287468}, {-0.7462421638484722, \
1.200556789468474}, {-0.9358597315848941, 0.6135770923916904}, 
     {-0.9348009477166834, 0.6211835161491779}}]}, {CMYKColor[0.95, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{-0.7462421638484722, 1.200556789468474}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
     {-0.9358597315848941, 0.6135770923916904}}]}, {CMYKColor[0.95, 0.5, \
0.058333333333333334, 0.1], 
   Polygon[{{-0.7530198841898177, 1.1763209525760543}, {-0.7620902444332882, \
1.1430205016052861}, {-0.9398655197725241, 0.5838857533279131}, 
     {-0.937572879870399, 0.6010618457721164}}]}, {CMYKColor[0.95, 0.5, \
0.075, 0.1], 
   Polygon[{{-0.7620902444332882, 1.1430205016052861}, {-0.7730568263118266, \
1.1013148858947228}, {-0.9426374519262395, 0.5624063276196131}, 
     {-0.9398655197725241, 0.5838857533279131}}]}, {CMYKColor[0.95, 0.5, \
0.09166666666666666, 0.1], 
   Polygon[{{-0.7730568263118266, 1.1013148858947228}, {-0.7854403375738425, \
1.0520980143876315}, {-0.9457675295952219, 0.5371028573756125}, 
     {-0.9426374519262395, 0.5624063276196131}}]}, {CMYKColor[0.95, 0.5, \
0.10833333333333334, 0.1], 
   Polygon[{{-0.7854403375738425, 1.0520980143876315}, {-0.7986995593545059, \
0.9965396214846565}, {-0.9491189533655575, 0.5085950701762803}, 
     {-0.9457675295952219, 0.5371028573756125}}]}, {CMYKColor[0.95, 0.5, \
0.125, 0.1], 
   Polygon[{{-0.7986995593545059, 0.9965396214846565}, {-0.8122550000371968, \
0.9361441841071289}, {-0.9525452499365673, 0.47767060184981125}, 
     {-0.9491189533655575, 0.5085950701762803}}]}, {CMYKColor[0.95, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{-0.8122550000371968, 0.9361441841071289}, {-0.8255142218178602, \
0.8728320775698136}, {-0.955896673706903, 0.44532374723565715}, 
     {-0.9525452499365673, 0.47767060184981125}}]}, {CMYKColor[0.95, 0.5, \
0.15833333333333333, 0.1], 
   Polygon[{{-0.8255142218178602, 0.8728320775698136}, {-0.8378977330798761, \
0.8090441125945343}, {-0.9590267513758853, 0.41280605266694914}, 
     {-0.955896673706903, 0.44532374723565715}}]}, {CMYKColor[0.95, 0.5, \
0.175, 0.1], 
   Polygon[{{-0.8378977330798761, 0.8090441125945343}, {-0.8488643149584145, \
0.7478557941640124}, {-0.9617986835296009, 0.3816816923272197}, 
     {-0.9590267513758853, 0.41280605266694914}}]}, {CMYKColor[0.95, 0.5, \
0.19166666666666665, 0.1], 
   Polygon[{{-0.8488643149584145, 0.7478557941640124}, {-0.857934675201885, \
0.6930472461935383}, {-0.9640913234317259, 0.3538602304100192}, 
     {-0.9617986835296009, 0.3816816923272197}}]}, {CMYKColor[0.95, 0.5, \
0.20833333333333334, 0.1], 
   Polygon[{{-0.857934675201885, 0.6930472461935383}, {-0.8647123955432304, \
0.6489952411032616}, {-0.9658044717172307, 0.33154008354139486}, 
     {-0.9640913234317259, 0.3538602304100192}}]}, {CMYKColor[0.95, 0.5, \
0.225, 0.1], 
   Polygon[{{-0.8647123955432304, 0.6489952411032616}, {-0.8689012570804234, \
0.6201700772082621}, {-0.9668632555854414, 0.31695593148714096}, 
     {-0.9658044717172307, 0.33154008354139486}}]}, {CMYKColor[0.95, 0.5, \
0.24166666666666667, 0.1], 
   Polygon[{{-0.8689012570804234, 0.6201700772082621}, {-0.8703181864639009, \
0.6101049646137015}, {-0.9672214011007083, 0.3118675362266397}, 
     {-0.9668632555854414, 0.31695593148714096}}]}, {CMYKColor[0.95, 0.5, \
0.2583333333333333, 0.1], 
   Polygon[{{-0.8703181864639009, 0.6101049646137015}, {-0.8689012570804234, \
0.6201700772082621}, {-0.9668632555854414, 0.31695593148714096}, 
     {-0.9672214011007083, 0.3118675362266397}}]}, {CMYKColor[0.95, 0.5, \
0.275, 0.1], 
   Polygon[{{-0.8689012570804234, 0.6201700772082621}, {-0.8647123955432304, \
0.6489952411032616}, {-0.9658044717172307, 0.33154008354139486}, 
     {-0.9668632555854414, 0.31695593148714096}}]}, {CMYKColor[0.95, 0.5, \
0.2916666666666667, 0.1], 
   Polygon[{{-0.8647123955432304, 0.6489952411032616}, {-0.857934675201885, \
0.6930472461935381}, {-0.9640913234317259, 0.3538602304100192}, 
     {-0.9658044717172307, 0.33154008354139486}}]}, {CMYKColor[0.95, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{-0.857934675201885, 0.6930472461935381}, {-0.8488643149584145, \
0.7478557941640123}, {-0.9617986835296009, 0.3816816923272197}, 
     {-0.9640913234317259, 0.3538602304100192}}]}, {CMYKColor[0.95, 0.5, \
0.325, 0.1], 
   Polygon[{{-0.8488643149584145, 0.7478557941640123}, {-0.8378977330798763, \
0.809044112594534}, {-0.9590267513758853, 0.41280605266694914}, 
     {-0.9617986835296009, 0.3816816923272197}}]}, {CMYKColor[0.95, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{-0.8378977330798763, 0.809044112594534}, {-0.8255142218178603, \
0.8728320775698134}, {-0.955896673706903, 0.44532374723565715}, 
     {-0.9590267513758853, 0.41280605266694914}}]}, {CMYKColor[0.95, 0.5, \
0.35833333333333334, 0.1], 
   Polygon[{{-0.8255142218178603, 0.8728320775698134}, {-0.8122550000371969, \
0.9361441841071285}, {-0.9525452499365673, 0.47767060184981125}, 
     {-0.955896673706903, 0.44532374723565715}}]}, {CMYKColor[0.95, 0.5, \
0.375, 0.1], 
   Polygon[{{-0.8122550000371969, 0.9361441841071285}, {-0.798699559354506, \
0.9965396214846562}, {-0.9491189533655575, 0.5085950701762803}, 
     {-0.9525452499365673, 0.47767060184981125}}]}, {CMYKColor[0.95, 0.5, \
0.39166666666666666, 0.1], 
   Polygon[{{-0.798699559354506, 0.9965396214846562}, {-0.7854403375738425, \
1.0520980143876313}, {-0.9457675295952219, 0.5371028573756125}, 
     {-0.9491189533655575, 0.5085950701762803}}]}, {CMYKColor[0.95, 0.5, \
0.4083333333333333, 0.1], 
   Polygon[{{-0.7854403375738425, 1.0520980143876313}, {-0.7730568263118266, \
1.1013148858947226}, {-0.9426374519262395, 0.5624063276196131}, 
     {-0.9457675295952219, 0.5371028573756125}}]}, {CMYKColor[0.95, 0.5, \
0.425, 0.1], 
   Polygon[{{-0.7730568263118266, 1.1013148858947226}, {-0.7620902444332882, \
1.143020501605286}, {-0.9398655197725241, 0.5838857533279131}, 
     {-0.9426374519262395, 0.5624063276196131}}]}, {CMYKColor[0.95, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{-0.7620902444332882, 1.143020501605286}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
     {-0.9398655197725241, 0.5838857533279131}}]}, {CMYKColor[0.95, 0.5, \
0.4583333333333333, 0.1], 
   Polygon[{{-0.7530198841898177, 1.1763209525760543}, {-0.7462421638484723, \
1.200556789468474}, {-0.9358597315848941, 0.6135770923916904}, 
     {-0.937572879870399, 0.6010618457721164}}]}, {CMYKColor[0.95, 0.5, \
0.475, 0.1], 
   Polygon[{{-0.7462421638484723, 1.200556789468474}, {-0.7420533023112793, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
     {-0.9358597315848941, 0.6135770923916904}}]}, {CMYKColor[0.95, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{-0.7420533023112793, 1.2152748245287468}, {-0.7406363729278018, \
1.220209929227403}, {-0.9344428022014165, 0.6237350724532796}, 
     {-0.9348009477166834, 0.6211835161491779}}]}, {CMYKColor[0.95, 0.5, \
0.5083333333333333, 0.1], 
   Polygon[{{-0.7406363729278018, 1.220209929227403}, {-0.7420533023112793, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
     {-0.9344428022014165, 0.6237350724532796}}]}, {CMYKColor[0.95, 0.5, \
0.525, 0.1], 
   Polygon[{{-0.7420533023112793, 1.2152748245287468}, {-0.7462421638484722, \
1.200556789468474}, {-0.9358597315848941, 0.6135770923916904}, 
     {-0.9348009477166834, 0.6211835161491779}}]}, {CMYKColor[0.95, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{-0.7462421638484722, 1.200556789468474}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
     {-0.9358597315848941, 0.6135770923916904}}]}, {CMYKColor[0.95, 0.5, \
0.5583333333333333, 0.1], 
   Polygon[{{-0.7530198841898177, 1.1763209525760543}, {-0.7620902444332881, \
1.1430205016052863}, {-0.939865519772524, 0.5838857533279135}, 
     {-0.937572879870399, 0.6010618457721164}}]}, {CMYKColor[0.95, 0.5, \
0.575, 0.1], 
   Polygon[{{-0.7620902444332881, 1.1430205016052863}, {-0.7730568263118266, \
1.1013148858947228}, {-0.9426374519262395, 0.5624063276196133}, 
     {-0.939865519772524, 0.5838857533279135}}]}, {CMYKColor[0.95, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{-0.7730568263118266, 1.1013148858947228}, {-0.7854403375738425, \
1.0520980143876315}, {-0.9457675295952218, 0.5371028573756126}, 
     {-0.9426374519262395, 0.5624063276196133}}]}, {CMYKColor[0.95, 0.5, \
0.6083333333333333, 0.1], 
   Polygon[{{-0.7854403375738425, 1.0520980143876315}, {-0.7986995593545059, \
0.9965396214846567}, {-0.9491189533655575, 0.5085950701762803}, 
     {-0.9457675295952218, 0.5371028573756126}}]}, {CMYKColor[0.95, 0.5, \
0.625, 0.1], 
   Polygon[{{-0.7986995593545059, 0.9965396214846567}, {-0.8122550000371966, \
0.9361441841071292}, {-0.9525452499365673, 0.4776706018498115}, 
     {-0.9491189533655575, 0.5085950701762803}}]}, {CMYKColor[0.95, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{-0.8122550000371966, 0.9361441841071292}, {-0.8255142218178602, \
0.8728320775698137}, {-0.955896673706903, 0.44532374723565715}, 
     {-0.9525452499365673, 0.4776706018498115}}]}, {CMYKColor[0.95, 0.5, \
0.6583333333333333, 0.1], 
   Polygon[{{-0.8255142218178602, 0.8728320775698137}, {-0.837897733079876, \
0.8090441125945347}, {-0.9590267513758853, 0.41280605266694914}, 
     {-0.955896673706903, 0.44532374723565715}}]}, {CMYKColor[0.95, 0.5, \
0.675, 0.1], 
   Polygon[{{-0.837897733079876, 0.8090441125945347}, {-0.8488643149584145, \
0.7478557941640125}, {-0.9617986835296009, 0.3816816923272197}, 
     {-0.9590267513758853, 0.41280605266694914}}]}, {CMYKColor[0.95, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{-0.8488643149584145, 0.7478557941640125}, {-0.857934675201885, \
0.6930472461935383}, {-0.9640913234317259, 0.3538602304100192}, 
     {-0.9617986835296009, 0.3816816923272197}}]}, {CMYKColor[0.95, 0.5, \
0.7083333333333334, 0.1], 
   Polygon[{{-0.857934675201885, 0.6930472461935383}, {-0.8647123955432304, \
0.6489952411032617}, {-0.9658044717172307, 0.33154008354139486}, 
     {-0.9640913234317259, 0.3538602304100192}}]}, {CMYKColor[0.95, 0.5, \
0.725, 0.1], 
   Polygon[{{-0.8647123955432304, 0.6489952411032617}, {-0.8689012570804234, \
0.6201700772082622}, {-0.9668632555854413, 0.31695593148714163}, 
     {-0.9658044717172307, 0.33154008354139486}}]}, {CMYKColor[0.95, 0.5, \
0.7416666666666667, 0.1], 
   Polygon[{{-0.8689012570804234, 0.6201700772082622}, {-0.8703181864639009, \
0.6101049646137015}, {-0.9672214011007083, 0.3118675362266397}, 
     {-0.9668632555854413, 0.31695593148714163}}]}, {CMYKColor[0.95, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{-0.8703181864639009, 0.6101049646137015}, {-0.8689012570804235, \
0.6201700772082617}, {-0.9668632555854414, 0.31695593148714096}, 
     {-0.9672214011007083, 0.3118675362266397}}]}, {CMYKColor[0.95, 0.5, \
0.775, 0.1], 
   Polygon[{{-0.8689012570804235, 0.6201700772082617}, {-0.8647123955432305, \
0.6489952411032612}, {-0.9658044717172307, 0.33154008354139486}, 
     {-0.9668632555854414, 0.31695593148714096}}]}, {CMYKColor[0.95, 0.5, \
0.7916666666666666, 0.1], 
   Polygon[{{-0.8647123955432305, 0.6489952411032612}, {-0.857934675201885, \
0.6930472461935381}, {-0.9640913234317259, 0.3538602304100192}, 
     {-0.9658044717172307, 0.33154008354139486}}]}, {CMYKColor[0.95, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{-0.857934675201885, 0.6930472461935381}, {-0.8488643149584146, \
0.7478557941640119}, {-0.9617986835296009, 0.38168169232721944}, 
     {-0.9640913234317259, 0.3538602304100192}}]}, {CMYKColor[0.95, 0.5, \
0.825, 0.1], 
   Polygon[{{-0.8488643149584146, 0.7478557941640119}, {-0.8378977330798763, \
0.8090441125945338}, {-0.9590267513758853, 0.41280605266694886}, 
     {-0.9617986835296009, 0.38168169232721944}}]}, {CMYKColor[0.95, 0.5, \
0.8416666666666667, 0.1], 
   Polygon[{{-0.8378977330798763, 0.8090441125945338}, {-0.8255142218178603, \
0.8728320775698134}, {-0.955896673706903, 0.44532374723565715}, 
     {-0.9590267513758853, 0.41280605266694886}}]}, {CMYKColor[0.95, 0.5, \
0.8583333333333333, 0.1], 
   Polygon[{{-0.8255142218178603, 0.8728320775698134}, {-0.8122550000371969, \
0.9361441841071284}, {-0.9525452499365673, 0.47767060184981125}, 
     {-0.955896673706903, 0.44532374723565715}}]}, {CMYKColor[0.95, 0.5, \
0.875, 0.1], 
   Polygon[{{-0.8122550000371969, 0.9361441841071284}, {-0.798699559354506, \
0.996539621484656}, {-0.9491189533655575, 0.50859507017628}, 
     {-0.9525452499365673, 0.47767060184981125}}]}, {CMYKColor[0.95, 0.5, \
0.8916666666666666, 0.1], 
   Polygon[{{-0.798699559354506, 0.996539621484656}, {-0.7854403375738425, \
1.0520980143876313}, {-0.9457675295952219, 0.5371028573756125}, 
     {-0.9491189533655575, 0.50859507017628}}]}, {CMYKColor[0.95, 0.5, \
0.9083333333333333, 0.1], 
   Polygon[{{-0.7854403375738425, 1.0520980143876313}, {-0.7730568263118266, \
1.1013148858947226}, {-0.9426374519262395, 0.5624063276196131}, 
     {-0.9457675295952219, 0.5371028573756125}}]}, {CMYKColor[0.95, 0.5, \
0.9249999999999999, 0.1], 
   Polygon[{{-0.7730568263118266, 1.1013148858947226}, {-0.7620902444332882, \
1.143020501605286}, {-0.939865519772524, 0.5838857533279135}, 
     {-0.9426374519262395, 0.5624063276196131}}]}, {CMYKColor[0.95, 0.5, \
0.9416666666666667, 0.1], 
   Polygon[{{-0.7620902444332882, 1.143020501605286}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
     {-0.939865519772524, 0.5838857533279135}}]}, {CMYKColor[0.95, 0.5, \
0.9583333333333334, 0.1], 
   Polygon[{{-0.7530198841898177, 1.1763209525760543}, {-0.7462421638484723, \
1.200556789468474}, {-0.935859731584894, 0.6135770923916908}, 
     {-0.937572879870399, 0.6010618457721164}}]}, {CMYKColor[0.95, 0.5, \
0.975, 0.1], 
   Polygon[{{-0.7462421638484723, 1.200556789468474}, {-0.7420533023112792, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
     {-0.935859731584894, 0.6135770923916908}}]}, {CMYKColor[0.95, 0.5, \
0.9916666666666667, 0.1], 
   Polygon[{{-0.7420533023112792, 1.2152748245287468}, {-0.7406363729278018, \
1.220209929227403}, {-0.9344428022014165, 0.6237350724532796}, 
     {-0.9348009477166834, 0.6211835161491779}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{-0.9344428022014165, 0.6237350724532796}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.025, 0.1], \
Polygon[{{-0.9348009477166834, 0.6211835161491779}, {-0.9358597315848941, \
0.6135770923916904}, 
     {-1., 0.}, {-1., 0.}}]}, {CMYKColor[0.9833333333333333, 0.5, \
0.041666666666666664, 0.1], 
   Polygon[{{-0.9358597315848941, 0.6135770923916904}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.058333333333333334, 0.1], \
Polygon[{{-0.937572879870399, 0.6010618457721164}, 
     {-0.9398655197725241, 0.5838857533279131}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{-0.9398655197725241, 0.5838857533279131}, {-0.9426374519262395, \
0.5624063276196131}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.09166666666666666, 0.1], \
Polygon[{{-0.9426374519262395, 0.5624063276196131}, 
     {-0.9457675295952219, 0.5371028573756125}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{-0.9457675295952219, 0.5371028573756125}, {-0.9491189533655575, \
0.5085950701762803}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.125, 0.1], \
Polygon[{{-0.9491189533655575, 0.5085950701762803}, {-0.9525452499365673, \
0.47767060184981125}, 
     {-1., 0.}, {-1., 0.}}]}, {CMYKColor[0.9833333333333333, 0.5, \
0.14166666666666666, 0.1], 
   Polygon[{{-0.9525452499365673, 0.47767060184981125}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.15833333333333333, 0.1], \
Polygon[{{-0.955896673706903, 0.44532374723565715}, 
     {-0.9590267513758853, 0.41280605266694914}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{-0.9590267513758853, 0.41280605266694914}, {-0.9617986835296009, \
0.3816816923272197}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.19166666666666665, 0.1], \
Polygon[{{-0.9617986835296009, 0.3816816923272197}, 
     {-0.9640913234317259, 0.3538602304100192}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{-0.9640913234317259, 0.3538602304100192}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.225, 0.1], \
Polygon[{{-0.9658044717172307, 0.33154008354139486}, 
     {-0.9668632555854414, 0.31695593148714096}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{-0.9668632555854414, 0.31695593148714096}, {-0.9672214011007083, \
0.3118675362266397}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.2583333333333333, 0.1], \
Polygon[{{-0.9672214011007083, 0.3118675362266397}, 
     {-0.9668632555854414, 0.31695593148714096}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{-0.9668632555854414, 0.31695593148714096}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.2916666666666667, 0.1], \
Polygon[{{-0.9658044717172307, 0.33154008354139486}, 
     {-0.9640913234317259, 0.3538602304100192}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.9640913234317259, 0.3538602304100192}, {-0.9617986835296009, \
0.3816816923272197}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.325, 0.1], \
Polygon[{{-0.9617986835296009, 0.3816816923272197}, {-0.9590267513758853, \
0.41280605266694914}, 
     {-1., 0.}, {-1., 0.}}]}, {CMYKColor[0.9833333333333333, 0.5, \
0.3416666666666667, 0.1], 
   Polygon[{{-0.9590267513758853, 0.41280605266694914}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.35833333333333334, 0.1], \
Polygon[{{-0.955896673706903, 0.44532374723565715}, 
     {-0.9525452499365673, 0.47767060184981125}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{-0.9525452499365673, 0.47767060184981125}, {-0.9491189533655575, \
0.5085950701762803}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.39166666666666666, 0.1], \
Polygon[{{-0.9491189533655575, 0.5085950701762803}, 
     {-0.9457675295952219, 0.5371028573756125}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.9457675295952219, 0.5371028573756125}, {-0.9426374519262395, \
0.5624063276196131}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.425, 0.1], \
Polygon[{{-0.9426374519262395, 0.5624063276196131}, {-0.9398655197725241, \
0.5838857533279131}, 
     {-1., 0.}, {-1., 0.}}]}, {CMYKColor[0.9833333333333333, 0.5, \
0.44166666666666665, 0.1], 
   Polygon[{{-0.9398655197725241, 0.5838857533279131}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.4583333333333333, 0.1], \
Polygon[{{-0.937572879870399, 0.6010618457721164}, 
     {-0.9358597315848941, 0.6135770923916904}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{-0.9358597315848941, 0.6135770923916904}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.49166666666666664, 0.1], \
Polygon[{{-0.9348009477166834, 0.6211835161491779}, 
     {-0.9344428022014165, 0.6237350724532796}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.9344428022014165, 0.6237350724532796}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.525, 0.1], \
Polygon[{{-0.9348009477166834, 0.6211835161491779}, {-0.9358597315848941, \
0.6135770923916904}, 
     {-1., 0.}, {-1., 0.}}]}, {CMYKColor[0.9833333333333333, 0.5, \
0.5416666666666666, 0.1], 
   Polygon[{{-0.9358597315848941, 0.6135770923916904}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.5583333333333333, 0.1], \
Polygon[{{-0.937572879870399, 0.6010618457721164}, 
     {-0.939865519772524, 0.5838857533279135}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{-0.939865519772524, 0.5838857533279135}, {-0.9426374519262395, \
0.5624063276196133}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.5916666666666667, 0.1], \
Polygon[{{-0.9426374519262395, 0.5624063276196133}, 
     {-0.9457675295952218, 0.5371028573756126}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-0.9457675295952218, 0.5371028573756126}, {-0.9491189533655575, \
0.5085950701762803}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.625, 0.1], \
Polygon[{{-0.9491189533655575, 0.5085950701762803}, {-0.9525452499365673, \
0.4776706018498115}, 
     {-1., 0.}, {-1., 0.}}]}, {CMYKColor[0.9833333333333333, 0.5, \
0.6416666666666666, 0.1], 
   Polygon[{{-0.9525452499365673, 0.4776706018498115}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.6583333333333333, 0.1], \
Polygon[{{-0.955896673706903, 0.44532374723565715}, 
     {-0.9590267513758853, 0.41280605266694914}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{-0.9590267513758853, 0.41280605266694914}, {-0.9617986835296009, \
0.3816816923272197}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.6916666666666667, 0.1], \
Polygon[{{-0.9617986835296009, 0.3816816923272197}, 
     {-0.9640913234317259, 0.3538602304100192}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.9640913234317259, 0.3538602304100192}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.725, 0.1], \
Polygon[{{-0.9658044717172307, 0.33154008354139486}, 
     {-0.9668632555854413, 0.31695593148714163}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.9668632555854413, 0.31695593148714163}, {-0.9672214011007083, \
0.3118675362266397}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.7583333333333333, 0.1], \
Polygon[{{-0.9672214011007083, 0.3118675362266397}, 
     {-0.9668632555854414, 0.31695593148714096}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.775, 0.1], 
   Polygon[{{-0.9668632555854414, 0.31695593148714096}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.7916666666666666, 0.1], \
Polygon[{{-0.9658044717172307, 0.33154008354139486}, 
     {-0.9640913234317259, 0.3538602304100192}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{-0.9640913234317259, 0.3538602304100192}, {-0.9617986835296009, \
0.38168169232721944}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.825, 0.1], \
Polygon[{{-0.9617986835296009, 0.38168169232721944}, 
     {-0.9590267513758853, 0.41280605266694886}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{-0.9590267513758853, 0.41280605266694886}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.8583333333333333, 0.1], \
Polygon[{{-0.955896673706903, 0.44532374723565715}, 
     {-0.9525452499365673, 0.47767060184981125}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{-0.9525452499365673, 0.47767060184981125}, {-0.9491189533655575, \
0.50859507017628}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.8916666666666666, 0.1], \
Polygon[{{-0.9491189533655575, 0.50859507017628}, 
     {-0.9457675295952219, 0.5371028573756125}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{-0.9457675295952219, 0.5371028573756125}, {-0.9426374519262395, \
0.5624063276196131}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.9249999999999999, 0.1], \
Polygon[{{-0.9426374519262395, 0.5624063276196131}, 
     {-0.939865519772524, 0.5838857533279135}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{-0.939865519772524, 0.5838857533279135}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.9583333333333334, 0.1], \
Polygon[{{-0.937572879870399, 0.6010618457721164}, 
     {-0.935859731584894, 0.6135770923916908}, {-1., 0.}, {-1., 0.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{-0.935859731584894, 0.6135770923916908}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.9916666666666667, 0.1], \
Polygon[{{-0.9348009477166834, 0.6211835161491779}, 
     {-0.9344428022014165, 0.6237350724532796}, {-1., 0.}, {-1., 0.}}]}, 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9344428022014168, 0.623735072453278}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9358597315848943, 0.613577092391689}, \
{-0.9348009477166837, 0.6211835161491764}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721149}, \
{-0.9358597315848943, 0.613577092391689}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279119}, \
{-0.9375728798703992, 0.6010618457721149}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196118}, \
{-0.9398655197725243, 0.5838857533279119}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, \
{-0.9426374519262397, 0.5624063276196118}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.508595070176279}, \
{-0.945767529595222, 0.5371028573756114}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9525452499365675, 0.4776706018498101}, \
{-0.9491189533655577, 0.508595070176279}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.4453237472356564}, \
{-0.9525452499365675, 0.4776706018498101}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9590267513758856, 0.4128060526669478}, \
{-0.9558966737069031, 0.4453237472356564}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.961798683529601, 0.3816816923272188}, \
{-0.9590267513758856, 0.4128060526669478}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, \
{-0.961798683529601, 0.3816816923272188}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9658044717172308, 0.33154008354139414}, \
{-0.964091323431726, 0.35386023041001824}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9668632555854415, 0.31695593148714024}, \
{-0.9658044717172308, 0.33154008354139414}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9672214011007084, 0.311867536226639}, \
{-0.9668632555854415, 0.31695593148714024}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9668632555854415, 0.31695593148714024}, \
{-0.9672214011007084, 0.311867536226639}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9658044717172308, 0.33154008354139414}, \
{-0.9668632555854415, 0.31695593148714024}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, \
{-0.9658044717172308, 0.33154008354139414}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.961798683529601, 0.38168169232721855}, \
{-0.964091323431726, 0.35386023041001824}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9590267513758856, 0.4128060526669478}, \
{-0.961798683529601, 0.38168169232721855}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.4453237472356564}, \
{-0.9590267513758856, 0.4128060526669478}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9525452499365675, 0.47767060184980986}, \
{-0.9558966737069031, 0.4453237472356564}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.508595070176279}, \
{-0.9525452499365675, 0.47767060184980986}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, \
{-0.9491189533655577, 0.508595070176279}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196116}, \
{-0.945767529595222, 0.5371028573756114}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279119}, \
{-0.9426374519262397, 0.5624063276196116}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721149}, \
{-0.9398655197725243, 0.5838857533279119}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9358597315848944, 0.6135770923916888}, \
{-0.9375728798703992, 0.6010618457721149}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9358597315848944, 0.6135770923916888}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9344428022014168, 0.623735072453278}, \
{-0.9348009477166837, 0.6211835161491764}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9344428022014168, 0.623735072453278}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9358597315848943, 0.613577092391689}, \
{-0.9348009477166837, 0.6211835161491764}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721151}, \
{-0.9358597315848943, 0.613577092391689}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279119}, \
{-0.9375728798703992, 0.6010618457721151}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196118}, \
{-0.9398655197725243, 0.5838857533279119}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, \
{-0.9426374519262397, 0.5624063276196118}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.508595070176279}, \
{-0.945767529595222, 0.5371028573756114}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9525452499365675, 0.4776706018498101}, \
{-0.9491189533655577, 0.508595070176279}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.4453237472356564}, \
{-0.9525452499365675, 0.4776706018498101}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9590267513758856, 0.4128060526669481}, \
{-0.9558966737069031, 0.4453237472356564}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.961798683529601, 0.3816816923272188}, \
{-0.9590267513758856, 0.4128060526669481}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, \
{-0.961798683529601, 0.3816816923272188}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9658044717172308, 0.33154008354139414}, \
{-0.964091323431726, 0.35386023041001824}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9668632555854414, 0.31695593148714096}, \
{-0.9658044717172308, 0.33154008354139414}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9672214011007084, 0.311867536226639}, \
{-0.9668632555854414, 0.31695593148714096}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9668632555854415, 0.31695593148714024}, \
{-0.9672214011007084, 0.311867536226639}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9658044717172309, 0.33154008354139347}, \
{-0.9668632555854415, 0.31695593148714024}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.964091323431726, 0.35386023041001824}, \
{-0.9658044717172309, 0.33154008354139347}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9617986835296011, 0.38168169232721827}, \
{-0.964091323431726, 0.35386023041001824}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9590267513758856, 0.41280605266694753}, \
{-0.9617986835296011, 0.38168169232721827}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9558966737069031, 0.44532374723565615}, \
{-0.9590267513758856, 0.41280605266694753}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9525452499365675, 0.47767060184980986}, \
{-0.9558966737069031, 0.44532374723565615}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9491189533655577, 0.5085950701762788}, \
{-0.9525452499365675, 0.47767060184980986}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.945767529595222, 0.5371028573756114}, \
{-0.9491189533655577, 0.5085950701762788}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9426374519262397, 0.5624063276196116}, \
{-0.945767529595222, 0.5371028573756114}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9398655197725243, 0.5838857533279117}, \
{-0.9426374519262397, 0.5624063276196116}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9375728798703992, 0.6010618457721149}, \
{-0.9398655197725243, 0.5838857533279117}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9358597315848944, 0.6135770923916888}, \
{-0.9375728798703992, 0.6010618457721149}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9348009477166837, 0.6211835161491764}, \
{-0.9358597315848944, 0.6135770923916888}, {-1., 0.}}], 
  Line[{{-1., 0.}, {-1., 0.}, {-0.9344428022014168, 0.623735072453278}, \
{-0.9348009477166837, 0.6211835161491764}, {-1., 0.}}], 
  Line[{{-0.9344428022014168, 0.623735072453278}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112804, 1.2152748245287444}, 
    {-0.7406363729278029, 1.2202099292274005}, {-0.9344428022014168, \
0.623735072453278}}], 
  Line[{{-0.9348009477166837, 0.6211835161491764}, {-0.9358597315848943, \
0.613577092391689}, {-0.7462421638484733, 1.2005567894684717}, 
    {-0.7420533023112804, 1.2152748245287444}, {-0.9348009477166837, \
0.6211835161491764}}], 
  Line[{{-0.9358597315848943, 0.613577092391689}, {-0.9375728798703992, \
0.6010618457721149}, {-0.7530198841898188, 1.1763209525760518}, 
    {-0.7462421638484733, 1.2005567894684717}, {-0.9358597315848943, \
0.613577092391689}}], 
  Line[{{-0.9375728798703992, 0.6010618457721149}, {-0.9398655197725243, \
0.5838857533279119}, {-0.7620902444332892, 1.143020501605284}, 
    {-0.7530198841898188, 1.1763209525760518}, {-0.9375728798703992, \
0.6010618457721149}}], 
  Line[{{-0.9398655197725243, 0.5838857533279119}, {-0.9426374519262397, \
0.5624063276196118}, {-0.7730568263118275, 1.1013148858947208}, 
    {-0.7620902444332892, 1.143020501605284}, {-0.9398655197725243, \
0.5838857533279119}}], 
  Line[{{-0.9426374519262397, 0.5624063276196118}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738435, 1.0520980143876293}, 
    {-0.7730568263118275, 1.1013148858947208}, {-0.9426374519262397, \
0.5624063276196118}}], 
  Line[{{-0.945767529595222, 0.5371028573756114}, {-0.9491189533655577, \
0.508595070176279}, {-0.7986995593545068, 0.9965396214846545}, 
    {-0.7854403375738435, 1.0520980143876293}, {-0.945767529595222, \
0.5371028573756114}}], 
  Line[{{-0.9491189533655577, 0.508595070176279}, {-0.9525452499365675, \
0.4776706018498101}, {-0.8122550000371975, 0.9361441841071271}, 
    {-0.7986995593545068, 0.9965396214846545}, {-0.9491189533655577, \
0.508595070176279}}], 
  Line[{{-0.9525452499365675, 0.4776706018498101}, {-0.9558966737069031, \
0.4453237472356564}, {-0.8255142218178609, 0.8728320775698118}, 
    {-0.8122550000371975, 0.9361441841071271}, {-0.9525452499365675, \
0.4776706018498101}}], 
  Line[{{-0.9558966737069031, 0.4453237472356564}, {-0.9590267513758856, \
0.4128060526669478}, {-0.8378977330798768, 0.8090441125945328}, 
    {-0.8255142218178609, 0.8728320775698118}, {-0.9558966737069031, \
0.4453237472356564}}], 
  Line[{{-0.9590267513758856, 0.4128060526669478}, {-0.961798683529601, \
0.3816816923272188}, {-0.8488643149584152, 0.7478557941640108}, 
    {-0.8378977330798768, 0.8090441125945328}, {-0.9590267513758856, \
0.4128060526669478}}], 
  Line[{{-0.961798683529601, 0.3816816923272188}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018857, 0.6930472461935369}, 
    {-0.8488643149584152, 0.7478557941640108}, {-0.961798683529601, \
0.3816816923272188}}], 
  Line[{{-0.964091323431726, 0.35386023041001824}, {-0.9658044717172308, \
0.33154008354139414}, {-0.864712395543231, 0.6489952411032603}, 
    {-0.8579346752018857, 0.6930472461935369}, {-0.964091323431726, \
0.35386023041001824}}], 
  Line[{{-0.9658044717172308, 0.33154008354139414}, {-0.9668632555854415, \
0.31695593148714024}, {-0.868901257080424, 0.6201700772082609}, 
    {-0.864712395543231, 0.6489952411032603}, {-0.9658044717172308, \
0.33154008354139414}}], 
  Line[{{-0.9668632555854415, 0.31695593148714024}, {-0.9672214011007084, \
0.311867536226639}, {-0.8703181864639015, 0.6101049646137003}, 
    {-0.868901257080424, 0.6201700772082609}, {-0.9668632555854415, \
0.31695593148714024}}], 
  Line[{{-0.9672214011007084, 0.311867536226639}, {-0.9668632555854415, \
0.31695593148714024}, {-0.8689012570804241, 0.6201700772082606}, 
    {-0.8703181864639015, 0.6101049646137003}, {-0.9672214011007084, \
0.311867536226639}}], 
  Line[{{-0.9668632555854415, 0.31695593148714024}, {-0.9658044717172308, \
0.33154008354139414}, {-0.864712395543231, 0.6489952411032603}, 
    {-0.8689012570804241, 0.6201700772082606}, {-0.9668632555854415, \
0.31695593148714024}}], 
  Line[{{-0.9658044717172308, 0.33154008354139414}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018857, 0.6930472461935366}, 
    {-0.864712395543231, 0.6489952411032603}, {-0.9658044717172308, \
0.33154008354139414}}], 
  Line[{{-0.964091323431726, 0.35386023041001824}, {-0.961798683529601, \
0.38168169232721855}, {-0.8488643149584152, 0.7478557941640107}, 
    {-0.8579346752018857, 0.6930472461935366}, {-0.964091323431726, \
0.35386023041001824}}], 
  Line[{{-0.961798683529601, 0.38168169232721855}, {-0.9590267513758856, \
0.4128060526669478}, {-0.8378977330798769, 0.8090441125945326}, 
    {-0.8488643149584152, 0.7478557941640107}, {-0.961798683529601, \
0.38168169232721855}}], 
  Line[{{-0.9590267513758856, 0.4128060526669478}, {-0.9558966737069031, \
0.4453237472356564}, {-0.8255142218178609, 0.8728320775698117}, 
    {-0.8378977330798769, 0.8090441125945326}, {-0.9590267513758856, \
0.4128060526669478}}], 
  Line[{{-0.9558966737069031, 0.4453237472356564}, {-0.9525452499365675, \
0.47767060184980986}, {-0.8122550000371976, 0.9361441841071267}, 
    {-0.8255142218178609, 0.8728320775698117}, {-0.9558966737069031, \
0.4453237472356564}}], 
  Line[{{-0.9525452499365675, 0.47767060184980986}, {-0.9491189533655577, \
0.508595070176279}, {-0.7986995593545069, 0.9965396214846542}, 
    {-0.8122550000371976, 0.9361441841071267}, {-0.9525452499365675, \
0.47767060184980986}}], 
  Line[{{-0.9491189533655577, 0.508595070176279}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738435, 1.0520980143876293}, 
    {-0.7986995593545069, 0.9965396214846542}, {-0.9491189533655577, \
0.508595070176279}}], 
  Line[{{-0.945767529595222, 0.5371028573756114}, {-0.9426374519262397, \
0.5624063276196116}, {-0.7730568263118276, 1.1013148858947206}, 
    {-0.7854403375738435, 1.0520980143876293}, {-0.945767529595222, \
0.5371028573756114}}], 
  Line[{{-0.9426374519262397, 0.5624063276196116}, {-0.9398655197725243, \
0.5838857533279119}, {-0.7620902444332892, 1.1430205016052837}, 
    {-0.7730568263118276, 1.1013148858947206}, {-0.9426374519262397, \
0.5624063276196116}}], 
  Line[{{-0.9398655197725243, 0.5838857533279119}, {-0.9375728798703992, \
0.6010618457721149}, {-0.7530198841898188, 1.1763209525760518}, 
    {-0.7620902444332892, 1.1430205016052837}, {-0.9398655197725243, \
0.5838857533279119}}], 
  Line[{{-0.9375728798703992, 0.6010618457721149}, {-0.9358597315848944, \
0.6135770923916888}, {-0.7462421638484733, 1.2005567894684717}, 
    {-0.7530198841898188, 1.1763209525760518}, {-0.9375728798703992, \
0.6010618457721149}}], 
  Line[{{-0.9358597315848944, 0.6135770923916888}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112804, 1.2152748245287444}, 
    {-0.7462421638484733, 1.2005567894684717}, {-0.9358597315848944, \
0.6135770923916888}}], 
  Line[{{-0.9348009477166837, 0.6211835161491764}, {-0.9344428022014168, \
0.623735072453278}, {-0.7406363729278029, 1.2202099292274005}, 
    {-0.7420533023112804, 1.2152748245287444}, {-0.9348009477166837, \
0.6211835161491764}}], 
  Line[{{-0.9344428022014168, 0.623735072453278}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112804, 1.2152748245287444}, 
    {-0.7406363729278029, 1.2202099292274005}, {-0.9344428022014168, \
0.623735072453278}}], 
  Line[{{-0.9348009477166837, 0.6211835161491764}, {-0.9358597315848943, \
0.613577092391689}, {-0.7462421638484733, 1.2005567894684717}, 
    {-0.7420533023112804, 1.2152748245287444}, {-0.9348009477166837, \
0.6211835161491764}}], 
  Line[{{-0.9358597315848943, 0.613577092391689}, {-0.9375728798703992, \
0.6010618457721151}, {-0.7530198841898188, 1.1763209525760518}, 
    {-0.7462421638484733, 1.2005567894684717}, {-0.9358597315848943, \
0.613577092391689}}], 
  Line[{{-0.9375728798703992, 0.6010618457721151}, {-0.9398655197725243, \
0.5838857533279119}, {-0.7620902444332891, 1.1430205016052841}, 
    {-0.7530198841898188, 1.1763209525760518}, {-0.9375728798703992, \
0.6010618457721151}}], 
  Line[{{-0.9398655197725243, 0.5838857533279119}, {-0.9426374519262397, \
0.5624063276196118}, {-0.7730568263118276, 1.1013148858947208}, 
    {-0.7620902444332891, 1.1430205016052841}, {-0.9398655197725243, \
0.5838857533279119}}], 
  Line[{{-0.9426374519262397, 0.5624063276196118}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738434, 1.0520980143876295}, 
    {-0.7730568263118276, 1.1013148858947208}, {-0.9426374519262397, \
0.5624063276196118}}], 
  Line[{{-0.945767529595222, 0.5371028573756114}, {-0.9491189533655577, \
0.508595070176279}, {-0.7986995593545068, 0.9965396214846547}, 
    {-0.7854403375738434, 1.0520980143876295}, {-0.945767529595222, \
0.5371028573756114}}], 
  Line[{{-0.9491189533655577, 0.508595070176279}, {-0.9525452499365675, \
0.4776706018498101}, {-0.8122550000371975, 0.9361441841071272}, 
    {-0.7986995593545068, 0.9965396214846547}, {-0.9491189533655577, \
0.508595070176279}}], 
  Line[{{-0.9525452499365675, 0.4776706018498101}, {-0.9558966737069031, \
0.4453237472356564}, {-0.825514221817861, 0.8728320775698117}, 
    {-0.8122550000371975, 0.9361441841071272}, {-0.9525452499365675, \
0.4776706018498101}}], 
  Line[{{-0.9558966737069031, 0.4453237472356564}, {-0.9590267513758856, \
0.4128060526669481}, {-0.8378977330798767, 0.8090441125945331}, 
    {-0.825514221817861, 0.8728320775698117}, {-0.9558966737069031, \
0.4453237472356564}}], 
  Line[{{-0.9590267513758856, 0.4128060526669481}, {-0.961798683529601, \
0.3816816923272188}, {-0.8488643149584152, 0.747855794164011}, 
    {-0.8378977330798767, 0.8090441125945331}, {-0.9590267513758856, \
0.4128060526669481}}], 
  Line[{{-0.961798683529601, 0.3816816923272188}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018856, 0.6930472461935369}, 
    {-0.8488643149584152, 0.747855794164011}, {-0.961798683529601, \
0.3816816923272188}}], 
  Line[{{-0.964091323431726, 0.35386023041001824}, {-0.9658044717172308, \
0.33154008354139414}, {-0.864712395543231, 0.6489952411032606}, 
    {-0.8579346752018856, 0.6930472461935369}, {-0.964091323431726, \
0.35386023041001824}}], 
  Line[{{-0.9658044717172308, 0.33154008354139414}, {-0.9668632555854414, \
0.31695593148714096}, {-0.868901257080424, 0.6201700772082609}, 
    {-0.864712395543231, 0.6489952411032606}, {-0.9658044717172308, \
0.33154008354139414}}], 
  Line[{{-0.9668632555854414, 0.31695593148714096}, {-0.9672214011007084, \
0.311867536226639}, {-0.8703181864639015, 0.6101049646137003}, 
    {-0.868901257080424, 0.6201700772082609}, {-0.9668632555854414, \
0.31695593148714096}}], 
  Line[{{-0.9672214011007084, 0.311867536226639}, {-0.9668632555854415, \
0.31695593148714024}, {-0.8689012570804241, 0.6201700772082606}, 
    {-0.8703181864639015, 0.6101049646137003}, {-0.9672214011007084, \
0.311867536226639}}], 
  Line[{{-0.9668632555854415, 0.31695593148714024}, {-0.9658044717172309, \
0.33154008354139347}, {-0.8647123955432311, 0.64899524110326}, 
    {-0.8689012570804241, 0.6201700772082606}, {-0.9668632555854415, \
0.31695593148714024}}], 
  Line[{{-0.9658044717172309, 0.33154008354139347}, {-0.964091323431726, \
0.35386023041001824}, {-0.8579346752018857, 0.6930472461935366}, 
    {-0.8647123955432311, 0.64899524110326}, {-0.9658044717172309, \
0.33154008354139347}}], 
  Line[{{-0.964091323431726, 0.35386023041001824}, {-0.9617986835296011, \
0.38168169232721827}, {-0.8488643149584153, 0.7478557941640104}, 
    {-0.8579346752018857, 0.6930472461935366}, {-0.964091323431726, \
0.35386023041001824}}], 
  Line[{{-0.9617986835296011, 0.38168169232721827}, {-0.9590267513758856, \
0.41280605266694753}, {-0.8378977330798769, 0.8090441125945322}, 
    {-0.8488643149584153, 0.7478557941640104}, {-0.9617986835296011, \
0.38168169232721827}}], 
  Line[{{-0.9590267513758856, 0.41280605266694753}, {-0.9558966737069031, \
0.44532374723565615}, {-0.8255142218178609, 0.8728320775698117}, 
    {-0.8378977330798769, 0.8090441125945322}, {-0.9590267513758856, \
0.41280605266694753}}], 
  Line[{{-0.9558966737069031, 0.44532374723565615}, {-0.9525452499365675, \
0.47767060184980986}, {-0.8122550000371977, 0.9361441841071265}, 
    {-0.8255142218178609, 0.8728320775698117}, {-0.9558966737069031, \
0.44532374723565615}}], 
  Line[{{-0.9525452499365675, 0.47767060184980986}, {-0.9491189533655577, \
0.5085950701762788}, {-0.798699559354507, 0.9965396214846538}, 
    {-0.8122550000371977, 0.9361441841071265}, {-0.9525452499365675, \
0.47767060184980986}}], 
  Line[{{-0.9491189533655577, 0.5085950701762788}, {-0.945767529595222, \
0.5371028573756114}, {-0.7854403375738435, 1.0520980143876293}, 
    {-0.798699559354507, 0.9965396214846538}, {-0.9491189533655577, \
0.5085950701762788}}], 
  Line[{{-0.945767529595222, 0.5371028573756114}, {-0.9426374519262397, \
0.5624063276196116}, {-0.7730568263118276, 1.1013148858947206}, 
    {-0.7854403375738435, 1.0520980143876293}, {-0.945767529595222, \
0.5371028573756114}}], 
  Line[{{-0.9426374519262397, 0.5624063276196116}, {-0.9398655197725243, \
0.5838857533279117}, {-0.7620902444332892, 1.1430205016052835}, 
    {-0.7730568263118276, 1.1013148858947206}, {-0.9426374519262397, \
0.5624063276196116}}], 
  Line[{{-0.9398655197725243, 0.5838857533279117}, {-0.9375728798703992, \
0.6010618457721149}, {-0.7530198841898188, 1.1763209525760518}, 
    {-0.7620902444332892, 1.1430205016052835}, {-0.9398655197725243, \
0.5838857533279117}}], 
  Line[{{-0.9375728798703992, 0.6010618457721149}, {-0.9358597315848944, \
0.6135770923916888}, {-0.7462421638484733, 1.2005567894684717}, 
    {-0.7530198841898188, 1.1763209525760518}, {-0.9375728798703992, \
0.6010618457721149}}], 
  Line[{{-0.9358597315848944, 0.6135770923916888}, {-0.9348009477166837, \
0.6211835161491764}, {-0.7420533023112803, 1.2152748245287444}, 
    {-0.7462421638484733, 1.2005567894684717}, {-0.9358597315848944, \
0.6135770923916888}}], 
  Line[{{-0.9348009477166837, 0.6211835161491764}, {-0.9344428022014168, \
0.623735072453278}, {-0.7406363729278029, 1.2202099292274005}, 
    {-0.7420533023112803, 1.2152748245287444}, {-0.9348009477166837, \
0.6211835161491764}}], 
  Line[{{-0.7406363729278029, 1.2202099292274005}, {-0.7420533023112804, \
1.2152748245287444}, {-0.4301810607938247, 1.7563683493937294}, 
    {-0.42705098312484224, 1.7633557568774194}, {-0.7406363729278029, \
1.2202099292274005}}], 
  Line[{{-0.7420533023112804, 1.2152748245287444}, {-0.7462421638484733, \
1.2005567894684717}, {-0.43943449438685805, 1.7355139912456732}, 
    {-0.4301810607938247, 1.7563683493937294}, {-0.7420533023112804, \
1.2152748245287444}}], 
  Line[{{-0.7462421638484733, 1.2005567894684717}, {-0.7530198841898188, \
1.1763209525760518}, {-0.45440686445302647, 1.7011229525643672}, 
    {-0.43943449438685805, 1.7355139912456732}, {-0.7462421638484733, \
1.2005567894684717}}], 
  Line[{{-0.7530198841898188, 1.1763209525760518}, {-0.7620902444332892, \
1.143020501605284}, {-0.4744438065750352, 1.653768235803273}, 
    {-0.45440686445302647, 1.7011229525643672}, {-0.7530198841898188, \
1.1763209525760518}}], 
  Line[{{-0.7620902444332892, 1.143020501605284}, {-0.7730568263118275, \
1.1013148858947208}, {-0.49866961023423695, 1.5943005668830774}, 
    {-0.4744438065750352, 1.653768235803273}, {-0.7620902444332892, \
1.143020501605284}}], 
  Line[{{-0.7730568263118275, 1.1013148858947208}, {-0.7854403375738435, \
1.0520980143876293}, {-0.5260254915624212, 1.523900157708533}, 
    {-0.49866961023423695, 1.5943005668830774}, {-0.7730568263118275, \
1.1013148858947208}}], 
  Line[{{-0.7854403375738435, 1.0520980143876293}, {-0.7986995593545068, \
0.9965396214846545}, {-0.5553158672774633, 1.444148941758488}, 
    {-0.5260254915624212, 1.523900157708533}, {-0.7854403375738435, \
1.0520980143876293}}], 
  Line[{{-0.7986995593545068, 0.9965396214846545}, {-0.8122550000371975, \
0.9361441841071271}, {-0.5852606074097999, 1.3571288512592452}, 
    {-0.5553158672774633, 1.444148941758488}, {-0.7986995593545068, \
0.9965396214846545}}], 
  Line[{{-0.8122550000371975, 0.9361441841071271}, {-0.8255142218178609, \
0.8728320775698118}, {-0.6145509831248422, 1.2655525104241707}, 
    {-0.5852606074097999, 1.3571288512592452}, {-0.8122550000371975, \
0.9361441841071271}}], 
  Line[{{-0.8255142218178609, 0.8728320775698118}, {-0.8378977330798768, \
0.8090441125945328}, {-0.6419068644530264, 1.1729281630054869}, 
    {-0.6145509831248422, 1.2655525104241707}, {-0.8255142218178609, \
0.8728320775698118}}], 
  Line[{{-0.8378977330798768, 0.8090441125945328}, {-0.8488643149584152, \
0.7478557941640108}, {-0.6661326681122282, 1.0837396094369778}, 
    {-0.6419068644530264, 1.1729281630054869}, {-0.8378977330798768, \
0.8090441125945328}}], 
  Line[{{-0.8488643149584152, 0.7478557941640108}, {-0.8579346752018857, \
0.6930472461935369}, {-0.686169610234237, 1.0035621274868154}, 
    {-0.6661326681122282, 1.0837396094369778}, {-0.8488643149584152, \
0.7478557941640108}}], 
  Line[{{-0.8579346752018857, 0.6930472461935369}, {-0.864712395543231, \
0.6489952411032603}, {-0.7011419803004051, 0.9389137397717197}, 
    {-0.686169610234237, 1.0035621274868154}, {-0.8579346752018857, \
0.6930472461935369}}], 
  Line[{{-0.864712395543231, 0.6489952411032603}, {-0.868901257080424, \
0.6201700772082609}, {-0.7103954138934387, 0.8965062230902947}, 
    {-0.7011419803004051, 0.9389137397717197}, {-0.864712395543231, \
0.6489952411032603}}], 
  Line[{{-0.868901257080424, 0.6201700772082609}, {-0.8703181864639015, \
0.6101049646137003}, {-0.7135254915624211, 0.8816778784387097}, 
    {-0.7103954138934387, 0.8965062230902947}, {-0.868901257080424, \
0.6201700772082609}}], 
  Line[{{-0.8703181864639015, 0.6101049646137003}, {-0.8689012570804241, \
0.6201700772082606}, {-0.7103954138934387, 0.8965062230902947}, 
    {-0.7135254915624211, 0.8816778784387097}, {-0.8703181864639015, \
0.6101049646137003}}], 
  Line[{{-0.8689012570804241, 0.6201700772082606}, {-0.864712395543231, \
0.6489952411032603}, {-0.7011419803004052, 0.9389137397717193}, 
    {-0.7103954138934387, 0.8965062230902947}, {-0.8689012570804241, \
0.6201700772082606}}], 
  Line[{{-0.864712395543231, 0.6489952411032603}, {-0.8579346752018857, \
0.6930472461935366}, {-0.686169610234237, 1.0035621274868152}, 
    {-0.7011419803004052, 0.9389137397717193}, {-0.864712395543231, \
0.6489952411032603}}], 
  Line[{{-0.8579346752018857, 0.6930472461935366}, {-0.8488643149584152, \
0.7478557941640107}, {-0.6661326681122282, 1.0837396094369778}, 
    {-0.686169610234237, 1.0035621274868152}, {-0.8579346752018857, \
0.6930472461935366}}], 
  Line[{{-0.8488643149584152, 0.7478557941640107}, {-0.8378977330798769, \
0.8090441125945326}, {-0.6419068644530265, 1.1729281630054864}, 
    {-0.6661326681122282, 1.0837396094369778}, {-0.8488643149584152, \
0.7478557941640107}}], 
  Line[{{-0.8378977330798769, 0.8090441125945326}, {-0.8255142218178609, \
0.8728320775698117}, {-0.6145509831248422, 1.2655525104241705}, 
    {-0.6419068644530265, 1.1729281630054864}, {-0.8378977330798769, \
0.8090441125945326}}], 
  Line[{{-0.8255142218178609, 0.8728320775698117}, {-0.8122550000371976, \
0.9361441841071267}, {-0.5852606074098001, 1.357128851259245}, 
    {-0.6145509831248422, 1.2655525104241705}, {-0.8255142218178609, \
0.8728320775698117}}], 
  Line[{{-0.8122550000371976, 0.9361441841071267}, {-0.7986995593545069, \
0.9965396214846542}, {-0.5553158672774634, 1.4441489417584878}, 
    {-0.5852606074098001, 1.357128851259245}, {-0.8122550000371976, \
0.9361441841071267}}], 
  Line[{{-0.7986995593545069, 0.9965396214846542}, {-0.7854403375738435, \
1.0520980143876293}, {-0.5260254915624212, 1.523900157708533}, 
    {-0.5553158672774634, 1.4441489417584878}, {-0.7986995593545069, \
0.9965396214846542}}], 
  Line[{{-0.7854403375738435, 1.0520980143876293}, {-0.7730568263118276, \
1.1013148858947206}, {-0.4986696102342371, 1.594300566883077}, 
    {-0.5260254915624212, 1.523900157708533}, {-0.7854403375738435, \
1.0520980143876293}}], 
  Line[{{-0.7730568263118276, 1.1013148858947206}, {-0.7620902444332892, \
1.1430205016052837}, {-0.47444380657503515, 1.653768235803273}, 
    {-0.4986696102342371, 1.594300566883077}, {-0.7730568263118276, \
1.1013148858947206}}], 
  Line[{{-0.7620902444332892, 1.1430205016052837}, {-0.7530198841898188, \
1.1763209525760518}, {-0.45440686445302647, 1.7011229525643672}, 
    {-0.47444380657503515, 1.653768235803273}, {-0.7620902444332892, \
1.1430205016052837}}], 
  Line[{{-0.7530198841898188, 1.1763209525760518}, {-0.7462421638484733, \
1.2005567894684717}, {-0.4394344943868581, 1.735513991245673}, 
    {-0.45440686445302647, 1.7011229525643672}, {-0.7530198841898188, \
1.1763209525760518}}], 
  Line[{{-0.7462421638484733, 1.2005567894684717}, {-0.7420533023112804, \
1.2152748245287444}, {-0.4301810607938247, 1.7563683493937294}, 
    {-0.4394344943868581, 1.735513991245673}, {-0.7462421638484733, \
1.2005567894684717}}], 
  Line[{{-0.7420533023112804, 1.2152748245287444}, {-0.7406363729278029, \
1.2202099292274005}, {-0.42705098312484224, 1.7633557568774194}, 
    {-0.4301810607938247, 1.7563683493937294}, {-0.7420533023112804, \
1.2152748245287444}}], 
  Line[{{-0.7406363729278029, 1.2202099292274005}, {-0.7420533023112804, \
1.2152748245287444}, {-0.43018106079382457, 1.7563683493937297}, 
    {-0.42705098312484224, 1.7633557568774194}, {-0.7406363729278029, \
1.2202099292274005}}], 
  Line[{{-0.7420533023112804, 1.2152748245287444}, {-0.7462421638484733, \
1.2005567894684717}, {-0.4394344943868581, 1.7355139912456732}, 
    {-0.43018106079382457, 1.7563683493937297}, {-0.7420533023112804, \
1.2152748245287444}}], 
  Line[{{-0.7462421638484733, 1.2005567894684717}, {-0.7530198841898188, \
1.1763209525760518}, {-0.45440686445302636, 1.7011229525643672}, 
    {-0.4394344943868581, 1.7355139912456732}, {-0.7462421638484733, \
1.2005567894684717}}], 
  Line[{{-0.7530198841898188, 1.1763209525760518}, {-0.7620902444332891, \
1.1430205016052841}, {-0.47444380657503504, 1.6537682358032735}, 
    {-0.45440686445302636, 1.7011229525643672}, {-0.7530198841898188, \
1.1763209525760518}}], 
  Line[{{-0.7620902444332891, 1.1430205016052841}, {-0.7730568263118276, \
1.1013148858947208}, {-0.4986696102342368, 1.5943005668830776}, 
    {-0.47444380657503504, 1.6537682358032735}, {-0.7620902444332891, \
1.1430205016052841}}], 
  Line[{{-0.7730568263118276, 1.1013148858947208}, {-0.7854403375738434, \
1.0520980143876295}, {-0.526025491562421, 1.5239001577085334}, 
    {-0.4986696102342368, 1.5943005668830776}, {-0.7730568263118276, \
1.1013148858947208}}], 
  Line[{{-0.7854403375738434, 1.0520980143876295}, {-0.7986995593545068, \
0.9965396214846547}, {-0.5553158672774632, 1.4441489417584885}, 
    {-0.526025491562421, 1.5239001577085334}, {-0.7854403375738434, \
1.0520980143876295}}], 
  Line[{{-0.7986995593545068, 0.9965396214846547}, {-0.8122550000371975, \
0.9361441841071272}, {-0.5852606074097999, 1.3571288512592454}, 
    {-0.5553158672774632, 1.4441489417584885}, {-0.7986995593545068, \
0.9965396214846547}}], 
  Line[{{-0.8122550000371975, 0.9361441841071272}, {-0.825514221817861, \
0.8728320775698117}, {-0.6145509831248421, 1.265552510424171}, 
    {-0.5852606074097999, 1.3571288512592454}, {-0.8122550000371975, \
0.9361441841071272}}], 
  Line[{{-0.825514221817861, 0.8728320775698117}, {-0.8378977330798767, \
0.8090441125945331}, {-0.6419068644530262, 1.1729281630054873}, 
    {-0.6145509831248421, 1.265552510424171}, {-0.825514221817861, \
0.8728320775698117}}], 
  Line[{{-0.8378977330798767, 0.8090441125945331}, {-0.8488643149584152, \
0.747855794164011}, {-0.6661326681122279, 1.0837396094369784}, 
    {-0.6419068644530262, 1.1729281630054873}, {-0.8378977330798767, \
0.8090441125945331}}], 
  Line[{{-0.8488643149584152, 0.747855794164011}, {-0.8579346752018856, \
0.6930472461935369}, {-0.6861696102342368, 1.0035621274868156}, 
    {-0.6661326681122279, 1.0837396094369784}, {-0.8488643149584152, \
0.747855794164011}}], 
  Line[{{-0.8579346752018856, 0.6930472461935369}, {-0.864712395543231, \
0.6489952411032606}, {-0.7011419803004051, 0.9389137397717197}, 
    {-0.6861696102342368, 1.0035621274868156}, {-0.8579346752018856, \
0.6930472461935369}}], 
  Line[{{-0.864712395543231, 0.6489952411032606}, {-0.868901257080424, \
0.6201700772082609}, {-0.7103954138934386, 0.8965062230902949}, 
    {-0.7011419803004051, 0.9389137397717197}, {-0.864712395543231, \
0.6489952411032606}}], 
  Line[{{-0.868901257080424, 0.6201700772082609}, {-0.8703181864639015, \
0.6101049646137003}, {-0.7135254915624211, 0.8816778784387097}, 
    {-0.7103954138934386, 0.8965062230902949}, {-0.868901257080424, \
0.6201700772082609}}], 
  Line[{{-0.8703181864639015, 0.6101049646137003}, {-0.8689012570804241, \
0.6201700772082606}, {-0.7103954138934387, 0.8965062230902945}, 
    {-0.7135254915624211, 0.8816778784387097}, {-0.8703181864639015, \
0.6101049646137003}}], 
  Line[{{-0.8689012570804241, 0.6201700772082606}, {-0.8647123955432311, \
0.64899524110326}, {-0.7011419803004053, 0.938913739771719}, 
    {-0.7103954138934387, 0.8965062230902945}, {-0.8689012570804241, \
0.6201700772082606}}], 
  Line[{{-0.8647123955432311, 0.64899524110326}, {-0.8579346752018857, \
0.6930472461935366}, {-0.686169610234237, 1.0035621274868152}, 
    {-0.7011419803004053, 0.938913739771719}, {-0.8647123955432311, \
0.64899524110326}}], 
  Line[{{-0.8579346752018857, 0.6930472461935366}, {-0.8488643149584153, \
0.7478557941640104}, {-0.6661326681122283, 1.0837396094369776}, 
    {-0.686169610234237, 1.0035621274868152}, {-0.8579346752018857, \
0.6930472461935366}}], 
  Line[{{-0.8488643149584153, 0.7478557941640104}, {-0.8378977330798769, \
0.8090441125945322}, {-0.6419068644530266, 1.172928163005486}, 
    {-0.6661326681122283, 1.0837396094369776}, {-0.8488643149584153, \
0.7478557941640104}}], 
  Line[{{-0.8378977330798769, 0.8090441125945322}, {-0.8255142218178609, \
0.8728320775698117}, {-0.6145509831248424, 1.2655525104241703}, 
    {-0.6419068644530266, 1.172928163005486}, {-0.8378977330798769, \
0.8090441125945322}}], 
  Line[{{-0.8255142218178609, 0.8728320775698117}, {-0.8122550000371977, \
0.9361441841071265}, {-0.5852606074098001, 1.357128851259245}, 
    {-0.6145509831248424, 1.2655525104241703}, {-0.8255142218178609, \
0.8728320775698117}}], 
  Line[{{-0.8122550000371977, 0.9361441841071265}, {-0.798699559354507, \
0.9965396214846538}, {-0.5553158672774636, 1.4441489417584874}, 
    {-0.5852606074098001, 1.357128851259245}, {-0.8122550000371977, \
0.9361441841071265}}], 
  Line[{{-0.798699559354507, 0.9965396214846538}, {-0.7854403375738435, \
1.0520980143876293}, {-0.5260254915624211, 1.5239001577085332}, 
    {-0.5553158672774636, 1.4441489417584874}, {-0.798699559354507, \
0.9965396214846538}}], 
  Line[{{-0.7854403375738435, 1.0520980143876293}, {-0.7730568263118276, \
1.1013148858947206}, {-0.49866961023423706, 1.594300566883077}, 
    {-0.5260254915624211, 1.5239001577085332}, {-0.7854403375738435, \
1.0520980143876293}}], 
  Line[{{-0.7730568263118276, 1.1013148858947206}, {-0.7620902444332892, \
1.1430205016052835}, {-0.4744438065750353, 1.6537682358032726}, 
    {-0.49866961023423706, 1.594300566883077}, {-0.7730568263118276, \
1.1013148858947206}}], 
  Line[{{-0.7620902444332892, 1.1430205016052835}, {-0.7530198841898188, \
1.1763209525760518}, {-0.4544068644530264, 1.7011229525643672}, 
    {-0.4744438065750353, 1.6537682358032726}, {-0.7620902444332892, \
1.1430205016052835}}], 
  Line[{{-0.7530198841898188, 1.1763209525760518}, {-0.7462421638484733, \
1.2005567894684717}, {-0.4394344943868581, 1.735513991245673}, 
    {-0.4544068644530264, 1.7011229525643672}, {-0.7530198841898188, \
1.1763209525760518}}], 
  Line[{{-0.7462421638484733, 1.2005567894684717}, {-0.7420533023112803, \
1.2152748245287444}, {-0.4301810607938246, 1.7563683493937294}, 
    {-0.4394344943868581, 1.735513991245673}, {-0.7462421638484733, \
1.2005567894684717}}], 
  Line[{{-0.7420533023112803, 1.2152748245287444}, {-0.7406363729278029, \
1.2202099292274005}, {-0.42705098312484224, 1.7633557568774194}, 
    {-0.4301810607938246, 1.7563683493937294}, {-0.7420533023112803, \
1.2152748245287444}}], 
  Line[{{-0.42705098312484224, 1.7633557568774194}, {-0.4301810607938247, \
1.7563683493937294}, {-0.012814536647682145, 2.2208803408437956}, 
    {-0.007391819076574713, 2.2294344764321825}, {-0.42705098312484224, \
1.7633557568774194}}], 
  Line[{{-0.4301810607938247, 1.7563683493937294}, {-0.43943449438685805, \
1.7355139912456732}, {-0.028845690582060914, 2.195318553032826}, 
    {-0.012814536647682145, 2.2208803408437956}, {-0.4301810607938247, \
1.7563683493937294}}], 
  Line[{{-0.43943449438685805, 1.7355139912456732}, {-0.45440686445302647, \
1.7011229525643672}, {-0.05478464252676769, 2.1530633066599703}, 
    {-0.028845690582060914, 2.195318553032826}, {-0.43943449438685805, \
1.7355139912456732}}], 
  Line[{{-0.45440686445302647, 1.7011229525643672}, {-0.4744438065750352, \
1.653768235803273}, {-0.08949773581291746, 2.0946793219544757}, 
    {-0.05478464252676769, 2.1530633066599703}, {-0.45440686445302647, \
1.7011229525643672}}], 
  Line[{{-0.4744438065750352, 1.653768235803273}, {-0.49866961023423695, \
1.5943005668830774}, {-0.1314678416920028, 2.0210434859217035}, 
    {-0.08949773581291746, 2.0946793219544757}, {-0.4744438065750352, \
1.653768235803273}}], 
  Line[{{-0.49866961023423695, 1.5943005668830774}, {-0.5260254915624212, \
1.523900157708533}, {-0.17886066514219576, 1.933432094411191}, 
    {-0.1314678416920028, 2.0210434859217035}, {-0.49866961023423695, \
1.5943005668830774}}], 
  Line[{{-0.5260254915624212, 1.523900157708533}, {-0.5553158672774633, \
1.444148941758488}, {-0.2296049123627243, 1.833636456582809}, 
    {-0.17886066514219576, 1.933432094411191}, {-0.5260254915624212, \
1.523900157708533}}], 
  Line[{{-0.5553158672774633, 1.444148941758488}, {-0.5852606074097999, \
1.3571288512592452}, {-0.28148281625213767, 1.7241122839361493}, 
    {-0.2296049123627243, 1.833636456582809}, {-0.5553158672774633, \
1.444148941758488}}], 
  Line[{{-0.5852606074097999, 1.3571288512592452}, {-0.6145509831248422, \
1.2655525104241707}, {-0.3322270634726663, 1.6081701375219566}, 
    {-0.28148281625213767, 1.7241122839361493}, {-0.5852606074097999, \
1.3571288512592452}}], 
  Line[{{-0.6145509831248422, 1.2655525104241707}, {-0.6419068644530264, \
1.1729281630054869}, {-0.3796198869228592, 1.490209713504239}, 
    {-0.3322270634726663, 1.6081701375219566}, {-0.6145509831248422, \
1.2655525104241707}}], 
  Line[{{-0.6419068644530264, 1.1729281630054869}, {-0.6661326681122282, \
1.0837396094369778}, {-0.4215899928019446, 1.3759750672106554}, 
    {-0.3796198869228592, 1.490209713504239}, {-0.6419068644530264, \
1.1729281630054869}}], 
  Line[{{-0.6661326681122282, 1.0837396094369778}, {-0.686169610234237, \
1.0035621274868154}, {-0.45630308608809433, 1.2727298803122147}, 
    {-0.4215899928019446, 1.3759750672106554}, {-0.6661326681122282, \
1.0837396094369778}}], 
  Line[{{-0.686169610234237, 1.0035621274868154}, {-0.7011419803004051, \
0.9389137397717197}, {-0.482242038032801, 1.189085281951672}, 
    {-0.45630308608809433, 1.2727298803122147}, {-0.686169610234237, \
1.0035621274868154}}], 
  Line[{{-0.7011419803004051, 0.9389137397717197}, {-0.7103954138934387, \
0.8965062230902947}, {-0.4982731919671799, 1.1340136417284856}, 
    {-0.482242038032801, 1.189085281951672}, {-0.7011419803004051, \
0.9389137397717197}}], 
  Line[{{-0.7103954138934387, 0.8965062230902947}, {-0.7135254915624211, \
0.8816778784387097}, {-0.5036959095382874, 1.1147172382160913}, 
    {-0.4982731919671799, 1.1340136417284856}, {-0.7103954138934387, \
0.8965062230902947}}], 
  Line[{{-0.7135254915624211, 0.8816778784387097}, {-0.7103954138934387, \
0.8965062230902947}, {-0.49827319196717995, 1.1340136417284856}, 
    {-0.5036959095382874, 1.1147172382160913}, {-0.7135254915624211, \
0.8816778784387097}}], 
  Line[{{-0.7103954138934387, 0.8965062230902947}, {-0.7011419803004052, \
0.9389137397717193}, {-0.482242038032801, 1.1890852819516717}, 
    {-0.49827319196717995, 1.1340136417284856}, {-0.7103954138934387, \
0.8965062230902947}}], 
  Line[{{-0.7011419803004052, 0.9389137397717193}, {-0.686169610234237, \
1.0035621274868152}, {-0.4563030860880944, 1.2727298803122145}, 
    {-0.482242038032801, 1.1890852819516717}, {-0.7011419803004052, \
0.9389137397717193}}], 
  Line[{{-0.686169610234237, 1.0035621274868152}, {-0.6661326681122282, \
1.0837396094369778}, {-0.42158999280194476, 1.375975067210655}, 
    {-0.4563030860880944, 1.2727298803122145}, {-0.686169610234237, \
1.0035621274868152}}], 
  Line[{{-0.6661326681122282, 1.0837396094369778}, {-0.6419068644530265, \
1.1729281630054864}, {-0.3796198869228593, 1.4902097135042385}, 
    {-0.42158999280194476, 1.375975067210655}, {-0.6661326681122282, \
1.0837396094369778}}], 
  Line[{{-0.6419068644530265, 1.1729281630054864}, {-0.6145509831248422, \
1.2655525104241705}, {-0.3322270634726663, 1.6081701375219564}, 
    {-0.3796198869228593, 1.4902097135042385}, {-0.6419068644530265, \
1.1729281630054864}}], 
  Line[{{-0.6145509831248422, 1.2655525104241705}, {-0.5852606074098001, \
1.357128851259245}, {-0.2814828162521379, 1.724112283936149}, 
    {-0.3322270634726663, 1.6081701375219564}, {-0.6145509831248422, \
1.2655525104241705}}], 
  Line[{{-0.5852606074098001, 1.357128851259245}, {-0.5553158672774634, \
1.4441489417584878}, {-0.22960491236272457, 1.8336364565828085}, 
    {-0.2814828162521379, 1.724112283936149}, {-0.5852606074098001, \
1.357128851259245}}], 
  Line[{{-0.5553158672774634, 1.4441489417584878}, {-0.5260254915624212, \
1.523900157708533}, {-0.1788606651421958, 1.933432094411191}, 
    {-0.22960491236272457, 1.8336364565828085}, {-0.5553158672774634, \
1.4441489417584878}}], 
  Line[{{-0.5260254915624212, 1.523900157708533}, {-0.4986696102342371, \
1.594300566883077}, {-0.13146784169200298, 2.021043485921703}, 
    {-0.1788606651421958, 1.933432094411191}, {-0.5260254915624212, \
1.523900157708533}}], 
  Line[{{-0.4986696102342371, 1.594300566883077}, {-0.47444380657503515, \
1.653768235803273}, {-0.0894977358129174, 2.0946793219544757}, 
    {-0.13146784169200298, 2.021043485921703}, {-0.4986696102342371, \
1.594300566883077}}], 
  Line[{{-0.47444380657503515, 1.653768235803273}, {-0.45440686445302647, \
1.7011229525643672}, {-0.05478464252676767, 2.1530633066599703}, 
    {-0.0894977358129174, 2.0946793219544757}, {-0.47444380657503515, \
1.653768235803273}}], 
  Line[{{-0.45440686445302647, 1.7011229525643672}, {-0.4394344943868581, \
1.735513991245673}, {-0.02884569058206097, 2.1953185530328256}, 
    {-0.05478464252676767, 2.1530633066599703}, {-0.45440686445302647, \
1.7011229525643672}}], 
  Line[{{-0.4394344943868581, 1.735513991245673}, {-0.4301810607938247, \
1.7563683493937294}, {-0.012814536647682125, 2.2208803408437956}, 
    {-0.02884569058206097, 2.1953185530328256}, {-0.4394344943868581, \
1.735513991245673}}], 
  Line[{{-0.4301810607938247, 1.7563683493937294}, {-0.42705098312484224, \
1.7633557568774194}, {-0.007391819076574713, 2.2294344764321825}, 
    {-0.012814536647682125, 2.2208803408437956}, {-0.4301810607938247, \
1.7563683493937294}}], 
  Line[{{-0.42705098312484224, 1.7633557568774194}, {-0.43018106079382457, \
1.7563683493937297}, {-0.012814536647682062, 2.2208803408437956}, 
    {-0.007391819076574713, 2.2294344764321825}, {-0.42705098312484224, \
1.7633557568774194}}], 
  Line[{{-0.43018106079382457, 1.7563683493937297}, {-0.4394344943868581, \
1.7355139912456732}, {-0.02884569058206095, 2.195318553032826}, 
    {-0.012814536647682062, 2.2208803408437956}, {-0.43018106079382457, \
1.7563683493937297}}], 
  Line[{{-0.4394344943868581, 1.7355139912456732}, {-0.45440686445302636, \
1.7011229525643672}, {-0.0547846425267676, 2.1530633066599703}, 
    {-0.02884569058206095, 2.195318553032826}, {-0.4394344943868581, \
1.7355139912456732}}], 
  Line[{{-0.45440686445302636, 1.7011229525643672}, {-0.47444380657503504, \
1.6537682358032735}, {-0.08949773581291712, 2.094679321954476}, 
    {-0.0547846425267676, 2.1530633066599703}, {-0.45440686445302636, \
1.7011229525643672}}], 
  Line[{{-0.47444380657503504, 1.6537682358032735}, {-0.4986696102342368, \
1.5943005668830776}, {-0.13146784169200265, 2.0210434859217035}, 
    {-0.08949773581291712, 2.094679321954476}, {-0.47444380657503504, \
1.6537682358032735}}], 
  Line[{{-0.4986696102342368, 1.5943005668830776}, {-0.526025491562421, \
1.5239001577085334}, {-0.17886066514219567, 1.9334320944111911}, 
    {-0.13146784169200265, 2.0210434859217035}, {-0.4986696102342368, \
1.5943005668830776}}], 
  Line[{{-0.526025491562421, 1.5239001577085334}, {-0.5553158672774632, \
1.4441489417584885}, {-0.2296049123627241, 1.8336364565828094}, 
    {-0.17886066514219567, 1.9334320944111911}, {-0.526025491562421, \
1.5239001577085334}}], 
  Line[{{-0.5553158672774632, 1.4441489417584885}, {-0.5852606074097999, \
1.3571288512592454}, {-0.2814828162521375, 1.7241122839361496}, 
    {-0.2296049123627241, 1.8336364565828094}, {-0.5553158672774632, \
1.4441489417584885}}], 
  Line[{{-0.5852606074097999, 1.3571288512592454}, {-0.6145509831248421, \
1.265552510424171}, {-0.33222706347266606, 1.6081701375219568}, 
    {-0.2814828162521375, 1.7241122839361496}, {-0.5852606074097999, \
1.3571288512592454}}], 
  Line[{{-0.6145509831248421, 1.265552510424171}, {-0.6419068644530262, \
1.1729281630054873}, {-0.379619886922859, 1.4902097135042394}, 
    {-0.33222706347266606, 1.6081701375219568}, {-0.6145509831248421, \
1.265552510424171}}], 
  Line[{{-0.6419068644530262, 1.1729281630054873}, {-0.6661326681122279, \
1.0837396094369784}, {-0.4215899928019444, 1.3759750672106559}, 
    {-0.379619886922859, 1.4902097135042394}, {-0.6419068644530262, \
1.1729281630054873}}], 
  Line[{{-0.6661326681122279, 1.0837396094369784}, {-0.6861696102342368, \
1.0035621274868156}, {-0.45630308608809433, 1.2727298803122147}, 
    {-0.4215899928019444, 1.3759750672106559}, {-0.6661326681122279, \
1.0837396094369784}}], 
  Line[{{-0.6861696102342368, 1.0035621274868156}, {-0.7011419803004051, \
0.9389137397717197}, {-0.4822420380328009, 1.1890852819516722}, 
    {-0.45630308608809433, 1.2727298803122147}, {-0.6861696102342368, \
1.0035621274868156}}], 
  Line[{{-0.7011419803004051, 0.9389137397717197}, {-0.7103954138934386, \
0.8965062230902949}, {-0.4982731919671798, 1.1340136417284858}, 
    {-0.4822420380328009, 1.1890852819516722}, {-0.7011419803004051, \
0.9389137397717197}}], 
  Line[{{-0.7103954138934386, 0.8965062230902949}, {-0.7135254915624211, \
0.8816778784387097}, {-0.5036959095382874, 1.1147172382160913}, 
    {-0.4982731919671798, 1.1340136417284858}, {-0.7103954138934386, \
0.8965062230902949}}], 
  Line[{{-0.7135254915624211, 0.8816778784387097}, {-0.7103954138934387, \
0.8965062230902945}, {-0.49827319196717995, 1.1340136417284854}, 
    {-0.5036959095382874, 1.1147172382160913}, {-0.7135254915624211, \
0.8816778784387097}}], 
  Line[{{-0.7103954138934387, 0.8965062230902945}, {-0.7011419803004053, \
0.938913739771719}, {-0.48224203803280125, 1.1890852819516713}, 
    {-0.49827319196717995, 1.1340136417284854}, {-0.7103954138934387, \
0.8965062230902945}}], 
  Line[{{-0.7011419803004053, 0.938913739771719}, {-0.686169610234237, \
1.0035621274868152}, {-0.4563030860880944, 1.2727298803122145}, 
    {-0.48224203803280125, 1.1890852819516713}, {-0.7011419803004053, \
0.938913739771719}}], 
  Line[{{-0.686169610234237, 1.0035621274868152}, {-0.6661326681122283, \
1.0837396094369776}, {-0.42158999280194487, 1.3759750672106545}, 
    {-0.4563030860880944, 1.2727298803122145}, {-0.686169610234237, \
1.0035621274868152}}], 
  Line[{{-0.6661326681122283, 1.0837396094369776}, {-0.6419068644530266, \
1.172928163005486}, {-0.3796198869228595, 1.490209713504238}, 
    {-0.42158999280194487, 1.3759750672106545}, {-0.6661326681122283, \
1.0837396094369776}}], 
  Line[{{-0.6419068644530266, 1.172928163005486}, {-0.6145509831248424, \
1.2655525104241703}, {-0.3322270634726664, 1.6081701375219564}, 
    {-0.3796198869228595, 1.490209713504238}, {-0.6419068644530266, \
1.172928163005486}}], 
  Line[{{-0.6145509831248424, 1.2655525104241703}, {-0.5852606074098001, \
1.357128851259245}, {-0.28148281625213795, 1.7241122839361487}, 
    {-0.3322270634726664, 1.6081701375219564}, {-0.6145509831248424, \
1.2655525104241703}}], 
  Line[{{-0.5852606074098001, 1.357128851259245}, {-0.5553158672774636, \
1.4441489417584874}, {-0.22960491236272482, 1.833636456582808}, 
    {-0.28148281625213795, 1.7241122839361487}, {-0.5852606074098001, \
1.357128851259245}}], 
  Line[{{-0.5553158672774636, 1.4441489417584874}, {-0.5260254915624211, \
1.5239001577085332}, {-0.17886066514219578, 1.933432094411191}, 
    {-0.22960491236272482, 1.833636456582808}, {-0.5553158672774636, \
1.4441489417584874}}], 
  Line[{{-0.5260254915624211, 1.5239001577085332}, {-0.49866961023423706, \
1.594300566883077}, {-0.13146784169200307, 2.021043485921703}, 
    {-0.17886066514219578, 1.933432094411191}, {-0.5260254915624211, \
1.5239001577085332}}], 
  Line[{{-0.49866961023423706, 1.594300566883077}, {-0.4744438065750353, \
1.6537682358032726}, {-0.0894977358129177, 2.0946793219544753}, 
    {-0.13146784169200307, 2.021043485921703}, {-0.49866961023423706, \
1.594300566883077}}], 
  Line[{{-0.4744438065750353, 1.6537682358032726}, {-0.4544068644530264, \
1.7011229525643672}, {-0.054784642526767645, 2.1530633066599703}, 
    {-0.0894977358129177, 2.0946793219544753}, {-0.4744438065750353, \
1.6537682358032726}}], 
  Line[{{-0.4544068644530264, 1.7011229525643672}, {-0.4394344943868581, \
1.735513991245673}, {-0.02884569058206095, 2.1953185530328256}, 
    {-0.054784642526767645, 2.1530633066599703}, {-0.4544068644530264, \
1.7011229525643672}}], 
  Line[{{-0.4394344943868581, 1.735513991245673}, {-0.4301810607938246, \
1.7563683493937294}, {-0.012814536647682086, 2.2208803408437956}, 
    {-0.02884569058206095, 2.1953185530328256}, {-0.4394344943868581, \
1.735513991245673}}], 
  Line[{{-0.4301810607938246, 1.7563683493937294}, {-0.42705098312484224, \
1.7633557568774194}, {-0.007391819076574713, 2.2294344764321825}, 
    {-0.012814536647682086, 2.2208803408437956}, {-0.4301810607938246, \
1.7563683493937294}}], 
  Line[{{-0.007391819076574713, 2.2294344764321825}, {-0.012814536647682145, \
2.2208803408437956}, {0.4918053502751766, 2.588583579753018}, 
    {0.49999999999999967, 2.5980762113533156}, {-0.007391819076574713, \
2.2294344764321825}}], 
  Line[{{-0.012814536647682145, 2.2208803408437956}, {-0.028845690582060914, \
2.195318553032826}, {0.4675795466159753, 2.5601613609103286}, 
    {0.4918053502751766, 2.588583579753018}, {-0.012814536647682145, \
2.2208803408437956}}], 
  Line[{{-0.028845690582060914, 2.195318553032826}, {-0.05478464252676769, \
2.1530633066599703}, {0.42838137289060485, 2.512998012254406}, 
    {0.4675795466159753, 2.5601613609103286}, {-0.028845690582060914, \
2.195318553032826}}], 
  Line[{{-0.05478464252676769, 2.1530633066599703}, {-0.08949773581291746, \
2.0946793219544757}, {0.3759239773845714, 2.4474780907945557}, 
    {0.42838137289060485, 2.512998012254406}, {-0.05478464252676769, \
2.1530633066599703}}], 
  Line[{{-0.08949773581291746, 2.0946793219544757}, {-0.1314678416920028, \
2.0210434859217035}, {0.31249999999999983, 2.364285039922217}, 
    {0.3759239773845714, 2.4474780907945557}, {-0.08949773581291746, \
2.0946793219544757}}], 
  Line[{{-0.1314678416920028, 2.0210434859217035}, {-0.17886066514219576, \
1.933432094411191}, {0.24088137289060504, 2.2645409632922457}, 
    {0.31249999999999983, 2.364285039922217}, {-0.1314678416920028, \
2.0210434859217035}}], 
  Line[{{-0.17886066514219576, 1.933432094411191}, {-0.2296049123627243, \
1.833636456582809}, {0.16419817372536988, 2.1499828315181597}, 
    {0.24088137289060504, 2.2645409632922457}, {-0.17886066514219576, \
1.933432094411191}}], 
  Line[{{-0.2296049123627243, 1.833636456582809}, {-0.28148281625213767, \
1.7241122839361493}, {0.08580182627462962, 2.0231783980979894}, 
    {0.16419817372536988, 2.1499828315181597}, {-0.2296049123627243, \
1.833636456582809}}], 
  Line[{{-0.28148281625213767, 1.7241122839361493}, {-0.3322270634726663, \
1.6081701375219566}, {0.009118627109394484, 1.8877889819588953}, 
    {0.08580182627462962, 2.0231783980979894}, {-0.28148281625213767, \
1.7241122839361493}}], 
  Line[{{-0.3322270634726663, 1.6081701375219566}, {-0.3796198869228592, \
1.490209713504239}, {-0.06250000000000011, 1.7488835724541527}, 
    {0.009118627109394484, 1.8877889819588953}, {-0.3322270634726663, \
1.6081701375219566}}], 
  Line[{{-0.3796198869228592, 1.490209713504239}, {-0.4215899928019446, \
1.3759750672106554}, {-0.125923977384572, 1.6132809148526015}, 
    {-0.06250000000000011, 1.7488835724541527}, {-0.3796198869228592, \
1.490209713504239}}], 
  Line[{{-0.4215899928019446, 1.3759750672106554}, {-0.45630308608809433, \
1.2727298803122147}, {-0.17838137289060557, 1.4898021598760776}, 
    {-0.125923977384572, 1.6132809148526015}, {-0.4215899928019446, \
1.3759750672106554}}], 
  Line[{{-0.45630308608809433, 1.2727298803122147}, {-0.482242038032801, \
1.189085281951672}, {-0.21757954661597556, 1.389101261457407}, 
    {-0.17838137289060557, 1.4898021598760776}, {-0.45630308608809433, \
1.2727298803122147}}], 
  Line[{{-0.482242038032801, 1.189085281951672}, {-0.4982731919671799, \
1.1340136417284856}, {-0.2418053502751773, 1.3224570770546993}, 
    {-0.21757954661597556, 1.389101261457407}, {-0.482242038032801, \
1.189085281951672}}], 
  Line[{{-0.4982731919671799, 1.1340136417284856}, {-0.5036959095382874, \
1.1147172382160913}, {-0.2500000000000002, 1.299038105676658}, 
    {-0.2418053502751773, 1.3224570770546993}, {-0.4982731919671799, \
1.1340136417284856}}], 
  Line[{{-0.5036959095382874, 1.1147172382160913}, {-0.49827319196717995, \
1.1340136417284856}, {-0.2418053502751773, 1.3224570770546993}, 
    {-0.2500000000000002, 1.299038105676658}, {-0.5036959095382874, \
1.1147172382160913}}], 
  Line[{{-0.49827319196717995, 1.1340136417284856}, {-0.482242038032801, \
1.1890852819516717}, {-0.21757954661597556, 1.3891012614574068}, 
    {-0.2418053502751773, 1.3224570770546993}, {-0.49827319196717995, \
1.1340136417284856}}], 
  Line[{{-0.482242038032801, 1.1890852819516717}, {-0.4563030860880944, \
1.2727298803122145}, {-0.17838137289060557, 1.4898021598760776}, 
    {-0.21757954661597556, 1.3891012614574068}, {-0.482242038032801, \
1.1890852819516717}}], 
  Line[{{-0.4563030860880944, 1.2727298803122145}, {-0.42158999280194476, \
1.375975067210655}, {-0.12592397738457223, 1.6132809148526013}, 
    {-0.17838137289060557, 1.4898021598760776}, {-0.4563030860880944, \
1.2727298803122145}}], 
  Line[{{-0.42158999280194476, 1.375975067210655}, {-0.3796198869228593, \
1.4902097135042385}, {-0.06250000000000044, 1.7488835724541523}, 
    {-0.12592397738457223, 1.6132809148526013}, {-0.42158999280194476, \
1.375975067210655}}], 
  Line[{{-0.3796198869228593, 1.4902097135042385}, {-0.3322270634726663, \
1.6081701375219564}, {0.009118627109394317, 1.887788981958895}, 
    {-0.06250000000000044, 1.7488835724541523}, {-0.3796198869228593, \
1.4902097135042385}}], 
  Line[{{-0.3322270634726663, 1.6081701375219564}, {-0.2814828162521379, \
1.724112283936149}, {0.08580182627462934, 2.023178398097989}, 
    {0.009118627109394317, 1.887788981958895}, {-0.3322270634726663, \
1.6081701375219564}}], 
  Line[{{-0.2814828162521379, 1.724112283936149}, {-0.22960491236272457, \
1.8336364565828085}, {0.1641981737253695, 2.1499828315181593}, 
    {0.08580182627462934, 2.023178398097989}, {-0.2814828162521379, \
1.724112283936149}}], 
  Line[{{-0.22960491236272457, 1.8336364565828085}, {-0.1788606651421958, \
1.933432094411191}, {0.2408813728906049, 2.264540963292246}, 
    {0.1641981737253695, 2.1499828315181593}, {-0.22960491236272457, \
1.8336364565828085}}], 
  Line[{{-0.1788606651421958, 1.933432094411191}, {-0.13146784169200298, \
2.021043485921703}, {0.31249999999999944, 2.3642850399222164}, 
    {0.2408813728906049, 2.264540963292246}, {-0.1788606651421958, \
1.933432094411191}}], 
  Line[{{-0.13146784169200298, 2.021043485921703}, {-0.0894977358129174, \
2.0946793219544757}, {0.3759239773845713, 2.447478090794556}, 
    {0.31249999999999944, 2.3642850399222164}, {-0.13146784169200298, \
2.021043485921703}}], 
  Line[{{-0.0894977358129174, 2.0946793219544757}, {-0.05478464252676767, \
2.1530633066599703}, {0.42838137289060485, 2.512998012254406}, 
    {0.3759239773845713, 2.447478090794556}, {-0.0894977358129174, \
2.0946793219544757}}], 
  Line[{{-0.05478464252676767, 2.1530633066599703}, {-0.02884569058206097, \
2.1953185530328256}, {0.46757954661597495, 2.560161360910328}, 
    {0.42838137289060485, 2.512998012254406}, {-0.05478464252676767, \
2.1530633066599703}}], 
  Line[{{-0.02884569058206097, 2.1953185530328256}, {-0.012814536647682125, \
2.2208803408437956}, {0.49180535027517663, 2.588583579753018}, 
    {0.46757954661597495, 2.560161360910328}, {-0.02884569058206097, \
2.1953185530328256}}], 
  Line[{{-0.012814536647682125, 2.2208803408437956}, {-0.007391819076574713, \
2.2294344764321825}, {0.49999999999999967, 2.5980762113533156}, 
    {0.49180535027517663, 2.588583579753018}, {-0.012814536647682125, \
2.2208803408437956}}], 
  Line[{{-0.007391819076574713, 2.2294344764321825}, {-0.012814536647682062, \
2.2208803408437956}, {0.49180535027517697, 2.588583579753018}, 
    {0.49999999999999967, 2.5980762113533156}, {-0.007391819076574713, \
2.2294344764321825}}], 
  Line[{{-0.012814536647682062, 2.2208803408437956}, {-0.02884569058206095, \
2.195318553032826}, {0.46757954661597523, 2.5601613609103286}, 
    {0.49180535027517697, 2.588583579753018}, {-0.012814536647682062, \
2.2208803408437956}}], 
  Line[{{-0.02884569058206095, 2.195318553032826}, {-0.0547846425267676, \
2.1530633066599703}, {0.428381372890605, 2.512998012254406}, 
    {0.46757954661597523, 2.5601613609103286}, {-0.02884569058206095, \
2.195318553032826}}], 
  Line[{{-0.0547846425267676, 2.1530633066599703}, {-0.08949773581291712, \
2.094679321954476}, {0.3759239773845719, 2.4474780907945566}, 
    {0.428381372890605, 2.512998012254406}, {-0.0547846425267676, \
2.1530633066599703}}], 
  Line[{{-0.08949773581291712, 2.094679321954476}, {-0.13146784169200265, \
2.0210434859217035}, {0.31249999999999994, 2.3642850399222173}, 
    {0.3759239773845719, 2.4474780907945566}, {-0.08949773581291712, \
2.094679321954476}}], 
  Line[{{-0.13146784169200265, 2.0210434859217035}, {-0.17886066514219567, \
1.9334320944111911}, {0.2408813728906052, 2.264540963292246}, 
    {0.31249999999999994, 2.3642850399222173}, {-0.13146784169200265, \
2.0210434859217035}}], 
  Line[{{-0.17886066514219567, 1.9334320944111911}, {-0.2296049123627241, \
1.8336364565828094}, {0.16419817372537018, 2.14998283151816}, 
    {0.2408813728906052, 2.264540963292246}, {-0.17886066514219567, \
1.9334320944111911}}], 
  Line[{{-0.2296049123627241, 1.8336364565828094}, {-0.2814828162521375, \
1.7241122839361496}, {0.0858018262746299, 2.02317839809799}, 
    {0.16419817372537018, 2.14998283151816}, {-0.2296049123627241, \
1.8336364565828094}}], 
  Line[{{-0.2814828162521375, 1.7241122839361496}, {-0.33222706347266606, \
1.6081701375219568}, {0.009118627109394595, 1.8877889819588956}, 
    {0.0858018262746299, 2.02317839809799}, {-0.2814828162521375, \
1.7241122839361496}}], 
  Line[{{-0.33222706347266606, 1.6081701375219568}, {-0.379619886922859, \
1.4902097135042394}, {-0.062499999999999944, 1.7488835724541534}, 
    {0.009118627109394595, 1.8877889819588956}, {-0.33222706347266606, \
1.6081701375219568}}], 
  Line[{{-0.379619886922859, 1.4902097135042394}, {-0.4215899928019444, \
1.3759750672106559}, {-0.12592397738457173, 1.6132809148526024}, 
    {-0.062499999999999944, 1.7488835724541534}, {-0.379619886922859, \
1.4902097135042394}}], 
  Line[{{-0.4215899928019444, 1.3759750672106559}, {-0.45630308608809433, \
1.2727298803122147}, {-0.17838137289060546, 1.4898021598760776}, 
    {-0.12592397738457173, 1.6132809148526024}, {-0.4215899928019444, \
1.3759750672106559}}], 
  Line[{{-0.45630308608809433, 1.2727298803122147}, {-0.4822420380328009, \
1.1890852819516722}, {-0.21757954661597534, 1.3891012614574072}, 
    {-0.17838137289060546, 1.4898021598760776}, {-0.45630308608809433, \
1.2727298803122147}}], 
  Line[{{-0.4822420380328009, 1.1890852819516722}, {-0.4982731919671798, \
1.1340136417284858}, {-0.2418053502751772, 1.3224570770546997}, 
    {-0.21757954661597534, 1.3891012614574072}, {-0.4822420380328009, \
1.1890852819516722}}], 
  Line[{{-0.4982731919671798, 1.1340136417284858}, {-0.5036959095382874, \
1.1147172382160913}, {-0.2500000000000002, 1.299038105676658}, 
    {-0.2418053502751772, 1.3224570770546997}, {-0.4982731919671798, \
1.1340136417284858}}], 
  Line[{{-0.5036959095382874, 1.1147172382160913}, {-0.49827319196717995, \
1.1340136417284854}, {-0.2418053502751774, 1.322457077054699}, 
    {-0.2500000000000002, 1.299038105676658}, {-0.5036959095382874, \
1.1147172382160913}}], 
  Line[{{-0.49827319196717995, 1.1340136417284854}, {-0.48224203803280125, \
1.1890852819516713}, {-0.21757954661597584, 1.389101261457406}, 
    {-0.2418053502751774, 1.322457077054699}, {-0.49827319196717995, \
1.1340136417284854}}], 
  Line[{{-0.48224203803280125, 1.1890852819516713}, {-0.4563030860880944, \
1.2727298803122145}, {-0.17838137289060568, 1.4898021598760773}, 
    {-0.21757954661597584, 1.389101261457406}, {-0.48224203803280125, \
1.1890852819516713}}], 
  Line[{{-0.4563030860880944, 1.2727298803122145}, {-0.42158999280194487, \
1.3759750672106545}, {-0.12592397738457234, 1.6132809148526008}, 
    {-0.17838137289060568, 1.4898021598760773}, {-0.4563030860880944, \
1.2727298803122145}}], 
  Line[{{-0.42158999280194487, 1.3759750672106545}, {-0.3796198869228595, \
1.490209713504238}, {-0.06250000000000078, 1.7488835724541516}, 
    {-0.12592397738457234, 1.6132809148526008}, {-0.42158999280194487, \
1.3759750672106545}}], 
  Line[{{-0.3796198869228595, 1.490209713504238}, {-0.3322270634726664, \
1.6081701375219564}, {0.009118627109394317, 1.8877889819588949}, 
    {-0.06250000000000078, 1.7488835724541516}, {-0.3796198869228595, \
1.490209713504238}}], 
  Line[{{-0.3322270634726664, 1.6081701375219564}, {-0.28148281625213795, \
1.7241122839361487}, {0.08580182627462918, 2.0231783980979885}, 
    {0.009118627109394317, 1.8877889819588949}, {-0.3322270634726664, \
1.6081701375219564}}], 
  Line[{{-0.28148281625213795, 1.7241122839361487}, {-0.22960491236272482, \
1.833636456582808}, {0.1641981737253691, 2.149982831518159}, 
    {0.08580182627462918, 2.0231783980979885}, {-0.28148281625213795, \
1.7241122839361487}}], 
  Line[{{-0.22960491236272482, 1.833636456582808}, {-0.17886066514219578, \
1.933432094411191}, {0.24088137289060496, 2.264540963292246}, 
    {0.1641981737253691, 2.149982831518159}, {-0.22960491236272482, \
1.833636456582808}}], 
  Line[{{-0.17886066514219578, 1.933432094411191}, {-0.13146784169200307, \
2.021043485921703}, {0.31249999999999944, 2.3642850399222164}, 
    {0.24088137289060496, 2.264540963292246}, {-0.17886066514219578, \
1.933432094411191}}], 
  Line[{{-0.13146784169200307, 2.021043485921703}, {-0.0894977358129177, \
2.0946793219544753}, {0.375923977384571, 2.4474780907945557}, 
    {0.31249999999999944, 2.3642850399222164}, {-0.13146784169200307, \
2.021043485921703}}], 
  Line[{{-0.0894977358129177, 2.0946793219544753}, {-0.054784642526767645, \
2.1530633066599703}, {0.4283813728906049, 2.512998012254406}, 
    {0.375923977384571, 2.4474780907945557}, {-0.0894977358129177, \
2.0946793219544753}}], 
  Line[{{-0.054784642526767645, 2.1530633066599703}, {-0.02884569058206095, \
2.1953185530328256}, {0.46757954661597495, 2.560161360910328}, 
    {0.4283813728906049, 2.512998012254406}, {-0.054784642526767645, \
2.1530633066599703}}], 
  Line[{{-0.02884569058206095, 2.1953185530328256}, {-0.012814536647682086, \
2.2208803408437956}, {0.4918053502751767, 2.588583579753018}, 
    {0.46757954661597495, 2.560161360910328}, {-0.02884569058206095, \
2.1953185530328256}}], 
  Line[{{-0.012814536647682086, 2.2208803408437956}, {-0.007391819076574713, \
2.2294344764321825}, {0.49999999999999967, 2.5980762113533156}, 
    {0.4918053502751767, 2.588583579753018}, {-0.012814536647682086, \
2.2208803408437956}}], 
  Line[{{0.49999999999999967, 2.5980762113533156}, {0.4918053502751766, \
2.588583579753018}, {1.0616242894813523, 2.8434972909653364}, 
    {1.0729490168751576, 2.8531695488854605}, {0.49999999999999967, \
2.5980762113533156}}], 
  Line[{{0.4918053502751766, 2.588583579753018}, {0.4675795466159753, \
2.5601613609103286}, {1.0281450522291173, 2.8144424077524013}, 
    {1.0616242894813523, 2.8434972909653364}, {0.4918053502751766, \
2.588583579753018}}], 
  Line[{{0.4675795466159753, 2.5601613609103286}, {0.42838137289060485, \
2.512998012254406}, {0.9739745084375786, 2.7659262761959793}, 
    {1.0281450522291173, 2.8144424077524013}, {0.4675795466159753, \
2.5601613609103286}}], 
  Line[{{0.42838137289060485, 2.512998012254406}, {0.3759239773845714, \
2.4474780907945557}, {0.9014801708095362, 2.697933958917173}, 
    {0.9739745084375786, 2.7659262761959793}, {0.42838137289060485, \
2.512998012254406}}], 
  Line[{{0.3759239773845714, 2.4474780907945557}, {0.31249999999999983, \
2.364285039922217}, {0.813830389765763, 2.6106791787633683}, 
    {0.9014801708095362, 2.697933958917173}, {0.3759239773845714, \
2.4474780907945557}}], 
  Line[{{0.31249999999999983, 2.364285039922217}, {0.24088137289060504, \
2.2645409632922457}, {0.714855881328184, 2.504820390287959}, 
    {0.813830389765763, 2.6106791787633683}, {0.31249999999999983, \
2.364285039922217}}], 
  Line[{{0.24088137289060504, 2.2645409632922457}, {0.16419817372536988, \
2.1499828315181597}, {0.6088823064479068, 2.381720267244781}, 
    {0.714855881328184, 2.504820390287959}, {0.24088137289060504, \
2.2645409632922457}}], 
  Line[{{0.16419817372536988, 2.1499828315181597}, {0.08580182627462962, \
2.0231783980979894}, {0.5005412188648298, 2.2437468595288657}, 
    {0.6088823064479068, 2.381720267244781}, {0.16419817372536988, \
2.1499828315181597}}], 
  Line[{{0.08580182627462962, 2.0231783980979894}, {0.009118627109394484, \
1.8877889819588953}, {0.39456764398455235, 2.0946223601372336}, 
    {0.5005412188648298, 2.2437468595288657}, {0.08580182627462962, \
2.0231783980979894}}], 
  Line[{{0.009118627109394484, 1.8877889819588953}, {-0.06250000000000011, \
1.7488835724541527}, {0.2955931355469736, 1.9398272078772507}, 
    {0.39456764398455235, 2.0946223601372336}, {0.009118627109394484, \
1.8877889819588953}}], 
  Line[{{-0.06250000000000011, 1.7488835724541527}, {-0.125923977384572, \
1.6132809148526015}, {0.20794335450320006, 1.7870411277345812}, 
    {0.2955931355469736, 1.9398272078772507}, {-0.06250000000000011, \
1.7488835724541527}}], 
  Line[{{-0.125923977384572, 1.6132809148526015}, {-0.17838137289060557, \
1.4898021598760776}, {0.13544901687515765, 1.6464961680271788}, 
    {0.20794335450320006, 1.7870411277345812}, {-0.125923977384572, \
1.6132809148526015}}], 
  Line[{{-0.17838137289060557, 1.4898021598760776}, {-0.21757954661597556, \
1.389101261457407}, {0.08127847308361946, 1.5308481540548229}, 
    {0.13544901687515765, 1.6464961680271788}, {-0.17838137289060557, \
1.4898021598760776}}], 
  Line[{{-0.21757954661597556, 1.389101261457407}, {-0.2418053502751773, \
1.3224570770546993}, {0.047799235831384124, 1.4537753723488893}, 
    {0.08127847308361946, 1.5308481540548229}, {-0.21757954661597556, \
1.389101261457407}}], 
  Line[{{-0.2418053502751773, 1.3224570770546993}, {-0.2500000000000002, \
1.299038105676658}, {0.03647450843757882, 1.4265847744427302}, 
    {0.047799235831384124, 1.4537753723488893}, {-0.2418053502751773, \
1.3224570770546993}}], 
  Line[{{-0.2500000000000002, 1.299038105676658}, {-0.2418053502751773, \
1.3224570770546993}, {0.047799235831384124, 1.453775372348889}, 
    {0.03647450843757882, 1.4265847744427302}, {-0.2500000000000002, \
1.299038105676658}}], 
  Line[{{-0.2418053502751773, 1.3224570770546993}, {-0.21757954661597556, \
1.3891012614574068}, {0.08127847308361935, 1.5308481540548224}, 
    {0.047799235831384124, 1.453775372348889}, {-0.2418053502751773, \
1.3224570770546993}}], 
  Line[{{-0.21757954661597556, 1.3891012614574068}, {-0.17838137289060557, \
1.4898021598760776}, {0.13544901687515776, 1.6464961680271788}, 
    {0.08127847308361935, 1.5308481540548224}, {-0.21757954661597556, \
1.3891012614574068}}], 
  Line[{{-0.17838137289060557, 1.4898021598760776}, {-0.12592397738457223, \
1.6132809148526013}, {0.20794335450319978, 1.7870411277345808}, 
    {0.13544901687515776, 1.6464961680271788}, {-0.17838137289060557, \
1.4898021598760776}}], 
  Line[{{-0.12592397738457223, 1.6132809148526013}, {-0.06250000000000044, \
1.7488835724541523}, {0.29559313554697325, 1.9398272078772505}, 
    {0.20794335450319978, 1.7870411277345808}, {-0.12592397738457223, \
1.6132809148526013}}], 
  Line[{{-0.06250000000000044, 1.7488835724541523}, {0.009118627109394317, \
1.887788981958895}, {0.39456764398455224, 2.094622360137233}, 
    {0.29559313554697325, 1.9398272078772505}, {-0.06250000000000044, \
1.7488835724541523}}], 
  Line[{{0.009118627109394317, 1.887788981958895}, {0.08580182627462934, \
2.023178398097989}, {0.5005412188648295, 2.243746859528865}, 
    {0.39456764398455224, 2.094622360137233}, {0.009118627109394317, \
1.887788981958895}}], 
  Line[{{0.08580182627462934, 2.023178398097989}, {0.1641981737253695, \
2.1499828315181593}, {0.6088823064479062, 2.3817202672447806}, 
    {0.5005412188648295, 2.243746859528865}, {0.08580182627462934, \
2.023178398097989}}], 
  Line[{{0.1641981737253695, 2.1499828315181593}, {0.2408813728906049, \
2.264540963292246}, {0.7148558813281839, 2.504820390287959}, 
    {0.6088823064479062, 2.3817202672447806}, {0.1641981737253695, \
2.1499828315181593}}], 
  Line[{{0.2408813728906049, 2.264540963292246}, {0.31249999999999944, \
2.3642850399222164}, {0.8138303897657626, 2.610679178763368}, 
    {0.7148558813281839, 2.504820390287959}, {0.2408813728906049, \
2.264540963292246}}], 
  Line[{{0.31249999999999944, 2.3642850399222164}, {0.3759239773845713, \
2.447478090794556}, {0.9014801708095362, 2.697933958917173}, 
    {0.8138303897657626, 2.610679178763368}, {0.31249999999999944, \
2.3642850399222164}}], 
  Line[{{0.3759239773845713, 2.447478090794556}, {0.42838137289060485, \
2.512998012254406}, {0.9739745084375787, 2.765926276195979}, 
    {0.9014801708095362, 2.697933958917173}, {0.3759239773845713, \
2.447478090794556}}], 
  Line[{{0.42838137289060485, 2.512998012254406}, {0.46757954661597495, \
2.560161360910328}, {1.0281450522291171, 2.8144424077524013}, 
    {0.9739745084375787, 2.765926276195979}, {0.42838137289060485, \
2.512998012254406}}], 
  Line[{{0.46757954661597495, 2.560161360910328}, {0.49180535027517663, \
2.588583579753018}, {1.0616242894813523, 2.8434972909653364}, 
    {1.0281450522291171, 2.8144424077524013}, {0.46757954661597495, \
2.560161360910328}}], 
  Line[{{0.49180535027517663, 2.588583579753018}, {0.49999999999999967, \
2.5980762113533156}, {1.0729490168751576, 2.8531695488854605}, 
    {1.0616242894813523, 2.8434972909653364}, {0.49180535027517663, \
2.588583579753018}}], 
  Line[{{0.49999999999999967, 2.5980762113533156}, {0.49180535027517697, \
2.588583579753018}, {1.0616242894813526, 2.843497290965337}, 
    {1.0729490168751576, 2.8531695488854605}, {0.49999999999999967, \
2.5980762113533156}}], 
  Line[{{0.49180535027517697, 2.588583579753018}, {0.46757954661597523, \
2.5601613609103286}, {1.0281450522291173, 2.8144424077524013}, 
    {1.0616242894813526, 2.843497290965337}, {0.49180535027517697, \
2.588583579753018}}], 
  Line[{{0.46757954661597523, 2.5601613609103286}, {0.428381372890605, \
2.512998012254406}, {0.973974508437579, 2.7659262761959793}, 
    {1.0281450522291173, 2.8144424077524013}, {0.46757954661597523, \
2.5601613609103286}}], 
  Line[{{0.428381372890605, 2.512998012254406}, {0.3759239773845719, \
2.4474780907945566}, {0.901480170809537, 2.6979339589171736}, 
    {0.973974508437579, 2.7659262761959793}, {0.428381372890605, \
2.512998012254406}}], 
  Line[{{0.3759239773845719, 2.4474780907945566}, {0.31249999999999994, \
2.3642850399222173}, {0.8138303897657633, 2.6106791787633687}, 
    {0.901480170809537, 2.6979339589171736}, {0.3759239773845719, \
2.4474780907945566}}], 
  Line[{{0.31249999999999994, 2.3642850399222173}, {0.2408813728906052, \
2.264540963292246}, {0.7148558813281845, 2.504820390287959}, 
    {0.8138303897657633, 2.6106791787633687}, {0.31249999999999994, \
2.3642850399222173}}], 
  Line[{{0.2408813728906052, 2.264540963292246}, {0.16419817372537018, \
2.14998283151816}, {0.6088823064479071, 2.3817202672447815}, 
    {0.7148558813281845, 2.504820390287959}, {0.2408813728906052, \
2.264540963292246}}], 
  Line[{{0.16419817372537018, 2.14998283151816}, {0.0858018262746299, \
2.02317839809799}, {0.5005412188648302, 2.243746859528866}, 
    {0.6088823064479071, 2.3817202672447815}, {0.16419817372537018, \
2.14998283151816}}], 
  Line[{{0.0858018262746299, 2.02317839809799}, {0.009118627109394595, \
1.8877889819588956}, {0.3945676439845526, 2.0946223601372336}, 
    {0.5005412188648302, 2.243746859528866}, {0.0858018262746299, \
2.02317839809799}}], 
  Line[{{0.009118627109394595, 1.8877889819588956}, {-0.062499999999999944, \
1.7488835724541534}, {0.295593135546974, 1.9398272078772514}, 
    {0.3945676439845526, 2.0946223601372336}, {0.009118627109394595, \
1.8877889819588956}}], 
  Line[{{-0.062499999999999944, 1.7488835724541534}, {-0.12592397738457173, \
1.6132809148526024}, {0.20794335450320034, 1.7870411277345821}, 
    {0.295593135546974, 1.9398272078772514}, {-0.062499999999999944, \
1.7488835724541534}}], 
  Line[{{-0.12592397738457173, 1.6132809148526024}, {-0.17838137289060546, \
1.4898021598760776}, {0.13544901687515776, 1.646496168027179}, 
    {0.20794335450320034, 1.7870411277345821}, {-0.12592397738457173, \
1.6132809148526024}}], 
  Line[{{-0.17838137289060546, 1.4898021598760776}, {-0.21757954661597534, \
1.3891012614574072}, {0.08127847308361968, 1.530848154054823}, 
    {0.13544901687515776, 1.646496168027179}, {-0.17838137289060546, \
1.4898021598760776}}], 
  Line[{{-0.21757954661597534, 1.3891012614574072}, {-0.2418053502751772, \
1.3224570770546997}, {0.047799235831384346, 1.4537753723488895}, 
    {0.08127847308361968, 1.530848154054823}, {-0.21757954661597534, \
1.3891012614574072}}], 
  Line[{{-0.2418053502751772, 1.3224570770546997}, {-0.2500000000000002, \
1.299038105676658}, {0.03647450843757882, 1.4265847744427302}, 
    {0.047799235831384346, 1.4537753723488895}, {-0.2418053502751772, \
1.3224570770546997}}], 
  Line[{{-0.2500000000000002, 1.299038105676658}, {-0.2418053502751774, \
1.322457077054699}, {0.04779923583138401, 1.4537753723488889}, 
    {0.03647450843757882, 1.4265847744427302}, {-0.2500000000000002, \
1.299038105676658}}], 
  Line[{{-0.2418053502751774, 1.322457077054699}, {-0.21757954661597584, \
1.389101261457406}, {0.08127847308361902, 1.530848154054822}, 
    {0.04779923583138401, 1.4537753723488889}, {-0.2418053502751774, \
1.322457077054699}}], 
  Line[{{-0.21757954661597584, 1.389101261457406}, {-0.17838137289060568, \
1.4898021598760773}, {0.1354490168751576, 1.6464961680271786}, 
    {0.08127847308361902, 1.530848154054822}, {-0.21757954661597584, \
1.389101261457406}}], 
  Line[{{-0.17838137289060568, 1.4898021598760773}, {-0.12592397738457234, \
1.6132809148526008}, {0.20794335450319956, 1.7870411277345803}, 
    {0.1354490168751576, 1.6464961680271786}, {-0.17838137289060568, \
1.4898021598760773}}], 
  Line[{{-0.12592397738457234, 1.6132809148526008}, {-0.06250000000000078, \
1.7488835724541516}, {0.2955931355469728, 1.9398272078772496}, 
    {0.20794335450319956, 1.7870411277345803}, {-0.12592397738457234, \
1.6132809148526008}}], 
  Line[{{-0.06250000000000078, 1.7488835724541516}, {0.009118627109394317, \
1.8877889819588949}, {0.39456764398455213, 2.0946223601372327}, 
    {0.2955931355469728, 1.9398272078772496}, {-0.06250000000000078, \
1.7488835724541516}}], 
  Line[{{0.009118627109394317, 1.8877889819588949}, {0.08580182627462918, \
2.0231783980979885}, {0.5005412188648293, 2.2437468595288648}, 
    {0.39456764398455213, 2.0946223601372327}, {0.009118627109394317, \
1.8877889819588949}}], 
  Line[{{0.08580182627462918, 2.0231783980979885}, {0.1641981737253691, \
2.149982831518159}, {0.6088823064479056, 2.38172026724478}, 
    {0.5005412188648293, 2.2437468595288648}, {0.08580182627462918, \
2.0231783980979885}}], 
  Line[{{0.1641981737253691, 2.149982831518159}, {0.24088137289060496, \
2.264540963292246}, {0.714855881328184, 2.504820390287959}, 
    {0.6088823064479056, 2.38172026724478}, {0.1641981737253691, \
2.149982831518159}}], 
  Line[{{0.24088137289060496, 2.264540963292246}, {0.31249999999999944, \
2.3642850399222164}, {0.8138303897657625, 2.610679178763368}, 
    {0.714855881328184, 2.504820390287959}, {0.24088137289060496, \
2.264540963292246}}], 
  Line[{{0.31249999999999944, 2.3642850399222164}, {0.375923977384571, \
2.4474780907945557}, {0.9014801708095358, 2.6979339589171727}, 
    {0.8138303897657625, 2.610679178763368}, {0.31249999999999944, \
2.3642850399222164}}], 
  Line[{{0.375923977384571, 2.4474780907945557}, {0.4283813728906049, \
2.512998012254406}, {0.9739745084375787, 2.765926276195979}, 
    {0.9014801708095358, 2.6979339589171727}, {0.375923977384571, \
2.4474780907945557}}], 
  Line[{{0.4283813728906049, 2.512998012254406}, {0.46757954661597495, \
2.560161360910328}, {1.0281450522291171, 2.8144424077524013}, 
    {0.9739745084375787, 2.765926276195979}, {0.4283813728906049, \
2.512998012254406}}], 
  Line[{{0.46757954661597495, 2.560161360910328}, {0.4918053502751767, \
2.588583579753018}, {1.0616242894813523, 2.8434972909653364}, 
    {1.0281450522291171, 2.8144424077524013}, {0.46757954661597495, \
2.560161360910328}}], 
  Line[{{0.4918053502751767, 2.588583579753018}, {0.49999999999999967, \
2.5980762113533156}, {1.0729490168751576, 2.8531695488854605}, 
    {1.0616242894813523, 2.8434972909653364}, {0.4918053502751767, \
2.588583579753018}}], 
  Line[{{1.0729490168751576, 2.8531695488854605}, {1.0616242894813523, \
2.8434972909653364}, {1.6717384590328979, 2.9745950829027943}, 
    {1.6864146101970388, 2.98356568610482}, {1.0729490168751576, \
2.8531695488854605}}], 
  Line[{{1.0616242894813523, 2.8434972909653364}, {1.0281450522291173, \
2.8144424077524013}, {1.6283514237703351, 2.9474883844565616}, 
    {1.6717384590328979, 2.9745950829027943}, {1.0616242894813523, \
2.8434972909653364}}], 
  Line[{{1.0281450522291173, 2.8144424077524013}, {0.9739745084375786, \
2.7659262761959793}, {1.5581497260444177, 2.9017190909782276}, 
    {1.6283514237703351, 2.9474883844565616}, {1.0281450522291173, \
2.8144424077524013}}], 
  Line[{{0.9739745084375786, 2.7659262761959793}, {0.9014801708095362, \
2.697933958917173}, {1.4642015169108888, 2.836596676593442}, 
    {1.5581497260444177, 2.9017190909782276}, {0.9739745084375786, \
2.7659262761959793}}], 
  Line[{{0.9014801708095362, 2.697933958917173}, {0.813830389765763, \
2.6106791787633683}, {1.3506127839224091, 2.751525170659194}, 
    {1.4642015169108888, 2.836596676593442}, {0.9014801708095362, \
2.697933958917173}}], 
  Line[{{0.813830389765763, 2.6106791787633683}, {0.714855881328184, \
2.504820390287959}, {1.2223478997697876, 2.646328981764321}, 
    {1.3506127839224091, 2.751525170659194}, {0.813830389765763, \
2.6106791787633683}}], 
  Line[{{0.714855881328184, 2.504820390287959}, {0.6088823064479068, \
2.381720267244781}, {1.0850126553736965, 2.5216249314090464}, 
    {1.2223478997697876, 2.646328981764321}, {0.714855881328184, \
2.504820390287959}}], 
  Line[{{0.6088823064479068, 2.381720267244781}, {0.5005412188648298, \
2.2437468595288657}, {0.9446092599218617, 2.3792297776658287}, 
    {1.0850126553736965, 2.5216249314090464}, {0.6088823064479068, \
2.381720267244781}}], 
  Line[{{0.5005412188648298, 2.2437468595288657}, {0.39456764398455235, \
2.0946223601372336}, {0.8072740155257703, 2.222607239695348}, 
    {0.9446092599218617, 2.3792297776658287}, {0.5005412188648298, \
2.2437468595288657}}], 
  Line[{{0.39456764398455235, 2.0946223601372336}, {0.2955931355469736, \
1.9398272078772507}, {0.6790091313731493, 2.0573688751735335}, 
    {0.8072740155257703, 2.222607239695348}, {0.39456764398455235, \
2.0946223601372336}}], 
  Line[{{0.2955931355469736, 1.9398272078772507}, {0.20794335450320006, \
1.7870411277345812}, {0.5654203983846692, 1.8918241808350187}, 
    {0.6790091313731493, 2.0573688751735335}, {0.2955931355469736, \
1.9398272078772507}}], 
  Line[{{0.20794335450320006, 1.7870411277345812}, {0.13544901687515765, \
1.6464961680271788}, {0.47147218925114043, 1.7374623647519978}, 
    {0.5654203983846692, 1.8918241808350187}, {0.20794335450320006, \
1.7870411277345812}}], 
  Line[{{0.13544901687515765, 1.6464961680271788}, {0.08127847308361946, \
1.5308481540548229}, {0.40127049152522337, 1.6089224974238359}, 
    {0.47147218925114043, 1.7374623647519978}, {0.13544901687515765, \
1.6464961680271788}}], 
  Line[{{0.08127847308361946, 1.5308481540548229}, {0.047799235831384124, \
1.4537753723488893}, {0.35788345626266027, 1.5224519023538965}, 
    {0.40127049152522337, 1.6089224974238359}, {0.08127847308361946, \
1.5308481540548229}}], 
  Line[{{0.047799235831384124, 1.4537753723488893}, {0.03647450843757882, \
1.4265847744427302}, {0.3432073050985194, 1.49178284305241}, 
    {0.35788345626266027, 1.5224519023538965}, {0.047799235831384124, \
1.4537753723488893}}], 
  Line[{{0.03647450843757882, 1.4265847744427302}, {0.047799235831384124, \
1.453775372348889}, {0.35788345626266027, 1.5224519023538965}, 
    {0.3432073050985194, 1.49178284305241}, {0.03647450843757882, \
1.4265847744427302}}], 
  Line[{{0.047799235831384124, 1.453775372348889}, {0.08127847308361935, \
1.5308481540548224}, {0.40127049152522326, 1.6089224974238354}, 
    {0.35788345626266027, 1.5224519023538965}, {0.047799235831384124, \
1.453775372348889}}], 
  Line[{{0.08127847308361935, 1.5308481540548224}, {0.13544901687515776, \
1.6464961680271788}, {0.4714721892511405, 1.7374623647519976}, 
    {0.40127049152522326, 1.6089224974238354}, {0.08127847308361935, \
1.5308481540548224}}], 
  Line[{{0.13544901687515776, 1.6464961680271788}, {0.20794335450319978, \
1.7870411277345808}, {0.5654203983846688, 1.8918241808350182}, 
    {0.4714721892511405, 1.7374623647519976}, {0.13544901687515776, \
1.6464961680271788}}], 
  Line[{{0.20794335450319978, 1.7870411277345808}, {0.29559313554697325, \
1.9398272078772505}, {0.6790091313731489, 2.0573688751735326}, 
    {0.5654203983846688, 1.8918241808350182}, {0.20794335450319978, \
1.7870411277345808}}], 
  Line[{{0.29559313554697325, 1.9398272078772505}, {0.39456764398455224, \
2.094622360137233}, {0.80727401552577, 2.2226072396953476}, 
    {0.6790091313731489, 2.0573688751735326}, {0.29559313554697325, \
1.9398272078772505}}], 
  Line[{{0.39456764398455224, 2.094622360137233}, {0.5005412188648295, \
2.243746859528865}, {0.9446092599218614, 2.379229777665828}, 
    {0.80727401552577, 2.2226072396953476}, {0.39456764398455224, \
2.094622360137233}}], 
  Line[{{0.5005412188648295, 2.243746859528865}, {0.6088823064479062, \
2.3817202672447806}, {1.0850126553736956, 2.521624931409046}, 
    {0.9446092599218614, 2.379229777665828}, {0.5005412188648295, \
2.243746859528865}}], 
  Line[{{0.6088823064479062, 2.3817202672447806}, {0.7148558813281839, \
2.504820390287959}, {1.2223478997697876, 2.646328981764321}, 
    {1.0850126553736956, 2.521624931409046}, {0.6088823064479062, \
2.3817202672447806}}], 
  Line[{{0.7148558813281839, 2.504820390287959}, {0.8138303897657626, \
2.610679178763368}, {1.3506127839224085, 2.7515251706591934}, 
    {1.2223478997697876, 2.646328981764321}, {0.7148558813281839, \
2.504820390287959}}], 
  Line[{{0.8138303897657626, 2.610679178763368}, {0.9014801708095362, \
2.697933958917173}, {1.4642015169108888, 2.836596676593442}, 
    {1.3506127839224085, 2.7515251706591934}, {0.8138303897657626, \
2.610679178763368}}], 
  Line[{{0.9014801708095362, 2.697933958917173}, {0.9739745084375787, \
2.765926276195979}, {1.5581497260444177, 2.9017190909782276}, 
    {1.4642015169108888, 2.836596676593442}, {0.9014801708095362, \
2.697933958917173}}], 
  Line[{{0.9739745084375787, 2.765926276195979}, {1.0281450522291171, \
2.8144424077524013}, {1.628351423770335, 2.9474883844565616}, 
    {1.5581497260444177, 2.9017190909782276}, {0.9739745084375787, \
2.765926276195979}}], 
  Line[{{1.0281450522291171, 2.8144424077524013}, {1.0616242894813523, \
2.8434972909653364}, {1.6717384590328979, 2.9745950829027943}, 
    {1.628351423770335, 2.9474883844565616}, {1.0281450522291171, \
2.8144424077524013}}], 
  Line[{{1.0616242894813523, 2.8434972909653364}, {1.0729490168751576, \
2.8531695488854605}, {1.6864146101970388, 2.98356568610482}, 
    {1.6717384590328979, 2.9745950829027943}, {1.0616242894813523, \
2.8434972909653364}}], 
  Line[{{1.0729490168751576, 2.8531695488854605}, {1.0616242894813526, \
2.843497290965337}, {1.6717384590328983, 2.974595082902794}, 
    {1.6864146101970388, 2.98356568610482}, {1.0729490168751576, \
2.8531695488854605}}], 
  Line[{{1.0616242894813526, 2.843497290965337}, {1.0281450522291173, \
2.8144424077524013}, {1.6283514237703351, 2.947488384456561}, 
    {1.6717384590328983, 2.974595082902794}, {1.0616242894813526, \
2.843497290965337}}], 
  Line[{{1.0281450522291173, 2.8144424077524013}, {0.973974508437579, \
2.7659262761959793}, {1.558149726044418, 2.9017190909782276}, 
    {1.6283514237703351, 2.947488384456561}, {1.0281450522291173, \
2.8144424077524013}}], 
  Line[{{0.973974508437579, 2.7659262761959793}, {0.901480170809537, \
2.6979339589171736}, {1.4642015169108895, 2.836596676593442}, 
    {1.558149726044418, 2.9017190909782276}, {0.973974508437579, \
2.7659262761959793}}], 
  Line[{{0.901480170809537, 2.6979339589171736}, {0.8138303897657633, \
2.6106791787633687}, {1.3506127839224094, 2.751525170659194}, 
    {1.4642015169108895, 2.836596676593442}, {0.901480170809537, \
2.6979339589171736}}], 
  Line[{{0.8138303897657633, 2.6106791787633687}, {0.7148558813281845, \
2.504820390287959}, {1.2223478997697883, 2.646328981764321}, 
    {1.3506127839224094, 2.751525170659194}, {0.8138303897657633, \
2.6106791787633687}}], 
  Line[{{0.7148558813281845, 2.504820390287959}, {0.6088823064479071, \
2.3817202672447815}, {1.085012655373697, 2.521624931409047}, 
    {1.2223478997697883, 2.646328981764321}, {0.7148558813281845, \
2.504820390287959}}], 
  Line[{{0.6088823064479071, 2.3817202672447815}, {0.5005412188648302, \
2.243746859528866}, {0.9446092599218623, 2.379229777665829}, 
    {1.085012655373697, 2.521624931409047}, {0.6088823064479071, \
2.3817202672447815}}], 
  Line[{{0.5005412188648302, 2.243746859528866}, {0.3945676439845526, \
2.0946223601372336}, {0.8072740155257706, 2.222607239695348}, 
    {0.9446092599218623, 2.379229777665829}, {0.5005412188648302, \
2.243746859528866}}], 
  Line[{{0.3945676439845526, 2.0946223601372336}, {0.295593135546974, \
1.9398272078772514}, {0.6790091313731498, 2.057368875173534}, 
    {0.8072740155257706, 2.222607239695348}, {0.3945676439845526, \
2.0946223601372336}}], 
  Line[{{0.295593135546974, 1.9398272078772514}, {0.20794335450320034, \
1.7870411277345821}, {0.5654203983846697, 1.8918241808350196}, 
    {0.6790091313731498, 2.057368875173534}, {0.295593135546974, \
1.9398272078772514}}], 
  Line[{{0.20794335450320034, 1.7870411277345821}, {0.13544901687515776, \
1.646496168027179}, {0.4714721892511406, 1.7374623647519978}, 
    {0.5654203983846697, 1.8918241808350196}, {0.20794335450320034, \
1.7870411277345821}}], 
  Line[{{0.13544901687515776, 1.646496168027179}, {0.08127847308361968, \
1.530848154054823}, {0.40127049152522365, 1.608922497423836}, 
    {0.4714721892511406, 1.7374623647519978}, {0.13544901687515776, \
1.646496168027179}}], 
  Line[{{0.08127847308361968, 1.530848154054823}, {0.047799235831384346, \
1.4537753723488895}, {0.3578834562626605, 1.5224519023538967}, 
    {0.40127049152522365, 1.608922497423836}, {0.08127847308361968, \
1.530848154054823}}], 
  Line[{{0.047799235831384346, 1.4537753723488895}, {0.03647450843757882, \
1.4265847744427302}, {0.3432073050985194, 1.49178284305241}, 
    {0.3578834562626605, 1.5224519023538967}, {0.047799235831384346, \
1.4537753723488895}}], 
  Line[{{0.03647450843757882, 1.4265847744427302}, {0.04779923583138401, \
1.4537753723488889}, {0.35788345626266016, 1.5224519023538963}, 
    {0.3432073050985194, 1.49178284305241}, {0.03647450843757882, \
1.4265847744427302}}], 
  Line[{{0.04779923583138401, 1.4537753723488889}, {0.08127847308361902, \
1.530848154054822}, {0.40127049152522287, 1.608922497423835}, 
    {0.35788345626266016, 1.5224519023538963}, {0.04779923583138401, \
1.4537753723488889}}], 
  Line[{{0.08127847308361902, 1.530848154054822}, {0.1354490168751576, \
1.6464961680271786}, {0.4714721892511403, 1.7374623647519973}, 
    {0.40127049152522287, 1.608922497423835}, {0.08127847308361902, \
1.530848154054822}}], 
  Line[{{0.1354490168751576, 1.6464961680271786}, {0.20794335450319956, \
1.7870411277345803}, {0.5654203983846685, 1.8918241808350178}, 
    {0.4714721892511403, 1.7374623647519973}, {0.1354490168751576, \
1.6464961680271786}}], 
  Line[{{0.20794335450319956, 1.7870411277345803}, {0.2955931355469728, \
1.9398272078772496}, {0.6790091313731483, 2.057368875173532}, 
    {0.5654203983846685, 1.8918241808350178}, {0.20794335450319956, \
1.7870411277345803}}], 
  Line[{{0.2955931355469728, 1.9398272078772496}, {0.39456764398455213, \
2.0946223601372327}, {0.80727401552577, 2.2226072396953476}, 
    {0.6790091313731483, 2.057368875173532}, {0.2955931355469728, \
1.9398272078772496}}], 
  Line[{{0.39456764398455213, 2.0946223601372327}, {0.5005412188648293, \
2.2437468595288648}, {0.944609259921861, 2.379229777665828}, 
    {0.80727401552577, 2.2226072396953476}, {0.39456764398455213, \
2.0946223601372327}}], 
  Line[{{0.5005412188648293, 2.2437468595288648}, {0.6088823064479056, \
2.38172026724478}, {1.085012655373695, 2.521624931409045}, 
    {0.944609259921861, 2.379229777665828}, {0.5005412188648293, \
2.2437468595288648}}], 
  Line[{{0.6088823064479056, 2.38172026724478}, {0.714855881328184, \
2.504820390287959}, {1.2223478997697876, 2.646328981764321}, 
    {1.085012655373695, 2.521624931409045}, {0.6088823064479056, \
2.38172026724478}}], 
  Line[{{0.714855881328184, 2.504820390287959}, {0.8138303897657625, \
2.610679178763368}, {1.3506127839224085, 2.7515251706591934}, 
    {1.2223478997697876, 2.646328981764321}, {0.714855881328184, \
2.504820390287959}}], 
  Line[{{0.8138303897657625, 2.610679178763368}, {0.9014801708095358, \
2.6979339589171727}, {1.4642015169108882, 2.836596676593441}, 
    {1.3506127839224085, 2.7515251706591934}, {0.8138303897657625, \
2.610679178763368}}], 
  Line[{{0.9014801708095358, 2.6979339589171727}, {0.9739745084375787, \
2.765926276195979}, {1.5581497260444177, 2.901719090978228}, 
    {1.4642015169108882, 2.836596676593441}, {0.9014801708095358, \
2.6979339589171727}}], 
  Line[{{0.9739745084375787, 2.765926276195979}, {1.0281450522291171, \
2.8144424077524013}, {1.628351423770335, 2.9474883844565616}, 
    {1.5581497260444177, 2.901719090978228}, {0.9739745084375787, \
2.765926276195979}}], 
  Line[{{1.0281450522291171, 2.8144424077524013}, {1.0616242894813523, \
2.8434972909653364}, {1.671738459032898, 2.9745950829027943}, 
    {1.628351423770335, 2.9474883844565616}, {1.0281450522291171, \
2.8144424077524013}}], 
  Line[{{1.0616242894813523, 2.8434972909653364}, {1.0729490168751576, \
2.8531695488854605}, {1.6864146101970388, 2.98356568610482}, 
    {1.671738459032898, 2.9745950829027943}, {1.0616242894813523, \
2.8434972909653364}}], 
  Line[{{1.6864146101970388, 2.98356568610482}, {1.6717384590328979, \
2.9745950829027943}, {2.2954829420678085, 2.9763034938899464}, 
    {2.3135853898029595, 2.98356568610482}, {1.6864146101970388, \
2.98356568610482}}], 
  Line[{{1.6717384590328979, 2.9745950829027943}, {1.6283514237703351, \
2.9474883844565616}, {2.241966762693565, 2.9540812792513704}, 
    {2.2954829420678085, 2.9763034938899464}, {1.6717384590328979, \
2.9745950829027943}}], 
  Line[{{1.6283514237703351, 2.9474883844565616}, {1.5581497260444177, \
2.9017190909782276}, {2.1553757655180017, 2.9156867970745455}, 
    {2.241966762693565, 2.9540812792513704}, {1.6283514237703351, \
2.9474883844565616}}], 
  Line[{{1.5581497260444177, 2.9017190909782276}, {1.4642015169108888, \
2.836596676593442}, {2.039494392627396, 2.859399797409293}, 
    {2.1553757655180017, 2.9156867970745455}, {1.5581497260444177, \
2.9017190909782276}}], 
  Line[{{1.4642015169108888, 2.836596676593442}, {1.3506127839224091, \
2.751525170659194}, {1.8993872160775895, 2.7833940695732022}, 
    {2.039494392627396, 2.859399797409293}, {1.4642015169108888, \
2.836596676593442}}], 
  Line[{{1.3506127839224091, 2.751525170659194}, {1.2223478997697876, \
2.646328981764321}, {1.7411775917926318, 2.686221801523239}, 
    {1.8993872160775895, 2.7833940695732022}, {1.3506127839224091, \
2.751525170659194}}], 
  Line[{{1.2223478997697876, 2.646328981764321}, {1.0850126553736965, \
2.5216249314090464}, {1.5717800395277828, 2.567335508777075}, 
    {1.7411775917926318, 2.686221801523239}, {1.2223478997697876, \
2.646328981764321}}], 
  Line[{{1.0850126553736965, 2.5216249314090464}, {0.9446092599218617, \
2.3792297776658287}, {1.3985980451766564, 2.427623046285348}, 
    {1.5717800395277828, 2.567335508777075}, {1.0850126553736965, \
2.5216249314090464}}], 
  Line[{{0.9446092599218617, 2.3792297776658287}, {0.8072740155257703, \
2.222607239695348}, {1.2292004929118074, 2.2699589047379565}, 
    {1.3985980451766564, 2.427623046285348}, {0.9446092599218617, \
2.3792297776658287}}], 
  Line[{{0.8072740155257703, 2.222607239695348}, {0.6790091313731493, \
2.0573688751735335}, {1.07099086862685, 2.099799626225554}, 
    {1.2292004929118074, 2.2699589047379565}, {0.8072740155257703, \
2.222607239695348}}], 
  Line[{{0.6790091313731493, 2.0573688751735335}, {0.5654203983846692, \
1.8918241808350187}, {0.9308836920770429, 1.9258466260207312}, 
    {1.07099086862685, 2.099799626225554}, {0.6790091313731493, \
2.0573688751735335}}], 
  Line[{{0.5654203983846692, 1.8918241808350187}, {0.47147218925114043, \
1.7374623647519978}, {0.8150023191864373, 1.760690570377689}, 
    {0.9308836920770429, 1.9258466260207312}, {0.5654203983846692, \
1.8918241808350187}}], 
  Line[{{0.47147218925114043, 1.7374623647519978}, {0.40127049152522337, \
1.6089224974238359}, {0.7284113220108746, 1.6209688555409116}, 
    {0.8150023191864373, 1.760690570377689}, {0.47147218925114043, \
1.7374623647519978}}], 
  Line[{{0.40127049152522337, 1.6089224974238359}, {0.35788345626266027, \
1.5224519023538965}, {0.6748951426366303, 1.525787133086728}, 
    {0.7284113220108746, 1.6209688555409116}, {0.40127049152522337, \
1.6089224974238359}}], 
  Line[{{0.35788345626266027, 1.5224519023538965}, {0.3432073050985194, \
1.49178284305241}, {0.6567926949014797, 1.4917828430524098}, 
    {0.6748951426366303, 1.525787133086728}, {0.35788345626266027, \
1.5224519023538965}}], 
  Line[{{0.3432073050985194, 1.49178284305241}, {0.35788345626266027, \
1.5224519023538965}, {0.6748951426366303, 1.5257871330867279}, 
    {0.6567926949014797, 1.4917828430524098}, {0.3432073050985194, \
1.49178284305241}}], 
  Line[{{0.35788345626266027, 1.5224519023538965}, {0.40127049152522326, \
1.6089224974238354}, {0.7284113220108744, 1.6209688555409114}, 
    {0.6748951426366303, 1.5257871330867279}, {0.35788345626266027, \
1.5224519023538965}}], 
  Line[{{0.40127049152522326, 1.6089224974238354}, {0.4714721892511405, \
1.7374623647519976}, {0.8150023191864375, 1.7606905703776887}, 
    {0.7284113220108744, 1.6209688555409114}, {0.40127049152522326, \
1.6089224974238354}}], 
  Line[{{0.4714721892511405, 1.7374623647519976}, {0.5654203983846688, \
1.8918241808350182}, {0.9308836920770425, 1.9258466260207305}, 
    {0.8150023191864375, 1.7606905703776887}, {0.4714721892511405, \
1.7374623647519976}}], 
  Line[{{0.5654203983846688, 1.8918241808350182}, {0.6790091313731489, \
2.0573688751735326}, {1.0709908686268492, 2.099799626225553}, 
    {0.9308836920770425, 1.9258466260207305}, {0.5654203983846688, \
1.8918241808350182}}], 
  Line[{{0.6790091313731489, 2.0573688751735326}, {0.80727401552577, \
2.2226072396953476}, {1.229200492911807, 2.269958904737956}, 
    {1.0709908686268492, 2.099799626225553}, {0.6790091313731489, \
2.0573688751735326}}], 
  Line[{{0.80727401552577, 2.2226072396953476}, {0.9446092599218614, \
2.379229777665828}, {1.3985980451766555, 2.4276230462853476}, 
    {1.229200492911807, 2.269958904737956}, {0.80727401552577, \
2.2226072396953476}}], 
  Line[{{0.9446092599218614, 2.379229777665828}, {1.0850126553736956, \
2.521624931409046}, {1.571780039527782, 2.5673355087770746}, 
    {1.3985980451766555, 2.4276230462853476}, {0.9446092599218614, \
2.379229777665828}}], 
  Line[{{1.0850126553736956, 2.521624931409046}, {1.2223478997697876, \
2.646328981764321}, {1.7411775917926315, 2.686221801523239}, 
    {1.571780039527782, 2.5673355087770746}, {1.0850126553736956, \
2.521624931409046}}], 
  Line[{{1.2223478997697876, 2.646328981764321}, {1.3506127839224085, \
2.7515251706591934}, {1.8993872160775886, 2.7833940695732022}, 
    {1.7411775917926315, 2.686221801523239}, {1.2223478997697876, \
2.646328981764321}}], 
  Line[{{1.3506127839224085, 2.7515251706591934}, {1.4642015169108888, \
2.836596676593442}, {2.039494392627396, 2.859399797409293}, 
    {1.8993872160775886, 2.7833940695732022}, {1.3506127839224085, \
2.7515251706591934}}], 
  Line[{{1.4642015169108888, 2.836596676593442}, {1.5581497260444177, \
2.9017190909782276}, {2.1553757655180017, 2.9156867970745455}, 
    {2.039494392627396, 2.859399797409293}, {1.4642015169108888, \
2.836596676593442}}], 
  Line[{{1.5581497260444177, 2.9017190909782276}, {1.628351423770335, \
2.9474883844565616}, {2.241966762693565, 2.95408127925137}, 
    {2.1553757655180017, 2.9156867970745455}, {1.5581497260444177, \
2.9017190909782276}}], 
  Line[{{1.628351423770335, 2.9474883844565616}, {1.6717384590328979, \
2.9745950829027943}, {2.2954829420678085, 2.9763034938899464}, 
    {2.241966762693565, 2.95408127925137}, {1.628351423770335, \
2.9474883844565616}}], 
  Line[{{1.6717384590328979, 2.9745950829027943}, {1.6864146101970388, \
2.98356568610482}, {2.3135853898029595, 2.98356568610482}, 
    {2.2954829420678085, 2.9763034938899464}, {1.6717384590328979, \
2.9745950829027943}}], 
  Line[{{1.6864146101970388, 2.98356568610482}, {1.6717384590328983, \
2.974595082902794}, {2.2954829420678093, 2.9763034938899464}, 
    {2.3135853898029595, 2.98356568610482}, {1.6864146101970388, \
2.98356568610482}}], 
  Line[{{1.6717384590328983, 2.974595082902794}, {1.6283514237703351, \
2.947488384456561}, {2.241966762693565, 2.9540812792513704}, 
    {2.2954829420678093, 2.9763034938899464}, {1.6717384590328983, \
2.974595082902794}}], 
  Line[{{1.6283514237703351, 2.947488384456561}, {1.558149726044418, \
2.9017190909782276}, {2.155375765518002, 2.9156867970745455}, 
    {2.241966762693565, 2.9540812792513704}, {1.6283514237703351, \
2.947488384456561}}], 
  Line[{{1.558149726044418, 2.9017190909782276}, {1.4642015169108895, \
2.836596676593442}, {2.0394943926273967, 2.859399797409293}, 
    {2.155375765518002, 2.9156867970745455}, {1.558149726044418, \
2.9017190909782276}}], 
  Line[{{1.4642015169108895, 2.836596676593442}, {1.3506127839224094, \
2.751525170659194}, {1.8993872160775902, 2.7833940695732027}, 
    {2.0394943926273967, 2.859399797409293}, {1.4642015169108895, \
2.836596676593442}}], 
  Line[{{1.3506127839224094, 2.751525170659194}, {1.2223478997697883, \
2.646328981764321}, {1.7411775917926322, 2.6862218015232395}, 
    {1.8993872160775902, 2.7833940695732027}, {1.3506127839224094, \
2.751525170659194}}], 
  Line[{{1.2223478997697883, 2.646328981764321}, {1.085012655373697, \
2.521624931409047}, {1.5717800395277832, 2.5673355087770755}, 
    {1.7411775917926322, 2.6862218015232395}, {1.2223478997697883, \
2.646328981764321}}], 
  Line[{{1.085012655373697, 2.521624931409047}, {0.9446092599218623, \
2.379229777665829}, {1.3985980451766569, 2.4276230462853485}, 
    {1.5717800395277832, 2.5673355087770755}, {1.085012655373697, \
2.521624931409047}}], 
  Line[{{0.9446092599218623, 2.379229777665829}, {0.8072740155257706, \
2.222607239695348}, {1.2292004929118077, 2.269958904737957}, 
    {1.3985980451766569, 2.4276230462853485}, {0.9446092599218623, \
2.379229777665829}}], 
  Line[{{0.8072740155257706, 2.222607239695348}, {0.6790091313731498, \
2.057368875173534}, {1.0709908686268503, 2.0997996262255545}, 
    {1.2292004929118077, 2.269958904737957}, {0.8072740155257706, \
2.222607239695348}}], 
  Line[{{0.6790091313731498, 2.057368875173534}, {0.5654203983846697, \
1.8918241808350196}, {0.9308836920770434, 1.9258466260207323}, 
    {1.0709908686268503, 2.0997996262255545}, {0.6790091313731498, \
2.057368875173534}}], 
  Line[{{0.5654203983846697, 1.8918241808350196}, {0.4714721892511406, \
1.7374623647519978}, {0.8150023191864375, 1.760690570377689}, 
    {0.9308836920770434, 1.9258466260207323}, {0.5654203983846697, \
1.8918241808350196}}], 
  Line[{{0.4714721892511406, 1.7374623647519978}, {0.40127049152522365, \
1.608922497423836}, {0.728411322010875, 1.620968855540912}, 
    {0.8150023191864375, 1.760690570377689}, {0.4714721892511406, \
1.7374623647519978}}], 
  Line[{{0.40127049152522365, 1.608922497423836}, {0.3578834562626605, \
1.5224519023538967}, {0.6748951426366308, 1.5257871330867285}, 
    {0.728411322010875, 1.620968855540912}, {0.40127049152522365, \
1.608922497423836}}], 
  Line[{{0.3578834562626605, 1.5224519023538967}, {0.3432073050985194, \
1.49178284305241}, {0.6567926949014797, 1.4917828430524098}, 
    {0.6748951426366308, 1.5257871330867285}, {0.3578834562626605, \
1.5224519023538967}}], 
  Line[{{0.3432073050985194, 1.49178284305241}, {0.35788345626266016, \
1.5224519023538963}, {0.6748951426366302, 1.5257871330867274}, 
    {0.6567926949014797, 1.4917828430524098}, {0.3432073050985194, \
1.49178284305241}}], 
  Line[{{0.35788345626266016, 1.5224519023538963}, {0.40127049152522287, \
1.608922497423835}, {0.7284113220108738, 1.6209688555409107}, 
    {0.6748951426366302, 1.5257871330867274}, {0.35788345626266016, \
1.5224519023538963}}], 
  Line[{{0.40127049152522287, 1.608922497423835}, {0.4714721892511403, \
1.7374623647519973}, {0.8150023191864373, 1.7606905703776887}, 
    {0.7284113220108738, 1.6209688555409107}, {0.40127049152522287, \
1.608922497423835}}], 
  Line[{{0.4714721892511403, 1.7374623647519973}, {0.5654203983846685, \
1.8918241808350178}, {0.930883692077042, 1.92584662602073}, 
    {0.8150023191864373, 1.7606905703776887}, {0.4714721892511403, \
1.7374623647519973}}], 
  Line[{{0.5654203983846685, 1.8918241808350178}, {0.6790091313731483, \
2.057368875173532}, {1.0709908686268486, 2.0997996262255523}, 
    {0.930883692077042, 1.92584662602073}, {0.5654203983846685, \
1.8918241808350178}}], 
  Line[{{0.6790091313731483, 2.057368875173532}, {0.80727401552577, \
2.2226072396953476}, {1.229200492911807, 2.269958904737956}, 
    {1.0709908686268486, 2.0997996262255523}, {0.6790091313731483, \
2.057368875173532}}], 
  Line[{{0.80727401552577, 2.2226072396953476}, {0.944609259921861, \
2.379229777665828}, {1.3985980451766553, 2.427623046285347}, 
    {1.229200492911807, 2.269958904737956}, {0.80727401552577, \
2.2226072396953476}}], 
  Line[{{0.944609259921861, 2.379229777665828}, {1.085012655373695, \
2.521624931409045}, {1.571780039527781, 2.5673355087770737}, 
    {1.3985980451766553, 2.427623046285347}, {0.944609259921861, \
2.379229777665828}}], 
  Line[{{1.085012655373695, 2.521624931409045}, {1.2223478997697876, \
2.646328981764321}, {1.7411775917926318, 2.686221801523239}, 
    {1.571780039527781, 2.5673355087770737}, {1.085012655373695, \
2.521624931409045}}], 
  Line[{{1.2223478997697876, 2.646328981764321}, {1.3506127839224085, \
2.7515251706591934}, {1.8993872160775886, 2.7833940695732022}, 
    {1.7411775917926318, 2.686221801523239}, {1.2223478997697876, \
2.646328981764321}}], 
  Line[{{1.3506127839224085, 2.7515251706591934}, {1.4642015169108882, \
2.836596676593441}, {2.0394943926273954, 2.8593997974092926}, 
    {1.8993872160775886, 2.7833940695732022}, {1.3506127839224085, \
2.7515251706591934}}], 
  Line[{{1.4642015169108882, 2.836596676593441}, {1.5581497260444177, \
2.901719090978228}, {2.1553757655180017, 2.9156867970745455}, 
    {2.0394943926273954, 2.8593997974092926}, {1.4642015169108882, \
2.836596676593441}}], 
  Line[{{1.5581497260444177, 2.901719090978228}, {1.628351423770335, \
2.9474883844565616}, {2.241966762693565, 2.95408127925137}, 
    {2.1553757655180017, 2.9156867970745455}, {1.5581497260444177, \
2.901719090978228}}], 
  Line[{{1.628351423770335, 2.9474883844565616}, {1.671738459032898, \
2.9745950829027943}, {2.295482942067809, 2.9763034938899455}, 
    {2.241966762693565, 2.95408127925137}, {1.628351423770335, \
2.9474883844565616}}], 
  Line[{{1.671738459032898, 2.9745950829027943}, {1.6864146101970388, \
2.98356568610482}, {2.3135853898029595, 2.98356568610482}, 
    {2.295482942067809, 2.9763034938899455}, {1.671738459032898, \
2.9745950829027943}}], 
  Line[{{2.3135853898029595, 2.98356568610482}, {2.2954829420678085, \
2.9763034938899464}, {2.9055971116193557, 2.8487773266631815}, 
    {2.9270509831248424, 2.8531695488854605}, {2.3135853898029595, \
2.98356568610482}}], 
  Line[{{2.2954829420678085, 2.9763034938899464}, {2.241966762693565, \
2.9540812792513704}, {2.842173134234785, 2.834803496770629}, 
    {2.9055971116193557, 2.8487773266631815}, {2.2954829420678085, \
2.9763034938899464}}], 
  Line[{{2.241966762693565, 2.9540812792513704}, {2.1553757655180017, \
2.9156867970745455}, {2.739550983124842, 2.809014835019403}, 
    {2.842173134234785, 2.834803496770629}, {2.241966762693565, \
2.9540812792513704}}], 
  Line[{{2.1553757655180017, 2.9156867970745455}, {2.039494392627396, \
2.859399797409293}, {2.602215738728751, 2.768181798733441}, 
    {2.739550983124842, 2.809014835019403}, {2.1553757655180017, \
2.9156867970745455}}], 
  Line[{{2.039494392627396, 2.859399797409293}, {1.8993872160775895, \
2.7833940695732022}, {2.4361696102342374, 2.7087103854853694}, 
    {2.602215738728751, 2.768181798733441}, {2.039494392627396, \
2.859399797409293}}], 
  Line[{{1.8993872160775895, 2.7833940695732022}, {1.7411775917926318, \
2.686221801523239}, {2.248669610234237, 2.6273597595826383}, 
    {2.4361696102342374, 2.7087103854853694}, {1.8993872160775895, \
2.7833940695732022}}], 
  Line[{{1.7411775917926318, 2.686221801523239}, {1.5717800395277828, \
2.567335508777075}, {2.047910388453574, 2.521960112821855}, 
    {2.248669610234237, 2.6273597595826383}, {1.7411775917926318, \
2.686221801523239}}], 
  Line[{{1.5717800395277828, 2.567335508777075}, {1.3985980451766564, \
2.427623046285348}, {1.8426660862336899, 2.392089327116677}, 
    {2.047910388453574, 2.521960112821855}, {1.5717800395277828, \
2.567335508777075}}], 
  Line[{{1.3985980451766564, 2.427623046285348}, {1.2292004929118074, \
2.2699589047379565}, {1.6419068644530264, 2.239718051509763}, 
    {1.8426660862336899, 2.392089327116677}, {1.3985980451766564, \
2.427623046285348}}], 
  Line[{{1.2292004929118074, 2.2699589047379565}, {1.07099086862685, \
2.099799626225554}, {1.4544068644530266, 2.0698782028004876}, 
    {1.6419068644530264, 2.239718051509763}, {1.2292004929118074, \
2.2699589047379565}}], 
  Line[{{1.07099086862685, 2.099799626225554}, {0.9308836920770429, \
1.9258466260207312}, {1.2883607359585132, 1.8914277190459865}, 
    {1.4544068644530266, 2.0698782028004876}, {1.07099086862685, \
2.099799626225554}}], 
  Line[{{0.9308836920770429, 1.9258466260207312}, {0.8150023191864373, \
1.760690570377689}, {1.151025491562421, 1.7178957504272223}, 
    {1.2883607359585132, 1.8914277190459865}, {0.9308836920770429, \
1.9258466260207312}}], 
  Line[{{0.8150023191864373, 1.760690570377689}, {0.7284113220108746, \
1.6209688555409116}, {1.0484033404524793, 1.5679671136605229}, 
    {1.151025491562421, 1.7178957504272223}, {0.8150023191864373, \
1.760690570377689}}], 
  Line[{{0.7284113220108746, 1.6209688555409116}, {0.6748951426366303, \
1.525787133086728}, {0.9849793630679075, 1.464075901868194}, 
    {1.0484033404524793, 1.5679671136605229}, {0.7284113220108746, \
1.6209688555409116}}], 
  Line[{{0.6748951426366303, 1.525787133086728}, {0.6567926949014797, \
1.4917828430524098}, {0.9635254915624212, 1.4265847744427302}, 
    {0.9849793630679075, 1.464075901868194}, {0.6748951426366303, \
1.525787133086728}}], 
  Line[{{0.6567926949014797, 1.4917828430524098}, {0.6748951426366303, \
1.5257871330867279}, {0.9849793630679075, 1.4640759018681935}, 
    {0.9635254915624212, 1.4265847744427302}, {0.6567926949014797, \
1.4917828430524098}}], 
  Line[{{0.6748951426366303, 1.5257871330867279}, {0.7284113220108744, \
1.6209688555409114}, {1.0484033404524793, 1.5679671136605227}, 
    {0.9849793630679075, 1.4640759018681935}, {0.6748951426366303, \
1.5257871330867279}}], 
  Line[{{0.7284113220108744, 1.6209688555409114}, {0.8150023191864375, \
1.7606905703776887}, {1.1510254915624212, 1.7178957504272216}, 
    {1.0484033404524793, 1.5679671136605227}, {0.7284113220108744, \
1.6209688555409114}}], 
  Line[{{0.8150023191864375, 1.7606905703776887}, {0.9308836920770425, \
1.9258466260207305}, {1.2883607359585123, 1.8914277190459858}, 
    {1.1510254915624212, 1.7178957504272216}, {0.8150023191864375, \
1.7606905703776887}}], 
  Line[{{0.9308836920770425, 1.9258466260207305}, {1.0709908686268492, \
2.099799626225553}, {1.4544068644530257, 2.069878202800487}, 
    {1.2883607359585123, 1.8914277190459858}, {0.9308836920770425, \
1.9258466260207305}}], 
  Line[{{1.0709908686268492, 2.099799626225553}, {1.229200492911807, \
2.269958904737956}, {1.6419068644530261, 2.239718051509763}, 
    {1.4544068644530257, 2.069878202800487}, {1.0709908686268492, \
2.099799626225553}}], 
  Line[{{1.229200492911807, 2.269958904737956}, {1.3985980451766555, \
2.4276230462853476}, {1.842666086233689, 2.3920893271166768}, 
    {1.6419068644530261, 2.239718051509763}, {1.229200492911807, \
2.269958904737956}}], 
  Line[{{1.3985980451766555, 2.4276230462853476}, {1.571780039527782, \
2.5673355087770746}, {2.0479103884535728, 2.521960112821855}, 
    {1.842666086233689, 2.3920893271166768}, {1.3985980451766555, \
2.4276230462853476}}], 
  Line[{{1.571780039527782, 2.5673355087770746}, {1.7411775917926315, \
2.686221801523239}, {2.248669610234237, 2.627359759582638}, 
    {2.0479103884535728, 2.521960112821855}, {1.571780039527782, \
2.5673355087770746}}], 
  Line[{{1.7411775917926315, 2.686221801523239}, {1.8993872160775886, \
2.7833940695732022}, {2.436169610234236, 2.70871038548537}, 
    {2.248669610234237, 2.627359759582638}, {1.7411775917926315, \
2.686221801523239}}], 
  Line[{{1.8993872160775886, 2.7833940695732022}, {2.039494392627396, \
2.859399797409293}, {2.6022157387287503, 2.7681817987334414}, 
    {2.436169610234236, 2.70871038548537}, {1.8993872160775886, \
2.7833940695732022}}], 
  Line[{{2.039494392627396, 2.859399797409293}, {2.1553757655180017, \
2.9156867970745455}, {2.739550983124842, 2.809014835019403}, 
    {2.6022157387287503, 2.7681817987334414}, {2.039494392627396, \
2.859399797409293}}], 
  Line[{{2.1553757655180017, 2.9156867970745455}, {2.241966762693565, \
2.95408127925137}, {2.842173134234784, 2.834803496770629}, 
    {2.739550983124842, 2.809014835019403}, {2.1553757655180017, \
2.9156867970745455}}], 
  Line[{{2.241966762693565, 2.95408127925137}, {2.2954829420678085, \
2.9763034938899464}, {2.9055971116193557, 2.8487773266631815}, 
    {2.842173134234784, 2.834803496770629}, {2.241966762693565, \
2.95408127925137}}], 
  Line[{{2.2954829420678085, 2.9763034938899464}, {2.3135853898029595, \
2.98356568610482}, {2.9270509831248424, 2.8531695488854605}, 
    {2.9055971116193557, 2.8487773266631815}, {2.2954829420678085, \
2.9763034938899464}}], 
  Line[{{2.3135853898029595, 2.98356568610482}, {2.2954829420678093, \
2.9763034938899464}, {2.9055971116193566, 2.8487773266631806}, 
    {2.9270509831248424, 2.8531695488854605}, {2.3135853898029595, \
2.98356568610482}}], 
  Line[{{2.2954829420678093, 2.9763034938899464}, {2.241966762693565, \
2.9540812792513704}, {2.8421731342347845, 2.8348034967706295}, 
    {2.9055971116193566, 2.8487773266631806}, {2.2954829420678093, \
2.9763034938899464}}], 
  Line[{{2.241966762693565, 2.9540812792513704}, {2.155375765518002, \
2.9156867970745455}, {2.739550983124843, 2.8090148350194024}, 
    {2.8421731342347845, 2.8348034967706295}, {2.241966762693565, \
2.9540812792513704}}], 
  Line[{{2.155375765518002, 2.9156867970745455}, {2.0394943926273967, \
2.859399797409293}, {2.6022157387287517, 2.7681817987334414}, 
    {2.739550983124843, 2.8090148350194024}, {2.155375765518002, \
2.9156867970745455}}], 
  Line[{{2.0394943926273967, 2.859399797409293}, {1.8993872160775902, \
2.7833940695732027}, {2.436169610234238, 2.70871038548537}, 
    {2.6022157387287517, 2.7681817987334414}, {2.0394943926273967, \
2.859399797409293}}], 
  Line[{{1.8993872160775902, 2.7833940695732027}, {1.7411775917926322, \
2.6862218015232395}, {2.2486696102342374, 2.6273597595826383}, 
    {2.436169610234238, 2.70871038548537}, {1.8993872160775902, \
2.7833940695732027}}], 
  Line[{{1.7411775917926322, 2.6862218015232395}, {1.5717800395277832, \
2.5673355087770755}, {2.047910388453575, 2.521960112821855}, 
    {2.2486696102342374, 2.6273597595826383}, {1.7411775917926322, \
2.6862218015232395}}], 
  Line[{{1.5717800395277832, 2.5673355087770755}, {1.3985980451766569, \
2.4276230462853485}, {1.8426660862336905, 2.3920893271166777}, 
    {2.047910388453575, 2.521960112821855}, {1.5717800395277832, \
2.5673355087770755}}], 
  Line[{{1.3985980451766569, 2.4276230462853485}, {1.2292004929118077, \
2.269958904737957}, {1.641906864453027, 2.239718051509763}, 
    {1.8426660862336905, 2.3920893271166777}, {1.3985980451766569, \
2.4276230462853485}}], 
  Line[{{1.2292004929118077, 2.269958904737957}, {1.0709908686268503, \
2.0997996262255545}, {1.4544068644530275, 2.069878202800488}, 
    {1.641906864453027, 2.239718051509763}, {1.2292004929118077, \
2.269958904737957}}], 
  Line[{{1.0709908686268503, 2.0997996262255545}, {0.9308836920770434, \
1.9258466260207323}, {1.2883607359585136, 1.8914277190459876}, 
    {1.4544068644530275, 2.069878202800488}, {1.0709908686268503, \
2.0997996262255545}}], 
  Line[{{0.9308836920770434, 1.9258466260207323}, {0.8150023191864375, \
1.760690570377689}, {1.1510254915624212, 1.7178957504272223}, 
    {1.2883607359585136, 1.8914277190459876}, {0.9308836920770434, \
1.9258466260207323}}], 
  Line[{{0.8150023191864375, 1.760690570377689}, {0.728411322010875, \
1.620968855540912}, {1.0484033404524797, 1.5679671136605233}, 
    {1.1510254915624212, 1.7178957504272223}, {0.8150023191864375, \
1.760690570377689}}], 
  Line[{{0.728411322010875, 1.620968855540912}, {0.6748951426366308, \
1.5257871330867285}, {0.9849793630679078, 1.4640759018681944}, 
    {1.0484033404524797, 1.5679671136605233}, {0.728411322010875, \
1.620968855540912}}], 
  Line[{{0.6748951426366308, 1.5257871330867285}, {0.6567926949014797, \
1.4917828430524098}, {0.9635254915624212, 1.4265847744427302}, 
    {0.9849793630679078, 1.4640759018681944}, {0.6748951426366308, \
1.5257871330867285}}], 
  Line[{{0.6567926949014797, 1.4917828430524098}, {0.6748951426366302, \
1.5257871330867274}, {0.9849793630679072, 1.4640759018681933}, 
    {0.9635254915624212, 1.4265847744427302}, {0.6567926949014797, \
1.4917828430524098}}], 
  Line[{{0.6748951426366302, 1.5257871330867274}, {0.7284113220108738, \
1.6209688555409107}, {1.0484033404524786, 1.5679671136605218}, 
    {0.9849793630679072, 1.4640759018681933}, {0.6748951426366302, \
1.5257871330867274}}], 
  Line[{{0.7284113220108738, 1.6209688555409107}, {0.8150023191864373, \
1.7606905703776887}, {1.151025491562421, 1.7178957504272216}, 
    {1.0484033404524786, 1.5679671136605218}, {0.7284113220108738, \
1.6209688555409107}}], 
  Line[{{0.8150023191864373, 1.7606905703776887}, {0.930883692077042, \
1.92584662602073}, {1.288360735958512, 1.8914277190459854}, 
    {1.151025491562421, 1.7178957504272216}, {0.8150023191864373, \
1.7606905703776887}}], 
  Line[{{0.930883692077042, 1.92584662602073}, {1.0709908686268486, \
2.0997996262255523}, {1.4544068644530252, 2.069878202800486}, 
    {1.288360735958512, 1.8914277190459854}, {0.930883692077042, \
1.92584662602073}}], 
  Line[{{1.0709908686268486, 2.0997996262255523}, {1.229200492911807, \
2.269958904737956}, {1.6419068644530261, 2.239718051509763}, 
    {1.4544068644530252, 2.069878202800486}, {1.0709908686268486, \
2.0997996262255523}}], 
  Line[{{1.229200492911807, 2.269958904737956}, {1.3985980451766553, \
2.427623046285347}, {1.8426660862336885, 2.3920893271166768}, 
    {1.6419068644530261, 2.239718051509763}, {1.229200492911807, \
2.269958904737956}}], 
  Line[{{1.3985980451766553, 2.427623046285347}, {1.571780039527781, \
2.5673355087770737}, {2.047910388453572, 2.521960112821854}, 
    {1.8426660862336885, 2.3920893271166768}, {1.3985980451766553, \
2.427623046285347}}], 
  Line[{{1.571780039527781, 2.5673355087770737}, {1.7411775917926318, \
2.686221801523239}, {2.248669610234237, 2.6273597595826383}, 
    {2.047910388453572, 2.521960112821854}, {1.571780039527781, \
2.5673355087770737}}], 
  Line[{{1.7411775917926318, 2.686221801523239}, {1.8993872160775886, \
2.7833940695732022}, {2.436169610234236, 2.7087103854853694}, 
    {2.248669610234237, 2.6273597595826383}, {1.7411775917926318, \
2.686221801523239}}], 
  Line[{{1.8993872160775886, 2.7833940695732022}, {2.0394943926273954, \
2.8593997974092926}, {2.602215738728749, 2.7681817987334414}, 
    {2.436169610234236, 2.7087103854853694}, {1.8993872160775886, \
2.7833940695732022}}], 
  Line[{{2.0394943926273954, 2.8593997974092926}, {2.1553757655180017, \
2.9156867970745455}, {2.739550983124842, 2.809014835019403}, 
    {2.602215738728749, 2.7681817987334414}, {2.0394943926273954, \
2.8593997974092926}}], 
  Line[{{2.1553757655180017, 2.9156867970745455}, {2.241966762693565, \
2.95408127925137}, {2.842173134234784, 2.834803496770629}, 
    {2.739550983124842, 2.809014835019403}, {2.1553757655180017, \
2.9156867970745455}}], 
  Line[{{2.241966762693565, 2.95408127925137}, {2.295482942067809, \
2.9763034938899455}, {2.905597111619356, 2.848777326663181}, 
    {2.842173134234784, 2.834803496770629}, {2.241966762693565, \
2.95408127925137}}], 
  Line[{{2.295482942067809, 2.9763034938899455}, {2.3135853898029595, \
2.98356568610482}, {2.9270509831248424, 2.8531695488854605}, 
    {2.905597111619356, 2.848777326663181}, {2.295482942067809, \
2.9763034938899455}}], 
  Line[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193557, \
2.8487773266631815}, {3.4754160508255305, 2.5979598975817524}, 
    {3.4999999999999996, 2.598076211353316}, {2.9270509831248424, \
2.8531695488854605}}], 
  Line[{{2.9055971116193557, 2.8487773266631815}, {2.842173134234785, \
2.834803496770629}, {3.402738639847926, 2.5962550390555568}, 
    {3.4754160508255305, 2.5979598975817524}, {2.9055971116193557, \
2.8487773266631815}}], 
  Line[{{2.842173134234785, 2.834803496770629}, {2.739550983124842, \
2.809014835019403}, {3.285144118671815, 2.5891768866299363}, 
    {3.402738639847926, 2.5962550390555568}, {2.842173134234785, \
2.834803496770629}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.602215738728751, \
2.768181798733441}, {3.1277719321537143, 2.5712732770958877}, 
    {3.285144118671815, 2.5891768866299363}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.602215738728751, 2.768181798733441}, {2.4361696102342374, \
2.7087103854853694}, {2.9375, 2.536452985962878}, 
    {3.1277719321537143, 2.5712732770958877}, {2.602215738728751, \
2.768181798733441}}], 
  Line[{{2.4361696102342374, 2.7087103854853694}, {2.248669610234237, \
2.6273597595826383}, {2.7226441186718153, 2.479055835144598}, 
    {2.9375, 2.536452985962878}, {2.4361696102342374, 2.7087103854853694}}], 
  Line[{{2.248669610234237, 2.6273597595826383}, {2.047910388453574, \
2.521960112821855}, {2.4925945211761102, 2.394814022264695}, 
    {2.7226441186718153, 2.479055835144598}, {2.248669610234237, \
2.6273597595826383}}], 
  Line[{{2.047910388453574, 2.521960112821855}, {1.8426660862336899, \
2.392089327116677}, {2.2574054788238893, 2.281657041700859}, 
    {2.4925945211761102, 2.394814022264695}, {2.047910388453574, \
2.521960112821855}}], 
  Line[{{1.8426660862336899, 2.392089327116677}, {1.6419068644530264, \
2.239718051509763}, {2.027355881328184, 2.14040166785146}, 
    {2.2574054788238893, 2.281657041700859}, {1.8426660862336899, \
2.392089327116677}}], 
  Line[{{1.6419068644530264, 2.239718051509763}, {1.4544068644530266, \
2.0698782028004876}, {1.8124999999999998, 1.9754350786598887}, 
    {2.027355881328184, 2.14040166785146}, {1.6419068644530264, \
2.239718051509763}}], 
  Line[{{1.4544068644530266, 2.0698782028004876}, {1.2883607359585132, \
1.8914277190459865}, {1.6222280678462844, 1.7955424168801202}, 
    {1.8124999999999998, 1.9754350786598887}, {1.4544068644530266, \
2.0698782028004876}}], 
  Line[{{1.2883607359585132, 1.8914277190459865}, {1.151025491562421, \
1.7178957504272223}, {1.4648558813281836, 1.61498867371741}, 
    {1.6222280678462844, 1.7955424168801202}, {1.2883607359585132, \
1.8914277190459865}}], 
  Line[{{1.151025491562421, 1.7178957504272223}, {1.0484033404524793, \
1.5679671136605229}, {1.3472613601520738, 1.4545502220637494}, 
    {1.4648558813281836, 1.61498867371741}, {1.151025491562421, \
1.7178957504272223}}], 
  Line[{{1.0484033404524793, 1.5679671136605229}, {0.9849793630679075, \
1.464075901868194}, {1.2745839491744684, 1.340717494749769}, 
    {1.3472613601520738, 1.4545502220637494}, {1.0484033404524793, \
1.5679671136605229}}], 
  Line[{{0.9849793630679075, 1.464075901868194}, {0.9635254915624212, \
1.4265847744427302}, {1.2499999999999996, 1.2990381056766582}, 
    {1.2745839491744684, 1.340717494749769}, {0.9849793630679075, \
1.464075901868194}}], 
  Line[{{0.9635254915624212, 1.4265847744427302}, {0.9849793630679075, \
1.4640759018681935}, {1.2745839491744684, 1.3407174947497689}, 
    {1.2499999999999996, 1.2990381056766582}, {0.9635254915624212, \
1.4265847744427302}}], 
  Line[{{0.9849793630679075, 1.4640759018681935}, {1.0484033404524793, \
1.5679671136605227}, {1.3472613601520735, 1.4545502220637487}, 
    {1.2745839491744684, 1.3407174947497689}, {0.9849793630679075, \
1.4640759018681935}}], 
  Line[{{1.0484033404524793, 1.5679671136605227}, {1.1510254915624212, \
1.7178957504272216}, {1.4648558813281838, 1.6149886737174097}, 
    {1.3472613601520735, 1.4545502220637487}, {1.0484033404524793, \
1.5679671136605227}}], 
  Line[{{1.1510254915624212, 1.7178957504272216}, {1.2883607359585123, \
1.8914277190459858}, {1.622228067846284, 1.7955424168801195}, 
    {1.4648558813281838, 1.6149886737174097}, {1.1510254915624212, \
1.7178957504272216}}], 
  Line[{{1.2883607359585123, 1.8914277190459858}, {1.4544068644530257, \
2.069878202800487}, {1.8124999999999991, 1.975435078659888}, 
    {1.622228067846284, 1.7955424168801195}, {1.2883607359585123, \
1.8914277190459858}}], 
  Line[{{1.4544068644530257, 2.069878202800487}, {1.6419068644530261, \
2.239718051509763}, {2.0273558813281833, 2.1404016678514597}, 
    {1.8124999999999991, 1.975435078659888}, {1.4544068644530257, \
2.069878202800487}}], 
  Line[{{1.6419068644530261, 2.239718051509763}, {1.842666086233689, \
2.3920893271166768}, {2.2574054788238884, 2.2816570417008584}, 
    {2.0273558813281833, 2.1404016678514597}, {1.6419068644530261, \
2.239718051509763}}], 
  Line[{{1.842666086233689, 2.3920893271166768}, {2.0479103884535728, \
2.521960112821855}, {2.492594521176109, 2.394814022264695}, 
    {2.2574054788238884, 2.2816570417008584}, {1.842666086233689, \
2.3920893271166768}}], 
  Line[{{2.0479103884535728, 2.521960112821855}, {2.248669610234237, \
2.627359759582638}, {2.7226441186718153, 2.479055835144598}, 
    {2.492594521176109, 2.394814022264695}, {2.0479103884535728, \
2.521960112821855}}], 
  Line[{{2.248669610234237, 2.627359759582638}, {2.436169610234236, \
2.70871038548537}, {2.9374999999999987, 2.536452985962878}, 
    {2.7226441186718153, 2.479055835144598}, {2.248669610234237, \
2.627359759582638}}], 
  Line[{{2.436169610234236, 2.70871038548537}, {2.6022157387287503, \
2.7681817987334414}, {3.1277719321537147, 2.5712732770958873}, 
    {2.9374999999999987, 2.536452985962878}, {2.436169610234236, \
2.70871038548537}}], 
  Line[{{2.6022157387287503, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {3.2851441186718153, 2.589176886629936}, 
    {3.1277719321537147, 2.5712732770958873}, {2.6022157387287503, \
2.7681817987334414}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {3.4027386398479256, 2.5962550390555554}, 
    {3.2851441186718153, 2.589176886629936}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.842173134234784, 2.834803496770629}, {2.9055971116193557, \
2.8487773266631815}, {3.4754160508255305, 2.5979598975817524}, 
    {3.4027386398479256, 2.5962550390555554}, {2.842173134234784, \
2.834803496770629}}], 
  Line[{{2.9055971116193557, 2.8487773266631815}, {2.9270509831248424, \
2.8531695488854605}, {3.4999999999999996, 2.598076211353316}, 
    {3.4754160508255305, 2.5979598975817524}, {2.9055971116193557, \
2.8487773266631815}}], 
  Line[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193566, \
2.8487773266631806}, {3.4754160508255314, 2.5979598975817515}, 
    {3.4999999999999996, 2.598076211353316}, {2.9270509831248424, \
2.8531695488854605}}], 
  Line[{{2.9055971116193566, 2.8487773266631806}, {2.8421731342347845, \
2.8348034967706295}, {3.402738639847926, 2.5962550390555568}, 
    {3.4754160508255314, 2.5979598975817515}, {2.9055971116193566, \
2.8487773266631806}}], 
  Line[{{2.8421731342347845, 2.8348034967706295}, {2.739550983124843, \
2.8090148350194024}, {3.2851441186718158, 2.589176886629936}, 
    {3.402738639847926, 2.5962550390555568}, {2.8421731342347845, \
2.8348034967706295}}], 
  Line[{{2.739550983124843, 2.8090148350194024}, {2.6022157387287517, \
2.7681817987334414}, {3.1277719321537156, 2.5712732770958877}, 
    {3.2851441186718158, 2.589176886629936}, {2.739550983124843, \
2.8090148350194024}}], 
  Line[{{2.6022157387287517, 2.7681817987334414}, {2.436169610234238, \
2.70871038548537}, {2.9375000000000004, 2.5364529859628786}, 
    {3.1277719321537156, 2.5712732770958877}, {2.6022157387287517, \
2.7681817987334414}}], 
  Line[{{2.436169610234238, 2.70871038548537}, {2.2486696102342374, \
2.6273597595826383}, {2.722644118671816, 2.479055835144598}, 
    {2.9375000000000004, 2.5364529859628786}, {2.436169610234238, \
2.70871038548537}}], 
  Line[{{2.2486696102342374, 2.6273597595826383}, {2.047910388453575, \
2.521960112821855}, {2.492594521176111, 2.3948140222646956}, 
    {2.722644118671816, 2.479055835144598}, {2.2486696102342374, \
2.6273597595826383}}], 
  Line[{{2.047910388453575, 2.521960112821855}, {1.8426660862336905, \
2.3920893271166777}, {2.25740547882389, 2.281657041700859}, 
    {2.492594521176111, 2.3948140222646956}, {2.047910388453575, \
2.521960112821855}}], 
  Line[{{1.8426660862336905, 2.3920893271166777}, {1.641906864453027, \
2.239718051509763}, {2.0273558813281842, 2.14040166785146}, 
    {2.25740547882389, 2.281657041700859}, {1.8426660862336905, \
2.3920893271166777}}], 
  Line[{{1.641906864453027, 2.239718051509763}, {1.4544068644530275, \
2.069878202800488}, {1.8125000000000004, 1.9754350786598895}, 
    {2.0273558813281842, 2.14040166785146}, {1.641906864453027, \
2.239718051509763}}], 
  Line[{{1.4544068644530275, 2.069878202800488}, {1.2883607359585136, \
1.8914277190459876}, {1.6222280678462853, 1.7955424168801213}, 
    {1.8125000000000004, 1.9754350786598895}, {1.4544068644530275, \
2.069878202800488}}], 
  Line[{{1.2883607359585136, 1.8914277190459876}, {1.1510254915624212, \
1.7178957504272223}, {1.4648558813281838, 1.6149886737174104}, 
    {1.6222280678462853, 1.7955424168801213}, {1.2883607359585136, \
1.8914277190459876}}], 
  Line[{{1.1510254915624212, 1.7178957504272223}, {1.0484033404524797, \
1.5679671136605233}, {1.3472613601520744, 1.4545502220637496}, 
    {1.4648558813281838, 1.6149886737174104}, {1.1510254915624212, \
1.7178957504272223}}], 
  Line[{{1.0484033404524797, 1.5679671136605233}, {0.9849793630679078, \
1.4640759018681944}, {1.2745839491744688, 1.3407174947497695}, 
    {1.3472613601520744, 1.4545502220637496}, {1.0484033404524797, \
1.5679671136605233}}], 
  Line[{{0.9849793630679078, 1.4640759018681944}, {0.9635254915624212, \
1.4265847744427302}, {1.2499999999999996, 1.2990381056766582}, 
    {1.2745839491744688, 1.3407174947497695}, {0.9849793630679078, \
1.4640759018681944}}], 
  Line[{{0.9635254915624212, 1.4265847744427302}, {0.9849793630679072, \
1.4640759018681933}, {1.2745839491744682, 1.3407174947497684}, 
    {1.2499999999999996, 1.2990381056766582}, {0.9635254915624212, \
1.4265847744427302}}], 
  Line[{{0.9849793630679072, 1.4640759018681933}, {1.0484033404524786, \
1.5679671136605218}, {1.3472613601520729, 1.454550222063748}, 
    {1.2745839491744682, 1.3407174947497684}, {0.9849793630679072, \
1.4640759018681933}}], 
  Line[{{1.0484033404524786, 1.5679671136605218}, {1.151025491562421, \
1.7178957504272216}, {1.4648558813281836, 1.6149886737174093}, 
    {1.3472613601520729, 1.454550222063748}, {1.0484033404524786, \
1.5679671136605218}}], 
  Line[{{1.151025491562421, 1.7178957504272216}, {1.288360735958512, \
1.8914277190459854}, {1.622228067846283, 1.7955424168801193}, 
    {1.4648558813281836, 1.6149886737174093}, {1.151025491562421, \
1.7178957504272216}}], 
  Line[{{1.288360735958512, 1.8914277190459854}, {1.4544068644530252, \
2.069878202800486}, {1.8124999999999982, 1.975435078659887}, 
    {1.622228067846283, 1.7955424168801193}, {1.288360735958512, \
1.8914277190459854}}], 
  Line[{{1.4544068644530252, 2.069878202800486}, {1.6419068644530261, \
2.239718051509763}, {2.0273558813281833, 2.1404016678514592}, 
    {1.8124999999999982, 1.975435078659887}, {1.4544068644530252, \
2.069878202800486}}], 
  Line[{{1.6419068644530261, 2.239718051509763}, {1.8426660862336885, \
2.3920893271166768}, {2.257405478823888, 2.281657041700858}, 
    {2.0273558813281833, 2.1404016678514592}, {1.6419068644530261, \
2.239718051509763}}], 
  Line[{{1.8426660862336885, 2.3920893271166768}, {2.047910388453572, \
2.521960112821854}, {2.492594521176108, 2.3948140222646943}, 
    {2.257405478823888, 2.281657041700858}, {1.8426660862336885, \
2.3920893271166768}}], 
  Line[{{2.047910388453572, 2.521960112821854}, {2.248669610234237, \
2.6273597595826383}, {2.7226441186718153, 2.479055835144598}, 
    {2.492594521176108, 2.3948140222646943}, {2.047910388453572, \
2.521960112821854}}], 
  Line[{{2.248669610234237, 2.6273597595826383}, {2.436169610234236, \
2.7087103854853694}, {2.9374999999999987, 2.5364529859628777}, 
    {2.7226441186718153, 2.479055835144598}, {2.248669610234237, \
2.6273597595826383}}], 
  Line[{{2.436169610234236, 2.7087103854853694}, {2.602215738728749, \
2.7681817987334414}, {3.1277719321537134, 2.5712732770958864}, 
    {2.9374999999999987, 2.5364529859628777}, {2.436169610234236, \
2.7087103854853694}}], 
  Line[{{2.602215738728749, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {3.2851441186718153, 2.589176886629936}, 
    {3.1277719321537134, 2.5712732770958864}, {2.602215738728749, \
2.7681817987334414}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {3.4027386398479256, 2.5962550390555554}, 
    {3.2851441186718153, 2.589176886629936}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.842173134234784, 2.834803496770629}, {2.905597111619356, \
2.848777326663181}, {3.475416050825531, 2.5979598975817515}, 
    {3.4027386398479256, 2.5962550390555554}, {2.842173134234784, \
2.834803496770629}}], 
  Line[{{2.905597111619356, 2.848777326663181}, {2.9270509831248424, \
2.8531695488854605}, {3.4999999999999996, 2.598076211353316}, 
    {3.475416050825531, 2.5979598975817515}, {2.905597111619356, \
2.848777326663181}}], 
  Line[{{3.4999999999999996, 2.598076211353316}, {3.4754160508255305, \
2.5979598975817524}, {3.98003593774839, 2.235484296800204}, 
    {4.007391819076574, 2.229434476432184}, {3.4999999999999996, \
2.598076211353316}}], 
  Line[{{3.4754160508255305, 2.5979598975817524}, {3.402738639847926, \
2.5962550390555568}, {3.8991638770459622, 2.251331326578102}, 
    {3.98003593774839, 2.235484296800204}, {3.4754160508255305, \
2.5979598975817524}}], 
  Line[{{3.402738639847926, 2.5962550390555568}, {3.285144118671815, \
2.5891768866299363}, {3.768310134089188, 2.270646210820903}, 
    {3.8991638770459622, 2.251331326578102}, {3.402738639847926, \
2.5962550390555568}}], 
  Line[{{3.285144118671815, 2.5891768866299363}, {3.1277719321537143, \
2.5712732770958877}, {3.593193645351204, 2.284543605895154}, 
    {3.768310134089188, 2.270646210820903}, {3.285144118671815, \
2.5891768866299363}}], 
  Line[{{3.1277719321537143, 2.5712732770958877}, {2.9375, \
2.536452985962878}, {3.381467841692003, 2.283369148915068}, 
    {3.593193645351204, 2.284543605895154}, {3.1277719321537143, \
2.5712732770958877}}], 
  Line[{{2.9375, 2.536452985962878}, {2.7226441186718153, 2.479055835144598}, \
{3.1423861567046165, 2.2583039834915453}, 
    {3.381467841692003, 2.283369148915068}, {2.9375, 2.536452985962878}}], 
  Line[{{2.7226441186718153, 2.479055835144598}, {2.4925945211761102, \
2.394814022264695}, {2.886397607264205, 2.202570463435661}, 
    {3.1423861567046165, 2.2583039834915453}, {2.7226441186718153, \
2.479055835144598}}], 
  Line[{{2.4925945211761102, 2.394814022264695}, {2.2574054788238893, \
2.281657041700859}, {2.624690121350657, 2.112263515546569}, 
    {2.886397607264205, 2.202570463435661}, {2.4925945211761102, \
2.394814022264695}}], 
  Line[{{2.2574054788238893, 2.281657041700859}, {2.027355881328184, \
2.14040166785146}, {2.3687015719102447, 1.9869545564435858}, 
    {2.624690121350657, 2.112263515546569}, {2.2574054788238893, \
2.281657041700859}}], 
  Line[{{2.027355881328184, 2.14040166785146}, {1.8124999999999998, \
1.9754350786598887}, {2.129619886922859, 1.83026852905604}, 
    {2.3687015719102447, 1.9869545564435858}, {2.027355881328184, \
2.14040166785146}}], 
  Line[{{1.8124999999999998, 1.9754350786598887}, {1.6222280678462844, \
1.7955424168801202}, {1.9178940832636575, 1.6506863454327518}, 
    {2.129619886922859, 1.83026852905604}, {1.8124999999999998, \
1.9754350786598887}}], 
  Line[{{1.6222280678462844, 1.7955424168801202}, {1.4648558813281836, \
1.61498867371741}, {1.7427775945256727, 1.4628718195622261}, 
    {1.9178940832636575, 1.6506863454327518}, {1.6222280678462844, \
1.7955424168801202}}], 
  Line[{{1.4648558813281836, 1.61498867371741}, {1.3472613601520738, \
1.4545502220637494}, {1.6119238515688996, 1.2895708590441468}, 
    {1.7427775945256727, 1.4628718195622261}, {1.4648558813281836, \
1.61498867371741}}], 
  Line[{{1.3472613601520738, 1.4545502220637494}, {1.2745839491744684, \
1.340717494749769}, {1.5310517908664711, 1.162354288726182}, 
    {1.6119238515688996, 1.2895708590441468}, {1.3472613601520738, \
1.4545502220637494}}], 
  Line[{{1.2745839491744684, 1.340717494749769}, {1.2499999999999996, \
1.2990381056766582}, {1.503695909538287, 1.1147172382160917}, 
    {1.5310517908664711, 1.162354288726182}, {1.2745839491744684, \
1.340717494749769}}], 
  Line[{{1.2499999999999996, 1.2990381056766582}, {1.2745839491744684, \
1.3407174947497689}, {1.5310517908664711, 1.1623542887261817}, 
    {1.503695909538287, 1.1147172382160917}, {1.2499999999999996, \
1.2990381056766582}}], 
  Line[{{1.2745839491744684, 1.3407174947497689}, {1.3472613601520735, \
1.4545502220637487}, {1.6119238515688992, 1.2895708590441464}, 
    {1.5310517908664711, 1.1623542887261817}, {1.2745839491744684, \
1.3407174947497689}}], 
  Line[{{1.3472613601520735, 1.4545502220637487}, {1.4648558813281838, \
1.6149886737174097}, {1.742777594525673, 1.4628718195622257}, 
    {1.6119238515688992, 1.2895708590441464}, {1.3472613601520735, \
1.4545502220637487}}], 
  Line[{{1.4648558813281838, 1.6149886737174097}, {1.622228067846284, \
1.7955424168801195}, {1.9178940832636566, 1.6506863454327514}, 
    {1.742777594525673, 1.4628718195622257}, {1.4648558813281838, \
1.6149886737174097}}], 
  Line[{{1.622228067846284, 1.7955424168801195}, {1.8124999999999991, \
1.975435078659888}, {2.129619886922858, 1.8302685290560394}, 
    {1.9178940832636566, 1.6506863454327514}, {1.622228067846284, \
1.7955424168801195}}], 
  Line[{{1.8124999999999991, 1.975435078659888}, {2.0273558813281833, \
2.1404016678514597}, {2.368701571910244, 1.9869545564435858}, 
    {2.129619886922858, 1.8302685290560394}, {1.8124999999999991, \
1.975435078659888}}], 
  Line[{{2.0273558813281833, 2.1404016678514597}, {2.2574054788238884, \
2.2816570417008584}, {2.624690121350656, 2.112263515546568}, 
    {2.368701571910244, 1.9869545564435858}, {2.0273558813281833, \
2.1404016678514597}}], 
  Line[{{2.2574054788238884, 2.2816570417008584}, {2.492594521176109, \
2.394814022264695}, {2.8863976072642035, 2.202570463435661}, 
    {2.624690121350656, 2.112263515546568}, {2.2574054788238884, \
2.2816570417008584}}], 
  Line[{{2.492594521176109, 2.394814022264695}, {2.7226441186718153, \
2.479055835144598}, {3.1423861567046165, 2.258303983491545}, 
    {2.8863976072642035, 2.202570463435661}, {2.492594521176109, \
2.394814022264695}}], 
  Line[{{2.7226441186718153, 2.479055835144598}, {2.9374999999999987, \
2.536452985962878}, {3.3814678416920017, 2.2833691489150683}, 
    {3.1423861567046165, 2.258303983491545}, {2.7226441186718153, \
2.479055835144598}}], 
  Line[{{2.9374999999999987, 2.536452985962878}, {3.1277719321537147, \
2.5712732770958873}, {3.593193645351204, 2.284543605895154}, 
    {3.3814678416920017, 2.2833691489150683}, {2.9374999999999987, \
2.536452985962878}}], 
  Line[{{3.1277719321537147, 2.5712732770958873}, {3.2851441186718153, \
2.589176886629936}, {3.768310134089188, 2.270646210820903}, 
    {3.593193645351204, 2.284543605895154}, {3.1277719321537147, \
2.5712732770958873}}], 
  Line[{{3.2851441186718153, 2.589176886629936}, {3.4027386398479256, \
2.5962550390555554}, {3.899163877045962, 2.251331326578102}, 
    {3.768310134089188, 2.270646210820903}, {3.2851441186718153, \
2.589176886629936}}], 
  Line[{{3.4027386398479256, 2.5962550390555554}, {3.4754160508255305, \
2.5979598975817524}, {3.98003593774839, 2.235484296800204}, 
    {3.899163877045962, 2.251331326578102}, {3.4027386398479256, \
2.5962550390555554}}], 
  Line[{{3.4754160508255305, 2.5979598975817524}, {3.4999999999999996, \
2.598076211353316}, {4.007391819076574, 2.229434476432184}, 
    {3.98003593774839, 2.235484296800204}, {3.4754160508255305, \
2.5979598975817524}}], 
  Line[{{3.4999999999999996, 2.598076211353316}, {3.4754160508255314, \
2.5979598975817515}, {3.9800359377483905, 2.235484296800204}, 
    {4.007391819076574, 2.229434476432184}, {3.4999999999999996, \
2.598076211353316}}], 
  Line[{{3.4754160508255314, 2.5979598975817515}, {3.402738639847926, \
2.5962550390555568}, {3.8991638770459622, 2.251331326578102}, 
    {3.9800359377483905, 2.235484296800204}, {3.4754160508255314, \
2.5979598975817515}}], 
  Line[{{3.402738639847926, 2.5962550390555568}, {3.2851441186718158, \
2.589176886629936}, {3.7683101340891887, 2.2706462108209022}, 
    {3.8991638770459622, 2.251331326578102}, {3.402738639847926, \
2.5962550390555568}}], 
  Line[{{3.2851441186718158, 2.589176886629936}, {3.1277719321537156, \
2.5712732770958877}, {3.5931936453512052, 2.284543605895154}, 
    {3.7683101340891887, 2.2706462108209022}, {3.2851441186718158, \
2.589176886629936}}], 
  Line[{{3.1277719321537156, 2.5712732770958877}, {2.9375000000000004, \
2.5364529859628786}, {3.3814678416920034, 2.2833691489150687}, 
    {3.5931936453512052, 2.284543605895154}, {3.1277719321537156, \
2.5712732770958877}}], 
  Line[{{2.9375000000000004, 2.5364529859628786}, {2.722644118671816, \
2.479055835144598}, {3.1423861567046174, 2.2583039834915453}, 
    {3.3814678416920034, 2.2833691489150687}, {2.9375000000000004, \
2.5364529859628786}}], 
  Line[{{2.722644118671816, 2.479055835144598}, {2.492594521176111, \
2.3948140222646956}, {2.8863976072642057, 2.202570463435661}, 
    {3.1423861567046174, 2.2583039834915453}, {2.722644118671816, \
2.479055835144598}}], 
  Line[{{2.492594521176111, 2.3948140222646956}, {2.25740547882389, \
2.281657041700859}, {2.6246901213506577, 2.112263515546569}, 
    {2.8863976072642057, 2.202570463435661}, {2.492594521176111, \
2.3948140222646956}}], 
  Line[{{2.25740547882389, 2.281657041700859}, {2.0273558813281842, \
2.14040166785146}, {2.368701571910245, 1.9869545564435862}, 
    {2.6246901213506577, 2.112263515546569}, {2.25740547882389, \
2.281657041700859}}], 
  Line[{{2.0273558813281842, 2.14040166785146}, {1.8125000000000004, \
1.9754350786598895}, {2.12961988692286, 1.8302685290560408}, 
    {2.368701571910245, 1.9869545564435862}, {2.0273558813281842, \
2.14040166785146}}], 
  Line[{{1.8125000000000004, 1.9754350786598895}, {1.6222280678462853, \
1.7955424168801213}, {1.9178940832636582, 1.6506863454327532}, 
    {2.12961988692286, 1.8302685290560408}, {1.8125000000000004, \
1.9754350786598895}}], 
  Line[{{1.6222280678462853, 1.7955424168801213}, {1.4648558813281838, \
1.6149886737174104}, {1.7427775945256732, 1.4628718195622263}, 
    {1.9178940832636582, 1.6506863454327532}, {1.6222280678462853, \
1.7955424168801213}}], 
  Line[{{1.4648558813281838, 1.6149886737174104}, {1.3472613601520744, \
1.4545502220637496}, {1.6119238515689, 1.2895708590441473}, 
    {1.7427775945256732, 1.4628718195622263}, {1.4648558813281838, \
1.6149886737174104}}], 
  Line[{{1.3472613601520744, 1.4545502220637496}, {1.2745839491744688, \
1.3407174947497695}, {1.5310517908664716, 1.1623542887261822}, 
    {1.6119238515689, 1.2895708590441473}, {1.3472613601520744, \
1.4545502220637496}}], 
  Line[{{1.2745839491744688, 1.3407174947497695}, {1.2499999999999996, \
1.2990381056766582}, {1.503695909538287, 1.1147172382160917}, 
    {1.5310517908664716, 1.1623542887261822}, {1.2745839491744688, \
1.3407174947497695}}], 
  Line[{{1.2499999999999996, 1.2990381056766582}, {1.2745839491744682, \
1.3407174947497684}, {1.531051790866471, 1.162354288726181}, 
    {1.503695909538287, 1.1147172382160917}, {1.2499999999999996, \
1.2990381056766582}}], 
  Line[{{1.2745839491744682, 1.3407174947497684}, {1.3472613601520729, \
1.454550222063748}, {1.6119238515688985, 1.2895708590441455}, 
    {1.531051790866471, 1.162354288726181}, {1.2745839491744682, \
1.3407174947497684}}], 
  Line[{{1.3472613601520729, 1.454550222063748}, {1.4648558813281836, \
1.6149886737174093}, {1.7427775945256727, 1.4628718195622255}, 
    {1.6119238515688985, 1.2895708590441455}, {1.3472613601520729, \
1.454550222063748}}], 
  Line[{{1.4648558813281836, 1.6149886737174093}, {1.622228067846283, \
1.7955424168801193}, {1.917894083263656, 1.6506863454327507}, 
    {1.7427775945256727, 1.4628718195622255}, {1.4648558813281836, \
1.6149886737174093}}], 
  Line[{{1.622228067846283, 1.7955424168801193}, {1.8124999999999982, \
1.975435078659887}, {2.129619886922857, 1.830268529056039}, 
    {1.917894083263656, 1.6506863454327507}, {1.622228067846283, \
1.7955424168801193}}], 
  Line[{{1.8124999999999982, 1.975435078659887}, {2.0273558813281833, \
2.1404016678514592}, {2.368701571910244, 1.9869545564435853}, 
    {2.129619886922857, 1.830268529056039}, {1.8124999999999982, \
1.975435078659887}}], 
  Line[{{2.0273558813281833, 2.1404016678514592}, {2.257405478823888, \
2.281657041700858}, {2.6246901213506555, 2.1122635155465685}, 
    {2.368701571910244, 1.9869545564435853}, {2.0273558813281833, \
2.1404016678514592}}], 
  Line[{{2.257405478823888, 2.281657041700858}, {2.492594521176108, \
2.3948140222646943}, {2.886397607264202, 2.2025704634356607}, 
    {2.6246901213506555, 2.1122635155465685}, {2.257405478823888, \
2.281657041700858}}], 
  Line[{{2.492594521176108, 2.3948140222646943}, {2.7226441186718153, \
2.479055835144598}, {3.1423861567046165, 2.2583039834915453}, 
    {2.886397607264202, 2.2025704634356607}, {2.492594521176108, \
2.3948140222646943}}], 
  Line[{{2.7226441186718153, 2.479055835144598}, {2.9374999999999987, \
2.5364529859628777}, {3.381467841692001, 2.283369148915069}, 
    {3.1423861567046165, 2.2583039834915453}, {2.7226441186718153, \
2.479055835144598}}], 
  Line[{{2.9374999999999987, 2.5364529859628777}, {3.1277719321537134, \
2.5712732770958864}, {3.5931936453512026, 2.284543605895154}, 
    {3.381467841692001, 2.283369148915069}, {2.9374999999999987, \
2.5364529859628777}}], 
  Line[{{3.1277719321537134, 2.5712732770958864}, {3.2851441186718153, \
2.589176886629936}, {3.7683101340891882, 2.2706462108209022}, 
    {3.5931936453512026, 2.284543605895154}, {3.1277719321537134, \
2.5712732770958864}}], 
  Line[{{3.2851441186718153, 2.589176886629936}, {3.4027386398479256, \
2.5962550390555554}, {3.899163877045962, 2.251331326578102}, 
    {3.7683101340891882, 2.2706462108209022}, {3.2851441186718153, \
2.589176886629936}}], 
  Line[{{3.4027386398479256, 2.5962550390555554}, {3.475416050825531, \
2.5979598975817515}, {3.98003593774839, 2.235484296800204}, 
    {3.899163877045962, 2.251331326578102}, {3.4027386398479256, \
2.5962550390555554}}], 
  Line[{{3.475416050825531, 2.5979598975817515}, {3.4999999999999996, \
2.598076211353316}, {4.007391819076574, 2.229434476432184}, 
    {3.98003593774839, 2.235484296800204}, {3.475416050825531, \
2.5979598975817515}}], 
  Line[{{4.007391819076574, 2.229434476432184}, {3.98003593774839, \
2.235484296800204}, {4.397402461894532, 1.7786275248098211}, 
    {4.4270509831248415, 1.763355756877421}, {4.007391819076574, \
2.229434476432184}}], 
  Line[{{3.98003593774839, 2.235484296800204}, {3.8991638770459622, \
2.251331326578102}, {4.309752680850759, 1.8202053857959228}, 
    {4.397402461894532, 1.7786275248098211}, {3.98003593774839, \
2.235484296800204}}], 
  Line[{{3.8991638770459622, 2.251331326578102}, {3.768310134089188, \
2.270646210820903}, {4.167932356015447, 1.8768892930626264}, 
    {4.309752680850759, 1.8202053857959228}, {3.8991638770459622, \
2.251331326578102}}], 
  Line[{{3.768310134089188, 2.270646210820903}, {3.593193645351204, \
2.284543605895154}, {3.9781397161133216, 1.9339672857886054}, 
    {4.167932356015447, 1.8768892930626264}, {3.768310134089188, \
2.270646210820903}}], 
  Line[{{3.593193645351204, 2.284543605895154}, {3.381467841692003, \
2.283369148915068}, {3.748669610234237, 1.976615915035449}, 
    {3.9781397161133216, 1.9339672857886054}, {3.593193645351204, \
2.284543605895154}}], 
  Line[{{3.381467841692003, 2.283369148915068}, {3.1423861567046165, \
2.2583039834915453}, {3.489550983124842, 1.99216913656241}, 
    {3.748669610234237, 1.976615915035449}, {3.381467841692003, \
2.283369148915068}}], 
  Line[{{3.1423861567046165, 2.2583039834915453}, {2.886397607264205, \
2.202570463435661}, {3.2121085621789436, 1.9712852585698504}, 
    {3.489550983124842, 1.99216913656241}, {3.1423861567046165, \
2.2583039834915453}}], 
  Line[{{2.886397607264205, 2.202570463435661}, {2.624690121350657, \
2.112263515546569}, {2.928467912508319, 1.9084543807995193}, 
    {3.2121085621789436, 1.9712852585698504}, {2.886397607264205, \
2.202570463435661}}], 
  Line[{{2.624690121350657, 2.112263515546569}, {2.3687015719102447, \
1.9869545564435858}, {2.6510254915624207, 1.802245636601361}, 
    {2.928467912508319, 1.9084543807995193}, {2.624690121350657, \
2.112263515546569}}], 
  Line[{{2.3687015719102447, 1.9869545564435858}, {2.129619886922859, \
1.83026852905604}, {2.391906864453026, 1.65558951844325}, 
    {2.6510254915624207, 1.802245636601361}, {2.3687015719102447, \
1.9869545564435858}}], 
  Line[{{2.129619886922859, 1.83026852905604}, {1.9178940832636575, \
1.6506863454327518}, {2.162436758573941, 1.4764049667388985}, 
    {2.391906864453026, 1.65558951844325}, {2.129619886922859, \
1.83026852905604}}], 
  Line[{{1.9178940832636575, 1.6506863454327518}, {1.7427775945256727, \
1.4628718195622261}, {1.9726441186718153, 1.2790742990138144}, 
    {2.162436758573941, 1.4764049667388985}, {1.9178940832636575, \
1.6506863454327518}}], 
  Line[{{1.7427775945256727, 1.4628718195622261}, {1.6119238515688996, \
1.2895708590441468}, {1.8308237938365037, 1.0875191232355925}, 
    {1.9726441186718153, 1.2790742990138144}, {1.7427775945256727, \
1.4628718195622261}}], 
  Line[{{1.6119238515688996, 1.2895708590441468}, {1.5310517908664711, \
1.162354288726182}, {1.7431740127927302, 0.9393665425693404}, 
    {1.8308237938365037, 1.0875191232355925}, {1.6119238515688996, \
1.2895708590441468}}], 
  Line[{{1.5310517908664711, 1.162354288726182}, {1.503695909538287, \
1.1147172382160917}, {1.713525491562421, 0.8816778784387097}, 
    {1.7431740127927302, 0.9393665425693404}, {1.5310517908664711, \
1.162354288726182}}], 
  Line[{{1.503695909538287, 1.1147172382160917}, {1.5310517908664711, \
1.1623542887261817}, {1.7431740127927302, 0.9393665425693399}, 
    {1.713525491562421, 0.8816778784387097}, {1.503695909538287, \
1.1147172382160917}}], 
  Line[{{1.5310517908664711, 1.1623542887261817}, {1.6119238515688992, \
1.2895708590441464}, {1.8308237938365037, 1.0875191232355916}, 
    {1.7431740127927302, 0.9393665425693399}, {1.5310517908664711, \
1.1623542887261817}}], 
  Line[{{1.6119238515688992, 1.2895708590441464}, {1.742777594525673, \
1.4628718195622257}, {1.9726441186718155, 1.2790742990138138}, 
    {1.8308237938365037, 1.0875191232355916}, {1.6119238515688992, \
1.2895708590441464}}], 
  Line[{{1.742777594525673, 1.4628718195622257}, {1.9178940832636566, \
1.6506863454327514}, {2.16243675857394, 1.4764049667388985}, 
    {1.9726441186718155, 1.2790742990138138}, {1.742777594525673, \
1.4628718195622257}}], 
  Line[{{1.9178940832636566, 1.6506863454327514}, {2.129619886922858, \
1.8302685290560394}, {2.3919068644530252, 1.6555895184432492}, 
    {2.16243675857394, 1.4764049667388985}, {1.9178940832636566, \
1.6506863454327514}}], 
  Line[{{2.129619886922858, 1.8302685290560394}, {2.368701571910244, \
1.9869545564435858}, {2.6510254915624203, 1.8022456366013613}, 
    {2.3919068644530252, 1.6555895184432492}, {2.129619886922858, \
1.8302685290560394}}], 
  Line[{{2.368701571910244, 1.9869545564435858}, {2.624690121350656, \
2.112263515546568}, {2.928467912508318, 1.9084543807995193}, 
    {2.6510254915624203, 1.8022456366013613}, {2.368701571910244, \
1.9869545564435858}}], 
  Line[{{2.624690121350656, 2.112263515546568}, {2.8863976072642035, \
2.202570463435661}, {3.2121085621789423, 1.97128525856985}, 
    {2.928467912508318, 1.9084543807995193}, {2.624690121350656, \
2.112263515546568}}], 
  Line[{{2.8863976072642035, 2.202570463435661}, {3.1423861567046165, \
2.258303983491545}, {3.4895509831248415, 1.99216913656241}, 
    {3.2121085621789423, 1.97128525856985}, {2.8863976072642035, \
2.202570463435661}}], 
  Line[{{3.1423861567046165, 2.258303983491545}, {3.3814678416920017, \
2.2833691489150683}, {3.748669610234236, 1.976615915035449}, 
    {3.4895509831248415, 1.99216913656241}, {3.1423861567046165, \
2.258303983491545}}], 
  Line[{{3.3814678416920017, 2.2833691489150683}, {3.593193645351204, \
2.284543605895154}, {3.9781397161133216, 1.9339672857886054}, 
    {3.748669610234236, 1.976615915035449}, {3.3814678416920017, \
2.2833691489150683}}], 
  Line[{{3.593193645351204, 2.284543605895154}, {3.768310134089188, \
2.270646210820903}, {4.167932356015447, 1.8768892930626264}, 
    {3.9781397161133216, 1.9339672857886054}, {3.593193645351204, \
2.284543605895154}}], 
  Line[{{3.768310134089188, 2.270646210820903}, {3.899163877045962, \
2.251331326578102}, {4.3097526808507585, 1.8202053857959228}, 
    {4.167932356015447, 1.8768892930626264}, {3.768310134089188, \
2.270646210820903}}], 
  Line[{{3.899163877045962, 2.251331326578102}, {3.98003593774839, \
2.235484296800204}, {4.397402461894532, 1.7786275248098211}, 
    {4.3097526808507585, 1.8202053857959228}, {3.899163877045962, \
2.251331326578102}}], 
  Line[{{3.98003593774839, 2.235484296800204}, {4.007391819076574, \
2.229434476432184}, {4.4270509831248415, 1.763355756877421}, 
    {4.397402461894532, 1.7786275248098211}, {3.98003593774839, \
2.235484296800204}}], 
  Line[{{4.007391819076574, 2.229434476432184}, {3.9800359377483905, \
2.235484296800204}, {4.397402461894533, 1.7786275248098191}, 
    {4.4270509831248415, 1.763355756877421}, {4.007391819076574, \
2.229434476432184}}], 
  Line[{{3.9800359377483905, 2.235484296800204}, {3.8991638770459622, \
2.251331326578102}, {4.309752680850759, 1.8202053857959217}, 
    {4.397402461894533, 1.7786275248098191}, {3.9800359377483905, \
2.235484296800204}}], 
  Line[{{3.8991638770459622, 2.251331326578102}, {3.7683101340891887, \
2.2706462108209022}, {4.167932356015448, 1.8768892930626255}, 
    {4.309752680850759, 1.8202053857959217}, {3.8991638770459622, \
2.251331326578102}}], 
  Line[{{3.7683101340891887, 2.2706462108209022}, {3.5931936453512052, \
2.284543605895154}, {3.9781397161133234, 1.9339672857886037}, 
    {4.167932356015448, 1.8768892930626255}, {3.7683101340891887, \
2.2706462108209022}}], 
  Line[{{3.5931936453512052, 2.284543605895154}, {3.3814678416920034, \
2.2833691489150687}, {3.7486696102342374, 1.976615915035449}, 
    {3.9781397161133234, 1.9339672857886037}, {3.5931936453512052, \
2.284543605895154}}], 
  Line[{{3.3814678416920034, 2.2833691489150687}, {3.1423861567046174, \
2.2583039834915453}, {3.489550983124843, 1.9921691365624095}, 
    {3.7486696102342374, 1.976615915035449}, {3.3814678416920034, \
2.2833691489150687}}], 
  Line[{{3.1423861567046174, 2.2583039834915453}, {2.8863976072642057, \
2.202570463435661}, {3.212108562178945, 1.9712852585698495}, 
    {3.489550983124843, 1.9921691365624095}, {3.1423861567046174, \
2.2583039834915453}}], 
  Line[{{2.8863976072642057, 2.202570463435661}, {2.6246901213506577, \
2.112263515546569}, {2.9284679125083204, 1.9084543807995193}, 
    {3.212108562178945, 1.9712852585698495}, {2.8863976072642057, \
2.202570463435661}}], 
  Line[{{2.6246901213506577, 2.112263515546569}, {2.368701571910245, \
1.9869545564435862}, {2.6510254915624216, 1.8022456366013608}, 
    {2.9284679125083204, 1.9084543807995193}, {2.6246901213506577, \
2.112263515546569}}], 
  Line[{{2.368701571910245, 1.9869545564435862}, {2.12961988692286, \
1.8302685290560408}, {2.3919068644530275, 1.6555895184432503}, 
    {2.6510254915624216, 1.8022456366013608}, {2.368701571910245, \
1.9869545564435862}}], 
  Line[{{2.12961988692286, 1.8302685290560408}, {1.9178940832636582, \
1.6506863454327532}, {2.162436758573942, 1.4764049667388996}, 
    {2.3919068644530275, 1.6555895184432503}, {2.12961988692286, \
1.8302685290560408}}], 
  Line[{{1.9178940832636582, 1.6506863454327532}, {1.7427775945256732, \
1.4628718195622263}, {1.9726441186718158, 1.2790742990138144}, 
    {2.162436758573942, 1.4764049667388996}, {1.9178940832636582, \
1.6506863454327532}}], 
  Line[{{1.7427775945256732, 1.4628718195622263}, {1.6119238515689, \
1.2895708590441473}, {1.8308237938365044, 1.0875191232355932}, 
    {1.9726441186718158, 1.2790742990138144}, {1.7427775945256732, \
1.4628718195622263}}], 
  Line[{{1.6119238515689, 1.2895708590441473}, {1.5310517908664716, \
1.1623542887261822}, {1.7431740127927307, 0.9393665425693408}, 
    {1.8308237938365044, 1.0875191232355932}, {1.6119238515689, \
1.2895708590441473}}], 
  Line[{{1.5310517908664716, 1.1623542887261822}, {1.503695909538287, \
1.1147172382160917}, {1.713525491562421, 0.8816778784387097}, 
    {1.7431740127927307, 0.9393665425693408}, {1.5310517908664716, \
1.1623542887261822}}], 
  Line[{{1.503695909538287, 1.1147172382160917}, {1.531051790866471, \
1.162354288726181}, {1.74317401279273, 0.9393665425693394}, 
    {1.713525491562421, 0.8816778784387097}, {1.503695909538287, \
1.1147172382160917}}], 
  Line[{{1.531051790866471, 1.162354288726181}, {1.6119238515688985, \
1.2895708590441455}, {1.8308237938365028, 1.087519123235591}, 
    {1.74317401279273, 0.9393665425693394}, {1.531051790866471, \
1.162354288726181}}], 
  Line[{{1.6119238515688985, 1.2895708590441455}, {1.7427775945256727, \
1.4628718195622255}, {1.9726441186718153, 1.2790742990138133}, 
    {1.8308237938365028, 1.087519123235591}, {1.6119238515688985, \
1.2895708590441455}}], 
  Line[{{1.7427775945256727, 1.4628718195622255}, {1.917894083263656, \
1.6506863454327507}, {2.1624367585739397, 1.4764049667388974}, 
    {1.9726441186718153, 1.2790742990138133}, {1.7427775945256727, \
1.4628718195622255}}], 
  Line[{{1.917894083263656, 1.6506863454327507}, {2.129619886922857, \
1.830268529056039}, {2.3919068644530244, 1.655589518443248}, 
    {2.1624367585739397, 1.4764049667388974}, {1.917894083263656, \
1.6506863454327507}}], 
  Line[{{2.129619886922857, 1.830268529056039}, {2.368701571910244, \
1.9869545564435853}, {2.6510254915624203, 1.8022456366013608}, 
    {2.3919068644530244, 1.655589518443248}, {2.129619886922857, \
1.830268529056039}}], 
  Line[{{2.368701571910244, 1.9869545564435853}, {2.6246901213506555, \
2.1122635155465685}, {2.9284679125083177, 1.9084543807995193}, 
    {2.6510254915624203, 1.8022456366013608}, {2.368701571910244, \
1.9869545564435853}}], 
  Line[{{2.6246901213506555, 2.1122635155465685}, {2.886397607264202, \
2.2025704634356607}, {3.212108562178941, 1.971285258569849}, 
    {2.9284679125083177, 1.9084543807995193}, {2.6246901213506555, \
2.1122635155465685}}], 
  Line[{{2.886397607264202, 2.2025704634356607}, {3.1423861567046165, \
2.2583039834915453}, {3.489550983124842, 1.992169136562409}, 
    {3.212108562178941, 1.971285258569849}, {2.886397607264202, \
2.2025704634356607}}], 
  Line[{{3.1423861567046165, 2.2583039834915453}, {3.381467841692001, \
2.283369148915069}, {3.748669610234235, 1.9766159150354499}, 
    {3.489550983124842, 1.992169136562409}, {3.1423861567046165, \
2.2583039834915453}}], 
  Line[{{3.381467841692001, 2.283369148915069}, {3.5931936453512026, \
2.284543605895154}, {3.9781397161133203, 1.9339672857886054}, 
    {3.748669610234235, 1.9766159150354499}, {3.381467841692001, \
2.283369148915069}}], 
  Line[{{3.5931936453512026, 2.284543605895154}, {3.7683101340891882, \
2.2706462108209022}, {4.167932356015447, 1.8768892930626275}, 
    {3.9781397161133203, 1.9339672857886054}, {3.5931936453512026, \
2.284543605895154}}], 
  Line[{{3.7683101340891882, 2.2706462108209022}, {3.899163877045962, \
2.251331326578102}, {4.309752680850759, 1.8202053857959208}, 
    {4.167932356015447, 1.8768892930626275}, {3.7683101340891882, \
2.2706462108209022}}], 
  Line[{{3.899163877045962, 2.251331326578102}, {3.98003593774839, \
2.235484296800204}, {4.397402461894532, 1.7786275248098211}, 
    {4.309752680850759, 1.8202053857959208}, {3.899163877045962, \
2.251331326578102}}], 
  Line[{{3.98003593774839, 2.235484296800204}, {4.007391819076574, \
2.229434476432184}, {4.4270509831248415, 1.763355756877421}, 
    {4.397402461894532, 1.7786275248098211}, {3.98003593774839, \
2.235484296800204}}], 
  Line[{{4.4270509831248415, 1.763355756877421}, {4.397402461894532, \
1.7786275248098211}, {4.709274703411987, 1.251297555701461}, 
    {4.740636372927802, 1.220209929227404}, {4.4270509831248415, \
1.763355756877421}}], 
  Line[{{4.397402461894532, 1.7786275248098211}, {4.309752680850759, \
1.8202053857959228}, {4.616560350312374, 1.334684931108052}, 
    {4.709274703411987, 1.251297555701461}, {4.397402461894532, \
1.7786275248098211}}], 
  Line[{{4.309752680850759, 1.8202053857959228}, {4.167932356015447, \
1.8768892930626264}, {4.466545375752238, 1.4470248504530114}, 
    {4.616560350312374, 1.334684931108052}, {4.309752680850759, \
1.8202053857959228}}], 
  Line[{{4.167932356015447, 1.8768892930626264}, {3.9781397161133216, \
1.9339672857886054}, {4.265786153971575, 1.5625819810819581}, 
    {4.466545375752238, 1.4470248504530114}, {4.167932356015447, \
1.8768892930626264}}], 
  Line[{{3.9781397161133216, 1.9339672857886054}, {3.748669610234237, \
1.976615915035449}, {4.023056826311827, 1.6596693760099304}, 
    {4.265786153971575, 1.5625819810819581}, {3.9781397161133216, \
1.9339672857886054}}], 
  Line[{{3.748669610234237, 1.976615915035449}, {3.489550983124842, \
1.99216913656241}, {3.748965829136264, 1.7222389198769967}, 
    {4.023056826311827, 1.6596693760099304}, {3.748669610234237, \
1.976615915035449}}], 
  Line[{{3.489550983124842, 1.99216913656241}, {3.2121085621789436, \
1.9712852585698504}, {3.455492254255987, 1.7395717696563653}, 
    {3.748965829136264, 1.7222389198769967}, {3.489550983124842, \
1.99216913656241}}], 
  Line[{{3.2121085621789436, 1.9712852585698504}, {2.928467912508319, \
1.9084543807995193}, {3.1554623051357167, 1.705691841463223}, 
    {3.455492254255987, 1.7395717696563653}, {3.2121085621789436, \
1.9712852585698504}}], 
  Line[{{2.928467912508319, 1.9084543807995193}, {2.6510254915624207, \
1.802245636601361}, {2.8619887302554394, 1.6189603147994474}, 
    {3.1554623051357167, 1.705691841463223}, {2.928467912508319, \
1.9084543807995193}}], 
  Line[{{2.6510254915624207, 1.802245636601361}, {2.391906864453026, \
1.65558951844325}, {2.5878977330798767, 1.4819447816621802}, 
    {2.8619887302554394, 1.6189603147994474}, {2.6510254915624207, \
1.802245636601361}}], 
  Line[{{2.391906864453026, 1.65558951844325}, {2.162436758573941, \
1.4764049667388985}, {2.345168405420128, 1.3017122836390165}, 
    {2.5878977330798767, 1.4819447816621802}, {2.391906864453026, \
1.65558951844325}}], 
  Line[{{2.162436758573941, 1.4764049667388985}, {1.9726441186718153, \
1.2790742990138144}, {2.144409183639464, 1.0910840571723013}, 
    {2.345168405420128, 1.3017122836390165}, {2.162436758573941, \
1.4764049667388985}}], 
  Line[{{1.9726441186718153, 1.2790742990138144}, {1.8308237938365037, \
1.0875191232355925}, {1.9943942090793294, 0.8724918816600732}, 
    {2.144409183639464, 1.0910840571723013}, {1.9726441186718153, \
1.2790742990138144}}], 
  Line[{{1.8308237938365037, 1.0875191232355925}, {1.7431740127927302, \
0.9393665425693404}, {1.9016798559797152, 0.6880869119781089}, 
    {1.9943942090793294, 0.8724918816600732}, {1.8308237938365037, \
1.0875191232355925}}], 
  Line[{{1.7431740127927302, 0.9393665425693404}, {1.713525491562421, \
0.8816778784387097}, {1.8703181864639011, 0.6101049646137006}, 
    {1.9016798559797152, 0.6880869119781089}, {1.7431740127927302, \
0.9393665425693404}}], 
  Line[{{1.713525491562421, 0.8816778784387097}, {1.7431740127927302, \
0.9393665425693399}, {1.9016798559797154, 0.6880869119781076}, 
    {1.8703181864639011, 0.6101049646137006}, {1.713525491562421, \
0.8816778784387097}}], 
  Line[{{1.7431740127927302, 0.9393665425693399}, {1.8308237938365037, \
1.0875191232355916}, {1.9943942090793292, 0.8724918816600722}, 
    {1.9016798559797154, 0.6880869119781076}, {1.7431740127927302, \
0.9393665425693399}}], 
  Line[{{1.8308237938365037, 1.0875191232355916}, {1.9726441186718155, \
1.2790742990138138}, {2.144409183639464, 1.0910840571723004}, 
    {1.9943942090793292, 0.8724918816600722}, {1.8308237938365037, \
1.0875191232355916}}], 
  Line[{{1.9726441186718155, 1.2790742990138138}, {2.16243675857394, \
1.4764049667388985}, {2.345168405420127, 1.3017122836390158}, 
    {2.144409183639464, 1.0910840571723004}, {1.9726441186718155, \
1.2790742990138138}}], 
  Line[{{2.16243675857394, 1.4764049667388985}, {2.3919068644530252, \
1.6555895184432492}, {2.5878977330798754, 1.48194478166218}, 
    {2.345168405420127, 1.3017122836390158}, {2.16243675857394, \
1.4764049667388985}}], 
  Line[{{2.3919068644530252, 1.6555895184432492}, {2.6510254915624203, \
1.8022456366013613}, {2.8619887302554385, 1.6189603147994478}, 
    {2.5878977330798754, 1.48194478166218}, {2.3919068644530252, \
1.6555895184432492}}], 
  Line[{{2.6510254915624203, 1.8022456366013613}, {2.928467912508318, \
1.9084543807995193}, {3.155462305135716, 1.7056918414632214}, 
    {2.8619887302554385, 1.6189603147994478}, {2.6510254915624203, \
1.8022456366013613}}], 
  Line[{{2.928467912508318, 1.9084543807995193}, {3.2121085621789423, \
1.97128525856985}, {3.4554922542559856, 1.7395717696563653}, 
    {3.155462305135716, 1.7056918414632214}, {2.928467912508318, \
1.9084543807995193}}], 
  Line[{{3.2121085621789423, 1.97128525856985}, {3.4895509831248415, \
1.99216913656241}, {3.7489658291362637, 1.7222389198769967}, 
    {3.4554922542559856, 1.7395717696563653}, {3.2121085621789423, \
1.97128525856985}}], 
  Line[{{3.4895509831248415, 1.99216913656241}, {3.748669610234236, \
1.976615915035449}, {4.023056826311826, 1.6596693760099326}, 
    {3.7489658291362637, 1.7222389198769967}, {3.4895509831248415, \
1.99216913656241}}], 
  Line[{{3.748669610234236, 1.976615915035449}, {3.9781397161133216, \
1.9339672857886054}, {4.265786153971575, 1.5625819810819581}, 
    {4.023056826311826, 1.6596693760099326}, {3.748669610234236, \
1.976615915035449}}], 
  Line[{{3.9781397161133216, 1.9339672857886054}, {4.167932356015447, \
1.8768892930626264}, {4.466545375752238, 1.4470248504530114}, 
    {4.265786153971575, 1.5625819810819581}, {3.9781397161133216, \
1.9339672857886054}}], 
  Line[{{4.167932356015447, 1.8768892930626264}, {4.3097526808507585, \
1.8202053857959228}, {4.616560350312374, 1.3346849311080506}, 
    {4.466545375752238, 1.4470248504530114}, {4.167932356015447, \
1.8768892930626264}}], 
  Line[{{4.3097526808507585, 1.8202053857959228}, {4.397402461894532, \
1.7786275248098211}, {4.709274703411987, 1.251297555701461}, 
    {4.616560350312374, 1.3346849311080506}, {4.3097526808507585, \
1.8202053857959228}}], 
  Line[{{4.397402461894532, 1.7786275248098211}, {4.4270509831248415, \
1.763355756877421}, {4.740636372927802, 1.220209929227404}, 
    {4.709274703411987, 1.251297555701461}, {4.397402461894532, \
1.7786275248098211}}], 
  Line[{{4.4270509831248415, 1.763355756877421}, {4.397402461894533, \
1.7786275248098191}, {4.709274703411988, 1.251297555701461}, 
    {4.740636372927802, 1.220209929227404}, {4.4270509831248415, \
1.763355756877421}}], 
  Line[{{4.397402461894533, 1.7786275248098191}, {4.309752680850759, \
1.8202053857959217}, {4.616560350312374, 1.334684931108052}, 
    {4.709274703411988, 1.251297555701461}, {4.397402461894533, \
1.7786275248098191}}], 
  Line[{{4.309752680850759, 1.8202053857959217}, {4.167932356015448, \
1.8768892930626255}, {4.46654537575224, 1.447024850453009}, 
    {4.616560350312374, 1.334684931108052}, {4.309752680850759, \
1.8202053857959217}}], 
  Line[{{4.167932356015448, 1.8768892930626255}, {3.9781397161133234, \
1.9339672857886037}, {4.265786153971577, 1.562581981081957}, 
    {4.46654537575224, 1.447024850453009}, {4.167932356015448, \
1.8768892930626255}}], 
  Line[{{3.9781397161133234, 1.9339672857886037}, {3.7486696102342374, \
1.976615915035449}, {4.023056826311828, 1.6596693760099304}, 
    {4.265786153971577, 1.562581981081957}, {3.9781397161133234, \
1.9339672857886037}}], 
  Line[{{3.7486696102342374, 1.976615915035449}, {3.489550983124843, \
1.9921691365624095}, {3.7489658291362646, 1.7222389198769967}, 
    {4.023056826311828, 1.6596693760099304}, {3.7486696102342374, \
1.976615915035449}}], 
  Line[{{3.489550983124843, 1.9921691365624095}, {3.212108562178945, \
1.9712852585698495}, {3.4554922542559883, 1.7395717696563648}, 
    {3.7489658291362646, 1.7222389198769967}, {3.489550983124843, \
1.9921691365624095}}], 
  Line[{{3.212108562178945, 1.9712852585698495}, {2.9284679125083204, \
1.9084543807995193}, {3.1554623051357176, 1.705691841463223}, 
    {3.4554922542559883, 1.7395717696563648}, {3.212108562178945, \
1.9712852585698495}}], 
  Line[{{2.9284679125083204, 1.9084543807995193}, {2.6510254915624216, \
1.8022456366013608}, {2.86198873025544, 1.6189603147994478}, 
    {3.1554623051357176, 1.705691841463223}, {2.9284679125083204, \
1.9084543807995193}}], 
  Line[{{2.6510254915624216, 1.8022456366013608}, {2.3919068644530275, \
1.6555895184432503}, {2.5878977330798776, 1.481944781662181}, 
    {2.86198873025544, 1.6189603147994478}, {2.6510254915624216, \
1.8022456366013608}}], 
  Line[{{2.3919068644530275, 1.6555895184432503}, {2.162436758573942, \
1.4764049667388996}, {2.3451684054201287, 1.3017122836390178}, 
    {2.5878977330798776, 1.481944781662181}, {2.3919068644530275, \
1.6555895184432503}}], 
  Line[{{2.162436758573942, 1.4764049667388996}, {1.9726441186718158, \
1.2790742990138144}, {2.1444091836394645, 1.0910840571723013}, 
    {2.3451684054201287, 1.3017122836390178}, {2.162436758573942, \
1.4764049667388996}}], 
  Line[{{1.9726441186718158, 1.2790742990138144}, {1.8308237938365044, \
1.0875191232355932}, {1.99439420907933, 0.872491881660074}, 
    {2.1444091836394645, 1.0910840571723013}, {1.9726441186718158, \
1.2790742990138144}}], 
  Line[{{1.8308237938365044, 1.0875191232355932}, {1.7431740127927307, \
0.9393665425693408}, {1.901679855979716, 0.6880869119781089}, 
    {1.99439420907933, 0.872491881660074}, {1.8308237938365044, \
1.0875191232355932}}], 
  Line[{{1.7431740127927307, 0.9393665425693408}, {1.713525491562421, \
0.8816778784387097}, {1.8703181864639011, 0.6101049646137006}, 
    {1.901679855979716, 0.6880869119781089}, {1.7431740127927307, \
0.9393665425693408}}], 
  Line[{{1.713525491562421, 0.8816778784387097}, {1.74317401279273, \
0.9393665425693394}, {1.901679855979715, 0.6880869119781076}, 
    {1.8703181864639011, 0.6101049646137006}, {1.713525491562421, \
0.8816778784387097}}], 
  Line[{{1.74317401279273, 0.9393665425693394}, {1.8308237938365028, \
1.087519123235591}, {1.9943942090793283, 0.8724918816600712}, 
    {1.901679855979715, 0.6880869119781076}, {1.74317401279273, \
0.9393665425693394}}], 
  Line[{{1.8308237938365028, 1.087519123235591}, {1.9726441186718153, \
1.2790742990138133}, {2.1444091836394636, 1.0910840571723008}, 
    {1.9943942090793283, 0.8724918816600712}, {1.8308237938365028, \
1.087519123235591}}], 
  Line[{{1.9726441186718153, 1.2790742990138133}, {2.1624367585739397, \
1.4764049667388974}, {2.345168405420126, 1.3017122836390158}, 
    {2.1444091836394636, 1.0910840571723008}, {1.9726441186718153, \
1.2790742990138133}}], 
  Line[{{2.1624367585739397, 1.4764049667388974}, {2.3919068644530244, \
1.655589518443248}, {2.5878977330798745, 1.4819447816621785}, 
    {2.345168405420126, 1.3017122836390158}, {2.1624367585739397, \
1.4764049667388974}}], 
  Line[{{2.3919068644530244, 1.655589518443248}, {2.6510254915624203, \
1.8022456366013608}, {2.8619887302554385, 1.6189603147994474}, 
    {2.5878977330798745, 1.4819447816621785}, {2.3919068644530244, \
1.655589518443248}}], 
  Line[{{2.6510254915624203, 1.8022456366013608}, {2.9284679125083177, \
1.9084543807995193}, {3.155462305135715, 1.7056918414632225}, 
    {2.8619887302554385, 1.6189603147994474}, {2.6510254915624203, \
1.8022456366013608}}], 
  Line[{{2.9284679125083177, 1.9084543807995193}, {3.212108562178941, \
1.971285258569849}, {3.455492254255984, 1.7395717696563653}, 
    {3.155462305135715, 1.7056918414632225}, {2.9284679125083177, \
1.9084543807995193}}], 
  Line[{{3.212108562178941, 1.971285258569849}, {3.489550983124842, \
1.992169136562409}, {3.748965829136264, 1.7222389198769967}, 
    {3.455492254255984, 1.7395717696563653}, {3.212108562178941, \
1.971285258569849}}], 
  Line[{{3.489550983124842, 1.992169136562409}, {3.748669610234235, \
1.9766159150354499}, {4.023056826311826, 1.6596693760099326}, 
    {3.748965829136264, 1.7222389198769967}, {3.489550983124842, \
1.992169136562409}}], 
  Line[{{3.748669610234235, 1.9766159150354499}, {3.9781397161133203, \
1.9339672857886054}, {4.265786153971574, 1.5625819810819614}, 
    {4.023056826311826, 1.6596693760099326}, {3.748669610234235, \
1.9766159150354499}}], 
  Line[{{3.9781397161133203, 1.9339672857886054}, {4.167932356015447, \
1.8768892930626275}, {4.466545375752238, 1.4470248504530128}, 
    {4.265786153971574, 1.5625819810819614}, {3.9781397161133203, \
1.9339672857886054}}], 
  Line[{{4.167932356015447, 1.8768892930626275}, {4.309752680850759, \
1.8202053857959208}, {4.616560350312374, 1.3346849311080506}, 
    {4.466545375752238, 1.4470248504530128}, {4.167932356015447, \
1.8768892930626275}}], 
  Line[{{4.309752680850759, 1.8202053857959208}, {4.397402461894532, \
1.7786275248098211}, {4.709274703411988, 1.251297555701458}, 
    {4.616560350312374, 1.3346849311080506}, {4.309752680850759, \
1.8202053857959208}}], 
  Line[{{4.397402461894532, 1.7786275248098211}, {4.4270509831248415, \
1.763355756877421}, {4.740636372927802, 1.220209929227404}, 
    {4.709274703411988, 1.251297555701458}, {4.397402461894532, \
1.7786275248098211}}], 
  Line[{{4.740636372927802, 1.220209929227404}, {4.709274703411987, \
1.251297555701461}, {4.902022348817391, 0.693545187289426}, 
    {4.934442802201416, 0.6237350724532809}, {4.740636372927802, \
1.220209929227404}}], 
  Line[{{4.709274703411987, 1.251297555701461}, {4.616560350312374, \
1.334684931108052}, {4.806177918048795, 0.8605642566348376}, 
    {4.902022348817391, 0.693545187289426}, {4.709274703411987, \
1.251297555701461}}], 
  Line[{{4.616560350312374, 1.334684931108052}, {4.466545375752238, \
1.4470248504530114}, {4.651098371432819, 1.0590770192391419}, 
    {4.806177918048795, 0.8605642566348376}, {4.616560350312374, \
1.334684931108052}}], 
  Line[{{4.466545375752238, 1.4470248504530114}, {4.265786153971575, \
1.5625819810819581}, {4.44356142931081, 1.2475429541754062}, 
    {4.651098371432819, 1.0590770192391419}, {4.466545375752238, \
1.4470248504530114}}], 
  Line[{{4.265786153971575, 1.5625819810819581}, {4.023056826311827, \
1.6596693760099304}, {4.19263745192624, 1.4024710170213415}, 
    {4.44356142931081, 1.2475429541754062}, {4.265786153971575, \
1.5625819810819581}}], 
  Line[{{4.023056826311827, 1.6596693760099304}, {3.748965829136264, \
1.7222389198769967}, {3.9092930211576427, 1.5096856680207968}, 
    {4.19263745192624, 1.4024710170213415}, {4.023056826311827, \
1.6596693760099304}}], 
  Line[{{3.748965829136264, 1.7222389198769967}, {3.455492254255987, \
1.7395717696563653}, {3.605911648267038, 1.560594218929799}, 
    {3.9092930211576427, 1.5096856680207968}, {3.748965829136264, \
1.7222389198769967}}], 
  Line[{{3.455492254255987, 1.7395717696563653}, {3.1554623051357167, \
1.705691841463223}, {3.2957525550350866, 1.5507915961279441}, 
    {3.605911648267038, 1.560594218929799}, {3.455492254255987, \
1.7395717696563653}}], 
  Line[{{3.1554623051357167, 1.705691841463223}, {2.8619887302554394, \
1.6189603147994474}, {2.9923711821444816, 1.4795217391705875}, 
    {3.2957525550350866, 1.5507915961279441}, {3.1554623051357167, \
1.705691841463223}}], 
  Line[{{2.8619887302554394, 1.6189603147994474}, {2.5878977330798767, \
1.4819447816621802}, {2.7090267513758857, 1.3494565251821808}, 
    {2.9923711821444816, 1.4795217391705875}, {2.8619887302554394, \
1.6189603147994474}}], 
  Line[{{2.5878977330798767, 1.4819447816621802}, {2.345168405420128, \
1.3017122836390165}, {2.458102773991314, 1.1666712321091814}, 
    {2.7090267513758857, 1.3494565251821808}, {2.5878977330798767, \
1.4819447816621802}}], 
  Line[{{2.345168405420128, 1.3017122836390165}, {2.144409183639464, \
1.0910840571723013}, {2.2505658318693045, 0.9410557119019621}, 
    {2.458102773991314, 1.1666712321091814}, {2.345168405420128, \
1.3017122836390165}}], 
  Line[{{2.144409183639464, 1.0910840571723013}, {1.9943942090793294, \
0.8724918816600732}, {2.0954862852533296, 0.688485888369732}, 
    {2.2505658318693045, 0.9410557119019621}, {2.144409183639464, \
1.0910840571723013}}], 
  Line[{{1.9943942090793294, 0.8724918816600732}, {1.9016798559797152, \
0.6880869119781089}, {1.999641854484733, 0.442263528432697}, 
    {2.0954862852533296, 0.688485888369732}, {1.9943942090793294, \
0.8724918816600732}}], 
  Line[{{1.9016798559797152, 0.6880869119781089}, {1.8703181864639011, \
0.6101049646137006}, {1.9672214011007083, 0.311867536226639}, 
    {1.999641854484733, 0.442263528432697}, {1.9016798559797152, \
0.6880869119781089}}], 
  Line[{{1.8703181864639011, 0.6101049646137006}, {1.9016798559797154, \
0.6880869119781076}, {1.999641854484733, 0.442263528432696}, 
    {1.9672214011007083, 0.311867536226639}, {1.8703181864639011, \
0.6101049646137006}}], 
  Line[{{1.9016798559797154, 0.6880869119781076}, {1.9943942090793292, \
0.8724918816600722}, {2.095486285253329, 0.6884858883697308}, 
    {1.999641854484733, 0.442263528432696}, {1.9016798559797154, \
0.6880869119781076}}], 
  Line[{{1.9943942090793292, 0.8724918816600722}, {2.144409183639464, \
1.0910840571723004}, {2.250565831869305, 0.9410557119019607}, 
    {2.095486285253329, 0.6884858883697308}, {1.9943942090793292, \
0.8724918816600722}}], 
  Line[{{2.144409183639464, 1.0910840571723004}, {2.345168405420127, \
1.3017122836390158}, {2.458102773991313, 1.166671232109181}, 
    {2.250565831869305, 0.9410557119019607}, {2.144409183639464, \
1.0910840571723004}}], 
  Line[{{2.345168405420127, 1.3017122836390158}, {2.5878977330798754, \
1.48194478166218}, {2.7090267513758843, 1.3494565251821808}, 
    {2.458102773991313, 1.166671232109181}, {2.345168405420127, \
1.3017122836390158}}], 
  Line[{{2.5878977330798754, 1.48194478166218}, {2.8619887302554385, \
1.6189603147994478}, {2.992371182144481, 1.479521739170588}, 
    {2.7090267513758843, 1.3494565251821808}, {2.5878977330798754, \
1.48194478166218}}], 
  Line[{{2.8619887302554385, 1.6189603147994478}, {3.155462305135716, \
1.7056918414632214}, {3.2957525550350857, 1.5507915961279435}, 
    {2.992371182144481, 1.479521739170588}, {2.8619887302554385, \
1.6189603147994478}}], 
  Line[{{3.155462305135716, 1.7056918414632214}, {3.4554922542559856, \
1.7395717696563653}, {3.6059116482670364, 1.5605942189298}, 
    {3.2957525550350857, 1.5507915961279435}, {3.155462305135716, \
1.7056918414632214}}], 
  Line[{{3.4554922542559856, 1.7395717696563653}, {3.7489658291362637, \
1.7222389198769967}, {3.9092930211576427, 1.5096856680207968}, 
    {3.6059116482670364, 1.5605942189298}, {3.4554922542559856, \
1.7395717696563653}}], 
  Line[{{3.7489658291362637, 1.7222389198769967}, {4.023056826311826, \
1.6596693760099326}, {4.192637451926238, 1.4024710170213415}, 
    {3.9092930211576427, 1.5096856680207968}, {3.7489658291362637, \
1.7222389198769967}}], 
  Line[{{4.023056826311826, 1.6596693760099326}, {4.265786153971575, \
1.5625819810819581}, {4.443561429310811, 1.247542954175402}, 
    {4.192637451926238, 1.4024710170213415}, {4.023056826311826, \
1.6596693760099326}}], 
  Line[{{4.265786153971575, 1.5625819810819581}, {4.466545375752238, \
1.4470248504530114}, {4.651098371432819, 1.0590770192391419}, 
    {4.443561429310811, 1.247542954175402}, {4.265786153971575, \
1.5625819810819581}}], 
  Line[{{4.466545375752238, 1.4470248504530114}, {4.616560350312374, \
1.3346849311080506}, {4.806177918048795, 0.8605642566348355}, 
    {4.651098371432819, 1.0590770192391419}, {4.466545375752238, \
1.4470248504530114}}], 
  Line[{{4.616560350312374, 1.3346849311080506}, {4.709274703411987, \
1.251297555701461}, {4.902022348817391, 0.693545187289426}, 
    {4.806177918048795, 0.8605642566348355}, {4.616560350312374, \
1.3346849311080506}}], 
  Line[{{4.709274703411987, 1.251297555701461}, {4.740636372927802, \
1.220209929227404}, {4.934442802201416, 0.6237350724532809}, 
    {4.902022348817391, 0.693545187289426}, {4.709274703411987, \
1.251297555701461}}], 
  Line[{{4.740636372927802, 1.220209929227404}, {4.709274703411988, \
1.251297555701461}, {4.9020223488173915, 0.6935451872894235}, 
    {4.934442802201416, 0.6237350724532809}, {4.740636372927802, \
1.220209929227404}}], 
  Line[{{4.709274703411988, 1.251297555701461}, {4.616560350312374, \
1.334684931108052}, {4.806177918048795, 0.8605642566348376}, 
    {4.9020223488173915, 0.6935451872894235}, {4.709274703411988, \
1.251297555701461}}], 
  Line[{{4.616560350312374, 1.334684931108052}, {4.46654537575224, \
1.447024850453009}, {4.651098371432821, 1.0590770192391368}, 
    {4.806177918048795, 0.8605642566348376}, {4.616560350312374, \
1.334684931108052}}], 
  Line[{{4.46654537575224, 1.447024850453009}, {4.265786153971577, \
1.562581981081957}, {4.443561429310812, 1.247542954175402}, 
    {4.651098371432821, 1.0590770192391368}, {4.46654537575224, \
1.447024850453009}}], 
  Line[{{4.265786153971577, 1.562581981081957}, {4.023056826311828, \
1.6596693760099304}, {4.19263745192624, 1.4024710170213426}, 
    {4.443561429310812, 1.247542954175402}, {4.265786153971577, \
1.562581981081957}}], 
  Line[{{4.023056826311828, 1.6596693760099304}, {3.7489658291362646, \
1.7222389198769967}, {3.9092930211576435, 1.5096856680207968}, 
    {4.19263745192624, 1.4024710170213426}, {4.023056826311828, \
1.6596693760099304}}], 
  Line[{{3.7489658291362646, 1.7222389198769967}, {3.4554922542559883, \
1.7395717696563648}, {3.605911648267039, 1.560594218929799}, 
    {3.9092930211576435, 1.5096856680207968}, {3.7489658291362646, \
1.7222389198769967}}], 
  Line[{{3.4554922542559883, 1.7395717696563648}, {3.1554623051357176, \
1.705691841463223}, {3.2957525550350875, 1.5507915961279446}, 
    {3.605911648267039, 1.560594218929799}, {3.4554922542559883, \
1.7395717696563648}}], 
  Line[{{3.1554623051357176, 1.705691841463223}, {2.86198873025544, \
1.6189603147994478}, {2.992371182144482, 1.4795217391705875}, 
    {3.2957525550350875, 1.5507915961279446}, {3.1554623051357176, \
1.705691841463223}}], 
  Line[{{2.86198873025544, 1.6189603147994478}, {2.5878977330798776, \
1.481944781662181}, {2.7090267513758866, 1.3494565251821808}, 
    {2.992371182144482, 1.4795217391705875}, {2.86198873025544, \
1.6189603147994478}}], 
  Line[{{2.5878977330798776, 1.481944781662181}, {2.3451684054201287, \
1.3017122836390178}, {2.458102773991315, 1.1666712321091826}, 
    {2.7090267513758866, 1.3494565251821808}, {2.5878977330798776, \
1.481944781662181}}], 
  Line[{{2.3451684054201287, 1.3017122836390178}, {2.1444091836394645, \
1.0910840571723013}, {2.250565831869305, 0.9410557119019621}, 
    {2.458102773991315, 1.1666712321091826}, {2.3451684054201287, \
1.3017122836390178}}], 
  Line[{{2.1444091836394645, 1.0910840571723013}, {1.99439420907933, \
0.872491881660074}, {2.09548628525333, 0.6884858883697327}, 
    {2.250565831869305, 0.9410557119019621}, {2.1444091836394645, \
1.0910840571723013}}], 
  Line[{{1.99439420907933, 0.872491881660074}, {1.901679855979716, \
0.6880869119781089}, {1.9996418544847336, 0.442263528432698}, 
    {2.09548628525333, 0.6884858883697327}, {1.99439420907933, \
0.872491881660074}}], 
  Line[{{1.901679855979716, 0.6880869119781089}, {1.8703181864639011, \
0.6101049646137006}, {1.9672214011007083, 0.311867536226639}, 
    {1.9996418544847336, 0.442263528432698}, {1.901679855979716, \
0.6880869119781089}}], 
  Line[{{1.8703181864639011, 0.6101049646137006}, {1.901679855979715, \
0.6880869119781076}, {1.9996418544847328, 0.442263528432695}, 
    {1.9672214011007083, 0.311867536226639}, {1.8703181864639011, \
0.6101049646137006}}], 
  Line[{{1.901679855979715, 0.6880869119781076}, {1.9943942090793283, \
0.8724918816600712}, {2.0954862852533283, 0.6884858883697301}, 
    {1.9996418544847328, 0.442263528432695}, {1.901679855979715, \
0.6880869119781076}}], 
  Line[{{1.9943942090793283, 0.8724918816600712}, {2.1444091836394636, \
1.0910840571723008}, {2.2505658318693045, 0.9410557119019607}, 
    {2.0954862852533283, 0.6884858883697301}, {1.9943942090793283, \
0.8724918816600712}}], 
  Line[{{2.1444091836394636, 1.0910840571723008}, {2.345168405420126, \
1.3017122836390158}, {2.458102773991312, 1.1666712321091806}, 
    {2.2505658318693045, 0.9410557119019607}, {2.1444091836394636, \
1.0910840571723008}}], 
  Line[{{2.345168405420126, 1.3017122836390158}, {2.5878977330798745, \
1.4819447816621785}, {2.709026751375883, 1.3494565251821795}, 
    {2.458102773991312, 1.1666712321091806}, {2.345168405420126, \
1.3017122836390158}}], 
  Line[{{2.5878977330798745, 1.4819447816621785}, {2.8619887302554385, \
1.6189603147994474}, {2.992371182144481, 1.4795217391705868}, 
    {2.709026751375883, 1.3494565251821795}, {2.5878977330798745, \
1.4819447816621785}}], 
  Line[{{2.8619887302554385, 1.6189603147994474}, {3.155462305135715, \
1.7056918414632225}, {3.295752555035085, 1.5507915961279446}, 
    {2.992371182144481, 1.4795217391705868}, {2.8619887302554385, \
1.6189603147994474}}], 
  Line[{{3.155462305135715, 1.7056918414632225}, {3.455492254255984, \
1.7395717696563653}, {3.605911648267035, 1.560594218929799}, 
    {3.295752555035085, 1.5507915961279446}, {3.155462305135715, \
1.7056918414632225}}], 
  Line[{{3.455492254255984, 1.7395717696563653}, {3.748965829136264, \
1.7222389198769967}, {3.9092930211576427, 1.5096856680207968}, 
    {3.605911648267035, 1.560594218929799}, {3.455492254255984, \
1.7395717696563653}}], 
  Line[{{3.748965829136264, 1.7222389198769967}, {4.023056826311826, \
1.6596693760099326}, {4.192637451926238, 1.4024710170213415}, 
    {3.9092930211576427, 1.5096856680207968}, {3.748965829136264, \
1.7222389198769967}}], 
  Line[{{4.023056826311826, 1.6596693760099326}, {4.265786153971574, \
1.5625819810819614}, {4.443561429310809, 1.2475429541754033}, 
    {4.192637451926238, 1.4024710170213415}, {4.023056826311826, \
1.6596693760099326}}], 
  Line[{{4.265786153971574, 1.5625819810819614}, {4.466545375752238, \
1.4470248504530128}, {4.651098371432819, 1.0590770192391419}, 
    {4.443561429310809, 1.2475429541754033}, {4.265786153971574, \
1.5625819810819614}}], 
  Line[{{4.466545375752238, 1.4470248504530128}, {4.616560350312374, \
1.3346849311080506}, {4.806177918048795, 0.8605642566348355}, 
    {4.651098371432819, 1.0590770192391419}, {4.466545375752238, \
1.4470248504530128}}], 
  Line[{{4.616560350312374, 1.3346849311080506}, {4.709274703411988, \
1.251297555701458}, {4.9020223488173915, 0.6935451872894184}, 
    {4.806177918048795, 0.8605642566348355}, {4.616560350312374, \
1.3346849311080506}}], 
  Line[{{4.709274703411988, 1.251297555701458}, {4.740636372927802, \
1.220209929227404}, {4.934442802201416, 0.6237350724532809}, 
    {4.9020223488173915, 0.6935451872894184}, {4.709274703411988, \
1.251297555701458}}], 
  Line[{{4.934442802201416, 0.6237350724532809}, {4.902022348817391, \
0.693545187289426}, {4.967221401100708, 0.3118675362266461}, {5., 0.}, 
    {4.934442802201416, 0.6237350724532809}}], Line[{{4.902022348817391, \
0.693545187289426}, {4.806177918048795, 0.8605642566348376}, 
    {4.870318186463902, 0.6101049646136962}, {4.967221401100708, \
0.3118675362266461}, {4.902022348817391, 0.693545187289426}}], 
  Line[{{4.806177918048795, 0.8605642566348376}, {4.651098371432819, \
1.0590770192391419}, {4.713525491562421, 0.8816778784387095}, 
    {4.870318186463902, 0.6101049646136962}, {4.806177918048795, \
0.8605642566348376}}], 
  Line[{{4.651098371432819, 1.0590770192391419}, {4.44356142931081, \
1.2475429541754062}, {4.503695909538287, 1.1147172382160924}, 
    {4.713525491562421, 0.8816778784387095}, {4.651098371432819, \
1.0590770192391419}}], 
  Line[{{4.44356142931081, 1.2475429541754062}, {4.19263745192624, \
1.4024710170213415}, {4.25, 1.2990381056766593}, 
    {4.503695909538287, 1.1147172382160924}, {4.44356142931081, \
1.2475429541754062}}], 
  Line[{{4.19263745192624, 1.4024710170213415}, {3.9092930211576427, \
1.5096856680207968}, {3.963525491562421, 1.4265847744427318}, 
    {4.25, 1.2990381056766593}, {4.19263745192624, 1.4024710170213415}}], 
  Line[{{3.9092930211576427, 1.5096856680207968}, {3.605911648267038, \
1.560594218929799}, {3.6567926949014806, 1.49178284305241}, 
    {3.963525491562421, 1.4265847744427318}, {3.9092930211576427, \
1.5096856680207968}}], 
  Line[{{3.605911648267038, 1.560594218929799}, {3.2957525550350866, \
1.5507915961279441}, {3.3432073050985194, 1.4917828430524107}, 
    {3.6567926949014806, 1.49178284305241}, {3.605911648267038, \
1.560594218929799}}], 
  Line[{{3.2957525550350866, 1.5507915961279441}, {2.9923711821444816, \
1.4795217391705875}, {3.036474508437579, 1.4265847744427305}, 
    {3.3432073050985194, 1.4917828430524107}, {3.2957525550350866, \
1.5507915961279441}}], 
  Line[{{2.9923711821444816, 1.4795217391705875}, {2.7090267513758857, \
1.3494565251821808}, {2.75, 1.2990381056766587}, 
    {3.036474508437579, 1.4265847744427305}, {2.9923711821444816, \
1.4795217391705875}}], 
  Line[{{2.7090267513758857, 1.3494565251821808}, {2.458102773991314, \
1.1666712321091814}, {2.496304090461713, 1.1147172382160917}, 
    {2.75, 1.2990381056766587}, {2.7090267513758857, 1.3494565251821808}}], 
  Line[{{2.458102773991314, 1.1666712321091814}, {2.2505658318693045, \
0.9410557119019621}, {2.286474508437579, 0.88167787843871}, 
    {2.496304090461713, 1.1147172382160917}, {2.458102773991314, \
1.1666712321091814}}], 
  Line[{{2.2505658318693045, 0.9410557119019621}, {2.0954862852533296, \
0.688485888369732}, {2.1296818135360986, 0.6101049646137013}, 
    {2.286474508437579, 0.88167787843871}, {2.2505658318693045, \
0.9410557119019621}}], 
  Line[{{2.0954862852533296, 0.688485888369732}, {1.999641854484733, \
0.442263528432697}, {2.0327785988992915, 0.31186753622664043}, 
    {2.1296818135360986, 0.6101049646137013}, {2.0954862852533296, \
0.688485888369732}}], 
  Line[{{1.999641854484733, 0.442263528432697}, {1.9672214011007083, \
0.311867536226639}, {2., 0.}, {2.0327785988992915, 0.31186753622664043}, 
    {1.999641854484733, 0.442263528432697}}], Line[{{1.9672214011007083, \
0.311867536226639}, {1.999641854484733, 0.442263528432696}, 
    {2.0327785988992915, 0.311867536226639}, {2., 0.}, {1.9672214011007083, \
0.311867536226639}}], 
  Line[{{1.999641854484733, 0.442263528432696}, {2.095486285253329, \
0.6884858883697308}, {2.1296818135360986, 0.6101049646136991}, 
    {2.0327785988992915, 0.311867536226639}, {1.999641854484733, \
0.442263528432696}}], 
  Line[{{2.095486285253329, 0.6884858883697308}, {2.250565831869305, \
0.9410557119019607}, {2.286474508437579, 0.8816778784387095}, 
    {2.1296818135360986, 0.6101049646136991}, {2.095486285253329, \
0.6884858883697308}}], 
  Line[{{2.250565831869305, 0.9410557119019607}, {2.458102773991313, \
1.166671232109181}, {2.496304090461712, 1.1147172382160913}, 
    {2.286474508437579, 0.8816778784387095}, {2.250565831869305, \
0.9410557119019607}}], 
  Line[{{2.458102773991313, 1.166671232109181}, {2.7090267513758843, \
1.3494565251821808}, {2.749999999999999, 1.299038105676658}, 
    {2.496304090461712, 1.1147172382160913}, {2.458102773991313, \
1.166671232109181}}], 
  Line[{{2.7090267513758843, 1.3494565251821808}, {2.992371182144481, \
1.479521739170588}, {3.0364745084375784, 1.4265847744427305}, 
    {2.749999999999999, 1.299038105676658}, {2.7090267513758843, \
1.3494565251821808}}], 
  Line[{{2.992371182144481, 1.479521739170588}, {3.2957525550350857, \
1.5507915961279435}, {3.3432073050985185, 1.4917828430524107}, 
    {3.0364745084375784, 1.4265847744427305}, {2.992371182144481, \
1.479521739170588}}], 
  Line[{{3.2957525550350857, 1.5507915961279435}, {3.6059116482670364, \
1.5605942189298}, {3.656792694901479, 1.4917828430524112}, 
    {3.3432073050985185, 1.4917828430524107}, {3.2957525550350857, \
1.5507915961279435}}], 
  Line[{{3.6059116482670364, 1.5605942189298}, {3.9092930211576427, \
1.5096856680207968}, {3.963525491562421, 1.4265847744427305}, 
    {3.656792694901479, 1.4917828430524112}, {3.6059116482670364, \
1.5605942189298}}], 
  Line[{{3.9092930211576427, 1.5096856680207968}, {4.192637451926238, \
1.4024710170213415}, {4.249999999999999, 1.299038105676658}, 
    {3.963525491562421, 1.4265847744427305}, {3.9092930211576427, \
1.5096856680207968}}], 
  Line[{{4.192637451926238, 1.4024710170213415}, {4.443561429310811, \
1.247542954175402}, {4.503695909538286, 1.1147172382160955}, 
    {4.249999999999999, 1.299038105676658}, {4.192637451926238, \
1.4024710170213415}}], 
  Line[{{4.443561429310811, 1.247542954175402}, {4.651098371432819, \
1.0590770192391419}, {4.713525491562421, 0.8816778784387115}, 
    {4.503695909538286, 1.1147172382160955}, {4.443561429310811, \
1.247542954175402}}], 
  Line[{{4.651098371432819, 1.0590770192391419}, {4.806177918048795, \
0.8605642566348355}, {4.870318186463901, 0.6101049646136991}, 
    {4.713525491562421, 0.8816778784387115}, {4.651098371432819, \
1.0590770192391419}}], 
  Line[{{4.806177918048795, 0.8605642566348355}, {4.902022348817391, \
0.693545187289426}, {4.967221401100708, 0.3118675362266461}, 
    {4.870318186463901, 0.6101049646136991}, {4.806177918048795, \
0.8605642566348355}}], 
  Line[{{4.902022348817391, 0.693545187289426}, {4.934442802201416, \
0.6237350724532809}, {5., 0.}, {4.967221401100708, 0.3118675362266461}, 
    {4.902022348817391, 0.693545187289426}}], Line[{{4.934442802201416, \
0.6237350724532809}, {4.9020223488173915, 0.6935451872894235}, 
    {4.967221401100709, 0.31186753622662905}, {5., 0.}, {4.934442802201416, \
0.6237350724532809}}], 
  Line[{{4.9020223488173915, 0.6935451872894235}, {4.806177918048795, \
0.8605642566348376}, {4.870318186463902, 0.6101049646136962}, 
    {4.967221401100709, 0.31186753622662905}, {4.9020223488173915, \
0.6935451872894235}}], 
  Line[{{4.806177918048795, 0.8605642566348376}, {4.651098371432821, \
1.0590770192391368}, {4.713525491562422, 0.8816778784387075}, 
    {4.870318186463902, 0.6101049646136962}, {4.806177918048795, \
0.8605642566348376}}], 
  Line[{{4.651098371432821, 1.0590770192391368}, {4.443561429310812, \
1.247542954175402}, {4.503695909538288, 1.1147172382160924}, 
    {4.713525491562422, 0.8816778784387075}, {4.651098371432821, \
1.0590770192391368}}], 
  Line[{{4.443561429310812, 1.247542954175402}, {4.19263745192624, \
1.4024710170213426}, {4.250000000000001, 1.299038105676658}, 
    {4.503695909538288, 1.1147172382160924}, {4.443561429310812, \
1.247542954175402}}], 
  Line[{{4.19263745192624, 1.4024710170213426}, {3.9092930211576435, \
1.5096856680207968}, {3.9635254915624225, 1.426584774442728}, 
    {4.250000000000001, 1.299038105676658}, {4.19263745192624, \
1.4024710170213426}}], 
  Line[{{3.9092930211576435, 1.5096856680207968}, {3.605911648267039, \
1.560594218929799}, {3.656792694901482, 1.491782843052409}, 
    {3.9635254915624225, 1.426584774442728}, {3.9092930211576435, \
1.5096856680207968}}], 
  Line[{{3.605911648267039, 1.560594218929799}, {3.2957525550350875, \
1.5507915961279446}, {3.3432073050985207, 1.49178284305241}, 
    {3.656792694901482, 1.491782843052409}, {3.605911648267039, \
1.560594218929799}}], 
  Line[{{3.2957525550350875, 1.5507915961279446}, {2.992371182144482, \
1.4795217391705875}, {3.0364745084375793, 1.4265847744427311}, 
    {3.3432073050985207, 1.49178284305241}, {3.2957525550350875, \
1.5507915961279446}}], 
  Line[{{2.992371182144482, 1.4795217391705875}, {2.7090267513758866, \
1.3494565251821808}, {2.7500000000000013, 1.2990381056766587}, 
    {3.0364745084375793, 1.4265847744427311}, {2.992371182144482, \
1.4795217391705875}}], 
  Line[{{2.7090267513758866, 1.3494565251821808}, {2.458102773991315, \
1.1666712321091826}, {2.496304090461714, 1.1147172382160933}, 
    {2.7500000000000013, 1.2990381056766587}, {2.7090267513758866, \
1.3494565251821808}}], 
  Line[{{2.458102773991315, 1.1666712321091826}, {2.250565831869305, \
0.9410557119019621}, {2.2864745084375793, 0.88167787843871}, 
    {2.496304090461714, 1.1147172382160933}, {2.458102773991315, \
1.1666712321091826}}], 
  Line[{{2.250565831869305, 0.9410557119019621}, {2.09548628525333, \
0.6884858883697327}, {2.1296818135360995, 0.6101049646137006}, 
    {2.2864745084375793, 0.88167787843871}, {2.250565831869305, \
0.9410557119019621}}], 
  Line[{{2.09548628525333, 0.6884858883697327}, {1.9996418544847336, \
0.442263528432698}, {2.0327785988992924, 0.31186753622664043}, 
    {2.1296818135360995, 0.6101049646137006}, {2.09548628525333, \
0.6884858883697327}}], 
  Line[{{1.9996418544847336, 0.442263528432698}, {1.9672214011007083, \
0.311867536226639}, {2., 0.}, {2.0327785988992924, 0.31186753622664043}, 
    {1.9996418544847336, 0.442263528432698}}], Line[{{1.9672214011007083, \
0.311867536226639}, {1.9996418544847328, 0.442263528432695}, 
    {2.0327785988992915, 0.31186753622663616}, {2., 0.}, {1.9672214011007083, \
0.311867536226639}}], 
  Line[{{1.9996418544847328, 0.442263528432695}, {2.0954862852533283, \
0.6884858883697301}, {2.1296818135360978, 0.6101049646136977}, 
    {2.0327785988992915, 0.31186753622663616}, {1.9996418544847328, \
0.442263528432695}}], 
  Line[{{2.0954862852533283, 0.6884858883697301}, {2.2505658318693045, \
0.9410557119019607}, {2.2864745084375784, 0.8816778784387095}, 
    {2.1296818135360978, 0.6101049646136977}, {2.0954862852533283, \
0.6884858883697301}}], 
  Line[{{2.2505658318693045, 0.9410557119019607}, {2.458102773991312, \
1.1666712321091806}, {2.4963040904617113, 1.1147172382160908}, 
    {2.2864745084375784, 0.8816778784387095}, {2.2505658318693045, \
0.9410557119019607}}], 
  Line[{{2.458102773991312, 1.1666712321091806}, {2.709026751375883, \
1.3494565251821795}, {2.7499999999999982, 1.2990381056766562}, 
    {2.4963040904617113, 1.1147172382160908}, {2.458102773991312, \
1.1666712321091806}}], 
  Line[{{2.709026751375883, 1.3494565251821795}, {2.992371182144481, \
1.4795217391705868}, {3.0364745084375784, 1.4265847744427305}, 
    {2.7499999999999982, 1.2990381056766562}, {2.709026751375883, \
1.3494565251821795}}], 
  Line[{{2.992371182144481, 1.4795217391705868}, {3.295752555035085, \
1.5507915961279446}, {3.3432073050985176, 1.4917828430524107}, 
    {3.0364745084375784, 1.4265847744427305}, {2.992371182144481, \
1.4795217391705868}}], 
  Line[{{3.295752555035085, 1.5507915961279446}, {3.605911648267035, \
1.560594218929799}, {3.6567926949014775, 1.49178284305241}, 
    {3.3432073050985176, 1.4917828430524107}, {3.295752555035085, \
1.5507915961279446}}], 
  Line[{{3.605911648267035, 1.560594218929799}, {3.9092930211576427, \
1.5096856680207968}, {3.963525491562421, 1.4265847744427305}, 
    {3.6567926949014775, 1.49178284305241}, {3.605911648267035, \
1.560594218929799}}], 
  Line[{{3.9092930211576427, 1.5096856680207968}, {4.192637451926238, \
1.4024710170213415}, {4.249999999999998, 1.2990381056766607}, 
    {3.963525491562421, 1.4265847744427305}, {3.9092930211576427, \
1.5096856680207968}}], 
  Line[{{4.192637451926238, 1.4024710170213415}, {4.443561429310809, \
1.2475429541754033}, {4.503695909538285, 1.114717238216094}, 
    {4.249999999999998, 1.2990381056766607}, {4.192637451926238, \
1.4024710170213415}}], 
  Line[{{4.443561429310809, 1.2475429541754033}, {4.651098371432819, \
1.0590770192391419}, {4.713525491562421, 0.8816778784387115}, 
    {4.503695909538285, 1.114717238216094}, {4.443561429310809, \
1.2475429541754033}}], 
  Line[{{4.651098371432819, 1.0590770192391419}, {4.806177918048795, \
0.8605642566348355}, {4.870318186463901, 0.6101049646136991}, 
    {4.713525491562421, 0.8816778784387115}, {4.651098371432819, \
1.0590770192391419}}], 
  Line[{{4.806177918048795, 0.8605642566348355}, {4.9020223488173915, \
0.6935451872894184}, {4.967221401100708, 0.3118675362266461}, 
    {4.870318186463901, 0.6101049646136991}, {4.806177918048795, \
0.8605642566348355}}], 
  Line[{{4.9020223488173915, 0.6935451872894184}, {4.934442802201416, \
0.6237350724532809}, {5., 0.}, {4.967221401100708, 0.3118675362266461}, 
    {4.9020223488173915, 0.6935451872894184}}], Line[{{5., 0.}, \
{4.967221401100708, 0.3118675362266461}, {4.902022348817392, \
0.6935451872894184}, 
    {4.934442802201418, 0.6237350724532723}, {5., 0.}}], \
Line[{{4.967221401100708, 0.3118675362266461}, {4.870318186463902, \
0.6101049646136962}, 
    {4.806177918048797, 0.8605642566348314}, {4.902022348817392, \
0.6935451872894184}, {4.967221401100708, 0.3118675362266461}}], 
  Line[{{4.870318186463902, 0.6101049646136962}, {4.713525491562421, \
0.8816778784387095}, {4.651098371432821, 1.0590770192391386}, 
    {4.806177918048797, 0.8605642566348314}, {4.870318186463902, \
0.6101049646136962}}], 
  Line[{{4.713525491562421, 0.8816778784387095}, {4.503695909538287, \
1.1147172382160924}, {4.443561429310812, 1.247542954175402}, 
    {4.651098371432821, 1.0590770192391386}, {4.713525491562421, \
0.8816778784387095}}], 
  Line[{{4.503695909538287, 1.1147172382160924}, {4.25, 1.2990381056766593}, \
{4.192637451926241, 1.4024710170213401}, 
    {4.443561429310812, 1.247542954175402}, {4.503695909538287, \
1.1147172382160924}}], 
  Line[{{4.25, 1.2990381056766593}, {3.963525491562421, 1.4265847744427318}, \
{3.909293021157644, 1.5096856680207957}, 
    {4.192637451926241, 1.4024710170213401}, {4.25, 1.2990381056766593}}], 
  Line[{{3.963525491562421, 1.4265847744427318}, {3.6567926949014806, \
1.49178284305241}, {3.605911648267039, 1.5605942189297979}, 
    {3.909293021157644, 1.5096856680207957}, {3.963525491562421, \
1.4265847744427318}}], 
  Line[{{3.6567926949014806, 1.49178284305241}, {3.3432073050985194, \
1.4917828430524107}, {3.2957525550350875, 1.5507915961279435}, 
    {3.605911648267039, 1.5605942189297979}, {3.6567926949014806, \
1.49178284305241}}], 
  Line[{{3.3432073050985194, 1.4917828430524107}, {3.036474508437579, \
1.4265847744427305}, {2.9923711821444825, 1.4795217391705868}, 
    {3.2957525550350875, 1.5507915961279435}, {3.3432073050985194, \
1.4917828430524107}}], 
  Line[{{3.036474508437579, 1.4265847744427305}, {2.75, 1.2990381056766587}, \
{2.7090267513758866, 1.3494565251821795}, 
    {2.9923711821444825, 1.4795217391705868}, {3.036474508437579, \
1.4265847744427305}}], 
  Line[{{2.75, 1.2990381056766587}, {2.496304090461713, 1.1147172382160917}, \
{2.458102773991315, 1.1666712321091803}, 
    {2.7090267513758866, 1.3494565251821795}, {2.75, 1.2990381056766587}}], 
  Line[{{2.496304090461713, 1.1147172382160917}, {2.286474508437579, \
0.88167787843871}, {2.2505658318693054, 0.9410557119019611}, 
    {2.458102773991315, 1.1666712321091803}, {2.496304090461713, \
1.1147172382160917}}], 
  Line[{{2.286474508437579, 0.88167787843871}, {2.1296818135360986, \
0.6101049646137013}, {2.09548628525333, 0.6884858883697313}, 
    {2.2505658318693054, 0.9410557119019611}, {2.286474508437579, \
0.88167787843871}}], 
  Line[{{2.1296818135360986, 0.6101049646137013}, {2.0327785988992915, \
0.31186753622664043}, {1.9996418544847334, 0.442263528432696}, 
    {2.09548628525333, 0.6884858883697313}, {2.1296818135360986, \
0.6101049646137013}}], 
  Line[{{2.0327785988992915, 0.31186753622664043}, {2., 0.}, \
{1.9672214011007088, 0.31186753622663826}, {1.9996418544847334, \
0.442263528432696}, 
    {2.0327785988992915, 0.31186753622664043}}], Line[{{2., 0.}, \
{2.0327785988992915, 0.311867536226639}, {1.9996418544847336, \
0.442263528432694}, 
    {1.9672214011007088, 0.31186753622663826}, {2., 0.}}], 
  Line[{{2.0327785988992915, 0.311867536226639}, {2.1296818135360986, \
0.6101049646136991}, {2.09548628525333, 0.6884858883697295}, 
    {1.9996418544847336, 0.442263528432694}, {2.0327785988992915, \
0.311867536226639}}], 
  Line[{{2.1296818135360986, 0.6101049646136991}, {2.286474508437579, \
0.8816778784387095}, {2.2505658318693054, 0.9410557119019607}, 
    {2.09548628525333, 0.6884858883697295}, {2.1296818135360986, \
0.6101049646136991}}], 
  Line[{{2.286474508437579, 0.8816778784387095}, {2.496304090461712, \
1.1147172382160913}, {2.458102773991314, 1.16667123210918}, 
    {2.2505658318693054, 0.9410557119019607}, {2.286474508437579, \
0.8816778784387095}}], 
  Line[{{2.496304090461712, 1.1147172382160913}, {2.749999999999999, \
1.299038105676658}, {2.7090267513758852, 1.3494565251821795}, 
    {2.458102773991314, 1.16667123210918}, {2.496304090461712, \
1.1147172382160913}}], 
  Line[{{2.749999999999999, 1.299038105676658}, {3.0364745084375784, \
1.4265847744427305}, {2.992371182144482, 1.4795217391705868}, 
    {2.7090267513758852, 1.3494565251821795}, {2.749999999999999, \
1.299038105676658}}], 
  Line[{{3.0364745084375784, 1.4265847744427305}, {3.3432073050985185, \
1.4917828430524107}, {3.2957525550350866, 1.550791596127943}, 
    {2.992371182144482, 1.4795217391705868}, {3.0364745084375784, \
1.4265847744427305}}], 
  Line[{{3.3432073050985185, 1.4917828430524107}, {3.656792694901479, \
1.4917828430524112}, {3.6059116482670377, 1.5605942189297983}, 
    {3.2957525550350866, 1.550791596127943}, {3.3432073050985185, \
1.4917828430524107}}], 
  Line[{{3.656792694901479, 1.4917828430524112}, {3.963525491562421, \
1.4265847744427305}, {3.909293021157644, 1.5096856680207946}, 
    {3.6059116482670377, 1.5605942189297983}, {3.656792694901479, \
1.4917828430524112}}], 
  Line[{{3.963525491562421, 1.4265847744427305}, {4.249999999999999, \
1.299038105676658}, {4.19263745192624, 1.4024710170213388}, 
    {3.909293021157644, 1.5096856680207946}, {3.963525491562421, \
1.4265847744427305}}], 
  Line[{{4.249999999999999, 1.299038105676658}, {4.503695909538286, \
1.1147172382160955}, {4.4435614293108125, 1.2475429541753977}, 
    {4.19263745192624, 1.4024710170213388}, {4.249999999999999, \
1.299038105676658}}], 
  Line[{{4.503695909538286, 1.1147172382160955}, {4.713525491562421, \
0.8816778784387115}, {4.651098371432821, 1.0590770192391386}, 
    {4.4435614293108125, 1.2475429541753977}, {4.503695909538286, \
1.1147172382160955}}], 
  Line[{{4.713525491562421, 0.8816778784387115}, {4.870318186463901, \
0.6101049646136991}, {4.806177918048797, 0.8605642566348294}, 
    {4.651098371432821, 1.0590770192391386}, {4.713525491562421, \
0.8816778784387115}}], 
  Line[{{4.870318186463901, 0.6101049646136991}, {4.967221401100708, \
0.3118675362266461}, {4.902022348817392, 0.6935451872894184}, 
    {4.806177918048797, 0.8605642566348294}, {4.870318186463901, \
0.6101049646136991}}], 
  Line[{{4.967221401100708, 0.3118675362266461}, {5., 0.}, \
{4.934442802201418, 0.6237350724532723}, {4.902022348817392, \
0.6935451872894184}, 
    {4.967221401100708, 0.3118675362266461}}], Line[{{5., 0.}, \
{4.967221401100709, 0.31186753622662905}, {4.902022348817393, \
0.6935451872894158}, 
    {4.934442802201418, 0.6237350724532723}, {5., 0.}}], \
Line[{{4.967221401100709, 0.31186753622662905}, {4.870318186463902, \
0.6101049646136962}, 
    {4.806177918048797, 0.8605642566348314}, {4.902022348817393, \
0.6935451872894158}, {4.967221401100709, 0.31186753622662905}}], 
  Line[{{4.870318186463902, 0.6101049646136962}, {4.713525491562422, \
0.8816778784387075}, {4.651098371432822, 1.0590770192391352}, 
    {4.806177918048797, 0.8605642566348314}, {4.870318186463902, \
0.6101049646136962}}], 
  Line[{{4.713525491562422, 0.8816778784387075}, {4.503695909538288, \
1.1147172382160924}, {4.443561429310814, 1.2475429541753962}, 
    {4.651098371432822, 1.0590770192391352}, {4.713525491562422, \
0.8816778784387075}}], 
  Line[{{4.503695909538288, 1.1147172382160924}, {4.250000000000001, \
1.299038105676658}, {4.192637451926242, 1.4024710170213401}, 
    {4.443561429310814, 1.2475429541753962}, {4.503695909538288, \
1.1147172382160924}}], 
  Line[{{4.250000000000001, 1.299038105676658}, {3.9635254915624225, \
1.426584774442728}, {3.9092930211576453, 1.5096856680207935}, 
    {4.192637451926242, 1.4024710170213401}, {4.250000000000001, \
1.299038105676658}}], 
  Line[{{3.9635254915624225, 1.426584774442728}, {3.656792694901482, \
1.491782843052409}, {3.6059116482670404, 1.5605942189297979}, 
    {3.9092930211576453, 1.5096856680207935}, {3.9635254915624225, \
1.426584774442728}}], 
  Line[{{3.656792694901482, 1.491782843052409}, {3.3432073050985207, \
1.49178284305241}, {3.295752555035089, 1.550791596127943}, 
    {3.6059116482670404, 1.5605942189297979}, {3.656792694901482, \
1.491782843052409}}], 
  Line[{{3.3432073050985207, 1.49178284305241}, {3.0364745084375793, \
1.4265847744427311}, {2.992371182144483, 1.4795217391705875}, 
    {3.295752555035089, 1.550791596127943}, {3.3432073050985207, \
1.49178284305241}}], 
  Line[{{3.0364745084375793, 1.4265847744427311}, {2.7500000000000013, \
1.2990381056766587}, {2.7090267513758874, 1.3494565251821806}, 
    {2.992371182144483, 1.4795217391705875}, {3.0364745084375793, \
1.4265847744427311}}], 
  Line[{{2.7500000000000013, 1.2990381056766587}, {2.496304090461714, \
1.1147172382160933}, {2.4581027739913157, 1.1666712321091814}, 
    {2.7090267513758874, 1.3494565251821806}, {2.7500000000000013, \
1.2990381056766587}}], 
  Line[{{2.496304090461714, 1.1147172382160933}, {2.2864745084375793, \
0.88167787843871}, {2.250565831869306, 0.9410557119019607}, 
    {2.4581027739913157, 1.1666712321091814}, {2.496304090461714, \
1.1147172382160933}}], 
  Line[{{2.2864745084375793, 0.88167787843871}, {2.1296818135360995, \
0.6101049646137006}, {2.095486285253331, 0.6884858883697308}, 
    {2.250565831869306, 0.9410557119019607}, {2.2864745084375793, \
0.88167787843871}}], 
  Line[{{2.1296818135360995, 0.6101049646137006}, {2.0327785988992924, \
0.31186753622664043}, {1.999641854484734, 0.442263528432697}, 
    {2.095486285253331, 0.6884858883697308}, {2.1296818135360995, \
0.6101049646137006}}], 
  Line[{{2.0327785988992924, 0.31186753622664043}, {2., 0.}, \
{1.9672214011007088, 0.31186753622663826}, {1.999641854484734, \
0.442263528432697}, 
    {2.0327785988992924, 0.31186753622664043}}], Line[{{2., 0.}, \
{2.0327785988992915, 0.31186753622663616}, 
    {1.9996418544847332, 0.442263528432694}, {1.9672214011007088, \
0.31186753622663826}, {2., 0.}}], 
  Line[{{2.0327785988992915, 0.31186753622663616}, {2.1296818135360978, \
0.6101049646136977}, {2.095486285253329, 0.6884858883697281}, 
    {1.9996418544847332, 0.442263528432694}, {2.0327785988992915, \
0.31186753622663616}}], 
  Line[{{2.1296818135360978, 0.6101049646136977}, {2.2864745084375784, \
0.8816778784387095}, {2.250565831869305, 0.9410557119019607}, 
    {2.095486285253329, 0.6884858883697281}, {2.1296818135360978, \
0.6101049646136977}}], 
  Line[{{2.2864745084375784, 0.8816778784387095}, {2.4963040904617113, \
1.1147172382160908}, {2.458102773991313, 1.1666712321091794}, 
    {2.250565831869305, 0.9410557119019607}, {2.2864745084375784, \
0.8816778784387095}}], 
  Line[{{2.4963040904617113, 1.1147172382160908}, {2.7499999999999982, \
1.2990381056766562}, {2.709026751375884, 1.3494565251821788}, 
    {2.458102773991313, 1.1666712321091794}, {2.4963040904617113, \
1.1147172382160908}}], 
  Line[{{2.7499999999999982, 1.2990381056766562}, {3.0364745084375784, \
1.4265847744427305}, {2.992371182144482, 1.4795217391705862}, 
    {2.709026751375884, 1.3494565251821788}, {2.7499999999999982, \
1.2990381056766562}}], 
  Line[{{3.0364745084375784, 1.4265847744427305}, {3.3432073050985176, \
1.4917828430524107}, {3.2957525550350857, 1.5507915961279441}, 
    {2.992371182144482, 1.4795217391705862}, {3.0364745084375784, \
1.4265847744427305}}], 
  Line[{{3.3432073050985176, 1.4917828430524107}, {3.6567926949014775, \
1.49178284305241}, {3.605911648267036, 1.5605942189297983}, 
    {3.2957525550350857, 1.5507915961279441}, {3.3432073050985176, \
1.4917828430524107}}], 
  Line[{{3.6567926949014775, 1.49178284305241}, {3.963525491562421, \
1.4265847744427305}, {3.9092930211576444, 1.5096856680207935}, 
    {3.605911648267036, 1.5605942189297983}, {3.6567926949014775, \
1.49178284305241}}], 
  Line[{{3.963525491562421, 1.4265847744427305}, {4.249999999999998, \
1.2990381056766607}, {4.19263745192624, 1.4024710170213388}, 
    {3.9092930211576444, 1.5096856680207935}, {3.963525491562421, \
1.4265847744427305}}], 
  Line[{{4.249999999999998, 1.2990381056766607}, {4.503695909538285, \
1.114717238216094}, {4.443561429310811, 1.2475429541754004}, 
    {4.19263745192624, 1.4024710170213388}, {4.249999999999998, \
1.2990381056766607}}], 
  Line[{{4.503695909538285, 1.114717238216094}, {4.713525491562421, \
0.8816778784387115}, {4.651098371432821, 1.0590770192391386}, 
    {4.443561429310811, 1.2475429541754004}, {4.503695909538285, \
1.114717238216094}}], 
  Line[{{4.713525491562421, 0.8816778784387115}, {4.870318186463901, \
0.6101049646136991}, {4.806177918048797, 0.8605642566348294}, 
    {4.651098371432821, 1.0590770192391386}, {4.713525491562421, \
0.8816778784387115}}], 
  Line[{{4.870318186463901, 0.6101049646136991}, {4.967221401100708, \
0.3118675362266461}, {4.902022348817393, 0.6935451872894107}, 
    {4.806177918048797, 0.8605642566348294}, {4.870318186463901, \
0.6101049646136991}}], 
  Line[{{4.967221401100708, 0.3118675362266461}, {5., 0.}, \
{4.934442802201418, 0.6237350724532723}, {4.902022348817393, \
0.6935451872894107}, 
    {4.967221401100708, 0.3118675362266461}}], Line[{{4.934442802201418, \
0.6237350724532723}, {4.902022348817392, 0.6935451872894184}, 
    {4.709274703411989, 1.2512975557014567}, {4.740636372927804, \
1.2202099292273982}, {4.934442802201418, 0.6237350724532723}}], 
  Line[{{4.902022348817392, 0.6935451872894184}, {4.806177918048797, \
0.8605642566348314}, {4.616560350312376, 1.3346849311080466}, 
    {4.709274703411989, 1.2512975557014567}, {4.902022348817392, \
0.6935451872894184}}], 
  Line[{{4.806177918048797, 0.8605642566348314}, {4.651098371432821, \
1.0590770192391386}, {4.46654537575224, 1.4470248504530079}, 
    {4.616560350312376, 1.3346849311080466}, {4.806177918048797, \
0.8605642566348314}}], 
  Line[{{4.651098371432821, 1.0590770192391386}, {4.443561429310812, \
1.247542954175402}, {4.265786153971577, 1.5625819810819546}, 
    {4.46654537575224, 1.4470248504530079}, {4.651098371432821, \
1.0590770192391386}}], 
  Line[{{4.443561429310812, 1.247542954175402}, {4.192637451926241, \
1.4024710170213401}, {4.023056826311829, 1.6596693760099273}, 
    {4.265786153971577, 1.5625819810819546}, {4.443561429310812, \
1.247542954175402}}], 
  Line[{{4.192637451926241, 1.4024710170213401}, {3.909293021157644, \
1.5096856680207957}, {3.7489658291362655, 1.7222389198769947}, 
    {4.023056826311829, 1.6596693760099273}, {4.192637451926241, \
1.4024710170213401}}], 
  Line[{{3.909293021157644, 1.5096856680207957}, {3.605911648267039, \
1.5605942189297979}, {3.4554922542559883, 1.7395717696563637}, 
    {3.7489658291362655, 1.7222389198769947}, {3.909293021157644, \
1.5096856680207957}}], 
  Line[{{3.605911648267039, 1.5605942189297979}, {3.2957525550350875, \
1.5507915961279435}, {3.1554623051357176, 1.705691841463222}, 
    {3.4554922542559883, 1.7395717696563637}, {3.605911648267039, \
1.5605942189297979}}], 
  Line[{{3.2957525550350875, 1.5507915961279435}, {2.9923711821444825, \
1.4795217391705868}, {2.8619887302554403, 1.6189603147994467}, 
    {3.1554623051357176, 1.705691841463222}, {3.2957525550350875, \
1.5507915961279435}}], 
  Line[{{2.9923711821444825, 1.4795217391705868}, {2.7090267513758866, \
1.3494565251821795}, {2.5878977330798776, 1.4819447816621785}, 
    {2.8619887302554403, 1.6189603147994467}, {2.9923711821444825, \
1.4795217391705868}}], 
  Line[{{2.7090267513758866, 1.3494565251821795}, {2.458102773991315, \
1.1666712321091803}, {2.3451684054201287, 1.3017122836390151}, 
    {2.5878977330798776, 1.4819447816621785}, {2.7090267513758866, \
1.3494565251821795}}], 
  Line[{{2.458102773991315, 1.1666712321091803}, {2.2505658318693054, \
0.9410557119019611}, {2.144409183639465, 1.0910840571723}, 
    {2.3451684054201287, 1.3017122836390151}, {2.458102773991315, \
1.1666712321091803}}], 
  Line[{{2.2505658318693054, 0.9410557119019611}, {2.09548628525333, \
0.6884858883697313}, {1.99439420907933, 0.8724918816600724}, 
    {2.144409183639465, 1.0910840571723}, {2.2505658318693054, \
0.9410557119019611}}], 
  Line[{{2.09548628525333, 0.6884858883697313}, {1.9996418544847334, \
0.442263528432696}, {1.901679855979716, 0.6880869119781076}, 
    {1.99439420907933, 0.8724918816600724}, {2.09548628525333, \
0.6884858883697313}}], 
  Line[{{1.9996418544847334, 0.442263528432696}, {1.9672214011007088, \
0.31186753622663826}, {1.8703181864639018, 0.6101049646136991}, 
    {1.901679855979716, 0.6880869119781076}, {1.9996418544847334, \
0.442263528432696}}], 
  Line[{{1.9672214011007088, 0.31186753622663826}, {1.9996418544847336, \
0.442263528432694}, {1.901679855979716, 0.6880869119781069}, 
    {1.8703181864639018, 0.6101049646136991}, {1.9672214011007088, \
0.31186753622663826}}], 
  Line[{{1.9996418544847336, 0.442263528432694}, {2.09548628525333, \
0.6884858883697295}, {1.9943942090793298, 0.8724918816600712}, 
    {1.901679855979716, 0.6880869119781069}, {1.9996418544847336, \
0.442263528432694}}], 
  Line[{{2.09548628525333, 0.6884858883697295}, {2.2505658318693054, \
0.9410557119019607}, {2.144409183639465, 1.0910840571722995}, 
    {1.9943942090793298, 0.8724918816600712}, {2.09548628525333, \
0.6884858883697295}}], 
  Line[{{2.2505658318693054, 0.9410557119019607}, {2.458102773991314, \
1.16667123210918}, {2.345168405420128, 1.301712283639015}, 
    {2.144409183639465, 1.0910840571722995}, {2.2505658318693054, \
0.9410557119019607}}], 
  Line[{{2.458102773991314, 1.16667123210918}, {2.7090267513758852, \
1.3494565251821795}, {2.5878977330798767, 1.4819447816621778}, 
    {2.345168405420128, 1.301712283639015}, {2.458102773991314, \
1.16667123210918}}], 
  Line[{{2.7090267513758852, 1.3494565251821795}, {2.992371182144482, \
1.4795217391705868}, {2.86198873025544, 1.6189603147994462}, 
    {2.5878977330798767, 1.4819447816621778}, {2.7090267513758852, \
1.3494565251821795}}], 
  Line[{{2.992371182144482, 1.4795217391705868}, {3.2957525550350866, \
1.550791596127943}, {3.1554623051357167, 1.705691841463221}, 
    {2.86198873025544, 1.6189603147994462}, {2.992371182144482, \
1.4795217391705868}}], 
  Line[{{3.2957525550350866, 1.550791596127943}, {3.6059116482670377, \
1.5605942189297983}, {3.4554922542559865, 1.7395717696563644}, 
    {3.1554623051357167, 1.705691841463221}, {3.2957525550350866, \
1.550791596127943}}], 
  Line[{{3.6059116482670377, 1.5605942189297983}, {3.909293021157644, \
1.5096856680207946}, {3.748965829136265, 1.7222389198769947}, 
    {3.4554922542559865, 1.7395717696563644}, {3.6059116482670377, \
1.5605942189297983}}], 
  Line[{{3.909293021157644, 1.5096856680207946}, {4.19263745192624, \
1.4024710170213388}, {4.023056826311827, 1.6596693760099293}, 
    {3.748965829136265, 1.7222389198769947}, {3.909293021157644, \
1.5096856680207946}}], 
  Line[{{4.19263745192624, 1.4024710170213388}, {4.4435614293108125, \
1.2475429541753977}, {4.265786153971577, 1.5625819810819535}, 
    {4.023056826311827, 1.6596693760099293}, {4.19263745192624, \
1.4024710170213388}}], 
  Line[{{4.4435614293108125, 1.2475429541753977}, {4.651098371432821, \
1.0590770192391386}, {4.46654537575224, 1.447024850453009}, 
    {4.265786153971577, 1.5625819810819535}, {4.4435614293108125, \
1.2475429541753977}}], 
  Line[{{4.651098371432821, 1.0590770192391386}, {4.806177918048797, \
0.8605642566348294}, {4.616560350312375, 1.3346849311080493}, 
    {4.46654537575224, 1.447024850453009}, {4.651098371432821, \
1.0590770192391386}}], 
  Line[{{4.806177918048797, 0.8605642566348294}, {4.902022348817392, \
0.6935451872894184}, {4.709274703411989, 1.2512975557014567}, 
    {4.616560350312375, 1.3346849311080493}, {4.806177918048797, \
0.8605642566348294}}], 
  Line[{{4.902022348817392, 0.6935451872894184}, {4.934442802201418, \
0.6237350724532723}, {4.740636372927804, 1.2202099292273982}, 
    {4.709274703411989, 1.2512975557014567}, {4.902022348817392, \
0.6935451872894184}}], 
  Line[{{4.934442802201418, 0.6237350724532723}, {4.902022348817393, \
0.6935451872894158}, {4.70927470341199, 1.2512975557014552}, 
    {4.740636372927804, 1.2202099292273982}, {4.934442802201418, \
0.6237350724532723}}], 
  Line[{{4.902022348817393, 0.6935451872894158}, {4.806177918048797, \
0.8605642566348314}, {4.616560350312376, 1.3346849311080466}, 
    {4.70927470341199, 1.2512975557014552}, {4.902022348817393, \
0.6935451872894158}}], 
  Line[{{4.806177918048797, 0.8605642566348314}, {4.651098371432822, \
1.0590770192391352}, {4.466545375752241, 1.4470248504530079}, 
    {4.616560350312376, 1.3346849311080466}, {4.806177918048797, \
0.8605642566348314}}], 
  Line[{{4.651098371432822, 1.0590770192391352}, {4.443561429310814, \
1.2475429541753962}, {4.265786153971579, 1.5625819810819535}, 
    {4.466545375752241, 1.4470248504530079}, {4.651098371432822, \
1.0590770192391352}}], 
  Line[{{4.443561429310814, 1.2475429541753962}, {4.192637451926242, \
1.4024710170213401}, {4.02305682631183, 1.6596693760099261}, 
    {4.265786153971579, 1.5625819810819535}, {4.443561429310814, \
1.2475429541753962}}], 
  Line[{{4.192637451926242, 1.4024710170213401}, {3.9092930211576453, \
1.5096856680207935}, {3.7489658291362664, 1.7222389198769943}, 
    {4.02305682631183, 1.6596693760099261}, {4.192637451926242, \
1.4024710170213401}}], 
  Line[{{3.9092930211576453, 1.5096856680207935}, {3.6059116482670404, \
1.5605942189297979}, {3.455492254255989, 1.7395717696563633}, 
    {3.7489658291362664, 1.7222389198769943}, {3.9092930211576453, \
1.5096856680207935}}], 
  Line[{{3.6059116482670404, 1.5605942189297979}, {3.295752555035089, \
1.550791596127943}, {3.155462305135719, 1.705691841463221}, 
    {3.455492254255989, 1.7395717696563633}, {3.6059116482670404, \
1.5605942189297979}}], 
  Line[{{3.295752555035089, 1.550791596127943}, {2.992371182144483, \
1.4795217391705875}, {2.861988730255441, 1.6189603147994462}, 
    {3.155462305135719, 1.705691841463221}, {3.295752555035089, \
1.550791596127943}}], 
  Line[{{2.992371182144483, 1.4795217391705875}, {2.7090267513758874, \
1.3494565251821806}, {2.5878977330798785, 1.4819447816621794}, 
    {2.861988730255441, 1.6189603147994462}, {2.992371182144483, \
1.4795217391705875}}], 
  Line[{{2.7090267513758874, 1.3494565251821806}, {2.4581027739913157, \
1.1666712321091814}, {2.3451684054201296, 1.301712283639017}, 
    {2.5878977330798785, 1.4819447816621794}, {2.7090267513758874, \
1.3494565251821806}}], 
  Line[{{2.4581027739913157, 1.1666712321091814}, {2.250565831869306, \
0.9410557119019607}, {2.144409183639465, 1.0910840571723004}, 
    {2.3451684054201296, 1.301712283639017}, {2.4581027739913157, \
1.1666712321091814}}], 
  Line[{{2.250565831869306, 0.9410557119019607}, {2.095486285253331, \
0.6884858883697308}, {1.9943942090793307, 0.8724918816600724}, 
    {2.144409183639465, 1.0910840571723004}, {2.250565831869306, \
0.9410557119019607}}], 
  Line[{{2.095486285253331, 0.6884858883697308}, {1.999641854484734, \
0.442263528432697}, {1.9016798559797166, 0.6880869119781079}, 
    {1.9943942090793307, 0.8724918816600724}, {2.095486285253331, \
0.6884858883697308}}], 
  Line[{{1.999641854484734, 0.442263528432697}, {1.9672214011007088, \
0.31186753622663826}, {1.8703181864639018, 0.6101049646136991}, 
    {1.9016798559797166, 0.6880869119781079}, {1.999641854484734, \
0.442263528432697}}], 
  Line[{{1.9672214011007088, 0.31186753622663826}, {1.9996418544847332, \
0.442263528432694}, {1.9016798559797157, 0.6880869119781062}, 
    {1.8703181864639018, 0.6101049646136991}, {1.9672214011007088, \
0.31186753622663826}}], 
  Line[{{1.9996418544847332, 0.442263528432694}, {2.095486285253329, \
0.6884858883697281}, {1.994394209079329, 0.8724918816600701}, 
    {1.9016798559797157, 0.6880869119781062}, {1.9996418544847332, \
0.442263528432694}}], 
  Line[{{2.095486285253329, 0.6884858883697281}, {2.250565831869305, \
0.9410557119019607}, {2.1444091836394645, 1.0910840571722995}, 
    {1.994394209079329, 0.8724918816600701}, {2.095486285253329, \
0.6884858883697281}}], 
  Line[{{2.250565831869305, 0.9410557119019607}, {2.458102773991313, \
1.1666712321091794}, {2.345168405420127, 1.3017122836390145}, 
    {2.1444091836394645, 1.0910840571722995}, {2.250565831869305, \
0.9410557119019607}}], 
  Line[{{2.458102773991313, 1.1666712321091794}, {2.709026751375884, \
1.3494565251821788}, {2.587897733079876, 1.481944781662177}, 
    {2.345168405420127, 1.3017122836390145}, {2.458102773991313, \
1.1666712321091794}}], 
  Line[{{2.709026751375884, 1.3494565251821788}, {2.992371182144482, \
1.4795217391705862}, {2.8619887302554394, 1.6189603147994462}, 
    {2.587897733079876, 1.481944781662177}, {2.709026751375884, \
1.3494565251821788}}], 
  Line[{{2.992371182144482, 1.4795217391705862}, {3.2957525550350857, \
1.5507915961279441}, {3.1554623051357167, 1.7056918414632198}, 
    {2.8619887302554394, 1.6189603147994462}, {2.992371182144482, \
1.4795217391705862}}], 
  Line[{{3.2957525550350857, 1.5507915961279441}, {3.605911648267036, \
1.5605942189297983}, {3.455492254255985, 1.7395717696563637}, 
    {3.1554623051357167, 1.7056918414632198}, {3.2957525550350857, \
1.5507915961279441}}], 
  Line[{{3.605911648267036, 1.5605942189297983}, {3.9092930211576444, \
1.5096856680207935}, {3.7489658291362655, 1.7222389198769938}, 
    {3.455492254255985, 1.7395717696563637}, {3.605911648267036, \
1.5605942189297983}}], 
  Line[{{3.9092930211576444, 1.5096856680207935}, {4.19263745192624, \
1.4024710170213388}, {4.023056826311827, 1.6596693760099281}, 
    {3.7489658291362655, 1.7222389198769938}, {3.9092930211576444, \
1.5096856680207935}}], 
  Line[{{4.19263745192624, 1.4024710170213388}, {4.443561429310811, \
1.2475429541754004}, {4.265786153971575, 1.562581981081956}, 
    {4.023056826311827, 1.6596693760099281}, {4.19263745192624, \
1.4024710170213388}}], 
  Line[{{4.443561429310811, 1.2475429541754004}, {4.651098371432821, \
1.0590770192391386}, {4.46654537575224, 1.447024850453009}, 
    {4.265786153971575, 1.562581981081956}, {4.443561429310811, \
1.2475429541754004}}], 
  Line[{{4.651098371432821, 1.0590770192391386}, {4.806177918048797, \
0.8605642566348294}, {4.616560350312375, 1.3346849311080493}, 
    {4.46654537575224, 1.447024850453009}, {4.651098371432821, \
1.0590770192391386}}], 
  Line[{{4.806177918048797, 0.8605642566348294}, {4.902022348817393, \
0.6935451872894107}, {4.70927470341199, 1.2512975557014525}, 
    {4.616560350312375, 1.3346849311080493}, {4.806177918048797, \
0.8605642566348294}}], 
  Line[{{4.902022348817393, 0.6935451872894107}, {4.934442802201418, \
0.6237350724532723}, {4.740636372927804, 1.2202099292273982}, 
    {4.70927470341199, 1.2512975557014525}, {4.902022348817393, \
0.6935451872894107}}], 
  Line[{{4.740636372927804, 1.2202099292273982}, {4.709274703411989, \
1.2512975557014567}, {4.397402461894534, 1.7786275248098171}, 
    {4.427050983124843, 1.763355756877417}, {4.740636372927804, \
1.2202099292273982}}], 
  Line[{{4.709274703411989, 1.2512975557014567}, {4.616560350312376, \
1.3346849311080466}, {4.309752680850761, 1.82020538579592}, 
    {4.397402461894534, 1.7786275248098171}, {4.709274703411989, \
1.2512975557014567}}], 
  Line[{{4.616560350312376, 1.3346849311080466}, {4.46654537575224, \
1.4470248504530079}, {4.167932356015448, 1.8768892930626255}, 
    {4.309752680850761, 1.82020538579592}, {4.616560350312376, \
1.3346849311080466}}], 
  Line[{{4.46654537575224, 1.4470248504530079}, {4.265786153971577, \
1.5625819810819546}, {3.9781397161133225, 1.9339672857886046}, 
    {4.167932356015448, 1.8768892930626255}, {4.46654537575224, \
1.4470248504530079}}], 
  Line[{{4.265786153971577, 1.5625819810819546}, {4.023056826311829, \
1.6596693760099273}, {3.748669610234238, 1.976615915035448}, 
    {3.9781397161133225, 1.9339672857886046}, {4.265786153971577, \
1.5625819810819546}}], 
  Line[{{4.023056826311829, 1.6596693760099273}, {3.7489658291362655, \
1.7222389198769947}, {3.489550983124843, 1.9921691365624095}, 
    {3.748669610234238, 1.976615915035448}, {4.023056826311829, \
1.6596693760099273}}], 
  Line[{{3.7489658291362655, 1.7222389198769947}, {3.4554922542559883, \
1.7395717696563637}, {3.212108562178944, 1.97128525856985}, 
    {3.489550983124843, 1.9921691365624095}, {3.7489658291362655, \
1.7222389198769947}}], 
  Line[{{3.4554922542559883, 1.7395717696563637}, {3.1554623051357176, \
1.705691841463222}, {2.92846791250832, 1.908454380799519}, 
    {3.212108562178944, 1.97128525856985}, {3.4554922542559883, \
1.7395717696563637}}], 
  Line[{{3.1554623051357176, 1.705691841463222}, {2.8619887302554403, \
1.6189603147994467}, {2.6510254915624216, 1.8022456366013602}, 
    {2.92846791250832, 1.908454380799519}, {3.1554623051357176, \
1.705691841463222}}], 
  Line[{{2.8619887302554403, 1.6189603147994467}, {2.5878977330798776, \
1.4819447816621785}, {2.391906864453027, 1.6555895184432492}, 
    {2.6510254915624216, 1.8022456366013602}, {2.8619887302554403, \
1.6189603147994467}}], 
  Line[{{2.5878977330798776, 1.4819447816621785}, {2.3451684054201287, \
1.3017122836390151}, {2.162436758573942, 1.4764049667388979}, 
    {2.391906864453027, 1.6555895184432492}, {2.5878977330798776, \
1.4819447816621785}}], 
  Line[{{2.3451684054201287, 1.3017122836390151}, {2.144409183639465, \
1.0910840571723}, {1.972644118671816, 1.2790742990138138}, 
    {2.162436758573942, 1.4764049667388979}, {2.3451684054201287, \
1.3017122836390151}}], 
  Line[{{2.144409183639465, 1.0910840571723}, {1.99439420907933, \
0.8724918816600724}, {1.8308237938365044, 1.0875191232355923}, 
    {1.972644118671816, 1.2790742990138138}, {2.144409183639465, \
1.0910840571723}}], 
  Line[{{1.99439420907933, 0.8724918816600724}, {1.901679855979716, \
0.6880869119781076}, {1.7431740127927307, 0.9393665425693399}, 
    {1.8308237938365044, 1.0875191232355923}, {1.99439420907933, \
0.8724918816600724}}], 
  Line[{{1.901679855979716, 0.6880869119781076}, {1.8703181864639018, \
0.6101049646136991}, {1.7135254915624214, 0.8816778784387095}, 
    {1.7431740127927307, 0.9393665425693399}, {1.901679855979716, \
0.6880869119781076}}], 
  Line[{{1.8703181864639018, 0.6101049646136991}, {1.901679855979716, \
0.6880869119781069}, {1.7431740127927309, 0.9393665425693389}, 
    {1.7135254915624214, 0.8816778784387095}, {1.8703181864639018, \
0.6101049646136991}}], 
  Line[{{1.901679855979716, 0.6880869119781069}, {1.9943942090793298, \
0.8724918816600712}, {1.8308237938365042, 1.0875191232355914}, 
    {1.7431740127927309, 0.9393665425693389}, {1.901679855979716, \
0.6880869119781069}}], 
  Line[{{1.9943942090793298, 0.8724918816600712}, {2.144409183639465, \
1.0910840571722995}, {1.9726441186718162, 1.279074299013813}, 
    {1.8308237938365042, 1.0875191232355914}, {1.9943942090793298, \
0.8724918816600712}}], 
  Line[{{2.144409183639465, 1.0910840571722995}, {2.345168405420128, \
1.301712283639015}, {2.162436758573941, 1.4764049667388972}, 
    {1.9726441186718162, 1.279074299013813}, {2.144409183639465, \
1.0910840571722995}}], 
  Line[{{2.345168405420128, 1.301712283639015}, {2.5878977330798767, \
1.4819447816621778}, {2.391906864453026, 1.6555895184432483}, 
    {2.162436758573941, 1.4764049667388972}, {2.345168405420128, \
1.301712283639015}}], 
  Line[{{2.5878977330798767, 1.4819447816621778}, {2.86198873025544, \
1.6189603147994462}, {2.6510254915624207, 1.8022456366013606}, 
    {2.391906864453026, 1.6555895184432483}, {2.5878977330798767, \
1.4819447816621778}}], 
  Line[{{2.86198873025544, 1.6189603147994462}, {3.1554623051357167, \
1.705691841463221}, {2.928467912508319, 1.9084543807995185}, 
    {2.6510254915624207, 1.8022456366013606}, {2.86198873025544, \
1.6189603147994462}}], 
  Line[{{3.1554623051357167, 1.705691841463221}, {3.4554922542559865, \
1.7395717696563644}, {3.212108562178943, 1.9712852585698486}, 
    {2.928467912508319, 1.9084543807995185}, {3.1554623051357167, \
1.705691841463221}}], 
  Line[{{3.4554922542559865, 1.7395717696563644}, {3.748965829136265, \
1.7222389198769947}, {3.489550983124843, 1.9921691365624086}, 
    {3.212108562178943, 1.9712852585698486}, {3.4554922542559865, \
1.7395717696563644}}], 
  Line[{{3.748965829136265, 1.7222389198769947}, {4.023056826311827, \
1.6596693760099293}, {3.7486696102342365, 1.976615915035448}, 
    {3.489550983124843, 1.9921691365624086}, {3.748965829136265, \
1.7222389198769947}}], 
  Line[{{4.023056826311827, 1.6596693760099293}, {4.265786153971577, \
1.5625819810819535}, {3.9781397161133225, 1.9339672857886046}, 
    {3.7486696102342365, 1.976615915035448}, {4.023056826311827, \
1.6596693760099293}}], 
  Line[{{4.265786153971577, 1.5625819810819535}, {4.46654537575224, \
1.447024850453009}, {4.167932356015448, 1.8768892930626255}, 
    {3.9781397161133225, 1.9339672857886046}, {4.265786153971577, \
1.5625819810819535}}], 
  Line[{{4.46654537575224, 1.447024850453009}, {4.616560350312375, \
1.3346849311080493}, {4.309752680850761, 1.820205385795918}, 
    {4.167932356015448, 1.8768892930626255}, {4.46654537575224, \
1.447024850453009}}], 
  Line[{{4.616560350312375, 1.3346849311080493}, {4.709274703411989, \
1.2512975557014567}, {4.397402461894534, 1.7786275248098171}, 
    {4.309752680850761, 1.820205385795918}, {4.616560350312375, \
1.3346849311080493}}], 
  Line[{{4.709274703411989, 1.2512975557014567}, {4.740636372927804, \
1.2202099292273982}, {4.427050983124843, 1.763355756877417}, 
    {4.397402461894534, 1.7786275248098171}, {4.709274703411989, \
1.2512975557014567}}], 
  Line[{{4.740636372927804, 1.2202099292273982}, {4.70927470341199, \
1.2512975557014552}, {4.397402461894535, 1.778627524809816}, 
    {4.427050983124843, 1.763355756877417}, {4.740636372927804, \
1.2202099292273982}}], 
  Line[{{4.70927470341199, 1.2512975557014552}, {4.616560350312376, \
1.3346849311080466}, {4.309752680850761, 1.8202053857959188}, 
    {4.397402461894535, 1.778627524809816}, {4.70927470341199, \
1.2512975557014552}}], 
  Line[{{4.616560350312376, 1.3346849311080466}, {4.466545375752241, \
1.4470248504530079}, {4.167932356015449, 1.8768892930626246}, 
    {4.309752680850761, 1.8202053857959188}, {4.616560350312376, \
1.3346849311080466}}], 
  Line[{{4.466545375752241, 1.4470248504530079}, {4.265786153971579, \
1.5625819810819535}, {3.978139716113324, 1.9339672857886037}, 
    {4.167932356015449, 1.8768892930626246}, {4.466545375752241, \
1.4470248504530079}}], 
  Line[{{4.265786153971579, 1.5625819810819535}, {4.02305682631183, \
1.6596693760099261}, {3.7486696102342387, 1.9766159150354476}, 
    {3.978139716113324, 1.9339672857886037}, {4.265786153971579, \
1.5625819810819535}}], 
  Line[{{4.02305682631183, 1.6596693760099261}, {3.7489658291362664, \
1.7222389198769943}, {3.4895509831248437, 1.9921691365624086}, 
    {3.7486696102342387, 1.9766159150354476}, {4.02305682631183, \
1.6596693760099261}}], 
  Line[{{3.7489658291362664, 1.7222389198769943}, {3.455492254255989, \
1.7395717696563633}, {3.2121085621789454, 1.971285258569849}, 
    {3.4895509831248437, 1.9921691365624086}, {3.7489658291362664, \
1.7222389198769943}}], 
  Line[{{3.455492254255989, 1.7395717696563633}, {3.155462305135719, \
1.705691841463221}, {2.928467912508321, 1.9084543807995193}, 
    {3.2121085621789454, 1.971285258569849}, {3.455492254255989, \
1.7395717696563633}}], 
  Line[{{3.155462305135719, 1.705691841463221}, {2.861988730255441, \
1.6189603147994462}, {2.651025491562422, 1.8022456366013606}, 
    {2.928467912508321, 1.9084543807995193}, {3.155462305135719, \
1.705691841463221}}], 
  Line[{{2.861988730255441, 1.6189603147994462}, {2.5878977330798785, \
1.4819447816621794}, {2.391906864453028, 1.6555895184432494}, 
    {2.651025491562422, 1.8022456366013606}, {2.861988730255441, \
1.6189603147994462}}], 
  Line[{{2.5878977330798785, 1.4819447816621794}, {2.3451684054201296, \
1.301712283639017}, {2.1624367585739424, 1.4764049667388996}, 
    {2.391906864453028, 1.6555895184432494}, {2.5878977330798785, \
1.4819447816621794}}], 
  Line[{{2.3451684054201296, 1.301712283639017}, {2.144409183639465, \
1.0910840571723004}, {1.9726441186718164, 1.2790742990138138}, 
    {2.1624367585739424, 1.4764049667388996}, {2.3451684054201296, \
1.301712283639017}}], 
  Line[{{2.144409183639465, 1.0910840571723004}, {1.9943942090793307, \
0.8724918816600724}, {1.830823793836505, 1.0875191232355925}, 
    {1.9726441186718164, 1.2790742990138138}, {2.144409183639465, \
1.0910840571723004}}], 
  Line[{{1.9943942090793307, 0.8724918816600724}, {1.9016798559797166, \
0.6880869119781079}, {1.7431740127927313, 0.9393665425693402}, 
    {1.830823793836505, 1.0875191232355925}, {1.9943942090793307, \
0.8724918816600724}}], 
  Line[{{1.9016798559797166, 0.6880869119781079}, {1.8703181864639018, \
0.6101049646136991}, {1.7135254915624214, 0.8816778784387095}, 
    {1.7431740127927313, 0.9393665425693402}, {1.9016798559797166, \
0.6880869119781079}}], 
  Line[{{1.8703181864639018, 0.6101049646136991}, {1.9016798559797157, \
0.6880869119781062}, {1.7431740127927304, 0.9393665425693389}, 
    {1.7135254915624214, 0.8816778784387095}, {1.8703181864639018, \
0.6101049646136991}}], 
  Line[{{1.9016798559797157, 0.6880869119781062}, {1.994394209079329, \
0.8724918816600701}, {1.8308237938365033, 1.0875191232355905}, 
    {1.7431740127927304, 0.9393665425693389}, {1.9016798559797157, \
0.6880869119781062}}], 
  Line[{{1.994394209079329, 0.8724918816600701}, {2.1444091836394645, \
1.0910840571722995}, {1.9726441186718158, 1.279074299013813}, 
    {1.8308237938365033, 1.0875191232355905}, {1.994394209079329, \
0.8724918816600701}}], 
  Line[{{2.1444091836394645, 1.0910840571722995}, {2.345168405420127, \
1.3017122836390145}, {2.16243675857394, 1.476404966738897}, 
    {1.9726441186718158, 1.279074299013813}, {2.1444091836394645, \
1.0910840571722995}}], 
  Line[{{2.345168405420127, 1.3017122836390145}, {2.587897733079876, \
1.481944781662177}, {2.391906864453025, 1.6555895184432476}, 
    {2.16243675857394, 1.476404966738897}, {2.345168405420127, \
1.3017122836390145}}], 
  Line[{{2.587897733079876, 1.481944781662177}, {2.8619887302554394, \
1.6189603147994462}, {2.6510254915624207, 1.8022456366013606}, 
    {2.391906864453025, 1.6555895184432476}, {2.587897733079876, \
1.481944781662177}}], 
  Line[{{2.8619887302554394, 1.6189603147994462}, {3.1554623051357167, \
1.7056918414632198}, {2.928467912508318, 1.908454380799519}, 
    {2.6510254915624207, 1.8022456366013606}, {2.8619887302554394, \
1.6189603147994462}}], 
  Line[{{3.1554623051357167, 1.7056918414632198}, {3.455492254255985, \
1.7395717696563637}, {3.2121085621789414, 1.9712852585698495}, 
    {2.928467912508318, 1.908454380799519}, {3.1554623051357167, \
1.7056918414632198}}], 
  Line[{{3.455492254255985, 1.7395717696563637}, {3.7489658291362655, \
1.7222389198769938}, {3.489550983124843, 1.9921691365624086}, 
    {3.2121085621789414, 1.9712852585698495}, {3.455492254255985, \
1.7395717696563637}}], 
  Line[{{3.7489658291362655, 1.7222389198769938}, {4.023056826311827, \
1.6596693760099281}, {3.748669610234236, 1.976615915035449}, 
    {3.489550983124843, 1.9921691365624086}, {3.7489658291362655, \
1.7222389198769938}}], 
  Line[{{4.023056826311827, 1.6596693760099281}, {4.265786153971575, \
1.562581981081956}, {3.978139716113321, 1.9339672857886046}, 
    {3.748669610234236, 1.976615915035449}, {4.023056826311827, \
1.6596693760099281}}], 
  Line[{{4.265786153971575, 1.562581981081956}, {4.46654537575224, \
1.447024850453009}, {4.167932356015449, 1.8768892930626246}, 
    {3.978139716113321, 1.9339672857886046}, {4.265786153971575, \
1.562581981081956}}], 
  Line[{{4.46654537575224, 1.447024850453009}, {4.616560350312375, \
1.3346849311080493}, {4.309752680850761, 1.820205385795918}, 
    {4.167932356015449, 1.8768892930626246}, {4.46654537575224, \
1.447024850453009}}], 
  Line[{{4.616560350312375, 1.3346849311080493}, {4.70927470341199, \
1.2512975557014525}, {4.397402461894534, 1.7786275248098171}, 
    {4.309752680850761, 1.820205385795918}, {4.616560350312375, \
1.3346849311080493}}], 
  Line[{{4.70927470341199, 1.2512975557014525}, {4.740636372927804, \
1.2202099292273982}, {4.427050983124843, 1.763355756877417}, 
    {4.397402461894534, 1.7786275248098171}, {4.70927470341199, \
1.2512975557014525}}], 
  Line[{{4.427050983124843, 1.763355756877417}, {4.397402461894534, \
1.7786275248098171}, {3.980035937748391, 2.235484296800203}, 
    {4.007391819076576, 2.2294344764321816}, {4.427050983124843, \
1.763355756877417}}], 
  Line[{{4.397402461894534, 1.7786275248098171}, {4.309752680850761, \
1.82020538579592}, {3.8991638770459636, 2.2513313265781}, 
    {3.980035937748391, 2.235484296800203}, {4.397402461894534, \
1.7786275248098171}}], 
  Line[{{4.309752680850761, 1.82020538579592}, {4.167932356015448, \
1.8768892930626255}, {3.7683101340891887, 2.2706462108209022}, 
    {3.8991638770459636, 2.2513313265781}, {4.309752680850761, \
1.82020538579592}}], 
  Line[{{4.167932356015448, 1.8768892930626255}, {3.9781397161133225, \
1.9339672857886046}, {3.593193645351205, 2.284543605895154}, 
    {3.7683101340891887, 2.2706462108209022}, {4.167932356015448, \
1.8768892930626255}}], 
  Line[{{3.9781397161133225, 1.9339672857886046}, {3.748669610234238, \
1.976615915035448}, {3.3814678416920034, 2.283369148915068}, 
    {3.593193645351205, 2.284543605895154}, {3.9781397161133225, \
1.9339672857886046}}], 
  Line[{{3.748669610234238, 1.976615915035448}, {3.489550983124843, \
1.9921691365624095}, {3.1423861567046174, 2.258303983491545}, 
    {3.3814678416920034, 2.283369148915068}, {3.748669610234238, \
1.976615915035448}}], 
  Line[{{3.489550983124843, 1.9921691365624095}, {3.212108562178944, \
1.97128525856985}, {2.8863976072642052, 2.202570463435661}, 
    {3.1423861567046174, 2.258303983491545}, {3.489550983124843, \
1.9921691365624095}}], 
  Line[{{3.212108562178944, 1.97128525856985}, {2.92846791250832, \
1.908454380799519}, {2.6246901213506577, 2.1122635155465685}, 
    {2.8863976072642052, 2.202570463435661}, {3.212108562178944, \
1.97128525856985}}], 
  Line[{{2.92846791250832, 1.908454380799519}, {2.6510254915624216, \
1.8022456366013602}, {2.368701571910245, 1.9869545564435855}, 
    {2.6246901213506577, 2.1122635155465685}, {2.92846791250832, \
1.908454380799519}}], 
  Line[{{2.6510254915624216, 1.8022456366013602}, {2.391906864453027, \
1.6555895184432492}, {2.12961988692286, 1.8302685290560392}, 
    {2.368701571910245, 1.9869545564435855}, {2.6510254915624216, \
1.8022456366013602}}], 
  Line[{{2.391906864453027, 1.6555895184432492}, {2.162436758573942, \
1.4764049667388979}, {1.9178940832636582, 1.6506863454327514}, 
    {2.12961988692286, 1.8302685290560392}, {2.391906864453027, \
1.6555895184432492}}], 
  Line[{{2.162436758573942, 1.4764049667388979}, {1.972644118671816, \
1.2790742990138138}, {1.7427775945256736, 1.4628718195622255}, 
    {1.9178940832636582, 1.6506863454327514}, {2.162436758573942, \
1.4764049667388979}}], 
  Line[{{1.972644118671816, 1.2790742990138138}, {1.8308237938365044, \
1.0875191232355923}, {1.6119238515689, 1.2895708590441461}, 
    {1.7427775945256736, 1.4628718195622255}, {1.972644118671816, \
1.2790742990138138}}], 
  Line[{{1.8308237938365044, 1.0875191232355923}, {1.7431740127927307, \
0.9393665425693399}, {1.5310517908664718, 1.1623542887261813}, 
    {1.6119238515689, 1.2895708590441461}, {1.8308237938365044, \
1.0875191232355923}}], 
  Line[{{1.7431740127927307, 0.9393665425693399}, {1.7135254915624214, \
0.8816778784387095}, {1.5036959095382878, 1.114717238216091}, 
    {1.5310517908664718, 1.1623542887261813}, {1.7431740127927307, \
0.9393665425693399}}], 
  Line[{{1.7135254915624214, 0.8816778784387095}, {1.7431740127927309, \
0.9393665425693389}, {1.531051790866472, 1.1623542887261806}, 
    {1.5036959095382878, 1.114717238216091}, {1.7135254915624214, \
0.8816778784387095}}], 
  Line[{{1.7431740127927309, 0.9393665425693389}, {1.8308237938365042, \
1.0875191232355914}, {1.6119238515688998, 1.289570859044146}, 
    {1.531051790866472, 1.1623542887261806}, {1.7431740127927309, \
0.9393665425693389}}], 
  Line[{{1.8308237938365042, 1.0875191232355914}, {1.9726441186718162, \
1.279074299013813}, {1.7427775945256734, 1.4628718195622255}, 
    {1.6119238515688998, 1.289570859044146}, {1.8308237938365042, \
1.0875191232355914}}], 
  Line[{{1.9726441186718162, 1.279074299013813}, {2.162436758573941, \
1.4764049667388972}, {1.9178940832636575, 1.650686345432751}, 
    {1.7427775945256734, 1.4628718195622255}, {1.9726441186718162, \
1.279074299013813}}], 
  Line[{{2.162436758573941, 1.4764049667388972}, {2.391906864453026, \
1.6555895184432483}, {2.129619886922859, 1.8302685290560388}, 
    {1.9178940832636575, 1.650686345432751}, {2.162436758573941, \
1.4764049667388972}}], 
  Line[{{2.391906864453026, 1.6555895184432483}, {2.6510254915624207, \
1.8022456366013606}, {2.368701571910245, 1.9869545564435847}, 
    {2.129619886922859, 1.8302685290560388}, {2.391906864453026, \
1.6555895184432483}}], 
  Line[{{2.6510254915624207, 1.8022456366013606}, {2.928467912508319, \
1.9084543807995185}, {2.624690121350657, 2.112263515546568}, 
    {2.368701571910245, 1.9869545564435847}, {2.6510254915624207, \
1.8022456366013606}}], 
  Line[{{2.928467912508319, 1.9084543807995185}, {3.212108562178943, \
1.9712852585698486}, {2.886397607264204, 2.202570463435661}, 
    {2.624690121350657, 2.112263515546568}, {2.928467912508319, \
1.9084543807995185}}], 
  Line[{{3.212108562178943, 1.9712852585698486}, {3.489550983124843, \
1.9921691365624086}, {3.1423861567046174, 2.258303983491545}, 
    {2.886397607264204, 2.202570463435661}, {3.212108562178943, \
1.9712852585698486}}], 
  Line[{{3.489550983124843, 1.9921691365624086}, {3.7486696102342365, \
1.976615915035448}, {3.3814678416920025, 2.283369148915068}, 
    {3.1423861567046174, 2.258303983491545}, {3.489550983124843, \
1.9921691365624086}}], 
  Line[{{3.7486696102342365, 1.976615915035448}, {3.9781397161133225, \
1.9339672857886046}, {3.593193645351205, 2.284543605895153}, 
    {3.3814678416920025, 2.283369148915068}, {3.7486696102342365, \
1.976615915035448}}], 
  Line[{{3.9781397161133225, 1.9339672857886046}, {4.167932356015448, \
1.8768892930626255}, {3.7683101340891887, 2.2706462108209022}, 
    {3.593193645351205, 2.284543605895153}, {3.9781397161133225, \
1.9339672857886046}}], 
  Line[{{4.167932356015448, 1.8768892930626255}, {4.309752680850761, \
1.820205385795918}, {3.8991638770459627, 2.251331326578101}, 
    {3.7683101340891887, 2.2706462108209022}, {4.167932356015448, \
1.8768892930626255}}], 
  Line[{{4.309752680850761, 1.820205385795918}, {4.397402461894534, \
1.7786275248098171}, {3.980035937748391, 2.235484296800203}, 
    {3.8991638770459627, 2.251331326578101}, {4.309752680850761, \
1.820205385795918}}], 
  Line[{{4.397402461894534, 1.7786275248098171}, {4.427050983124843, \
1.763355756877417}, {4.007391819076576, 2.2294344764321816}, 
    {3.980035937748391, 2.235484296800203}, {4.397402461894534, \
1.7786275248098171}}], 
  Line[{{4.427050983124843, 1.763355756877417}, {4.397402461894535, \
1.778627524809816}, {3.9800359377483914, 2.235484296800203}, 
    {4.007391819076576, 2.2294344764321816}, {4.427050983124843, \
1.763355756877417}}], 
  Line[{{4.397402461894535, 1.778627524809816}, {4.309752680850761, \
1.8202053857959188}, {3.899163877045963, 2.251331326578101}, 
    {3.9800359377483914, 2.235484296800203}, {4.397402461894535, \
1.778627524809816}}], 
  Line[{{4.309752680850761, 1.8202053857959188}, {4.167932356015449, \
1.8768892930626246}, {3.7683101340891896, 2.2706462108209013}, 
    {3.899163877045963, 2.251331326578101}, {4.309752680850761, \
1.8202053857959188}}], 
  Line[{{4.167932356015449, 1.8768892930626246}, {3.978139716113324, \
1.9339672857886037}, {3.593193645351206, 2.284543605895153}, 
    {3.7683101340891896, 2.2706462108209013}, {4.167932356015449, \
1.8768892930626246}}], 
  Line[{{3.978139716113324, 1.9339672857886037}, {3.7486696102342387, \
1.9766159150354476}, {3.3814678416920043, 2.2833691489150674}, 
    {3.593193645351206, 2.284543605895153}, {3.978139716113324, \
1.9339672857886037}}], 
  Line[{{3.7486696102342387, 1.9766159150354476}, {3.4895509831248437, \
1.9921691365624086}, {3.1423861567046183, 2.258303983491545}, 
    {3.3814678416920043, 2.2833691489150674}, {3.7486696102342387, \
1.9766159150354476}}], 
  Line[{{3.4895509831248437, 1.9921691365624086}, {3.2121085621789454, \
1.971285258569849}, {2.886397607264206, 2.202570463435661}, 
    {3.1423861567046183, 2.258303983491545}, {3.4895509831248437, \
1.9921691365624086}}], 
  Line[{{3.2121085621789454, 1.971285258569849}, {2.928467912508321, \
1.9084543807995193}, {2.6246901213506586, 2.1122635155465685}, 
    {2.886397607264206, 2.202570463435661}, {3.2121085621789454, \
1.971285258569849}}], 
  Line[{{2.928467912508321, 1.9084543807995193}, {2.651025491562422, \
1.8022456366013606}, {2.368701571910246, 1.9869545564435855}, 
    {2.6246901213506586, 2.1122635155465685}, {2.928467912508321, \
1.9084543807995193}}], 
  Line[{{2.651025491562422, 1.8022456366013606}, {2.391906864453028, \
1.6555895184432494}, {2.1296198869228604, 1.83026852905604}, 
    {2.368701571910246, 1.9869545564435855}, {2.651025491562422, \
1.8022456366013606}}], 
  Line[{{2.391906864453028, 1.6555895184432494}, {2.1624367585739424, \
1.4764049667388996}, {1.917894083263659, 1.6506863454327527}, 
    {2.1296198869228604, 1.83026852905604}, {2.391906864453028, \
1.6555895184432494}}], 
  Line[{{2.1624367585739424, 1.4764049667388996}, {1.9726441186718164, \
1.2790742990138138}, {1.7427775945256738, 1.4628718195622255}, 
    {1.917894083263659, 1.6506863454327527}, {2.1624367585739424, \
1.4764049667388996}}], 
  Line[{{1.9726441186718164, 1.2790742990138138}, {1.830823793836505, \
1.0875191232355925}, {1.6119238515689007, 1.2895708590441464}, 
    {1.7427775945256738, 1.4628718195622255}, {1.9726441186718164, \
1.2790742990138138}}], 
  Line[{{1.830823793836505, 1.0875191232355925}, {1.7431740127927313, \
0.9393665425693402}, {1.5310517908664723, 1.1623542887261817}, 
    {1.6119238515689007, 1.2895708590441464}, {1.830823793836505, \
1.0875191232355925}}], 
  Line[{{1.7431740127927313, 0.9393665425693402}, {1.7135254915624214, \
0.8816778784387095}, {1.5036959095382878, 1.114717238216091}, 
    {1.5310517908664723, 1.1623542887261817}, {1.7431740127927313, \
0.9393665425693402}}], 
  Line[{{1.7135254915624214, 0.8816778784387095}, {1.7431740127927304, \
0.9393665425693389}, {1.5310517908664716, 1.1623542887261806}, 
    {1.5036959095382878, 1.114717238216091}, {1.7135254915624214, \
0.8816778784387095}}], 
  Line[{{1.7431740127927304, 0.9393665425693389}, {1.8308237938365033, \
1.0875191232355905}, {1.6119238515688992, 1.289570859044145}, 
    {1.5310517908664716, 1.1623542887261806}, {1.7431740127927304, \
0.9393665425693389}}], 
  Line[{{1.8308237938365033, 1.0875191232355905}, {1.9726441186718158, \
1.279074299013813}, {1.7427775945256732, 1.462871819562225}, 
    {1.6119238515688992, 1.289570859044145}, {1.8308237938365033, \
1.0875191232355905}}], 
  Line[{{1.9726441186718158, 1.279074299013813}, {2.16243675857394, \
1.476404966738897}, {1.9178940832636568, 1.6506863454327505}, 
    {1.7427775945256732, 1.462871819562225}, {1.9726441186718158, \
1.279074299013813}}], 
  Line[{{2.16243675857394, 1.476404966738897}, {2.391906864453025, \
1.6555895184432476}, {2.1296198869228578, 1.830268529056038}, 
    {1.9178940832636568, 1.6506863454327505}, {2.16243675857394, \
1.476404966738897}}], 
  Line[{{2.391906864453025, 1.6555895184432476}, {2.6510254915624207, \
1.8022456366013606}, {2.368701571910245, 1.9869545564435847}, 
    {2.1296198869228578, 1.830268529056038}, {2.391906864453025, \
1.6555895184432476}}], 
  Line[{{2.6510254915624207, 1.8022456366013606}, {2.928467912508318, \
1.908454380799519}, {2.6246901213506564, 2.112263515546568}, 
    {2.368701571910245, 1.9869545564435847}, {2.6510254915624207, \
1.8022456366013606}}], 
  Line[{{2.928467912508318, 1.908454380799519}, {3.2121085621789414, \
1.9712852585698495}, {2.8863976072642026, 2.2025704634356607}, 
    {2.6246901213506564, 2.112263515546568}, {2.928467912508318, \
1.908454380799519}}], 
  Line[{{3.2121085621789414, 1.9712852585698495}, {3.489550983124843, \
1.9921691365624086}, {3.1423861567046174, 2.258303983491545}, 
    {2.8863976072642026, 2.2025704634356607}, {3.2121085621789414, \
1.9712852585698495}}], 
  Line[{{3.489550983124843, 1.9921691365624086}, {3.748669610234236, \
1.976615915035449}, {3.381467841692002, 2.283369148915068}, 
    {3.1423861567046174, 2.258303983491545}, {3.489550983124843, \
1.9921691365624086}}], 
  Line[{{3.748669610234236, 1.976615915035449}, {3.978139716113321, \
1.9339672857886046}, {3.5931936453512034, 2.2845436058951534}, 
    {3.381467841692002, 2.283369148915068}, {3.748669610234236, \
1.976615915035449}}], 
  Line[{{3.978139716113321, 1.9339672857886046}, {4.167932356015449, \
1.8768892930626246}, {3.768310134089189, 2.2706462108209013}, 
    {3.5931936453512034, 2.2845436058951534}, {3.978139716113321, \
1.9339672857886046}}], 
  Line[{{4.167932356015449, 1.8768892930626246}, {4.309752680850761, \
1.820205385795918}, {3.8991638770459627, 2.251331326578101}, 
    {3.768310134089189, 2.2706462108209013}, {4.167932356015449, \
1.8768892930626246}}], 
  Line[{{4.309752680850761, 1.820205385795918}, {4.397402461894534, \
1.7786275248098171}, {3.980035937748391, 2.235484296800203}, 
    {3.8991638770459627, 2.251331326578101}, {4.309752680850761, \
1.820205385795918}}], 
  Line[{{4.397402461894534, 1.7786275248098171}, {4.427050983124843, \
1.763355756877417}, {4.007391819076576, 2.2294344764321816}, 
    {3.980035937748391, 2.235484296800203}, {4.397402461894534, \
1.7786275248098171}}], 
  Line[{{4.007391819076576, 2.2294344764321816}, {3.980035937748391, \
2.235484296800203}, {3.4754160508255314, 2.5979598975817524}, 
    {3.500000000000001, 2.598076211353315}, {4.007391819076576, \
2.2294344764321816}}], 
  Line[{{3.980035937748391, 2.235484296800203}, {3.8991638770459636, \
2.2513313265781}, {3.402738639847927, 2.596255039055556}, 
    {3.4754160508255314, 2.5979598975817524}, {3.980035937748391, \
2.235484296800203}}], 
  Line[{{3.8991638770459636, 2.2513313265781}, {3.7683101340891887, \
2.2706462108209022}, {3.2851441186718167, 2.589176886629936}, 
    {3.402738639847927, 2.596255039055556}, {3.8991638770459636, \
2.2513313265781}}], 
  Line[{{3.7683101340891887, 2.2706462108209022}, {3.593193645351205, \
2.284543605895154}, {3.127771932153716, 2.5712732770958864}, 
    {3.2851441186718167, 2.589176886629936}, {3.7683101340891887, \
2.2706462108209022}}], 
  Line[{{3.593193645351205, 2.284543605895154}, {3.3814678416920034, \
2.283369148915068}, {2.937500000000001, 2.536452985962878}, 
    {3.127771932153716, 2.5712732770958864}, {3.593193645351205, \
2.284543605895154}}], 
  Line[{{3.3814678416920034, 2.283369148915068}, {3.1423861567046174, \
2.258303983491545}, {2.7226441186718167, 2.479055835144598}, 
    {2.937500000000001, 2.536452985962878}, {3.3814678416920034, \
2.283369148915068}}], 
  Line[{{3.1423861567046174, 2.258303983491545}, {2.8863976072642052, \
2.202570463435661}, {2.492594521176111, 2.3948140222646956}, 
    {2.7226441186718167, 2.479055835144598}, {3.1423861567046174, \
2.258303983491545}}], 
  Line[{{2.8863976072642052, 2.202570463435661}, {2.6246901213506577, \
2.1122635155465685}, {2.25740547882389, 2.281657041700859}, 
    {2.492594521176111, 2.3948140222646956}, {2.8863976072642052, \
2.202570463435661}}], 
  Line[{{2.6246901213506577, 2.1122635155465685}, {2.368701571910245, \
1.9869545564435855}, {2.0273558813281847, 2.1404016678514597}, 
    {2.25740547882389, 2.281657041700859}, {2.6246901213506577, \
2.1122635155465685}}], 
  Line[{{2.368701571910245, 1.9869545564435855}, {2.12961988692286, \
1.8302685290560392}, {1.8125000000000009, 1.9754350786598884}, 
    {2.0273558813281847, 2.1404016678514597}, {2.368701571910245, \
1.9869545564435855}}], 
  Line[{{2.12961988692286, 1.8302685290560392}, {1.9178940832636582, \
1.6506863454327514}, {1.6222280678462853, 1.7955424168801197}, 
    {1.8125000000000009, 1.9754350786598884}, {2.12961988692286, \
1.8302685290560392}}], 
  Line[{{1.9178940832636582, 1.6506863454327514}, {1.7427775945256736, \
1.4628718195622255}, {1.4648558813281845, 1.6149886737174097}, 
    {1.6222280678462853, 1.7955424168801197}, {1.9178940832636582, \
1.6506863454327514}}], 
  Line[{{1.7427775945256736, 1.4628718195622255}, {1.6119238515689, \
1.2895708590441461}, {1.3472613601520744, 1.454550222063749}, 
    {1.4648558813281845, 1.6149886737174097}, {1.7427775945256736, \
1.4628718195622255}}], 
  Line[{{1.6119238515689, 1.2895708590441461}, {1.5310517908664718, \
1.1623542887261813}, {1.274583949174469, 1.3407174947497684}, 
    {1.3472613601520744, 1.454550222063749}, {1.6119238515689, \
1.2895708590441461}}], 
  Line[{{1.5310517908664718, 1.1623542887261813}, {1.5036959095382878, \
1.114717238216091}, {1.2500000000000004, 1.2990381056766576}, 
    {1.274583949174469, 1.3407174947497684}, {1.5310517908664718, \
1.1623542887261813}}], 
  Line[{{1.5036959095382878, 1.114717238216091}, {1.531051790866472, \
1.1623542887261806}, {1.2745839491744693, 1.3407174947497684}, 
    {1.2500000000000004, 1.2990381056766576}, {1.5036959095382878, \
1.114717238216091}}], 
  Line[{{1.531051790866472, 1.1623542887261806}, {1.6119238515688998, \
1.289570859044146}, {1.3472613601520744, 1.4545502220637483}, 
    {1.2745839491744693, 1.3407174947497684}, {1.531051790866472, \
1.1623542887261806}}], 
  Line[{{1.6119238515688998, 1.289570859044146}, {1.7427775945256734, \
1.4628718195622255}, {1.4648558813281847, 1.6149886737174093}, 
    {1.3472613601520744, 1.4545502220637483}, {1.6119238515688998, \
1.289570859044146}}], 
  Line[{{1.7427775945256734, 1.4628718195622255}, {1.9178940832636575, \
1.650686345432751}, {1.6222280678462848, 1.7955424168801193}, 
    {1.4648558813281847, 1.6149886737174093}, {1.7427775945256734, \
1.4628718195622255}}], 
  Line[{{1.9178940832636575, 1.650686345432751}, {2.129619886922859, \
1.8302685290560388}, {1.8125, 1.9754350786598878}, 
    {1.6222280678462848, 1.7955424168801193}, {1.9178940832636575, \
1.650686345432751}}], 
  Line[{{2.129619886922859, 1.8302685290560388}, {2.368701571910245, \
1.9869545564435847}, {2.0273558813281842, 2.1404016678514597}, 
    {1.8125, 1.9754350786598878}, {2.129619886922859, 1.8302685290560388}}], 
  Line[{{2.368701571910245, 1.9869545564435847}, {2.624690121350657, \
2.112263515546568}, {2.2574054788238893, 2.281657041700858}, 
    {2.0273558813281842, 2.1404016678514597}, {2.368701571910245, \
1.9869545564435847}}], 
  Line[{{2.624690121350657, 2.112263515546568}, {2.886397607264204, \
2.202570463435661}, {2.49259452117611, 2.394814022264695}, 
    {2.2574054788238893, 2.281657041700858}, {2.624690121350657, \
2.112263515546568}}], 
  Line[{{2.886397607264204, 2.202570463435661}, {3.1423861567046174, \
2.258303983491545}, {2.7226441186718158, 2.479055835144599}, 
    {2.49259452117611, 2.394814022264695}, {2.886397607264204, \
2.202570463435661}}], 
  Line[{{3.1423861567046174, 2.258303983491545}, {3.3814678416920025, \
2.283369148915068}, {2.9374999999999996, 2.536452985962878}, 
    {2.7226441186718158, 2.479055835144599}, {3.1423861567046174, \
2.258303983491545}}], 
  Line[{{3.3814678416920025, 2.283369148915068}, {3.593193645351205, \
2.284543605895153}, {3.127771932153715, 2.5712732770958873}, 
    {2.9374999999999996, 2.536452985962878}, {3.3814678416920025, \
2.283369148915068}}], 
  Line[{{3.593193645351205, 2.284543605895153}, {3.7683101340891887, \
2.2706462108209022}, {3.2851441186718167, 2.589176886629936}, 
    {3.127771932153715, 2.5712732770958873}, {3.593193645351205, \
2.284543605895153}}], 
  Line[{{3.7683101340891887, 2.2706462108209022}, {3.8991638770459627, \
2.251331326578101}, {3.4027386398479265, 2.596255039055556}, 
    {3.2851441186718167, 2.589176886629936}, {3.7683101340891887, \
2.2706462108209022}}], 
  Line[{{3.8991638770459627, 2.251331326578101}, {3.980035937748391, \
2.235484296800203}, {3.4754160508255314, 2.5979598975817524}, 
    {3.4027386398479265, 2.596255039055556}, {3.8991638770459627, \
2.251331326578101}}], 
  Line[{{3.980035937748391, 2.235484296800203}, {4.007391819076576, \
2.2294344764321816}, {3.500000000000001, 2.598076211353315}, 
    {3.4754160508255314, 2.5979598975817524}, {3.980035937748391, \
2.235484296800203}}], 
  Line[{{4.007391819076576, 2.2294344764321816}, {3.9800359377483914, \
2.235484296800203}, {3.4754160508255323, 2.597959897581752}, 
    {3.500000000000001, 2.598076211353315}, {4.007391819076576, \
2.2294344764321816}}], 
  Line[{{3.9800359377483914, 2.235484296800203}, {3.899163877045963, \
2.251331326578101}, {3.402738639847927, 2.596255039055556}, 
    {3.4754160508255323, 2.597959897581752}, {3.9800359377483914, \
2.235484296800203}}], 
  Line[{{3.899163877045963, 2.251331326578101}, {3.7683101340891896, \
2.2706462108209013}, {3.285144118671817, 2.589176886629936}, 
    {3.402738639847927, 2.596255039055556}, {3.899163877045963, \
2.251331326578101}}], 
  Line[{{3.7683101340891896, 2.2706462108209013}, {3.593193645351206, \
2.284543605895153}, {3.1277719321537174, 2.5712732770958864}, 
    {3.285144118671817, 2.589176886629936}, {3.7683101340891896, \
2.2706462108209013}}], 
  Line[{{3.593193645351206, 2.284543605895153}, {3.3814678416920043, \
2.2833691489150674}, {2.9375000000000013, 2.5364529859628786}, 
    {3.1277719321537174, 2.5712732770958864}, {3.593193645351206, \
2.284543605895153}}], 
  Line[{{3.3814678416920043, 2.2833691489150674}, {3.1423861567046183, \
2.258303983491545}, {2.722644118671817, 2.479055835144598}, 
    {2.9375000000000013, 2.5364529859628786}, {3.3814678416920043, \
2.2833691489150674}}], 
  Line[{{3.1423861567046183, 2.258303983491545}, {2.886397607264206, \
2.202570463435661}, {2.492594521176112, 2.394814022264695}, 
    {2.722644118671817, 2.479055835144598}, {3.1423861567046183, \
2.258303983491545}}], 
  Line[{{2.886397607264206, 2.202570463435661}, {2.6246901213506586, \
2.1122635155465685}, {2.257405478823891, 2.281657041700859}, 
    {2.492594521176112, 2.394814022264695}, {2.886397607264206, \
2.202570463435661}}], 
  Line[{{2.6246901213506586, 2.1122635155465685}, {2.368701571910246, \
1.9869545564435855}, {2.027355881328185, 2.14040166785146}, 
    {2.257405478823891, 2.281657041700859}, {2.6246901213506586, \
2.1122635155465685}}], 
  Line[{{2.368701571910246, 1.9869545564435855}, {2.1296198869228604, \
1.83026852905604}, {1.8125000000000016, 1.975435078659889}, 
    {2.027355881328185, 2.14040166785146}, {2.368701571910246, \
1.9869545564435855}}], 
  Line[{{2.1296198869228604, 1.83026852905604}, {1.917894083263659, \
1.6506863454327527}, {1.622228067846286, 1.7955424168801213}, 
    {1.8125000000000016, 1.975435078659889}, {2.1296198869228604, \
1.83026852905604}}], 
  Line[{{1.917894083263659, 1.6506863454327527}, {1.7427775945256738, \
1.4628718195622255}, {1.4648558813281847, 1.6149886737174095}, 
    {1.622228067846286, 1.7955424168801213}, {1.917894083263659, \
1.6506863454327527}}], 
  Line[{{1.7427775945256738, 1.4628718195622255}, {1.6119238515689007, \
1.2895708590441464}, {1.3472613601520749, 1.4545502220637494}, 
    {1.4648558813281847, 1.6149886737174095}, {1.7427775945256738, \
1.4628718195622255}}], 
  Line[{{1.6119238515689007, 1.2895708590441464}, {1.5310517908664723, \
1.1623542887261817}, {1.2745839491744695, 1.340717494749769}, 
    {1.3472613601520749, 1.4545502220637494}, {1.6119238515689007, \
1.2895708590441464}}], 
  Line[{{1.5310517908664723, 1.1623542887261817}, {1.5036959095382878, \
1.114717238216091}, {1.2500000000000004, 1.2990381056766576}, 
    {1.2745839491744695, 1.340717494749769}, {1.5310517908664723, \
1.1623542887261817}}], 
  Line[{{1.5036959095382878, 1.114717238216091}, {1.5310517908664716, \
1.1623542887261806}, {1.274583949174469, 1.3407174947497678}, 
    {1.2500000000000004, 1.2990381056766576}, {1.5036959095382878, \
1.114717238216091}}], 
  Line[{{1.5310517908664716, 1.1623542887261806}, {1.6119238515688992, \
1.289570859044145}, {1.3472613601520738, 1.4545502220637476}, 
    {1.274583949174469, 1.3407174947497678}, {1.5310517908664716, \
1.1623542887261806}}], 
  Line[{{1.6119238515688992, 1.289570859044145}, {1.7427775945256732, \
1.462871819562225}, {1.4648558813281845, 1.6149886737174093}, 
    {1.3472613601520738, 1.4545502220637476}, {1.6119238515688992, \
1.289570859044145}}], 
  Line[{{1.7427775945256732, 1.462871819562225}, {1.9178940832636568, \
1.6506863454327505}, {1.622228067846284, 1.795542416880119}, 
    {1.4648558813281845, 1.6149886737174093}, {1.7427775945256732, \
1.462871819562225}}], 
  Line[{{1.9178940832636568, 1.6506863454327505}, {2.1296198869228578, \
1.830268529056038}, {1.812499999999999, 1.9754350786598873}, 
    {1.622228067846284, 1.795542416880119}, {1.9178940832636568, \
1.6506863454327505}}], 
  Line[{{2.1296198869228578, 1.830268529056038}, {2.368701571910245, \
1.9869545564435847}, {2.027355881328184, 2.1404016678514597}, 
    {1.812499999999999, 1.9754350786598873}, {2.1296198869228578, \
1.830268529056038}}], 
  Line[{{2.368701571910245, 1.9869545564435847}, {2.6246901213506564, \
2.112263515546568}, {2.257405478823889, 2.281657041700858}, 
    {2.027355881328184, 2.1404016678514597}, {2.368701571910245, \
1.9869545564435847}}], 
  Line[{{2.6246901213506564, 2.112263515546568}, {2.8863976072642026, \
2.2025704634356607}, {2.492594521176109, 2.3948140222646943}, 
    {2.257405478823889, 2.281657041700858}, {2.6246901213506564, \
2.112263515546568}}], 
  Line[{{2.8863976072642026, 2.2025704634356607}, {3.1423861567046174, \
2.258303983491545}, {2.722644118671816, 2.4790558351445986}, 
    {2.492594521176109, 2.3948140222646943}, {2.8863976072642026, \
2.2025704634356607}}], 
  Line[{{3.1423861567046174, 2.258303983491545}, {3.381467841692002, \
2.283369148915068}, {2.9375, 2.5364529859628773}, 
    {2.722644118671816, 2.4790558351445986}, {3.1423861567046174, \
2.258303983491545}}], 
  Line[{{3.381467841692002, 2.283369148915068}, {3.5931936453512034, \
2.2845436058951534}, {3.1277719321537143, 2.571273277095887}, 
    {2.9375, 2.5364529859628773}, {3.381467841692002, 2.283369148915068}}], 
  Line[{{3.5931936453512034, 2.2845436058951534}, {3.768310134089189, \
2.2706462108209013}, {3.2851441186718167, 2.589176886629936}, 
    {3.1277719321537143, 2.571273277095887}, {3.5931936453512034, \
2.2845436058951534}}], 
  Line[{{3.768310134089189, 2.2706462108209013}, {3.8991638770459627, \
2.251331326578101}, {3.4027386398479265, 2.596255039055556}, 
    {3.2851441186718167, 2.589176886629936}, {3.768310134089189, \
2.2706462108209013}}], 
  Line[{{3.8991638770459627, 2.251331326578101}, {3.980035937748391, \
2.235484296800203}, {3.475416050825532, 2.597959897581752}, 
    {3.4027386398479265, 2.596255039055556}, {3.8991638770459627, \
2.251331326578101}}], 
  Line[{{3.980035937748391, 2.235484296800203}, {4.007391819076576, \
2.2294344764321816}, {3.500000000000001, 2.598076211353315}, 
    {3.475416050825532, 2.597959897581752}, {3.980035937748391, \
2.235484296800203}}], 
  Line[{{3.500000000000001, 2.598076211353315}, {3.4754160508255314, \
2.5979598975817524}, {2.9055971116193557, 2.8487773266631815}, 
    {2.9270509831248424, 2.8531695488854605}, {3.500000000000001, \
2.598076211353315}}], 
  Line[{{3.4754160508255314, 2.5979598975817524}, {3.402738639847927, \
2.596255039055556}, {2.842173134234785, 2.834803496770629}, 
    {2.9055971116193557, 2.8487773266631815}, {3.4754160508255314, \
2.5979598975817524}}], 
  Line[{{3.402738639847927, 2.596255039055556}, {3.2851441186718167, \
2.589176886629936}, {2.739550983124842, 2.809014835019403}, 
    {2.842173134234785, 2.834803496770629}, {3.402738639847927, \
2.596255039055556}}], 
  Line[{{3.2851441186718167, 2.589176886629936}, {3.127771932153716, \
2.5712732770958864}, {2.602215738728751, 2.768181798733441}, 
    {2.739550983124842, 2.809014835019403}, {3.2851441186718167, \
2.589176886629936}}], 
  Line[{{3.127771932153716, 2.5712732770958864}, {2.937500000000001, \
2.536452985962878}, {2.4361696102342374, 2.7087103854853694}, 
    {2.602215738728751, 2.768181798733441}, {3.127771932153716, \
2.5712732770958864}}], 
  Line[{{2.937500000000001, 2.536452985962878}, {2.7226441186718167, \
2.479055835144598}, {2.248669610234237, 2.6273597595826383}, 
    {2.4361696102342374, 2.7087103854853694}, {2.937500000000001, \
2.536452985962878}}], 
  Line[{{2.7226441186718167, 2.479055835144598}, {2.492594521176111, \
2.3948140222646956}, {2.047910388453574, 2.521960112821855}, 
    {2.248669610234237, 2.6273597595826383}, {2.7226441186718167, \
2.479055835144598}}], 
  Line[{{2.492594521176111, 2.3948140222646956}, {2.25740547882389, \
2.281657041700859}, {1.8426660862336899, 2.392089327116677}, 
    {2.047910388453574, 2.521960112821855}, {2.492594521176111, \
2.3948140222646956}}], 
  Line[{{2.25740547882389, 2.281657041700859}, {2.0273558813281847, \
2.1404016678514597}, {1.6419068644530266, 2.239718051509763}, 
    {1.8426660862336899, 2.392089327116677}, {2.25740547882389, \
2.281657041700859}}], 
  Line[{{2.0273558813281847, 2.1404016678514597}, {1.8125000000000009, \
1.9754350786598884}, {1.4544068644530268, 2.069878202800487}, 
    {1.6419068644530266, 2.239718051509763}, {2.0273558813281847, \
2.1404016678514597}}], 
  Line[{{1.8125000000000009, 1.9754350786598884}, {1.6222280678462853, \
1.7955424168801197}, {1.2883607359585132, 1.8914277190459865}, 
    {1.4544068644530268, 2.069878202800487}, {1.8125000000000009, \
1.9754350786598884}}], 
  Line[{{1.6222280678462853, 1.7955424168801197}, {1.4648558813281845, \
1.6149886737174097}, {1.1510254915624212, 1.7178957504272219}, 
    {1.2883607359585132, 1.8914277190459865}, {1.6222280678462853, \
1.7955424168801197}}], 
  Line[{{1.4648558813281845, 1.6149886737174097}, {1.3472613601520744, \
1.454550222063749}, {1.0484033404524795, 1.5679671136605227}, 
    {1.1510254915624212, 1.7178957504272219}, {1.4648558813281845, \
1.6149886737174097}}], 
  Line[{{1.3472613601520744, 1.454550222063749}, {1.274583949174469, \
1.3407174947497684}, {0.9849793630679076, 1.4640759018681937}, 
    {1.0484033404524795, 1.5679671136605227}, {1.3472613601520744, \
1.454550222063749}}], 
  Line[{{1.274583949174469, 1.3407174947497684}, {1.2500000000000004, \
1.2990381056766576}, {0.9635254915624213, 1.4265847744427302}, 
    {0.9849793630679076, 1.4640759018681937}, {1.274583949174469, \
1.3407174947497684}}], 
  Line[{{1.2500000000000004, 1.2990381056766576}, {1.2745839491744693, \
1.3407174947497684}, {0.9849793630679076, 1.4640759018681933}, 
    {0.9635254915624213, 1.4265847744427302}, {1.2500000000000004, \
1.2990381056766576}}], 
  Line[{{1.2745839491744693, 1.3407174947497684}, {1.3472613601520744, \
1.4545502220637483}, {1.0484033404524795, 1.5679671136605224}, 
    {0.9849793630679076, 1.4640759018681933}, {1.2745839491744693, \
1.3407174947497684}}], 
  Line[{{1.3472613601520744, 1.4545502220637483}, {1.4648558813281847, \
1.6149886737174093}, {1.1510254915624214, 1.7178957504272216}, 
    {1.0484033404524795, 1.5679671136605224}, {1.3472613601520744, \
1.4545502220637483}}], 
  Line[{{1.4648558813281847, 1.6149886737174093}, {1.6222280678462848, \
1.7955424168801193}, {1.2883607359585125, 1.8914277190459858}, 
    {1.1510254915624214, 1.7178957504272216}, {1.4648558813281847, \
1.6149886737174093}}], 
  Line[{{1.6222280678462848, 1.7955424168801193}, {1.8125, \
1.9754350786598878}, {1.454406864453026, 2.0698782028004867}, 
    {1.2883607359585125, 1.8914277190459858}, {1.6222280678462848, \
1.7955424168801193}}], 
  Line[{{1.8125, 1.9754350786598878}, {2.0273558813281842, \
2.1404016678514597}, {1.6419068644530261, 2.239718051509763}, 
    {1.454406864453026, 2.0698782028004867}, {1.8125, 1.9754350786598878}}], 
  Line[{{2.0273558813281842, 2.1404016678514597}, {2.2574054788238893, \
2.281657041700858}, {1.8426660862336892, 2.3920893271166763}, 
    {1.6419068644530261, 2.239718051509763}, {2.0273558813281842, \
2.1404016678514597}}], 
  Line[{{2.2574054788238893, 2.281657041700858}, {2.49259452117611, \
2.394814022264695}, {2.0479103884535728, 2.521960112821855}, 
    {1.8426660862336892, 2.3920893271166763}, {2.2574054788238893, \
2.281657041700858}}], 
  Line[{{2.49259452117611, 2.394814022264695}, {2.7226441186718158, \
2.479055835144599}, {2.248669610234237, 2.627359759582638}, 
    {2.0479103884535728, 2.521960112821855}, {2.49259452117611, \
2.394814022264695}}], 
  Line[{{2.7226441186718158, 2.479055835144599}, {2.9374999999999996, \
2.536452985962878}, {2.436169610234236, 2.70871038548537}, 
    {2.248669610234237, 2.627359759582638}, {2.7226441186718158, \
2.479055835144599}}], 
  Line[{{2.9374999999999996, 2.536452985962878}, {3.127771932153715, \
2.5712732770958873}, {2.6022157387287503, 2.7681817987334414}, 
    {2.436169610234236, 2.70871038548537}, {2.9374999999999996, \
2.536452985962878}}], 
  Line[{{3.127771932153715, 2.5712732770958873}, {3.2851441186718167, \
2.589176886629936}, {2.739550983124842, 2.809014835019403}, 
    {2.6022157387287503, 2.7681817987334414}, {3.127771932153715, \
2.5712732770958873}}], 
  Line[{{3.2851441186718167, 2.589176886629936}, {3.4027386398479265, \
2.596255039055556}, {2.842173134234784, 2.834803496770629}, 
    {2.739550983124842, 2.809014835019403}, {3.2851441186718167, \
2.589176886629936}}], 
  Line[{{3.4027386398479265, 2.596255039055556}, {3.4754160508255314, \
2.5979598975817524}, {2.9055971116193557, 2.8487773266631815}, 
    {2.842173134234784, 2.834803496770629}, {3.4027386398479265, \
2.596255039055556}}], 
  Line[{{3.4754160508255314, 2.5979598975817524}, {3.500000000000001, \
2.598076211353315}, {2.9270509831248424, 2.8531695488854605}, 
    {2.9055971116193557, 2.8487773266631815}, {3.4754160508255314, \
2.5979598975817524}}], 
  Line[{{3.500000000000001, 2.598076211353315}, {3.4754160508255323, \
2.597959897581752}, {2.9055971116193566, 2.8487773266631806}, 
    {2.9270509831248424, 2.8531695488854605}, {3.500000000000001, \
2.598076211353315}}], 
  Line[{{3.4754160508255323, 2.597959897581752}, {3.402738639847927, \
2.596255039055556}, {2.8421731342347845, 2.8348034967706295}, 
    {2.9055971116193566, 2.8487773266631806}, {3.4754160508255323, \
2.597959897581752}}], 
  Line[{{3.402738639847927, 2.596255039055556}, {3.285144118671817, \
2.589176886629936}, {2.739550983124843, 2.8090148350194024}, 
    {2.8421731342347845, 2.8348034967706295}, {3.402738639847927, \
2.596255039055556}}], 
  Line[{{3.285144118671817, 2.589176886629936}, {3.1277719321537174, \
2.5712732770958864}, {2.6022157387287517, 2.7681817987334414}, 
    {2.739550983124843, 2.8090148350194024}, {3.285144118671817, \
2.589176886629936}}], 
  Line[{{3.1277719321537174, 2.5712732770958864}, {2.9375000000000013, \
2.5364529859628786}, {2.436169610234238, 2.70871038548537}, 
    {2.6022157387287517, 2.7681817987334414}, {3.1277719321537174, \
2.5712732770958864}}], 
  Line[{{2.9375000000000013, 2.5364529859628786}, {2.722644118671817, \
2.479055835144598}, {2.2486696102342374, 2.6273597595826383}, 
    {2.436169610234238, 2.70871038548537}, {2.9375000000000013, \
2.5364529859628786}}], 
  Line[{{2.722644118671817, 2.479055835144598}, {2.492594521176112, \
2.394814022264695}, {2.047910388453575, 2.521960112821855}, 
    {2.2486696102342374, 2.6273597595826383}, {2.722644118671817, \
2.479055835144598}}], 
  Line[{{2.492594521176112, 2.394814022264695}, {2.257405478823891, \
2.281657041700859}, {1.8426660862336905, 2.3920893271166777}, 
    {2.047910388453575, 2.521960112821855}, {2.492594521176112, \
2.394814022264695}}], 
  Line[{{2.257405478823891, 2.281657041700859}, {2.027355881328185, \
2.14040166785146}, {1.641906864453027, 2.239718051509763}, 
    {1.8426660862336905, 2.3920893271166777}, {2.257405478823891, \
2.281657041700859}}], 
  Line[{{2.027355881328185, 2.14040166785146}, {1.8125000000000016, \
1.975435078659889}, {1.4544068644530275, 2.0698782028004876}, 
    {1.641906864453027, 2.239718051509763}, {2.027355881328185, \
2.14040166785146}}], 
  Line[{{1.8125000000000016, 1.975435078659889}, {1.622228067846286, \
1.7955424168801213}, {1.2883607359585139, 1.8914277190459874}, 
    {1.4544068644530275, 2.0698782028004876}, {1.8125000000000016, \
1.975435078659889}}], 
  Line[{{1.622228067846286, 1.7955424168801213}, {1.4648558813281847, \
1.6149886737174095}, {1.1510254915624214, 1.7178957504272219}, 
    {1.2883607359585139, 1.8914277190459874}, {1.622228067846286, \
1.7955424168801213}}], 
  Line[{{1.4648558813281847, 1.6149886737174095}, {1.3472613601520749, \
1.4545502220637494}, {1.04840334045248, 1.5679671136605233}, 
    {1.1510254915624214, 1.7178957504272219}, {1.4648558813281847, \
1.6149886737174095}}], 
  Line[{{1.3472613601520749, 1.4545502220637494}, {1.2745839491744695, \
1.340717494749769}, {0.984979363067908, 1.464075901868194}, 
    {1.04840334045248, 1.5679671136605233}, {1.3472613601520749, \
1.4545502220637494}}], 
  Line[{{1.2745839491744695, 1.340717494749769}, {1.2500000000000004, \
1.2990381056766576}, {0.9635254915624213, 1.4265847744427302}, 
    {0.984979363067908, 1.464075901868194}, {1.2745839491744695, \
1.340717494749769}}], 
  Line[{{1.2500000000000004, 1.2990381056766576}, {1.274583949174469, \
1.3407174947497678}, {0.9849793630679073, 1.464075901868193}, 
    {0.9635254915624213, 1.4265847744427302}, {1.2500000000000004, \
1.2990381056766576}}], 
  Line[{{1.274583949174469, 1.3407174947497678}, {1.3472613601520738, \
1.4545502220637476}, {1.0484033404524786, 1.5679671136605218}, 
    {0.9849793630679073, 1.464075901868193}, {1.274583949174469, \
1.3407174947497678}}], 
  Line[{{1.3472613601520738, 1.4545502220637476}, {1.4648558813281845, \
1.6149886737174093}, {1.1510254915624212, 1.7178957504272214}, 
    {1.0484033404524786, 1.5679671136605218}, {1.3472613601520738, \
1.4545502220637476}}], 
  Line[{{1.4648558813281845, 1.6149886737174093}, {1.622228067846284, \
1.795542416880119}, {1.2883607359585123, 1.8914277190459852}, 
    {1.1510254915624212, 1.7178957504272214}, {1.4648558813281845, \
1.6149886737174093}}], 
  Line[{{1.622228067846284, 1.795542416880119}, {1.812499999999999, \
1.9754350786598873}, {1.4544068644530252, 2.069878202800486}, 
    {1.2883607359585123, 1.8914277190459852}, {1.622228067846284, \
1.795542416880119}}], 
  Line[{{1.812499999999999, 1.9754350786598873}, {2.027355881328184, \
2.1404016678514597}, {1.6419068644530261, 2.2397180515097626}, 
    {1.4544068644530252, 2.069878202800486}, {1.812499999999999, \
1.9754350786598873}}], 
  Line[{{2.027355881328184, 2.1404016678514597}, {2.257405478823889, \
2.281657041700858}, {1.842666086233689, 2.3920893271166763}, 
    {1.6419068644530261, 2.2397180515097626}, {2.027355881328184, \
2.1404016678514597}}], 
  Line[{{2.257405478823889, 2.281657041700858}, {2.492594521176109, \
2.3948140222646943}, {2.047910388453572, 2.521960112821854}, 
    {1.842666086233689, 2.3920893271166763}, {2.257405478823889, \
2.281657041700858}}], 
  Line[{{2.492594521176109, 2.3948140222646943}, {2.722644118671816, \
2.4790558351445986}, {2.248669610234237, 2.6273597595826383}, 
    {2.047910388453572, 2.521960112821854}, {2.492594521176109, \
2.3948140222646943}}], 
  Line[{{2.722644118671816, 2.4790558351445986}, {2.9375, \
2.5364529859628773}, {2.436169610234236, 2.7087103854853694}, 
    {2.248669610234237, 2.6273597595826383}, {2.722644118671816, \
2.4790558351445986}}], 
  Line[{{2.9375, 2.5364529859628773}, {3.1277719321537143, \
2.571273277095887}, {2.602215738728749, 2.7681817987334414}, 
    {2.436169610234236, 2.7087103854853694}, {2.9375, 2.5364529859628773}}], 
  Line[{{3.1277719321537143, 2.571273277095887}, {3.2851441186718167, \
2.589176886629936}, {2.739550983124842, 2.809014835019403}, 
    {2.602215738728749, 2.7681817987334414}, {3.1277719321537143, \
2.571273277095887}}], 
  Line[{{3.2851441186718167, 2.589176886629936}, {3.4027386398479265, \
2.596255039055556}, {2.842173134234784, 2.834803496770629}, 
    {2.739550983124842, 2.809014835019403}, {3.2851441186718167, \
2.589176886629936}}], 
  Line[{{3.4027386398479265, 2.596255039055556}, {3.475416050825532, \
2.597959897581752}, {2.905597111619356, 2.848777326663181}, 
    {2.842173134234784, 2.834803496770629}, {3.4027386398479265, \
2.596255039055556}}], 
  Line[{{3.475416050825532, 2.597959897581752}, {3.500000000000001, \
2.598076211353315}, {2.9270509831248424, 2.8531695488854605}, 
    {2.905597111619356, 2.848777326663181}, {3.475416050825532, \
2.597959897581752}}], 
  Line[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193557, \
2.8487773266631815}, {2.2954829420678116, 2.976303493889946}, 
    {2.3135853898029626, 2.9835656861048196}, {2.9270509831248424, \
2.8531695488854605}}], 
  Line[{{2.9055971116193557, 2.8487773266631815}, {2.842173134234785, \
2.834803496770629}, {2.2419667626935684, 2.95408127925137}, 
    {2.2954829420678116, 2.976303493889946}, {2.9055971116193557, \
2.8487773266631815}}], 
  Line[{{2.842173134234785, 2.834803496770629}, {2.739550983124842, \
2.809014835019403}, {2.1553757655180044, 2.9156867970745455}, 
    {2.2419667626935684, 2.95408127925137}, {2.842173134234785, \
2.834803496770629}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.602215738728751, \
2.768181798733441}, {2.039494392627399, 2.8593997974092926}, 
    {2.1553757655180044, 2.9156867970745455}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.602215738728751, 2.768181798733441}, {2.4361696102342374, \
2.7087103854853694}, {1.8993872160775924, 2.7833940695732022}, 
    {2.039494392627399, 2.8593997974092926}, {2.602215738728751, \
2.768181798733441}}], 
  Line[{{2.4361696102342374, 2.7087103854853694}, {2.248669610234237, \
2.6273597595826383}, {1.7411775917926342, 2.686221801523239}, 
    {1.8993872160775924, 2.7833940695732022}, {2.4361696102342374, \
2.7087103854853694}}], 
  Line[{{2.248669610234237, 2.6273597595826383}, {2.047910388453574, \
2.521960112821855}, {1.5717800395277852, 2.567335508777075}, 
    {1.7411775917926342, 2.686221801523239}, {2.248669610234237, \
2.6273597595826383}}], 
  Line[{{2.047910388453574, 2.521960112821855}, {1.8426660862336899, \
2.392089327116677}, {1.3985980451766586, 2.427623046285348}, 
    {1.5717800395277852, 2.567335508777075}, {2.047910388453574, \
2.521960112821855}}], 
  Line[{{1.8426660862336899, 2.392089327116677}, {1.6419068644530266, \
2.239718051509763}, {1.2292004929118094, 2.2699589047379565}, 
    {1.3985980451766586, 2.427623046285348}, {1.8426660862336899, \
2.392089327116677}}], 
  Line[{{1.6419068644530266, 2.239718051509763}, {1.4544068644530268, \
2.069878202800487}, {1.0709908686268519, 2.099799626225554}, 
    {1.2292004929118094, 2.2699589047379565}, {1.6419068644530266, \
2.239718051509763}}], 
  Line[{{1.4544068644530268, 2.069878202800487}, {1.2883607359585132, \
1.8914277190459865}, {0.9308836920770447, 1.9258466260207314}, 
    {1.0709908686268519, 2.099799626225554}, {1.4544068644530268, \
2.069878202800487}}], 
  Line[{{1.2883607359585132, 1.8914277190459865}, {1.1510254915624212, \
1.7178957504272219}, {0.8150023191864391, 1.760690570377689}, 
    {0.9308836920770447, 1.9258466260207314}, {1.2883607359585132, \
1.8914277190459865}}], 
  Line[{{1.1510254915624212, 1.7178957504272219}, {1.0484033404524795, \
1.5679671136605227}, {0.7284113220108761, 1.6209688555409116}, 
    {0.8150023191864391, 1.760690570377689}, {1.1510254915624212, \
1.7178957504272219}}], 
  Line[{{1.0484033404524795, 1.5679671136605227}, {0.9849793630679076, \
1.4640759018681937}, {0.674895142636632, 1.5257871330867279}, 
    {0.7284113220108761, 1.6209688555409116}, {1.0484033404524795, \
1.5679671136605227}}], 
  Line[{{0.9849793630679076, 1.4640759018681937}, {0.9635254915624213, \
1.4265847744427302}, {0.6567926949014813, 1.4917828430524098}, 
    {0.674895142636632, 1.5257871330867279}, {0.9849793630679076, \
1.4640759018681937}}], 
  Line[{{0.9635254915624213, 1.4265847744427302}, {0.9849793630679076, \
1.4640759018681933}, {0.674895142636632, 1.5257871330867276}, 
    {0.6567926949014813, 1.4917828430524098}, {0.9635254915624213, \
1.4265847744427302}}], 
  Line[{{0.9849793630679076, 1.4640759018681933}, {1.0484033404524795, \
1.5679671136605224}, {0.7284113220108761, 1.6209688555409112}, 
    {0.674895142636632, 1.5257871330867276}, {0.9849793630679076, \
1.4640759018681933}}], 
  Line[{{1.0484033404524795, 1.5679671136605224}, {1.1510254915624214, \
1.7178957504272216}, {0.8150023191864392, 1.7606905703776887}, 
    {0.7284113220108761, 1.6209688555409112}, {1.0484033404524795, \
1.5679671136605224}}], 
  Line[{{1.1510254915624214, 1.7178957504272216}, {1.2883607359585125, \
1.8914277190459858}, {0.9308836920770442, 1.9258466260207308}, 
    {0.8150023191864392, 1.7606905703776887}, {1.1510254915624214, \
1.7178957504272216}}], 
  Line[{{1.2883607359585125, 1.8914277190459858}, {1.454406864453026, \
2.0698782028004867}, {1.070990868626851, 2.099799626225553}, 
    {0.9308836920770442, 1.9258466260207308}, {1.2883607359585125, \
1.8914277190459858}}], 
  Line[{{1.454406864453026, 2.0698782028004867}, {1.6419068644530261, \
2.239718051509763}, {1.2292004929118092, 2.2699589047379565}, 
    {1.070990868626851, 2.099799626225553}, {1.454406864453026, \
2.0698782028004867}}], 
  Line[{{1.6419068644530261, 2.239718051509763}, {1.8426660862336892, \
2.3920893271166763}, {1.3985980451766582, 2.427623046285347}, 
    {1.2292004929118092, 2.2699589047379565}, {1.6419068644530261, \
2.239718051509763}}], 
  Line[{{1.8426660862336892, 2.3920893271166763}, {2.0479103884535728, \
2.521960112821855}, {1.5717800395277841, 2.567335508777075}, 
    {1.3985980451766582, 2.427623046285347}, {1.8426660862336892, \
2.3920893271166763}}], 
  Line[{{2.0479103884535728, 2.521960112821855}, {2.248669610234237, \
2.627359759582638}, {1.7411775917926342, 2.6862218015232386}, 
    {1.5717800395277841, 2.567335508777075}, {2.0479103884535728, \
2.521960112821855}}], 
  Line[{{2.248669610234237, 2.627359759582638}, {2.436169610234236, \
2.70871038548537}, {1.8993872160775915, 2.783394069573202}, 
    {1.7411775917926342, 2.6862218015232386}, {2.248669610234237, \
2.627359759582638}}], 
  Line[{{2.436169610234236, 2.70871038548537}, {2.6022157387287503, \
2.7681817987334414}, {2.039494392627399, 2.8593997974092926}, 
    {1.8993872160775915, 2.783394069573202}, {2.436169610234236, \
2.70871038548537}}], 
  Line[{{2.6022157387287503, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {2.155375765518005, 2.9156867970745455}, 
    {2.039494392627399, 2.8593997974092926}, {2.6022157387287503, \
2.7681817987334414}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {2.241966762693568, 2.9540812792513695}, 
    {2.155375765518005, 2.9156867970745455}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.842173134234784, 2.834803496770629}, {2.9055971116193557, \
2.8487773266631815}, {2.2954829420678116, 2.976303493889946}, 
    {2.241966762693568, 2.9540812792513695}, {2.842173134234784, \
2.834803496770629}}], 
  Line[{{2.9055971116193557, 2.8487773266631815}, {2.9270509831248424, \
2.8531695488854605}, {2.3135853898029626, 2.9835656861048196}, 
    {2.2954829420678116, 2.976303493889946}, {2.9055971116193557, \
2.8487773266631815}}], 
  Line[{{2.9270509831248424, 2.8531695488854605}, {2.9055971116193566, \
2.8487773266631806}, {2.2954829420678124, 2.9763034938899455}, 
    {2.3135853898029626, 2.9835656861048196}, {2.9270509831248424, \
2.8531695488854605}}], 
  Line[{{2.9055971116193566, 2.8487773266631806}, {2.8421731342347845, \
2.8348034967706295}, {2.241966762693568, 2.9540812792513704}, 
    {2.2954829420678124, 2.9763034938899455}, {2.9055971116193566, \
2.8487773266631806}}], 
  Line[{{2.8421731342347845, 2.8348034967706295}, {2.739550983124843, \
2.8090148350194024}, {2.155375765518005, 2.9156867970745455}, 
    {2.241966762693568, 2.9540812792513704}, {2.8421731342347845, \
2.8348034967706295}}], 
  Line[{{2.739550983124843, 2.8090148350194024}, {2.6022157387287517, \
2.7681817987334414}, {2.0394943926274, 2.859399797409293}, 
    {2.155375765518005, 2.9156867970745455}, {2.739550983124843, \
2.8090148350194024}}], 
  Line[{{2.6022157387287517, 2.7681817987334414}, {2.436169610234238, \
2.70871038548537}, {1.8993872160775926, 2.7833940695732027}, 
    {2.0394943926274, 2.859399797409293}, {2.6022157387287517, \
2.7681817987334414}}], 
  Line[{{2.436169610234238, 2.70871038548537}, {2.2486696102342374, \
2.6273597595826383}, {1.7411775917926349, 2.686221801523239}, 
    {1.8993872160775926, 2.7833940695732027}, {2.436169610234238, \
2.70871038548537}}], 
  Line[{{2.2486696102342374, 2.6273597595826383}, {2.047910388453575, \
2.521960112821855}, {1.5717800395277857, 2.5673355087770755}, 
    {1.7411775917926349, 2.686221801523239}, {2.2486696102342374, \
2.6273597595826383}}], 
  Line[{{2.047910388453575, 2.521960112821855}, {1.8426660862336905, \
2.3920893271166777}, {1.3985980451766593, 2.4276230462853485}, 
    {1.5717800395277857, 2.5673355087770755}, {2.047910388453575, \
2.521960112821855}}], 
  Line[{{1.8426660862336905, 2.3920893271166777}, {1.641906864453027, \
2.239718051509763}, {1.2292004929118097, 2.269958904737957}, 
    {1.3985980451766593, 2.4276230462853485}, {1.8426660862336905, \
2.3920893271166777}}], 
  Line[{{1.641906864453027, 2.239718051509763}, {1.4544068644530275, \
2.0698782028004876}, {1.0709908686268523, 2.099799626225555}, 
    {1.2292004929118097, 2.269958904737957}, {1.641906864453027, \
2.239718051509763}}], 
  Line[{{1.4544068644530275, 2.0698782028004876}, {1.2883607359585139, \
1.8914277190459874}, {0.9308836920770454, 1.9258466260207323}, 
    {1.0709908686268523, 2.099799626225555}, {1.4544068644530275, \
2.0698782028004876}}], 
  Line[{{1.2883607359585139, 1.8914277190459874}, {1.1510254915624214, \
1.7178957504272219}, {0.8150023191864393, 1.7606905703776892}, 
    {0.9308836920770454, 1.9258466260207323}, {1.2883607359585139, \
1.8914277190459874}}], 
  Line[{{1.1510254915624214, 1.7178957504272219}, {1.04840334045248, \
1.5679671136605233}, {0.7284113220108764, 1.620968855540912}, 
    {0.8150023191864393, 1.7606905703776892}, {1.1510254915624214, \
1.7178957504272219}}], 
  Line[{{1.04840334045248, 1.5679671136605233}, {0.984979363067908, \
1.464075901868194}, {0.6748951426366323, 1.5257871330867283}, 
    {0.7284113220108764, 1.620968855540912}, {1.04840334045248, \
1.5679671136605233}}], 
  Line[{{0.984979363067908, 1.464075901868194}, {0.9635254915624213, \
1.4265847744427302}, {0.6567926949014813, 1.4917828430524098}, 
    {0.6748951426366323, 1.5257871330867283}, {0.984979363067908, \
1.464075901868194}}], 
  Line[{{0.9635254915624213, 1.4265847744427302}, {0.9849793630679073, \
1.464075901868193}, {0.6748951426366318, 1.5257871330867276}, 
    {0.6567926949014813, 1.4917828430524098}, {0.9635254915624213, \
1.4265847744427302}}], 
  Line[{{0.9849793630679073, 1.464075901868193}, {1.0484033404524786, \
1.5679671136605218}, {0.7284113220108754, 1.6209688555409107}, 
    {0.6748951426366318, 1.5257871330867276}, {0.9849793630679073, \
1.464075901868193}}], 
  Line[{{1.0484033404524786, 1.5679671136605218}, {1.1510254915624212, \
1.7178957504272214}, {0.815002319186439, 1.7606905703776887}, 
    {0.7284113220108754, 1.6209688555409107}, {1.0484033404524786, \
1.5679671136605218}}], 
  Line[{{1.1510254915624212, 1.7178957504272214}, {1.2883607359585123, \
1.8914277190459852}, {0.9308836920770438, 1.9258466260207303}, 
    {0.815002319186439, 1.7606905703776887}, {1.1510254915624212, \
1.7178957504272214}}], 
  Line[{{1.2883607359585123, 1.8914277190459852}, {1.4544068644530252, \
2.069878202800486}, {1.0709908686268506, 2.0997996262255523}, 
    {0.9308836920770438, 1.9258466260207303}, {1.2883607359585123, \
1.8914277190459852}}], 
  Line[{{1.4544068644530252, 2.069878202800486}, {1.6419068644530261, \
2.2397180515097626}, {1.229200492911809, 2.269958904737956}, 
    {1.0709908686268506, 2.0997996262255523}, {1.4544068644530252, \
2.069878202800486}}], 
  Line[{{1.6419068644530261, 2.2397180515097626}, {1.842666086233689, \
2.3920893271166763}, {1.3985980451766578, 2.427623046285347}, 
    {1.229200492911809, 2.269958904737956}, {1.6419068644530261, \
2.2397180515097626}}], 
  Line[{{1.842666086233689, 2.3920893271166763}, {2.047910388453572, \
2.521960112821854}, {1.5717800395277832, 2.5673355087770737}, 
    {1.3985980451766578, 2.427623046285347}, {1.842666086233689, \
2.3920893271166763}}], 
  Line[{{2.047910388453572, 2.521960112821854}, {2.248669610234237, \
2.6273597595826383}, {1.7411775917926344, 2.686221801523239}, 
    {1.5717800395277832, 2.5673355087770737}, {2.047910388453572, \
2.521960112821854}}], 
  Line[{{2.248669610234237, 2.6273597595826383}, {2.436169610234236, \
2.7087103854853694}, {1.8993872160775913, 2.783394069573202}, 
    {1.7411775917926344, 2.686221801523239}, {2.248669610234237, \
2.6273597595826383}}], 
  Line[{{2.436169610234236, 2.7087103854853694}, {2.602215738728749, \
2.7681817987334414}, {2.039494392627398, 2.859399797409292}, 
    {1.8993872160775913, 2.783394069573202}, {2.436169610234236, \
2.7087103854853694}}], 
  Line[{{2.602215738728749, 2.7681817987334414}, {2.739550983124842, \
2.809014835019403}, {2.155375765518005, 2.9156867970745455}, 
    {2.039494392627398, 2.859399797409292}, {2.602215738728749, \
2.7681817987334414}}], 
  Line[{{2.739550983124842, 2.809014835019403}, {2.842173134234784, \
2.834803496770629}, {2.241966762693568, 2.9540812792513695}, 
    {2.155375765518005, 2.9156867970745455}, {2.739550983124842, \
2.809014835019403}}], 
  Line[{{2.842173134234784, 2.834803496770629}, {2.905597111619356, \
2.848777326663181}, {2.295482942067812, 2.9763034938899455}, 
    {2.241966762693568, 2.9540812792513695}, {2.842173134234784, \
2.834803496770629}}], 
  Line[{{2.905597111619356, 2.848777326663181}, {2.9270509831248424, \
2.8531695488854605}, {2.3135853898029626, 2.9835656861048196}, 
    {2.295482942067812, 2.9763034938899455}, {2.905597111619356, \
2.848777326663181}}], 
  Line[{{2.3135853898029626, 2.9835656861048196}, {2.2954829420678116, \
2.976303493889946}, {1.6717384590329, 2.9745950829027943}, 
    {1.686414610197041, 2.9835656861048196}, {2.3135853898029626, \
2.9835656861048196}}], 
  Line[{{2.2954829420678116, 2.976303493889946}, {2.2419667626935684, \
2.95408127925137}, {1.6283514237703374, 2.947488384456562}, 
    {1.6717384590329, 2.9745950829027943}, {2.2954829420678116, \
2.976303493889946}}], 
  Line[{{2.2419667626935684, 2.95408127925137}, {2.1553757655180044, \
2.9156867970745455}, {1.5581497260444195, 2.9017190909782276}, 
    {1.6283514237703374, 2.947488384456562}, {2.2419667626935684, \
2.95408127925137}}], 
  Line[{{2.1553757655180044, 2.9156867970745455}, {2.039494392627399, \
2.8593997974092926}, {1.464201516910891, 2.8365966765934414}, 
    {1.5581497260444195, 2.9017190909782276}, {2.1553757655180044, \
2.9156867970745455}}], 
  Line[{{2.039494392627399, 2.8593997974092926}, {1.8993872160775924, \
2.7833940695732022}, {1.350612783922411, 2.751525170659194}, 
    {1.464201516910891, 2.8365966765934414}, {2.039494392627399, \
2.8593997974092926}}], 
  Line[{{1.8993872160775924, 2.7833940695732022}, {1.7411775917926342, \
2.686221801523239}, {1.2223478997697899, 2.646328981764321}, 
    {1.350612783922411, 2.751525170659194}, {1.8993872160775924, \
2.7833940695732022}}], 
  Line[{{1.7411775917926342, 2.686221801523239}, {1.5717800395277852, \
2.567335508777075}, {1.0850126553736983, 2.5216249314090464}, 
    {1.2223478997697899, 2.646328981764321}, {1.7411775917926342, \
2.686221801523239}}], 
  Line[{{1.5717800395277852, 2.567335508777075}, {1.3985980451766586, \
2.427623046285348}, {0.9446092599218634, 2.379229777665829}, 
    {1.0850126553736983, 2.5216249314090464}, {1.5717800395277852, \
2.567335508777075}}], 
  Line[{{1.3985980451766586, 2.427623046285348}, {1.2292004929118094, \
2.2699589047379565}, {0.8072740155257718, 2.222607239695348}, 
    {0.9446092599218634, 2.379229777665829}, {1.3985980451766586, \
2.427623046285348}}], 
  Line[{{1.2292004929118094, 2.2699589047379565}, {1.0709908686268519, \
2.099799626225554}, {0.6790091313731508, 2.0573688751735335}, 
    {0.8072740155257718, 2.222607239695348}, {1.2292004929118094, \
2.2699589047379565}}], 
  Line[{{1.0709908686268519, 2.099799626225554}, {0.9308836920770447, \
1.9258466260207314}, {0.5654203983846704, 1.8918241808350191}, 
    {0.6790091313731508, 2.0573688751735335}, {1.0709908686268519, \
2.099799626225554}}], 
  Line[{{0.9308836920770447, 1.9258466260207314}, {0.8150023191864391, \
1.760690570377689}, {0.4714721892511417, 1.7374623647519978}, 
    {0.5654203983846704, 1.8918241808350191}, {0.9308836920770447, \
1.9258466260207314}}], 
  Line[{{0.8150023191864391, 1.760690570377689}, {0.7284113220108761, \
1.6209688555409116}, {0.40127049152522454, 1.6089224974238359}, 
    {0.4714721892511417, 1.7374623647519978}, {0.8150023191864391, \
1.760690570377689}}], 
  Line[{{0.7284113220108761, 1.6209688555409116}, {0.674895142636632, \
1.5257871330867279}, {0.3578834562626614, 1.5224519023538965}, 
    {0.40127049152522454, 1.6089224974238359}, {0.7284113220108761, \
1.6209688555409116}}], 
  Line[{{0.674895142636632, 1.5257871330867279}, {0.6567926949014813, \
1.4917828430524098}, {0.3432073050985205, 1.49178284305241}, 
    {0.3578834562626614, 1.5224519023538965}, {0.674895142636632, \
1.5257871330867279}}], 
  Line[{{0.6567926949014813, 1.4917828430524098}, {0.674895142636632, \
1.5257871330867276}, {0.3578834562626615, 1.5224519023538965}, 
    {0.3432073050985205, 1.49178284305241}, {0.6567926949014813, \
1.4917828430524098}}], 
  Line[{{0.674895142636632, 1.5257871330867276}, {0.7284113220108761, \
1.6209688555409112}, {0.4012704915252243, 1.6089224974238356}, 
    {0.3578834562626615, 1.5224519023538965}, {0.674895142636632, \
1.5257871330867276}}], 
  Line[{{0.7284113220108761, 1.6209688555409112}, {0.8150023191864392, \
1.7606905703776887}, {0.47147218925114165, 1.7374623647519978}, 
    {0.4012704915252243, 1.6089224974238356}, {0.7284113220108761, \
1.6209688555409112}}], 
  Line[{{0.8150023191864392, 1.7606905703776887}, {0.9308836920770442, \
1.9258466260207308}, {0.5654203983846702, 1.8918241808350182}, 
    {0.47147218925114165, 1.7374623647519978}, {0.8150023191864392, \
1.7606905703776887}}], 
  Line[{{0.9308836920770442, 1.9258466260207308}, {1.070990868626851, \
2.099799626225553}, {0.6790091313731502, 2.057368875173533}, 
    {0.5654203983846702, 1.8918241808350182}, {0.9308836920770442, \
1.9258466260207308}}], 
  Line[{{1.070990868626851, 2.099799626225553}, {1.2292004929118092, \
2.2699589047379565}, {0.8072740155257716, 2.222607239695348}, 
    {0.6790091313731502, 2.057368875173533}, {1.070990868626851, \
2.099799626225553}}], 
  Line[{{1.2292004929118092, 2.2699589047379565}, {1.3985980451766582, \
2.427623046285347}, {0.9446092599218627, 2.379229777665828}, 
    {0.8072740155257716, 2.222607239695348}, {1.2292004929118092, \
2.2699589047379565}}], 
  Line[{{1.3985980451766582, 2.427623046285347}, {1.5717800395277841, \
2.567335508777075}, {1.0850126553736974, 2.5216249314090464}, 
    {0.9446092599218627, 2.379229777665828}, {1.3985980451766582, \
2.427623046285347}}], 
  Line[{{1.5717800395277841, 2.567335508777075}, {1.7411775917926342, \
2.6862218015232386}, {1.2223478997697894, 2.646328981764321}, 
    {1.0850126553736974, 2.5216249314090464}, {1.5717800395277841, \
2.567335508777075}}], 
  Line[{{1.7411775917926342, 2.6862218015232386}, {1.8993872160775915, \
2.783394069573202}, {1.3506127839224105, 2.751525170659194}, 
    {1.2223478997697894, 2.646328981764321}, {1.7411775917926342, \
2.6862218015232386}}], 
  Line[{{1.8993872160775915, 2.783394069573202}, {2.039494392627399, \
2.8593997974092926}, {1.4642015169108908, 2.836596676593442}, 
    {1.3506127839224105, 2.751525170659194}, {1.8993872160775915, \
2.783394069573202}}], 
  Line[{{2.039494392627399, 2.8593997974092926}, {2.155375765518005, \
2.9156867970745455}, {1.5581497260444195, 2.901719090978228}, 
    {1.4642015169108908, 2.836596676593442}, {2.039494392627399, \
2.8593997974092926}}], 
  Line[{{2.155375765518005, 2.9156867970745455}, {2.241966762693568, \
2.9540812792513695}, {1.6283514237703371, 2.947488384456561}, 
    {1.5581497260444195, 2.901719090978228}, {2.155375765518005, \
2.9156867970745455}}], 
  Line[{{2.241966762693568, 2.9540812792513695}, {2.2954829420678116, \
2.976303493889946}, {1.6717384590329, 2.9745950829027943}, 
    {1.6283514237703371, 2.947488384456561}, {2.241966762693568, \
2.9540812792513695}}], 
  Line[{{2.2954829420678116, 2.976303493889946}, {2.3135853898029626, \
2.9835656861048196}, {1.686414610197041, 2.9835656861048196}, 
    {1.6717384590329, 2.9745950829027943}, {2.2954829420678116, \
2.976303493889946}}], 
  Line[{{2.3135853898029626, 2.9835656861048196}, {2.2954829420678124, \
2.9763034938899455}, {1.6717384590329005, 2.9745950829027943}, 
    {1.686414610197041, 2.9835656861048196}, {2.3135853898029626, \
2.9835656861048196}}], 
  Line[{{2.2954829420678124, 2.9763034938899455}, {2.241966762693568, \
2.9540812792513704}, {1.6283514237703374, 2.9474883844565616}, 
    {1.6717384590329005, 2.9745950829027943}, {2.2954829420678124, \
2.9763034938899455}}], 
  Line[{{2.241966762693568, 2.9540812792513704}, {2.155375765518005, \
2.9156867970745455}, {1.55814972604442, 2.901719090978228}, 
    {1.6283514237703374, 2.9474883844565616}, {2.241966762693568, \
2.9540812792513704}}], 
  Line[{{2.155375765518005, 2.9156867970745455}, {2.0394943926274, \
2.859399797409293}, {1.4642015169108917, 2.836596676593442}, 
    {1.55814972604442, 2.901719090978228}, {2.155375765518005, \
2.9156867970745455}}], 
  Line[{{2.0394943926274, 2.859399797409293}, {1.8993872160775926, \
2.7833940695732027}, {1.3506127839224114, 2.7515251706591943}, 
    {1.4642015169108917, 2.836596676593442}, {2.0394943926274, \
2.859399797409293}}], 
  Line[{{1.8993872160775926, 2.7833940695732027}, {1.7411775917926349, \
2.686221801523239}, {1.22234789976979, 2.646328981764321}, 
    {1.3506127839224114, 2.7515251706591943}, {1.8993872160775926, \
2.7833940695732027}}], 
  Line[{{1.7411775917926349, 2.686221801523239}, {1.5717800395277857, \
2.5673355087770755}, {1.0850126553736987, 2.5216249314090473}, 
    {1.22234789976979, 2.646328981764321}, {1.7411775917926349, \
2.686221801523239}}], 
  Line[{{1.5717800395277857, 2.5673355087770755}, {1.3985980451766593, \
2.4276230462853485}, {0.9446092599218641, 2.3792297776658295}, 
    {1.0850126553736987, 2.5216249314090473}, {1.5717800395277857, \
2.5673355087770755}}], 
  Line[{{1.3985980451766593, 2.4276230462853485}, {1.2292004929118097, \
2.269958904737957}, {0.807274015525772, 2.2226072396953485}, 
    {0.9446092599218641, 2.3792297776658295}, {1.3985980451766593, \
2.4276230462853485}}], 
  Line[{{1.2292004929118097, 2.269958904737957}, {1.0709908686268523, \
2.099799626225555}, {0.6790091313731512, 2.0573688751735344}, 
    {0.807274015525772, 2.2226072396953485}, {1.2292004929118097, \
2.269958904737957}}], 
  Line[{{1.0709908686268523, 2.099799626225555}, {0.9308836920770454, \
1.9258466260207323}, {0.565420398384671, 1.8918241808350198}, 
    {0.6790091313731512, 2.0573688751735344}, {1.0709908686268523, \
2.099799626225555}}], 
  Line[{{0.9308836920770454, 1.9258466260207323}, {0.8150023191864393, \
1.7606905703776892}, {0.47147218925114187, 1.737462364751998}, 
    {0.565420398384671, 1.8918241808350198}, {0.9308836920770454, \
1.9258466260207323}}], 
  Line[{{0.8150023191864393, 1.7606905703776892}, {0.7284113220108764, \
1.620968855540912}, {0.40127049152522487, 1.6089224974238363}, 
    {0.47147218925114187, 1.737462364751998}, {0.8150023191864393, \
1.7606905703776892}}], 
  Line[{{0.7284113220108764, 1.620968855540912}, {0.6748951426366323, \
1.5257871330867283}, {0.3578834562626616, 1.522451902353897}, 
    {0.40127049152522487, 1.6089224974238363}, {0.7284113220108764, \
1.620968855540912}}], 
  Line[{{0.6748951426366323, 1.5257871330867283}, {0.6567926949014813, \
1.4917828430524098}, {0.3432073050985205, 1.49178284305241}, 
    {0.3578834562626616, 1.522451902353897}, {0.6748951426366323, \
1.5257871330867283}}], 
  Line[{{0.6567926949014813, 1.4917828430524098}, {0.6748951426366318, \
1.5257871330867276}, {0.35788345626266127, 1.5224519023538963}, 
    {0.3432073050985205, 1.49178284305241}, {0.6567926949014813, \
1.4917828430524098}}], 
  Line[{{0.6748951426366318, 1.5257871330867276}, {0.7284113220108754, \
1.6209688555409107}, {0.401270491525224, 1.608922497423835}, 
    {0.35788345626266127, 1.5224519023538963}, {0.6748951426366318, \
1.5257871330867276}}], 
  Line[{{0.7284113220108754, 1.6209688555409107}, {0.815002319186439, \
1.7606905703776887}, {0.47147218925114154, 1.7374623647519976}, 
    {0.401270491525224, 1.608922497423835}, {0.7284113220108754, \
1.6209688555409107}}], 
  Line[{{0.815002319186439, 1.7606905703776887}, {0.9308836920770438, \
1.9258466260207303}, {0.5654203983846697, 1.891824180835018}, 
    {0.47147218925114154, 1.7374623647519976}, {0.815002319186439, \
1.7606905703776887}}], 
  Line[{{0.9308836920770438, 1.9258466260207303}, {1.0709908686268506, \
2.0997996262255523}, {0.6790091313731498, 2.057368875173532}, 
    {0.5654203983846697, 1.891824180835018}, {0.9308836920770438, \
1.9258466260207303}}], 
  Line[{{1.0709908686268506, 2.0997996262255523}, {1.229200492911809, \
2.269958904737956}, {0.8072740155257715, 2.2226072396953476}, 
    {0.6790091313731498, 2.057368875173532}, {1.0709908686268506, \
2.0997996262255523}}], 
  Line[{{1.229200492911809, 2.269958904737956}, {1.3985980451766578, \
2.427623046285347}, {0.9446092599218627, 2.3792297776658278}, 
    {0.8072740155257715, 2.2226072396953476}, {1.229200492911809, \
2.269958904737956}}], 
  Line[{{1.3985980451766578, 2.427623046285347}, {1.5717800395277832, \
2.5673355087770737}, {1.0850126553736967, 2.5216249314090455}, 
    {0.9446092599218627, 2.3792297776658278}, {1.3985980451766578, \
2.427623046285347}}], 
  Line[{{1.5717800395277832, 2.5673355087770737}, {1.7411775917926344, \
2.686221801523239}, {1.2223478997697896, 2.6463289817643205}, 
    {1.0850126553736967, 2.5216249314090455}, {1.5717800395277832, \
2.5673355087770737}}], 
  Line[{{1.7411775917926344, 2.686221801523239}, {1.8993872160775913, \
2.783394069573202}, {1.3506127839224105, 2.7515251706591934}, 
    {1.2223478997697896, 2.6463289817643205}, {1.7411775917926344, \
2.686221801523239}}], 
  Line[{{1.8993872160775913, 2.783394069573202}, {2.039494392627398, \
2.859399797409292}, {1.4642015169108902, 2.8365966765934414}, 
    {1.3506127839224105, 2.7515251706591934}, {1.8993872160775913, \
2.783394069573202}}], 
  Line[{{2.039494392627398, 2.859399797409292}, {2.155375765518005, \
2.9156867970745455}, {1.5581497260444195, 2.901719090978228}, 
    {1.4642015169108902, 2.8365966765934414}, {2.039494392627398, \
2.859399797409292}}], 
  Line[{{2.155375765518005, 2.9156867970745455}, {2.241966762693568, \
2.9540812792513695}, {1.6283514237703371, 2.947488384456561}, 
    {1.5581497260444195, 2.901719090978228}, {2.155375765518005, \
2.9156867970745455}}], 
  Line[{{2.241966762693568, 2.9540812792513695}, {2.295482942067812, \
2.9763034938899455}, {1.6717384590329003, 2.974595082902794}, 
    {1.6283514237703371, 2.947488384456561}, {2.241966762693568, \
2.9540812792513695}}], 
  Line[{{2.295482942067812, 2.9763034938899455}, {2.3135853898029626, \
2.9835656861048196}, {1.686414610197041, 2.9835656861048196}, 
    {1.6717384590329003, 2.974595082902794}, {2.295482942067812, \
2.9763034938899455}}], 
  Line[{{1.686414610197041, 2.9835656861048196}, {1.6717384590329, \
2.9745950829027943}, {1.0616242894813532, 2.843497290965337}, 
    {1.0729490168751585, 2.853169548885461}, {1.686414610197041, \
2.9835656861048196}}], 
  Line[{{1.6717384590329, 2.9745950829027943}, {1.6283514237703374, \
2.947488384456562}, {1.0281450522291185, 2.8144424077524017}, 
    {1.0616242894813532, 2.843497290965337}, {1.6717384590329, \
2.9745950829027943}}], 
  Line[{{1.6283514237703374, 2.947488384456562}, {1.5581497260444195, \
2.9017190909782276}, {0.9739745084375796, 2.7659262761959793}, 
    {1.0281450522291185, 2.8144424077524017}, {1.6283514237703374, \
2.947488384456562}}], 
  Line[{{1.5581497260444195, 2.9017190909782276}, {1.464201516910891, \
2.8365966765934414}, {0.9014801708095374, 2.6979339589171736}, 
    {0.9739745084375796, 2.7659262761959793}, {1.5581497260444195, \
2.9017190909782276}}], 
  Line[{{1.464201516910891, 2.8365966765934414}, {1.350612783922411, \
2.751525170659194}, {0.8138303897657639, 2.6106791787633687}, 
    {0.9014801708095374, 2.6979339589171736}, {1.464201516910891, \
2.8365966765934414}}], 
  Line[{{1.350612783922411, 2.751525170659194}, {1.2223478997697899, \
2.646328981764321}, {0.7148558813281849, 2.504820390287959}, 
    {0.8138303897657639, 2.6106791787633687}, {1.350612783922411, \
2.751525170659194}}], 
  Line[{{1.2223478997697899, 2.646328981764321}, {1.0850126553736983, \
2.5216249314090464}, {0.6088823064479074, 2.3817202672447815}, 
    {0.7148558813281849, 2.504820390287959}, {1.2223478997697899, \
2.646328981764321}}], 
  Line[{{1.0850126553736983, 2.5216249314090464}, {0.9446092599218634, \
2.379229777665829}, {0.5005412188648306, 2.2437468595288657}, 
    {0.6088823064479074, 2.3817202672447815}, {1.0850126553736983, \
2.5216249314090464}}], 
  Line[{{0.9446092599218634, 2.379229777665829}, {0.8072740155257718, \
2.222607239695348}, {0.394567643984553, 2.0946223601372336}, 
    {0.5005412188648306, 2.2437468595288657}, {0.9446092599218634, \
2.379229777665829}}], 
  Line[{{0.8072740155257718, 2.222607239695348}, {0.6790091313731508, \
2.0573688751735335}, {0.29559313554697425, 1.9398272078772512}, 
    {0.394567643984553, 2.0946223601372336}, {0.8072740155257718, \
2.222607239695348}}], 
  Line[{{0.6790091313731508, 2.0573688751735335}, {0.5654203983846704, \
1.8918241808350191}, {0.20794335450320056, 1.7870411277345815}, 
    {0.29559313554697425, 1.9398272078772512}, {0.6790091313731508, \
2.0573688751735335}}], 
  Line[{{0.5654203983846704, 1.8918241808350191}, {0.4714721892511417, \
1.7374623647519978}, {0.13544901687515815, 1.646496168027179}, 
    {0.20794335450320056, 1.7870411277345815}, {0.5654203983846704, \
1.8918241808350191}}], 
  Line[{{0.4714721892511417, 1.7374623647519978}, {0.40127049152522454, \
1.6089224974238359}, {0.0812784730836198, 1.5308481540548229}, 
    {0.13544901687515815, 1.646496168027179}, {0.4714721892511417, \
1.7374623647519978}}], 
  Line[{{0.40127049152522454, 1.6089224974238359}, {0.3578834562626614, \
1.5224519023538965}, {0.04779923583138457, 1.4537753723488893}, 
    {0.0812784730836198, 1.5308481540548229}, {0.40127049152522454, \
1.6089224974238359}}], 
  Line[{{0.3578834562626614, 1.5224519023538965}, {0.3432073050985205, \
1.49178284305241}, {0.03647450843757927, 1.4265847744427305}, 
    {0.04779923583138457, 1.4537753723488893}, {0.3578834562626614, \
1.5224519023538965}}], 
  Line[{{0.3432073050985205, 1.49178284305241}, {0.3578834562626615, \
1.5224519023538965}, {0.04779923583138457, 1.4537753723488893}, 
    {0.03647450843757927, 1.4265847744427305}, {0.3432073050985205, \
1.49178284305241}}], 
  Line[{{0.3578834562626615, 1.5224519023538965}, {0.4012704915252243, \
1.6089224974238356}, {0.0812784730836198, 1.5308481540548227}, 
    {0.04779923583138457, 1.4537753723488893}, {0.3578834562626615, \
1.5224519023538965}}], 
  Line[{{0.4012704915252243, 1.6089224974238356}, {0.47147218925114165, \
1.7374623647519978}, {0.13544901687515815, 1.646496168027179}, 
    {0.0812784730836198, 1.5308481540548227}, {0.4012704915252243, \
1.6089224974238356}}], 
  Line[{{0.47147218925114165, 1.7374623647519978}, {0.5654203983846702, \
1.8918241808350182}, {0.20794335450320034, 1.787041127734581}, 
    {0.13544901687515815, 1.646496168027179}, {0.47147218925114165, \
1.7374623647519978}}], 
  Line[{{0.5654203983846702, 1.8918241808350182}, {0.6790091313731502, \
2.057368875173533}, {0.2955931355469738, 1.9398272078772505}, 
    {0.20794335450320034, 1.787041127734581}, {0.5654203983846702, \
1.8918241808350182}}], 
  Line[{{0.6790091313731502, 2.057368875173533}, {0.8072740155257716, \
2.222607239695348}, {0.3945676439845528, 2.0946223601372336}, 
    {0.2955931355469738, 1.9398272078772505}, {0.6790091313731502, \
2.057368875173533}}], 
  Line[{{0.8072740155257716, 2.222607239695348}, {0.9446092599218627, \
2.379229777665828}, {0.5005412188648302, 2.243746859528865}, 
    {0.3945676439845528, 2.0946223601372336}, {0.8072740155257716, \
2.222607239695348}}], 
  Line[{{0.9446092599218627, 2.379229777665828}, {1.0850126553736974, \
2.5216249314090464}, {0.608882306447907, 2.3817202672447806}, 
    {0.5005412188648302, 2.243746859528865}, {0.9446092599218627, \
2.379229777665828}}], 
  Line[{{1.0850126553736974, 2.5216249314090464}, {1.2223478997697894, \
2.646328981764321}, {0.7148558813281848, 2.5048203902879584}, 
    {0.608882306447907, 2.3817202672447806}, {1.0850126553736974, \
2.5216249314090464}}], 
  Line[{{1.2223478997697894, 2.646328981764321}, {1.3506127839224105, \
2.751525170659194}, {0.8138303897657635, 2.610679178763368}, 
    {0.7148558813281848, 2.5048203902879584}, {1.2223478997697894, \
2.646328981764321}}], 
  Line[{{1.3506127839224105, 2.751525170659194}, {1.4642015169108908, \
2.836596676593442}, {0.9014801708095372, 2.697933958917173}, 
    {0.8138303897657635, 2.610679178763368}, {1.3506127839224105, \
2.751525170659194}}], 
  Line[{{1.4642015169108908, 2.836596676593442}, {1.5581497260444195, \
2.901719090978228}, {0.9739745084375797, 2.7659262761959793}, 
    {0.9014801708095372, 2.697933958917173}, {1.4642015169108908, \
2.836596676593442}}], 
  Line[{{1.5581497260444195, 2.901719090978228}, {1.6283514237703371, \
2.947488384456561}, {1.028145052229118, 2.8144424077524017}, 
    {0.9739745084375797, 2.7659262761959793}, {1.5581497260444195, \
2.901719090978228}}], 
  Line[{{1.6283514237703371, 2.947488384456561}, {1.6717384590329, \
2.9745950829027943}, {1.0616242894813532, 2.843497290965337}, 
    {1.028145052229118, 2.8144424077524017}, {1.6283514237703371, \
2.947488384456561}}], 
  Line[{{1.6717384590329, 2.9745950829027943}, {1.686414610197041, \
2.9835656861048196}, {1.0729490168751585, 2.853169548885461}, 
    {1.0616242894813532, 2.843497290965337}, {1.6717384590329, \
2.9745950829027943}}], 
  Line[{{1.686414610197041, 2.9835656861048196}, {1.6717384590329005, \
2.9745950829027943}, {1.0616242894813537, 2.843497290965337}, 
    {1.0729490168751585, 2.853169548885461}, {1.686414610197041, \
2.9835656861048196}}], 
  Line[{{1.6717384590329005, 2.9745950829027943}, {1.6283514237703374, \
2.9474883844565616}, {1.0281450522291182, 2.8144424077524013}, 
    {1.0616242894813537, 2.843497290965337}, {1.6717384590329005, \
2.9745950829027943}}], 
  Line[{{1.6283514237703374, 2.9474883844565616}, {1.55814972604442, \
2.901719090978228}, {0.9739745084375798, 2.7659262761959797}, 
    {1.0281450522291182, 2.8144424077524013}, {1.6283514237703374, \
2.9474883844565616}}], 
  Line[{{1.55814972604442, 2.901719090978228}, {1.4642015169108917, \
2.836596676593442}, {0.9014801708095378, 2.6979339589171736}, 
    {0.9739745084375798, 2.7659262761959797}, {1.55814972604442, \
2.901719090978228}}], 
  Line[{{1.4642015169108917, 2.836596676593442}, {1.3506127839224114, \
2.7515251706591943}, {0.8138303897657642, 2.6106791787633687}, 
    {0.9014801708095378, 2.6979339589171736}, {1.4642015169108917, \
2.836596676593442}}], 
  Line[{{1.3506127839224114, 2.7515251706591943}, {1.22234789976979, \
2.646328981764321}, {0.7148558813281853, 2.5048203902879593}, 
    {0.8138303897657642, 2.6106791787633687}, {1.3506127839224114, \
2.7515251706591943}}], 
  Line[{{1.22234789976979, 2.646328981764321}, {1.0850126553736987, \
2.5216249314090473}, {0.6088823064479079, 2.381720267244782}, 
    {0.7148558813281853, 2.5048203902879593}, {1.22234789976979, \
2.646328981764321}}], 
  Line[{{1.0850126553736987, 2.5216249314090473}, {0.9446092599218641, \
2.3792297776658295}, {0.5005412188648309, 2.243746859528866}, 
    {0.6088823064479079, 2.381720267244782}, {1.0850126553736987, \
2.5216249314090473}}], 
  Line[{{0.9446092599218641, 2.3792297776658295}, {0.807274015525772, \
2.2226072396953485}, {0.39456764398455324, 2.094622360137234}, 
    {0.5005412188648309, 2.243746859528866}, {0.9446092599218641, \
2.3792297776658295}}], 
  Line[{{0.807274015525772, 2.2226072396953485}, {0.6790091313731512, \
2.0573688751735344}, {0.29559313554697453, 1.9398272078772518}, 
    {0.39456764398455324, 2.094622360137234}, {0.807274015525772, \
2.2226072396953485}}], 
  Line[{{0.6790091313731512, 2.0573688751735344}, {0.565420398384671, \
1.8918241808350198}, {0.20794335450320095, 1.7870411277345821}, 
    {0.29559313554697453, 1.9398272078772518}, {0.6790091313731512, \
2.0573688751735344}}], 
  Line[{{0.565420398384671, 1.8918241808350198}, {0.47147218925114187, \
1.737462364751998}, {0.13544901687515826, 1.6464961680271792}, 
    {0.20794335450320095, 1.7870411277345821}, {0.565420398384671, \
1.8918241808350198}}], 
  Line[{{0.47147218925114187, 1.737462364751998}, {0.40127049152522487, \
1.6089224974238363}, {0.08127847308362002, 1.5308481540548233}, 
    {0.13544901687515826, 1.6464961680271792}, {0.47147218925114187, \
1.737462364751998}}], 
  Line[{{0.40127049152522487, 1.6089224974238363}, {0.3578834562626616, \
1.522451902353897}, {0.04779923583138479, 1.4537753723488898}, 
    {0.08127847308362002, 1.5308481540548233}, {0.40127049152522487, \
1.6089224974238363}}], 
  Line[{{0.3578834562626616, 1.522451902353897}, {0.3432073050985205, \
1.49178284305241}, {0.03647450843757927, 1.4265847744427305}, 
    {0.04779923583138479, 1.4537753723488898}, {0.3578834562626616, \
1.522451902353897}}], 
  Line[{{0.3432073050985205, 1.49178284305241}, {0.35788345626266127, \
1.5224519023538963}, {0.04779923583138446, 1.453775372348889}, 
    {0.03647450843757927, 1.4265847744427305}, {0.3432073050985205, \
1.49178284305241}}], 
  Line[{{0.35788345626266127, 1.5224519023538963}, {0.401270491525224, \
1.608922497423835}, {0.08127847308361935, 1.530848154054822}, 
    {0.04779923583138446, 1.453775372348889}, {0.35788345626266127, \
1.5224519023538963}}], 
  Line[{{0.401270491525224, 1.608922497423835}, {0.47147218925114154, \
1.7374623647519976}, {0.13544901687515803, 1.6464961680271788}, 
    {0.08127847308361935, 1.530848154054822}, {0.401270491525224, \
1.608922497423835}}], 
  Line[{{0.47147218925114154, 1.7374623647519976}, {0.5654203983846697, \
1.891824180835018}, {0.20794335450320006, 1.7870411277345806}, 
    {0.13544901687515803, 1.6464961680271788}, {0.47147218925114154, \
1.7374623647519976}}], 
  Line[{{0.5654203983846697, 1.891824180835018}, {0.6790091313731498, \
2.057368875173532}, {0.29559313554697336, 1.9398272078772498}, 
    {0.20794335450320006, 1.7870411277345806}, {0.5654203983846697, \
1.891824180835018}}], 
  Line[{{0.6790091313731498, 2.057368875173532}, {0.8072740155257715, \
2.2226072396953476}, {0.3945676439845528, 2.094622360137233}, 
    {0.29559313554697336, 1.9398272078772498}, {0.6790091313731498, \
2.057368875173532}}], 
  Line[{{0.8072740155257715, 2.2226072396953476}, {0.9446092599218627, \
2.3792297776658278}, {0.5005412188648299, 2.243746859528865}, 
    {0.3945676439845528, 2.094622360137233}, {0.8072740155257715, \
2.2226072396953476}}], 
  Line[{{0.9446092599218627, 2.3792297776658278}, {1.0850126553736967, \
2.5216249314090455}, {0.6088823064479063, 2.38172026724478}, 
    {0.5005412188648299, 2.243746859528865}, {0.9446092599218627, \
2.3792297776658278}}], 
  Line[{{1.0850126553736967, 2.5216249314090455}, {1.2223478997697896, \
2.6463289817643205}, {0.7148558813281849, 2.5048203902879584}, 
    {0.6088823064479063, 2.38172026724478}, {1.0850126553736967, \
2.5216249314090455}}], 
  Line[{{1.2223478997697896, 2.6463289817643205}, {1.3506127839224105, \
2.7515251706591934}, {0.8138303897657633, 2.610679178763368}, 
    {0.7148558813281849, 2.5048203902879584}, {1.2223478997697896, \
2.6463289817643205}}], 
  Line[{{1.3506127839224105, 2.7515251706591934}, {1.4642015169108902, \
2.8365966765934414}, {0.9014801708095367, 2.6979339589171727}, 
    {0.8138303897657633, 2.610679178763368}, {1.3506127839224105, \
2.7515251706591934}}], 
  Line[{{1.4642015169108902, 2.8365966765934414}, {1.5581497260444195, \
2.901719090978228}, {0.9739745084375797, 2.7659262761959793}, 
    {0.9014801708095367, 2.6979339589171727}, {1.4642015169108902, \
2.8365966765934414}}], 
  Line[{{1.5581497260444195, 2.901719090978228}, {1.6283514237703371, \
2.947488384456561}, {1.028145052229118, 2.8144424077524017}, 
    {0.9739745084375797, 2.7659262761959793}, {1.5581497260444195, \
2.901719090978228}}], 
  Line[{{1.6283514237703371, 2.947488384456561}, {1.6717384590329003, \
2.974595082902794}, {1.0616242894813532, 2.843497290965337}, 
    {1.028145052229118, 2.8144424077524017}, {1.6283514237703371, \
2.947488384456561}}], 
  Line[{{1.6717384590329003, 2.974595082902794}, {1.686414610197041, \
2.9835656861048196}, {1.0729490168751585, 2.853169548885461}, 
    {1.0616242894813532, 2.843497290965337}, {1.6717384590329003, \
2.974595082902794}}], 
  Line[{{1.0729490168751585, 2.853169548885461}, {1.0616242894813532, \
2.843497290965337}, {0.491805350275179, 2.5885835797530192}, 
    {0.5000000000000021, 2.5980762113533173}, {1.0729490168751585, \
2.853169548885461}}], 
  Line[{{1.0616242894813532, 2.843497290965337}, {1.0281450522291185, \
2.8144424077524017}, {0.46757954661597756, 2.56016136091033}, 
    {0.491805350275179, 2.5885835797530192}, {1.0616242894813532, \
2.843497290965337}}], 
  Line[{{1.0281450522291185, 2.8144424077524017}, {0.9739745084375796, \
2.7659262761959793}, {0.4283813728906071, 2.5129980122544073}, 
    {0.46757954661597756, 2.56016136091033}, {1.0281450522291185, \
2.8144424077524017}}], 
  Line[{{0.9739745084375796, 2.7659262761959793}, {0.9014801708095374, \
2.6979339589171736}, {0.3759239773845737, 2.4474780907945575}, 
    {0.4283813728906071, 2.5129980122544073}, {0.9739745084375796, \
2.7659262761959793}}], 
  Line[{{0.9014801708095374, 2.6979339589171736}, {0.8138303897657639, \
2.6106791787633687}, {0.3125000000000019, 2.3642850399222186}, 
    {0.3759239773845737, 2.4474780907945575}, {0.9014801708095374, \
2.6979339589171736}}], 
  Line[{{0.8138303897657639, 2.6106791787633687}, {0.7148558813281849, \
2.504820390287959}, {0.24088137289060696, 2.2645409632922475}, 
    {0.3125000000000019, 2.3642850399222186}, {0.8138303897657639, \
2.6106791787633687}}], 
  Line[{{0.7148558813281849, 2.504820390287959}, {0.6088823064479074, \
2.3817202672447815}, {0.1641981737253718, 2.149982831518161}, 
    {0.24088137289060696, 2.2645409632922475}, {0.7148558813281849, \
2.504820390287959}}], 
  Line[{{0.6088823064479074, 2.3817202672447815}, {0.5005412188648306, \
2.2437468595288657}, {0.0858018262746314, 2.0231783980979907}, 
    {0.1641981737253718, 2.149982831518161}, {0.6088823064479074, \
2.3817202672447815}}], 
  Line[{{0.5005412188648306, 2.2437468595288657}, {0.394567643984553, \
2.0946223601372336}, {0.009118627109396094, 1.8877889819588962}, 
    {0.0858018262746314, 2.0231783980979907}, {0.5005412188648306, \
2.2437468595288657}}], 
  Line[{{0.394567643984553, 2.0946223601372336}, {0.29559313554697425, \
1.9398272078772512}, {-0.06249999999999867, 1.7488835724541536}, 
    {0.009118627109396094, 1.8877889819588962}, {0.394567643984553, \
2.0946223601372336}}], 
  Line[{{0.29559313554697425, 1.9398272078772512}, {0.20794335450320056, \
1.7870411277345815}, {-0.12592397738457056, 1.6132809148526024}, 
    {-0.06249999999999867, 1.7488835724541536}, {0.29559313554697425, \
1.9398272078772512}}], 
  Line[{{0.20794335450320056, 1.7870411277345815}, {0.13544901687515815, \
1.646496168027179}, {-0.17838137289060418, 1.4898021598760784}, 
    {-0.12592397738457056, 1.6132809148526024}, {0.20794335450320056, \
1.7870411277345815}}], 
  Line[{{0.13544901687515815, 1.646496168027179}, {0.0812784730836198, \
1.5308481540548229}, {-0.21757954661597428, 1.3891012614574076}, 
    {-0.17838137289060418, 1.4898021598760784}, {0.13544901687515815, \
1.646496168027179}}], 
  Line[{{0.0812784730836198, 1.5308481540548229}, {0.04779923583138457, \
1.4537753723488893}, {-0.24180535027517608, 1.3224570770547}, 
    {-0.21757954661597428, 1.3891012614574076}, {0.0812784730836198, \
1.5308481540548229}}], 
  Line[{{0.04779923583138457, 1.4537753723488893}, {0.03647450843757927, \
1.4265847744427305}, {-0.249999999999999, 1.2990381056766584}, 
    {-0.24180535027517608, 1.3224570770547}, {0.04779923583138457, \
1.4537753723488893}}], 
  Line[{{0.03647450843757927, 1.4265847744427305}, {0.04779923583138457, \
1.4537753723488893}, {-0.24180535027517608, 1.3224570770547}, 
    {-0.249999999999999, 1.2990381056766584}, {0.03647450843757927, \
1.4265847744427305}}], 
  Line[{{0.04779923583138457, 1.4537753723488893}, {0.0812784730836198, \
1.5308481540548227}, {-0.2175795466159744, 1.3891012614574074}, 
    {-0.24180535027517608, 1.3224570770547}, {0.04779923583138457, \
1.4537753723488893}}], 
  Line[{{0.0812784730836198, 1.5308481540548227}, {0.13544901687515815, \
1.646496168027179}, {-0.17838137289060418, 1.4898021598760782}, 
    {-0.2175795466159744, 1.3891012614574074}, {0.0812784730836198, \
1.5308481540548227}}], 
  Line[{{0.13544901687515815, 1.646496168027179}, {0.20794335450320034, \
1.787041127734581}, {-0.12592397738457067, 1.6132809148526022}, 
    {-0.17838137289060418, 1.4898021598760782}, {0.13544901687515815, \
1.646496168027179}}], 
  Line[{{0.20794335450320034, 1.787041127734581}, {0.2955931355469738, \
1.9398272078772505}, {-0.062499999999998945, 1.7488835724541534}, 
    {-0.12592397738457067, 1.6132809148526022}, {0.20794335450320034, \
1.787041127734581}}], 
  Line[{{0.2955931355469738, 1.9398272078772505}, {0.3945676439845528, \
2.0946223601372336}, {0.009118627109395983, 1.887788981958896}, 
    {-0.062499999999998945, 1.7488835724541534}, {0.2955931355469738, \
1.9398272078772505}}], 
  Line[{{0.3945676439845528, 2.0946223601372336}, {0.5005412188648302, \
2.243746859528865}, {0.08580182627463112, 2.0231783980979903}, 
    {0.009118627109395983, 1.887788981958896}, {0.3945676439845528, \
2.0946223601372336}}], 
  Line[{{0.5005412188648302, 2.243746859528865}, {0.608882306447907, \
2.3817202672447806}, {0.1641981737253714, 2.14998283151816}, 
    {0.08580182627463112, 2.0231783980979903}, {0.5005412188648302, \
2.243746859528865}}], 
  Line[{{0.608882306447907, 2.3817202672447806}, {0.7148558813281848, \
2.5048203902879584}, {0.24088137289060693, 2.264540963292247}, 
    {0.1641981737253714, 2.14998283151816}, {0.608882306447907, \
2.3817202672447806}}], 
  Line[{{0.7148558813281848, 2.5048203902879584}, {0.8138303897657635, \
2.610679178763368}, {0.31250000000000155, 2.3642850399222177}, 
    {0.24088137289060693, 2.264540963292247}, {0.7148558813281848, \
2.5048203902879584}}], 
  Line[{{0.8138303897657635, 2.610679178763368}, {0.9014801708095372, \
2.697933958917173}, {0.3759239773845736, 2.4474780907945575}, 
    {0.31250000000000155, 2.3642850399222177}, {0.8138303897657635, \
2.610679178763368}}], 
  Line[{{0.9014801708095372, 2.697933958917173}, {0.9739745084375797, \
2.7659262761959793}, {0.4283813728906072, 2.5129980122544073}, 
    {0.3759239773845736, 2.4474780907945575}, {0.9014801708095372, \
2.697933958917173}}], 
  Line[{{0.9739745084375797, 2.7659262761959793}, {1.028145052229118, \
2.8144424077524017}, {0.4675795466159774, 2.5601613609103295}, 
    {0.4283813728906072, 2.5129980122544073}, {0.9739745084375797, \
2.7659262761959793}}], 
  Line[{{1.028145052229118, 2.8144424077524017}, {1.0616242894813532, \
2.843497290965337}, {0.4918053502751791, 2.5885835797530192}, 
    {0.4675795466159774, 2.5601613609103295}, {1.028145052229118, \
2.8144424077524017}}], 
  Line[{{1.0616242894813532, 2.843497290965337}, {1.0729490168751585, \
2.853169548885461}, {0.5000000000000021, 2.5980762113533173}, 
    {0.4918053502751791, 2.5885835797530192}, {1.0616242894813532, \
2.843497290965337}}], 
  Line[{{1.0729490168751585, 2.853169548885461}, {1.0616242894813537, \
2.843497290965337}, {0.49180535027517946, 2.5885835797530197}, 
    {0.5000000000000021, 2.5980762113533173}, {1.0729490168751585, \
2.853169548885461}}], 
  Line[{{1.0616242894813537, 2.843497290965337}, {1.0281450522291182, \
2.8144424077524013}, {0.4675795466159775, 2.56016136091033}, 
    {0.49180535027517946, 2.5885835797530197}, {1.0616242894813537, \
2.843497290965337}}], 
  Line[{{1.0281450522291182, 2.8144424077524013}, {0.9739745084375798, \
2.7659262761959797}, {0.4283813728906073, 2.5129980122544078}, 
    {0.4675795466159775, 2.56016136091033}, {1.0281450522291182, \
2.8144424077524013}}], 
  Line[{{0.9739745084375798, 2.7659262761959797}, {0.9014801708095378, \
2.6979339589171736}, {0.375923977384574, 2.4474780907945575}, 
    {0.4283813728906073, 2.5129980122544078}, {0.9739745084375798, \
2.7659262761959797}}], 
  Line[{{0.9014801708095378, 2.6979339589171736}, {0.8138303897657642, \
2.6106791787633687}, {0.3125000000000021, 2.3642850399222186}, 
    {0.375923977384574, 2.4474780907945575}, {0.9014801708095378, \
2.6979339589171736}}], 
  Line[{{0.8138303897657642, 2.6106791787633687}, {0.7148558813281853, \
2.5048203902879593}, {0.24088137289060724, 2.2645409632922475}, 
    {0.3125000000000021, 2.3642850399222186}, {0.8138303897657642, \
2.6106791787633687}}], 
  Line[{{0.7148558813281853, 2.5048203902879593}, {0.6088823064479079, \
2.381720267244782}, {0.1641981737253721, 2.1499828315181615}, 
    {0.24088137289060724, 2.2645409632922475}, {0.7148558813281853, \
2.5048203902879593}}], 
  Line[{{0.6088823064479079, 2.381720267244782}, {0.5005412188648309, \
2.243746859528866}, {0.08580182627463168, 2.023178398097991}, 
    {0.1641981737253721, 2.1499828315181615}, {0.6088823064479079, \
2.381720267244782}}], 
  Line[{{0.5005412188648309, 2.243746859528866}, {0.39456764398455324, \
2.094622360137234}, {0.00911862710939626, 1.8877889819588964}, 
    {0.08580182627463168, 2.023178398097991}, {0.5005412188648309, \
2.243746859528866}}], 
  Line[{{0.39456764398455324, 2.094622360137234}, {0.29559313554697453, \
1.9398272078772518}, {-0.06249999999999839, 1.7488835724541543}, 
    {0.00911862710939626, 1.8877889819588964}, {0.39456764398455324, \
2.094622360137234}}], 
  Line[{{0.29559313554697453, 1.9398272078772518}, {0.20794335450320095, \
1.7870411277345821}, {-0.12592397738457028, 1.613280914852603}, 
    {-0.06249999999999839, 1.7488835724541543}, {0.29559313554697453, \
1.9398272078772518}}], 
  Line[{{0.20794335450320095, 1.7870411277345821}, {0.13544901687515826, \
1.6464961680271792}, {-0.17838137289060407, 1.4898021598760784}, 
    {-0.12592397738457028, 1.613280914852603}, {0.20794335450320095, \
1.7870411277345821}}], 
  Line[{{0.13544901687515826, 1.6464961680271792}, {0.08127847308362002, \
1.5308481540548233}, {-0.21757954661597417, 1.3891012614574079}, 
    {-0.17838137289060407, 1.4898021598760784}, {0.13544901687515826, \
1.6464961680271792}}], 
  Line[{{0.08127847308362002, 1.5308481540548233}, {0.04779923583138479, \
1.4537753723488898}, {-0.24180535027517597, 1.3224570770547004}, 
    {-0.21757954661597417, 1.3891012614574079}, {0.08127847308362002, \
1.5308481540548233}}], 
  Line[{{0.04779923583138479, 1.4537753723488898}, {0.03647450843757927, \
1.4265847744427305}, {-0.249999999999999, 1.2990381056766584}, 
    {-0.24180535027517597, 1.3224570770547004}, {0.04779923583138479, \
1.4537753723488898}}], 
  Line[{{0.03647450843757927, 1.4265847744427305}, {0.04779923583138446, \
1.453775372348889}, {-0.2418053502751762, 1.3224570770547}, 
    {-0.249999999999999, 1.2990381056766584}, {0.03647450843757927, \
1.4265847744427305}}], 
  Line[{{0.04779923583138446, 1.453775372348889}, {0.08127847308361935, \
1.530848154054822}, {-0.21757954661597456, 1.389101261457407}, 
    {-0.2418053502751762, 1.3224570770547}, {0.04779923583138446, \
1.453775372348889}}], 
  Line[{{0.08127847308361935, 1.530848154054822}, {0.13544901687515803, \
1.6464961680271788}, {-0.1783813728906043, 1.489802159876078}, 
    {-0.21757954661597456, 1.389101261457407}, {0.08127847308361935, \
1.530848154054822}}], 
  Line[{{0.13544901687515803, 1.6464961680271788}, {0.20794335450320006, \
1.7870411277345806}, {-0.125923977384571, 1.6132809148526015}, 
    {-0.1783813728906043, 1.489802159876078}, {0.13544901687515803, \
1.6464961680271788}}], 
  Line[{{0.20794335450320006, 1.7870411277345806}, {0.29559313554697336, \
1.9398272078772498}, {-0.06249999999999922, 1.7488835724541525}, 
    {-0.125923977384571, 1.6132809148526015}, {0.20794335450320006, \
1.7870411277345806}}], 
  Line[{{0.29559313554697336, 1.9398272078772498}, {0.3945676439845528, \
2.094622360137233}, {0.009118627109395927, 1.887788981958896}, 
    {-0.06249999999999922, 1.7488835724541525}, {0.29559313554697336, \
1.9398272078772498}}], 
  Line[{{0.3945676439845528, 2.094622360137233}, {0.5005412188648299, \
2.243746859528865}, {0.08580182627463095, 2.02317839809799}, 
    {0.009118627109395927, 1.887788981958896}, {0.3945676439845528, \
2.094622360137233}}], 
  Line[{{0.5005412188648299, 2.243746859528865}, {0.6088823064479063, \
2.38172026724478}, {0.16419817372537102, 2.1499828315181597}, 
    {0.08580182627463095, 2.02317839809799}, {0.5005412188648299, \
2.243746859528865}}], 
  Line[{{0.6088823064479063, 2.38172026724478}, {0.7148558813281849, \
2.5048203902879584}, {0.240881372890607, 2.264540963292247}, 
    {0.16419817372537102, 2.1499828315181597}, {0.6088823064479063, \
2.38172026724478}}], 
  Line[{{0.7148558813281849, 2.5048203902879584}, {0.8138303897657633, \
2.610679178763368}, {0.3125000000000015, 2.3642850399222177}, 
    {0.240881372890607, 2.264540963292247}, {0.7148558813281849, \
2.5048203902879584}}], 
  Line[{{0.8138303897657633, 2.610679178763368}, {0.9014801708095367, \
2.6979339589171727}, {0.37592397738457317, 2.4474780907945566}, 
    {0.3125000000000015, 2.3642850399222177}, {0.8138303897657633, \
2.610679178763368}}], 
  Line[{{0.9014801708095367, 2.6979339589171727}, {0.9739745084375797, \
2.7659262761959793}, {0.4283813728906072, 2.5129980122544073}, 
    {0.37592397738457317, 2.4474780907945566}, {0.9014801708095367, \
2.6979339589171727}}], 
  Line[{{0.9739745084375797, 2.7659262761959793}, {1.028145052229118, \
2.8144424077524017}, {0.46757954661597745, 2.5601613609103295}, 
    {0.4283813728906072, 2.5129980122544073}, {0.9739745084375797, \
2.7659262761959793}}], 
  Line[{{1.028145052229118, 2.8144424077524017}, {1.0616242894813532, \
2.843497290965337}, {0.49180535027517913, 2.5885835797530192}, 
    {0.46757954661597745, 2.5601613609103295}, {1.028145052229118, \
2.8144424077524017}}], 
  Line[{{1.0616242894813532, 2.843497290965337}, {1.0729490168751585, \
2.853169548885461}, {0.5000000000000021, 2.5980762113533173}, 
    {0.49180535027517913, 2.5885835797530192}, {1.0616242894813532, \
2.843497290965337}}], 
  Line[{{0.5000000000000021, 2.5980762113533173}, {0.491805350275179, \
2.5885835797530192}, {-0.012814536647680919, 2.2208803408437965}, 
    {-0.0073918190765734915, 2.2294344764321834}, {0.5000000000000021, \
2.5980762113533173}}], 
  Line[{{0.491805350275179, 2.5885835797530192}, {0.46757954661597756, \
2.56016136091033}, {-0.02884569058205967, 2.1953185530328274}, 
    {-0.012814536647680919, 2.2208803408437965}, {0.491805350275179, \
2.5885835797530192}}], 
  Line[{{0.46757954661597756, 2.56016136091033}, {0.4283813728906071, \
2.5129980122544073}, {-0.05478464252676654, 2.153063306659971}, 
    {-0.02884569058205967, 2.1953185530328274}, {0.46757954661597756, \
2.56016136091033}}], 
  Line[{{0.4283813728906071, 2.5129980122544073}, {0.3759239773845737, \
2.4474780907945575}, {-0.08949773581291628, 2.094679321954477}, 
    {-0.05478464252676654, 2.153063306659971}, {0.4283813728906071, \
2.5129980122544073}}], 
  Line[{{0.3759239773845737, 2.4474780907945575}, {0.3125000000000019, \
2.3642850399222186}, {-0.13146784169200168, 2.0210434859217044}, 
    {-0.08949773581291628, 2.094679321954477}, {0.3759239773845737, \
2.4474780907945575}}], 
  Line[{{0.3125000000000019, 2.3642850399222186}, {0.24088137289060696, \
2.2645409632922475}, {-0.17886066514219484, 1.933432094411192}, 
    {-0.13146784169200168, 2.0210434859217044}, {0.3125000000000019, \
2.3642850399222186}}], 
  Line[{{0.24088137289060696, 2.2645409632922475}, {0.1641981737253718, \
2.149982831518161}, {-0.22960491236272335, 1.8336364565828096}, 
    {-0.17886066514219484, 1.933432094411192}, {0.24088137289060696, \
2.2645409632922475}}], 
  Line[{{0.1641981737253718, 2.149982831518161}, {0.0858018262746314, \
2.0231783980979907}, {-0.28148281625213684, 1.7241122839361502}, 
    {-0.22960491236272335, 1.8336364565828096}, {0.1641981737253718, \
2.149982831518161}}], 
  Line[{{0.0858018262746314, 2.0231783980979907}, {0.009118627109396094, \
1.8877889819588962}, {-0.3322270634726655, 1.6081701375219575}, 
    {-0.28148281625213684, 1.7241122839361502}, {0.0858018262746314, \
2.0231783980979907}}], 
  Line[{{0.009118627109396094, 1.8877889819588962}, {-0.06249999999999867, \
1.7488835724541536}, {-0.3796198869228584, 1.4902097135042398}, 
    {-0.3322270634726655, 1.6081701375219575}, {0.009118627109396094, \
1.8877889819588962}}], 
  Line[{{-0.06249999999999867, 1.7488835724541536}, {-0.12592397738457056, \
1.6132809148526024}, {-0.421589992801944, 1.3759750672106559}, 
    {-0.3796198869228584, 1.4902097135042398}, {-0.06249999999999867, \
1.7488835724541536}}], 
  Line[{{-0.12592397738457056, 1.6132809148526024}, {-0.17838137289060418, \
1.4898021598760784}, {-0.4563030860880937, 1.2727298803122153}, 
    {-0.421589992801944, 1.3759750672106559}, {-0.12592397738457056, \
1.6132809148526024}}], 
  Line[{{-0.17838137289060418, 1.4898021598760784}, {-0.21757954661597428, \
1.3891012614574076}, {-0.48224203803280036, 1.1890852819516726}, 
    {-0.4563030860880937, 1.2727298803122153}, {-0.17838137289060418, \
1.4898021598760784}}], 
  Line[{{-0.21757954661597428, 1.3891012614574076}, {-0.24180535027517608, \
1.3224570770547}, {-0.49827319196717934, 1.1340136417284863}, 
    {-0.48224203803280036, 1.1890852819516726}, {-0.21757954661597428, \
1.3891012614574076}}], 
  Line[{{-0.24180535027517608, 1.3224570770547}, {-0.249999999999999, \
1.2990381056766584}, {-0.5036959095382867, 1.1147172382160917}, 
    {-0.49827319196717934, 1.1340136417284863}, {-0.24180535027517608, \
1.3224570770547}}], 
  Line[{{-0.249999999999999, 1.2990381056766584}, {-0.24180535027517608, \
1.3224570770547}, {-0.4982731919671793, 1.1340136417284863}, 
    {-0.5036959095382867, 1.1147172382160917}, {-0.249999999999999, \
1.2990381056766584}}], 
  Line[{{-0.24180535027517608, 1.3224570770547}, {-0.2175795466159744, \
1.3891012614574074}, {-0.4822420380328004, 1.1890852819516724}, 
    {-0.4982731919671793, 1.1340136417284863}, {-0.24180535027517608, \
1.3224570770547}}], 
  Line[{{-0.2175795466159744, 1.3891012614574074}, {-0.17838137289060418, \
1.4898021598760782}, {-0.4563030860880938, 1.2727298803122153}, 
    {-0.4822420380328004, 1.1890852819516724}, {-0.2175795466159744, \
1.3891012614574074}}], 
  Line[{{-0.17838137289060418, 1.4898021598760782}, {-0.12592397738457067, \
1.6132809148526022}, {-0.42158999280194415, 1.3759750672106557}, 
    {-0.4563030860880938, 1.2727298803122153}, {-0.17838137289060418, \
1.4898021598760782}}], 
  Line[{{-0.12592397738457067, 1.6132809148526022}, {-0.062499999999998945, \
1.7488835724541534}, {-0.37961988692285853, 1.4902097135042391}, 
    {-0.42158999280194415, 1.3759750672106557}, {-0.12592397738457067, \
1.6132809148526022}}], 
  Line[{{-0.062499999999998945, 1.7488835724541534}, {0.009118627109395983, \
1.887788981958896}, {-0.3322270634726655, 1.6081701375219573}, 
    {-0.37961988692285853, 1.4902097135042391}, {-0.062499999999998945, \
1.7488835724541534}}], 
  Line[{{0.009118627109395983, 1.887788981958896}, {0.08580182627463112, \
2.0231783980979903}, {-0.281482816252137, 1.72411228393615}, 
    {-0.3322270634726655, 1.6081701375219573}, {0.009118627109395983, \
1.887788981958896}}], 
  Line[{{0.08580182627463112, 2.0231783980979903}, {0.1641981737253714, \
2.14998283151816}, {-0.22960491236272362, 1.8336364565828094}, 
    {-0.281482816252137, 1.72411228393615}, {0.08580182627463112, \
2.0231783980979903}}], 
  Line[{{0.1641981737253714, 2.14998283151816}, {0.24088137289060693, \
2.264540963292247}, {-0.1788606651421949, 1.9334320944111918}, 
    {-0.22960491236272362, 1.8336364565828094}, {0.1641981737253714, \
2.14998283151816}}], 
  Line[{{0.24088137289060693, 2.264540963292247}, {0.31250000000000155, \
2.3642850399222177}, {-0.13146784169200199, 2.021043485921704}, 
    {-0.1788606651421949, 1.9334320944111918}, {0.24088137289060693, \
2.264540963292247}}], 
  Line[{{0.31250000000000155, 2.3642850399222177}, {0.3759239773845736, \
2.4474780907945575}, {-0.08949773581291631, 2.094679321954477}, 
    {-0.13146784169200199, 2.021043485921704}, {0.31250000000000155, \
2.3642850399222177}}], 
  Line[{{0.3759239773845736, 2.4474780907945575}, {0.4283813728906072, \
2.5129980122544073}, {-0.054784642526766514, 2.153063306659971}, 
    {-0.08949773581291631, 2.094679321954477}, {0.3759239773845736, \
2.4474780907945575}}], 
  Line[{{0.4283813728906072, 2.5129980122544073}, {0.4675795466159774, \
2.5601613609103295}, {-0.028845690582059838, 2.195318553032827}, 
    {-0.054784642526766514, 2.153063306659971}, {0.4283813728906072, \
2.5129980122544073}}], 
  Line[{{0.4675795466159774, 2.5601613609103295}, {0.4918053502751791, \
2.5885835797530192}, {-0.0128145366476809, 2.2208803408437965}, 
    {-0.028845690582059838, 2.195318553032827}, {0.4675795466159774, \
2.5601613609103295}}], 
  Line[{{0.4918053502751791, 2.5885835797530192}, {0.5000000000000021, \
2.5980762113533173}, {-0.0073918190765734915, 2.2294344764321834}, 
    {-0.0128145366476809, 2.2208803408437965}, {0.4918053502751791, \
2.5885835797530192}}], 
  Line[{{0.5000000000000021, 2.5980762113533173}, {0.49180535027517946, \
2.5885835797530197}, {-0.012814536647680836, 2.220880340843797}, 
    {-0.0073918190765734915, 2.2294344764321834}, {0.5000000000000021, \
2.5980762113533173}}], 
  Line[{{0.49180535027517946, 2.5885835797530197}, {0.4675795466159775, \
2.56016136091033}, {-0.028845690582059706, 2.1953185530328274}, 
    {-0.012814536647680836, 2.220880340843797}, {0.49180535027517946, \
2.5885835797530197}}], 
  Line[{{0.4675795466159775, 2.56016136091033}, {0.4283813728906073, \
2.5129980122544078}, {-0.05478464252676645, 2.153063306659971}, 
    {-0.028845690582059706, 2.1953185530328274}, {0.4675795466159775, \
2.56016136091033}}], 
  Line[{{0.4283813728906073, 2.5129980122544078}, {0.375923977384574, \
2.4474780907945575}, {-0.08949773581291603, 2.0946793219544775}, 
    {-0.05478464252676645, 2.153063306659971}, {0.4283813728906073, \
2.5129980122544078}}], 
  Line[{{0.375923977384574, 2.4474780907945575}, {0.3125000000000021, \
2.3642850399222186}, {-0.13146784169200165, 2.0210434859217044}, 
    {-0.08949773581291603, 2.0946793219544775}, {0.375923977384574, \
2.4474780907945575}}], 
  Line[{{0.3125000000000021, 2.3642850399222186}, {0.24088137289060724, \
2.2645409632922475}, {-0.17886066514219465, 1.9334320944111922}, 
    {-0.13146784169200165, 2.0210434859217044}, {0.3125000000000021, \
2.3642850399222186}}], 
  Line[{{0.24088137289060724, 2.2645409632922475}, {0.1641981737253721, \
2.1499828315181615}, {-0.22960491236272318, 1.8336364565828103}, 
    {-0.17886066514219465, 1.9334320944111922}, {0.24088137289060724, \
2.2645409632922475}}], 
  Line[{{0.1641981737253721, 2.1499828315181615}, {0.08580182627463168, \
2.023178398097991}, {-0.28148281625213667, 1.7241122839361507}, 
    {-0.22960491236272318, 1.8336364565828103}, {0.1641981737253721, \
2.1499828315181615}}], 
  Line[{{0.08580182627463168, 2.023178398097991}, {0.00911862710939626, \
1.8877889819588964}, {-0.33222706347266534, 1.6081701375219577}, 
    {-0.28148281625213667, 1.7241122839361507}, {0.08580182627463168, \
2.023178398097991}}], 
  Line[{{0.00911862710939626, 1.8877889819588964}, {-0.06249999999999839, \
1.7488835724541543}, {-0.3796198869228583, 1.49020971350424}, 
    {-0.33222706347266534, 1.6081701375219577}, {0.00911862710939626, \
1.8877889819588964}}], 
  Line[{{-0.06249999999999839, 1.7488835724541543}, {-0.12592397738457028, \
1.613280914852603}, {-0.42158999280194376, 1.3759750672106568}, 
    {-0.3796198869228583, 1.49020971350424}, {-0.06249999999999839, \
1.7488835724541543}}], 
  Line[{{-0.12592397738457028, 1.613280914852603}, {-0.17838137289060407, \
1.4898021598760784}, {-0.4563030860880937, 1.2727298803122153}, 
    {-0.42158999280194376, 1.3759750672106568}, {-0.12592397738457028, \
1.613280914852603}}], 
  Line[{{-0.17838137289060407, 1.4898021598760784}, {-0.21757954661597417, \
1.3891012614574079}, {-0.48224203803280025, 1.1890852819516728}, 
    {-0.4563030860880937, 1.2727298803122153}, {-0.17838137289060407, \
1.4898021598760784}}], 
  Line[{{-0.21757954661597417, 1.3891012614574079}, {-0.24180535027517597, \
1.3224570770547004}, {-0.49827319196717923, 1.1340136417284865}, 
    {-0.48224203803280025, 1.1890852819516728}, {-0.21757954661597417, \
1.3891012614574079}}], 
  Line[{{-0.24180535027517597, 1.3224570770547004}, {-0.249999999999999, \
1.2990381056766584}, {-0.5036959095382867, 1.1147172382160917}, 
    {-0.49827319196717923, 1.1340136417284865}, {-0.24180535027517597, \
1.3224570770547004}}], 
  Line[{{-0.249999999999999, 1.2990381056766584}, {-0.2418053502751762, \
1.3224570770547}, {-0.4982731919671794, 1.134013641728486}, 
    {-0.5036959095382867, 1.1147172382160917}, {-0.249999999999999, \
1.2990381056766584}}], 
  Line[{{-0.2418053502751762, 1.3224570770547}, {-0.21757954661597456, \
1.389101261457407}, {-0.4822420380328006, 1.189085281951672}, 
    {-0.4982731919671794, 1.134013641728486}, {-0.2418053502751762, \
1.3224570770547}}], 
  Line[{{-0.21757954661597456, 1.389101261457407}, {-0.1783813728906043, \
1.489802159876078}, {-0.4563030860880938, 1.2727298803122151}, 
    {-0.4822420380328006, 1.189085281951672}, {-0.21757954661597456, \
1.389101261457407}}], 
  Line[{{-0.1783813728906043, 1.489802159876078}, {-0.125923977384571, \
1.6132809148526015}, {-0.4215899928019442, 1.3759750672106552}, 
    {-0.4563030860880938, 1.2727298803122151}, {-0.1783813728906043, \
1.489802159876078}}], 
  Line[{{-0.125923977384571, 1.6132809148526015}, {-0.06249999999999922, \
1.7488835724541525}, {-0.3796198869228588, 1.4902097135042387}, 
    {-0.4215899928019442, 1.3759750672106552}, {-0.125923977384571, \
1.6132809148526015}}], 
  Line[{{-0.06249999999999922, 1.7488835724541525}, {0.009118627109395927, \
1.887788981958896}, {-0.33222706347266556, 1.6081701375219573}, 
    {-0.3796198869228588, 1.4902097135042387}, {-0.06249999999999922, \
1.7488835724541525}}], 
  Line[{{0.009118627109395927, 1.887788981958896}, {0.08580182627463095, \
2.02317839809799}, {-0.2814828162521371, 1.7241122839361496}, 
    {-0.33222706347266556, 1.6081701375219573}, {0.009118627109395927, \
1.887788981958896}}], 
  Line[{{0.08580182627463095, 2.02317839809799}, {0.16419817372537102, \
2.1499828315181597}, {-0.2296049123627239, 1.833636456582809}, 
    {-0.2814828162521371, 1.7241122839361496}, {0.08580182627463095, \
2.02317839809799}}], 
  Line[{{0.16419817372537102, 2.1499828315181597}, {0.240881372890607, \
2.264540963292247}, {-0.17886066514219484, 1.9334320944111918}, 
    {-0.2296049123627239, 1.833636456582809}, {0.16419817372537102, \
2.1499828315181597}}], 
  Line[{{0.240881372890607, 2.264540963292247}, {0.3125000000000015, \
2.3642850399222177}, {-0.13146784169200207, 2.021043485921704}, 
    {-0.17886066514219484, 1.9334320944111918}, {0.240881372890607, \
2.264540963292247}}], 
  Line[{{0.3125000000000015, 2.3642850399222177}, {0.37592397738457317, \
2.4474780907945566}, {-0.0894977358129165, 2.0946793219544766}, 
    {-0.13146784169200207, 2.021043485921704}, {0.3125000000000015, \
2.3642850399222177}}], 
  Line[{{0.37592397738457317, 2.4474780907945566}, {0.4283813728906072, \
2.5129980122544073}, {-0.05478464252676649, 2.153063306659971}, 
    {-0.0894977358129165, 2.0946793219544766}, {0.37592397738457317, \
2.4474780907945566}}], 
  Line[{{0.4283813728906072, 2.5129980122544073}, {0.46757954661597745, \
2.5601613609103295}, {-0.02884569058205982, 2.195318553032827}, 
    {-0.05478464252676649, 2.153063306659971}, {0.4283813728906072, \
2.5129980122544073}}], 
  Line[{{0.46757954661597745, 2.5601613609103295}, {0.49180535027517913, \
2.5885835797530192}, {-0.01281453664768086, 2.2208803408437965}, 
    {-0.02884569058205982, 2.195318553032827}, {0.46757954661597745, \
2.5601613609103295}}], 
  Line[{{0.49180535027517913, 2.5885835797530192}, {0.5000000000000021, \
2.5980762113533173}, {-0.0073918190765734915, 2.2294344764321834}, 
    {-0.01281453664768086, 2.2208803408437965}, {0.49180535027517913, \
2.5885835797530192}}], 
  Line[{{-0.0073918190765734915, 2.2294344764321834}, {-0.012814536647680919, \
2.2208803408437965}, {-0.43018106079382434, 1.75636834939373}, 
    {-0.4270509831248419, 1.7633557568774199}, {-0.0073918190765734915, \
2.2294344764321834}}], 
  Line[{{-0.012814536647680919, 2.2208803408437965}, {-0.02884569058205967, \
2.1953185530328274}, {-0.4394344943868577, 1.7355139912456736}, 
    {-0.43018106079382434, 1.75636834939373}, {-0.012814536647680919, \
2.2208803408437965}}], 
  Line[{{-0.02884569058205967, 2.1953185530328274}, {-0.05478464252676654, \
2.153063306659971}, {-0.45440686445302614, 1.7011229525643676}, 
    {-0.4394344943868577, 1.7355139912456736}, {-0.02884569058205967, \
2.1953185530328274}}], 
  Line[{{-0.05478464252676654, 2.153063306659971}, {-0.08949773581291628, \
2.094679321954477}, {-0.474443806575035, 1.6537682358032737}, 
    {-0.45440686445302614, 1.7011229525643676}, {-0.05478464252676654, \
2.153063306659971}}], 
  Line[{{-0.08949773581291628, 2.094679321954477}, {-0.13146784169200168, \
2.0210434859217044}, {-0.4986696102342367, 1.594300566883078}, 
    {-0.474443806575035, 1.6537682358032737}, {-0.08949773581291628, \
2.094679321954477}}], 
  Line[{{-0.13146784169200168, 2.0210434859217044}, {-0.17886066514219484, \
1.933432094411192}, {-0.5260254915624208, 1.5239001577085334}, 
    {-0.4986696102342367, 1.594300566883078}, {-0.13146784169200168, \
2.0210434859217044}}], 
  Line[{{-0.17886066514219484, 1.933432094411192}, {-0.22960491236272335, \
1.8336364565828096}, {-0.5553158672774632, 1.4441489417584887}, 
    {-0.5260254915624208, 1.5239001577085334}, {-0.17886066514219484, \
1.933432094411192}}], 
  Line[{{-0.22960491236272335, 1.8336364565828096}, {-0.28148281625213684, \
1.7241122839361502}, {-0.5852606074097998, 1.3571288512592459}, 
    {-0.5553158672774632, 1.4441489417584887}, {-0.22960491236272335, \
1.8336364565828096}}], 
  Line[{{-0.28148281625213684, 1.7241122839361502}, {-0.3322270634726655, \
1.6081701375219575}, {-0.614550983124842, 1.2655525104241712}, 
    {-0.5852606074097998, 1.3571288512592459}, {-0.28148281625213684, \
1.7241122839361502}}], 
  Line[{{-0.3322270634726655, 1.6081701375219575}, {-0.3796198869228584, \
1.4902097135042398}, {-0.6419068644530261, 1.1729281630054873}, 
    {-0.614550983124842, 1.2655525104241712}, {-0.3322270634726655, \
1.6081701375219575}}], 
  Line[{{-0.3796198869228584, 1.4902097135042398}, {-0.421589992801944, \
1.3759750672106559}, {-0.6661326681122279, 1.0837396094369784}, 
    {-0.6419068644530261, 1.1729281630054873}, {-0.3796198869228584, \
1.4902097135042398}}], 
  Line[{{-0.421589992801944, 1.3759750672106559}, {-0.4563030860880937, \
1.2727298803122153}, {-0.6861696102342367, 1.0035621274868158}, 
    {-0.6661326681122279, 1.0837396094369784}, {-0.421589992801944, \
1.3759750672106559}}], 
  Line[{{-0.4563030860880937, 1.2727298803122153}, {-0.48224203803280036, \
1.1890852819516726}, {-0.701141980300405, 0.9389137397717199}, 
    {-0.6861696102342367, 1.0035621274868158}, {-0.4563030860880937, \
1.2727298803122153}}], 
  Line[{{-0.48224203803280036, 1.1890852819516726}, {-0.49827319196717934, \
1.1340136417284863}, {-0.7103954138934385, 0.896506223090295}, 
    {-0.701141980300405, 0.9389137397717199}, {-0.48224203803280036, \
1.1890852819516726}}], 
  Line[{{-0.49827319196717934, 1.1340136417284863}, {-0.5036959095382867, \
1.1147172382160917}, {-0.713525491562421, 0.8816778784387099}, 
    {-0.7103954138934385, 0.896506223090295}, {-0.49827319196717934, \
1.1340136417284863}}], 
  Line[{{-0.5036959095382867, 1.1147172382160917}, {-0.4982731919671793, \
1.1340136417284863}, {-0.7103954138934385, 0.896506223090295}, 
    {-0.713525491562421, 0.8816778784387099}, {-0.5036959095382867, \
1.1147172382160917}}], 
  Line[{{-0.4982731919671793, 1.1340136417284863}, {-0.4822420380328004, \
1.1890852819516724}, {-0.7011419803004051, 0.9389137397717195}, 
    {-0.7103954138934385, 0.896506223090295}, {-0.4982731919671793, \
1.1340136417284863}}], 
  Line[{{-0.4822420380328004, 1.1890852819516724}, {-0.4563030860880938, \
1.2727298803122153}, {-0.6861696102342368, 1.0035621274868156}, 
    {-0.7011419803004051, 0.9389137397717195}, {-0.4822420380328004, \
1.1890852819516724}}], 
  Line[{{-0.4563030860880938, 1.2727298803122153}, {-0.42158999280194415, \
1.3759750672106557}, {-0.6661326681122279, 1.0837396094369782}, 
    {-0.6861696102342368, 1.0035621274868156}, {-0.4563030860880938, \
1.2727298803122153}}], 
  Line[{{-0.42158999280194415, 1.3759750672106557}, {-0.37961988692285853, \
1.4902097135042391}, {-0.6419068644530262, 1.1729281630054869}, 
    {-0.6661326681122279, 1.0837396094369782}, {-0.42158999280194415, \
1.3759750672106557}}], 
  Line[{{-0.37961988692285853, 1.4902097135042391}, {-0.3322270634726655, \
1.6081701375219573}, {-0.614550983124842, 1.265552510424171}, 
    {-0.6419068644530262, 1.1729281630054869}, {-0.37961988692285853, \
1.4902097135042391}}], 
  Line[{{-0.3322270634726655, 1.6081701375219573}, {-0.281482816252137, \
1.72411228393615}, {-0.5852606074097999, 1.3571288512592452}, 
    {-0.614550983124842, 1.265552510424171}, {-0.3322270634726655, \
1.6081701375219573}}], 
  Line[{{-0.281482816252137, 1.72411228393615}, {-0.22960491236272362, \
1.8336364565828094}, {-0.5553158672774632, 1.4441489417584883}, 
    {-0.5852606074097999, 1.3571288512592452}, {-0.281482816252137, \
1.72411228393615}}], 
  Line[{{-0.22960491236272362, 1.8336364565828094}, {-0.1788606651421949, \
1.9334320944111918}, {-0.5260254915624208, 1.5239001577085334}, 
    {-0.5553158672774632, 1.4441489417584883}, {-0.22960491236272362, \
1.8336364565828094}}], 
  Line[{{-0.1788606651421949, 1.9334320944111918}, {-0.13146784169200199, \
2.021043485921704}, {-0.4986696102342367, 1.5943005668830776}, 
    {-0.5260254915624208, 1.5239001577085334}, {-0.1788606651421949, \
1.9334320944111918}}], 
  Line[{{-0.13146784169200199, 2.021043485921704}, {-0.08949773581291631, \
2.094679321954477}, {-0.47444380657503493, 1.6537682358032735}, 
    {-0.4986696102342367, 1.5943005668830776}, {-0.13146784169200199, \
2.021043485921704}}], 
  Line[{{-0.08949773581291631, 2.094679321954477}, {-0.054784642526766514, \
2.153063306659971}, {-0.4544068644530261, 1.7011229525643676}, 
    {-0.47444380657503493, 1.6537682358032735}, {-0.08949773581291631, \
2.094679321954477}}], 
  Line[{{-0.054784642526766514, 2.153063306659971}, {-0.028845690582059838, \
2.195318553032827}, {-0.43943449438685783, 1.7355139912456734}, 
    {-0.4544068644530261, 1.7011229525643676}, {-0.054784642526766514, \
2.153063306659971}}], 
  Line[{{-0.028845690582059838, 2.195318553032827}, {-0.0128145366476809, \
2.2208803408437965}, {-0.43018106079382434, 1.75636834939373}, 
    {-0.43943449438685783, 1.7355139912456734}, {-0.028845690582059838, \
2.195318553032827}}], 
  Line[{{-0.0128145366476809, 2.2208803408437965}, {-0.0073918190765734915, \
2.2294344764321834}, {-0.4270509831248419, 1.7633557568774199}, 
    {-0.43018106079382434, 1.75636834939373}, {-0.0128145366476809, \
2.2208803408437965}}], 
  Line[{{-0.0073918190765734915, 2.2294344764321834}, {-0.012814536647680836, \
2.220880340843797}, {-0.43018106079382423, 1.75636834939373}, 
    {-0.4270509831248419, 1.7633557568774199}, {-0.0073918190765734915, \
2.2294344764321834}}], 
  Line[{{-0.012814536647680836, 2.220880340843797}, {-0.028845690582059706, \
2.1953185530328274}, {-0.4394344943868578, 1.7355139912456736}, 
    {-0.43018106079382423, 1.75636834939373}, {-0.012814536647680836, \
2.220880340843797}}], 
  Line[{{-0.028845690582059706, 2.1953185530328274}, {-0.05478464252676645, \
2.153063306659971}, {-0.454406864453026, 1.7011229525643679}, 
    {-0.4394344943868578, 1.7355139912456736}, {-0.028845690582059706, \
2.1953185530328274}}], 
  Line[{{-0.05478464252676645, 2.153063306659971}, {-0.08949773581291603, \
2.0946793219544775}, {-0.4744438065750348, 1.653768235803274}, 
    {-0.454406864453026, 1.7011229525643679}, {-0.05478464252676645, \
2.153063306659971}}], 
  Line[{{-0.08949773581291603, 2.0946793219544775}, {-0.13146784169200165, \
2.0210434859217044}, {-0.4986696102342365, 1.594300566883078}, 
    {-0.4744438065750348, 1.653768235803274}, {-0.08949773581291603, \
2.0946793219544775}}], 
  Line[{{-0.13146784169200165, 2.0210434859217044}, {-0.17886066514219465, \
1.9334320944111922}, {-0.5260254915624207, 1.5239001577085336}, 
    {-0.4986696102342365, 1.594300566883078}, {-0.13146784169200165, \
2.0210434859217044}}], 
  Line[{{-0.17886066514219465, 1.9334320944111922}, {-0.22960491236272318, \
1.8336364565828103}, {-0.5553158672774631, 1.4441489417584887}, 
    {-0.5260254915624207, 1.5239001577085336}, {-0.17886066514219465, \
1.9334320944111922}}], 
  Line[{{-0.22960491236272318, 1.8336364565828103}, {-0.28148281625213667, \
1.7241122839361507}, {-0.5852606074097996, 1.357128851259246}, 
    {-0.5553158672774631, 1.4441489417584887}, {-0.22960491236272318, \
1.8336364565828103}}], 
  Line[{{-0.28148281625213667, 1.7241122839361507}, {-0.33222706347266534, \
1.6081701375219577}, {-0.6145509831248419, 1.2655525104241714}, 
    {-0.5852606074097996, 1.357128851259246}, {-0.28148281625213667, \
1.7241122839361507}}], 
  Line[{{-0.33222706347266534, 1.6081701375219577}, {-0.3796198869228583, \
1.49020971350424}, {-0.641906864453026, 1.1729281630054875}, 
    {-0.6145509831248419, 1.2655525104241714}, {-0.33222706347266534, \
1.6081701375219577}}], 
  Line[{{-0.3796198869228583, 1.49020971350424}, {-0.42158999280194376, \
1.3759750672106568}, {-0.6661326681122279, 1.0837396094369787}, 
    {-0.641906864453026, 1.1729281630054875}, {-0.3796198869228583, \
1.49020971350424}}], 
  Line[{{-0.42158999280194376, 1.3759750672106568}, {-0.4563030860880937, \
1.2727298803122153}, {-0.6861696102342367, 1.0035621274868158}, 
    {-0.6661326681122279, 1.0837396094369787}, {-0.42158999280194376, \
1.3759750672106568}}], 
  Line[{{-0.4563030860880937, 1.2727298803122153}, {-0.48224203803280025, \
1.1890852819516728}, {-0.701141980300405, 0.93891373977172}, 
    {-0.6861696102342367, 1.0035621274868158}, {-0.4563030860880937, \
1.2727298803122153}}], 
  Line[{{-0.48224203803280025, 1.1890852819516728}, {-0.49827319196717923, \
1.1340136417284865}, {-0.7103954138934385, 0.8965062230902952}, 
    {-0.701141980300405, 0.93891373977172}, {-0.48224203803280025, \
1.1890852819516728}}], 
  Line[{{-0.49827319196717923, 1.1340136417284865}, {-0.5036959095382867, \
1.1147172382160917}, {-0.713525491562421, 0.8816778784387099}, 
    {-0.7103954138934385, 0.8965062230902952}, {-0.49827319196717923, \
1.1340136417284865}}], 
  Line[{{-0.5036959095382867, 1.1147172382160917}, {-0.4982731919671794, \
1.134013641728486}, {-0.7103954138934385, 0.8965062230902949}, 
    {-0.713525491562421, 0.8816778784387099}, {-0.5036959095382867, \
1.1147172382160917}}], 
  Line[{{-0.4982731919671794, 1.134013641728486}, {-0.4822420380328006, \
1.189085281951672}, {-0.7011419803004052, 0.9389137397717192}, 
    {-0.7103954138934385, 0.8965062230902949}, {-0.4982731919671794, \
1.134013641728486}}], 
  Line[{{-0.4822420380328006, 1.189085281951672}, {-0.4563030860880938, \
1.2727298803122151}, {-0.6861696102342368, 1.0035621274868154}, 
    {-0.7011419803004052, 0.9389137397717192}, {-0.4822420380328006, \
1.189085281951672}}], 
  Line[{{-0.4563030860880938, 1.2727298803122151}, {-0.4215899928019442, \
1.3759750672106552}, {-0.6661326681122282, 1.0837396094369776}, 
    {-0.6861696102342368, 1.0035621274868154}, {-0.4563030860880938, \
1.2727298803122151}}], 
  Line[{{-0.4215899928019442, 1.3759750672106552}, {-0.3796198869228588, \
1.4902097135042387}, {-0.6419068644530264, 1.1729281630054864}, 
    {-0.6661326681122282, 1.0837396094369776}, {-0.4215899928019442, \
1.3759750672106552}}], 
  Line[{{-0.3796198869228588, 1.4902097135042387}, {-0.33222706347266556, \
1.6081701375219573}, {-0.614550983124842, 1.2655525104241707}, 
    {-0.6419068644530264, 1.1729281630054864}, {-0.3796198869228588, \
1.4902097135042387}}], 
  Line[{{-0.33222706347266556, 1.6081701375219573}, {-0.2814828162521371, \
1.7241122839361496}, {-0.5852606074097999, 1.3571288512592452}, 
    {-0.614550983124842, 1.2655525104241707}, {-0.33222706347266556, \
1.6081701375219573}}], 
  Line[{{-0.2814828162521371, 1.7241122839361496}, {-0.2296049123627239, \
1.833636456582809}, {-0.5553158672774634, 1.4441489417584878}, 
    {-0.5852606074097999, 1.3571288512592452}, {-0.2814828162521371, \
1.7241122839361496}}], 
  Line[{{-0.2296049123627239, 1.833636456582809}, {-0.17886066514219484, \
1.9334320944111918}, {-0.5260254915624208, 1.5239001577085334}, 
    {-0.5553158672774634, 1.4441489417584878}, {-0.2296049123627239, \
1.833636456582809}}], 
  Line[{{-0.17886066514219484, 1.9334320944111918}, {-0.13146784169200207, \
2.021043485921704}, {-0.49866961023423684, 1.5943005668830776}, 
    {-0.5260254915624208, 1.5239001577085334}, {-0.17886066514219484, \
1.9334320944111918}}], 
  Line[{{-0.13146784169200207, 2.021043485921704}, {-0.0894977358129165, \
2.0946793219544766}, {-0.4744438065750351, 1.6537682358032733}, 
    {-0.49866961023423684, 1.5943005668830776}, {-0.13146784169200207, \
2.021043485921704}}], 
  Line[{{-0.0894977358129165, 2.0946793219544766}, {-0.05478464252676649, \
2.153063306659971}, {-0.4544068644530261, 1.7011229525643676}, 
    {-0.4744438065750351, 1.6537682358032733}, {-0.0894977358129165, \
2.0946793219544766}}], 
  Line[{{-0.05478464252676649, 2.153063306659971}, {-0.02884569058205982, \
2.195318553032827}, {-0.4394344943868578, 1.7355139912456734}, 
    {-0.4544068644530261, 1.7011229525643676}, {-0.05478464252676649, \
2.153063306659971}}], 
  Line[{{-0.02884569058205982, 2.195318553032827}, {-0.01281453664768086, \
2.2208803408437965}, {-0.4301810607938243, 1.75636834939373}, 
    {-0.4394344943868578, 1.7355139912456734}, {-0.02884569058205982, \
2.195318553032827}}], 
  Line[{{-0.01281453664768086, 2.2208803408437965}, {-0.0073918190765734915, \
2.2294344764321834}, {-0.4270509831248419, 1.7633557568774199}, 
    {-0.4301810607938243, 1.75636834939373}, {-0.01281453664768086, \
2.2208803408437965}}], 
  Line[{{-0.4270509831248419, 1.7633557568774199}, {-0.43018106079382434, \
1.75636834939373}, {-0.7420533023112793, 1.2152748245287468}, 
    {-0.7406363729278018, 1.220209929227403}, {-0.4270509831248419, \
1.7633557568774199}}], 
  Line[{{-0.43018106079382434, 1.75636834939373}, {-0.4394344943868577, \
1.7355139912456736}, {-0.7462421638484722, 1.200556789468474}, 
    {-0.7420533023112793, 1.2152748245287468}, {-0.43018106079382434, \
1.75636834939373}}], 
  Line[{{-0.4394344943868577, 1.7355139912456736}, {-0.45440686445302614, \
1.7011229525643676}, {-0.7530198841898177, 1.1763209525760543}, 
    {-0.7462421638484722, 1.200556789468474}, {-0.4394344943868577, \
1.7355139912456736}}], 
  Line[{{-0.45440686445302614, 1.7011229525643676}, {-0.474443806575035, \
1.6537682358032737}, {-0.7620902444332882, 1.1430205016052861}, 
    {-0.7530198841898177, 1.1763209525760543}, {-0.45440686445302614, \
1.7011229525643676}}], 
  Line[{{-0.474443806575035, 1.6537682358032737}, {-0.4986696102342367, \
1.594300566883078}, {-0.7730568263118266, 1.1013148858947228}, 
    {-0.7620902444332882, 1.1430205016052861}, {-0.474443806575035, \
1.6537682358032737}}], 
  Line[{{-0.4986696102342367, 1.594300566883078}, {-0.5260254915624208, \
1.5239001577085334}, {-0.7854403375738425, 1.0520980143876315}, 
    {-0.7730568263118266, 1.1013148858947228}, {-0.4986696102342367, \
1.594300566883078}}], 
  Line[{{-0.5260254915624208, 1.5239001577085334}, {-0.5553158672774632, \
1.4441489417584887}, {-0.7986995593545059, 0.9965396214846565}, 
    {-0.7854403375738425, 1.0520980143876315}, {-0.5260254915624208, \
1.5239001577085334}}], 
  Line[{{-0.5553158672774632, 1.4441489417584887}, {-0.5852606074097998, \
1.3571288512592459}, {-0.8122550000371968, 0.9361441841071289}, 
    {-0.7986995593545059, 0.9965396214846565}, {-0.5553158672774632, \
1.4441489417584887}}], 
  Line[{{-0.5852606074097998, 1.3571288512592459}, {-0.614550983124842, \
1.2655525104241712}, {-0.8255142218178602, 0.8728320775698136}, 
    {-0.8122550000371968, 0.9361441841071289}, {-0.5852606074097998, \
1.3571288512592459}}], 
  Line[{{-0.614550983124842, 1.2655525104241712}, {-0.6419068644530261, \
1.1729281630054873}, {-0.8378977330798761, 0.8090441125945343}, 
    {-0.8255142218178602, 0.8728320775698136}, {-0.614550983124842, \
1.2655525104241712}}], 
  Line[{{-0.6419068644530261, 1.1729281630054873}, {-0.6661326681122279, \
1.0837396094369784}, {-0.8488643149584145, 0.7478557941640124}, 
    {-0.8378977330798761, 0.8090441125945343}, {-0.6419068644530261, \
1.1729281630054873}}], 
  Line[{{-0.6661326681122279, 1.0837396094369784}, {-0.6861696102342367, \
1.0035621274868158}, {-0.857934675201885, 0.6930472461935383}, 
    {-0.8488643149584145, 0.7478557941640124}, {-0.6661326681122279, \
1.0837396094369784}}], 
  Line[{{-0.6861696102342367, 1.0035621274868158}, {-0.701141980300405, \
0.9389137397717199}, {-0.8647123955432304, 0.6489952411032616}, 
    {-0.857934675201885, 0.6930472461935383}, {-0.6861696102342367, \
1.0035621274868158}}], 
  Line[{{-0.701141980300405, 0.9389137397717199}, {-0.7103954138934385, \
0.896506223090295}, {-0.8689012570804234, 0.6201700772082621}, 
    {-0.8647123955432304, 0.6489952411032616}, {-0.701141980300405, \
0.9389137397717199}}], 
  Line[{{-0.7103954138934385, 0.896506223090295}, {-0.713525491562421, \
0.8816778784387099}, {-0.8703181864639009, 0.6101049646137015}, 
    {-0.8689012570804234, 0.6201700772082621}, {-0.7103954138934385, \
0.896506223090295}}], 
  Line[{{-0.713525491562421, 0.8816778784387099}, {-0.7103954138934385, \
0.896506223090295}, {-0.8689012570804234, 0.6201700772082621}, 
    {-0.8703181864639009, 0.6101049646137015}, {-0.713525491562421, \
0.8816778784387099}}], 
  Line[{{-0.7103954138934385, 0.896506223090295}, {-0.7011419803004051, \
0.9389137397717195}, {-0.8647123955432304, 0.6489952411032616}, 
    {-0.8689012570804234, 0.6201700772082621}, {-0.7103954138934385, \
0.896506223090295}}], 
  Line[{{-0.7011419803004051, 0.9389137397717195}, {-0.6861696102342368, \
1.0035621274868156}, {-0.857934675201885, 0.6930472461935381}, 
    {-0.8647123955432304, 0.6489952411032616}, {-0.7011419803004051, \
0.9389137397717195}}], 
  Line[{{-0.6861696102342368, 1.0035621274868156}, {-0.6661326681122279, \
1.0837396094369782}, {-0.8488643149584145, 0.7478557941640123}, 
    {-0.857934675201885, 0.6930472461935381}, {-0.6861696102342368, \
1.0035621274868156}}], 
  Line[{{-0.6661326681122279, 1.0837396094369782}, {-0.6419068644530262, \
1.1729281630054869}, {-0.8378977330798763, 0.809044112594534}, 
    {-0.8488643149584145, 0.7478557941640123}, {-0.6661326681122279, \
1.0837396094369782}}], 
  Line[{{-0.6419068644530262, 1.1729281630054869}, {-0.614550983124842, \
1.265552510424171}, {-0.8255142218178603, 0.8728320775698134}, 
    {-0.8378977330798763, 0.809044112594534}, {-0.6419068644530262, \
1.1729281630054869}}], 
  Line[{{-0.614550983124842, 1.265552510424171}, {-0.5852606074097999, \
1.3571288512592452}, {-0.8122550000371969, 0.9361441841071285}, 
    {-0.8255142218178603, 0.8728320775698134}, {-0.614550983124842, \
1.265552510424171}}], 
  Line[{{-0.5852606074097999, 1.3571288512592452}, {-0.5553158672774632, \
1.4441489417584883}, {-0.798699559354506, 0.9965396214846562}, 
    {-0.8122550000371969, 0.9361441841071285}, {-0.5852606074097999, \
1.3571288512592452}}], 
  Line[{{-0.5553158672774632, 1.4441489417584883}, {-0.5260254915624208, \
1.5239001577085334}, {-0.7854403375738425, 1.0520980143876313}, 
    {-0.798699559354506, 0.9965396214846562}, {-0.5553158672774632, \
1.4441489417584883}}], 
  Line[{{-0.5260254915624208, 1.5239001577085334}, {-0.4986696102342367, \
1.5943005668830776}, {-0.7730568263118266, 1.1013148858947226}, 
    {-0.7854403375738425, 1.0520980143876313}, {-0.5260254915624208, \
1.5239001577085334}}], 
  Line[{{-0.4986696102342367, 1.5943005668830776}, {-0.47444380657503493, \
1.6537682358032735}, {-0.7620902444332882, 1.143020501605286}, 
    {-0.7730568263118266, 1.1013148858947226}, {-0.4986696102342367, \
1.5943005668830776}}], 
  Line[{{-0.47444380657503493, 1.6537682358032735}, {-0.4544068644530261, \
1.7011229525643676}, {-0.7530198841898177, 1.1763209525760543}, 
    {-0.7620902444332882, 1.143020501605286}, {-0.47444380657503493, \
1.6537682358032735}}], 
  Line[{{-0.4544068644530261, 1.7011229525643676}, {-0.43943449438685783, \
1.7355139912456734}, {-0.7462421638484723, 1.200556789468474}, 
    {-0.7530198841898177, 1.1763209525760543}, {-0.4544068644530261, \
1.7011229525643676}}], 
  Line[{{-0.43943449438685783, 1.7355139912456734}, {-0.43018106079382434, \
1.75636834939373}, {-0.7420533023112793, 1.2152748245287468}, 
    {-0.7462421638484723, 1.200556789468474}, {-0.43943449438685783, \
1.7355139912456734}}], 
  Line[{{-0.43018106079382434, 1.75636834939373}, {-0.4270509831248419, \
1.7633557568774199}, {-0.7406363729278018, 1.220209929227403}, 
    {-0.7420533023112793, 1.2152748245287468}, {-0.43018106079382434, \
1.75636834939373}}], 
  Line[{{-0.4270509831248419, 1.7633557568774199}, {-0.43018106079382423, \
1.75636834939373}, {-0.7420533023112793, 1.2152748245287468}, 
    {-0.7406363729278018, 1.220209929227403}, {-0.4270509831248419, \
1.7633557568774199}}], 
  Line[{{-0.43018106079382423, 1.75636834939373}, {-0.4394344943868578, \
1.7355139912456736}, {-0.7462421638484722, 1.200556789468474}, 
    {-0.7420533023112793, 1.2152748245287468}, {-0.43018106079382423, \
1.75636834939373}}], 
  Line[{{-0.4394344943868578, 1.7355139912456736}, {-0.454406864453026, \
1.7011229525643679}, {-0.7530198841898177, 1.1763209525760543}, 
    {-0.7462421638484722, 1.200556789468474}, {-0.4394344943868578, \
1.7355139912456736}}], 
  Line[{{-0.454406864453026, 1.7011229525643679}, {-0.4744438065750348, \
1.653768235803274}, {-0.7620902444332881, 1.1430205016052863}, 
    {-0.7530198841898177, 1.1763209525760543}, {-0.454406864453026, \
1.7011229525643679}}], 
  Line[{{-0.4744438065750348, 1.653768235803274}, {-0.4986696102342365, \
1.594300566883078}, {-0.7730568263118266, 1.1013148858947228}, 
    {-0.7620902444332881, 1.1430205016052863}, {-0.4744438065750348, \
1.653768235803274}}], 
  Line[{{-0.4986696102342365, 1.594300566883078}, {-0.5260254915624207, \
1.5239001577085336}, {-0.7854403375738425, 1.0520980143876315}, 
    {-0.7730568263118266, 1.1013148858947228}, {-0.4986696102342365, \
1.594300566883078}}], 
  Line[{{-0.5260254915624207, 1.5239001577085336}, {-0.5553158672774631, \
1.4441489417584887}, {-0.7986995593545059, 0.9965396214846567}, 
    {-0.7854403375738425, 1.0520980143876315}, {-0.5260254915624207, \
1.5239001577085336}}], 
  Line[{{-0.5553158672774631, 1.4441489417584887}, {-0.5852606074097996, \
1.357128851259246}, {-0.8122550000371966, 0.9361441841071292}, 
    {-0.7986995593545059, 0.9965396214846567}, {-0.5553158672774631, \
1.4441489417584887}}], 
  Line[{{-0.5852606074097996, 1.357128851259246}, {-0.6145509831248419, \
1.2655525104241714}, {-0.8255142218178602, 0.8728320775698137}, 
    {-0.8122550000371966, 0.9361441841071292}, {-0.5852606074097996, \
1.357128851259246}}], 
  Line[{{-0.6145509831248419, 1.2655525104241714}, {-0.641906864453026, \
1.1729281630054875}, {-0.837897733079876, 0.8090441125945347}, 
    {-0.8255142218178602, 0.8728320775698137}, {-0.6145509831248419, \
1.2655525104241714}}], 
  Line[{{-0.641906864453026, 1.1729281630054875}, {-0.6661326681122279, \
1.0837396094369787}, {-0.8488643149584145, 0.7478557941640125}, 
    {-0.837897733079876, 0.8090441125945347}, {-0.641906864453026, \
1.1729281630054875}}], 
  Line[{{-0.6661326681122279, 1.0837396094369787}, {-0.6861696102342367, \
1.0035621274868158}, {-0.857934675201885, 0.6930472461935383}, 
    {-0.8488643149584145, 0.7478557941640125}, {-0.6661326681122279, \
1.0837396094369787}}], 
  Line[{{-0.6861696102342367, 1.0035621274868158}, {-0.701141980300405, \
0.93891373977172}, {-0.8647123955432304, 0.6489952411032617}, 
    {-0.857934675201885, 0.6930472461935383}, {-0.6861696102342367, \
1.0035621274868158}}], 
  Line[{{-0.701141980300405, 0.93891373977172}, {-0.7103954138934385, \
0.8965062230902952}, {-0.8689012570804234, 0.6201700772082622}, 
    {-0.8647123955432304, 0.6489952411032617}, {-0.701141980300405, \
0.93891373977172}}], 
  Line[{{-0.7103954138934385, 0.8965062230902952}, {-0.713525491562421, \
0.8816778784387099}, {-0.8703181864639009, 0.6101049646137015}, 
    {-0.8689012570804234, 0.6201700772082622}, {-0.7103954138934385, \
0.8965062230902952}}], 
  Line[{{-0.713525491562421, 0.8816778784387099}, {-0.7103954138934385, \
0.8965062230902949}, {-0.8689012570804235, 0.6201700772082617}, 
    {-0.8703181864639009, 0.6101049646137015}, {-0.713525491562421, \
0.8816778784387099}}], 
  Line[{{-0.7103954138934385, 0.8965062230902949}, {-0.7011419803004052, \
0.9389137397717192}, {-0.8647123955432305, 0.6489952411032612}, 
    {-0.8689012570804235, 0.6201700772082617}, {-0.7103954138934385, \
0.8965062230902949}}], 
  Line[{{-0.7011419803004052, 0.9389137397717192}, {-0.6861696102342368, \
1.0035621274868154}, {-0.857934675201885, 0.6930472461935381}, 
    {-0.8647123955432305, 0.6489952411032612}, {-0.7011419803004052, \
0.9389137397717192}}], 
  Line[{{-0.6861696102342368, 1.0035621274868154}, {-0.6661326681122282, \
1.0837396094369776}, {-0.8488643149584146, 0.7478557941640119}, 
    {-0.857934675201885, 0.6930472461935381}, {-0.6861696102342368, \
1.0035621274868154}}], 
  Line[{{-0.6661326681122282, 1.0837396094369776}, {-0.6419068644530264, \
1.1729281630054864}, {-0.8378977330798763, 0.8090441125945338}, 
    {-0.8488643149584146, 0.7478557941640119}, {-0.6661326681122282, \
1.0837396094369776}}], 
  Line[{{-0.6419068644530264, 1.1729281630054864}, {-0.614550983124842, \
1.2655525104241707}, {-0.8255142218178603, 0.8728320775698134}, 
    {-0.8378977330798763, 0.8090441125945338}, {-0.6419068644530264, \
1.1729281630054864}}], 
  Line[{{-0.614550983124842, 1.2655525104241707}, {-0.5852606074097999, \
1.3571288512592452}, {-0.8122550000371969, 0.9361441841071284}, 
    {-0.8255142218178603, 0.8728320775698134}, {-0.614550983124842, \
1.2655525104241707}}], 
  Line[{{-0.5852606074097999, 1.3571288512592452}, {-0.5553158672774634, \
1.4441489417584878}, {-0.798699559354506, 0.996539621484656}, 
    {-0.8122550000371969, 0.9361441841071284}, {-0.5852606074097999, \
1.3571288512592452}}], 
  Line[{{-0.5553158672774634, 1.4441489417584878}, {-0.5260254915624208, \
1.5239001577085334}, {-0.7854403375738425, 1.0520980143876313}, 
    {-0.798699559354506, 0.996539621484656}, {-0.5553158672774634, \
1.4441489417584878}}], 
  Line[{{-0.5260254915624208, 1.5239001577085334}, {-0.49866961023423684, \
1.5943005668830776}, {-0.7730568263118266, 1.1013148858947226}, 
    {-0.7854403375738425, 1.0520980143876313}, {-0.5260254915624208, \
1.5239001577085334}}], 
  Line[{{-0.49866961023423684, 1.5943005668830776}, {-0.4744438065750351, \
1.6537682358032733}, {-0.7620902444332882, 1.143020501605286}, 
    {-0.7730568263118266, 1.1013148858947226}, {-0.49866961023423684, \
1.5943005668830776}}], 
  Line[{{-0.4744438065750351, 1.6537682358032733}, {-0.4544068644530261, \
1.7011229525643676}, {-0.7530198841898177, 1.1763209525760543}, 
    {-0.7620902444332882, 1.143020501605286}, {-0.4744438065750351, \
1.6537682358032733}}], 
  Line[{{-0.4544068644530261, 1.7011229525643676}, {-0.4394344943868578, \
1.7355139912456734}, {-0.7462421638484723, 1.200556789468474}, 
    {-0.7530198841898177, 1.1763209525760543}, {-0.4544068644530261, \
1.7011229525643676}}], 
  Line[{{-0.4394344943868578, 1.7355139912456734}, {-0.4301810607938243, \
1.75636834939373}, {-0.7420533023112792, 1.2152748245287468}, 
    {-0.7462421638484723, 1.200556789468474}, {-0.4394344943868578, \
1.7355139912456734}}], 
  Line[{{-0.4301810607938243, 1.75636834939373}, {-0.4270509831248419, \
1.7633557568774199}, {-0.7406363729278018, 1.220209929227403}, 
    {-0.7420533023112792, 1.2152748245287468}, {-0.4301810607938243, \
1.75636834939373}}], 
  Line[{{-0.7406363729278018, 1.220209929227403}, {-0.7420533023112793, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
    {-0.9344428022014165, 0.6237350724532796}, {-0.7406363729278018, \
1.220209929227403}}], 
  Line[{{-0.7420533023112793, 1.2152748245287468}, {-0.7462421638484722, \
1.200556789468474}, {-0.9358597315848941, 0.6135770923916904}, 
    {-0.9348009477166834, 0.6211835161491779}, {-0.7420533023112793, \
1.2152748245287468}}], 
  Line[{{-0.7462421638484722, 1.200556789468474}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
    {-0.9358597315848941, 0.6135770923916904}, {-0.7462421638484722, \
1.200556789468474}}], 
  Line[{{-0.7530198841898177, 1.1763209525760543}, {-0.7620902444332882, \
1.1430205016052861}, {-0.9398655197725241, 0.5838857533279131}, 
    {-0.937572879870399, 0.6010618457721164}, {-0.7530198841898177, \
1.1763209525760543}}], 
  Line[{{-0.7620902444332882, 1.1430205016052861}, {-0.7730568263118266, \
1.1013148858947228}, {-0.9426374519262395, 0.5624063276196131}, 
    {-0.9398655197725241, 0.5838857533279131}, {-0.7620902444332882, \
1.1430205016052861}}], 
  Line[{{-0.7730568263118266, 1.1013148858947228}, {-0.7854403375738425, \
1.0520980143876315}, {-0.9457675295952219, 0.5371028573756125}, 
    {-0.9426374519262395, 0.5624063276196131}, {-0.7730568263118266, \
1.1013148858947228}}], 
  Line[{{-0.7854403375738425, 1.0520980143876315}, {-0.7986995593545059, \
0.9965396214846565}, {-0.9491189533655575, 0.5085950701762803}, 
    {-0.9457675295952219, 0.5371028573756125}, {-0.7854403375738425, \
1.0520980143876315}}], 
  Line[{{-0.7986995593545059, 0.9965396214846565}, {-0.8122550000371968, \
0.9361441841071289}, {-0.9525452499365673, 0.47767060184981125}, 
    {-0.9491189533655575, 0.5085950701762803}, {-0.7986995593545059, \
0.9965396214846565}}], 
  Line[{{-0.8122550000371968, 0.9361441841071289}, {-0.8255142218178602, \
0.8728320775698136}, {-0.955896673706903, 0.44532374723565715}, 
    {-0.9525452499365673, 0.47767060184981125}, {-0.8122550000371968, \
0.9361441841071289}}], 
  Line[{{-0.8255142218178602, 0.8728320775698136}, {-0.8378977330798761, \
0.8090441125945343}, {-0.9590267513758853, 0.41280605266694914}, 
    {-0.955896673706903, 0.44532374723565715}, {-0.8255142218178602, \
0.8728320775698136}}], 
  Line[{{-0.8378977330798761, 0.8090441125945343}, {-0.8488643149584145, \
0.7478557941640124}, {-0.9617986835296009, 0.3816816923272197}, 
    {-0.9590267513758853, 0.41280605266694914}, {-0.8378977330798761, \
0.8090441125945343}}], 
  Line[{{-0.8488643149584145, 0.7478557941640124}, {-0.857934675201885, \
0.6930472461935383}, {-0.9640913234317259, 0.3538602304100192}, 
    {-0.9617986835296009, 0.3816816923272197}, {-0.8488643149584145, \
0.7478557941640124}}], 
  Line[{{-0.857934675201885, 0.6930472461935383}, {-0.8647123955432304, \
0.6489952411032616}, {-0.9658044717172307, 0.33154008354139486}, 
    {-0.9640913234317259, 0.3538602304100192}, {-0.857934675201885, \
0.6930472461935383}}], 
  Line[{{-0.8647123955432304, 0.6489952411032616}, {-0.8689012570804234, \
0.6201700772082621}, {-0.9668632555854414, 0.31695593148714096}, 
    {-0.9658044717172307, 0.33154008354139486}, {-0.8647123955432304, \
0.6489952411032616}}], 
  Line[{{-0.8689012570804234, 0.6201700772082621}, {-0.8703181864639009, \
0.6101049646137015}, {-0.9672214011007083, 0.3118675362266397}, 
    {-0.9668632555854414, 0.31695593148714096}, {-0.8689012570804234, \
0.6201700772082621}}], 
  Line[{{-0.8703181864639009, 0.6101049646137015}, {-0.8689012570804234, \
0.6201700772082621}, {-0.9668632555854414, 0.31695593148714096}, 
    {-0.9672214011007083, 0.3118675362266397}, {-0.8703181864639009, \
0.6101049646137015}}], 
  Line[{{-0.8689012570804234, 0.6201700772082621}, {-0.8647123955432304, \
0.6489952411032616}, {-0.9658044717172307, 0.33154008354139486}, 
    {-0.9668632555854414, 0.31695593148714096}, {-0.8689012570804234, \
0.6201700772082621}}], 
  Line[{{-0.8647123955432304, 0.6489952411032616}, {-0.857934675201885, \
0.6930472461935381}, {-0.9640913234317259, 0.3538602304100192}, 
    {-0.9658044717172307, 0.33154008354139486}, {-0.8647123955432304, \
0.6489952411032616}}], 
  Line[{{-0.857934675201885, 0.6930472461935381}, {-0.8488643149584145, \
0.7478557941640123}, {-0.9617986835296009, 0.3816816923272197}, 
    {-0.9640913234317259, 0.3538602304100192}, {-0.857934675201885, \
0.6930472461935381}}], 
  Line[{{-0.8488643149584145, 0.7478557941640123}, {-0.8378977330798763, \
0.809044112594534}, {-0.9590267513758853, 0.41280605266694914}, 
    {-0.9617986835296009, 0.3816816923272197}, {-0.8488643149584145, \
0.7478557941640123}}], 
  Line[{{-0.8378977330798763, 0.809044112594534}, {-0.8255142218178603, \
0.8728320775698134}, {-0.955896673706903, 0.44532374723565715}, 
    {-0.9590267513758853, 0.41280605266694914}, {-0.8378977330798763, \
0.809044112594534}}], 
  Line[{{-0.8255142218178603, 0.8728320775698134}, {-0.8122550000371969, \
0.9361441841071285}, {-0.9525452499365673, 0.47767060184981125}, 
    {-0.955896673706903, 0.44532374723565715}, {-0.8255142218178603, \
0.8728320775698134}}], 
  Line[{{-0.8122550000371969, 0.9361441841071285}, {-0.798699559354506, \
0.9965396214846562}, {-0.9491189533655575, 0.5085950701762803}, 
    {-0.9525452499365673, 0.47767060184981125}, {-0.8122550000371969, \
0.9361441841071285}}], 
  Line[{{-0.798699559354506, 0.9965396214846562}, {-0.7854403375738425, \
1.0520980143876313}, {-0.9457675295952219, 0.5371028573756125}, 
    {-0.9491189533655575, 0.5085950701762803}, {-0.798699559354506, \
0.9965396214846562}}], 
  Line[{{-0.7854403375738425, 1.0520980143876313}, {-0.7730568263118266, \
1.1013148858947226}, {-0.9426374519262395, 0.5624063276196131}, 
    {-0.9457675295952219, 0.5371028573756125}, {-0.7854403375738425, \
1.0520980143876313}}], 
  Line[{{-0.7730568263118266, 1.1013148858947226}, {-0.7620902444332882, \
1.143020501605286}, {-0.9398655197725241, 0.5838857533279131}, 
    {-0.9426374519262395, 0.5624063276196131}, {-0.7730568263118266, \
1.1013148858947226}}], 
  Line[{{-0.7620902444332882, 1.143020501605286}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
    {-0.9398655197725241, 0.5838857533279131}, {-0.7620902444332882, \
1.143020501605286}}], 
  Line[{{-0.7530198841898177, 1.1763209525760543}, {-0.7462421638484723, \
1.200556789468474}, {-0.9358597315848941, 0.6135770923916904}, 
    {-0.937572879870399, 0.6010618457721164}, {-0.7530198841898177, \
1.1763209525760543}}], 
  Line[{{-0.7462421638484723, 1.200556789468474}, {-0.7420533023112793, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
    {-0.9358597315848941, 0.6135770923916904}, {-0.7462421638484723, \
1.200556789468474}}], 
  Line[{{-0.7420533023112793, 1.2152748245287468}, {-0.7406363729278018, \
1.220209929227403}, {-0.9344428022014165, 0.6237350724532796}, 
    {-0.9348009477166834, 0.6211835161491779}, {-0.7420533023112793, \
1.2152748245287468}}], 
  Line[{{-0.7406363729278018, 1.220209929227403}, {-0.7420533023112793, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
    {-0.9344428022014165, 0.6237350724532796}, {-0.7406363729278018, \
1.220209929227403}}], 
  Line[{{-0.7420533023112793, 1.2152748245287468}, {-0.7462421638484722, \
1.200556789468474}, {-0.9358597315848941, 0.6135770923916904}, 
    {-0.9348009477166834, 0.6211835161491779}, {-0.7420533023112793, \
1.2152748245287468}}], 
  Line[{{-0.7462421638484722, 1.200556789468474}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
    {-0.9358597315848941, 0.6135770923916904}, {-0.7462421638484722, \
1.200556789468474}}], 
  Line[{{-0.7530198841898177, 1.1763209525760543}, {-0.7620902444332881, \
1.1430205016052863}, {-0.939865519772524, 0.5838857533279135}, 
    {-0.937572879870399, 0.6010618457721164}, {-0.7530198841898177, \
1.1763209525760543}}], 
  Line[{{-0.7620902444332881, 1.1430205016052863}, {-0.7730568263118266, \
1.1013148858947228}, {-0.9426374519262395, 0.5624063276196133}, 
    {-0.939865519772524, 0.5838857533279135}, {-0.7620902444332881, \
1.1430205016052863}}], 
  Line[{{-0.7730568263118266, 1.1013148858947228}, {-0.7854403375738425, \
1.0520980143876315}, {-0.9457675295952218, 0.5371028573756126}, 
    {-0.9426374519262395, 0.5624063276196133}, {-0.7730568263118266, \
1.1013148858947228}}], 
  Line[{{-0.7854403375738425, 1.0520980143876315}, {-0.7986995593545059, \
0.9965396214846567}, {-0.9491189533655575, 0.5085950701762803}, 
    {-0.9457675295952218, 0.5371028573756126}, {-0.7854403375738425, \
1.0520980143876315}}], 
  Line[{{-0.7986995593545059, 0.9965396214846567}, {-0.8122550000371966, \
0.9361441841071292}, {-0.9525452499365673, 0.4776706018498115}, 
    {-0.9491189533655575, 0.5085950701762803}, {-0.7986995593545059, \
0.9965396214846567}}], 
  Line[{{-0.8122550000371966, 0.9361441841071292}, {-0.8255142218178602, \
0.8728320775698137}, {-0.955896673706903, 0.44532374723565715}, 
    {-0.9525452499365673, 0.4776706018498115}, {-0.8122550000371966, \
0.9361441841071292}}], 
  Line[{{-0.8255142218178602, 0.8728320775698137}, {-0.837897733079876, \
0.8090441125945347}, {-0.9590267513758853, 0.41280605266694914}, 
    {-0.955896673706903, 0.44532374723565715}, {-0.8255142218178602, \
0.8728320775698137}}], 
  Line[{{-0.837897733079876, 0.8090441125945347}, {-0.8488643149584145, \
0.7478557941640125}, {-0.9617986835296009, 0.3816816923272197}, 
    {-0.9590267513758853, 0.41280605266694914}, {-0.837897733079876, \
0.8090441125945347}}], 
  Line[{{-0.8488643149584145, 0.7478557941640125}, {-0.857934675201885, \
0.6930472461935383}, {-0.9640913234317259, 0.3538602304100192}, 
    {-0.9617986835296009, 0.3816816923272197}, {-0.8488643149584145, \
0.7478557941640125}}], 
  Line[{{-0.857934675201885, 0.6930472461935383}, {-0.8647123955432304, \
0.6489952411032617}, {-0.9658044717172307, 0.33154008354139486}, 
    {-0.9640913234317259, 0.3538602304100192}, {-0.857934675201885, \
0.6930472461935383}}], 
  Line[{{-0.8647123955432304, 0.6489952411032617}, {-0.8689012570804234, \
0.6201700772082622}, {-0.9668632555854413, 0.31695593148714163}, 
    {-0.9658044717172307, 0.33154008354139486}, {-0.8647123955432304, \
0.6489952411032617}}], 
  Line[{{-0.8689012570804234, 0.6201700772082622}, {-0.8703181864639009, \
0.6101049646137015}, {-0.9672214011007083, 0.3118675362266397}, 
    {-0.9668632555854413, 0.31695593148714163}, {-0.8689012570804234, \
0.6201700772082622}}], 
  Line[{{-0.8703181864639009, 0.6101049646137015}, {-0.8689012570804235, \
0.6201700772082617}, {-0.9668632555854414, 0.31695593148714096}, 
    {-0.9672214011007083, 0.3118675362266397}, {-0.8703181864639009, \
0.6101049646137015}}], 
  Line[{{-0.8689012570804235, 0.6201700772082617}, {-0.8647123955432305, \
0.6489952411032612}, {-0.9658044717172307, 0.33154008354139486}, 
    {-0.9668632555854414, 0.31695593148714096}, {-0.8689012570804235, \
0.6201700772082617}}], 
  Line[{{-0.8647123955432305, 0.6489952411032612}, {-0.857934675201885, \
0.6930472461935381}, {-0.9640913234317259, 0.3538602304100192}, 
    {-0.9658044717172307, 0.33154008354139486}, {-0.8647123955432305, \
0.6489952411032612}}], 
  Line[{{-0.857934675201885, 0.6930472461935381}, {-0.8488643149584146, \
0.7478557941640119}, {-0.9617986835296009, 0.38168169232721944}, 
    {-0.9640913234317259, 0.3538602304100192}, {-0.857934675201885, \
0.6930472461935381}}], 
  Line[{{-0.8488643149584146, 0.7478557941640119}, {-0.8378977330798763, \
0.8090441125945338}, {-0.9590267513758853, 0.41280605266694886}, 
    {-0.9617986835296009, 0.38168169232721944}, {-0.8488643149584146, \
0.7478557941640119}}], 
  Line[{{-0.8378977330798763, 0.8090441125945338}, {-0.8255142218178603, \
0.8728320775698134}, {-0.955896673706903, 0.44532374723565715}, 
    {-0.9590267513758853, 0.41280605266694886}, {-0.8378977330798763, \
0.8090441125945338}}], 
  Line[{{-0.8255142218178603, 0.8728320775698134}, {-0.8122550000371969, \
0.9361441841071284}, {-0.9525452499365673, 0.47767060184981125}, 
    {-0.955896673706903, 0.44532374723565715}, {-0.8255142218178603, \
0.8728320775698134}}], 
  Line[{{-0.8122550000371969, 0.9361441841071284}, {-0.798699559354506, \
0.996539621484656}, {-0.9491189533655575, 0.50859507017628}, 
    {-0.9525452499365673, 0.47767060184981125}, {-0.8122550000371969, \
0.9361441841071284}}], 
  Line[{{-0.798699559354506, 0.996539621484656}, {-0.7854403375738425, \
1.0520980143876313}, {-0.9457675295952219, 0.5371028573756125}, 
    {-0.9491189533655575, 0.50859507017628}, {-0.798699559354506, \
0.996539621484656}}], 
  Line[{{-0.7854403375738425, 1.0520980143876313}, {-0.7730568263118266, \
1.1013148858947226}, {-0.9426374519262395, 0.5624063276196131}, 
    {-0.9457675295952219, 0.5371028573756125}, {-0.7854403375738425, \
1.0520980143876313}}], 
  Line[{{-0.7730568263118266, 1.1013148858947226}, {-0.7620902444332882, \
1.143020501605286}, {-0.939865519772524, 0.5838857533279135}, 
    {-0.9426374519262395, 0.5624063276196131}, {-0.7730568263118266, \
1.1013148858947226}}], 
  Line[{{-0.7620902444332882, 1.143020501605286}, {-0.7530198841898177, \
1.1763209525760543}, {-0.937572879870399, 0.6010618457721164}, 
    {-0.939865519772524, 0.5838857533279135}, {-0.7620902444332882, \
1.143020501605286}}], 
  Line[{{-0.7530198841898177, 1.1763209525760543}, {-0.7462421638484723, \
1.200556789468474}, {-0.935859731584894, 0.6135770923916908}, 
    {-0.937572879870399, 0.6010618457721164}, {-0.7530198841898177, \
1.1763209525760543}}], 
  Line[{{-0.7462421638484723, 1.200556789468474}, {-0.7420533023112792, \
1.2152748245287468}, {-0.9348009477166834, 0.6211835161491779}, 
    {-0.935859731584894, 0.6135770923916908}, {-0.7462421638484723, \
1.200556789468474}}], 
  Line[{{-0.7420533023112792, 1.2152748245287468}, {-0.7406363729278018, \
1.220209929227403}, {-0.9344428022014165, 0.6237350724532796}, 
    {-0.9348009477166834, 0.6211835161491779}, {-0.7420533023112792, \
1.2152748245287468}}], 
  Line[{{-0.9344428022014165, 0.6237350724532796}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}, 
    {-0.9344428022014165, 0.6237350724532796}}], Line[{{-0.9348009477166834, \
0.6211835161491779}, {-0.9358597315848941, 0.6135770923916904}, 
    {-1., 0.}, {-1., 0.}, {-0.9348009477166834, 0.6211835161491779}}], 
  Line[{{-0.9358597315848941, 0.6135770923916904}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}, 
    {-0.9358597315848941, 0.6135770923916904}}], Line[{{-0.937572879870399, \
0.6010618457721164}, {-0.9398655197725241, 0.5838857533279131}, 
    {-1., 0.}, {-1., 0.}, {-0.937572879870399, 0.6010618457721164}}], 
  Line[{{-0.9398655197725241, 0.5838857533279131}, {-0.9426374519262395, \
0.5624063276196131}, {-1., 0.}, {-1., 0.}, 
    {-0.9398655197725241, 0.5838857533279131}}], Line[{{-0.9426374519262395, \
0.5624063276196131}, {-0.9457675295952219, 0.5371028573756125}, 
    {-1., 0.}, {-1., 0.}, {-0.9426374519262395, 0.5624063276196131}}], 
  Line[{{-0.9457675295952219, 0.5371028573756125}, {-0.9491189533655575, \
0.5085950701762803}, {-1., 0.}, {-1., 0.}, 
    {-0.9457675295952219, 0.5371028573756125}}], Line[{{-0.9491189533655575, \
0.5085950701762803}, {-0.9525452499365673, 0.47767060184981125}, 
    {-1., 0.}, {-1., 0.}, {-0.9491189533655575, 0.5085950701762803}}], 
  Line[{{-0.9525452499365673, 0.47767060184981125}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}, 
    {-0.9525452499365673, 0.47767060184981125}}], Line[{{-0.955896673706903, \
0.44532374723565715}, {-0.9590267513758853, 0.41280605266694914}, 
    {-1., 0.}, {-1., 0.}, {-0.955896673706903, 0.44532374723565715}}], 
  Line[{{-0.9590267513758853, 0.41280605266694914}, {-0.9617986835296009, \
0.3816816923272197}, {-1., 0.}, {-1., 0.}, 
    {-0.9590267513758853, 0.41280605266694914}}], Line[{{-0.9617986835296009, \
0.3816816923272197}, {-0.9640913234317259, 0.3538602304100192}, 
    {-1., 0.}, {-1., 0.}, {-0.9617986835296009, 0.3816816923272197}}], 
  Line[{{-0.9640913234317259, 0.3538602304100192}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}, 
    {-0.9640913234317259, 0.3538602304100192}}], Line[{{-0.9658044717172307, \
0.33154008354139486}, {-0.9668632555854414, 0.31695593148714096}, 
    {-1., 0.}, {-1., 0.}, {-0.9658044717172307, 0.33154008354139486}}], 
  Line[{{-0.9668632555854414, 0.31695593148714096}, {-0.9672214011007083, \
0.3118675362266397}, {-1., 0.}, {-1., 0.}, 
    {-0.9668632555854414, 0.31695593148714096}}], Line[{{-0.9672214011007083, \
0.3118675362266397}, {-0.9668632555854414, 0.31695593148714096}, 
    {-1., 0.}, {-1., 0.}, {-0.9672214011007083, 0.3118675362266397}}], 
  Line[{{-0.9668632555854414, 0.31695593148714096}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}, 
    {-0.9668632555854414, 0.31695593148714096}}], Line[{{-0.9658044717172307, \
0.33154008354139486}, {-0.9640913234317259, 0.3538602304100192}, 
    {-1., 0.}, {-1., 0.}, {-0.9658044717172307, 0.33154008354139486}}], 
  Line[{{-0.9640913234317259, 0.3538602304100192}, {-0.9617986835296009, \
0.3816816923272197}, {-1., 0.}, {-1., 0.}, 
    {-0.9640913234317259, 0.3538602304100192}}], Line[{{-0.9617986835296009, \
0.3816816923272197}, {-0.9590267513758853, 0.41280605266694914}, 
    {-1., 0.}, {-1., 0.}, {-0.9617986835296009, 0.3816816923272197}}], 
  Line[{{-0.9590267513758853, 0.41280605266694914}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}, 
    {-0.9590267513758853, 0.41280605266694914}}], Line[{{-0.955896673706903, \
0.44532374723565715}, {-0.9525452499365673, 0.47767060184981125}, 
    {-1., 0.}, {-1., 0.}, {-0.955896673706903, 0.44532374723565715}}], 
  Line[{{-0.9525452499365673, 0.47767060184981125}, {-0.9491189533655575, \
0.5085950701762803}, {-1., 0.}, {-1., 0.}, 
    {-0.9525452499365673, 0.47767060184981125}}], Line[{{-0.9491189533655575, \
0.5085950701762803}, {-0.9457675295952219, 0.5371028573756125}, 
    {-1., 0.}, {-1., 0.}, {-0.9491189533655575, 0.5085950701762803}}], 
  Line[{{-0.9457675295952219, 0.5371028573756125}, {-0.9426374519262395, \
0.5624063276196131}, {-1., 0.}, {-1., 0.}, 
    {-0.9457675295952219, 0.5371028573756125}}], Line[{{-0.9426374519262395, \
0.5624063276196131}, {-0.9398655197725241, 0.5838857533279131}, 
    {-1., 0.}, {-1., 0.}, {-0.9426374519262395, 0.5624063276196131}}], 
  Line[{{-0.9398655197725241, 0.5838857533279131}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}, 
    {-0.9398655197725241, 0.5838857533279131}}], Line[{{-0.937572879870399, \
0.6010618457721164}, {-0.9358597315848941, 0.6135770923916904}, 
    {-1., 0.}, {-1., 0.}, {-0.937572879870399, 0.6010618457721164}}], 
  Line[{{-0.9358597315848941, 0.6135770923916904}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}, 
    {-0.9358597315848941, 0.6135770923916904}}], Line[{{-0.9348009477166834, \
0.6211835161491779}, {-0.9344428022014165, 0.6237350724532796}, 
    {-1., 0.}, {-1., 0.}, {-0.9348009477166834, 0.6211835161491779}}], 
  Line[{{-0.9344428022014165, 0.6237350724532796}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}, 
    {-0.9344428022014165, 0.6237350724532796}}], Line[{{-0.9348009477166834, \
0.6211835161491779}, {-0.9358597315848941, 0.6135770923916904}, 
    {-1., 0.}, {-1., 0.}, {-0.9348009477166834, 0.6211835161491779}}], 
  Line[{{-0.9358597315848941, 0.6135770923916904}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}, 
    {-0.9358597315848941, 0.6135770923916904}}], Line[{{-0.937572879870399, \
0.6010618457721164}, {-0.939865519772524, 0.5838857533279135}, 
    {-1., 0.}, {-1., 0.}, {-0.937572879870399, 0.6010618457721164}}], 
  Line[{{-0.939865519772524, 0.5838857533279135}, {-0.9426374519262395, \
0.5624063276196133}, {-1., 0.}, {-1., 0.}, 
    {-0.939865519772524, 0.5838857533279135}}], Line[{{-0.9426374519262395, \
0.5624063276196133}, {-0.9457675295952218, 0.5371028573756126}, 
    {-1., 0.}, {-1., 0.}, {-0.9426374519262395, 0.5624063276196133}}], 
  Line[{{-0.9457675295952218, 0.5371028573756126}, {-0.9491189533655575, \
0.5085950701762803}, {-1., 0.}, {-1., 0.}, 
    {-0.9457675295952218, 0.5371028573756126}}], Line[{{-0.9491189533655575, \
0.5085950701762803}, {-0.9525452499365673, 0.4776706018498115}, 
    {-1., 0.}, {-1., 0.}, {-0.9491189533655575, 0.5085950701762803}}], 
  Line[{{-0.9525452499365673, 0.4776706018498115}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}, 
    {-0.9525452499365673, 0.4776706018498115}}], Line[{{-0.955896673706903, \
0.44532374723565715}, {-0.9590267513758853, 0.41280605266694914}, 
    {-1., 0.}, {-1., 0.}, {-0.955896673706903, 0.44532374723565715}}], 
  Line[{{-0.9590267513758853, 0.41280605266694914}, {-0.9617986835296009, \
0.3816816923272197}, {-1., 0.}, {-1., 0.}, 
    {-0.9590267513758853, 0.41280605266694914}}], Line[{{-0.9617986835296009, \
0.3816816923272197}, {-0.9640913234317259, 0.3538602304100192}, 
    {-1., 0.}, {-1., 0.}, {-0.9617986835296009, 0.3816816923272197}}], 
  Line[{{-0.9640913234317259, 0.3538602304100192}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}, 
    {-0.9640913234317259, 0.3538602304100192}}], Line[{{-0.9658044717172307, \
0.33154008354139486}, {-0.9668632555854413, 0.31695593148714163}, 
    {-1., 0.}, {-1., 0.}, {-0.9658044717172307, 0.33154008354139486}}], 
  Line[{{-0.9668632555854413, 0.31695593148714163}, {-0.9672214011007083, \
0.3118675362266397}, {-1., 0.}, {-1., 0.}, 
    {-0.9668632555854413, 0.31695593148714163}}], Line[{{-0.9672214011007083, \
0.3118675362266397}, {-0.9668632555854414, 0.31695593148714096}, 
    {-1., 0.}, {-1., 0.}, {-0.9672214011007083, 0.3118675362266397}}], 
  Line[{{-0.9668632555854414, 0.31695593148714096}, {-0.9658044717172307, \
0.33154008354139486}, {-1., 0.}, {-1., 0.}, 
    {-0.9668632555854414, 0.31695593148714096}}], Line[{{-0.9658044717172307, \
0.33154008354139486}, {-0.9640913234317259, 0.3538602304100192}, 
    {-1., 0.}, {-1., 0.}, {-0.9658044717172307, 0.33154008354139486}}], 
  Line[{{-0.9640913234317259, 0.3538602304100192}, {-0.9617986835296009, \
0.38168169232721944}, {-1., 0.}, {-1., 0.}, 
    {-0.9640913234317259, 0.3538602304100192}}], Line[{{-0.9617986835296009, \
0.38168169232721944}, {-0.9590267513758853, 0.41280605266694886}, 
    {-1., 0.}, {-1., 0.}, {-0.9617986835296009, 0.38168169232721944}}], 
  Line[{{-0.9590267513758853, 0.41280605266694886}, {-0.955896673706903, \
0.44532374723565715}, {-1., 0.}, {-1., 0.}, 
    {-0.9590267513758853, 0.41280605266694886}}], Line[{{-0.955896673706903, \
0.44532374723565715}, {-0.9525452499365673, 0.47767060184981125}, 
    {-1., 0.}, {-1., 0.}, {-0.955896673706903, 0.44532374723565715}}], 
  Line[{{-0.9525452499365673, 0.47767060184981125}, {-0.9491189533655575, \
0.50859507017628}, {-1., 0.}, {-1., 0.}, 
    {-0.9525452499365673, 0.47767060184981125}}], Line[{{-0.9491189533655575, \
0.50859507017628}, {-0.9457675295952219, 0.5371028573756125}, 
    {-1., 0.}, {-1., 0.}, {-0.9491189533655575, 0.50859507017628}}], 
  Line[{{-0.9457675295952219, 0.5371028573756125}, {-0.9426374519262395, \
0.5624063276196131}, {-1., 0.}, {-1., 0.}, 
    {-0.9457675295952219, 0.5371028573756125}}], Line[{{-0.9426374519262395, \
0.5624063276196131}, {-0.939865519772524, 0.5838857533279135}, 
    {-1., 0.}, {-1., 0.}, {-0.9426374519262395, 0.5624063276196131}}], 
  Line[{{-0.939865519772524, 0.5838857533279135}, {-0.937572879870399, \
0.6010618457721164}, {-1., 0.}, {-1., 0.}, 
    {-0.939865519772524, 0.5838857533279135}}], Line[{{-0.937572879870399, \
0.6010618457721164}, {-0.935859731584894, 0.6135770923916908}, 
    {-1., 0.}, {-1., 0.}, {-0.937572879870399, 0.6010618457721164}}], 
  Line[{{-0.935859731584894, 0.6135770923916908}, {-0.9348009477166834, \
0.6211835161491779}, {-1., 0.}, {-1., 0.}, 
    {-0.935859731584894, 0.6135770923916908}}], Line[{{-0.9348009477166834, \
0.6211835161491779}, {-0.9344428022014165, 0.6237350724532796}, 
    {-1., 0.}, {-1., 0.}, {-0.9348009477166834, 0.6211835161491779}}]}, {Axes \
-> True, AspectRatio -> Automatic}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell["\<\
meshnodes = Map[ n  /.Thread[{t,p}\[Rule]#]&, thenodes, {2}];
thequads3D = Map[   Flatten[#,1][[{1,2,4,3}]]  & ,Flatten[ Partition[ \
meshnodes, {2,2}, {1,1}], 1]];
thesphere3D = Map[ ClosedLine, thequads3D];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
spherefill3D = ( Graphics3D /@ Transpose[ {colorlist, Polygon /@ thequads3D} \
]);
Show[ spherefill3D , Lighting -> False ]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 6.45642e-17 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.717 .5 .342 .1 k
.49889 .55376 m .52065 .55481 L .52015 .58412 L p F P
0 g
s
.717 .5 .342 .1 k
.52015 .58412 m .49647 .58301 L .49889 .55376 L p F P
0 g
s
.717 .5 .325 .1 k
.54389 .58377 m .52015 .58412 L .52065 .55481 L p F P
0 g
s
.683 .5 .342 .1 k
.49647 .58301 m .52015 .58412 L .51972 .61343 L p F P
0 g
s
.683 .5 .325 .1 k
.52015 .58412 m .54389 .58377 L .54514 .61306 L p F P
0 g
s
.683 .5 .325 .1 k
.54514 .61306 m .51972 .61343 L .52015 .58412 L p F P
0 g
s
.717 .5 .325 .1 k
.52065 .55481 m .54246 .55448 L .54389 .58377 L p F P
0 g
s
.717 .5 .308 .1 k
.56747 .58195 m .54389 .58377 L .54246 .55448 L p F P
0 g
s
.683 .5 .308 .1 k
.54389 .58377 m .56747 .58195 L .57041 .61115 L p F P
0 g
s
.683 .5 .308 .1 k
.57041 .61115 m .54514 .61306 L .54389 .58377 L p F P
0 g
s
.75 .5 .342 .1 k
.50157 .52473 m .52121 .52569 L .52065 .55481 L p F P
0 g
s
.75 .5 .342 .1 k
.52065 .55481 m .49889 .55376 L .50157 .52473 L p F P
0 g
s
.75 .5 .325 .1 k
.54246 .55448 m .52065 .55481 L .52121 .52569 L p F P
0 g
s
.717 .5 .358 .1 k
.47736 .55136 m .49889 .55376 L .49647 .58301 L p F P
0 g
s
.717 .5 .358 .1 k
.49647 .58301 m .47304 .58043 L .47736 .55136 L p F P
0 g
s
.683 .5 .358 .1 k
.47304 .58043 m .49647 .58301 L .49435 .61226 L p F P
0 g
s
.683 .5 .342 .1 k
.51972 .61343 m .49435 .61226 L .49647 .58301 L p F P
0 g
s
.65 .5 .342 .1 k
.49435 .61226 m .51972 .61343 L .51934 .64253 L p F P
0 g
s
.65 .5 .325 .1 k
.51972 .61343 m .54514 .61306 L .54621 .64215 L p F P
0 g
s
.65 .5 .325 .1 k
.54621 .64215 m .51934 .64253 L .51972 .61343 L p F P
0 g
s
.75 .5 .325 .1 k
.52121 .52569 m .54088 .52538 L .54246 .55448 L p F P
0 g
s
.75 .5 .308 .1 k
.56414 .55278 m .54246 .55448 L .54088 .52538 L p F P
0 g
s
.717 .5 .308 .1 k
.54246 .55448 m .56414 .55278 L .56747 .58195 L p F P
0 g
s
.65 .5 .308 .1 k
.54514 .61306 m .57041 .61115 L .57293 .64016 L p F P
0 g
s
.65 .5 .308 .1 k
.57293 .64016 m .54621 .64215 L .54514 .61306 L p F P
0 g
s
.75 .5 .358 .1 k
.48216 .52252 m .50157 .52473 L .49889 .55376 L p F P
0 g
s
.75 .5 .358 .1 k
.49889 .55376 m .47736 .55136 L .48216 .52252 L p F P
0 g
s
.717 .5 .292 .1 k
.59071 .57868 m .56747 .58195 L .56414 .55278 L p F P
0 g
s
.683 .5 .292 .1 k
.56747 .58195 m .59071 .57868 L .59531 .6077 L p F P
0 g
s
.683 .5 .292 .1 k
.59531 .6077 m .57041 .61115 L .56747 .58195 L p F P
0 g
s
.683 .5 .358 .1 k
.49435 .61226 m .46924 .60955 L .47304 .58043 L p F P
0 g
s
.65 .5 .358 .1 k
.46924 .60955 m .49435 .61226 L .49252 .64131 L p F P
0 g
s
.65 .5 .342 .1 k
.51934 .64253 m .49252 .64131 L .49435 .61226 L p F P
0 g
s
.75 .5 .308 .1 k
.54088 .52538 m .56043 .52382 L .56414 .55278 L p F P
0 g
s
.75 .5 .292 .1 k
.58549 .54971 m .56414 .55278 L .56043 .52382 L p F P
0 g
s
.717 .5 .292 .1 k
.56414 .55278 m .58549 .54971 L .59071 .57868 L p F P
0 g
s
.65 .5 .292 .1 k
.57041 .61115 m .59531 .6077 L .59927 .63658 L p F P
0 g
s
.65 .5 .292 .1 k
.59927 .63658 m .57293 .64016 L .57041 .61115 L p F P
0 g
s
.717 .5 .375 .1 k
.45625 .5476 m .47736 .55136 L .47304 .58043 L p F P
0 g
s
.717 .5 .375 .1 k
.47304 .58043 m .45006 .57641 L .45625 .5476 L p F P
0 g
s
.683 .5 .375 .1 k
.45006 .57641 m .47304 .58043 L .46924 .60955 L p F P
0 g
s
.783 .5 .342 .1 k
.50451 .49611 m .52181 .49696 L .52121 .52569 L p F P
0 g
s
.783 .5 .342 .1 k
.52121 .52569 m .50157 .52473 L .50451 .49611 L p F P
0 g
s
.783 .5 .325 .1 k
.54088 .52538 m .52121 .52569 L .52181 .49696 L p F P
0 g
s
.75 .5 .375 .1 k
.46313 .51907 m .48216 .52252 L .47736 .55136 L p F P
0 g
s
.75 .5 .375 .1 k
.47736 .55136 m .45625 .5476 L .46313 .51907 L p F P
0 g
s
.783 .5 .325 .1 k
.52181 .49696 m .53916 .49669 L .54088 .52538 L p F P
0 g
s
.783 .5 .308 .1 k
.56043 .52382 m .54088 .52538 L .53916 .49669 L p F P
0 g
s
.617 .5 .342 .1 k
.49252 .64131 m .51934 .64253 L .51903 .67122 L p F P
0 g
s
.617 .5 .325 .1 k
.51934 .64253 m .54621 .64215 L .5471 .67082 L p F P
0 g
s
.617 .5 .325 .1 k
.5471 .67082 m .51903 .67122 L .51934 .64253 L p F P
0 g
s
.617 .5 .308 .1 k
.54621 .64215 m .57293 .64016 L .57501 .66878 L p F P
0 g
s
.617 .5 .308 .1 k
.57501 .66878 m .5471 .67082 L .54621 .64215 L p F P
0 g
s
.683 .5 .375 .1 k
.46924 .60955 m .4446 .60531 L .45006 .57641 L p F P
0 g
s
.65 .5 .375 .1 k
.4446 .60531 m .46924 .60955 L .46597 .6385 L p F P
0 g
s
.65 .5 .358 .1 k
.49252 .64131 m .46597 .6385 L .46924 .60955 L p F P
0 g
s
.783 .5 .358 .1 k
.48741 .49413 m .50451 .49611 L .50157 .52473 L p F P
0 g
s
.783 .5 .358 .1 k
.50157 .52473 m .48216 .52252 L .48741 .49413 L p F P
0 g
s
.717 .5 .275 .1 k
.61341 .57397 m .59071 .57868 L .58549 .54971 L p F P
0 g
s
.683 .5 .275 .1 k
.59071 .57868 m .61341 .57397 L .61966 .60274 L p F P
0 g
s
.683 .5 .275 .1 k
.61966 .60274 m .59531 .6077 L .59071 .57868 L p F P
0 g
s
.617 .5 .358 .1 k
.46597 .6385 m .49252 .64131 L .49101 .66997 L p F P
0 g
s
.617 .5 .342 .1 k
.51903 .67122 m .49101 .66997 L .49252 .64131 L p F P
0 g
s
.75 .5 .292 .1 k
.56043 .52382 m .57968 .52101 L .58549 .54971 L p F P
0 g
s
.75 .5 .275 .1 k
.60633 .54531 m .58549 .54971 L .57968 .52101 L p F P
0 g
s
.717 .5 .275 .1 k
.58549 .54971 m .60633 .54531 L .61341 .57397 L p F P
0 g
s
.783 .5 .308 .1 k
.53916 .49669 m .55638 .4953 L .56043 .52382 L p F P
0 g
s
.783 .5 .292 .1 k
.57968 .52101 m .56043 .52382 L .55638 .4953 L p F P
0 g
s
.65 .5 .275 .1 k
.59531 .6077 m .61966 .60274 L .62502 .63143 L p F P
0 g
s
.65 .5 .275 .1 k
.62502 .63143 m .59927 .63658 L .59531 .6077 L p F P
0 g
s
.617 .5 .292 .1 k
.57293 .64016 m .59927 .63658 L .60253 .66511 L p F P
0 g
s
.617 .5 .292 .1 k
.60253 .66511 m .57501 .66878 L .57293 .64016 L p F P
0 g
s
.783 .5 .375 .1 k
.47065 .49104 m .48741 .49413 L .48216 .52252 L p F P
0 g
s
.783 .5 .375 .1 k
.48216 .52252 m .46313 .51907 L .47065 .49104 L p F P
0 g
s
.717 .5 .392 .1 k
.43575 .54251 m .45625 .5476 L .45006 .57641 L p F P
0 g
s
.717 .5 .392 .1 k
.45006 .57641 m .42772 .57097 L .43575 .54251 L p F P
0 g
s
.683 .5 .392 .1 k
.42772 .57097 m .45006 .57641 L .4446 .60531 L p F P
0 g
s
.75 .5 .392 .1 k
.44467 .51441 m .46313 .51907 L .45625 .5476 L p F P
0 g
s
.75 .5 .392 .1 k
.45625 .5476 m .43575 .54251 L .44467 .51441 L p F P
0 g
s
.783 .5 .292 .1 k
.55638 .4953 m .57334 .49278 L .57968 .52101 L p F P
0 g
s
.783 .5 .275 .1 k
.59846 .51698 m .57968 .52101 L .57334 .49278 L p F P
0 g
s
.75 .5 .275 .1 k
.57968 .52101 m .59846 .51698 L .60633 .54531 L p F P
0 g
s
.65 .5 .375 .1 k
.46597 .6385 m .43991 .6341 L .4446 .60531 L p F P
0 g
s
.617 .5 .375 .1 k
.43991 .6341 m .46597 .6385 L .46327 .66708 L p F P
0 g
s
.617 .5 .358 .1 k
.49101 .66997 m .46327 .66708 L .46597 .6385 L p F P
0 g
s
.683 .5 .392 .1 k
.4446 .60531 m .42063 .59958 L .42772 .57097 L p F P
0 g
s
.65 .5 .392 .1 k
.42063 .59958 m .4446 .60531 L .43991 .6341 L p F P
0 g
s
.817 .5 .342 .1 k
.50768 .46811 m .52247 .46885 L .52181 .49696 L p F P
0 g
s
.817 .5 .342 .1 k
.52181 .49696 m .50451 .49611 L .50768 .46811 L p F P
0 g
s
.817 .5 .325 .1 k
.53916 .49669 m .52181 .49696 L .52247 .46885 L p F P
0 g
s
.817 .5 .325 .1 k
.52247 .46885 m .53729 .46862 L .53916 .49669 L p F P
0 g
s
.817 .5 .308 .1 k
.55638 .4953 m .53916 .49669 L .53729 .46862 L p F P
0 g
s
.717 .5 .258 .1 k
.63537 .56785 m .61341 .57397 L .60633 .54531 L p F P
0 g
s
.683 .5 .258 .1 k
.61341 .57397 m .63537 .56785 L .64322 .59629 L p F P
0 g
s
.683 .5 .258 .1 k
.64322 .59629 m .61966 .60274 L .61341 .57397 L p F P
0 g
s
.75 .5 .258 .1 k
.62647 .5396 m .60633 .54531 L .59846 .51698 L p F P
0 g
s
.717 .5 .258 .1 k
.60633 .54531 m .62647 .5396 L .63537 .56785 L p F P
0 g
s
.583 .5 .342 .1 k
.49101 .66997 m .51903 .67122 L .51878 .69928 L p F P
0 g
s
.583 .5 .325 .1 k
.51903 .67122 m .5471 .67082 L .54779 .69888 L p F P
0 g
s
.583 .5 .325 .1 k
.54779 .69888 m .51878 .69928 L .51903 .67122 L p F P
0 g
s
.817 .5 .358 .1 k
.49307 .46639 m .50768 .46811 L .50451 .49611 L p F P
0 g
s
.817 .5 .358 .1 k
.50451 .49611 m .48741 .49413 L .49307 .46639 L p F P
0 g
s
.783 .5 .392 .1 k
.45441 .48687 m .47065 .49104 L .46313 .51907 L p F P
0 g
s
.783 .5 .392 .1 k
.46313 .51907 m .44467 .51441 L .45441 .48687 L p F P
0 g
s
.583 .5 .308 .1 k
.5471 .67082 m .57501 .66878 L .57663 .69681 L p F P
0 g
s
.583 .5 .308 .1 k
.57663 .69681 m .54779 .69888 L .5471 .67082 L p F P
0 g
s
.617 .5 .275 .1 k
.59927 .63658 m .62502 .63143 L .62945 .65982 L p F P
0 g
s
.617 .5 .275 .1 k
.62945 .65982 m .60253 .66511 L .59927 .63658 L p F P
0 g
s
.817 .5 .308 .1 k
.53729 .46862 m .55201 .4674 L .55638 .4953 L p F P
0 g
s
.817 .5 .292 .1 k
.57334 .49278 m .55638 .4953 L .55201 .4674 L p F P
0 g
s
.583 .5 .358 .1 k
.46327 .66708 m .49101 .66997 L .48983 .69801 L p F P
0 g
s
.583 .5 .342 .1 k
.51878 .69928 m .48983 .69801 L .49101 .66997 L p F P
0 g
s
.65 .5 .258 .1 k
.61966 .60274 m .64322 .59629 L .64997 .62473 L p F P
0 g
s
.65 .5 .258 .1 k
.64997 .62473 m .62502 .63143 L .61966 .60274 L p F P
0 g
s
.817 .5 .375 .1 k
.47877 .46371 m .49307 .46639 L .48741 .49413 L p F P
0 g
s
.817 .5 .375 .1 k
.48741 .49413 m .47065 .49104 L .47877 .46371 L p F P
0 g
s
.783 .5 .275 .1 k
.57334 .49278 m .58986 .48917 L .59846 .51698 L p F P
0 g
s
.783 .5 .258 .1 k
.6166 .51174 m .59846 .51698 L .58986 .48917 L p F P
0 g
s
.75 .5 .258 .1 k
.59846 .51698 m .6166 .51174 L .62647 .5396 L p F P
0 g
s
.583 .5 .292 .1 k
.57501 .66878 m .60253 .66511 L .60509 .69308 L p F P
0 g
s
.583 .5 .292 .1 k
.60509 .69308 m .57663 .69681 L .57501 .66878 L p F P
0 g
s
.75 .5 .408 .1 k
.42693 .50856 m .44467 .51441 L .43575 .54251 L p F P
0 g
s
.75 .5 .408 .1 k
.43575 .54251 m .41604 .53612 L .42693 .50856 L p F P
0 g
s
.717 .5 .408 .1 k
.41604 .53612 m .43575 .54251 L .42772 .57097 L p F P
0 g
s
.717 .5 .408 .1 k
.42772 .57097 m .40622 .56413 L .41604 .53612 L p F P
0 g
s
.683 .5 .408 .1 k
.40622 .56413 m .42772 .57097 L .42063 .59958 L p F P
0 g
s
.65 .5 .392 .1 k
.43991 .6341 m .41455 .62814 L .42063 .59958 L p F P
0 g
s
.617 .5 .392 .1 k
.41455 .62814 m .43991 .6341 L .43604 .66256 L p F P
0 g
s
.617 .5 .375 .1 k
.46327 .66708 m .43604 .66256 L .43991 .6341 L p F P
0 g
s
.817 .5 .292 .1 k
.55201 .4674 m .56648 .46522 L .57334 .49278 L p F P
0 g
s
.817 .5 .275 .1 k
.58986 .48917 m .57334 .49278 L .56648 .46522 L p F P
0 g
s
.583 .5 .375 .1 k
.43604 .66256 m .46327 .66708 L .46117 .69508 L p F P
0 g
s
.583 .5 .358 .1 k
.48983 .69801 m .46117 .69508 L .46327 .66708 L p F P
0 g
s
.783 .5 .408 .1 k
.43883 .48164 m .45441 .48687 L .44467 .51441 L p F P
0 g
s
.783 .5 .408 .1 k
.44467 .51441 m .42693 .50856 L .43883 .48164 L p F P
0 g
s
.683 .5 .408 .1 k
.42063 .59958 m .39755 .59237 L .40622 .56413 L p F P
0 g
s
.65 .5 .408 .1 k
.39755 .59237 m .42063 .59958 L .41455 .62814 L p F P
0 g
s
.817 .5 .392 .1 k
.46492 .46009 m .47877 .46371 L .47065 .49104 L p F P
0 g
s
.817 .5 .392 .1 k
.47065 .49104 m .45441 .48687 L .46492 .46009 L p F P
0 g
s
.75 .5 .242 .1 k
.64574 .5326 m .62647 .5396 L .6166 .51174 L p F P
0 g
s
.717 .5 .242 .1 k
.62647 .5396 m .64574 .5326 L .6564 .56036 L p F P
0 g
s
.717 .5 .242 .1 k
.6564 .56036 m .63537 .56785 L .62647 .5396 L p F P
0 g
s
.617 .5 .258 .1 k
.62502 .63143 m .64997 .62473 L .65555 .65294 L p F P
0 g
s
.617 .5 .258 .1 k
.65555 .65294 m .62945 .65982 L .62502 .63143 L p F P
0 g
s
.683 .5 .242 .1 k
.63537 .56785 m .6564 .56036 L .66581 .5884 L p F P
0 g
s
.683 .5 .242 .1 k
.66581 .5884 m .64322 .59629 L .63537 .56785 L p F P
0 g
s
.583 .5 .275 .1 k
.60253 .66511 m .62945 .65982 L .63292 .68771 L p F P
0 g
s
.583 .5 .275 .1 k
.63292 .68771 m .60509 .69308 L .60253 .66511 L p F P
0 g
s
.817 .5 .275 .1 k
.56648 .46522 m .58059 .46208 L .58986 .48917 L p F P
0 g
s
.817 .5 .258 .1 k
.60581 .48448 m .58986 .48917 L .58059 .46208 L p F P
0 g
s
.783 .5 .258 .1 k
.58986 .48917 m .60581 .48448 L .6166 .51174 L p F P
0 g
s
.85 .5 .342 .1 k
.51107 .44094 m .52317 .44156 L .52247 .46885 L p F P
0 g
s
.85 .5 .342 .1 k
.52247 .46885 m .50768 .46811 L .51107 .44094 L p F P
0 g
s
.85 .5 .325 .1 k
.53729 .46862 m .52247 .46885 L .52317 .44156 L p F P
0 g
s
.85 .5 .325 .1 k
.52317 .44156 m .53529 .44136 L .53729 .46862 L p F P
0 g
s
.85 .5 .308 .1 k
.55201 .4674 m .53729 .46862 L .53529 .44136 L p F P
0 g
s
.783 .5 .242 .1 k
.63392 .50534 m .6166 .51174 L .60581 .48448 L p F P
0 g
s
.75 .5 .242 .1 k
.6166 .51174 m .63392 .50534 L .64574 .5326 L p F P
0 g
s
.85 .5 .358 .1 k
.49912 .43951 m .51107 .44094 L .50768 .46811 L p F P
0 g
s
.85 .5 .358 .1 k
.50768 .46811 m .49307 .46639 L .49912 .43951 L p F P
0 g
s
.55 .5 .342 .1 k
.48983 .69801 m .51878 .69928 L .51861 .72651 L p F P
0 g
s
.55 .5 .325 .1 k
.51878 .69928 m .54779 .69888 L .54828 .7261 L p F P
0 g
s
.55 .5 .325 .1 k
.54828 .7261 m .51861 .72651 L .51878 .69928 L p F P
0 g
s
.65 .5 .242 .1 k
.64322 .59629 m .66581 .5884 L .67389 .61652 L p F P
0 g
s
.65 .5 .242 .1 k
.67389 .61652 m .64997 .62473 L .64322 .59629 L p F P
0 g
s
.55 .5 .308 .1 k
.54779 .69888 m .57663 .69681 L .57779 .72402 L p F P
0 g
s
.55 .5 .308 .1 k
.57779 .72402 m .54828 .7261 L .54779 .69888 L p F P
0 g
s
.85 .5 .308 .1 k
.53529 .44136 m .54733 .44035 L .55201 .4674 L p F P
0 g
s
.85 .5 .292 .1 k
.56648 .46522 m .55201 .4674 L .54733 .44035 L p F P
0 g
s
.75 .5 .425 .1 k
.4101 .50157 m .42693 .50856 L .41604 .53612 L p F P
0 g
s
.75 .5 .425 .1 k
.41604 .53612 m .3973 .52849 L .4101 .50157 L p F P
0 g
s
.717 .5 .425 .1 k
.3973 .52849 m .41604 .53612 L .40622 .56413 L p F P
0 g
s
.817 .5 .408 .1 k
.45164 .45556 m .46492 .46009 L .45441 .48687 L p F P
0 g
s
.817 .5 .408 .1 k
.45441 .48687 m .43883 .48164 L .45164 .45556 L p F P
0 g
s
.617 .5 .392 .1 k
.43604 .66256 m .40952 .65645 L .41455 .62814 L p F P
0 g
s
.583 .5 .392 .1 k
.40952 .65645 m .43604 .66256 L .43301 .69049 L p F P
0 g
s
.583 .5 .375 .1 k
.46117 .69508 m .43301 .69049 L .43604 .66256 L p F P
0 g
s
.65 .5 .408 .1 k
.41455 .62814 m .3901 .62065 L .39755 .59237 L p F P
0 g
s
.617 .5 .408 .1 k
.3901 .62065 m .41455 .62814 L .40952 .65645 L p F P
0 g
s
.55 .5 .358 .1 k
.46117 .69508 m .48983 .69801 L .489 .72523 L p F P
0 g
s
.55 .5 .342 .1 k
.51861 .72651 m .489 .72523 L .48983 .69801 L p F P
0 g
s
.85 .5 .375 .1 k
.48743 .43729 m .49912 .43951 L .49307 .46639 L p F P
0 g
s
.85 .5 .375 .1 k
.49307 .46639 m .47877 .46371 L .48743 .43729 L p F P
0 g
s
.717 .5 .425 .1 k
.40622 .56413 m .38576 .55595 L .3973 .52849 L p F P
0 g
s
.683 .5 .425 .1 k
.38576 .55595 m .40622 .56413 L .39755 .59237 L p F P
0 g
s
.783 .5 .425 .1 k
.42406 .47539 m .43883 .48164 L .42693 .50856 L p F P
0 g
s
.783 .5 .425 .1 k
.42693 .50856 m .4101 .50157 L .42406 .47539 L p F P
0 g
s
.55 .5 .292 .1 k
.57663 .69681 m .60509 .69308 L .60689 .72028 L p F P
0 g
s
.55 .5 .292 .1 k
.60689 .72028 m .57779 .72402 L .57663 .69681 L p F P
0 g
s
.85 .5 .292 .1 k
.54733 .44035 m .55917 .43854 L .56648 .46522 L p F P
0 g
s
.85 .5 .275 .1 k
.58059 .46208 m .56648 .46522 L .55917 .43854 L p F P
0 g
s
.817 .5 .258 .1 k
.58059 .46208 m .59418 .45802 L .60581 .48448 L p F P
0 g
s
.817 .5 .242 .1 k
.62102 .47876 m .60581 .48448 L .59418 .45802 L p F P
0 g
s
.783 .5 .242 .1 k
.60581 .48448 m .62102 .47876 L .63392 .50534 L p F P
0 g
s
.85 .5 .392 .1 k
.47612 .43428 m .48743 .43729 L .47877 .46371 L p F P
0 g
s
.85 .5 .392 .1 k
.47877 .46371 m .46492 .46009 L .47612 .43428 L p F P
0 g
s
.583 .5 .258 .1 k
.62945 .65982 m .65555 .65294 L .65991 .68072 L p F P
0 g
s
.583 .5 .258 .1 k
.65991 .68072 m .63292 .68771 L .62945 .65982 L p F P
0 g
s
.683 .5 .425 .1 k
.39755 .59237 m .37556 .58374 L .38576 .55595 L p F P
0 g
s
.65 .5 .425 .1 k
.37556 .58374 m .39755 .59237 L .3901 .62065 L p F P
0 g
s
.55 .5 .375 .1 k
.43301 .69049 m .46117 .69508 L .45967 .72229 L p F P
0 g
s
.55 .5 .358 .1 k
.489 .72523 m .45967 .72229 L .46117 .69508 L p F P
0 g
s
.75 .5 .225 .1 k
.66395 .52438 m .64574 .5326 L .63392 .50534 L p F P
0 g
s
.717 .5 .225 .1 k
.64574 .5326 m .66395 .52438 L .67629 .55154 L p F P
0 g
s
.717 .5 .225 .1 k
.67629 .55154 m .6564 .56036 L .64574 .5326 L p F P
0 g
s
.617 .5 .242 .1 k
.64997 .62473 m .67389 .61652 L .68059 .64451 L p F P
0 g
s
.617 .5 .242 .1 k
.68059 .64451 m .65555 .65294 L .64997 .62473 L p F P
0 g
s
.683 .5 .225 .1 k
.6564 .56036 m .67629 .55154 L .6872 .5791 L p F P
0 g
s
.683 .5 .225 .1 k
.6872 .5791 m .66581 .5884 L .6564 .56036 L p F P
0 g
s
.85 .5 .275 .1 k
.55917 .43854 m .57069 .43594 L .58059 .46208 L p F P
0 g
s
.85 .5 .258 .1 k
.59418 .45802 m .58059 .46208 L .57069 .43594 L p F P
0 g
s
.783 .5 .225 .1 k
.65026 .49781 m .63392 .50534 L .62102 .47876 L p F P
0 g
s
.75 .5 .225 .1 k
.63392 .50534 m .65026 .49781 L .66395 .52438 L p F P
0 g
s
.817 .5 .425 .1 k
.43908 .45015 m .45164 .45556 L .43883 .48164 L p F P
0 g
s
.817 .5 .425 .1 k
.43883 .48164 m .42406 .47539 L .43908 .45015 L p F P
0 g
s
.55 .5 .275 .1 k
.60509 .69308 m .63292 .68771 L .63537 .71488 L p F P
0 g
s
.55 .5 .275 .1 k
.63537 .71488 m .60689 .72028 L .60509 .69308 L p F P
0 g
s
.85 .5 .408 .1 k
.4653 .43053 m .47612 .43428 L .46492 .46009 L p F P
0 g
s
.85 .5 .408 .1 k
.46492 .46009 m .45164 .45556 L .4653 .43053 L p F P
0 g
s
.617 .5 .408 .1 k
.40952 .65645 m .38394 .64875 L .3901 .62065 L p F P
0 g
s
.583 .5 .408 .1 k
.38394 .64875 m .40952 .65645 L .40558 .68428 L p F P
0 g
s
.583 .5 .392 .1 k
.43301 .69049 m .40558 .68428 L .40952 .65645 L p F P
0 g
s
.65 .5 .225 .1 k
.66581 .5884 m .6872 .5791 L .69658 .60684 L p F P
0 g
s
.65 .5 .225 .1 k
.69658 .60684 m .67389 .61652 L .66581 .5884 L p F P
0 g
s
.75 .5 .442 .1 k
.39432 .49349 m .4101 .50157 L .3973 .52849 L p F P
0 g
s
.75 .5 .442 .1 k
.3973 .52849 m .37972 .51965 L .39432 .49349 L p F P
0 g
s
.717 .5 .442 .1 k
.37972 .51965 m .3973 .52849 L .38576 .55595 L p F P
0 g
s
.817 .5 .242 .1 k
.59418 .45802 m .60713 .45306 L .62102 .47876 L p F P
0 g
s
.817 .5 .225 .1 k
.63535 .47204 m .62102 .47876 L .60713 .45306 L p F P
0 g
s
.783 .5 .225 .1 k
.62102 .47876 m .63535 .47204 L .65026 .49781 L p F P
0 g
s
.65 .5 .425 .1 k
.3901 .62065 m .36679 .61168 L .37556 .58374 L p F P
0 g
s
.617 .5 .425 .1 k
.36679 .61168 m .3901 .62065 L .38394 .64875 L p F P
0 g
s
.883 .5 .342 .1 k
.51465 .41481 m .52391 .41529 L .52317 .44156 L p F P
0 g
s
.883 .5 .342 .1 k
.52317 .44156 m .51107 .44094 L .51465 .41481 L p F P
0 g
s
.883 .5 .325 .1 k
.53529 .44136 m .52317 .44156 L .52391 .41529 L p F P
0 g
s
.783 .5 .442 .1 k
.41024 .46818 m .42406 .47539 L .4101 .50157 L p F P
0 g
s
.783 .5 .442 .1 k
.4101 .50157 m .39432 .49349 L .41024 .46818 L p F P
0 g
s
.883 .5 .325 .1 k
.52391 .41529 m .53319 .41514 L .53529 .44136 L p F P
0 g
s
.883 .5 .308 .1 k
.54733 .44035 m .53529 .44136 L .53319 .41514 L p F P
0 g
s
.85 .5 .258 .1 k
.57069 .43594 m .58178 .43257 L .59418 .45802 L p F P
0 g
s
.85 .5 .242 .1 k
.60713 .45306 m .59418 .45802 L .58178 .43257 L p F P
0 g
s
.55 .5 .392 .1 k
.40558 .68428 m .43301 .69049 L .43086 .71768 L p F P
0 g
s
.55 .5 .375 .1 k
.45967 .72229 m .43086 .71768 L .43301 .69049 L p F P
0 g
s
.883 .5 .358 .1 k
.50551 .41371 m .51465 .41481 L .51107 .44094 L p F P
0 g
s
.883 .5 .358 .1 k
.51107 .44094 m .49912 .43951 L .50551 .41371 L p F P
0 g
s
.717 .5 .442 .1 k
.38576 .55595 m .36653 .54647 L .37972 .51965 L p F P
0 g
s
.683 .5 .442 .1 k
.36653 .54647 m .38576 .55595 L .37556 .58374 L p F P
0 g
s
.517 .5 .342 .1 k
.489 .72523 m .51861 .72651 L .51851 .75269 L p F P
0 g
s
.517 .5 .325 .1 k
.51861 .72651 m .54828 .7261 L .54856 .75229 L p F P
0 g
s
.517 .5 .325 .1 k
.54856 .75229 m .51851 .75269 L .51861 .72651 L p F P
0 g
s
.883 .5 .308 .1 k
.53319 .41514 m .5424 .41436 L .54733 .44035 L p F P
0 g
s
.883 .5 .292 .1 k
.55917 .43854 m .54733 .44035 L .5424 .41436 L p F P
0 g
s
.517 .5 .308 .1 k
.54828 .7261 m .57779 .72402 L .57845 .75022 L p F P
0 g
s
.517 .5 .308 .1 k
.57845 .75022 m .54856 .75229 L .54828 .7261 L p F P
0 g
s
.883 .5 .375 .1 k
.49658 .41198 m .50551 .41371 L .49912 .43951 L p F P
0 g
s
.883 .5 .375 .1 k
.49912 .43951 m .48743 .43729 L .49658 .41198 L p F P
0 g
s
.583 .5 .242 .1 k
.65555 .65294 m .68059 .64451 L .68583 .67215 L p F P
0 g
s
.583 .5 .242 .1 k
.68583 .67215 m .65991 .68072 L .65555 .65294 L p F P
0 g
s
.517 .5 .358 .1 k
.45967 .72229 m .489 .72523 L .48852 .75142 L p F P
0 g
s
.517 .5 .342 .1 k
.51851 .75269 m .48852 .75142 L .489 .72523 L p F P
0 g
s
.85 .5 .425 .1 k
.45507 .42605 m .4653 .43053 L .45164 .45556 L p F P
0 g
s
.85 .5 .425 .1 k
.45164 .45556 m .43908 .45015 L .45507 .42605 L p F P
0 g
s
.883 .5 .292 .1 k
.5424 .41436 m .55145 .41295 L .55917 .43854 L p F P
0 g
s
.883 .5 .275 .1 k
.57069 .43594 m .55917 .43854 L .55145 .41295 L p F P
0 g
s
.817 .5 .442 .1 k
.42736 .44391 m .43908 .45015 L .42406 .47539 L p F P
0 g
s
.817 .5 .442 .1 k
.42406 .47539 m .41024 .46818 L .42736 .44391 L p F P
0 g
s
.55 .5 .258 .1 k
.63292 .68771 m .65991 .68072 L .663 .70786 L p F P
0 g
s
.55 .5 .258 .1 k
.663 .70786 m .63537 .71488 L .63292 .68771 L p F P
0 g
s
.75 .5 .208 .1 k
.68091 .51499 m .66395 .52438 L .65026 .49781 L p F P
0 g
s
.717 .5 .208 .1 k
.66395 .52438 m .68091 .51499 L .69485 .54146 L p F P
0 g
s
.717 .5 .208 .1 k
.69485 .54146 m .67629 .55154 L .66395 .52438 L p F P
0 g
s
.517 .5 .292 .1 k
.57779 .72402 m .60689 .72028 L .60793 .74648 L p F P
0 g
s
.517 .5 .292 .1 k
.60793 .74648 m .57845 .75022 L .57779 .72402 L p F P
0 g
s
.783 .5 .208 .1 k
.66546 .48923 m .65026 .49781 L .63535 .47204 L p F P
0 g
s
.75 .5 .208 .1 k
.65026 .49781 m .66546 .48923 L .68091 .51499 L p F P
0 g
s
.683 .5 .442 .1 k
.37556 .58374 m .35487 .57374 L .36653 .54647 L p F P
0 g
s
.65 .5 .442 .1 k
.35487 .57374 m .37556 .58374 L .36679 .61168 L p F P
0 g
s
.883 .5 .392 .1 k
.48794 .40965 m .49658 .41198 L .48743 .43729 L p F P
0 g
s
.883 .5 .392 .1 k
.48743 .43729 m .47612 .43428 L .48794 .40965 L p F P
0 g
s
.617 .5 .225 .1 k
.67389 .61652 m .69658 .60684 L .70436 .63456 L p F P
0 g
s
.617 .5 .225 .1 k
.70436 .63456 m .68059 .64451 L .67389 .61652 L p F P
0 g
s
.85 .5 .242 .1 k
.58178 .43257 m .59233 .42846 L .60713 .45306 L p F P
0 g
s
.85 .5 .225 .1 k
.6193 .44725 m .60713 .45306 L .59233 .42846 L p F P
0 g
s
.817 .5 .225 .1 k
.60713 .45306 m .6193 .44725 L .63535 .47204 L p F P
0 g
s
.683 .5 .208 .1 k
.67629 .55154 m .69485 .54146 L .70719 .56846 L p F P
0 g
s
.683 .5 .208 .1 k
.70719 .56846 m .6872 .5791 L .67629 .55154 L p F P
0 g
s
.883 .5 .275 .1 k
.55145 .41295 m .56025 .41094 L .57069 .43594 L p F P
0 g
s
.883 .5 .258 .1 k
.58178 .43257 m .57069 .43594 L .56025 .41094 L p F P
0 g
s
.517 .5 .375 .1 k
.43086 .71768 m .45967 .72229 L .45882 .74849 L p F P
0 g
s
.517 .5 .358 .1 k
.48852 .75142 m .45882 .74849 L .45967 .72229 L p F P
0 g
s
.817 .5 .208 .1 k
.64865 .46438 m .63535 .47204 L .6193 .44725 L p F P
0 g
s
.783 .5 .208 .1 k
.63535 .47204 m .64865 .46438 L .66546 .48923 L p F P
0 g
s
.617 .5 .425 .1 k
.38394 .64875 m .35953 .63953 L .36679 .61168 L p F P
0 g
s
.583 .5 .425 .1 k
.35953 .63953 m .38394 .64875 L .37912 .67647 L p F P
0 g
s
.583 .5 .408 .1 k
.40558 .68428 m .37912 .67647 L .38394 .64875 L p F P
0 g
s
.883 .5 .408 .1 k
.47969 .40674 m .48794 .40965 L .47612 .43428 L p F P
0 g
s
.883 .5 .408 .1 k
.47612 .43428 m .4653 .43053 L .47969 .40674 L p F P
0 g
s
.55 .5 .408 .1 k
.37912 .67647 m .40558 .68428 L .4028 .71143 L p F P
0 g
s
.55 .5 .392 .1 k
.43086 .71768 m .4028 .71143 L .40558 .68428 L p F P
0 g
s
.85 .5 .442 .1 k
.44555 .42089 m .45507 .42605 L .43908 .45015 L p F P
0 g
s
.85 .5 .442 .1 k
.43908 .45015 m .42736 .44391 L .44555 .42089 L p F P
0 g
s
.517 .5 .275 .1 k
.60689 .72028 m .63537 .71488 L .63678 .74111 L p F P
0 g
s
.517 .5 .275 .1 k
.63678 .74111 m .60793 .74648 L .60689 .72028 L p F P
0 g
s
.783 .5 .458 .1 k
.39754 .46005 m .41024 .46818 L .39432 .49349 L p F P
0 g
s
.783 .5 .458 .1 k
.39432 .49349 m .37978 .48437 L .39754 .46005 L p F P
0 g
s
.75 .5 .458 .1 k
.37978 .48437 m .39432 .49349 L .37972 .51965 L p F P
0 g
s
.75 .5 .458 .1 k
.37972 .51965 m .36347 .50967 L .37978 .48437 L p F P
0 g
s
.717 .5 .458 .1 k
.36347 .50967 m .37972 .51965 L .36653 .54647 L p F P
0 g
s
.883 .5 .258 .1 k
.56025 .41094 m .56871 .40832 L .58178 .43257 L p F P
0 g
s
.883 .5 .242 .1 k
.59233 .42846 m .58178 .43257 L .56871 .40832 L p F P
0 g
s
.65 .5 .208 .1 k
.6872 .5791 m .70719 .56846 L .71782 .59576 L p F P
0 g
s
.65 .5 .208 .1 k
.71782 .59576 m .69658 .60684 L .6872 .5791 L p F P
0 g
s
.65 .5 .442 .1 k
.36679 .61168 m .34483 .60126 L .35487 .57374 L p F P
0 g
s
.617 .5 .442 .1 k
.34483 .60126 m .36679 .61168 L .35953 .63953 L p F P
0 g
s
.817 .5 .458 .1 k
.4166 .4369 m .42736 .44391 L .41024 .46818 L p F P
0 g
s
.817 .5 .458 .1 k
.41024 .46818 m .39754 .46005 L .4166 .4369 L p F P
0 g
s
.717 .5 .458 .1 k
.36653 .54647 m .34873 .53575 L .36347 .50967 L p F P
0 g
s
.683 .5 .458 .1 k
.34873 .53575 m .36653 .54647 L .35487 .57374 L p F P
0 g
s
.883 .5 .425 .1 k
.47191 .40328 m .47969 .40674 L .4653 .43053 L p F P
0 g
s
.883 .5 .425 .1 k
.4653 .43053 m .45507 .42605 L .47191 .40328 L p F P
0 g
s
.85 .5 .225 .1 k
.59233 .42846 m .60223 .42365 L .6193 .44725 L p F P
0 g
s
.85 .5 .208 .1 k
.63057 .44063 m .6193 .44725 L .60223 .42365 L p F P
0 g
s
.817 .5 .208 .1 k
.6193 .44725 m .63057 .44063 L .64865 .46438 L p F P
0 g
s
.517 .5 .392 .1 k
.4028 .71143 m .43086 .71768 L .42963 .7439 L p F P
0 g
s
.517 .5 .375 .1 k
.45882 .74849 m .42963 .7439 L .43086 .71768 L p F P
0 g
s
.55 .5 .242 .1 k
.65991 .68072 m .68583 .67215 L .68954 .69924 L p F P
0 g
s
.55 .5 .242 .1 k
.68954 .69924 m .663 .70786 L .65991 .68072 L p F P
0 g
s
.583 .5 .225 .1 k
.68059 .64451 m .70436 .63456 L .71044 .66205 L p F P
0 g
s
.583 .5 .225 .1 k
.71044 .66205 m .68583 .67215 L .68059 .64451 L p F P
0 g
s
.917 .5 .342 .1 k
.5184 .38996 m .52468 .39029 L .52391 .41529 L p F P
0 g
s
.917 .5 .342 .1 k
.52391 .41529 m .51465 .41481 L .5184 .38996 L p F P
0 g
s
.917 .5 .325 .1 k
.53319 .41514 m .52391 .41529 L .52468 .39029 L p F P
0 g
s
.783 .5 .192 .1 k
.67936 .47964 m .66546 .48923 L .64865 .46438 L p F P
0 g
s
.75 .5 .192 .1 k
.66546 .48923 m .67936 .47964 L .69645 .50449 L p F P
0 g
s
.75 .5 .192 .1 k
.69645 .50449 m .68091 .51499 L .66546 .48923 L p F P
0 g
s
.917 .5 .325 .1 k
.52468 .39029 m .53098 .39018 L .53319 .41514 L p F P
0 g
s
.917 .5 .308 .1 k
.5424 .41436 m .53319 .41514 L .53098 .39018 L p F P
0 g
s
.883 .5 .242 .1 k
.56871 .40832 m .57675 .40515 L .59233 .42846 L p F P
0 g
s
.883 .5 .225 .1 k
.60223 .42365 m .59233 .42846 L .57675 .40515 L p F P
0 g
s
.917 .5 .358 .1 k
.51221 .38919 m .5184 .38996 L .51465 .41481 L p F P
0 g
s
.917 .5 .358 .1 k
.51465 .41481 m .50551 .41371 L .51221 .38919 L p F P
0 g
s
.717 .5 .192 .1 k
.68091 .51499 m .69645 .50449 L .7119 .53018 L p F P
0 g
s
.717 .5 .192 .1 k
.7119 .53018 m .69485 .54146 L .68091 .51499 L p F P
0 g
s
.917 .5 .308 .1 k
.53098 .39018 m .53722 .38964 L .5424 .41436 L p F P
0 g
s
.917 .5 .292 .1 k
.55145 .41295 m .5424 .41436 L .53722 .38964 L p F P
0 g
s
.483 .5 .342 .1 k
.48852 .75142 m .51851 .75269 L .51849 .7776 L p F P
0 g
s
.483 .5 .325 .1 k
.51851 .75269 m .54856 .75229 L .54863 .7772 L p F P
0 g
s
.483 .5 .325 .1 k
.54863 .7772 m .51849 .7776 L .51851 .75269 L p F P
0 g
s
.817 .5 .192 .1 k
.66078 .45584 m .64865 .46438 L .63057 .44063 L p F P
0 g
s
.783 .5 .192 .1 k
.64865 .46438 m .66078 .45584 L .67936 .47964 L p F P
0 g
s
.917 .5 .375 .1 k
.50615 .38801 m .51221 .38919 L .50551 .41371 L p F P
0 g
s
.917 .5 .375 .1 k
.50551 .41371 m .49658 .41198 L .50615 .38801 L p F P
0 g
s
.483 .5 .308 .1 k
.54856 .75229 m .57845 .75022 L .5786 .77516 L p F P
0 g
s
.483 .5 .308 .1 k
.5786 .77516 m .54863 .7772 L .54856 .75229 L p F P
0 g
s
.85 .5 .458 .1 k
.43683 .41509 m .44555 .42089 L .42736 .44391 L p F P
0 g
s
.85 .5 .458 .1 k
.42736 .44391 m .4166 .4369 L .43683 .41509 L p F P
0 g
s
.517 .5 .258 .1 k
.63537 .71488 m .663 .70786 L .66477 .73412 L p F P
0 g
s
.517 .5 .258 .1 k
.66477 .73412 m .63678 .74111 L .63537 .71488 L p F P
0 g
s
.683 .5 .458 .1 k
.35487 .57374 m .33568 .56242 L .34873 .53575 L p F P
0 g
s
.65 .5 .458 .1 k
.33568 .56242 m .35487 .57374 L .34483 .60126 L p F P
0 g
s
.617 .5 .208 .1 k
.69658 .60684 m .71782 .59576 L .72662 .62317 L p F P
0 g
s
.617 .5 .208 .1 k
.72662 .62317 m .70436 .63456 L .69658 .60684 L p F P
0 g
s
.917 .5 .292 .1 k
.53722 .38964 m .54336 .38868 L .55145 .41295 L p F P
0 g
s
.917 .5 .275 .1 k
.56025 .41094 m .55145 .41295 L .54336 .38868 L p F P
0 g
s
.883 .5 .442 .1 k
.46468 .39929 m .47191 .40328 L .45507 .42605 L p F P
0 g
s
.883 .5 .442 .1 k
.45507 .42605 m .44555 .42089 L .46468 .39929 L p F P
0 g
s
.483 .5 .358 .1 k
.45882 .74849 m .48852 .75142 L .48841 .77635 L p F P
0 g
s
.483 .5 .342 .1 k
.51849 .7776 m .48841 .77635 L .48852 .75142 L p F P
0 g
s
.683 .5 .192 .1 k
.69485 .54146 m .7119 .53018 L .72558 .55654 L p F P
0 g
s
.683 .5 .192 .1 k
.72558 .55654 m .70719 .56846 L .69485 .54146 L p F P
0 g
s
.917 .5 .392 .1 k
.50031 .38641 m .50615 .38801 L .49658 .41198 L p F P
0 g
s
.917 .5 .392 .1 k
.49658 .41198 m .48794 .40965 L .50031 .38641 L p F P
0 g
s
.583 .5 .425 .1 k
.37912 .67647 m .35385 .6671 L .35953 .63953 L p F P
0 g
s
.55 .5 .425 .1 k
.35385 .6671 m .37912 .67647 L .37571 .70358 L p F P
0 g
s
.55 .5 .408 .1 k
.4028 .71143 m .37571 .70358 L .37912 .67647 L p F P
0 g
s
.483 .5 .292 .1 k
.57845 .75022 m .60793 .74648 L .60817 .77148 L p F P
0 g
s
.483 .5 .292 .1 k
.60817 .77148 m .5786 .77516 L .57845 .75022 L p F P
0 g
s
.917 .5 .275 .1 k
.54336 .38868 m .54932 .38729 L .56025 .41094 L p F P
0 g
s
.917 .5 .258 .1 k
.56871 .40832 m .56025 .41094 L .54932 .38729 L p F P
0 g
s
.617 .5 .442 .1 k
.35953 .63953 m .33652 .62883 L .34483 .60126 L p F P
0 g
s
.583 .5 .442 .1 k
.33652 .62883 m .35953 .63953 L .35385 .6671 L p F P
0 g
s
.85 .5 .208 .1 k
.60223 .42365 m .61138 .41818 L .63057 .44063 L p F P
0 g
s
.85 .5 .192 .1 k
.64083 .43326 m .63057 .44063 L .61138 .41818 L p F P
0 g
s
.817 .5 .192 .1 k
.63057 .44063 m .64083 .43326 L .66078 .45584 L p F P
0 g
s
.883 .5 .225 .1 k
.57675 .40515 m .58427 .40143 L .60223 .42365 L p F P
0 g
s
.883 .5 .208 .1 k
.61138 .41818 m .60223 .42365 L .58427 .40143 L p F P
0 g
s
.783 .5 .475 .1 k
.38607 .45108 m .39754 .46005 L .37978 .48437 L p F P
0 g
s
.783 .5 .475 .1 k
.37978 .48437 m .36662 .4743 L .38607 .45108 L p F P
0 g
s
.75 .5 .475 .1 k
.36662 .4743 m .37978 .48437 L .36347 .50967 L p F P
0 g
s
.917 .5 .408 .1 k
.49473 .38442 m .50031 .38641 L .48794 .40965 L p F P
0 g
s
.917 .5 .408 .1 k
.48794 .40965 m .47969 .40674 L .49473 .38442 L p F P
0 g
s
.817 .5 .475 .1 k
.40692 .42916 m .4166 .4369 L .39754 .46005 L p F P
0 g
s
.817 .5 .475 .1 k
.39754 .46005 m .38607 .45108 L .40692 .42916 L p F P
0 g
s
.517 .5 .408 .1 k
.37571 .70358 m .4028 .71143 L .4012 .73768 L p F P
0 g
s
.517 .5 .392 .1 k
.42963 .7439 m .4012 .73768 L .4028 .71143 L p F P
0 g
s
.75 .5 .475 .1 k
.36347 .50967 m .34873 .49863 L .36662 .4743 L p F P
0 g
s
.717 .5 .475 .1 k
.34873 .49863 m .36347 .50967 L .34873 .53575 L p F P
0 g
s
.483 .5 .375 .1 k
.42963 .7439 m .45882 .74849 L .45862 .77345 L p F P
0 g
s
.483 .5 .358 .1 k
.48841 .77635 m .45862 .77345 L .45882 .74849 L p F P
0 g
s
.917 .5 .258 .1 k
.54932 .38729 m .55504 .3855 L .56871 .40832 L p F P
0 g
s
.917 .5 .242 .1 k
.57675 .40515 m .56871 .40832 L .55504 .3855 L p F P
0 g
s
.883 .5 .458 .1 k
.45808 .39482 m .46468 .39929 L .44555 .42089 L p F P
0 g
s
.883 .5 .458 .1 k
.44555 .42089 m .43683 .41509 L .45808 .39482 L p F P
0 g
s
.65 .5 .192 .1 k
.70719 .56846 m .72558 .55654 L .73738 .58334 L p F P
0 g
s
.65 .5 .192 .1 k
.73738 .58334 m .71782 .59576 L .70719 .56846 L p F P
0 g
s
.917 .5 .425 .1 k
.48948 .38204 m .49473 .38442 L .47969 .40674 L p F P
0 g
s
.917 .5 .425 .1 k
.47969 .40674 m .47191 .40328 L .48948 .38204 L p F P
0 g
s
.65 .5 .458 .1 k
.34483 .60126 m .32444 .58948 L .33568 .56242 L p F P
0 g
s
.617 .5 .458 .1 k
.32444 .58948 m .34483 .60126 L .33652 .62883 L p F P
0 g
s
.483 .5 .275 .1 k
.60793 .74648 m .63678 .74111 L .63711 .76618 L p F P
0 g
s
.483 .5 .275 .1 k
.63711 .76618 m .60817 .77148 L .60793 .74648 L p F P
0 g
s
.55 .5 .225 .1 k
.68583 .67215 m .71044 .66205 L .71475 .68908 L p F P
0 g
s
.55 .5 .225 .1 k
.71475 .68908 m .68954 .69924 L .68583 .67215 L p F P
0 g
s
.85 .5 .475 .1 k
.42901 .40871 m .43683 .41509 L .4166 .4369 L p F P
0 g
s
.85 .5 .475 .1 k
.4166 .4369 m .40692 .42916 L .42901 .40871 L p F P
0 g
s
.717 .5 .475 .1 k
.34873 .53575 m .33254 .52388 L .34873 .49863 L p F P
0 g
s
.683 .5 .475 .1 k
.33254 .52388 m .34873 .53575 L .33568 .56242 L p F P
0 g
s
.783 .5 .175 .1 k
.6918 .46913 m .67936 .47964 L .66078 .45584 L p F P
0 g
s
.75 .5 .175 .1 k
.67936 .47964 m .6918 .46913 L .7104 .49296 L p F P
0 g
s
.75 .5 .175 .1 k
.7104 .49296 m .69645 .50449 L .67936 .47964 L p F P
0 g
s
.917 .5 .242 .1 k
.55504 .3855 m .56047 .38332 L .57675 .40515 L p F P
0 g
s
.917 .5 .225 .1 k
.58427 .40143 m .57675 .40515 L .56047 .38332 L p F P
0 g
s
.817 .5 .175 .1 k
.6716 .44649 m .66078 .45584 L .64083 .43326 L p F P
0 g
s
.783 .5 .175 .1 k
.66078 .45584 m .6716 .44649 L .6918 .46913 L p F P
0 g
s
.517 .5 .242 .1 k
.663 .70786 m .68954 .69924 L .69166 .72554 L p F P
0 g
s
.517 .5 .242 .1 k
.69166 .72554 m .66477 .73412 L .663 .70786 L p F P
0 g
s
.583 .5 .208 .1 k
.70436 .63456 m .72662 .62317 L .73351 .65046 L p F P
0 g
s
.583 .5 .208 .1 k
.73351 .65046 m .71044 .66205 L .70436 .63456 L p F P
0 g
s
.883 .5 .208 .1 k
.58427 .40143 m .59121 .3972 L .61138 .41818 L p F P
0 g
s
.883 .5 .192 .1 k
.61968 .41209 m .61138 .41818 L .59121 .3972 L p F P
0 g
s
.85 .5 .192 .1 k
.61138 .41818 m .61968 .41209 L .64083 .43326 L p F P
0 g
s
.717 .5 .175 .1 k
.69645 .50449 m .7104 .49296 L .72724 .51779 L p F P
0 g
s
.717 .5 .175 .1 k
.72724 .51779 m .7119 .53018 L .69645 .50449 L p F P
0 g
s
.483 .5 .392 .1 k
.4012 .73768 m .42963 .7439 L .42935 .76893 L p F P
0 g
s
.483 .5 .375 .1 k
.45862 .77345 m .42935 .76893 L .42963 .7439 L p F P
0 g
s
.917 .5 .442 .1 k
.48462 .37931 m .48948 .38204 L .47191 .40328 L p F P
0 g
s
.917 .5 .442 .1 k
.47191 .40328 m .46468 .39929 L .48462 .37931 L p F P
0 g
s
.85 .5 .175 .1 k
.64995 .4252 m .64083 .43326 L .61968 .41209 L p F P
0 g
s
.817 .5 .175 .1 k
.64083 .43326 m .64995 .4252 L .6716 .44649 L p F P
0 g
s
.883 .5 .475 .1 k
.45217 .38991 m .45808 .39482 L .43683 .41509 L p F P
0 g
s
.883 .5 .475 .1 k
.43683 .41509 m .42901 .40871 L .45217 .38991 L p F P
0 g
s
.917 .5 .225 .1 k
.56047 .38332 m .56554 .38077 L .58427 .40143 L p F P
0 g
s
.917 .5 .208 .1 k
.59121 .3972 m .58427 .40143 L .56554 .38077 L p F P
0 g
s
.683 .5 .475 .1 k
.33568 .56242 m .3182 .54988 L .33254 .52388 L p F P
0 g
s
.65 .5 .475 .1 k
.3182 .54988 m .33568 .56242 L .32444 .58948 L p F P
0 g
s
.583 .5 .442 .1 k
.35385 .6671 m .33001 .65622 L .33652 .62883 L p F P
0 g
s
.55 .5 .442 .1 k
.33001 .65622 m .35385 .6671 L .34983 .69416 L p F P
0 g
s
.55 .5 .425 .1 k
.37571 .70358 m .34983 .69416 L .35385 .6671 L p F P
0 g
s
.617 .5 .192 .1 k
.71782 .59576 m .73738 .58334 L .74716 .61039 L p F P
0 g
s
.617 .5 .192 .1 k
.74716 .61039 m .72662 .62317 L .71782 .59576 L p F P
0 g
s
.817 .5 .492 .1 k
.39842 .42077 m .40692 .42916 L .38607 .45108 L p F P
0 g
s
.817 .5 .492 .1 k
.38607 .45108 m .37597 .44134 L .39842 .42077 L p F P
0 g
s
.783 .5 .492 .1 k
.37597 .44134 m .38607 .45108 L .36662 .4743 L p F P
0 g
s
.95 .5 .342 .1 k
.5223 .36659 m .52549 .36676 L .52468 .39029 L p F P
0 g
s
.95 .5 .342 .1 k
.52468 .39029 m .5184 .38996 L .5223 .36659 L p F P
0 g
s
.95 .5 .325 .1 k
.53098 .39018 m .52468 .39029 L .52549 .36676 L p F P
0 g
s
.483 .5 .258 .1 k
.63678 .74111 m .66477 .73412 L .66518 .75928 L p F P
0 g
s
.483 .5 .258 .1 k
.66518 .75928 m .63711 .76618 L .63678 .74111 L p F P
0 g
s
.517 .5 .425 .1 k
.34983 .69416 m .37571 .70358 L .37375 .72986 L p F P
0 g
s
.517 .5 .408 .1 k
.4012 .73768 m .37375 .72986 L .37571 .70358 L p F P
0 g
s
.95 .5 .325 .1 k
.52549 .36676 m .52868 .36671 L .53098 .39018 L p F P
0 g
s
.95 .5 .308 .1 k
.53722 .38964 m .53098 .39018 L .52868 .36671 L p F P
0 g
s
.683 .5 .175 .1 k
.7119 .53018 m .72724 .51779 L .74217 .54343 L p F P
0 g
s
.683 .5 .175 .1 k
.74217 .54343 m .72558 .55654 L .7119 .53018 L p F P
0 g
s
.783 .5 .492 .1 k
.36662 .4743 m .355 .46334 L .37597 .44134 L p F P
0 g
s
.75 .5 .492 .1 k
.355 .46334 m .36662 .4743 L .34873 .49863 L p F P
0 g
s
.95 .5 .358 .1 k
.51916 .3662 m .5223 .36659 L .5184 .38996 L p F P
0 g
s
.95 .5 .358 .1 k
.5184 .38996 m .51221 .38919 L .51916 .3662 L p F P
0 g
s
.95 .5 .308 .1 k
.52868 .36671 m .53185 .36643 L .53722 .38964 L p F P
0 g
s
.95 .5 .292 .1 k
.54336 .38868 m .53722 .38964 L .53185 .36643 L p F P
0 g
s
.917 .5 .458 .1 k
.48019 .37626 m .48462 .37931 L .46468 .39929 L p F P
0 g
s
.917 .5 .458 .1 k
.46468 .39929 m .45808 .39482 L .48019 .37626 L p F P
0 g
s
.95 .5 .375 .1 k
.51609 .36559 m .51916 .3662 L .51221 .38919 L p F P
0 g
s
.95 .5 .375 .1 k
.51221 .38919 m .50615 .38801 L .51609 .36559 L p F P
0 g
s
.45 .5 .342 .1 k
.48841 .77635 m .51849 .7776 L .51855 .80101 L p F P
0 g
s
.45 .5 .325 .1 k
.51849 .7776 m .54863 .7772 L .54847 .80062 L p F P
0 g
s
.45 .5 .325 .1 k
.54847 .80062 m .51855 .80101 L .51849 .7776 L p F P
0 g
s
.85 .5 .492 .1 k
.42218 .40181 m .42901 .40871 L .40692 .42916 L p F P
0 g
s
.85 .5 .492 .1 k
.40692 .42916 m .39842 .42077 L .42218 .40181 L p F P
0 g
s
.883 .5 .192 .1 k
.59121 .3972 m .59749 .39251 L .61968 .41209 L p F P
0 g
s
.883 .5 .175 .1 k
.62704 .40545 m .61968 .41209 L .59749 .39251 L p F P
0 g
s
.85 .5 .175 .1 k
.61968 .41209 m .62704 .40545 L .64995 .4252 L p F P
0 g
s
.95 .5 .292 .1 k
.53185 .36643 m .53496 .36593 L .54336 .38868 L p F P
0 g
s
.95 .5 .275 .1 k
.54932 .38729 m .54336 .38868 L .53496 .36593 L p F P
0 g
s
.617 .5 .458 .1 k
.33652 .62883 m .31512 .61671 L .32444 .58948 L p F P
0 g
s
.583 .5 .458 .1 k
.31512 .61671 m .33652 .62883 L .33001 .65622 L p F P
0 g
s
.45 .5 .308 .1 k
.54863 .7772 m .5786 .77516 L .57823 .79862 L p F P
0 g
s
.45 .5 .308 .1 k
.57823 .79862 m .54847 .80062 L .54863 .7772 L p F P
0 g
s
.95 .5 .392 .1 k
.51313 .36477 m .51609 .36559 L .50615 .38801 L p F P
0 g
s
.95 .5 .392 .1 k
.50615 .38801 m .50031 .38641 L .51313 .36477 L p F P
0 g
s
.75 .5 .492 .1 k
.34873 .49863 m .33567 .4866 L .355 .46334 L p F P
0 g
s
.717 .5 .492 .1 k
.33567 .4866 m .34873 .49863 L .33254 .52388 L p F P
0 g
s
.917 .5 .208 .1 k
.56554 .38077 m .5702 .37788 L .59121 .3972 L p F P
0 g
s
.917 .5 .192 .1 k
.59749 .39251 m .59121 .3972 L .5702 .37788 L p F P
0 g
s
.45 .5 .358 .1 k
.45862 .77345 m .48841 .77635 L .48868 .79978 L p F P
0 g
s
.45 .5 .342 .1 k
.51855 .80101 m .48868 .79978 L .48841 .77635 L p F P
0 g
s
.95 .5 .275 .1 k
.53496 .36593 m .53798 .36522 L .54932 .38729 L p F P
0 g
s
.95 .5 .258 .1 k
.55504 .3855 m .54932 .38729 L .53798 .36522 L p F P
0 g
s
.95 .5 .408 .1 k
.51031 .36375 m .51313 .36477 L .50031 .38641 L p F P
0 g
s
.95 .5 .408 .1 k
.50031 .38641 m .49473 .38442 L .51031 .36375 L p F P
0 g
s
.483 .5 .408 .1 k
.37375 .72986 m .4012 .73768 L .40083 .7628 L p F P
0 g
s
.483 .5 .392 .1 k
.42935 .76893 m .40083 .7628 L .4012 .73768 L p F P
0 g
s
.45 .5 .292 .1 k
.5786 .77516 m .60817 .77148 L .60759 .79503 L p F P
0 g
s
.45 .5 .292 .1 k
.60759 .79503 m .57823 .79862 L .5786 .77516 L p F P
0 g
s
.817 .5 .158 .1 k
.68099 .43641 m .6716 .44649 L .64995 .4252 L p F P
0 g
s
.783 .5 .158 .1 k
.6716 .44649 m .68099 .43641 L .70264 .45778 L p F P
0 g
s
.783 .5 .158 .1 k
.70264 .45778 m .6918 .46913 L .6716 .44649 L p F P
0 g
s
.95 .5 .258 .1 k
.53798 .36522 m .54088 .3643 L .55504 .3855 L p F P
0 g
s
.95 .5 .242 .1 k
.56047 .38332 m .55504 .3855 L .54088 .3643 L p F P
0 g
s
.883 .5 .492 .1 k
.44704 .38459 m .45217 .38991 L .42901 .40871 L p F P
0 g
s
.883 .5 .492 .1 k
.42901 .40871 m .42218 .40181 L .44704 .38459 L p F P
0 g
s
.917 .5 .475 .1 k
.47624 .3729 m .48019 .37626 L .45808 .39482 L p F P
0 g
s
.917 .5 .475 .1 k
.45808 .39482 m .45217 .38991 L .47624 .3729 L p F P
0 g
s
.55 .5 .208 .1 k
.71044 .66205 m .73351 .65046 L .7384 .67742 L p F P
0 g
s
.55 .5 .208 .1 k
.7384 .67742 m .71475 .68908 L .71044 .66205 L p F P
0 g
s
.517 .5 .225 .1 k
.68954 .69924 m .71475 .68908 L .71722 .71542 L p F P
0 g
s
.517 .5 .225 .1 k
.71722 .71542 m .69166 .72554 L .68954 .69924 L p F P
0 g
s
.85 .5 .158 .1 k
.65784 .41653 m .64995 .4252 L .62704 .40545 L p F P
0 g
s
.817 .5 .158 .1 k
.64995 .4252 m .65784 .41653 L .68099 .43641 L p F P
0 g
s
.75 .5 .158 .1 k
.6918 .46913 m .70264 .45778 L .7226 .4805 L p F P
0 g
s
.75 .5 .158 .1 k
.7226 .4805 m .7104 .49296 L .6918 .46913 L p F P
0 g
s
.65 .5 .175 .1 k
.72558 .55654 m .74217 .54343 L .75505 .56967 L p F P
0 g
s
.65 .5 .175 .1 k
.75505 .56967 m .73738 .58334 L .72558 .55654 L p F P
0 g
s
.95 .5 .425 .1 k
.50766 .36253 m .51031 .36375 L .49473 .38442 L p F P
0 g
s
.95 .5 .425 .1 k
.49473 .38442 m .48948 .38204 L .50766 .36253 L p F P
0 g
s
.65 .5 .475 .1 k
.32444 .58948 m .30584 .5764 L .3182 .54988 L p F P
0 g
s
.617 .5 .475 .1 k
.30584 .5764 m .32444 .58948 L .31512 .61671 L p F P
0 g
s
.45 .5 .375 .1 k
.42935 .76893 m .45862 .77345 L .4591 .79696 L p F P
0 g
s
.45 .5 .358 .1 k
.48868 .79978 m .4591 .79696 L .45862 .77345 L p F P
0 g
s
.717 .5 .492 .1 k
.33254 .52388 m .31816 .51095 L .33567 .4866 L p F P
0 g
s
.683 .5 .492 .1 k
.31816 .51095 m .33254 .52388 L .3182 .54988 L p F P
0 g
s
.95 .5 .242 .1 k
.54088 .3643 m .54362 .36319 L .56047 .38332 L p F P
0 g
s
.95 .5 .225 .1 k
.56554 .38077 m .56047 .38332 L .54362 .36319 L p F P
0 g
s
.917 .5 .192 .1 k
.5702 .37788 m .57441 .37468 L .59749 .39251 L p F P
0 g
s
.917 .5 .175 .1 k
.60303 .3874 m .59749 .39251 L .57441 .37468 L p F P
0 g
s
.883 .5 .175 .1 k
.59749 .39251 m .60303 .3874 L .62704 .40545 L p F P
0 g
s
.883 .5 .158 .1 k
.63337 .39832 m .62704 .40545 L .60303 .3874 L p F P
0 g
s
.85 .5 .158 .1 k
.62704 .40545 m .63337 .39832 L .65784 .41653 L p F P
0 g
s
.583 .5 .192 .1 k
.72662 .62317 m .74716 .61039 L .75481 .63746 L p F P
0 g
s
.583 .5 .192 .1 k
.75481 .63746 m .73351 .65046 L .72662 .62317 L p F P
0 g
s
.95 .5 .442 .1 k
.50521 .36114 m .50766 .36253 L .48948 .38204 L p F P
0 g
s
.95 .5 .442 .1 k
.48948 .38204 m .48462 .37931 L .50521 .36114 L p F P
0 g
s
.483 .5 .242 .1 k
.66477 .73412 m .69166 .72554 L .69215 .75082 L p F P
0 g
s
.483 .5 .242 .1 k
.69215 .75082 m .66518 .75928 L .66477 .73412 L p F P
0 g
s
.717 .5 .158 .1 k
.7104 .49296 m .7226 .4805 L .74069 .50437 L p F P
0 g
s
.717 .5 .158 .1 k
.74069 .50437 m .72724 .51779 L .7104 .49296 L p F P
0 g
s
.45 .5 .275 .1 k
.60817 .77148 m .63711 .76618 L .63632 .78985 L p F P
0 g
s
.45 .5 .275 .1 k
.63632 .78985 m .60759 .79503 L .60817 .77148 L p F P
0 g
s
.95 .5 .225 .1 k
.54362 .36319 m .54617 .36188 L .56554 .38077 L p F P
0 g
s
.95 .5 .208 .1 k
.5702 .37788 m .56554 .38077 L .54617 .36188 L p F P
0 g
s
.817 .5 .508 .1 k
.39122 .41181 m .39842 .42077 L .37597 .44134 L p F P
0 g
s
.817 .5 .508 .1 k
.37597 .44134 m .36737 .43092 L .39122 .41181 L p F P
0 g
s
.783 .5 .508 .1 k
.36737 .43092 m .37597 .44134 L .355 .46334 L p F P
0 g
s
.85 .5 .508 .1 k
.41641 .39444 m .42218 .40181 L .39842 .42077 L p F P
0 g
s
.85 .5 .508 .1 k
.39842 .42077 m .39122 .41181 L .41641 .39444 L p F P
0 g
s
.917 .5 .492 .1 k
.47282 .36929 m .47624 .3729 L .45217 .38991 L p F P
0 g
s
.917 .5 .492 .1 k
.45217 .38991 m .44704 .38459 L .47282 .36929 L p F P
0 g
s
.95 .5 .458 .1 k
.50299 .35958 m .50521 .36114 L .48462 .37931 L p F P
0 g
s
.95 .5 .458 .1 k
.48462 .37931 m .48019 .37626 L .50299 .35958 L p F P
0 g
s
.55 .5 .442 .1 k
.34983 .69416 m .3254 .68321 L .33001 .65622 L p F P
0 g
s
.517 .5 .442 .1 k
.3254 .68321 m .34983 .69416 L .34752 .72048 L p F P
0 g
s
.517 .5 .425 .1 k
.37375 .72986 m .34752 .72048 L .34983 .69416 L p F P
0 g
s
.783 .5 .508 .1 k
.355 .46334 m .34505 .4516 L .36737 .43092 L p F P
0 g
s
.75 .5 .508 .1 k
.34505 .4516 m .355 .46334 L .33567 .4866 L p F P
0 g
s
.883 .5 .508 .1 k
.44273 .37894 m .44704 .38459 L .42218 .40181 L p F P
0 g
s
.883 .5 .508 .1 k
.42218 .40181 m .41641 .39444 L .44273 .37894 L p F P
0 g
s
.583 .5 .458 .1 k
.33001 .65622 m .30783 .64389 L .31512 .61671 L p F P
0 g
s
.55 .5 .458 .1 k
.30783 .64389 m .33001 .65622 L .3254 .68321 L p F P
0 g
s
.45 .5 .392 .1 k
.40083 .7628 m .42935 .76893 L .43004 .79254 L p F P
0 g
s
.45 .5 .375 .1 k
.4591 .79696 m .43004 .79254 L .42935 .76893 L p F P
0 g
s
.95 .5 .208 .1 k
.54617 .36188 m .54852 .36041 L .5702 .37788 L p F P
0 g
s
.95 .5 .192 .1 k
.57441 .37468 m .5702 .37788 L .54852 .36041 L p F P
0 g
s
.917 .5 .175 .1 k
.57441 .37468 m .57811 .3712 L .60303 .3874 L p F P
0 g
s
.917 .5 .158 .1 k
.60777 .38191 m .60303 .3874 L .57811 .3712 L p F P
0 g
s
.883 .5 .158 .1 k
.60303 .3874 m .60777 .38191 L .63337 .39832 L p F P
0 g
s
.683 .5 .492 .1 k
.3182 .54988 m .30263 .53618 L .31816 .51095 L p F P
0 g
s
.65 .5 .492 .1 k
.30263 .53618 m .3182 .54988 L .30584 .5764 L p F P
0 g
s
.617 .5 .175 .1 k
.73738 .58334 m .75505 .56967 L .76574 .59631 L p F P
0 g
s
.617 .5 .175 .1 k
.76574 .59631 m .74716 .61039 L .73738 .58334 L p F P
0 g
s
.683 .5 .158 .1 k
.72724 .51779 m .74069 .50437 L .75675 .52922 L p F P
0 g
s
.683 .5 .158 .1 k
.75675 .52922 m .74217 .54343 L .72724 .51779 L p F P
0 g
s
.483 .5 .425 .1 k
.34752 .72048 m .37375 .72986 L .3733 .75508 L p F P
0 g
s
.483 .5 .408 .1 k
.40083 .7628 m .3733 .75508 L .37375 .72986 L p F P
0 g
s
.95 .5 .475 .1 k
.50102 .35787 m .50299 .35958 L .48019 .37626 L p F P
0 g
s
.95 .5 .475 .1 k
.48019 .37626 m .47624 .3729 L .50102 .35787 L p F P
0 g
s
.85 .5 .142 .1 k
.66438 .40732 m .65784 .41653 L .63337 .39832 L p F P
0 g
s
.817 .5 .142 .1 k
.65784 .41653 m .66438 .40732 L .68883 .42568 L p F P
0 g
s
.817 .5 .142 .1 k
.68883 .42568 m .68099 .43641 L .65784 .41653 L p F P
0 g
s
.783 .5 .142 .1 k
.68099 .43641 m .68883 .42568 L .71173 .4457 L p F P
0 g
s
.783 .5 .142 .1 k
.71173 .4457 m .70264 .45778 L .68099 .43641 L p F P
0 g
s
.883 .5 .142 .1 k
.63859 .39075 m .63337 .39832 L .60777 .38191 L p F P
0 g
s
.85 .5 .142 .1 k
.63337 .39832 m .63859 .39075 L .66438 .40732 L p F P
0 g
s
.75 .5 .508 .1 k
.33567 .4866 m .32445 .47369 L .34505 .4516 L p F P
0 g
s
.717 .5 .508 .1 k
.32445 .47369 m .33567 .4866 L .31816 .51095 L p F P
0 g
s
.917 .5 .508 .1 k
.46997 .36545 m .47282 .36929 L .44704 .38459 L p F P
0 g
s
.917 .5 .508 .1 k
.44704 .38459 m .44273 .37894 L .46997 .36545 L p F P
0 g
s
.95 .5 .192 .1 k
.54852 .36041 m .55062 .35877 L .57441 .37468 L p F P
0 g
s
.95 .5 .175 .1 k
.57811 .3712 m .57441 .37468 L .55062 .35877 L p F P
0 g
s
.617 .5 .475 .1 k
.31512 .61671 m .29557 .60324 L .30584 .5764 L p F P
0 g
s
.583 .5 .475 .1 k
.29557 .60324 m .31512 .61671 L .30783 .64389 L p F P
0 g
s
.45 .5 .258 .1 k
.63711 .76618 m .66518 .75928 L .66419 .78311 L p F P
0 g
s
.45 .5 .258 .1 k
.66419 .78311 m .63632 .78985 L .63711 .76618 L p F P
0 g
s
.95 .5 .492 .1 k
.49932 .35603 m .50102 .35787 L .47624 .3729 L p F P
0 g
s
.95 .5 .492 .1 k
.47624 .3729 m .47282 .36929 L .49932 .35603 L p F P
0 g
s
.517 .5 .208 .1 k
.71475 .68908 m .7384 .67742 L .7412 .70381 L p F P
0 g
s
.517 .5 .208 .1 k
.7412 .70381 m .71722 .71542 L .71475 .68908 L p F P
0 g
s
.983 .5 .342 .1 k
.52549 .36676 m .5223 .36659 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .325 .1 k
.52868 .36671 m .52549 .36676 L .52632 .34495 L closepath p F P
0 g
s
.75 .5 .142 .1 k
.70264 .45778 m .71173 .4457 L .73287 .4672 L p F P
0 g
s
.75 .5 .142 .1 k
.73287 .4672 m .7226 .4805 L .70264 .45778 L p F P
0 g
s
.983 .5 .308 .1 k
.53185 .36643 m .52868 .36671 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .358 .1 k
.5223 .36659 m .51916 .3662 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .292 .1 k
.53496 .36593 m .53185 .36643 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .375 .1 k
.51916 .3662 m .51609 .36559 L .52632 .34495 L closepath p F P
0 g
s
.917 .5 .158 .1 k
.57811 .3712 m .58126 .36747 L .60777 .38191 L p F P
0 g
s
.917 .5 .142 .1 k
.61166 .37611 m .60777 .38191 L .58126 .36747 L p F P
0 g
s
.883 .5 .142 .1 k
.60777 .38191 m .61166 .37611 L .63859 .39075 L p F P
0 g
s
.983 .5 .275 .1 k
.53798 .36522 m .53496 .36593 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .392 .1 k
.51609 .36559 m .51313 .36477 L .52632 .34495 L closepath p F P
0 g
s
.55 .5 .192 .1 k
.73351 .65046 m .75481 .63746 L .76025 .66434 L p F P
0 g
s
.55 .5 .192 .1 k
.76025 .66434 m .7384 .67742 L .73351 .65046 L p F P
0 g
s
.95 .5 .175 .1 k
.55062 .35877 m .55247 .357 L .57811 .3712 L p F P
0 g
s
.95 .5 .158 .1 k
.58126 .36747 m .57811 .3712 L .55247 .357 L p F P
0 g
s
.85 .5 .525 .1 k
.41179 .38669 m .41641 .39444 L .39122 .41181 L p F P
0 g
s
.85 .5 .525 .1 k
.39122 .41181 m .38541 .40236 L .41179 .38669 L p F P
0 g
s
.817 .5 .525 .1 k
.38541 .40236 m .39122 .41181 L .36737 .43092 L p F P
0 g
s
.417 .5 .342 .1 k
.48868 .79978 m .51855 .80101 L .51868 .82268 L p F P
0 g
s
.417 .5 .325 .1 k
.51855 .80101 m .54847 .80062 L .54809 .82231 L p F P
0 g
s
.417 .5 .325 .1 k
.54809 .82231 m .51868 .82268 L .51855 .80101 L p F P
0 g
s
.983 .5 .258 .1 k
.54088 .3643 m .53798 .36522 L .52632 .34495 L closepath p F P
0 g
s
.483 .5 .225 .1 k
.69166 .72554 m .71722 .71542 L .71779 .74084 L p F P
0 g
s
.483 .5 .225 .1 k
.71779 .74084 m .69215 .75082 L .69166 .72554 L p F P
0 g
s
.883 .5 .525 .1 k
.43931 .373 m .44273 .37894 L .41641 .39444 L p F P
0 g
s
.883 .5 .525 .1 k
.41641 .39444 m .41179 .38669 L .43931 .373 L p F P
0 g
s
.983 .5 .408 .1 k
.51313 .36477 m .51031 .36375 L .52632 .34495 L closepath p F P
0 g
s
.417 .5 .308 .1 k
.54847 .80062 m .57823 .79862 L .57733 .82038 L p F P
0 g
s
.417 .5 .308 .1 k
.57733 .82038 m .54809 .82231 L .54847 .80062 L p F P
0 g
s
.983 .5 .242 .1 k
.54362 .36319 m .54088 .3643 L .52632 .34495 L closepath p F P
0 g
s
.45 .5 .408 .1 k
.3733 .75508 m .40083 .7628 L .40173 .78655 L p F P
0 g
s
.45 .5 .392 .1 k
.43004 .79254 m .40173 .78655 L .40083 .7628 L p F P
0 g
s
.65 .5 .158 .1 k
.74217 .54343 m .75675 .52922 L .77062 .55484 L p F P
0 g
s
.65 .5 .158 .1 k
.77062 .55484 m .75505 .56967 L .74217 .54343 L p F P
0 g
s
.983 .5 .425 .1 k
.51031 .36375 m .50766 .36253 L .52632 .34495 L closepath p F P
0 g
s
.417 .5 .358 .1 k
.4591 .79696 m .48868 .79978 L .48933 .8215 L p F P
0 g
s
.417 .5 .342 .1 k
.51868 .82268 m .48933 .8215 L .48868 .79978 L p F P
0 g
s
.817 .5 .525 .1 k
.36737 .43092 m .36038 .4199 L .38541 .40236 L p F P
0 g
s
.783 .5 .525 .1 k
.36038 .4199 m .36737 .43092 L .34505 .4516 L p F P
0 g
s
.717 .5 .508 .1 k
.31816 .51095 m .30577 .49704 L .32445 .47369 L p F P
0 g
s
.683 .5 .508 .1 k
.30577 .49704 m .31816 .51095 L .30263 .53618 L p F P
0 g
s
.95 .5 .508 .1 k
.49791 .35408 m .49932 .35603 L .47282 .36929 L p F P
0 g
s
.95 .5 .508 .1 k
.47282 .36929 m .46997 .36545 L .49791 .35408 L p F P
0 g
s
.983 .5 .225 .1 k
.54617 .36188 m .54362 .36319 L .52632 .34495 L closepath p F P
0 g
s
.917 .5 .525 .1 k
.46772 .36142 m .46997 .36545 L .44273 .37894 L p F P
0 g
s
.917 .5 .525 .1 k
.44273 .37894 m .43931 .373 L .46772 .36142 L p F P
0 g
s
.65 .5 .492 .1 k
.30584 .5764 m .28923 .56211 L .30263 .53618 L p F P
0 g
s
.617 .5 .492 .1 k
.28923 .56211 m .30584 .5764 L .29557 .60324 L p F P
0 g
s
.983 .5 .442 .1 k
.50766 .36253 m .50521 .36114 L .52632 .34495 L closepath p F P
0 g
s
.717 .5 .142 .1 k
.7226 .4805 m .73287 .4672 L .75207 .49004 L p F P
0 g
s
.717 .5 .142 .1 k
.75207 .49004 m .74069 .50437 L .7226 .4805 L p F P
0 g
s
.417 .5 .292 .1 k
.57823 .79862 m .60759 .79503 L .60617 .8169 L p F P
0 g
s
.417 .5 .292 .1 k
.60617 .8169 m .57733 .82038 L .57823 .79862 L p F P
0 g
s
.983 .5 .208 .1 k
.54852 .36041 m .54617 .36188 L .52632 .34495 L closepath p F P
0 g
s
.95 .5 .158 .1 k
.55247 .357 m .55403 .3551 L .58126 .36747 L p F P
0 g
s
.95 .5 .142 .1 k
.58382 .36353 m .58126 .36747 L .55403 .3551 L p F P
0 g
s
.917 .5 .142 .1 k
.58126 .36747 m .58382 .36353 L .61166 .37611 L p F P
0 g
s
.583 .5 .175 .1 k
.74716 .61039 m .76574 .59631 L .77411 .62313 L p F P
0 g
s
.583 .5 .175 .1 k
.77411 .62313 m .75481 .63746 L .74716 .61039 L p F P
0 g
s
.883 .5 .125 .1 k
.64263 .38284 m .63859 .39075 L .61166 .37611 L p F P
0 g
s
.85 .5 .125 .1 k
.63859 .39075 m .64263 .38284 L .6695 .39767 L p F P
0 g
s
.85 .5 .125 .1 k
.6695 .39767 m .66438 .40732 L .63859 .39075 L p F P
0 g
s
.983 .5 .458 .1 k
.50521 .36114 m .50299 .35958 L .52632 .34495 L closepath p F P
0 g
s
.817 .5 .125 .1 k
.66438 .40732 m .6695 .39767 L .69501 .41442 L p F P
0 g
s
.817 .5 .125 .1 k
.69501 .41442 m .68883 .42568 L .66438 .40732 L p F P
0 g
s
.983 .5 .192 .1 k
.55062 .35877 m .54852 .36041 L .52632 .34495 L closepath p F P
0 g
s
.917 .5 .125 .1 k
.61465 .37006 m .61166 .37611 L .58382 .36353 L p F P
0 g
s
.883 .5 .125 .1 k
.61166 .37611 m .61465 .37006 L .64263 .38284 L p F P
0 g
s
.783 .5 .525 .1 k
.34505 .4516 m .33691 .43917 L .36038 .4199 L p F P
0 g
s
.75 .5 .525 .1 k
.33691 .43917 m .34505 .4516 L .32445 .47369 L p F P
0 g
s
.417 .5 .375 .1 k
.43004 .79254 m .4591 .79696 L .46027 .81876 L p F P
0 g
s
.417 .5 .358 .1 k
.48933 .8215 m .46027 .81876 L .4591 .79696 L p F P
0 g
s
.45 .5 .242 .1 k
.66518 .75928 m .69215 .75082 L .69096 .77485 L p F P
0 g
s
.45 .5 .242 .1 k
.69096 .77485 m .66419 .78311 L .66518 .75928 L p F P
0 g
s
.55 .5 .458 .1 k
.3254 .68321 m .30265 .6708 L .30783 .64389 L p F P
0 g
s
.517 .5 .458 .1 k
.30265 .6708 m .3254 .68321 L .32275 .70957 L p F P
0 g
s
.517 .5 .442 .1 k
.34752 .72048 m .32275 .70957 L .3254 .68321 L p F P
0 g
s
.983 .5 .475 .1 k
.50299 .35958 m .50102 .35787 L .52632 .34495 L closepath p F P
0 g
s
.95 .5 .525 .1 k
.4968 .35204 m .49791 .35408 L .46997 .36545 L p F P
0 g
s
.95 .5 .525 .1 k
.46997 .36545 m .46772 .36142 L .4968 .35204 L p F P
0 g
s
.483 .5 .442 .1 k
.32275 .70957 m .34752 .72048 L .34699 .74583 L p F P
0 g
s
.483 .5 .425 .1 k
.3733 .75508 m .34699 .74583 L .34752 .72048 L p F P
0 g
s
.983 .5 .175 .1 k
.55247 .357 m .55062 .35877 L .52632 .34495 L closepath p F P
0 g
s
.783 .5 .125 .1 k
.68883 .42568 m .69501 .41442 L .71895 .43298 L p F P
0 g
s
.783 .5 .125 .1 k
.71895 .43298 m .71173 .4457 L .68883 .42568 L p F P
0 g
s
.983 .5 .492 .1 k
.50102 .35787 m .49932 .35603 L .52632 .34495 L closepath p F P
0 g
s
.583 .5 .475 .1 k
.30783 .64389 m .28754 .63019 L .29557 .60324 L p F P
0 g
s
.55 .5 .475 .1 k
.28754 .63019 m .30783 .64389 L .30265 .6708 L p F P
0 g
s
.95 .5 .142 .1 k
.55403 .3551 m .55529 .35311 L .58382 .36353 L p F P
0 g
s
.95 .5 .125 .1 k
.58577 .35942 m .58382 .36353 L .55529 .35311 L p F P
0 g
s
.917 .5 .125 .1 k
.58382 .36353 m .58577 .35942 L .61465 .37006 L p F P
0 g
s
.417 .5 .275 .1 k
.60759 .79503 m .63632 .78985 L .63439 .81189 L p F P
0 g
s
.417 .5 .275 .1 k
.63439 .81189 m .60617 .8169 L .60759 .79503 L p F P
0 g
s
.883 .5 .542 .1 k
.4368 .36683 m .43931 .373 L .41179 .38669 L p F P
0 g
s
.883 .5 .542 .1 k
.41179 .38669 m .40838 .37862 L .4368 .36683 L p F P
0 g
s
.85 .5 .542 .1 k
.40838 .37862 m .41179 .38669 L .38541 .40236 L p F P
0 g
s
.917 .5 .542 .1 k
.4661 .35724 m .46772 .36142 L .43931 .373 L p F P
0 g
s
.917 .5 .542 .1 k
.43931 .373 m .4368 .36683 L .4661 .35724 L p F P
0 g
s
.983 .5 .158 .1 k
.55403 .3551 m .55247 .357 L .52632 .34495 L closepath p F P
0 g
s
.683 .5 .142 .1 k
.74069 .50437 m .75207 .49004 L .76913 .51402 L p F P
0 g
s
.683 .5 .142 .1 k
.76913 .51402 m .75675 .52922 L .74069 .50437 L p F P
0 g
s
.683 .5 .508 .1 k
.30263 .53618 m .28917 .52144 L .30577 .49704 L p F P
0 g
s
.65 .5 .508 .1 k
.28917 .52144 m .30263 .53618 L .28923 .56211 L p F P
0 g
s
.983 .5 .508 .1 k
.49932 .35603 m .49791 .35408 L .52632 .34495 L closepath p F P
0 g
s
.617 .5 .158 .1 k
.75505 .56967 m .77062 .55484 L .78214 .58102 L p F P
0 g
s
.617 .5 .158 .1 k
.78214 .58102 m .76574 .59631 L .75505 .56967 L p F P
0 g
s
.85 .5 .542 .1 k
.38541 .40236 m .38106 .39251 L .40838 .37862 L p F P
0 g
s
.817 .5 .542 .1 k
.38106 .39251 m .38541 .40236 L .36038 .4199 L p F P
0 g
s
.95 .5 .542 .1 k
.49602 .34992 m .4968 .35204 L .46772 .36142 L p F P
0 g
s
.95 .5 .542 .1 k
.46772 .36142 m .4661 .35724 L .49602 .34992 L p F P
0 g
s
.75 .5 .525 .1 k
.32445 .47369 m .31523 .46001 L .33691 .43917 L p F P
0 g
s
.717 .5 .525 .1 k
.31523 .46001 m .32445 .47369 L .30577 .49704 L p F P
0 g
s
.983 .5 .142 .1 k
.55529 .35311 m .55403 .3551 L .52632 .34495 L closepath p F P
0 g
s
.45 .5 .425 .1 k
.34699 .74583 m .3733 .75508 L .3744 .77901 L p F P
0 g
s
.45 .5 .408 .1 k
.40173 .78655 m .3744 .77901 L .3733 .75508 L p F P
0 g
s
.417 .5 .392 .1 k
.40173 .78655 m .43004 .79254 L .43172 .81449 L p F P
0 g
s
.417 .5 .375 .1 k
.46027 .81876 m .43172 .81449 L .43004 .79254 L p F P
0 g
s
.917 .5 .108 .1 k
.61669 .3638 m .61465 .37006 L .58577 .35942 L p F P
0 g
s
.883 .5 .108 .1 k
.61465 .37006 m .61669 .3638 L .64545 .37465 L p F P
0 g
s
.883 .5 .108 .1 k
.64545 .37465 m .64263 .38284 L .61465 .37006 L p F P
0 g
s
.983 .5 .525 .1 k
.49791 .35408 m .4968 .35204 L .52632 .34495 L closepath p F P
0 g
s
.75 .5 .125 .1 k
.71173 .4457 m .71895 .43298 L .74109 .45319 L p F P
0 g
s
.75 .5 .125 .1 k
.74109 .45319 m .73287 .4672 L .71173 .4457 L p F P
0 g
s
.95 .5 .125 .1 k
.55529 .35311 m .55624 .35103 L .58577 .35942 L p F P
0 g
s
.95 .5 .108 .1 k
.58708 .35519 m .58577 .35942 L .55624 .35103 L p F P
0 g
s
.917 .5 .108 .1 k
.58577 .35942 m .58708 .35519 L .61669 .3638 L p F P
0 g
s
.85 .5 .108 .1 k
.64263 .38284 m .64545 .37465 L .67311 .38766 L p F P
0 g
s
.85 .5 .108 .1 k
.67311 .38766 m .6695 .39767 L .64263 .38284 L p F P
0 g
s
.617 .5 .492 .1 k
.29557 .60324 m .2781 .58852 L .28923 .56211 L p F P
0 g
s
.583 .5 .492 .1 k
.2781 .58852 m .29557 .60324 L .28754 .63019 L p F P
0 g
s
.983 .5 .125 .1 k
.55624 .35103 m .55529 .35311 L .52632 .34495 L closepath p F P
0 g
s
.517 .5 .192 .1 k
.7384 .67742 m .76025 .66434 L .76337 .69077 L p F P
0 g
s
.517 .5 .192 .1 k
.76337 .69077 m .7412 .70381 L .7384 .67742 L p F P
0 g
s
.483 .5 .208 .1 k
.71722 .71542 m .7412 .70381 L .74185 .72938 L p F P
0 g
s
.483 .5 .208 .1 k
.74185 .72938 m .71779 .74084 L .71722 .71542 L p F P
0 g
s
.817 .5 .542 .1 k
.36038 .4199 m .3551 .4084 L .38106 .39251 L p F P
0 g
s
.783 .5 .542 .1 k
.3551 .4084 m .36038 .4199 L .33691 .43917 L p F P
0 g
s
.983 .5 .542 .1 k
.4968 .35204 m .49602 .34992 L .52632 .34495 L closepath p F P
0 g
s
.95 .5 .558 .1 k
.49557 .34777 m .49602 .34992 L .4661 .35724 L p F P
0 g
s
.95 .5 .558 .1 k
.4661 .35724 m .46513 .35297 L .49557 .34777 L p F P
0 g
s
.917 .5 .558 .1 k
.46513 .35297 m .4661 .35724 L .4368 .36683 L p F P
0 g
s
.983 .5 .108 .1 k
.55687 .34889 m .55624 .35103 L .52632 .34495 L closepath p F P
0 g
s
.95 .5 .108 .1 k
.55624 .35103 m .55687 .34889 L .58708 .35519 L p F P
0 g
s
.917 .5 .558 .1 k
.4368 .36683 m .43527 .3605 L .46513 .35297 L p F P
0 g
s
.883 .5 .558 .1 k
.43527 .3605 m .4368 .36683 L .40838 .37862 L p F P
0 g
s
.817 .5 .108 .1 k
.6695 .39767 m .67311 .38766 L .69944 .40272 L p F P
0 g
s
.817 .5 .108 .1 k
.69944 .40272 m .69501 .41442 L .6695 .39767 L p F P
0 g
s
.417 .5 .258 .1 k
.63632 .78985 m .66419 .78311 L .66176 .80537 L p F P
0 g
s
.417 .5 .258 .1 k
.66176 .80537 m .63439 .81189 L .63632 .78985 L p F P
0 g
s
.55 .5 .175 .1 k
.75481 .63746 m .77411 .62313 L .78006 .6499 L p F P
0 g
s
.55 .5 .175 .1 k
.78006 .6499 m .76025 .66434 L .75481 .63746 L p F P
0 g
s
.983 .5 .558 .1 k
.49602 .34992 m .49557 .34777 L .52632 .34495 L closepath p F P
0 g
s
.95 .5 .092 .1 k
.58773 .35089 m .58708 .35519 L .55687 .34889 L p F P
0 g
s
.917 .5 .092 .1 k
.58708 .35519 m .58773 .35089 L .61776 .35742 L p F P
0 g
s
.917 .5 .092 .1 k
.61776 .35742 m .61669 .3638 L .58708 .35519 L p F P
0 g
s
.45 .5 .225 .1 k
.69215 .75082 m .71779 .74084 L .7164 .76509 L p F P
0 g
s
.45 .5 .225 .1 k
.7164 .76509 m .69096 .77485 L .69215 .75082 L p F P
0 g
s
.883 .5 .558 .1 k
.40838 .37862 m .40622 .37032 L .43527 .3605 L p F P
0 g
s
.85 .5 .558 .1 k
.40622 .37032 m .40838 .37862 L .38106 .39251 L p F P
0 g
s
.983 .5 .092 .1 k
.55716 .34672 m .55687 .34889 L .52632 .34495 L closepath p F P
0 g
s
.95 .5 .092 .1 k
.55687 .34889 m .55716 .34672 L .58773 .35089 L p F P
0 g
s
.65 .5 .142 .1 k
.75675 .52922 m .76913 .51402 L .78388 .53895 L p F P
0 g
s
.65 .5 .142 .1 k
.78388 .53895 m .77062 .55484 L .75675 .52922 L p F P
0 g
s
.717 .5 .525 .1 k
.30577 .49704 m .29552 .48227 L .31523 .46001 L p F P
0 g
s
.683 .5 .525 .1 k
.29552 .48227 m .30577 .49704 L .28917 .52144 L p F P
0 g
s
.717 .5 .125 .1 k
.73287 .4672 m .74109 .45319 L .76122 .47491 L p F P
0 g
s
.717 .5 .125 .1 k
.76122 .47491 m .75207 .49004 L .73287 .4672 L p F P
0 g
s
.883 .5 .092 .1 k
.61669 .3638 m .61776 .35742 L .64699 .36627 L p F P
0 g
s
.883 .5 .092 .1 k
.64699 .36627 m .64545 .37465 L .61669 .3638 L p F P
0 g
s
.983 .5 .575 .1 k
.49557 .34777 m .49545 .34559 L .52632 .34495 L closepath p F P
0 g
s
.95 .5 .575 .1 k
.49545 .34559 m .49557 .34777 L .46513 .35297 L p F P
0 g
s
.783 .5 .542 .1 k
.33691 .43917 m .33071 .42616 L .3551 .4084 L p F P
0 g
s
.75 .5 .542 .1 k
.33071 .42616 m .33691 .43917 L .31523 .46001 L p F P
0 g
s
.65 .5 .508 .1 k
.28923 .56211 m .27483 .54672 L .28917 .52144 L p F P
0 g
s
.617 .5 .508 .1 k
.27483 .54672 m .28923 .56211 L .2781 .58852 L p F P
0 g
s
.95 .5 .575 .1 k
.46513 .35297 m .46483 .34864 L .49545 .34559 L p F P
0 g
s
.917 .5 .575 .1 k
.46483 .34864 m .46513 .35297 L .43527 .3605 L p F P
0 g
s
.983 .5 .992 .1 k
.55193 .33429 m .5536 .33618 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .975 .1 k
.54997 .33254 m .55193 .33429 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .958 .1 k
.54776 .33093 m .54997 .33254 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .942 .1 k
.5453 .32949 m .54776 .33093 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .925 .1 k
.54262 .32823 m .5453 .32949 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .908 .1 k
.53976 .32717 m .54262 .32823 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .742 .1 k
.5087 .32881 m .51147 .32765 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .725 .1 k
.50612 .33016 m .5087 .32881 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .708 .1 k
.50378 .33169 m .50612 .33016 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .692 .1 k
.50168 .33337 m .50378 .33169 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .675 .1 k
.49986 .33519 m .50168 .33337 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .658 .1 k
.49834 .33712 m .49986 .33519 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .642 .1 k
.49712 .33915 m .49834 .33712 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .625 .1 k
.49623 .34126 m .49712 .33915 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .608 .1 k
.49567 .34341 m .49623 .34126 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .592 .1 k
.49545 .34559 m .49567 .34341 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .075 .1 k
.55712 .34454 m .55716 .34672 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .058 .1 k
.55673 .34237 m .55712 .34454 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .042 .1 k
.55601 .34024 m .55673 .34237 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .025 .1 k
.55496 .33817 m .55601 .34024 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .008 .1 k
.5536 .33618 m .55496 .33817 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .892 .1 k
.53676 .32631 m .53976 .32717 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .875 .1 k
.53363 .32568 m .53676 .32631 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .858 .1 k
.53042 .32527 m .53363 .32568 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .842 .1 k
.52716 .32509 m .53042 .32527 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .825 .1 k
.5239 .32515 m .52716 .32509 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .808 .1 k
.52066 .32544 m .5239 .32515 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .792 .1 k
.51749 .32596 m .52066 .32544 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .775 .1 k
.51441 .3267 m .51749 .32596 L .52632 .34495 L closepath p F P
0 g
s
.983 .5 .758 .1 k
.51147 .32765 m .51441 .3267 L .52632 .34495 L closepath p F P
0 g
s
.95 .5 .075 .1 k
.55716 .34672 m .55712 .34454 L .58771 .34655 L p F P
0 g
s
.95 .5 .075 .1 k
.58771 .34655 m .58773 .35089 L .55716 .34672 L p F P
0 g
s
.783 .5 .108 .1 k
.69501 .41442 m .69944 .40272 L .72418 .41974 L p F P
0 g
s
.783 .5 .108 .1 k
.72418 .41974 m .71895 .43298 L .69501 .41442 L p F P
0 g
s
.417 .5 .408 .1 k
.3744 .77901 m .40173 .78655 L .40391 .80869 L p F P
0 g
s
.417 .5 .392 .1 k
.43172 .81449 m .40391 .80869 L .40173 .78655 L p F P
0 g
s
.95 .5 .592 .1 k
.49567 .34341 m .49545 .34559 L .46483 .34864 L p F P
0 g
s
.85 .5 .558 .1 k
.38106 .39251 m .37825 .38236 L .40622 .37032 L p F P
0 g
s
.817 .5 .558 .1 k
.37825 .38236 m .38106 .39251 L .3551 .4084 L p F P
0 g
s
.517 .5 .458 .1 k
.32275 .70957 m .29968 .69721 L .30265 .6708 L p F P
0 g
s
.483 .5 .458 .1 k
.29968 .69721 m .32275 .70957 L .32214 .73507 L p F P
0 g
s
.483 .5 .442 .1 k
.34699 .74583 m .32214 .73507 L .32275 .70957 L p F P
0 g
s
.383 .5 .342 .1 k
.48933 .8215 m .51868 .82268 L .5189 .84239 L p F P
0 g
s
.383 .5 .325 .1 k
.51868 .82268 m .54809 .82231 L .54747 .84203 L p F P
0 g
s
.383 .5 .325 .1 k
.54747 .84203 m .5189 .84239 L .51868 .82268 L p F P
0 g
s
.583 .5 .158 .1 k
.76574 .59631 m .78214 .58102 L .79118 .60756 L p F P
0 g
s
.583 .5 .158 .1 k
.79118 .60756 m .77411 .62313 L .76574 .59631 L p F P
0 g
s
.85 .5 .092 .1 k
.64545 .37465 m .64699 .36627 L .67516 .3774 L p F P
0 g
s
.85 .5 .092 .1 k
.67516 .3774 m .67311 .38766 L .64545 .37465 L p F P
0 g
s
.917 .5 .075 .1 k
.58773 .35089 m .58771 .34655 L .61783 .35097 L p F P
0 g
s
.917 .5 .075 .1 k
.61783 .35097 m .61776 .35742 L .58773 .35089 L p F P
0 g
s
.383 .5 .308 .1 k
.54809 .82231 m .57733 .82038 L .57588 .84018 L p F P
0 g
s
.383 .5 .308 .1 k
.57588 .84018 m .54747 .84203 L .54809 .82231 L p F P
0 g
s
.55 .5 .475 .1 k
.30265 .6708 m .28183 .65701 L .28754 .63019 L p F P
0 g
s
.517 .5 .475 .1 k
.28183 .65701 m .30265 .6708 L .29968 .69721 L p F P
0 g
s
.917 .5 .575 .1 k
.43527 .3605 m .43471 .35408 L .46483 .34864 L p F P
0 g
s
.883 .5 .575 .1 k
.43471 .35408 m .43527 .3605 L .40622 .37032 L p F P
0 g
s
.95 .5 .058 .1 k
.55712 .34454 m .55673 .34237 L .58701 .34222 L p F P
0 g
s
.95 .5 .058 .1 k
.58701 .34222 m .58771 .34655 L .55712 .34454 L p F P
0 g
s
.383 .5 .358 .1 k
.46027 .81876 m .48933 .8215 L .49038 .84126 L p F P
0 g
s
.383 .5 .342 .1 k
.5189 .84239 m .49038 .84126 L .48933 .8215 L p F P
0 g
s
.95 .5 .608 .1 k
.49623 .34126 m .49567 .34341 L .4652 .3443 L p F P
0 g
s
.95 .5 .592 .1 k
.46483 .34864 m .4652 .3443 L .49567 .34341 L p F P
0 g
s
.45 .5 .442 .1 k
.32214 .73507 m .34699 .74583 L .34828 .76997 L p F P
0 g
s
.45 .5 .425 .1 k
.3744 .77901 m .34828 .76997 L .34699 .74583 L p F P
0 g
s
.917 .5 .592 .1 k
.4652 .3443 m .46483 .34864 L .43471 .35408 L p F P
0 g
s
.95 .5 .042 .1 k
.55673 .34237 m .55601 .34024 L .58564 .33796 L p F P
0 g
s
.95 .5 .042 .1 k
.58564 .33796 m .58701 .34222 L .55673 .34237 L p F P
0 g
s
.383 .5 .292 .1 k
.57733 .82038 m .60617 .8169 L .6039 .83685 L p F P
0 g
s
.383 .5 .292 .1 k
.6039 .83685 m .57588 .84018 L .57733 .82038 L p F P
0 g
s
.417 .5 .242 .1 k
.66419 .78311 m .69096 .77485 L .68805 .79737 L p F P
0 g
s
.417 .5 .242 .1 k
.68805 .79737 m .66176 .80537 L .66419 .78311 L p F P
0 g
s
.583 .5 .492 .1 k
.28754 .63019 m .26937 .6152 L .2781 .58852 L p F P
0 g
s
.55 .5 .492 .1 k
.26937 .6152 m .28754 .63019 L .28183 .65701 L p F P
0 g
s
.883 .5 .075 .1 k
.61776 .35742 m .61783 .35097 L .64721 .3578 L p F P
0 g
s
.883 .5 .075 .1 k
.64721 .3578 m .64699 .36627 L .61776 .35742 L p F P
0 g
s
.95 .5 .625 .1 k
.49712 .33915 m .49623 .34126 L .46625 .34 L p F P
0 g
s
.95 .5 .608 .1 k
.4652 .3443 m .46625 .34 L .49623 .34126 L p F P
0 g
s
.683 .5 .125 .1 k
.75207 .49004 m .76122 .47491 L .77914 .49795 L p F P
0 g
s
.683 .5 .125 .1 k
.77914 .49795 m .76913 .51402 L .75207 .49004 L p F P
0 g
s
.75 .5 .108 .1 k
.71895 .43298 m .72418 .41974 L .74711 .43859 L p F P
0 g
s
.75 .5 .108 .1 k
.74711 .43859 m .74109 .45319 L .71895 .43298 L p F P
0 g
s
.883 .5 .575 .1 k
.40622 .37032 m .40536 .36188 L .43471 .35408 L p F P
0 g
s
.85 .5 .575 .1 k
.40536 .36188 m .40622 .37032 L .37825 .38236 L p F P
0 g
s
.75 .5 .542 .1 k
.31523 .46001 m .30814 .44568 L .33071 .42616 L p F P
0 g
s
.717 .5 .542 .1 k
.30814 .44568 m .31523 .46001 L .29552 .48227 L p F P
0 g
s
.917 .5 .058 .1 k
.58771 .34655 m .58701 .34222 L .61689 .34454 L p F P
0 g
s
.917 .5 .058 .1 k
.61689 .34454 m .61783 .35097 L .58771 .34655 L p F P
0 g
s
.817 .5 .092 .1 k
.67311 .38766 m .67516 .3774 L .70203 .39071 L p F P
0 g
s
.817 .5 .092 .1 k
.70203 .39071 m .69944 .40272 L .67311 .38766 L p F P
0 g
s
.817 .5 .558 .1 k
.3551 .4084 m .35162 .39652 L .37825 .38236 L p F P
0 g
s
.783 .5 .558 .1 k
.35162 .39652 m .3551 .4084 L .33071 .42616 L p F P
0 g
s
.95 .5 .025 .1 k
.55601 .34024 m .55496 .33817 L .58361 .33381 L p F P
0 g
s
.95 .5 .025 .1 k
.58361 .33381 m .58564 .33796 L .55601 .34024 L p F P
0 g
s
.383 .5 .375 .1 k
.43172 .81449 m .46027 .81876 L .46215 .83864 L p F P
0 g
s
.383 .5 .358 .1 k
.49038 .84126 m .46215 .83864 L .46027 .81876 L p F P
0 g
s
.683 .5 .525 .1 k
.28917 .52144 m .278 .50578 L .29552 .48227 L p F P
0 g
s
.65 .5 .525 .1 k
.278 .50578 m .28917 .52144 L .27483 .54672 L p F P
0 g
s
.95 .5 .642 .1 k
.49834 .33712 m .49712 .33915 L .46796 .33579 L p F P
0 g
s
.95 .5 .625 .1 k
.46625 .34 m .46796 .33579 L .49712 .33915 L p F P
0 g
s
.617 .5 .142 .1 k
.77062 .55484 m .78388 .53895 L .79615 .56464 L p F P
0 g
s
.617 .5 .142 .1 k
.79615 .56464 m .78214 .58102 L .77062 .55484 L p F P
0 g
s
.917 .5 .608 .1 k
.46625 .34 m .4652 .3443 L .43517 .34763 L p F P
0 g
s
.917 .5 .592 .1 k
.43471 .35408 m .43517 .34763 L .4652 .3443 L p F P
0 g
s
.483 .5 .192 .1 k
.7412 .70381 m .76337 .69077 L .76409 .71653 L p F P
0 g
s
.483 .5 .192 .1 k
.76409 .71653 m .74185 .72938 L .7412 .70381 L p F P
0 g
s
.95 .5 .008 .1 k
.55496 .33817 m .5536 .33618 L .58093 .32982 L p F P
0 g
s
.95 .5 .008 .1 k
.58093 .32982 m .58361 .33381 L .55496 .33817 L p F P
0 g
s
.883 .5 .592 .1 k
.43517 .34763 m .43471 .35408 L .40536 .36188 L p F P
0 g
s
.383 .5 .275 .1 k
.60617 .8169 m .63439 .81189 L .63131 .83205 L p F P
0 g
s
.383 .5 .275 .1 k
.63131 .83205 m .6039 .83685 L .60617 .8169 L p F P
0 g
s
.95 .5 .658 .1 k
.49986 .33519 m .49834 .33712 L .47033 .33172 L p F P
0 g
s
.95 .5 .642 .1 k
.46796 .33579 m .47033 .33172 L .49834 .33712 L p F P
0 g
s
.517 .5 .175 .1 k
.76025 .66434 m .78006 .6499 L .78347 .67639 L p F P
0 g
s
.517 .5 .175 .1 k
.78347 .67639 m .76337 .69077 L .76025 .66434 L p F P
0 g
s
.417 .5 .425 .1 k
.34828 .76997 m .3744 .77901 L .37708 .8014 L p F P
0 g
s
.417 .5 .408 .1 k
.40391 .80869 m .37708 .8014 L .3744 .77901 L p F P
0 g
s
.85 .5 .075 .1 k
.64699 .36627 m .64721 .3578 L .6756 .36699 L p F P
0 g
s
.85 .5 .075 .1 k
.6756 .36699 m .67516 .3774 L .64699 .36627 L p F P
0 g
s
.45 .5 .208 .1 k
.71779 .74084 m .74185 .72938 L .74028 .75391 L p F P
0 g
s
.45 .5 .208 .1 k
.74028 .75391 m .7164 .76509 L .71779 .74084 L p F P
0 g
s
.617 .5 .508 .1 k
.2781 .58852 m .26291 .57265 L .27483 .54672 L p F P
0 g
s
.583 .5 .508 .1 k
.26291 .57265 m .2781 .58852 L .26937 .6152 L p F P
0 g
s
.917 .5 .042 .1 k
.58701 .34222 m .58564 .33796 L .61494 .33818 L p F P
0 g
s
.917 .5 .042 .1 k
.61494 .33818 m .61689 .34454 L .58701 .34222 L p F P
0 g
s
.95 .5 .992 .1 k
.5536 .33618 m .55193 .33429 L .57764 .32604 L p F P
0 g
s
.95 .5 .992 .1 k
.57764 .32604 m .58093 .32982 L .5536 .33618 L p F P
0 g
s
.95 .5 .675 .1 k
.50168 .33337 m .49986 .33519 L .47333 .32783 L p F P
0 g
s
.95 .5 .658 .1 k
.47033 .33172 m .47333 .32783 L .49986 .33519 L p F P
0 g
s
.85 .5 .575 .1 k
.37825 .38236 m .37704 .37201 L .40536 .36188 L p F P
0 g
s
.817 .5 .575 .1 k
.37704 .37201 m .37825 .38236 L .35162 .39652 L p F P
0 g
s
.883 .5 .058 .1 k
.61783 .35097 m .61689 .34454 L .6461 .34932 L p F P
0 g
s
.883 .5 .058 .1 k
.6461 .34932 m .64721 .3578 L .61783 .35097 L p F P
0 g
s
.783 .5 .092 .1 k
.69944 .40272 m .70203 .39071 L .72733 .40612 L p F P
0 g
s
.783 .5 .092 .1 k
.72733 .40612 m .72418 .41974 L .69944 .40272 L p F P
0 g
s
.383 .5 .392 .1 k
.40391 .80869 m .43172 .81449 L .43442 .83454 L p F P
0 g
s
.383 .5 .375 .1 k
.46215 .83864 m .43442 .83454 L .43172 .81449 L p F P
0 g
s
.95 .5 .975 .1 k
.55193 .33429 m .54997 .33254 L .57377 .3225 L p F P
0 g
s
.95 .5 .975 .1 k
.57377 .3225 m .57764 .32604 L .55193 .33429 L p F P
0 g
s
.917 .5 .625 .1 k
.46796 .33579 m .46625 .34 L .43663 .34122 L p F P
0 g
s
.917 .5 .608 .1 k
.43517 .34763 m .43663 .34122 L .46625 .34 L p F P
0 g
s
.783 .5 .558 .1 k
.33071 .42616 m .32655 .41271 L .35162 .39652 L p F P
0 g
s
.75 .5 .558 .1 k
.32655 .41271 m .33071 .42616 L .30814 .44568 L p F P
0 g
s
.95 .5 .692 .1 k
.50378 .33169 m .50168 .33337 L .47693 .32417 L p F P
0 g
s
.95 .5 .675 .1 k
.47333 .32783 m .47693 .32417 L .50168 .33337 L p F P
0 g
s
.717 .5 .108 .1 k
.74109 .45319 m .74711 .43859 L .76799 .45911 L p F P
0 g
s
.717 .5 .108 .1 k
.76799 .45911 m .76122 .47491 L .74109 .45319 L p F P
0 g
s
.55 .5 .158 .1 k
.77411 .62313 m .79118 .60756 L .7976 .63422 L p F P
0 g
s
.55 .5 .158 .1 k
.7976 .63422 m .78006 .6499 L .77411 .62313 L p F P
0 g
s
.95 .5 .958 .1 k
.54997 .33254 m .54776 .33093 L .56935 .31926 L p F P
0 g
s
.95 .5 .958 .1 k
.56935 .31926 m .57377 .3225 L .54997 .33254 L p F P
0 g
s
.717 .5 .542 .1 k
.29552 .48227 m .28759 .46678 L .30814 .44568 L p F P
0 g
s
.683 .5 .542 .1 k
.28759 .46678 m .29552 .48227 L .278 .50578 L p F P
0 g
s
.883 .5 .592 .1 k
.40536 .36188 m .40583 .35339 L .43517 .34763 L p F P
0 g
s
.85 .5 .592 .1 k
.40583 .35339 m .40536 .36188 L .37704 .37201 L p F P
0 g
s
.917 .5 .025 .1 k
.58564 .33796 m .58361 .33381 L .612 .33197 L p F P
0 g
s
.917 .5 .025 .1 k
.612 .33197 m .61494 .33818 L .58564 .33796 L p F P
0 g
s
.95 .5 .708 .1 k
.50612 .33016 m .50378 .33169 L .48109 .32078 L p F P
0 g
s
.95 .5 .692 .1 k
.47693 .32417 m .48109 .32078 L .50378 .33169 L p F P
0 g
s
.65 .5 .125 .1 k
.76913 .51402 m .77914 .49795 L .79465 .52215 L p F P
0 g
s
.65 .5 .125 .1 k
.79465 .52215 m .78388 .53895 L .76913 .51402 L p F P
0 g
s
.883 .5 .608 .1 k
.43663 .34122 m .43517 .34763 L .40583 .35339 L p F P
0 g
s
.417 .5 .225 .1 k
.69096 .77485 m .7164 .76509 L .71302 .78794 L p F P
0 g
s
.417 .5 .225 .1 k
.71302 .78794 m .68805 .79737 L .69096 .77485 L p F P
0 g
s
.95 .5 .942 .1 k
.54776 .33093 m .5453 .32949 L .56445 .31634 L p F P
0 g
s
.95 .5 .942 .1 k
.56445 .31634 m .56935 .31926 L .54776 .33093 L p F P
0 g
s
.383 .5 .258 .1 k
.63439 .81189 m .66176 .80537 L .65788 .8258 L p F P
0 g
s
.383 .5 .258 .1 k
.65788 .8258 m .63131 .83205 L .63439 .81189 L p F P
0 g
s
.95 .5 .725 .1 k
.5087 .32881 m .50612 .33016 L .48577 .3177 L p F P
0 g
s
.95 .5 .708 .1 k
.48109 .32078 m .48577 .3177 L .50612 .33016 L p F P
0 g
s
.517 .5 .475 .1 k
.29968 .69721 m .27856 .68347 L .28183 .65701 L p F P
0 g
s
.483 .5 .475 .1 k
.27856 .68347 m .29968 .69721 L .299 .72288 L p F P
0 g
s
.483 .5 .458 .1 k
.32214 .73507 m .299 .72288 L .29968 .69721 L p F P
0 g
s
.817 .5 .075 .1 k
.67516 .3774 m .6756 .36699 L .70272 .3785 L p F P
0 g
s
.817 .5 .075 .1 k
.70272 .3785 m .70203 .39071 L .67516 .3774 L p F P
0 g
s
.917 .5 .642 .1 k
.47033 .33172 m .46796 .33579 L .43909 .33493 L p F P
0 g
s
.917 .5 .625 .1 k
.43663 .34122 m .43909 .33493 L .46796 .33579 L p F P
0 g
s
.65 .5 .525 .1 k
.27483 .54672 m .26283 .53034 L .278 .50578 L p F P
0 g
s
.617 .5 .525 .1 k
.26283 .53034 m .27483 .54672 L .26291 .57265 L p F P
0 g
s
.95 .5 .925 .1 k
.5453 .32949 m .54262 .32823 L .5591 .31379 L p F P
0 g
s
.95 .5 .925 .1 k
.5591 .31379 m .56445 .31634 L .5453 .32949 L p F P
0 g
s
.45 .5 .458 .1 k
.299 .72288 m .32214 .73507 L .32363 .75946 L p F P
0 g
s
.45 .5 .442 .1 k
.34828 .76997 m .32363 .75946 L .32214 .73507 L p F P
0 g
s
.95 .5 .742 .1 k
.51147 .32765 m .5087 .32881 L .49091 .31497 L p F P
0 g
s
.95 .5 .725 .1 k
.48577 .3177 m .49091 .31497 L .5087 .32881 L p F P
0 g
s
.883 .5 .042 .1 k
.61689 .34454 m .61494 .33818 L .64365 .34092 L p F P
0 g
s
.883 .5 .042 .1 k
.64365 .34092 m .6461 .34932 L .61689 .34454 L p F P
0 g
s
.95 .5 .908 .1 k
.54262 .32823 m .53976 .32717 L .55337 .31164 L p F P
0 g
s
.95 .5 .908 .1 k
.55337 .31164 m .5591 .31379 L .54262 .32823 L p F P
0 g
s
.55 .5 .492 .1 k
.28183 .65701 m .26317 .64191 L .26937 .6152 L p F P
0 g
s
.517 .5 .492 .1 k
.26317 .64191 m .28183 .65701 L .27856 .68347 L p F P
0 g
s
.817 .5 .575 .1 k
.35162 .39652 m .35001 .38439 L .37704 .37201 L p F P
0 g
s
.783 .5 .575 .1 k
.35001 .38439 m .35162 .39652 L .32655 .41271 L p F P
0 g
s
.85 .5 .058 .1 k
.64721 .3578 m .6461 .34932 L .67438 .35656 L p F P
0 g
s
.85 .5 .058 .1 k
.67438 .35656 m .6756 .36699 L .64721 .3578 L p F P
0 g
s
.917 .5 .008 .1 k
.58361 .33381 m .58093 .32982 L .60809 .326 L p F P
0 g
s
.917 .5 .008 .1 k
.60809 .326 m .612 .33197 L .58361 .33381 L p F P
0 g
s
.95 .5 .758 .1 k
.51441 .3267 m .51147 .32765 L .49647 .31263 L p F P
0 g
s
.95 .5 .742 .1 k
.49091 .31497 m .49647 .31263 L .51147 .32765 L p F P
0 g
s
.583 .5 .142 .1 k
.78214 .58102 m .79615 .56464 L .80578 .59087 L p F P
0 g
s
.583 .5 .142 .1 k
.80578 .59087 m .79118 .60756 L .78214 .58102 L p F P
0 g
s
.95 .5 .892 .1 k
.53976 .32717 m .53676 .32631 L .54733 .30991 L p F P
0 g
s
.95 .5 .892 .1 k
.54733 .30991 m .55337 .31164 L .53976 .32717 L p F P
0 g
s
.75 .5 .092 .1 k
.72418 .41974 m .72733 .40612 L .75081 .42353 L p F P
0 g
s
.75 .5 .092 .1 k
.75081 .42353 m .74711 .43859 L .72418 .41974 L p F P
0 g
s
.95 .5 .775 .1 k
.51749 .32596 m .51441 .3267 L .50237 .31069 L p F P
0 g
s
.95 .5 .758 .1 k
.49647 .31263 m .50237 .31069 L .51441 .3267 L p F P
0 g
s
.383 .5 .408 .1 k
.37708 .8014 m .40391 .80869 L .40741 .82899 L p F P
0 g
s
.383 .5 .392 .1 k
.43442 .83454 m .40741 .82899 L .40391 .80869 L p F P
0 g
s
.95 .5 .875 .1 k
.53676 .32631 m .53363 .32568 L .54104 .30862 L p F P
0 g
s
.95 .5 .875 .1 k
.54104 .30862 m .54733 .30991 L .53676 .32631 L p F P
0 g
s
.95 .5 .792 .1 k
.52066 .32544 m .51749 .32596 L .50854 .30918 L p F P
0 g
s
.95 .5 .775 .1 k
.50237 .31069 m .50854 .30918 L .51749 .32596 L p F P
0 g
s
.95 .5 .858 .1 k
.53363 .32568 m .53042 .32527 L .53458 .30779 L p F P
0 g
s
.95 .5 .858 .1 k
.53458 .30779 m .54104 .30862 L .53363 .32568 L p F P
0 g
s
.917 .5 .658 .1 k
.47333 .32783 m .47033 .33172 L .44254 .32884 L p F P
0 g
s
.917 .5 .642 .1 k
.43909 .33493 m .44254 .32884 L .47033 .33172 L p F P
0 g
s
.95 .5 .808 .1 k
.5239 .32515 m .52066 .32544 L .51493 .30813 L p F P
0 g
s
.95 .5 .792 .1 k
.50854 .30918 m .51493 .30813 L .52066 .32544 L p F P
0 g
s
.95 .5 .842 .1 k
.53042 .32527 m .52716 .32509 L .52802 .30743 L p F P
0 g
s
.95 .5 .842 .1 k
.52802 .30743 m .53458 .30779 L .53042 .32527 L p F P
0 g
s
.75 .5 .558 .1 k
.30814 .44568 m .3033 .43082 L .32655 .41271 L p F P
0 g
s
.717 .5 .558 .1 k
.3033 .43082 m .30814 .44568 L .28759 .46678 L p F P
0 g
s
.95 .5 .825 .1 k
.52716 .32509 m .5239 .32515 L .52145 .30754 L p F P
0 g
s
.95 .5 .808 .1 k
.51493 .30813 m .52145 .30754 L .5239 .32515 L p F P
0 g
s
.883 .5 .625 .1 k
.43909 .33493 m .43663 .34122 L .40763 .34494 L p F P
0 g
s
.883 .5 .608 .1 k
.40583 .35339 m .40763 .34494 L .43663 .34122 L p F P
0 g
s
.95 .5 .825 .1 k
.52145 .30754 m .52802 .30743 L .52716 .32509 L p F P
0 g
s
.417 .5 .442 .1 k
.32363 .75946 m .34828 .76997 L .35144 .79265 L p F P
0 g
s
.417 .5 .425 .1 k
.37708 .8014 m .35144 .79265 L .34828 .76997 L p F P
0 g
s
.85 .5 .592 .1 k
.37704 .37201 m .37746 .36157 L .40583 .35339 L p F P
0 g
s
.817 .5 .592 .1 k
.37746 .36157 m .37704 .37201 L .35001 .38439 L p F P
0 g
s
.683 .5 .108 .1 k
.76122 .47491 m .76799 .45911 L .7866 .48117 L p F P
0 g
s
.683 .5 .108 .1 k
.7866 .48117 m .77914 .49795 L .76122 .47491 L p F P
0 g
s
.583 .5 .508 .1 k
.26937 .6152 m .25355 .59903 L .26291 .57265 L p F P
0 g
s
.55 .5 .508 .1 k
.25355 .59903 m .26937 .6152 L .26317 .64191 L p F P
0 g
s
.917 .5 .992 .1 k
.58093 .32982 m .57764 .32604 L .60323 .32031 L p F P
0 g
s
.917 .5 .992 .1 k
.60323 .32031 m .60809 .326 L .58093 .32982 L p F P
0 g
s
.85 .5 .608 .1 k
.40763 .34494 m .40583 .35339 L .37746 .36157 L p F P
0 g
s
.35 .5 .342 .1 k
.49038 .84126 m .5189 .84239 L .5192 .85988 L p F P
0 g
s
.35 .5 .325 .1 k
.5189 .84239 m .54747 .84203 L .54662 .85954 L p F P
0 g
s
.35 .5 .325 .1 k
.54662 .85954 m .5192 .85988 L .5189 .84239 L p F P
0 g
s
.35 .5 .308 .1 k
.54747 .84203 m .57588 .84018 L .57388 .85779 L p F P
0 g
s
.35 .5 .308 .1 k
.57388 .85779 m .54662 .85954 L .54747 .84203 L p F P
0 g
s
.683 .5 .542 .1 k
.278 .50578 m .26929 .48932 L .28759 .46678 L p F P
0 g
s
.65 .5 .542 .1 k
.26929 .48932 m .278 .50578 L .26283 .53034 L p F P
0 g
s
.383 .5 .242 .1 k
.66176 .80537 m .68805 .79737 L .68339 .81815 L p F P
0 g
s
.383 .5 .242 .1 k
.68339 .81815 m .65788 .8258 L .66176 .80537 L p F P
0 g
s
.483 .5 .175 .1 k
.76337 .69077 m .78347 .67639 L .78426 .70234 L p F P
0 g
s
.483 .5 .175 .1 k
.78426 .70234 m .76409 .71653 L .76337 .69077 L p F P
0 g
s
.883 .5 .025 .1 k
.61494 .33818 m .612 .33197 L .63988 .33271 L p F P
0 g
s
.883 .5 .025 .1 k
.63988 .33271 m .64365 .34092 L .61494 .33818 L p F P
0 g
s
.783 .5 .075 .1 k
.70203 .39071 m .70272 .3785 L .72831 .39226 L p F P
0 g
s
.783 .5 .075 .1 k
.72831 .39226 m .72733 .40612 L .70203 .39071 L p F P
0 g
s
.45 .5 .192 .1 k
.74185 .72938 m .76409 .71653 L .76234 .74135 L p F P
0 g
s
.45 .5 .192 .1 k
.76234 .74135 m .74028 .75391 L .74185 .72938 L p F P
0 g
s
.917 .5 .675 .1 k
.47693 .32417 m .47333 .32783 L .44695 .323 L p F P
0 g
s
.917 .5 .658 .1 k
.44254 .32884 m .44695 .323 L .47333 .32783 L p F P
0 g
s
.35 .5 .358 .1 k
.46215 .83864 m .49038 .84126 L .49183 .85881 L p F P
0 g
s
.35 .5 .342 .1 k
.5192 .85988 m .49183 .85881 L .49038 .84126 L p F P
0 g
s
.617 .5 .125 .1 k
.78388 .53895 m .79465 .52215 L .80756 .5473 L p F P
0 g
s
.617 .5 .125 .1 k
.80756 .5473 m .79615 .56464 L .78388 .53895 L p F P
0 g
s
.35 .5 .292 .1 k
.57588 .84018 m .6039 .83685 L .60077 .85463 L p F P
0 g
s
.35 .5 .292 .1 k
.60077 .85463 m .57388 .85779 L .57588 .84018 L p F P
0 g
s
.917 .5 .975 .1 k
.57764 .32604 m .57377 .3225 L .59749 .31499 L p F P
0 g
s
.917 .5 .975 .1 k
.59749 .31499 m .60323 .32031 L .57764 .32604 L p F P
0 g
s
.517 .5 .158 .1 k
.78006 .6499 m .7976 .63422 L .80128 .66076 L p F P
0 g
s
.517 .5 .158 .1 k
.80128 .66076 m .78347 .67639 L .78006 .6499 L p F P
0 g
s
.783 .5 .575 .1 k
.32655 .41271 m .32452 .39895 L .35001 .38439 L p F P
0 g
s
.75 .5 .575 .1 k
.32452 .39895 m .32655 .41271 L .3033 .43082 L p F P
0 g
s
.817 .5 .058 .1 k
.6756 .36699 m .67438 .35656 L .70146 .36623 L p F P
0 g
s
.817 .5 .058 .1 k
.70146 .36623 m .70272 .3785 L .6756 .36699 L p F P
0 g
s
.85 .5 .042 .1 k
.6461 .34932 m .64365 .34092 L .67151 .34621 L p F P
0 g
s
.85 .5 .042 .1 k
.67151 .34621 m .67438 .35656 L .6461 .34932 L p F P
0 g
s
.883 .5 .642 .1 k
.44254 .32884 m .43909 .33493 L .41077 .33663 L p F P
0 g
s
.883 .5 .625 .1 k
.40763 .34494 m .41077 .33663 L .43909 .33493 L p F P
0 g
s
.417 .5 .208 .1 k
.7164 .76509 m .74028 .75391 L .73644 .77712 L p F P
0 g
s
.417 .5 .208 .1 k
.73644 .77712 m .71302 .78794 L .7164 .76509 L p F P
0 g
s
.35 .5 .375 .1 k
.43442 .83454 m .46215 .83864 L .46474 .85633 L p F P
0 g
s
.35 .5 .358 .1 k
.49183 .85881 m .46474 .85633 L .46215 .83864 L p F P
0 g
s
.917 .5 .692 .1 k
.48109 .32078 m .47693 .32417 L .45227 .3175 L p F P
0 g
s
.917 .5 .675 .1 k
.44695 .323 m .45227 .3175 L .47693 .32417 L p F P
0 g
s
.617 .5 .525 .1 k
.26291 .57265 m .25022 .55575 L .26283 .53034 L p F P
0 g
s
.583 .5 .525 .1 k
.25022 .55575 m .26291 .57265 L .25355 .59903 L p F P
0 g
s
.717 .5 .092 .1 k
.74711 .43859 m .75081 .42353 L .77224 .44281 L p F P
0 g
s
.717 .5 .092 .1 k
.77224 .44281 m .76799 .45911 L .74711 .43859 L p F P
0 g
s
.383 .5 .425 .1 k
.35144 .79265 m .37708 .8014 L .38136 .822 L p F P
0 g
s
.383 .5 .408 .1 k
.40741 .82899 m .38136 .822 L .37708 .8014 L p F P
0 g
s
.917 .5 .958 .1 k
.57377 .3225 m .56935 .31926 L .59093 .3101 L p F P
0 g
s
.917 .5 .958 .1 k
.59093 .3101 m .59749 .31499 L .57377 .3225 L p F P
0 g
s
.883 .5 .008 .1 k
.612 .33197 m .60809 .326 L .6348 .32478 L p F P
0 g
s
.883 .5 .008 .1 k
.6348 .32478 m .63988 .33271 L .612 .33197 L p F P
0 g
s
.35 .5 .275 .1 k
.6039 .83685 m .63131 .83205 L .62706 .85008 L p F P
0 g
s
.35 .5 .275 .1 k
.62706 .85008 m .60077 .85463 L .6039 .83685 L p F P
0 g
s
.717 .5 .558 .1 k
.28759 .46678 m .28211 .45071 L .3033 .43082 L p F P
0 g
s
.683 .5 .558 .1 k
.28211 .45071 m .28759 .46678 L .26929 .48932 L p F P
0 g
s
.817 .5 .592 .1 k
.35001 .38439 m .35032 .37213 L .37746 .36157 L p F P
0 g
s
.783 .5 .592 .1 k
.35032 .37213 m .35001 .38439 L .32452 .39895 L p F P
0 g
s
.55 .5 .142 .1 k
.79118 .60756 m .80578 .59087 L .81263 .6174 L p F P
0 g
s
.55 .5 .142 .1 k
.81263 .6174 m .7976 .63422 L .79118 .60756 L p F P
0 g
s
.85 .5 .625 .1 k
.41077 .33663 m .40763 .34494 L .37953 .35117 L p F P
0 g
s
.85 .5 .608 .1 k
.37746 .36157 m .37953 .35117 L .40763 .34494 L p F P
0 g
s
.917 .5 .708 .1 k
.48577 .3177 m .48109 .32078 L .45845 .3124 L p F P
0 g
s
.917 .5 .692 .1 k
.45227 .3175 m .45845 .3124 L .48109 .32078 L p F P
0 g
s
.65 .5 .108 .1 k
.77914 .49795 m .7866 .48117 L .80273 .50457 L p F P
0 g
s
.65 .5 .108 .1 k
.80273 .50457 m .79465 .52215 L .77914 .49795 L p F P
0 g
s
.817 .5 .608 .1 k
.37953 .35117 m .37746 .36157 L .35032 .37213 L p F P
0 g
s
.483 .5 .475 .1 k
.299 .72288 m .2778 .70932 L .27856 .68347 L p F P
0 g
s
.45 .5 .475 .1 k
.2778 .70932 m .299 .72288 L .30066 .74756 L p F P
0 g
s
.45 .5 .458 .1 k
.32363 .75946 m .30066 .74756 L .299 .72288 L p F P
0 g
s
.917 .5 .942 .1 k
.56935 .31926 m .56445 .31634 L .5836 .3057 L p F P
0 g
s
.917 .5 .942 .1 k
.5836 .3057 m .59093 .3101 L .56935 .31926 L p F P
0 g
s
.517 .5 .492 .1 k
.27856 .68347 m .25961 .66843 L .26317 .64191 L p F P
0 g
s
.483 .5 .492 .1 k
.25961 .66843 m .27856 .68347 L .2778 .70932 L p F P
0 g
s
.883 .5 .658 .1 k
.44695 .323 m .44254 .32884 L .41523 .32855 L p F P
0 g
s
.883 .5 .642 .1 k
.41077 .33663 m .41523 .32855 L .44254 .32884 L p F P
0 g
s
.35 .5 .392 .1 k
.40741 .82899 m .43442 .83454 L .43813 .85244 L p F P
0 g
s
.35 .5 .375 .1 k
.46474 .85633 m .43813 .85244 L .43442 .83454 L p F P
0 g
s
.75 .5 .075 .1 k
.72733 .40612 m .72831 .39226 L .75211 .40819 L p F P
0 g
s
.75 .5 .075 .1 k
.75211 .40819 m .75081 .42353 L .72733 .40612 L p F P
0 g
s
.917 .5 .725 .1 k
.49091 .31497 m .48577 .3177 L .46542 .30776 L p F P
0 g
s
.917 .5 .708 .1 k
.45845 .3124 m .46542 .30776 L .48577 .3177 L p F P
0 g
s
.383 .5 .225 .1 k
.68805 .79737 m .71302 .78794 L .70761 .80912 L p F P
0 g
s
.383 .5 .225 .1 k
.70761 .80912 m .68339 .81815 L .68805 .79737 L p F P
0 g
s
.65 .5 .542 .1 k
.26283 .53034 m .25344 .51312 L .26929 .48932 L p F P
0 g
s
.617 .5 .542 .1 k
.25344 .51312 m .26283 .53034 L .25022 .55575 L p F P
0 g
s
.417 .5 .458 .1 k
.30066 .74756 m .32363 .75946 L .32725 .7825 L p F P
0 g
s
.417 .5 .442 .1 k
.35144 .79265 m .32725 .7825 L .32363 .75946 L p F P
0 g
s
.85 .5 .025 .1 k
.64365 .34092 m .63988 .33271 L .66698 .33607 L p F P
0 g
s
.85 .5 .025 .1 k
.66698 .33607 m .67151 .34621 L .64365 .34092 L p F P
0 g
s
.917 .5 .925 .1 k
.56445 .31634 m .5591 .31379 L .5756 .30185 L p F P
0 g
s
.917 .5 .925 .1 k
.5756 .30185 m .5836 .3057 L .56445 .31634 L p F P
0 g
s
.55 .5 .508 .1 k
.26317 .64191 m .24691 .62562 L .25355 .59903 L p F P
0 g
s
.517 .5 .508 .1 k
.24691 .62562 m .26317 .64191 L .25961 .66843 L p F P
0 g
s
.883 .5 .992 .1 k
.60809 .326 m .60323 .32031 L .62846 .31723 L p F P
0 g
s
.883 .5 .992 .1 k
.62846 .31723 m .6348 .32478 L .60809 .326 L p F P
0 g
s
.75 .5 .575 .1 k
.3033 .43082 m .30084 .4156 L .32452 .39895 L p F P
0 g
s
.717 .5 .575 .1 k
.30084 .4156 m .3033 .43082 L .28211 .45071 L p F P
0 g
s
.783 .5 .058 .1 k
.70272 .3785 m .70146 .36623 L .72706 .37831 L p F P
0 g
s
.783 .5 .058 .1 k
.72706 .37831 m .72831 .39226 L .70272 .3785 L p F P
0 g
s
.35 .5 .258 .1 k
.63131 .83205 m .65788 .8258 L .65253 .84417 L p F P
0 g
s
.35 .5 .258 .1 k
.65253 .84417 m .62706 .85008 L .63131 .83205 L p F P
0 g
s
.917 .5 .742 .1 k
.49647 .31263 m .49091 .31497 L .47311 .30363 L p F P
0 g
s
.917 .5 .725 .1 k
.46542 .30776 m .47311 .30363 L .49091 .31497 L p F P
0 g
s
.583 .5 .125 .1 k
.79615 .56464 m .80756 .5473 L .81771 .57318 L p F P
0 g
s
.583 .5 .125 .1 k
.81771 .57318 m .80578 .59087 L .79615 .56464 L p F P
0 g
s
.817 .5 .042 .1 k
.67438 .35656 m .67151 .34621 L .69823 .35404 L p F P
0 g
s
.817 .5 .042 .1 k
.69823 .35404 m .70146 .36623 L .67438 .35656 L p F P
0 g
s
.917 .5 .908 .1 k
.5591 .31379 m .55337 .31164 L .56701 .29859 L p F P
0 g
s
.917 .5 .908 .1 k
.56701 .29859 m .5756 .30185 L .5591 .31379 L p F P
0 g
s
.683 .5 .092 .1 k
.76799 .45911 m .77224 .44281 L .79136 .46382 L p F P
0 g
s
.683 .5 .092 .1 k
.79136 .46382 m .7866 .48117 L .76799 .45911 L p F P
0 g
s
.883 .5 .675 .1 k
.45227 .3175 m .44695 .323 L .42097 .32081 L p F P
0 g
s
.883 .5 .658 .1 k
.41523 .32855 m .42097 .32081 L .44695 .323 L p F P
0 g
s
.917 .5 .758 .1 k
.50237 .31069 m .49647 .31263 L .48143 .30008 L p F P
0 g
s
.917 .5 .742 .1 k
.47311 .30363 m .48143 .30008 L .49647 .31263 L p F P
0 g
s
.85 .5 .642 .1 k
.41523 .32855 m .41077 .33663 L .38327 .34091 L p F P
0 g
s
.85 .5 .625 .1 k
.37953 .35117 m .38327 .34091 L .41077 .33663 L p F P
0 g
s
.45 .5 .175 .1 k
.76409 .71653 m .78426 .70234 L .78235 .7275 L p F P
0 g
s
.45 .5 .175 .1 k
.78235 .7275 m .76234 .74135 L .76409 .71653 L p F P
0 g
s
.917 .5 .892 .1 k
.55337 .31164 m .54733 .30991 L .55793 .29596 L p F P
0 g
s
.917 .5 .892 .1 k
.55793 .29596 m .56701 .29859 L .55337 .31164 L p F P
0 g
s
.383 .5 .442 .1 k
.32725 .7825 m .35144 .79265 L .3565 .81363 L p F P
0 g
s
.383 .5 .425 .1 k
.38136 .822 m .3565 .81363 L .35144 .79265 L p F P
0 g
s
.783 .5 .592 .1 k
.32452 .39895 m .32469 .38502 L .35032 .37213 L p F P
0 g
s
.75 .5 .592 .1 k
.32469 .38502 m .32452 .39895 L .30084 .4156 L p F P
0 g
s
.35 .5 .408 .1 k
.38136 .822 m .40741 .82899 L .41224 .84718 L p F P
0 g
s
.35 .5 .392 .1 k
.43813 .85244 m .41224 .84718 L .40741 .82899 L p F P
0 g
s
.583 .5 .525 .1 k
.25355 .59903 m .24031 .5818 L .25022 .55575 L p F P
0 g
s
.55 .5 .525 .1 k
.24031 .5818 m .25355 .59903 L .24691 .62562 L p F P
0 g
s
.917 .5 .775 .1 k
.50854 .30918 m .50237 .31069 L .49028 .29714 L p F P
0 g
s
.917 .5 .758 .1 k
.48143 .30008 m .49028 .29714 L .50237 .31069 L p F P
0 g
s
.483 .5 .158 .1 k
.78347 .67639 m .80128 .66076 L .80213 .68692 L p F P
0 g
s
.483 .5 .158 .1 k
.80213 .68692 m .78426 .70234 L .78347 .67639 L p F P
0 g
s
.683 .5 .558 .1 k
.26929 .48932 m .26321 .47222 L .28211 .45071 L p F P
0 g
s
.65 .5 .558 .1 k
.26321 .47222 m .26929 .48932 L .25344 .51312 L p F P
0 g
s
.883 .5 .975 .1 k
.60323 .32031 m .59749 .31499 L .62093 .31015 L p F P
0 g
s
.883 .5 .975 .1 k
.62093 .31015 m .62846 .31723 L .60323 .32031 L p F P
0 g
s
.417 .5 .192 .1 k
.74028 .75391 m .76234 .74135 L .75807 .76498 L p F P
0 g
s
.417 .5 .192 .1 k
.75807 .76498 m .73644 .77712 L .74028 .75391 L p F P
0 g
s
.917 .5 .875 .1 k
.54733 .30991 m .54104 .30862 L .54848 .29401 L p F P
0 g
s
.917 .5 .875 .1 k
.54848 .29401 m .55793 .29596 L .54733 .30991 L p F P
0 g
s
.817 .5 .625 .1 k
.38327 .34091 m .37953 .35117 L .3526 .35989 L p F P
0 g
s
.817 .5 .608 .1 k
.35032 .37213 m .3526 .35989 L .37953 .35117 L p F P
0 g
s
.917 .5 .792 .1 k
.51493 .30813 m .50854 .30918 L .49957 .29486 L p F P
0 g
s
.917 .5 .775 .1 k
.49028 .29714 m .49957 .29486 L .50854 .30918 L p F P
0 g
s
.783 .5 .608 .1 k
.3526 .35989 m .35032 .37213 L .32469 .38502 L p F P
0 g
s
.917 .5 .858 .1 k
.54104 .30862 m .53458 .30779 L .53876 .29275 L p F P
0 g
s
.917 .5 .858 .1 k
.53876 .29275 m .54848 .29401 L .54104 .30862 L p F P
0 g
s
.85 .5 .008 .1 k
.63988 .33271 m .6348 .32478 L .66082 .32625 L p F P
0 g
s
.85 .5 .008 .1 k
.66082 .32625 m .66698 .33607 L .63988 .33271 L p F P
0 g
s
.917 .5 .808 .1 k
.52145 .30754 m .51493 .30813 L .50917 .29327 L p F P
0 g
s
.917 .5 .792 .1 k
.49957 .29486 m .50917 .29327 L .51493 .30813 L p F P
0 g
s
.617 .5 .108 .1 k
.79465 .52215 m .80273 .50457 L .81618 .52913 L p F P
0 g
s
.617 .5 .108 .1 k
.81618 .52913 m .80756 .5473 L .79465 .52215 L p F P
0 g
s
.917 .5 .842 .1 k
.53458 .30779 m .52802 .30743 L .52889 .2922 L p F P
0 g
s
.917 .5 .842 .1 k
.52889 .2922 m .53876 .29275 L .53458 .30779 L p F P
0 g
s
.717 .5 .075 .1 k
.75081 .42353 m .75211 .40819 L .77385 .42616 L p F P
0 g
s
.717 .5 .075 .1 k
.77385 .42616 m .77224 .44281 L .75081 .42353 L p F P
0 g
s
.917 .5 .825 .1 k
.52802 .30743 m .52145 .30754 L .51899 .29238 L p F P
0 g
s
.917 .5 .808 .1 k
.50917 .29327 m .51899 .29238 L .52145 .30754 L p F P
0 g
s
.917 .5 .825 .1 k
.51899 .29238 m .52889 .2922 L .52802 .30743 L p F P
0 g
s
.883 .5 .692 .1 k
.45845 .3124 m .45227 .3175 L .42793 .31349 L p F P
0 g
s
.883 .5 .675 .1 k
.42097 .32081 m .42793 .31349 L .45227 .3175 L p F P
0 g
s
.517 .5 .142 .1 k
.7976 .63422 m .81263 .6174 L .81656 .64398 L p F P
0 g
s
.517 .5 .142 .1 k
.81656 .64398 m .80128 .66076 L .7976 .63422 L p F P
0 g
s
.35 .5 .242 .1 k
.65788 .8258 m .68339 .81815 L .67697 .83692 L p F P
0 g
s
.35 .5 .242 .1 k
.67697 .83692 m .65253 .84417 L .65788 .8258 L p F P
0 g
s
.317 .5 .342 .1 k
.49183 .85881 m .5192 .85988 L .51958 .87492 L p F P
0 g
s
.317 .5 .325 .1 k
.5192 .85988 m .54662 .85954 L .54553 .8746 L p F P
0 g
s
.317 .5 .325 .1 k
.54553 .8746 m .51958 .87492 L .5192 .85988 L p F P
0 g
s
.383 .5 .208 .1 k
.71302 .78794 m .73644 .77712 L .7303 .79877 L p F P
0 g
s
.383 .5 .208 .1 k
.7303 .79877 m .70761 .80912 L .71302 .78794 L p F P
0 g
s
.317 .5 .308 .1 k
.54662 .85954 m .57388 .85779 L .57133 .87296 L p F P
0 g
s
.317 .5 .308 .1 k
.57133 .87296 m .54553 .8746 L .54662 .85954 L p F P
0 g
s
.883 .5 .958 .1 k
.59749 .31499 m .59093 .3101 L .61227 .30363 L p F P
0 g
s
.883 .5 .958 .1 k
.61227 .30363 m .62093 .31015 L .59749 .31499 L p F P
0 g
s
.617 .5 .542 .1 k
.25022 .55575 m .24024 .53796 L .25344 .51312 L p F P
0 g
s
.583 .5 .542 .1 k
.24024 .53796 m .25022 .55575 L .24031 .5818 L p F P
0 g
s
.85 .5 .658 .1 k
.42097 .32081 m .41523 .32855 L .38865 .33092 L p F P
0 g
s
.85 .5 .642 .1 k
.38327 .34091 m .38865 .33092 L .41523 .32855 L p F P
0 g
s
.717 .5 .575 .1 k
.28211 .45071 m .27922 .4342 L .30084 .4156 L p F P
0 g
s
.683 .5 .575 .1 k
.27922 .4342 m .28211 .45071 L .26321 .47222 L p F P
0 g
s
.817 .5 .025 .1 k
.67151 .34621 m .66698 .33607 L .69303 .34207 L p F P
0 g
s
.817 .5 .025 .1 k
.69303 .34207 m .69823 .35404 L .67151 .34621 L p F P
0 g
s
.75 .5 .058 .1 k
.72831 .39226 m .72706 .37831 L .75091 .3927 L p F P
0 g
s
.75 .5 .058 .1 k
.75091 .3927 m .75211 .40819 L .72831 .39226 L p F P
0 g
s
.317 .5 .358 .1 k
.46474 .85633 m .49183 .85881 L .49367 .87392 L p F P
0 g
s
.317 .5 .342 .1 k
.51958 .87492 m .49367 .87392 L .49183 .85881 L p F P
0 g
s
.783 .5 .042 .1 k
.70146 .36623 m .69823 .35404 L .72355 .36441 L p F P
0 g
s
.783 .5 .042 .1 k
.72355 .36441 m .72706 .37831 L .70146 .36623 L p F P
0 g
s
.483 .5 .492 .1 k
.2778 .70932 m .25879 .69448 L .25961 .66843 L p F P
0 g
s
.45 .5 .492 .1 k
.25879 .69448 m .2778 .70932 L .27964 .73432 L p F P
0 g
s
.45 .5 .475 .1 k
.30066 .74756 m .27964 .73432 L .2778 .70932 L p F P
0 g
s
.317 .5 .292 .1 k
.57388 .85779 m .60077 .85463 L .59677 .87001 L p F P
0 g
s
.317 .5 .292 .1 k
.59677 .87001 m .57133 .87296 L .57388 .85779 L p F P
0 g
s
.883 .5 .708 .1 k
.46542 .30776 m .45845 .3124 L .43606 .30669 L p F P
0 g
s
.883 .5 .692 .1 k
.42793 .31349 m .43606 .30669 L .45845 .3124 L p F P
0 g
s
.417 .5 .475 .1 k
.27964 .73432 m .30066 .74756 L .30473 .77098 L p F P
0 g
s
.417 .5 .458 .1 k
.32725 .7825 m .30473 .77098 L .30066 .74756 L p F P
0 g
s
.35 .5 .425 .1 k
.3565 .81363 m .38136 .822 L .38728 .84057 L p F P
0 g
s
.35 .5 .408 .1 k
.41224 .84718 m .38728 .84057 L .38136 .822 L p F P
0 g
s
.65 .5 .092 .1 k
.7866 .48117 m .79136 .46382 L .80796 .48638 L p F P
0 g
s
.65 .5 .092 .1 k
.80796 .48638 m .80273 .50457 L .7866 .48117 L p F P
0 g
s
.55 .5 .125 .1 k
.80578 .59087 m .81771 .57318 L .82492 .59956 L p F P
0 g
s
.55 .5 .125 .1 k
.82492 .59956 m .81263 .6174 L .80578 .59087 L p F P
0 g
s
.517 .5 .508 .1 k
.25961 .66843 m .24309 .65218 L .24691 .62562 L p F P
0 g
s
.483 .5 .508 .1 k
.24309 .65218 m .25961 .66843 L .25879 .69448 L p F P
0 g
s
.85 .5 .992 .1 k
.6348 .32478 m .62846 .31723 L .65309 .31689 L p F P
0 g
s
.85 .5 .992 .1 k
.65309 .31689 m .66082 .32625 L .6348 .32478 L p F P
0 g
s
.317 .5 .375 .1 k
.43813 .85244 m .46474 .85633 L .46804 .87159 L p F P
0 g
s
.317 .5 .358 .1 k
.49367 .87392 m .46804 .87159 L .46474 .85633 L p F P
0 g
s
.883 .5 .942 .1 k
.59093 .3101 m .5836 .3057 L .60258 .29775 L p F P
0 g
s
.883 .5 .942 .1 k
.60258 .29775 m .61227 .30363 L .59093 .3101 L p F P
0 g
s
.75 .5 .592 .1 k
.30084 .4156 m .30083 .40016 L .32469 .38502 L p F P
0 g
s
.717 .5 .592 .1 k
.30083 .40016 m .30084 .4156 L .27922 .4342 L p F P
0 g
s
.817 .5 .642 .1 k
.38865 .33092 m .38327 .34091 L .35685 .34779 L p F P
0 g
s
.817 .5 .625 .1 k
.3526 .35989 m .35685 .34779 L .38327 .34091 L p F P
0 g
s
.317 .5 .275 .1 k
.60077 .85463 m .62706 .85008 L .62163 .86575 L p F P
0 g
s
.317 .5 .275 .1 k
.62163 .86575 m .59677 .87001 L .60077 .85463 L p F P
0 g
s
.65 .5 .558 .1 k
.25344 .51312 m .24682 .4952 L .26321 .47222 L p F P
0 g
s
.617 .5 .558 .1 k
.24682 .4952 m .25344 .51312 L .24024 .53796 L p F P
0 g
s
.383 .5 .458 .1 k
.30473 .77098 m .32725 .7825 L .33304 .80391 L p F P
0 g
s
.383 .5 .442 .1 k
.3565 .81363 m .33304 .80391 L .32725 .7825 L p F P
0 g
s
.883 .5 .725 .1 k
.47311 .30363 m .46542 .30776 L .44527 .30049 L p F P
0 g
s
.883 .5 .708 .1 k
.43606 .30669 m .44527 .30049 L .46542 .30776 L p F P
0 g
s
.783 .5 .608 .1 k
.32469 .38502 m .32711 .37108 L .3526 .35989 L p F P
0 g
s
.75 .5 .608 .1 k
.32711 .37108 m .32469 .38502 L .30083 .40016 L p F P
0 g
s
.85 .5 .675 .1 k
.42793 .31349 m .42097 .32081 L .39563 .32133 L p F P
0 g
s
.85 .5 .658 .1 k
.38865 .33092 m .39563 .32133 L .42097 .32081 L p F P
0 g
s
.55 .5 .525 .1 k
.24691 .62562 m .23327 .60825 L .24031 .5818 L p F P
0 g
s
.517 .5 .525 .1 k
.23327 .60825 m .24691 .62562 L .24309 .65218 L p F P
0 g
s
.35 .5 .225 .1 k
.68339 .81815 m .70761 .80912 L .70015 .82838 L p F P
0 g
s
.35 .5 .225 .1 k
.70015 .82838 m .67697 .83692 L .68339 .81815 L p F P
0 g
s
.783 .5 .625 .1 k
.35685 .34779 m .3526 .35989 L .32711 .37108 L p F P
0 g
s
.683 .5 .075 .1 k
.77224 .44281 m .77385 .42616 L .7933 .44607 L p F P
0 g
s
.683 .5 .075 .1 k
.7933 .44607 m .79136 .46382 L .77224 .44281 L p F P
0 g
s
.883 .5 .925 .1 k
.5836 .3057 m .5756 .30185 L .59197 .29259 L p F P
0 g
s
.883 .5 .925 .1 k
.59197 .29259 m .60258 .29775 L .5836 .3057 L p F P
0 g
s
.317 .5 .392 .1 k
.41224 .84718 m .43813 .85244 L .44287 .86796 L p F P
0 g
s
.317 .5 .375 .1 k
.46804 .87159 m .44287 .86796 L .43813 .85244 L p F P
0 g
s
.583 .5 .108 .1 k
.80756 .5473 m .81618 .52913 L .82675 .55464 L p F P
0 g
s
.583 .5 .108 .1 k
.82675 .55464 m .81771 .57318 L .80756 .5473 L p F P
0 g
s
.45 .5 .158 .1 k
.78426 .70234 m .80213 .68692 L .80007 .71244 L p F P
0 g
s
.45 .5 .158 .1 k
.80007 .71244 m .78235 .7275 L .78426 .70234 L p F P
0 g
s
.417 .5 .175 .1 k
.76234 .74135 m .78235 .7275 L .77768 .7516 L p F P
0 g
s
.417 .5 .175 .1 k
.77768 .7516 m .75807 .76498 L .76234 .74135 L p F P
0 g
s
.817 .5 .008 .1 k
.66698 .33607 m .66082 .32625 L .68589 .33047 L p F P
0 g
s
.817 .5 .008 .1 k
.68589 .33047 m .69303 .34207 L .66698 .33607 L p F P
0 g
s
.883 .5 .742 .1 k
.48143 .30008 m .47311 .30363 L .45545 .29498 L p F P
0 g
s
.883 .5 .725 .1 k
.44527 .30049 m .45545 .29498 L .47311 .30363 L p F P
0 g
s
.85 .5 .975 .1 k
.62846 .31723 m .62093 .31015 L .64384 .30809 L p F P
0 g
s
.85 .5 .975 .1 k
.64384 .30809 m .65309 .31689 L .62846 .31723 L p F P
0 g
s
.317 .5 .258 .1 k
.62706 .85008 m .65253 .84417 L .64571 .86022 L p F P
0 g
s
.317 .5 .258 .1 k
.64571 .86022 m .62163 .86575 L .62706 .85008 L p F P
0 g
s
.883 .5 .908 .1 k
.5756 .30185 m .56701 .29859 L .58055 .28822 L p F P
0 g
s
.883 .5 .908 .1 k
.58055 .28822 m .59197 .29259 L .5756 .30185 L p F P
0 g
s
.683 .5 .575 .1 k
.26321 .47222 m .2599 .45464 L .27922 .4342 L p F P
0 g
s
.65 .5 .575 .1 k
.2599 .45464 m .26321 .47222 L .24682 .4952 L p F P
0 g
s
.717 .5 .058 .1 k
.75211 .40819 m .75091 .3927 L .77274 .40934 L p F P
0 g
s
.717 .5 .058 .1 k
.77274 .40934 m .77385 .42616 L .75211 .40819 L p F P
0 g
s
.483 .5 .142 .1 k
.80128 .66076 m .81656 .64398 L .81746 .67037 L p F P
0 g
s
.483 .5 .142 .1 k
.81746 .67037 m .80213 .68692 L .80128 .66076 L p F P
0 g
s
.583 .5 .542 .1 k
.24031 .5818 m .22986 .56365 L .24024 .53796 L p F P
0 g
s
.55 .5 .542 .1 k
.22986 .56365 m .24031 .5818 L .23327 .60825 L p F P
0 g
s
.383 .5 .192 .1 k
.73644 .77712 m .75807 .76498 L .75125 .78716 L p F P
0 g
s
.383 .5 .192 .1 k
.75125 .78716 m .7303 .79877 L .73644 .77712 L p F P
0 g
s
.783 .5 .025 .1 k
.69823 .35404 m .69303 .34207 L .71776 .35074 L p F P
0 g
s
.783 .5 .025 .1 k
.71776 .35074 m .72355 .36441 L .69823 .35404 L p F P
0 g
s
.35 .5 .442 .1 k
.33304 .80391 m .3565 .81363 L .36346 .83265 L p F P
0 g
s
.35 .5 .425 .1 k
.38728 .84057 m .36346 .83265 L .3565 .81363 L p F P
0 g
s
.883 .5 .758 .1 k
.49028 .29714 m .48143 .30008 L .4665 .29022 L p F P
0 g
s
.883 .5 .742 .1 k
.45545 .29498 m .4665 .29022 L .48143 .30008 L p F P
0 g
s
.75 .5 .042 .1 k
.72706 .37831 m .72355 .36441 L .74717 .37726 L p F P
0 g
s
.75 .5 .042 .1 k
.74717 .37726 m .75091 .3927 L .72706 .37831 L p F P
0 g
s
.85 .5 .692 .1 k
.43606 .30669 m .42793 .31349 L .40416 .31224 L p F P
0 g
s
.85 .5 .675 .1 k
.39563 .32133 m .40416 .31224 L .42793 .31349 L p F P
0 g
s
.817 .5 .658 .1 k
.39563 .32133 m .38865 .33092 L .36307 .33599 L p F P
0 g
s
.817 .5 .642 .1 k
.35685 .34779 m .36307 .33599 L .38865 .33092 L p F P
0 g
s
.617 .5 .092 .1 k
.80273 .50457 m .80796 .48638 L .82181 .51031 L p F P
0 g
s
.617 .5 .092 .1 k
.82181 .51031 m .81618 .52913 L .80273 .50457 L p F P
0 g
s
.883 .5 .892 .1 k
.56701 .29859 m .55793 .29596 L .56848 .28471 L p F P
0 g
s
.883 .5 .892 .1 k
.56848 .28471 m .58055 .28822 L .56701 .29859 L p F P
0 g
s
.317 .5 .408 .1 k
.38728 .84057 m .41224 .84718 L .41839 .86304 L p F P
0 g
s
.317 .5 .392 .1 k
.44287 .86796 m .41839 .86304 L .41224 .84718 L p F P
0 g
s
.883 .5 .775 .1 k
.49957 .29486 m .49028 .29714 L .47827 .28629 L p F P
0 g
s
.883 .5 .758 .1 k
.4665 .29022 m .47827 .28629 L .49028 .29714 L p F P
0 g
s
.517 .5 .125 .1 k
.81263 .6174 m .82492 .59956 L .82907 .62619 L p F P
0 g
s
.517 .5 .125 .1 k
.82907 .62619 m .81656 .64398 L .81263 .6174 L p F P
0 g
s
.717 .5 .592 .1 k
.27922 .4342 m .27901 .41744 L .30083 .40016 L p F P
0 g
s
.683 .5 .592 .1 k
.27901 .41744 m .27922 .4342 L .2599 .45464 L p F P
0 g
s
.883 .5 .875 .1 k
.55793 .29596 m .54848 .29401 L .55588 .28208 L p F P
0 g
s
.883 .5 .875 .1 k
.55588 .28208 m .56848 .28471 L .55793 .29596 L p F P
0 g
s
.85 .5 .958 .1 k
.62093 .31015 m .61227 .30363 L .63317 .29997 L p F P
0 g
s
.85 .5 .958 .1 k
.63317 .29997 m .64384 .30809 L .62093 .31015 L p F P
0 g
s
.45 .5 .492 .1 k
.27964 .73432 m .26079 .71983 L .25879 .69448 L p F P
0 g
s
.417 .5 .492 .1 k
.26079 .71983 m .27964 .73432 L .28412 .75819 L p F P
0 g
s
.417 .5 .475 .1 k
.30473 .77098 m .28412 .75819 L .27964 .73432 L p F P
0 g
s
.883 .5 .792 .1 k
.50917 .29327 m .49957 .29486 L .49064 .28323 L p F P
0 g
s
.883 .5 .775 .1 k
.47827 .28629 m .49064 .28323 L .49957 .29486 L p F P
0 g
s
.617 .5 .558 .1 k
.24024 .53796 m .23315 .51943 L .24682 .4952 L p F P
0 g
s
.583 .5 .558 .1 k
.23315 .51943 m .24024 .53796 L .22986 .56365 L p F P
0 g
s
.35 .5 .208 .1 k
.70761 .80912 m .7303 .79877 L .72185 .81859 L p F P
0 g
s
.35 .5 .208 .1 k
.72185 .81859 m .70015 .82838 L .70761 .80912 L p F P
0 g
s
.483 .5 .508 .1 k
.25879 .69448 m .24221 .67846 L .24309 .65218 L p F P
0 g
s
.45 .5 .508 .1 k
.24221 .67846 m .25879 .69448 L .26079 .71983 L p F P
0 g
s
.883 .5 .858 .1 k
.54848 .29401 m .53876 .29275 L .54292 .28039 L p F P
0 g
s
.883 .5 .858 .1 k
.54292 .28039 m .55588 .28208 L .54848 .29401 L p F P
0 g
s
.817 .5 .992 .1 k
.66082 .32625 m .65309 .31689 L .67685 .31937 L p F P
0 g
s
.817 .5 .992 .1 k
.67685 .31937 m .68589 .33047 L .66082 .32625 L p F P
0 g
s
.783 .5 .642 .1 k
.36307 .33599 m .35685 .34779 L .3318 .35728 L p F P
0 g
s
.783 .5 .625 .1 k
.32711 .37108 m .3318 .35728 L .35685 .34779 L p F P
0 g
s
.317 .5 .242 .1 k
.65253 .84417 m .67697 .83692 L .66878 .85344 L p F P
0 g
s
.317 .5 .242 .1 k
.66878 .85344 m .64571 .86022 L .65253 .84417 L p F P
0 g
s
.883 .5 .808 .1 k
.51899 .29238 m .50917 .29327 L .50344 .28109 L p F P
0 g
s
.883 .5 .792 .1 k
.49064 .28323 m .50344 .28109 L .50917 .29327 L p F P
0 g
s
.75 .5 .608 .1 k
.30083 .40016 m .30334 .38467 L .32711 .37108 L p F P
0 g
s
.717 .5 .608 .1 k
.30334 .38467 m .30083 .40016 L .27901 .41744 L p F P
0 g
s
.883 .5 .842 .1 k
.53876 .29275 m .52889 .2922 L .52975 .27966 L p F P
0 g
s
.883 .5 .842 .1 k
.52975 .27966 m .54292 .28039 L .53876 .29275 L p F P
0 g
s
.383 .5 .475 .1 k
.28412 .75819 m .30473 .77098 L .31122 .7929 L p F P
0 g
s
.383 .5 .458 .1 k
.33304 .80391 m .31122 .7929 L .30473 .77098 L p F P
0 g
s
.65 .5 .075 .1 k
.79136 .46382 m .7933 .44607 L .81019 .46775 L p F P
0 g
s
.65 .5 .075 .1 k
.81019 .46775 m .80796 .48638 L .79136 .46382 L p F P
0 g
s
.85 .5 .708 .1 k
.44527 .30049 m .43606 .30669 L .41416 .30378 L p F P
0 g
s
.85 .5 .692 .1 k
.40416 .31224 m .41416 .30378 L .43606 .30669 L p F P
0 g
s
.883 .5 .825 .1 k
.52889 .2922 m .51899 .29238 L .51654 .27989 L p F P
0 g
s
.883 .5 .808 .1 k
.50344 .28109 m .51654 .27989 L .51899 .29238 L p F P
0 g
s
.883 .5 .825 .1 k
.51654 .27989 m .52975 .27966 L .52889 .2922 L p F P
0 g
s
.75 .5 .625 .1 k
.3318 .35728 m .32711 .37108 L .30334 .38467 L p F P
0 g
s
.517 .5 .525 .1 k
.24309 .65218 m .22922 .63486 L .23327 .60825 L p F P
0 g
s
.483 .5 .525 .1 k
.22922 .63486 m .24309 .65218 L .24221 .67846 L p F P
0 g
s
.55 .5 .108 .1 k
.81771 .57318 m .82675 .55464 L .83427 .58085 L p F P
0 g
s
.55 .5 .108 .1 k
.83427 .58085 m .82492 .59956 L .81771 .57318 L p F P
0 g
s
.283 .5 .342 .1 k
.49367 .87392 m .51958 .87492 L .52004 .88726 L p F P
0 g
s
.283 .5 .325 .1 k
.51958 .87492 m .54553 .8746 L .54421 .88697 L p F P
0 g
s
.283 .5 .325 .1 k
.54421 .88697 m .52004 .88726 L .51958 .87492 L p F P
0 g
s
.283 .5 .308 .1 k
.54553 .8746 m .57133 .87296 L .56824 .88545 L p F P
0 g
s
.283 .5 .308 .1 k
.56824 .88545 m .54421 .88697 L .54553 .8746 L p F P
0 g
s
.85 .5 .942 .1 k
.61227 .30363 m .60258 .29775 L .62119 .29265 L p F P
0 g
s
.85 .5 .942 .1 k
.62119 .29265 m .63317 .29997 L .61227 .30363 L p F P
0 g
s
.817 .5 .675 .1 k
.40416 .31224 m .39563 .32133 L .3712 .32464 L p F P
0 g
s
.817 .5 .658 .1 k
.36307 .33599 m .3712 .32464 L .39563 .32133 L p F P
0 g
s
.317 .5 .425 .1 k
.36346 .83265 m .38728 .84057 L .39481 .85686 L p F P
0 g
s
.317 .5 .408 .1 k
.41839 .86304 m .39481 .85686 L .38728 .84057 L p F P
0 g
s
.283 .5 .358 .1 k
.46804 .87159 m .49367 .87392 L .49592 .88633 L p F P
0 g
s
.283 .5 .342 .1 k
.52004 .88726 m .49592 .88633 L .49367 .87392 L p F P
0 g
s
.65 .5 .575 .1 k
.24682 .4952 m .24313 .47675 L .2599 .45464 L p F P
0 g
s
.617 .5 .575 .1 k
.24313 .47675 m .24682 .4952 L .23315 .51943 L p F P
0 g
s
.783 .5 .008 .1 k
.69303 .34207 m .68589 .33047 L .70972 .33746 L p F P
0 g
s
.783 .5 .008 .1 k
.70972 .33746 m .71776 .35074 L .69303 .34207 L p F P
0 g
s
.683 .5 .058 .1 k
.77385 .42616 m .77274 .40934 L .79229 .42811 L p F P
0 g
s
.683 .5 .058 .1 k
.79229 .42811 m .7933 .44607 L .77385 .42616 L p F P
0 g
s
.283 .5 .292 .1 k
.57133 .87296 m .59677 .87001 L .59191 .88272 L p F P
0 g
s
.283 .5 .292 .1 k
.59191 .88272 m .56824 .88545 L .57133 .87296 L p F P
0 g
s
.35 .5 .458 .1 k
.31122 .7929 m .33304 .80391 L .34102 .82345 L p F P
0 g
s
.35 .5 .442 .1 k
.36346 .83265 m .34102 .82345 L .33304 .80391 L p F P
0 g
s
.85 .5 .725 .1 k
.45545 .29498 m .44527 .30049 L .42552 .29607 L p F P
0 g
s
.85 .5 .708 .1 k
.41416 .30378 m .42552 .29607 L .44527 .30049 L p F P
0 g
s
.417 .5 .158 .1 k
.78235 .7275 m .80007 .71244 L .79502 .73705 L p F P
0 g
s
.417 .5 .158 .1 k
.79502 .73705 m .77768 .7516 L .78235 .7275 L p F P
0 g
s
.55 .5 .542 .1 k
.23327 .60825 m .22248 .58994 L .22986 .56365 L p F P
0 g
s
.517 .5 .542 .1 k
.22248 .58994 m .23327 .60825 L .22922 .63486 L p F P
0 g
s
.283 .5 .375 .1 k
.44287 .86796 m .46804 .87159 L .47205 .88419 L p F P
0 g
s
.283 .5 .358 .1 k
.49592 .88633 m .47205 .88419 L .46804 .87159 L p F P
0 g
s
.717 .5 .042 .1 k
.75091 .3927 m .74717 .37726 L .76884 .39254 L p F P
0 g
s
.717 .5 .042 .1 k
.76884 .39254 m .77274 .40934 L .75091 .3927 L p F P
0 g
s
.75 .5 .025 .1 k
.72355 .36441 m .71776 .35074 L .74088 .36205 L p F P
0 g
s
.75 .5 .025 .1 k
.74088 .36205 m .74717 .37726 L .72355 .36441 L p F P
0 g
s
.383 .5 .175 .1 k
.75807 .76498 m .77768 .7516 L .77021 .77437 L p F P
0 g
s
.383 .5 .175 .1 k
.77021 .77437 m .75125 .78716 L .75807 .76498 L p F P
0 g
s
.45 .5 .142 .1 k
.80213 .68692 m .81746 .67037 L .81526 .69628 L p F P
0 g
s
.45 .5 .142 .1 k
.81526 .69628 m .80007 .71244 L .80213 .68692 L p F P
0 g
s
.817 .5 .975 .1 k
.65309 .31689 m .64384 .30809 L .66598 .30893 L p F P
0 g
s
.817 .5 .975 .1 k
.66598 .30893 m .67685 .31937 L .65309 .31689 L p F P
0 g
s
.583 .5 .092 .1 k
.81618 .52913 m .82181 .51031 L .83271 .53541 L p F P
0 g
s
.583 .5 .092 .1 k
.83271 .53541 m .82675 .55464 L .81618 .52913 L p F P
0 g
s
.317 .5 .225 .1 k
.67697 .83692 m .70015 .82838 L .69065 .84546 L p F P
0 g
s
.317 .5 .225 .1 k
.69065 .84546 m .66878 .85344 L .67697 .83692 L p F P
0 g
s
.85 .5 .925 .1 k
.60258 .29775 m .59197 .29259 L .60804 .28621 L p F P
0 g
s
.85 .5 .925 .1 k
.60804 .28621 m .62119 .29265 L .60258 .29775 L p F P
0 g
s
.283 .5 .275 .1 k
.59677 .87001 m .62163 .86575 L .61504 .8788 L p F P
0 g
s
.283 .5 .275 .1 k
.61504 .8788 m .59191 .88272 L .59677 .87001 L p F P
0 g
s
.683 .5 .592 .1 k
.2599 .45464 m .25949 .43676 L .27901 .41744 L p F P
0 g
s
.65 .5 .592 .1 k
.25949 .43676 m .2599 .45464 L .24313 .47675 L p F P
0 g
s
.783 .5 .658 .1 k
.3712 .32464 m .36307 .33599 L .33876 .34379 L p F P
0 g
s
.783 .5 .642 .1 k
.3318 .35728 m .33876 .34379 L .36307 .33599 L p F P
0 g
s
.483 .5 .125 .1 k
.81656 .64398 m .82907 .62619 L .83002 .65281 L p F P
0 g
s
.483 .5 .125 .1 k
.83002 .65281 m .81746 .67037 L .81656 .64398 L p F P
0 g
s
.85 .5 .742 .1 k
.4665 .29022 m .45545 .29498 L .43813 .28919 L p F P
0 g
s
.85 .5 .725 .1 k
.42552 .29607 m .43813 .28919 L .45545 .29498 L p F P
0 g
s
.283 .5 .392 .1 k
.41839 .86304 m .44287 .86796 L .44863 .88083 L p F P
0 g
s
.283 .5 .375 .1 k
.47205 .88419 m .44863 .88083 L .44287 .86796 L p F P
0 g
s
.35 .5 .192 .1 k
.7303 .79877 m .75125 .78716 L .74186 .80762 L p F P
0 g
s
.35 .5 .192 .1 k
.74186 .80762 m .72185 .81859 L .7303 .79877 L p F P
0 g
s
.817 .5 .692 .1 k
.41416 .30378 m .40416 .31224 L .3812 .31386 L p F P
0 g
s
.817 .5 .675 .1 k
.3712 .32464 m .3812 .31386 L .40416 .31224 L p F P
0 g
s
.583 .5 .558 .1 k
.22986 .56365 m .2224 .54473 L .23315 .51943 L p F P
0 g
s
.55 .5 .558 .1 k
.2224 .54473 m .22986 .56365 L .22248 .58994 L p F P
0 g
s
.717 .5 .608 .1 k
.27901 .41744 m .28156 .40061 L .30334 .38467 L p F P
0 g
s
.683 .5 .608 .1 k
.28156 .40061 m .27901 .41744 L .25949 .43676 L p F P
0 g
s
.617 .5 .075 .1 k
.80796 .48638 m .81019 .46775 L .8243 .49102 L p F P
0 g
s
.617 .5 .075 .1 k
.8243 .49102 m .82181 .51031 L .80796 .48638 L p F P
0 g
s
.85 .5 .908 .1 k
.59197 .29259 m .58055 .28822 L .59387 .28075 L p F P
0 g
s
.85 .5 .908 .1 k
.59387 .28075 m .60804 .28621 L .59197 .29259 L p F P
0 g
s
.75 .5 .642 .1 k
.33876 .34379 m .3318 .35728 L .3084 .36933 L p F P
0 g
s
.75 .5 .625 .1 k
.30334 .38467 m .3084 .36933 L .3318 .35728 L p F P
0 g
s
.317 .5 .442 .1 k
.34102 .82345 m .36346 .83265 L .37233 .84945 L p F P
0 g
s
.317 .5 .425 .1 k
.39481 .85686 m .37233 .84945 L .36346 .83265 L p F P
0 g
s
.283 .5 .258 .1 k
.62163 .86575 m .64571 .86022 L .63742 .8737 L p F P
0 g
s
.283 .5 .258 .1 k
.63742 .8737 m .61504 .8788 L .62163 .86575 L p F P
0 g
s
.717 .5 .625 .1 k
.3084 .36933 m .30334 .38467 L .28156 .40061 L p F P
0 g
s
.45 .5 .508 .1 k
.26079 .71983 m .24435 .70418 L .24221 .67846 L p F P
0 g
s
.417 .5 .508 .1 k
.24435 .70418 m .26079 .71983 L .26566 .74419 L p F P
0 g
s
.417 .5 .492 .1 k
.28412 .75819 m .26566 .74419 L .26079 .71983 L p F P
0 g
s
.783 .5 .992 .1 k
.68589 .33047 m .67685 .31937 L .69948 .32474 L p F P
0 g
s
.783 .5 .992 .1 k
.69948 .32474 m .70972 .33746 L .68589 .33047 L p F P
0 g
s
.85 .5 .758 .1 k
.47827 .28629 m .4665 .29022 L .45183 .28325 L p F P
0 g
s
.85 .5 .742 .1 k
.43813 .28919 m .45183 .28325 L .4665 .29022 L p F P
0 g
s
.383 .5 .492 .1 k
.26566 .74419 m .28412 .75819 L .29128 .78067 L p F P
0 g
s
.383 .5 .475 .1 k
.31122 .7929 m .29128 .78067 L .28412 .75819 L p F P
0 g
s
.817 .5 .958 .1 k
.64384 .30809 m .63317 .29997 L .6534 .29928 L p F P
0 g
s
.817 .5 .958 .1 k
.6534 .29928 m .66598 .30893 L .64384 .30809 L p F P
0 g
s
.517 .5 .108 .1 k
.82492 .59956 m .83427 .58085 L .83859 .60753 L p F P
0 g
s
.517 .5 .108 .1 k
.83859 .60753 m .82907 .62619 L .82492 .59956 L p F P
0 g
s
.483 .5 .525 .1 k
.24221 .67846 m .22829 .66137 L .22922 .63486 L p F P
0 g
s
.45 .5 .525 .1 k
.22829 .66137 m .24221 .67846 L .24435 .70418 L p F P
0 g
s
.85 .5 .892 .1 k
.58055 .28822 m .56848 .28471 L .57885 .27635 L p F P
0 g
s
.85 .5 .892 .1 k
.57885 .27635 m .59387 .28075 L .58055 .28822 L p F P
0 g
s
.617 .5 .575 .1 k
.23315 .51943 m .22913 .50035 L .24313 .47675 L p F P
0 g
s
.583 .5 .575 .1 k
.22913 .50035 m .23315 .51943 L .2224 .54473 L p F P
0 g
s
.65 .5 .058 .1 k
.7933 .44607 m .79229 .42811 L .8093 .44887 L p F P
0 g
s
.65 .5 .058 .1 k
.8093 .44887 m .81019 .46775 L .7933 .44607 L p F P
0 g
s
.283 .5 .408 .1 k
.39481 .85686 m .41839 .86304 L .42587 .8763 L p F P
0 g
s
.283 .5 .392 .1 k
.44863 .88083 m .42587 .8763 L .41839 .86304 L p F P
0 g
s
.35 .5 .475 .1 k
.29128 .78067 m .31122 .7929 L .32017 .81304 L p F P
0 g
s
.35 .5 .458 .1 k
.34102 .82345 m .32017 .81304 L .31122 .7929 L p F P
0 g
s
.85 .5 .775 .1 k
.49064 .28323 m .47827 .28629 L .46646 .27833 L p F P
0 g
s
.85 .5 .758 .1 k
.45183 .28325 m .46646 .27833 L .47827 .28629 L p F P
0 g
s
.317 .5 .208 .1 k
.70015 .82838 m .72185 .81859 L .7111 .83632 L p F P
0 g
s
.317 .5 .208 .1 k
.7111 .83632 m .69065 .84546 L .70015 .82838 L p F P
0 g
s
.817 .5 .708 .1 k
.42552 .29607 m .41416 .30378 L .39297 .30381 L p F P
0 g
s
.817 .5 .692 .1 k
.3812 .31386 m .39297 .30381 L .41416 .30378 L p F P
0 g
s
.75 .5 .008 .1 k
.71776 .35074 m .70972 .33746 L .73205 .34724 L p F P
0 g
s
.75 .5 .008 .1 k
.73205 .34724 m .74088 .36205 L .71776 .35074 L p F P
0 g
s
.85 .5 .875 .1 k
.56848 .28471 m .55588 .28208 L .56317 .27307 L p F P
0 g
s
.85 .5 .875 .1 k
.56317 .27307 m .57885 .27635 L .56848 .28471 L p F P
0 g
s
.783 .5 .675 .1 k
.3812 .31386 m .3712 .32464 L .34796 .33078 L p F P
0 g
s
.783 .5 .658 .1 k
.33876 .34379 m .34796 .33078 L .3712 .32464 L p F P
0 g
s
.683 .5 .042 .1 k
.77274 .40934 m .76884 .39254 L .78827 .41015 L p F P
0 g
s
.683 .5 .042 .1 k
.78827 .41015 m .79229 .42811 L .77274 .40934 L p F P
0 g
s
.517 .5 .542 .1 k
.22922 .63486 m .21824 .6166 L .22248 .58994 L p F P
0 g
s
.483 .5 .542 .1 k
.21824 .6166 m .22922 .63486 L .22829 .66137 L p F P
0 g
s
.55 .5 .092 .1 k
.82675 .55464 m .83271 .53541 L .84047 .56144 L p F P
0 g
s
.55 .5 .092 .1 k
.84047 .56144 m .83427 .58085 L .82675 .55464 L p F P
0 g
s
.283 .5 .242 .1 k
.64571 .86022 m .66878 .85344 L .65885 .86746 L p F P
0 g
s
.283 .5 .242 .1 k
.65885 .86746 m .63742 .8737 L .64571 .86022 L p F P
0 g
s
.717 .5 .025 .1 k
.74717 .37726 m .74088 .36205 L .76212 .37595 L p F P
0 g
s
.717 .5 .025 .1 k
.76212 .37595 m .76884 .39254 L .74717 .37726 L p F P
0 g
s
.85 .5 .792 .1 k
.50344 .28109 m .49064 .28323 L .48185 .27451 L p F P
0 g
s
.85 .5 .775 .1 k
.46646 .27833 m .48185 .27451 L .49064 .28323 L p F P
0 g
s
.85 .5 .858 .1 k
.55588 .28208 m .54292 .28039 L .54701 .27096 L p F P
0 g
s
.85 .5 .858 .1 k
.54701 .27096 m .56317 .27307 L .55588 .28208 L p F P
0 g
s
.65 .5 .592 .1 k
.24313 .47675 m .24251 .45797 L .25949 .43676 L p F P
0 g
s
.617 .5 .592 .1 k
.24251 .45797 m .24313 .47675 L .22913 .50035 L p F P
0 g
s
.817 .5 .942 .1 k
.63317 .29997 m .62119 .29265 L .63924 .29056 L p F P
0 g
s
.817 .5 .942 .1 k
.63924 .29056 m .6534 .29928 L .63317 .29997 L p F P
0 g
s
.383 .5 .158 .1 k
.77768 .7516 m .79502 .73705 L .78697 .76047 L p F P
0 g
s
.383 .5 .158 .1 k
.78697 .76047 m .77021 .77437 L .77768 .7516 L p F P
0 g
s
.417 .5 .142 .1 k
.80007 .71244 m .81526 .69628 L .80988 .72145 L p F P
0 g
s
.417 .5 .142 .1 k
.80988 .72145 m .79502 .73705 L .80007 .71244 L p F P
0 g
s
.85 .5 .808 .1 k
.51654 .27989 m .50344 .28109 L .4978 .27183 L p F P
0 g
s
.85 .5 .792 .1 k
.48185 .27451 m .4978 .27183 L .50344 .28109 L p F P
0 g
s
.85 .5 .842 .1 k
.54292 .28039 m .52975 .27966 L .53059 .27004 L p F P
0 g
s
.85 .5 .842 .1 k
.53059 .27004 m .54701 .27096 L .54292 .28039 L p F P
0 g
s
.85 .5 .825 .1 k
.52975 .27966 m .51654 .27989 L .51412 .27033 L p F P
0 g
s
.85 .5 .808 .1 k
.4978 .27183 m .51412 .27033 L .51654 .27989 L p F P
0 g
s
.85 .5 .825 .1 k
.51412 .27033 m .53059 .27004 L .52975 .27966 L p F P
0 g
s
.317 .5 .458 .1 k
.32017 .81304 m .34102 .82345 L .35118 .84086 L p F P
0 g
s
.317 .5 .442 .1 k
.37233 .84945 m .35118 .84086 L .34102 .82345 L p F P
0 g
s
.783 .5 .975 .1 k
.67685 .31937 m .66598 .30893 L .68711 .31275 L p F P
0 g
s
.783 .5 .975 .1 k
.68711 .31275 m .69948 .32474 L .67685 .31937 L p F P
0 g
s
.35 .5 .175 .1 k
.75125 .78716 m .77021 .77437 L .75995 .79554 L p F P
0 g
s
.35 .5 .175 .1 k
.75995 .79554 m .74186 .80762 L .75125 .78716 L p F P
0 g
s
.283 .5 .425 .1 k
.37233 .84945 m .39481 .85686 L .40396 .8706 L p F P
0 g
s
.283 .5 .408 .1 k
.42587 .8763 m .40396 .8706 L .39481 .85686 L p F P
0 g
s
.55 .5 .558 .1 k
.22248 .58994 m .21474 .57085 L .2224 .54473 L p F P
0 g
s
.517 .5 .558 .1 k
.21474 .57085 m .22248 .58994 L .21824 .6166 L p F P
0 g
s
.45 .5 .125 .1 k
.81746 .67037 m .83002 .65281 L .8277 .67915 L p F P
0 g
s
.45 .5 .125 .1 k
.8277 .67915 m .81526 .69628 L .81746 .67037 L p F P
0 g
s
.75 .5 .658 .1 k
.34796 .33078 m .33876 .34379 L .31602 .3543 L p F P
0 g
s
.75 .5 .642 .1 k
.3084 .36933 m .31602 .3543 L .33876 .34379 L p F P
0 g
s
.817 .5 .725 .1 k
.43813 .28919 m .42552 .29607 L .40639 .29463 L p F P
0 g
s
.817 .5 .708 .1 k
.39297 .30381 m .40639 .29463 L .42552 .29607 L p F P
0 g
s
.25 .5 .342 .1 k
.49592 .88633 m .52004 .88726 L .52058 .89666 L p F P
0 g
s
.25 .5 .325 .1 k
.52004 .88726 m .54421 .88697 L .54266 .8964 L p F P
0 g
s
.25 .5 .325 .1 k
.54266 .8964 m .52058 .89666 L .52004 .88726 L p F P
0 g
s
.683 .5 .608 .1 k
.25949 .43676 m .26205 .41878 L .28156 .40061 L p F P
0 g
s
.65 .5 .608 .1 k
.26205 .41878 m .25949 .43676 L .24251 .45797 L p F P
0 g
s
.583 .5 .075 .1 k
.82181 .51031 m .8243 .49102 L .83542 .51569 L p F P
0 g
s
.583 .5 .075 .1 k
.83542 .51569 m .83271 .53541 L .82181 .51031 L p F P
0 g
s
.25 .5 .308 .1 k
.54421 .88697 m .56824 .88545 L .5646 .89502 L p F P
0 g
s
.25 .5 .308 .1 k
.5646 .89502 m .54266 .8964 L .54421 .88697 L p F P
0 g
s
.25 .5 .358 .1 k
.47205 .88419 m .49592 .88633 L .49856 .89582 L p F P
0 g
s
.25 .5 .342 .1 k
.52058 .89666 m .49856 .89582 L .49592 .88633 L p F P
0 g
s
.717 .5 .642 .1 k
.31602 .3543 m .3084 .36933 L .28693 .38389 L p F P
0 g
s
.717 .5 .625 .1 k
.28156 .40061 m .28693 .38389 L .3084 .36933 L p F P
0 g
s
.683 .5 .625 .1 k
.28693 .38389 m .28156 .40061 L .26205 .41878 L p F P
0 g
s
.25 .5 .292 .1 k
.56824 .88545 m .59191 .88272 L .58621 .89255 L p F P
0 g
s
.25 .5 .292 .1 k
.58621 .89255 m .5646 .89502 L .56824 .88545 L p F P
0 g
s
.817 .5 .925 .1 k
.62119 .29265 m .60804 .28621 L .62365 .28288 L p F P
0 g
s
.817 .5 .925 .1 k
.62365 .28288 m .63924 .29056 L .62119 .29265 L p F P
0 g
s
.283 .5 .225 .1 k
.66878 .85344 m .69065 .84546 L .67914 .86011 L p F P
0 g
s
.283 .5 .225 .1 k
.67914 .86011 m .65885 .86746 L .66878 .85344 L p F P
0 g
s
.783 .5 .692 .1 k
.39297 .30381 m .3812 .31386 L .35931 .31842 L p F P
0 g
s
.783 .5 .675 .1 k
.34796 .33078 m .35931 .31842 L .3812 .31386 L p F P
0 g
s
.483 .5 .108 .1 k
.82907 .62619 m .83859 .60753 L .83959 .6344 L p F P
0 g
s
.483 .5 .108 .1 k
.83959 .6344 m .83002 .65281 L .82907 .62619 L p F P
0 g
s
.25 .5 .375 .1 k
.44863 .88083 m .47205 .88419 L .47676 .89387 L p F P
0 g
s
.25 .5 .358 .1 k
.49856 .89582 m .47676 .89387 L .47205 .88419 L p F P
0 g
s
.317 .5 .192 .1 k
.72185 .81859 m .74186 .80762 L .72992 .82609 L p F P
0 g
s
.317 .5 .192 .1 k
.72992 .82609 m .7111 .83632 L .72185 .81859 L p F P
0 g
s
.583 .5 .575 .1 k
.2224 .54473 m .2181 .52522 L .22913 .50035 L p F P
0 g
s
.55 .5 .575 .1 k
.2181 .52522 m .2224 .54473 L .21474 .57085 L p F P
0 g
s
.617 .5 .058 .1 k
.81019 .46775 m .8093 .44887 L .82352 .47146 L p F P
0 g
s
.617 .5 .058 .1 k
.82352 .47146 m .8243 .49102 L .81019 .46775 L p F P
0 g
s
.417 .5 .508 .1 k
.26566 .74419 m .24957 .72908 L .24435 .70418 L p F P
0 g
s
.383 .5 .508 .1 k
.24957 .72908 m .26566 .74419 L .27343 .76729 L p F P
0 g
s
.383 .5 .492 .1 k
.29128 .78067 m .27343 .76729 L .26566 .74419 L p F P
0 g
s
.75 .5 .992 .1 k
.70972 .33746 m .69948 .32474 L .72071 .33304 L p F P
0 g
s
.75 .5 .992 .1 k
.72071 .33304 m .73205 .34724 L .70972 .33746 L p F P
0 g
s
.25 .5 .275 .1 k
.59191 .88272 m .61504 .8788 L .60731 .88899 L p F P
0 g
s
.25 .5 .275 .1 k
.60731 .88899 m .58621 .89255 L .59191 .88272 L p F P
0 g
s
.817 .5 .742 .1 k
.45183 .28325 m .43813 .28919 L .42132 .28644 L p F P
0 g
s
.817 .5 .725 .1 k
.40639 .29463 m .42132 .28644 L .43813 .28919 L p F P
0 g
s
.45 .5 .525 .1 k
.24435 .70418 m .23056 .6875 L .22829 .66137 L p F P
0 g
s
.417 .5 .525 .1 k
.23056 .6875 m .24435 .70418 L .24957 .72908 L p F P
0 g
s
.35 .5 .492 .1 k
.27343 .76729 m .29128 .78067 L .30113 .80148 L p F P
0 g
s
.35 .5 .475 .1 k
.32017 .81304 m .30113 .80148 L .29128 .78067 L p F P
0 g
s
.783 .5 .958 .1 k
.66598 .30893 m .6534 .29928 L .67274 .30166 L p F P
0 g
s
.783 .5 .958 .1 k
.67274 .30166 m .68711 .31275 L .66598 .30893 L p F P
0 g
s
.283 .5 .442 .1 k
.35118 .84086 m .37233 .84945 L .3831 .86378 L p F P
0 g
s
.283 .5 .425 .1 k
.40396 .8706 m .3831 .86378 L .37233 .84945 L p F P
0 g
s
.25 .5 .392 .1 k
.42587 .8763 m .44863 .88083 L .4554 .89084 L p F P
0 g
s
.25 .5 .375 .1 k
.47676 .89387 m .4554 .89084 L .44863 .88083 L p F P
0 g
s
.65 .5 .042 .1 k
.79229 .42811 m .78827 .41015 L .8052 .42997 L p F P
0 g
s
.65 .5 .042 .1 k
.8052 .42997 m .8093 .44887 L .79229 .42811 L p F P
0 g
s
.817 .5 .908 .1 k
.60804 .28621 m .59387 .28075 L .60682 .27637 L p F P
0 g
s
.817 .5 .908 .1 k
.60682 .27637 m .62365 .28288 L .60804 .28621 L p F P
0 g
s
.517 .5 .092 .1 k
.83427 .58085 m .84047 .56144 L .84493 .58816 L p F P
0 g
s
.517 .5 .092 .1 k
.84493 .58816 m .83859 .60753 L .83427 .58085 L p F P
0 g
s
.717 .5 .008 .1 k
.74088 .36205 m .73205 .34724 L .75258 .35979 L p F P
0 g
s
.717 .5 .008 .1 k
.75258 .35979 m .76212 .37595 L .74088 .36205 L p F P
0 g
s
.483 .5 .542 .1 k
.22829 .66137 m .21726 .64335 L .21824 .6166 L p F P
0 g
s
.45 .5 .542 .1 k
.21726 .64335 m .22829 .66137 L .23056 .6875 L p F P
0 g
s
.683 .5 .025 .1 k
.76884 .39254 m .76212 .37595 L .78119 .39239 L p F P
0 g
s
.683 .5 .025 .1 k
.78119 .39239 m .78827 .41015 L .76884 .39254 L p F P
0 g
s
.617 .5 .592 .1 k
.22913 .50035 m .22832 .48089 L .24251 .45797 L p F P
0 g
s
.583 .5 .592 .1 k
.22832 .48089 m .22913 .50035 L .2181 .52522 L p F P
0 g
s
.25 .5 .258 .1 k
.61504 .8788 m .63742 .8737 L .6277 .88437 L p F P
0 g
s
.25 .5 .258 .1 k
.6277 .88437 m .60731 .88899 L .61504 .8788 L p F P
0 g
s
.317 .5 .475 .1 k
.30113 .80148 m .32017 .81304 L .33155 .83115 L p F P
0 g
s
.317 .5 .458 .1 k
.35118 .84086 m .33155 .83115 L .32017 .81304 L p F P
0 g
s
.817 .5 .758 .1 k
.46646 .27833 m .45183 .28325 L .43758 .27935 L p F P
0 g
s
.817 .5 .742 .1 k
.42132 .28644 m .43758 .27935 L .45183 .28325 L p F P
0 g
s
.75 .5 .675 .1 k
.35931 .31842 m .34796 .33078 L .32616 .33978 L p F P
0 g
s
.75 .5 .658 .1 k
.31602 .3543 m .32616 .33978 L .34796 .33078 L p F P
0 g
s
.783 .5 .708 .1 k
.40639 .29463 m .39297 .30381 L .37274 .30687 L p F P
0 g
s
.783 .5 .692 .1 k
.35931 .31842 m .37274 .30687 L .39297 .30381 L p F P
0 g
s
.283 .5 .208 .1 k
.69065 .84546 m .7111 .83632 L .69807 .85171 L p F P
0 g
s
.283 .5 .208 .1 k
.69807 .85171 m .67914 .86011 L .69065 .84546 L p F P
0 g
s
.383 .5 .142 .1 k
.79502 .73705 m .80988 .72145 L .8013 .74558 L p F P
0 g
s
.383 .5 .142 .1 k
.8013 .74558 m .78697 .76047 L .79502 .73705 L p F P
0 g
s
.817 .5 .892 .1 k
.59387 .28075 m .57885 .27635 L .58895 .27111 L p F P
0 g
s
.817 .5 .892 .1 k
.58895 .27111 m .60682 .27637 L .59387 .28075 L p F P
0 g
s
.517 .5 .558 .1 k
.21824 .6166 m .21034 .59755 L .21474 .57085 L p F P
0 g
s
.483 .5 .558 .1 k
.21034 .59755 m .21824 .6166 L .21726 .64335 L p F P
0 g
s
.25 .5 .408 .1 k
.40396 .8706 m .42587 .8763 L .43464 .88673 L p F P
0 g
s
.25 .5 .392 .1 k
.4554 .89084 m .43464 .88673 L .42587 .8763 L p F P
0 g
s
.35 .5 .158 .1 k
.77021 .77437 m .78697 .76047 L .7759 .78242 L p F P
0 g
s
.35 .5 .158 .1 k
.7759 .78242 m .75995 .79554 L .77021 .77437 L p F P
0 g
s
.55 .5 .075 .1 k
.83271 .53541 m .83542 .51569 L .84334 .54152 L p F P
0 g
s
.55 .5 .075 .1 k
.84334 .54152 m .84047 .56144 L .83271 .53541 L p F P
0 g
s
.65 .5 .608 .1 k
.24251 .45797 m .24506 .43905 L .26205 .41878 L p F P
0 g
s
.617 .5 .608 .1 k
.24506 .43905 m .24251 .45797 L .22832 .48089 L p F P
0 g
s
.417 .5 .125 .1 k
.81526 .69628 m .8277 .67915 L .82203 .70491 L p F P
0 g
s
.417 .5 .125 .1 k
.82203 .70491 m .80988 .72145 L .81526 .69628 L p F P
0 g
s
.817 .5 .775 .1 k
.48185 .27451 m .46646 .27833 L .45497 .27348 L p F P
0 g
s
.817 .5 .758 .1 k
.43758 .27935 m .45497 .27348 L .46646 .27833 L p F P
0 g
s
.717 .5 .658 .1 k
.32616 .33978 m .31602 .3543 L .29511 .3675 L p F P
0 g
s
.717 .5 .642 .1 k
.28693 .38389 m .29511 .3675 L .31602 .3543 L p F P
0 g
s
.783 .5 .942 .1 k
.6534 .29928 m .63924 .29056 L .65651 .29161 L p F P
0 g
s
.783 .5 .942 .1 k
.65651 .29161 m .67274 .30166 L .6534 .29928 L p F P
0 g
s
.75 .5 .975 .1 k
.69948 .32474 m .68711 .31275 L .70697 .31963 L p F P
0 g
s
.75 .5 .975 .1 k
.70697 .31963 m .72071 .33304 L .69948 .32474 L p F P
0 g
s
.817 .5 .875 .1 k
.57885 .27635 m .56317 .27307 L .57026 .26719 L p F P
0 g
s
.817 .5 .875 .1 k
.57026 .26719 m .58895 .27111 L .57885 .27635 L p F P
0 g
s
.683 .5 .625 .1 k
.26205 .41878 m .26765 .40089 L .28693 .38389 L p F P
0 g
s
.65 .5 .625 .1 k
.26765 .40089 m .26205 .41878 L .24506 .43905 L p F P
0 g
s
.25 .5 .242 .1 k
.63742 .8737 m .65885 .86746 L .64721 .87872 L p F P
0 g
s
.25 .5 .242 .1 k
.64721 .87872 m .6277 .88437 L .63742 .8737 L p F P
0 g
s
.317 .5 .175 .1 k
.74186 .80762 m .75995 .79554 L .7469 .81483 L p F P
0 g
s
.317 .5 .175 .1 k
.7469 .81483 m .72992 .82609 L .74186 .80762 L p F P
0 g
s
.683 .5 .642 .1 k
.29511 .3675 m .28693 .38389 L .26765 .40089 L p F P
0 g
s
.45 .5 .108 .1 k
.83002 .65281 m .83959 .6344 L .83716 .66118 L p F P
0 g
s
.45 .5 .108 .1 k
.83716 .66118 m .8277 .67915 L .83002 .65281 L p F P
0 g
s
.283 .5 .458 .1 k
.33155 .83115 m .35118 .84086 L .36349 .85588 L p F P
0 g
s
.283 .5 .442 .1 k
.3831 .86378 m .36349 .85588 L .35118 .84086 L p F P
0 g
s
.817 .5 .792 .1 k
.4978 .27183 m .48185 .27451 L .4733 .26891 L p F P
0 g
s
.817 .5 .775 .1 k
.45497 .27348 m .4733 .26891 L .48185 .27451 L p F P
0 g
s
.55 .5 .575 .1 k
.21474 .57085 m .21025 .55115 L .2181 .52522 L p F P
0 g
s
.517 .5 .575 .1 k
.21025 .55115 m .21474 .57085 L .21034 .59755 L p F P
0 g
s
.583 .5 .058 .1 k
.8243 .49102 m .82352 .47146 L .83474 .49567 L p F P
0 g
s
.583 .5 .058 .1 k
.83474 .49567 m .83542 .51569 L .8243 .49102 L p F P
0 g
s
.817 .5 .858 .1 k
.56317 .27307 m .54701 .27096 L .551 .26466 L p F P
0 g
s
.817 .5 .858 .1 k
.551 .26466 m .57026 .26719 L .56317 .27307 L p F P
0 g
s
.783 .5 .725 .1 k
.42132 .28644 m .40639 .29463 L .38809 .29631 L p F P
0 g
s
.783 .5 .708 .1 k
.37274 .30687 m .38809 .29631 L .40639 .29463 L p F P
0 g
s
.25 .5 .425 .1 k
.3831 .86378 m .40396 .8706 L .41468 .88157 L p F P
0 g
s
.25 .5 .408 .1 k
.43464 .88673 m .41468 .88157 L .40396 .8706 L p F P
0 g
s
.817 .5 .808 .1 k
.51412 .27033 m .4978 .27183 L .49231 .2657 L p F P
0 g
s
.817 .5 .792 .1 k
.4733 .26891 m .49231 .2657 L .4978 .27183 L p F P
0 g
s
.817 .5 .842 .1 k
.54701 .27096 m .53059 .27004 L .53142 .26356 L p F P
0 g
s
.817 .5 .842 .1 k
.53142 .26356 m .551 .26466 L .54701 .27096 L p F P
0 g
s
.383 .5 .508 .1 k
.27343 .76729 m .25791 .75286 L .24957 .72908 L p F P
0 g
s
.35 .5 .508 .1 k
.25791 .75286 m .27343 .76729 L .28412 .78885 L p F P
0 g
s
.35 .5 .492 .1 k
.30113 .80148 m .28412 .78885 L .27343 .76729 L p F P
0 g
s
.75 .5 .692 .1 k
.37274 .30687 m .35931 .31842 L .33876 .32596 L p F P
0 g
s
.75 .5 .675 .1 k
.32616 .33978 m .33876 .32596 L .35931 .31842 L p F P
0 g
s
.417 .5 .525 .1 k
.24957 .72908 m .23609 .71297 L .23056 .6875 L p F P
0 g
s
.383 .5 .525 .1 k
.23609 .71297 m .24957 .72908 L .25791 .75286 L p F P
0 g
s
.717 .5 .992 .1 k
.73205 .34724 m .72071 .33304 L .74028 .34426 L p F P
0 g
s
.717 .5 .992 .1 k
.74028 .34426 m .75258 .35979 L .73205 .34724 L p F P
0 g
s
.817 .5 .825 .1 k
.53059 .27004 m .51412 .27033 L .51177 .26391 L p F P
0 g
s
.817 .5 .808 .1 k
.49231 .2657 m .51177 .26391 L .51412 .27033 L p F P
0 g
s
.817 .5 .825 .1 k
.51177 .26391 m .53142 .26356 L .53059 .27004 L p F P
0 g
s
.617 .5 .042 .1 k
.8093 .44887 m .8052 .42997 L .81937 .45184 L p F P
0 g
s
.617 .5 .042 .1 k
.81937 .45184 m .82352 .47146 L .8093 .44887 L p F P
0 g
s
.483 .5 .092 .1 k
.83859 .60753 m .84493 .58816 L .84596 .61528 L p F P
0 g
s
.483 .5 .092 .1 k
.84596 .61528 m .83959 .6344 L .83859 .60753 L p F P
0 g
s
.783 .5 .925 .1 k
.63924 .29056 m .62365 .28288 L .6386 .28277 L p F P
0 g
s
.783 .5 .925 .1 k
.6386 .28277 m .65651 .29161 L .63924 .29056 L p F P
0 g
s
.283 .5 .192 .1 k
.7111 .83632 m .72992 .82609 L .71547 .8423 L p F P
0 g
s
.283 .5 .192 .1 k
.71547 .8423 m .69807 .85171 L .7111 .83632 L p F P
0 g
s
.583 .5 .592 .1 k
.2181 .52522 m .21714 .50532 L .22832 .48089 L p F P
0 g
s
.55 .5 .592 .1 k
.21714 .50532 m .2181 .52522 L .21025 .55115 L p F P
0 g
s
.45 .5 .542 .1 k
.23056 .6875 m .21964 .66992 L .21726 .64335 L p F P
0 g
s
.417 .5 .542 .1 k
.21964 .66992 m .23056 .6875 L .23609 .71297 L p F P
0 g
s
.217 .5 .342 .1 k
.49856 .89582 m .52058 .89666 L .52121 .9029 L p F P
0 g
s
.217 .5 .325 .1 k
.52058 .89666 m .54266 .8964 L .54088 .90266 L p F P
0 g
s
.217 .5 .325 .1 k
.54088 .90266 m .52121 .9029 L .52058 .89666 L p F P
0 g
s
.317 .5 .492 .1 k
.28412 .78885 m .30113 .80148 L .31365 .82037 L p F P
0 g
s
.317 .5 .475 .1 k
.33155 .83115 m .31365 .82037 L .30113 .80148 L p F P
0 g
s
.217 .5 .308 .1 k
.54266 .8964 m .5646 .89502 L .56044 .90145 L p F P
0 g
s
.217 .5 .308 .1 k
.56044 .90145 m .54088 .90266 L .54266 .8964 L p F P
0 g
s
.25 .5 .225 .1 k
.65885 .86746 m .67914 .86011 L .66565 .87208 L p F P
0 g
s
.25 .5 .225 .1 k
.66565 .87208 m .64721 .87872 L .65885 .86746 L p F P
0 g
s
.683 .5 .008 .1 k
.76212 .37595 m .75258 .35979 L .77106 .37506 L p F P
0 g
s
.683 .5 .008 .1 k
.77106 .37506 m .78119 .39239 L .76212 .37595 L p F P
0 g
s
.65 .5 .025 .1 k
.78827 .41015 m .78119 .39239 L .79783 .41125 L p F P
0 g
s
.65 .5 .025 .1 k
.79783 .41125 m .8052 .42997 L .78827 .41015 L p F P
0 g
s
.217 .5 .358 .1 k
.47676 .89387 m .49856 .89582 L .50157 .90215 L p F P
0 g
s
.217 .5 .342 .1 k
.52121 .9029 m .50157 .90215 L .49856 .89582 L p F P
0 g
s
.217 .5 .292 .1 k
.5646 .89502 m .58621 .89255 L .57969 .89925 L p F P
0 g
s
.217 .5 .292 .1 k
.57969 .89925 m .56044 .90145 L .5646 .89502 L p F P
0 g
s
.75 .5 .958 .1 k
.68711 .31275 m .67274 .30166 L .69094 .3072 L p F P
0 g
s
.75 .5 .958 .1 k
.69094 .3072 m .70697 .31963 L .68711 .31275 L p F P
0 g
s
.783 .5 .742 .1 k
.43758 .27935 m .42132 .28644 L .40522 .28686 L p F P
0 g
s
.783 .5 .725 .1 k
.38809 .29631 m .40522 .28686 L .42132 .28644 L p F P
0 g
s
.217 .5 .375 .1 k
.4554 .89084 m .47676 .89387 L .48216 .90043 L p F P
0 g
s
.217 .5 .358 .1 k
.50157 .90215 m .48216 .90043 L .47676 .89387 L p F P
0 g
s
.483 .5 .558 .1 k
.21726 .64335 m .20932 .62455 L .21034 .59755 L p F P
0 g
s
.45 .5 .558 .1 k
.20932 .62455 m .21726 .64335 L .21964 .66992 L p F P
0 g
s
.517 .5 .075 .1 k
.84047 .56144 m .84334 .54152 L .8479 .56827 L p F P
0 g
s
.517 .5 .075 .1 k
.8479 .56827 m .84493 .58816 L .84047 .56144 L p F P
0 g
s
.717 .5 .675 .1 k
.33876 .32596 m .32616 .33978 L .30609 .35164 L p F P
0 g
s
.717 .5 .658 .1 k
.29511 .3675 m .30609 .35164 L .32616 .33978 L p F P
0 g
s
.617 .5 .608 .1 k
.22832 .48089 m .23084 .46127 L .24506 .43905 L p F P
0 g
s
.583 .5 .608 .1 k
.23084 .46127 m .22832 .48089 L .21714 .50532 L p F P
0 g
s
.25 .5 .442 .1 k
.36349 .85588 m .3831 .86378 L .3957 .8754 L p F P
0 g
s
.25 .5 .425 .1 k
.41468 .88157 m .3957 .8754 L .3831 .86378 L p F P
0 g
s
.217 .5 .275 .1 k
.58621 .89255 m .60731 .88899 L .59846 .8961 L p F P
0 g
s
.217 .5 .275 .1 k
.59846 .8961 m .57969 .89925 L .58621 .89255 L p F P
0 g
s
.35 .5 .142 .1 k
.78697 .76047 m .8013 .74558 L .78951 .76838 L p F P
0 g
s
.35 .5 .142 .1 k
.78951 .76838 m .7759 .78242 L .78697 .76047 L p F P
0 g
s
.283 .5 .475 .1 k
.31365 .82037 m .33155 .83115 L .34532 .84695 L p F P
0 g
s
.283 .5 .458 .1 k
.36349 .85588 m .34532 .84695 L .33155 .83115 L p F P
0 g
s
.783 .5 .908 .1 k
.62365 .28288 m .60682 .27637 L .61923 .27525 L p F P
0 g
s
.783 .5 .908 .1 k
.61923 .27525 m .6386 .28277 L .62365 .28288 L p F P
0 g
s
.383 .5 .125 .1 k
.80988 .72145 m .82203 .70491 L .81298 .7298 L p F P
0 g
s
.383 .5 .125 .1 k
.81298 .7298 m .8013 .74558 L .80988 .72145 L p F P
0 g
s
.317 .5 .158 .1 k
.75995 .79554 m .7759 .78242 L .76185 .80261 L p F P
0 g
s
.317 .5 .158 .1 k
.76185 .80261 m .7469 .81483 L .75995 .79554 L p F P
0 g
s
.217 .5 .392 .1 k
.43464 .88673 m .4554 .89084 L .46313 .89773 L p F P
0 g
s
.217 .5 .375 .1 k
.48216 .90043 m .46313 .89773 L .4554 .89084 L p F P
0 g
s
.65 .5 .625 .1 k
.24506 .43905 m .25085 .42021 L .26765 .40089 L p F P
0 g
s
.617 .5 .625 .1 k
.25085 .42021 m .24506 .43905 L .23084 .46127 L p F P
0 g
s
.75 .5 .708 .1 k
.38809 .29631 m .37274 .30687 L .35371 .31304 L p F P
0 g
s
.75 .5 .692 .1 k
.33876 .32596 m .35371 .31304 L .37274 .30687 L p F P
0 g
s
.683 .5 .658 .1 k
.30609 .35164 m .29511 .3675 L .27632 .38333 L p F P
0 g
s
.683 .5 .642 .1 k
.26765 .40089 m .27632 .38333 L .29511 .3675 L p F P
0 g
s
.517 .5 .575 .1 k
.21034 .59755 m .20573 .57789 L .21025 .55115 L p F P
0 g
s
.483 .5 .575 .1 k
.20573 .57789 m .21034 .59755 L .20932 .62455 L p F P
0 g
s
.417 .5 .108 .1 k
.8277 .67915 m .83716 .66118 L .83125 .68757 L p F P
0 g
s
.417 .5 .108 .1 k
.83125 .68757 m .82203 .70491 L .8277 .67915 L p F P
0 g
s
.55 .5 .058 .1 k
.83542 .51569 m .83474 .49567 L .84274 .52129 L p F P
0 g
s
.55 .5 .058 .1 k
.84274 .52129 m .84334 .54152 L .83542 .51569 L p F P
0 g
s
.65 .5 .642 .1 k
.27632 .38333 m .26765 .40089 L .25085 .42021 L p F P
0 g
s
.783 .5 .758 .1 k
.45497 .27348 m .43758 .27935 L .42391 .27869 L p F P
0 g
s
.783 .5 .742 .1 k
.40522 .28686 m .42391 .27869 L .43758 .27935 L p F P
0 g
s
.25 .5 .208 .1 k
.67914 .86011 m .69807 .85171 L .68283 .86449 L p F P
0 g
s
.25 .5 .208 .1 k
.68283 .86449 m .66565 .87208 L .67914 .86011 L p F P
0 g
s
.217 .5 .258 .1 k
.60731 .88899 m .6277 .88437 L .6166 .89201 L p F P
0 g
s
.217 .5 .258 .1 k
.6166 .89201 m .59846 .8961 L .60731 .88899 L p F P
0 g
s
.717 .5 .975 .1 k
.72071 .33304 m .70697 .31963 L .72529 .32957 L p F P
0 g
s
.717 .5 .975 .1 k
.72529 .32957 m .74028 .34426 L .72071 .33304 L p F P
0 g
s
.783 .5 .892 .1 k
.60682 .27637 m .58895 .27111 L .59863 .26917 L p F P
0 g
s
.783 .5 .892 .1 k
.59863 .26917 m .61923 .27525 L .60682 .27637 L p F P
0 g
s
.283 .5 .175 .1 k
.72992 .82609 m .7469 .81483 L .73113 .83196 L p F P
0 g
s
.283 .5 .175 .1 k
.73113 .83196 m .71547 .8423 L .72992 .82609 L p F P
0 g
s
.75 .5 .942 .1 k
.67274 .30166 m .65651 .29161 L .67279 .29593 L p F P
0 g
s
.75 .5 .942 .1 k
.67279 .29593 m .69094 .3072 L .67274 .30166 L p F P
0 g
s
.217 .5 .408 .1 k
.41468 .88157 m .43464 .88673 L .44466 .89409 L p F P
0 g
s
.217 .5 .392 .1 k
.46313 .89773 m .44466 .89409 L .43464 .88673 L p F P
0 g
s
.45 .5 .092 .1 k
.83959 .6344 m .84596 .61528 L .84346 .64253 L p F P
0 g
s
.45 .5 .092 .1 k
.84346 .64253 m .83716 .66118 L .83959 .6344 L p F P
0 g
s
.583 .5 .042 .1 k
.82352 .47146 m .81937 .45184 L .83056 .47558 L p F P
0 g
s
.583 .5 .042 .1 k
.83056 .47558 m .83474 .49567 L .82352 .47146 L p F P
0 g
s
.383 .5 .525 .1 k
.25791 .75286 m .24493 .73749 L .23609 .71297 L p F P
0 g
s
.35 .5 .525 .1 k
.24493 .73749 m .25791 .75286 L .26936 .77524 L p F P
0 g
s
.35 .5 .508 .1 k
.28412 .78885 m .26936 .77524 L .25791 .75286 L p F P
0 g
s
.55 .5 .592 .1 k
.21025 .55115 m .20916 .53105 L .21714 .50532 L p F P
0 g
s
.517 .5 .592 .1 k
.20916 .53105 m .21025 .55115 L .20573 .57789 L p F P
0 g
s
.783 .5 .775 .1 k
.4733 .26891 m .45497 .27348 L .44395 .27191 L p F P
0 g
s
.783 .5 .758 .1 k
.42391 .27869 m .44395 .27191 L .45497 .27348 L p F P
0 g
s
.25 .5 .458 .1 k
.34532 .84695 m .36349 .85588 L .3779 .86825 L p F P
0 g
s
.25 .5 .442 .1 k
.3957 .8754 m .3779 .86825 L .36349 .85588 L p F P
0 g
s
.317 .5 .508 .1 k
.26936 .77524 m .28412 .78885 L .29771 .8086 L p F P
0 g
s
.317 .5 .492 .1 k
.31365 .82037 m .29771 .8086 L .28412 .78885 L p F P
0 g
s
.683 .5 .992 .1 k
.75258 .35979 m .74028 .34426 L .7579 .35839 L p F P
0 g
s
.683 .5 .992 .1 k
.7579 .35839 m .77106 .37506 L .75258 .35979 L p F P
0 g
s
.217 .5 .242 .1 k
.6277 .88437 m .64721 .87872 L .63392 .88701 L p F P
0 g
s
.217 .5 .242 .1 k
.63392 .88701 m .6166 .89201 L .6277 .88437 L p F P
0 g
s
.417 .5 .542 .1 k
.23609 .71297 m .22544 .696 L .21964 .66992 L p F P
0 g
s
.383 .5 .542 .1 k
.22544 .696 m .23609 .71297 L .24493 .73749 L p F P
0 g
s
.617 .5 .025 .1 k
.8052 .42997 m .79783 .41125 L .81178 .4324 L p F P
0 g
s
.617 .5 .025 .1 k
.81178 .4324 m .81937 .45184 L .8052 .42997 L p F P
0 g
s
.783 .5 .875 .1 k
.58895 .27111 m .57026 .26719 L .57707 .26464 L p F P
0 g
s
.783 .5 .875 .1 k
.57707 .26464 m .59863 .26917 L .58895 .27111 L p F P
0 g
s
.717 .5 .692 .1 k
.35371 .31304 m .33876 .32596 L .3198 .33652 L p F P
0 g
s
.717 .5 .675 .1 k
.30609 .35164 m .3198 .33652 L .33876 .32596 L p F P
0 g
s
.65 .5 .008 .1 k
.78119 .39239 m .77106 .37506 L .78719 .39297 L p F P
0 g
s
.65 .5 .008 .1 k
.78719 .39297 m .79783 .41125 L .78119 .39239 L p F P
0 g
s
.75 .5 .725 .1 k
.40522 .28686 m .38809 .29631 L .37086 .30119 L p F P
0 g
s
.75 .5 .708 .1 k
.35371 .31304 m .37086 .30119 L .38809 .29631 L p F P
0 g
s
.783 .5 .792 .1 k
.49231 .2657 m .4733 .26891 L .46508 .26662 L p F P
0 g
s
.783 .5 .775 .1 k
.44395 .27191 m .46508 .26662 L .4733 .26891 L p F P
0 g
s
.483 .5 .075 .1 k
.84493 .58816 m .8479 .56827 L .84895 .59566 L p F P
0 g
s
.483 .5 .075 .1 k
.84895 .59566 m .84596 .61528 L .84493 .58816 L p F P
0 g
s
.283 .5 .492 .1 k
.29771 .8086 m .31365 .82037 L .3288 .83705 L p F P
0 g
s
.283 .5 .475 .1 k
.34532 .84695 m .3288 .83705 L .31365 .82037 L p F P
0 g
s
.217 .5 .425 .1 k
.3957 .8754 m .41468 .88157 L .42693 .88952 L p F P
0 g
s
.217 .5 .408 .1 k
.44466 .89409 m .42693 .88952 L .41468 .88157 L p F P
0 g
s
.45 .5 .558 .1 k
.21964 .66992 m .21179 .65157 L .20932 .62455 L p F P
0 g
s
.417 .5 .558 .1 k
.21179 .65157 m .21964 .66992 L .22544 .696 L p F P
0 g
s
.583 .5 .608 .1 k
.21714 .50532 m .21962 .48524 L .23084 .46127 L p F P
0 g
s
.55 .5 .608 .1 k
.21962 .48524 m .21714 .50532 L .20916 .53105 L p F P
0 g
s
.25 .5 .192 .1 k
.69807 .85171 m .71547 .8423 L .69858 .856 L p F P
0 g
s
.25 .5 .192 .1 k
.69858 .856 m .68283 .86449 L .69807 .85171 L p F P
0 g
s
.783 .5 .858 .1 k
.57026 .26719 m .551 .26466 L .55484 .26171 L p F P
0 g
s
.783 .5 .858 .1 k
.55484 .26171 m .57707 .26464 L .57026 .26719 L p F P
0 g
s
.783 .5 .808 .1 k
.51177 .26391 m .49231 .2657 L .48703 .26291 L p F P
0 g
s
.783 .5 .792 .1 k
.46508 .26662 m .48703 .26291 L .49231 .2657 L p F P
0 g
s
.75 .5 .925 .1 k
.65651 .29161 m .6386 .28277 L .65271 .28599 L p F P
0 g
s
.75 .5 .925 .1 k
.65271 .28599 m .67279 .29593 L .65651 .29161 L p F P
0 g
s
.783 .5 .842 .1 k
.551 .26466 m .53142 .26356 L .53221 .26044 L p F P
0 g
s
.783 .5 .842 .1 k
.53221 .26044 m .55484 .26171 L .551 .26466 L p F P
0 g
s
.717 .5 .958 .1 k
.70697 .31963 m .69094 .3072 L .70775 .31595 L p F P
0 g
s
.717 .5 .958 .1 k
.70775 .31595 m .72529 .32957 L .70697 .31963 L p F P
0 g
s
.35 .5 .125 .1 k
.8013 .74558 m .81298 .7298 L .80057 .75351 L p F P
0 g
s
.35 .5 .125 .1 k
.80057 .75351 m .78951 .76838 L .8013 .74558 L p F P
0 g
s
.683 .5 .675 .1 k
.3198 .33652 m .30609 .35164 L .28803 .36631 L p F P
0 g
s
.683 .5 .658 .1 k
.27632 .38333 m .28803 .36631 L .30609 .35164 L p F P
0 g
s
.217 .5 .225 .1 k
.64721 .87872 m .66565 .87208 L .65027 .88113 L p F P
0 g
s
.217 .5 .225 .1 k
.65027 .88113 m .63392 .88701 L .64721 .87872 L p F P
0 g
s
.317 .5 .142 .1 k
.7759 .78242 m .78951 .76838 L .77455 .78955 L p F P
0 g
s
.317 .5 .142 .1 k
.77455 .78955 m .76185 .80261 L .7759 .78242 L p F P
0 g
s
.783 .5 .825 .1 k
.53142 .26356 m .51177 .26391 L .50951 .26084 L p F P
0 g
s
.783 .5 .808 .1 k
.48703 .26291 m .50951 .26084 L .51177 .26391 L p F P
0 g
s
.783 .5 .825 .1 k
.50951 .26084 m .53221 .26044 L .53142 .26356 L p F P
0 g
s
.617 .5 .625 .1 k
.23084 .46127 m .23677 .44171 L .25085 .42021 L p F P
0 g
s
.583 .5 .625 .1 k
.23677 .44171 m .23084 .46127 L .21962 .48524 L p F P
0 g
s
.483 .5 .575 .1 k
.20932 .62455 m .20469 .60515 L .20573 .57789 L p F P
0 g
s
.45 .5 .575 .1 k
.20469 .60515 m .20932 .62455 L .21179 .65157 L p F P
0 g
s
.517 .5 .058 .1 k
.84334 .54152 m .84274 .52129 L .84734 .54807 L p F P
0 g
s
.517 .5 .058 .1 k
.84734 .54807 m .8479 .56827 L .84334 .54152 L p F P
0 g
s
.383 .5 .108 .1 k
.82203 .70491 m .83125 .68757 L .82182 .71327 L p F P
0 g
s
.383 .5 .108 .1 k
.82182 .71327 m .81298 .7298 L .82203 .70491 L p F P
0 g
s
.183 .5 .342 .1 k
.50157 .90215 m .52121 .9029 L .5219 .90577 L p F P
0 g
s
.183 .5 .325 .1 k
.52121 .9029 m .54088 .90266 L .53889 .90556 L p F P
0 g
s
.183 .5 .325 .1 k
.53889 .90556 m .5219 .90577 L .52121 .9029 L p F P
0 g
s
.183 .5 .308 .1 k
.54088 .90266 m .56044 .90145 L .55577 .90451 L p F P
0 g
s
.183 .5 .308 .1 k
.55577 .90451 m .53889 .90556 L .54088 .90266 L p F P
0 g
s
.65 .5 .658 .1 k
.28803 .36631 m .27632 .38333 L .25991 .40169 L p F P
0 g
s
.65 .5 .642 .1 k
.25085 .42021 m .25991 .40169 L .27632 .38333 L p F P
0 g
s
.75 .5 .742 .1 k
.42391 .27869 m .40522 .28686 L .39004 .29059 L p F P
0 g
s
.75 .5 .725 .1 k
.37086 .30119 m .39004 .29059 L .40522 .28686 L p F P
0 g
s
.283 .5 .158 .1 k
.7469 .81483 m .76185 .80261 L .74487 .82077 L p F P
0 g
s
.283 .5 .158 .1 k
.74487 .82077 m .73113 .83196 L .7469 .81483 L p F P
0 g
s
.617 .5 .642 .1 k
.25991 .40169 m .25085 .42021 L .23677 .44171 L p F P
0 g
s
.25 .5 .475 .1 k
.3288 .83705 m .34532 .84695 L .36144 .86019 L p F P
0 g
s
.25 .5 .458 .1 k
.3779 .86825 m .36144 .86019 L .34532 .84695 L p F P
0 g
s
.183 .5 .358 .1 k
.48216 .90043 m .50157 .90215 L .50496 .90512 L p F P
0 g
s
.183 .5 .342 .1 k
.5219 .90577 m .50496 .90512 L .50157 .90215 L p F P
0 g
s
.217 .5 .442 .1 k
.3779 .86825 m .3957 .8754 L .41009 .88407 L p F P
0 g
s
.217 .5 .425 .1 k
.42693 .88952 m .41009 .88407 L .3957 .8754 L p F P
0 g
s
.183 .5 .292 .1 k
.56044 .90145 m .57969 .89925 L .57238 .90262 L p F P
0 g
s
.183 .5 .292 .1 k
.57238 .90262 m .55577 .90451 L .56044 .90145 L p F P
0 g
s
.183 .5 .375 .1 k
.46313 .89773 m .48216 .90043 L .4882 .90364 L p F P
0 g
s
.183 .5 .358 .1 k
.50496 .90512 m .4882 .90364 L .48216 .90043 L p F P
0 g
s
.717 .5 .708 .1 k
.37086 .30119 m .35371 .31304 L .33613 .32236 L p F P
0 g
s
.717 .5 .692 .1 k
.3198 .33652 m .33613 .32236 L .35371 .31304 L p F P
0 g
s
.417 .5 .092 .1 k
.83716 .66118 m .84346 .64253 L .83735 .66959 L p F P
0 g
s
.417 .5 .092 .1 k
.83735 .66959 m .83125 .68757 L .83716 .66118 L p F P
0 g
s
.55 .5 .042 .1 k
.83474 .49567 m .83056 .47558 L .83854 .50098 L p F P
0 g
s
.55 .5 .042 .1 k
.83854 .50098 m .84274 .52129 L .83474 .49567 L p F P
0 g
s
.75 .5 .908 .1 k
.6386 .28277 m .61923 .27525 L .63096 .27754 L p F P
0 g
s
.75 .5 .908 .1 k
.63096 .27754 m .65271 .28599 L .6386 .28277 L p F P
0 g
s
.683 .5 .975 .1 k
.74028 .34426 m .72529 .32957 L .74182 .3426 L p F P
0 g
s
.683 .5 .975 .1 k
.74182 .3426 m .7579 .35839 L .74028 .34426 L p F P
0 g
s
.517 .5 .592 .1 k
.20573 .57789 m .20457 .55781 L .20916 .53105 L p F P
0 g
s
.483 .5 .592 .1 k
.20457 .55781 m .20573 .57789 L .20469 .60515 L p F P
0 g
s
.183 .5 .275 .1 k
.57969 .89925 m .59846 .8961 L .58856 .89991 L p F P
0 g
s
.183 .5 .275 .1 k
.58856 .89991 m .57238 .90262 L .57969 .89925 L p F P
0 g
s
.217 .5 .208 .1 k
.66565 .87208 m .68283 .86449 L .66547 .87443 L p F P
0 g
s
.217 .5 .208 .1 k
.66547 .87443 m .65027 .88113 L .66565 .87208 L p F P
0 g
s
.35 .5 .525 .1 k
.26936 .77524 m .25705 .76075 L .24493 .73749 L p F P
0 g
s
.317 .5 .525 .1 k
.25705 .76075 m .26936 .77524 L .2839 .79593 L p F P
0 g
s
.317 .5 .508 .1 k
.29771 .8086 m .2839 .79593 L .26936 .77524 L p F P
0 g
s
.25 .5 .175 .1 k
.71547 .8423 m .73113 .83196 L .71272 .84668 L p F P
0 g
s
.25 .5 .175 .1 k
.71272 .84668 m .69858 .856 L .71547 .8423 L p F P
0 g
s
.183 .5 .392 .1 k
.44466 .89409 m .46313 .89773 L .47179 .90132 L p F P
0 g
s
.183 .5 .375 .1 k
.4882 .90364 m .47179 .90132 L .46313 .89773 L p F P
0 g
s
.383 .5 .542 .1 k
.24493 .73749 m .23469 .7213 L .22544 .696 L p F P
0 g
s
.35 .5 .542 .1 k
.23469 .7213 m .24493 .73749 L .25705 .76075 L p F P
0 g
s
.583 .5 .025 .1 k
.81937 .45184 m .81178 .4324 L .8228 .45566 L p F P
0 g
s
.583 .5 .025 .1 k
.8228 .45566 m .83056 .47558 L .81937 .45184 L p F P
0 g
s
.75 .5 .758 .1 k
.44395 .27191 m .42391 .27869 L .41102 .28141 L p F P
0 g
s
.75 .5 .742 .1 k
.39004 .29059 m .41102 .28141 L .42391 .27869 L p F P
0 g
s
.283 .5 .508 .1 k
.2839 .79593 m .29771 .8086 L .31412 .82625 L p F P
0 g
s
.283 .5 .492 .1 k
.3288 .83705 m .31412 .82625 L .29771 .8086 L p F P
0 g
s
.65 .5 .992 .1 k
.77106 .37506 m .7579 .35839 L .77332 .37535 L p F P
0 g
s
.65 .5 .992 .1 k
.77332 .37535 m .78719 .39297 L .77106 .37506 L p F P
0 g
s
.717 .5 .942 .1 k
.69094 .3072 m .67279 .29593 L .68784 .30358 L p F P
0 g
s
.717 .5 .942 .1 k
.68784 .30358 m .70775 .31595 L .69094 .3072 L p F P
0 g
s
.183 .5 .258 .1 k
.59846 .8961 m .6166 .89201 L .60418 .89639 L p F P
0 g
s
.183 .5 .258 .1 k
.60418 .89639 m .58856 .89991 L .59846 .8961 L p F P
0 g
s
.45 .5 .075 .1 k
.84596 .61528 m .84895 .59566 L .84639 .62338 L p F P
0 g
s
.45 .5 .075 .1 k
.84639 .62338 m .84346 .64253 L .84596 .61528 L p F P
0 g
s
.617 .5 .008 .1 k
.79783 .41125 m .78719 .39297 L .80074 .41339 L p F P
0 g
s
.617 .5 .008 .1 k
.80074 .41339 m .81178 .4324 L .79783 .41125 L p F P
0 g
s
.417 .5 .558 .1 k
.22544 .696 m .21781 .67831 L .21179 .65157 L p F P
0 g
s
.383 .5 .558 .1 k
.21781 .67831 m .22544 .696 L .23469 .7213 L p F P
0 g
s
.55 .5 .608 .1 k
.20916 .53105 m .21162 .51074 L .21962 .48524 L p F P
0 g
s
.517 .5 .608 .1 k
.21162 .51074 m .20916 .53105 L .20457 .55781 L p F P
0 g
s
.75 .5 .892 .1 k
.61923 .27525 m .59863 .26917 L .60779 .2707 L p F P
0 g
s
.75 .5 .892 .1 k
.60779 .2707 m .63096 .27754 L .61923 .27525 L p F P
0 g
s
.217 .5 .458 .1 k
.36144 .86019 m .3779 .86825 L .39432 .87775 L p F P
0 g
s
.217 .5 .442 .1 k
.41009 .88407 m .39432 .87775 L .3779 .86825 L p F P
0 g
s
.683 .5 .692 .1 k
.33613 .32236 m .3198 .33652 L .30272 .35007 L p F P
0 g
s
.683 .5 .675 .1 k
.28803 .36631 m .30272 .35007 L .3198 .33652 L p F P
0 g
s
.183 .5 .408 .1 k
.42693 .88952 m .44466 .89409 L .45588 .89818 L p F P
0 g
s
.183 .5 .392 .1 k
.47179 .90132 m .45588 .89818 L .44466 .89409 L p F P
0 g
s
.25 .5 .492 .1 k
.31412 .82625 m .3288 .83705 L .3465 .85126 L p F P
0 g
s
.25 .5 .475 .1 k
.36144 .86019 m .3465 .85126 L .3288 .83705 L p F P
0 g
s
.75 .5 .775 .1 k
.46508 .26662 m .44395 .27191 L .43354 .27378 L p F P
0 g
s
.75 .5 .758 .1 k
.41102 .28141 m .43354 .27378 L .44395 .27191 L p F P
0 g
s
.717 .5 .725 .1 k
.39004 .29059 m .37086 .30119 L .35493 .30936 L p F P
0 g
s
.717 .5 .708 .1 k
.33613 .32236 m .35493 .30936 L .37086 .30119 L p F P
0 g
s
.183 .5 .242 .1 k
.6166 .89201 m .63392 .88701 L .61907 .8921 L p F P
0 g
s
.183 .5 .242 .1 k
.61907 .8921 m .60418 .89639 L .6166 .89201 L p F P
0 g
s
.317 .5 .125 .1 k
.78951 .76838 m .80057 .75351 L .78484 .77573 L p F P
0 g
s
.317 .5 .125 .1 k
.78484 .77573 m .77455 .78955 L .78951 .76838 L p F P
0 g
s
.45 .5 .575 .1 k
.21179 .65157 m .20722 .63264 L .20469 .60515 L p F P
0 g
s
.417 .5 .575 .1 k
.20722 .63264 m .21179 .65157 L .21781 .67831 L p F P
0 g
s
.583 .5 .625 .1 k
.21962 .48524 m .22565 .4652 L .23677 .44171 L p F P
0 g
s
.55 .5 .625 .1 k
.22565 .4652 m .21962 .48524 L .21162 .51074 L p F P
0 g
s
.483 .5 .058 .1 k
.8479 .56827 m .84734 .54807 L .8484 .57572 L p F P
0 g
s
.483 .5 .058 .1 k
.8484 .57572 m .84895 .59566 L .8479 .56827 L p F P
0 g
s
.283 .5 .142 .1 k
.76185 .80261 m .77455 .78955 L .75651 .8088 L p F P
0 g
s
.283 .5 .142 .1 k
.75651 .8088 m .74487 .82077 L .76185 .80261 L p F P
0 g
s
.217 .5 .192 .1 k
.68283 .86449 m .69858 .856 L .67937 .86694 L p F P
0 g
s
.217 .5 .192 .1 k
.67937 .86694 m .66547 .87443 L .68283 .86449 L p F P
0 g
s
.35 .5 .108 .1 k
.81298 .7298 m .82182 .71327 L .80889 .73795 L p F P
0 g
s
.35 .5 .108 .1 k
.80889 .73795 m .80057 .75351 L .81298 .7298 L p F P
0 g
s
.75 .5 .875 .1 k
.59863 .26917 m .57707 .26464 L .58352 .26559 L p F P
0 g
s
.75 .5 .875 .1 k
.58352 .26559 m .60779 .2707 L .59863 .26917 L p F P
0 g
s
.65 .5 .675 .1 k
.30272 .35007 m .28803 .36631 L .27224 .38372 L p F P
0 g
s
.65 .5 .658 .1 k
.25991 .40169 m .27224 .38372 L .28803 .36631 L p F P
0 g
s
.617 .5 .642 .1 k
.23677 .44171 m .24615 .42246 L .25991 .40169 L p F P
0 g
s
.583 .5 .642 .1 k
.24615 .42246 m .23677 .44171 L .22565 .4652 L p F P
0 g
s
.183 .5 .425 .1 k
.41009 .88407 m .42693 .88952 L .44063 .89426 L p F P
0 g
s
.183 .5 .408 .1 k
.45588 .89818 m .44063 .89426 L .42693 .88952 L p F P
0 g
s
.683 .5 .958 .1 k
.72529 .32957 m .70775 .31595 L .72294 .32793 L p F P
0 g
s
.683 .5 .958 .1 k
.72294 .32793 m .74182 .3426 L .72529 .32957 L p F P
0 g
s
.617 .5 .658 .1 k
.27224 .38372 m .25991 .40169 L .24615 .42246 L p F P
0 g
s
.75 .5 .792 .1 k
.48703 .26291 m .46508 .26662 L .45732 .26783 L p F P
0 g
s
.75 .5 .775 .1 k
.43354 .27378 m .45732 .26783 L .46508 .26662 L p F P
0 g
s
.717 .5 .925 .1 k
.67279 .29593 m .65271 .28599 L .66578 .29266 L p F P
0 g
s
.717 .5 .925 .1 k
.66578 .29266 m .68784 .30358 L .67279 .29593 L p F P
0 g
s
.383 .5 .092 .1 k
.83125 .68757 m .83735 .66959 L .82763 .69613 L p F P
0 g
s
.383 .5 .092 .1 k
.82763 .69613 m .82182 .71327 L .83125 .68757 L p F P
0 g
s
.25 .5 .158 .1 k
.73113 .83196 m .74487 .82077 L .72509 .8366 L p F P
0 g
s
.25 .5 .158 .1 k
.72509 .8366 m .71272 .84668 L .73113 .83196 L p F P
0 g
s
.483 .5 .592 .1 k
.20469 .60515 m .20351 .58533 L .20457 .55781 L p F P
0 g
s
.45 .5 .592 .1 k
.20351 .58533 m .20469 .60515 L .20722 .63264 L p F P
0 g
s
.517 .5 .042 .1 k
.84274 .52129 m .83854 .50098 L .84314 .52777 L p F P
0 g
s
.517 .5 .042 .1 k
.84314 .52777 m .84734 .54807 L .84274 .52129 L p F P
0 g
s
.75 .5 .858 .1 k
.57707 .26464 m .55484 .26171 L .55846 .26229 L p F P
0 g
s
.75 .5 .858 .1 k
.55846 .26229 m .58352 .26559 L .57707 .26464 L p F P
0 g
s
.183 .5 .225 .1 k
.63392 .88701 m .65027 .88113 L .63309 .88706 L p F P
0 g
s
.183 .5 .225 .1 k
.63309 .88706 m .61907 .8921 L .63392 .88701 L p F P
0 g
s
.217 .5 .458 .1 k
.39432 .87775 m .37978 .87064 L .36144 .86019 L p F P
0 g
s
.217 .5 .475 .1 k
.3465 .85126 m .36144 .86019 L .37978 .87064 L p F P
0 g
s
.75 .5 .792 .1 k
.45732 .26783 m .48204 .26365 L .48703 .26291 L p F P
0 g
s
.75 .5 .808 .1 k
.50951 .26084 m .48703 .26291 L .48204 .26365 L p F P
0 g
s
.75 .5 .842 .1 k
.55484 .26171 m .53221 .26044 L .53296 .26086 L p F P
0 g
s
.75 .5 .842 .1 k
.53296 .26086 m .55846 .26229 L .55484 .26171 L p F P
0 g
s
.35 .5 .542 .1 k
.25705 .76075 m .24739 .74551 L .23469 .7213 L p F P
0 g
s
.317 .5 .525 .1 k
.2839 .79593 m .27243 .78246 L .25705 .76075 L p F P
0 g
s
.317 .5 .542 .1 k
.24739 .74551 m .25705 .76075 L .27243 .78246 L p F P
0 g
s
.283 .5 .508 .1 k
.31412 .82625 m .30144 .81465 L .2839 .79593 L p F P
0 g
s
.283 .5 .525 .1 k
.27243 .78246 m .2839 .79593 L .30144 .81465 L p F P
0 g
s
.717 .5 .725 .1 k
.35493 .30936 m .37599 .29772 L .39004 .29059 L p F P
0 g
s
.717 .5 .742 .1 k
.41102 .28141 m .39004 .29059 L .37599 .29772 L p F P
0 g
s
.75 .5 .825 .1 k
.53221 .26044 m .50951 .26084 L .50737 .26131 L p F P
0 g
s
.75 .5 .808 .1 k
.48204 .26365 m .50737 .26131 L .50951 .26084 L p F P
0 g
s
.65 .5 .975 .1 k
.7579 .35839 m .74182 .3426 L .75629 .35866 L p F P
0 g
s
.65 .5 .975 .1 k
.75629 .35866 m .77332 .37535 L .7579 .35839 L p F P
0 g
s
.75 .5 .825 .1 k
.50737 .26131 m .53296 .26086 L .53221 .26044 L p F P
0 g
s
.55 .5 .025 .1 k
.83056 .47558 m .8228 .45566 L .83067 .48082 L p F P
0 g
s
.55 .5 .025 .1 k
.83067 .48082 m .83854 .50098 L .83056 .47558 L p F P
0 g
s
.417 .5 .075 .1 k
.84346 .64253 m .84639 .62338 L .84016 .65113 L p F P
0 g
s
.417 .5 .075 .1 k
.84016 .65113 m .83735 .66959 L .84346 .64253 L p F P
0 g
s
.683 .5 .692 .1 k
.30272 .35007 m .32027 .33483 L .33613 .32236 L p F P
0 g
s
.683 .5 .708 .1 k
.35493 .30936 m .33613 .32236 L .32027 .33483 L p F P
0 g
s
.183 .5 .425 .1 k
.44063 .89426 m .42617 .88957 L .41009 .88407 L p F P
0 g
s
.183 .5 .442 .1 k
.39432 .87775 m .41009 .88407 L .42617 .88957 L p F P
0 g
s
.517 .5 .608 .1 k
.20457 .55781 m .20701 .53753 L .21162 .51074 L p F P
0 g
s
.483 .5 .608 .1 k
.20701 .53753 m .20457 .55781 L .20351 .58533 L p F P
0 g
s
.383 .5 .558 .1 k
.23469 .7213 m .22741 .70444 L .21781 .67831 L p F P
0 g
s
.35 .5 .558 .1 k
.22741 .70444 m .23469 .7213 L .24739 .74551 L p F P
0 g
s
.15 .5 .342 .1 k
.50496 .90512 m .5219 .90577 L .52267 .90508 L p F P
0 g
s
.15 .5 .325 .1 k
.5219 .90577 m .53889 .90556 L .5367 .90491 L p F P
0 g
s
.15 .5 .325 .1 k
.5367 .90491 m .52267 .90508 L .5219 .90577 L p F P
0 g
s
.15 .5 .308 .1 k
.53889 .90556 m .55577 .90451 L .55063 .90404 L p F P
0 g
s
.15 .5 .308 .1 k
.55063 .90404 m .5367 .90491 L .53889 .90556 L p F P
0 g
s
.25 .5 .492 .1 k
.3465 .85126 m .33326 .84154 L .31412 .82625 L p F P
0 g
s
.25 .5 .508 .1 k
.30144 .81465 m .31412 .82625 L .33326 .84154 L p F P
0 g
s
.583 .5 .008 .1 k
.81178 .4324 m .80074 .41339 L .81144 .43616 L p F P
0 g
s
.583 .5 .008 .1 k
.81144 .43616 m .8228 .45566 L .81178 .4324 L p F P
0 g
s
.217 .5 .175 .1 k
.69858 .856 m .71272 .84668 L .69181 .85873 L p F P
0 g
s
.217 .5 .175 .1 k
.69181 .85873 m .67937 .86694 L .69858 .856 L p F P
0 g
s
.617 .5 .992 .1 k
.78719 .39297 m .77332 .37535 L .78627 .39505 L p F P
0 g
s
.617 .5 .992 .1 k
.78627 .39505 m .80074 .41339 L .78719 .39297 L p F P
0 g
s
.15 .5 .358 .1 k
.4882 .90364 m .50496 .90512 L .50868 .90454 L p F P
0 g
s
.15 .5 .342 .1 k
.52267 .90508 m .50868 .90454 L .50496 .90512 L p F P
0 g
s
.15 .5 .292 .1 k
.55577 .90451 m .57238 .90262 L .56433 .90248 L p F P
0 g
s
.15 .5 .292 .1 k
.56433 .90248 m .55063 .90404 L .55577 .90451 L p F P
0 g
s
.717 .5 .908 .1 k
.65271 .28599 m .63096 .27754 L .64182 .28336 L p F P
0 g
s
.717 .5 .908 .1 k
.64182 .28336 m .66578 .29266 L .65271 .28599 L p F P
0 g
s
.183 .5 .208 .1 k
.65027 .88113 m .66547 .87443 L .64611 .88131 L p F P
0 g
s
.183 .5 .208 .1 k
.64611 .88131 m .63309 .88706 L .65027 .88113 L p F P
0 g
s
.15 .5 .375 .1 k
.47179 .90132 m .4882 .90364 L .49485 .90332 L p F P
0 g
s
.15 .5 .358 .1 k
.50868 .90454 m .49485 .90332 L .4882 .90364 L p F P
0 g
s
.417 .5 .575 .1 k
.21781 .67831 m .2134 .66005 L .20722 .63264 L p F P
0 g
s
.383 .5 .575 .1 k
.2134 .66005 m .21781 .67831 L .22741 .70444 L p F P
0 g
s
.45 .5 .058 .1 k
.84895 .59566 m .8484 .57572 L .84582 .60394 L p F P
0 g
s
.45 .5 .058 .1 k
.84582 .60394 m .84639 .62338 L .84895 .59566 L p F P
0 g
s
.15 .5 .275 .1 k
.57238 .90262 m .58856 .89991 L .57767 .90024 L p F P
0 g
s
.15 .5 .275 .1 k
.57767 .90024 m .56433 .90248 L .57238 .90262 L p F P
0 g
s
.683 .5 .942 .1 k
.70775 .31595 m .68784 .30358 L .70145 .3146 L p F P
0 g
s
.683 .5 .942 .1 k
.70145 .3146 m .72294 .32793 L .70775 .31595 L p F P
0 g
s
.55 .5 .625 .1 k
.21162 .51074 m .21772 .49048 L .22565 .4652 L p F P
0 g
s
.517 .5 .625 .1 k
.21772 .49048 m .21162 .51074 L .20701 .53753 L p F P
0 g
s
.283 .5 .125 .1 k
.77455 .78955 m .78484 .77573 L .76589 .79617 L p F P
0 g
s
.283 .5 .125 .1 k
.76589 .79617 m .75651 .8088 L .77455 .78955 L p F P
0 g
s
.65 .5 .675 .1 k
.27224 .38372 m .28777 .36656 L .30272 .35007 L p F P
0 g
s
.65 .5 .692 .1 k
.32027 .33483 m .30272 .35007 L .28777 .36656 L p F P
0 g
s
.717 .5 .758 .1 k
.43354 .27378 m .41102 .28141 L .39907 .28762 L p F P
0 g
s
.717 .5 .742 .1 k
.37599 .29772 m .39907 .28762 L .41102 .28141 L p F P
0 g
s
.317 .5 .108 .1 k
.80057 .75351 m .80889 .73795 L .79252 .76129 L p F P
0 g
s
.317 .5 .108 .1 k
.79252 .76129 m .78484 .77573 L .80057 .75351 L p F P
0 g
s
.15 .5 .392 .1 k
.45588 .89818 m .47179 .90132 L .48132 .9014 L p F P
0 g
s
.15 .5 .375 .1 k
.49485 .90332 m .48132 .9014 L .47179 .90132 L p F P
0 g
s
.217 .5 .492 .1 k
.33326 .84154 m .3465 .85126 L .36662 .86277 L p F P
0 g
s
.217 .5 .475 .1 k
.37978 .87064 m .36662 .86277 L .3465 .85126 L p F P
0 g
s
.183 .5 .458 .1 k
.37978 .87064 m .39432 .87775 L .41265 .88416 L p F P
0 g
s
.183 .5 .442 .1 k
.42617 .88957 m .41265 .88416 L .39432 .87775 L p F P
0 g
s
.25 .5 .142 .1 k
.74487 .82077 m .75651 .8088 L .73552 .82585 L p F P
0 g
s
.25 .5 .142 .1 k
.73552 .82585 m .72509 .8366 L .74487 .82077 L p F P
0 g
s
.15 .5 .258 .1 k
.58856 .89991 m .60418 .89639 L .59052 .89734 L p F P
0 g
s
.15 .5 .258 .1 k
.59052 .89734 m .57767 .90024 L .58856 .89991 L p F P
0 g
s
.583 .5 .642 .1 k
.22565 .4652 m .23528 .44547 L .24615 .42246 L p F P
0 g
s
.55 .5 .642 .1 k
.23528 .44547 m .22565 .4652 L .21772 .49048 L p F P
0 g
s
.35 .5 .092 .1 k
.82182 .71327 m .82763 .69613 L .8143 .72183 L p F P
0 g
s
.35 .5 .092 .1 k
.8143 .72183 m .80889 .73795 L .82182 .71327 L p F P
0 g
s
.45 .5 .592 .1 k
.20722 .63264 m .20609 .61331 L .20351 .58533 L p F P
0 g
s
.417 .5 .592 .1 k
.20609 .61331 m .20722 .63264 L .2134 .66005 L p F P
0 g
s
.617 .5 .675 .1 k
.28777 .36656 m .27224 .38372 L .25898 .40377 L p F P
0 g
s
.617 .5 .658 .1 k
.24615 .42246 m .25898 .40377 L .27224 .38372 L p F P
0 g
s
.717 .5 .892 .1 k
.63096 .27754 m .60779 .2707 L .61629 .27583 L p F P
0 g
s
.717 .5 .892 .1 k
.61629 .27583 m .64182 .28336 L .63096 .27754 L p F P
0 g
s
.483 .5 .042 .1 k
.84734 .54807 m .84314 .52777 L .8442 .55569 L p F P
0 g
s
.483 .5 .042 .1 k
.8442 .55569 m .8484 .57572 L .84734 .54807 L p F P
0 g
s
.15 .5 .408 .1 k
.44063 .89426 m .45588 .89818 L .46822 .89882 L p F P
0 g
s
.15 .5 .392 .1 k
.48132 .9014 m .46822 .89882 L .45588 .89818 L p F P
0 g
s
.583 .5 .658 .1 k
.25898 .40377 m .24615 .42246 L .23528 .44547 L p F P
0 g
s
.683 .5 .725 .1 k
.37599 .29772 m .35493 .30936 L .34053 .32083 L p F P
0 g
s
.683 .5 .708 .1 k
.32027 .33483 m .34053 .32083 L .35493 .30936 L p F P
0 g
s
.183 .5 .192 .1 k
.66547 .87443 m .67937 .86694 L .65797 .8749 L p F P
0 g
s
.183 .5 .192 .1 k
.65797 .8749 m .64611 .88131 L .66547 .87443 L p F P
0 g
s
.217 .5 .158 .1 k
.71272 .84668 m .72509 .8366 L .70264 .84987 L p F P
0 g
s
.217 .5 .158 .1 k
.70264 .84987 m .69181 .85873 L .71272 .84668 L p F P
0 g
s
.15 .5 .242 .1 k
.60418 .89639 m .61907 .8921 L .60276 .8938 L p F P
0 g
s
.15 .5 .242 .1 k
.60276 .8938 m .59052 .89734 L .60418 .89639 L p F P
0 g
s
.65 .5 .958 .1 k
.74182 .3426 m .72294 .32793 L .73625 .34313 L p F P
0 g
s
.65 .5 .958 .1 k
.73625 .34313 m .75629 .35866 L .74182 .3426 L p F P
0 g
s
.717 .5 .775 .1 k
.45732 .26783 m .43354 .27378 L .42388 .27922 L p F P
0 g
s
.717 .5 .758 .1 k
.39907 .28762 m .42388 .27922 L .43354 .27378 L p F P
0 g
s
.383 .5 .075 .1 k
.83735 .66959 m .84016 .65113 L .83024 .67856 L p F P
0 g
s
.383 .5 .075 .1 k
.83024 .67856 m .82763 .69613 L .83735 .66959 L p F P
0 g
s
.317 .5 .542 .1 k
.27243 .78246 m .26347 .76831 L .24739 .74551 L p F P
0 g
s
.283 .5 .542 .1 k
.26347 .76831 m .27243 .78246 L .29096 .80232 L p F P
0 g
s
.283 .5 .525 .1 k
.30144 .81465 m .29096 .80232 L .27243 .78246 L p F P
0 g
s
.517 .5 .025 .1 k
.83854 .50098 m .83067 .48082 L .8352 .50763 L p F P
0 g
s
.517 .5 .025 .1 k
.8352 .50763 m .84314 .52777 L .83854 .50098 L p F P
0 g
s
.25 .5 .525 .1 k
.29096 .80232 m .30144 .81465 L .32188 .8311 L p F P
0 g
s
.25 .5 .508 .1 k
.33326 .84154 m .32188 .8311 L .30144 .81465 L p F P
0 g
s
.483 .5 .608 .1 k
.20351 .58533 m .20595 .56532 L .20701 .53753 L p F P
0 g
s
.45 .5 .608 .1 k
.20595 .56532 m .20351 .58533 L .20609 .61331 L p F P
0 g
s
.15 .5 .425 .1 k
.42617 .88957 m .44063 .89426 L .45567 .89558 L p F P
0 g
s
.15 .5 .408 .1 k
.46822 .89882 m .45567 .89558 L .44063 .89426 L p F P
0 g
s
.35 .5 .558 .1 k
.24739 .74551 m .24056 .72964 L .22741 .70444 L p F P
0 g
s
.317 .5 .558 .1 k
.24056 .72964 m .24739 .74551 L .26347 .76831 L p F P
0 g
s
.717 .5 .875 .1 k
.60779 .2707 m .58352 .26559 L .5895 .2702 L p F P
0 g
s
.717 .5 .875 .1 k
.5895 .2702 m .61629 .27583 L .60779 .2707 L p F P
0 g
s
.683 .5 .925 .1 k
.68784 .30358 m .66578 .29266 L .6776 .30282 L p F P
0 g
s
.683 .5 .925 .1 k
.6776 .30282 m .70145 .3146 L .68784 .30358 L p F P
0 g
s
.183 .5 .475 .1 k
.36662 .86277 m .37978 .87064 L .40022 .87806 L p F P
0 g
s
.183 .5 .458 .1 k
.41265 .88416 m .40022 .87806 L .37978 .87064 L p F P
0 g
s
.617 .5 .975 .1 k
.77332 .37535 m .75629 .35866 L .76846 .37766 L p F P
0 g
s
.617 .5 .975 .1 k
.76846 .37766 m .78627 .39505 L .77332 .37535 L p F P
0 g
s
.55 .5 .008 .1 k
.8228 .45566 m .81144 .43616 L .8191 .46107 L p F P
0 g
s
.55 .5 .008 .1 k
.8191 .46107 m .83067 .48082 L .8228 .45566 L p F P
0 g
s
.15 .5 .225 .1 k
.61907 .8921 m .63309 .88706 L .61426 .88966 L p F P
0 g
s
.15 .5 .225 .1 k
.61426 .88966 m .60276 .8938 L .61907 .8921 L p F P
0 g
s
.717 .5 .792 .1 k
.48204 .26365 m .45732 .26783 L .45011 .27266 L p F P
0 g
s
.717 .5 .775 .1 k
.42388 .27922 m .45011 .27266 L .45732 .26783 L p F P
0 g
s
.217 .5 .508 .1 k
.32188 .8311 m .33326 .84154 L .35499 .85421 L p F P
0 g
s
.217 .5 .492 .1 k
.36662 .86277 m .35499 .85421 L .33326 .84154 L p F P
0 g
s
.583 .5 .992 .1 k
.80074 .41339 m .78627 .39505 L .79652 .41734 L p F P
0 g
s
.583 .5 .992 .1 k
.79652 .41734 m .81144 .43616 L .80074 .41339 L p F P
0 g
s
.383 .5 .575 .1 k
.22741 .70444 m .22324 .68705 L .2134 .66005 L p F P
0 g
s
.35 .5 .575 .1 k
.22324 .68705 m .22741 .70444 L .24056 .72964 L p F P
0 g
s
.417 .5 .058 .1 k
.84639 .62338 m .84582 .60394 L .83953 .63239 L p F P
0 g
s
.417 .5 .058 .1 k
.83953 .63239 m .84016 .65113 L .84639 .62338 L p F P
0 g
s
.65 .5 .708 .1 k
.34053 .32083 m .32027 .33483 L .30638 .35044 L p F P
0 g
s
.65 .5 .692 .1 k
.28777 .36656 m .30638 .35044 L .32027 .33483 L p F P
0 g
s
.717 .5 .858 .1 k
.58352 .26559 m .55846 .26229 L .56183 .26656 L p F P
0 g
s
.717 .5 .858 .1 k
.56183 .26656 m .5895 .2702 L .58352 .26559 L p F P
0 g
s
.517 .5 .625 .1 k
.20701 .53753 m .21315 .51728 L .21772 .49048 L p F P
0 g
s
.483 .5 .625 .1 k
.21315 .51728 m .20701 .53753 L .20595 .56532 L p F P
0 g
s
.183 .5 .175 .1 k
.67937 .86694 m .69181 .85873 L .66855 .86789 L p F P
0 g
s
.183 .5 .175 .1 k
.66855 .86789 m .65797 .8749 L .67937 .86694 L p F P
0 g
s
.683 .5 .742 .1 k
.39907 .28762 m .37599 .29772 L .36328 .30828 L p F P
0 g
s
.683 .5 .725 .1 k
.34053 .32083 m .36328 .30828 L .37599 .29772 L p F P
0 g
s
.15 .5 .442 .1 k
.41265 .88416 m .42617 .88957 L .4438 .89172 L p F P
0 g
s
.15 .5 .425 .1 k
.45567 .89558 m .4438 .89172 L .42617 .88957 L p F P
0 g
s
.717 .5 .808 .1 k
.50737 .26131 m .48204 .26365 L .47741 .26806 L p F P
0 g
s
.717 .5 .792 .1 k
.45011 .27266 m .47741 .26806 L .48204 .26365 L p F P
0 g
s
.283 .5 .108 .1 k
.78484 .77573 m .79252 .76129 L .77283 .78298 L p F P
0 g
s
.283 .5 .108 .1 k
.77283 .78298 m .76589 .79617 L .78484 .77573 L p F P
0 g
s
.25 .5 .125 .1 k
.75651 .8088 m .76589 .79617 L .74386 .81452 L p F P
0 g
s
.25 .5 .125 .1 k
.74386 .81452 m .73552 .82585 L .75651 .8088 L p F P
0 g
s
.717 .5 .842 .1 k
.55846 .26229 m .53296 .26086 L .53366 .26498 L p F P
0 g
s
.717 .5 .842 .1 k
.53366 .26498 m .56183 .26656 L .55846 .26229 L p F P
0 g
s
.717 .5 .825 .1 k
.53296 .26086 m .50737 .26131 L .50539 .26548 L p F P
0 g
s
.717 .5 .808 .1 k
.47741 .26806 m .50539 .26548 L .50737 .26131 L p F P
0 g
s
.417 .5 .592 .1 k
.2134 .66005 m .21236 .64143 L .20609 .61331 L p F P
0 g
s
.383 .5 .592 .1 k
.21236 .64143 m .2134 .66005 L .22324 .68705 L p F P
0 g
s
.317 .5 .092 .1 k
.80889 .73795 m .8143 .72183 L .79745 .74636 L p F P
0 g
s
.317 .5 .092 .1 k
.79745 .74636 m .79252 .76129 L .80889 .73795 L p F P
0 g
s
.717 .5 .825 .1 k
.50539 .26548 m .53366 .26498 L .53296 .26086 L p F P
0 g
s
.15 .5 .208 .1 k
.63309 .88706 m .64611 .88131 L .62491 .88493 L p F P
0 g
s
.15 .5 .208 .1 k
.62491 .88493 m .61426 .88966 L .63309 .88706 L p F P
0 g
s
.217 .5 .142 .1 k
.72509 .8366 m .73552 .82585 L .71173 .84043 L p F P
0 g
s
.217 .5 .142 .1 k
.71173 .84043 m .70264 .84987 L .72509 .8366 L p F P
0 g
s
.55 .5 .642 .1 k
.21772 .49048 m .22751 .4705 L .23528 .44547 L p F P
0 g
s
.517 .5 .642 .1 k
.22751 .4705 m .21772 .49048 L .21315 .51728 L p F P
0 g
s
.45 .5 .042 .1 k
.8484 .57572 m .8442 .55569 L .84162 .5844 L p F P
0 g
s
.45 .5 .042 .1 k
.84162 .5844 m .84582 .60394 L .8484 .57572 L p F P
0 g
s
.683 .5 .908 .1 k
.66578 .29266 m .64182 .28336 L .65167 .29278 L p F P
0 g
s
.683 .5 .908 .1 k
.65167 .29278 m .6776 .30282 L .66578 .29266 L p F P
0 g
s
.617 .5 .692 .1 k
.30638 .35044 m .28777 .36656 L .2752 .38589 L p F P
0 g
s
.617 .5 .675 .1 k
.25898 .40377 m .2752 .38589 L .28777 .36656 L p F P
0 g
s
.183 .5 .492 .1 k
.35499 .85421 m .36662 .86277 L .389 .87133 L p F P
0 g
s
.183 .5 .475 .1 k
.40022 .87806 m .389 .87133 L .36662 .86277 L p F P
0 g
s
.65 .5 .942 .1 k
.72294 .32793 m .70145 .3146 L .7134 .329 L p F P
0 g
s
.65 .5 .942 .1 k
.7134 .329 m .73625 .34313 L .72294 .32793 L p F P
0 g
s
.117 .5 .342 .1 k
.50868 .90454 m .52267 .90508 L .52351 .90067 L p F P
0 g
s
.117 .5 .325 .1 k
.52267 .90508 m .5367 .90491 L .53432 .90054 L p F P
0 g
s
.117 .5 .325 .1 k
.53432 .90054 m .52351 .90067 L .52267 .90508 L p F P
0 g
s
.117 .5 .308 .1 k
.5367 .90491 m .55063 .90404 L .54506 .89987 L p F P
0 g
s
.117 .5 .308 .1 k
.54506 .89987 m .53432 .90054 L .5367 .90491 L p F P
0 g
s
.117 .5 .358 .1 k
.49485 .90332 m .50868 .90454 L .51272 .90026 L p F P
0 g
s
.117 .5 .342 .1 k
.52351 .90067 m .51272 .90026 L .50868 .90454 L p F P
0 g
s
.117 .5 .292 .1 k
.55063 .90404 m .56433 .90248 L .55561 .89867 L p F P
0 g
s
.117 .5 .292 .1 k
.55561 .89867 m .54506 .89987 L .55063 .90404 L p F P
0 g
s
.583 .5 .658 .1 k
.23528 .44547 m .24849 .42629 L .25898 .40377 L p F P
0 g
s
.55 .5 .658 .1 k
.24849 .42629 m .23528 .44547 L .22751 .4705 L p F P
0 g
s
.583 .5 .675 .1 k
.2752 .38589 m .25898 .40377 L .24849 .42629 L p F P
0 g
s
.15 .5 .458 .1 k
.40022 .87806 m .41265 .88416 L .43273 .88727 L p F P
0 g
s
.15 .5 .442 .1 k
.4438 .89172 m .43273 .88727 L .41265 .88416 L p F P
0 g
s
.35 .5 .075 .1 k
.82763 .69613 m .83024 .67856 L .81665 .70532 L p F P
0 g
s
.35 .5 .075 .1 k
.81665 .70532 m .8143 .72183 L .82763 .69613 L p F P
0 g
s
.117 .5 .375 .1 k
.48132 .9014 m .49485 .90332 L .50206 .89931 L p F P
0 g
s
.117 .5 .358 .1 k
.51272 .90026 m .50206 .89931 L .49485 .90332 L p F P
0 g
s
.117 .5 .275 .1 k
.56433 .90248 m .57767 .90024 L .56588 .89694 L p F P
0 g
s
.117 .5 .275 .1 k
.56588 .89694 m .55561 .89867 L .56433 .90248 L p F P
0 g
s
.283 .5 .542 .1 k
.29096 .80232 m .28283 .78939 L .26347 .76831 L p F P
0 g
s
.25 .5 .542 .1 k
.28283 .78939 m .29096 .80232 L .31252 .82004 L p F P
0 g
s
.25 .5 .525 .1 k
.32188 .8311 m .31252 .82004 L .29096 .80232 L p F P
0 g
s
.683 .5 .758 .1 k
.42388 .27922 m .39907 .28762 L .38825 .29738 L p F P
0 g
s
.683 .5 .742 .1 k
.36328 .30828 m .38825 .29738 L .39907 .28762 L p F P
0 g
s
.45 .5 .608 .1 k
.20609 .61331 m .20853 .5938 L .20595 .56532 L p F P
0 g
s
.417 .5 .608 .1 k
.20853 .5938 m .20609 .61331 L .21236 .64143 L p F P
0 g
s
.483 .5 .025 .1 k
.84314 .52777 m .8352 .50763 L .83625 .5358 L p F P
0 g
s
.483 .5 .025 .1 k
.83625 .5358 m .8442 .55569 L .84314 .52777 L p F P
0 g
s
.317 .5 .558 .1 k
.26347 .76831 m .2572 .75359 L .24056 .72964 L p F P
0 g
s
.283 .5 .558 .1 k
.2572 .75359 m .26347 .76831 L .28283 .78939 L p F P
0 g
s
.183 .5 .158 .1 k
.69181 .85873 m .70264 .84987 L .67773 .86033 L p F P
0 g
s
.183 .5 .158 .1 k
.67773 .86033 m .66855 .86789 L .69181 .85873 L p F P
0 g
s
.117 .5 .392 .1 k
.46822 .89882 m .48132 .9014 L .49165 .89783 L p F P
0 g
s
.117 .5 .375 .1 k
.50206 .89931 m .49165 .89783 L .48132 .9014 L p F P
0 g
s
.217 .5 .525 .1 k
.31252 .82004 m .32188 .8311 L .34504 .84504 L p F P
0 g
s
.217 .5 .508 .1 k
.35499 .85421 m .34504 .84504 L .32188 .8311 L p F P
0 g
s
.15 .5 .192 .1 k
.64611 .88131 m .65797 .8749 L .63458 .87968 L p F P
0 g
s
.15 .5 .192 .1 k
.63458 .87968 m .62491 .88493 L .64611 .88131 L p F P
0 g
s
.65 .5 .725 .1 k
.36328 .30828 m .34053 .32083 L .3279 .33561 L p F P
0 g
s
.65 .5 .708 .1 k
.30638 .35044 m .3279 .33561 L .34053 .32083 L p F P
0 g
s
.117 .5 .258 .1 k
.57767 .90024 m .59052 .89734 L .57576 .8947 L p F P
0 g
s
.117 .5 .258 .1 k
.57576 .8947 m .56588 .89694 L .57767 .90024 L p F P
0 g
s
.617 .5 .958 .1 k
.75629 .35866 m .73625 .34313 L .74746 .36146 L p F P
0 g
s
.617 .5 .958 .1 k
.74746 .36146 m .76846 .37766 L .75629 .35866 L p F P
0 g
s
.683 .5 .892 .1 k
.64182 .28336 m .61629 .27583 L .62399 .28465 L p F P
0 g
s
.683 .5 .892 .1 k
.62399 .28465 m .65167 .29278 L .64182 .28336 L p F P
0 g
s
.35 .5 .575 .1 k
.24056 .72964 m .23672 .7133 L .22324 .68705 L p F P
0 g
s
.317 .5 .575 .1 k
.23672 .7133 m .24056 .72964 L .2572 .75359 L p F P
0 g
s
.383 .5 .058 .1 k
.84016 .65113 m .83953 .63239 L .82951 .66073 L p F P
0 g
s
.383 .5 .058 .1 k
.82951 .66073 m .83024 .67856 L .84016 .65113 L p F P
0 g
s
.117 .5 .408 .1 k
.45567 .89558 m .46822 .89882 L .48157 .89584 L p F P
0 g
s
.117 .5 .392 .1 k
.49165 .89783 m .48157 .89584 L .46822 .89882 L p F P
0 g
s
.517 .5 .008 .1 k
.83067 .48082 m .8191 .46107 L .82351 .48789 L p F P
0 g
s
.517 .5 .008 .1 k
.82351 .48789 m .8352 .50763 L .83067 .48082 L p F P
0 g
s
.483 .5 .625 .1 k
.20595 .56532 m .21209 .54533 L .21315 .51728 L p F P
0 g
s
.45 .5 .625 .1 k
.21209 .54533 m .20595 .56532 L .20853 .5938 L p F P
0 g
s
.15 .5 .475 .1 k
.389 .87133 m .40022 .87806 L .42257 .88227 L p F P
0 g
s
.15 .5 .458 .1 k
.43273 .88727 m .42257 .88227 L .40022 .87806 L p F P
0 g
s
.583 .5 .975 .1 k
.78627 .39505 m .76846 .37766 L .7781 .39947 L p F P
0 g
s
.583 .5 .975 .1 k
.7781 .39947 m .79652 .41734 L .78627 .39505 L p F P
0 g
s
.117 .5 .242 .1 k
.59052 .89734 m .60276 .8938 L .58515 .89197 L p F P
0 g
s
.117 .5 .242 .1 k
.58515 .89197 m .57576 .8947 L .59052 .89734 L p F P
0 g
s
.183 .5 .508 .1 k
.34504 .84504 m .35499 .85421 L .37913 .86403 L p F P
0 g
s
.183 .5 .492 .1 k
.389 .87133 m .37913 .86403 L .35499 .85421 L p F P
0 g
s
.55 .5 .992 .1 k
.81144 .43616 m .79652 .41734 L .80384 .44201 L p F P
0 g
s
.55 .5 .992 .1 k
.80384 .44201 m .8191 .46107 L .81144 .43616 L p F P
0 g
s
.25 .5 .108 .1 k
.76589 .79617 m .77283 .78298 L .74998 .8027 L p F P
0 g
s
.25 .5 .108 .1 k
.74998 .8027 m .74386 .81452 L .76589 .79617 L p F P
0 g
s
.683 .5 .775 .1 k
.45011 .27266 m .42388 .27922 L .41513 .28831 L p F P
0 g
s
.683 .5 .758 .1 k
.38825 .29738 m .41513 .28831 L .42388 .27922 L p F P
0 g
s
.65 .5 .925 .1 k
.70145 .3146 m .6776 .30282 L .68799 .31651 L p F P
0 g
s
.65 .5 .925 .1 k
.68799 .31651 m .7134 .329 L .70145 .3146 L p F P
0 g
s
.217 .5 .125 .1 k
.73552 .82585 m .74386 .81452 L .71895 .8305 L p F P
0 g
s
.217 .5 .125 .1 k
.71895 .8305 m .71173 .84043 L .73552 .82585 L p F P
0 g
s
.117 .5 .425 .1 k
.4438 .89172 m .45567 .89558 L .47193 .89334 L p F P
0 g
s
.117 .5 .408 .1 k
.48157 .89584 m .47193 .89334 L .45567 .89558 L p F P
0 g
s
.383 .5 .592 .1 k
.22324 .68705 m .22235 .66933 L .21236 .64143 L p F P
0 g
s
.35 .5 .592 .1 k
.22235 .66933 m .22324 .68705 L .23672 .7133 L p F P
0 g
s
.283 .5 .092 .1 k
.79252 .76129 m .79745 .74636 L .77721 .76936 L p F P
0 g
s
.283 .5 .092 .1 k
.77721 .76936 m .77283 .78298 L .79252 .76129 L p F P
0 g
s
.417 .5 .042 .1 k
.84582 .60394 m .84162 .5844 L .83533 .61358 L p F P
0 g
s
.417 .5 .042 .1 k
.83533 .61358 m .83953 .63239 L .84582 .60394 L p F P
0 g
s
.15 .5 .175 .1 k
.65797 .8749 m .66855 .86789 L .64318 .87394 L p F P
0 g
s
.15 .5 .175 .1 k
.64318 .87394 m .63458 .87968 L .65797 .8749 L p F P
0 g
s
.617 .5 .708 .1 k
.3279 .33561 m .30638 .35044 L .29468 .36909 L p F P
0 g
s
.617 .5 .692 .1 k
.2752 .38589 m .29468 .36909 L .30638 .35044 L p F P
0 g
s
.683 .5 .875 .1 k
.61629 .27583 m .5895 .2702 L .59492 .27857 L p F P
0 g
s
.683 .5 .875 .1 k
.59492 .27857 m .62399 .28465 L .61629 .27583 L p F P
0 g
s
.117 .5 .225 .1 k
.60276 .8938 m .61426 .88966 L .59395 .88877 L p F P
0 g
s
.117 .5 .225 .1 k
.59395 .88877 m .58515 .89197 L .60276 .8938 L p F P
0 g
s
.517 .5 .642 .1 k
.21315 .51728 m .22303 .49732 L .22751 .4705 L p F P
0 g
s
.483 .5 .642 .1 k
.22303 .49732 m .21315 .51728 L .21209 .54533 L p F P
0 g
s
.183 .5 .142 .1 k
.70264 .84987 m .71173 .84043 L .68539 .85229 L p F P
0 g
s
.183 .5 .142 .1 k
.68539 .85229 m .67773 .86033 L .70264 .84987 L p F P
0 g
s
.317 .5 .075 .1 k
.8143 .72183 m .81665 .70532 L .79949 .73107 L p F P
0 g
s
.317 .5 .075 .1 k
.79949 .73107 m .79745 .74636 L .8143 .72183 L p F P
0 g
s
.683 .5 .792 .1 k
.47741 .26806 m .45011 .27266 L .44358 .28123 L p F P
0 g
s
.683 .5 .775 .1 k
.41513 .28831 m .44358 .28123 L .45011 .27266 L p F P
0 g
s
.117 .5 .442 .1 k
.43273 .88727 m .4438 .89172 L .46284 .89037 L p F P
0 g
s
.117 .5 .425 .1 k
.47193 .89334 m .46284 .89037 L .4438 .89172 L p F P
0 g
s
.65 .5 .742 .1 k
.38825 .29738 m .36328 .30828 L .35212 .3223 L p F P
0 g
s
.65 .5 .725 .1 k
.3279 .33561 m .35212 .3223 L .36328 .30828 L p F P
0 g
s
.417 .5 .608 .1 k
.21236 .64143 m .21483 .62262 L .20853 .5938 L p F P
0 g
s
.383 .5 .608 .1 k
.21483 .62262 m .21236 .64143 L .22235 .66933 L p F P
0 g
s
.15 .5 .492 .1 k
.37913 .86403 m .389 .87133 L .41344 .87676 L p F P
0 g
s
.15 .5 .475 .1 k
.42257 .88227 m .41344 .87676 L .389 .87133 L p F P
0 g
s
.55 .5 .658 .1 k
.22751 .4705 m .241 .45108 L .24849 .42629 L p F P
0 g
s
.517 .5 .658 .1 k
.241 .45108 m .22751 .4705 L .22303 .49732 L p F P
0 g
s
.583 .5 .692 .1 k
.29468 .36909 m .2752 .38589 L .26525 .40793 L p F P
0 g
s
.583 .5 .675 .1 k
.24849 .42629 m .26525 .40793 L .2752 .38589 L p F P
0 g
s
.25 .5 .542 .1 k
.31252 .82004 m .30531 .80844 L .28283 .78939 L p F P
0 g
s
.217 .5 .542 .1 k
.30531 .80844 m .31252 .82004 L .33691 .83533 L p F P
0 g
s
.217 .5 .525 .1 k
.34504 .84504 m .33691 .83533 L .31252 .82004 L p F P
0 g
s
.283 .5 .558 .1 k
.28283 .78939 m .2772 .77596 L .2572 .75359 L p F P
0 g
s
.25 .5 .558 .1 k
.2772 .77596 m .28283 .78939 L .30531 .80844 L p F P
0 g
s
.683 .5 .858 .1 k
.5895 .2702 m .56183 .26656 L .56488 .27463 L p F P
0 g
s
.683 .5 .858 .1 k
.56488 .27463 m .59492 .27857 L .5895 .2702 L p F P
0 g
s
.45 .5 .025 .1 k
.8442 .55569 m .83625 .5358 L .8337 .56502 L p F P
0 g
s
.45 .5 .025 .1 k
.8337 .56502 m .84162 .5844 L .8442 .55569 L p F P
0 g
s
.55 .5 .675 .1 k
.26525 .40793 m .24849 .42629 L .241 .45108 L p F P
0 g
s
.117 .5 .208 .1 k
.61426 .88966 m .62491 .88493 L .60207 .88514 L p F P
0 g
s
.117 .5 .208 .1 k
.60207 .88514 m .59395 .88877 L .61426 .88966 L p F P
0 g
s
.617 .5 .942 .1 k
.73625 .34313 m .7134 .329 L .72347 .34672 L p F P
0 g
s
.617 .5 .942 .1 k
.72347 .34672 m .74746 .36146 L .73625 .34313 L p F P
0 g
s
.683 .5 .808 .1 k
.50539 .26548 m .47741 .26806 L .4732 .27625 L p F P
0 g
s
.683 .5 .792 .1 k
.44358 .28123 m .4732 .27625 L .47741 .26806 L p F P
0 g
s
.317 .5 .575 .1 k
.2572 .75359 m .25375 .73846 L .23672 .7133 L p F P
0 g
s
.283 .5 .575 .1 k
.25375 .73846 m .2572 .75359 L .2772 .77596 L p F P
0 g
s
.183 .5 .525 .1 k
.33691 .83533 m .34504 .84504 L .37073 .85621 L p F P
0 g
s
.183 .5 .508 .1 k
.37913 .86403 m .37073 .85621 L .34504 .84504 L p F P
0 g
s
.35 .5 .058 .1 k
.83024 .67856 m .82951 .66073 L .81581 .68859 L p F P
0 g
s
.35 .5 .058 .1 k
.81581 .68859 m .81665 .70532 L .83024 .67856 L p F P
0 g
s
.683 .5 .842 .1 k
.56183 .26656 m .53366 .26498 L .53429 .27292 L p F P
0 g
s
.683 .5 .842 .1 k
.53429 .27292 m .56488 .27463 L .56183 .26656 L p F P
0 g
s
.65 .5 .908 .1 k
.6776 .30282 m .65167 .29278 L .66032 .30585 L p F P
0 g
s
.65 .5 .908 .1 k
.66032 .30585 m .68799 .31651 L .6776 .30282 L p F P
0 g
s
.15 .5 .158 .1 k
.66855 .86789 m .67773 .86033 L .6506 .86776 L p F P
0 g
s
.15 .5 .158 .1 k
.6506 .86776 m .64318 .87394 L .66855 .86789 L p F P
0 g
s
.117 .5 .458 .1 k
.42257 .88227 m .43273 .88727 L .45437 .88694 L p F P
0 g
s
.117 .5 .442 .1 k
.46284 .89037 m .45437 .88694 L .43273 .88727 L p F P
0 g
s
.683 .5 .825 .1 k
.53366 .26498 m .50539 .26548 L .50358 .27347 L p F P
0 g
s
.683 .5 .808 .1 k
.4732 .27625 m .50358 .27347 L .50539 .26548 L p F P
0 g
s
.683 .5 .825 .1 k
.50358 .27347 m .53429 .27292 L .53366 .26498 L p F P
0 g
s
.45 .5 .625 .1 k
.20853 .5938 m .21466 .57431 L .21209 .54533 L p F P
0 g
s
.417 .5 .625 .1 k
.21466 .57431 m .20853 .5938 L .21483 .62262 L p F P
0 g
s
.483 .5 .008 .1 k
.8352 .50763 m .82351 .48789 L .82453 .51632 L p F P
0 g
s
.483 .5 .008 .1 k
.82453 .51632 m .83625 .5358 L .8352 .50763 L p F P
0 g
s
.217 .5 .108 .1 k
.74386 .81452 m .74998 .8027 L .72419 .82016 L p F P
0 g
s
.217 .5 .108 .1 k
.72419 .82016 m .71895 .8305 L .74386 .81452 L p F P
0 g
s
.083 .5 .342 .1 k
.51272 .90026 m .52351 .90067 L .5244 .89244 L p F P
0 g
s
.083 .5 .325 .1 k
.52351 .90067 m .53432 .90054 L .53178 .89235 L p F P
0 g
s
.083 .5 .325 .1 k
.53178 .89235 m .5244 .89244 L .52351 .90067 L p F P
0 g
s
.083 .5 .308 .1 k
.53432 .90054 m .54506 .89987 L .53911 .89189 L p F P
0 g
s
.083 .5 .308 .1 k
.53911 .89189 m .53178 .89235 L .53432 .90054 L p F P
0 g
s
.117 .5 .192 .1 k
.62491 .88493 m .63458 .87968 L .60944 .88111 L p F P
0 g
s
.117 .5 .192 .1 k
.60944 .88111 m .60207 .88514 L .62491 .88493 L p F P
0 g
s
.35 .5 .592 .1 k
.23672 .7133 m .23601 .69666 L .22235 .66933 L p F P
0 g
s
.317 .5 .592 .1 k
.23601 .69666 m .23672 .7133 L .25375 .73846 L p F P
0 g
s
.583 .5 .958 .1 k
.76846 .37766 m .74746 .36146 L .75634 .38282 L p F P
0 g
s
.583 .5 .958 .1 k
.75634 .38282 m .7781 .39947 L .76846 .37766 L p F P
0 g
s
.083 .5 .358 .1 k
.50206 .89931 m .51272 .90026 L .51704 .89216 L p F P
0 g
s
.083 .5 .342 .1 k
.5244 .89244 m .51704 .89216 L .51272 .90026 L p F P
0 g
s
.25 .5 .092 .1 k
.77283 .78298 m .77721 .76936 L .75376 .79052 L p F P
0 g
s
.25 .5 .092 .1 k
.75376 .79052 m .74998 .8027 L .77283 .78298 L p F P
0 g
s
.083 .5 .292 .1 k
.54506 .89987 m .55561 .89867 L .54631 .89107 L p F P
0 g
s
.083 .5 .292 .1 k
.54631 .89107 m .53911 .89189 L .54506 .89987 L p F P
0 g
s
.65 .5 .758 .1 k
.41513 .28831 m .38825 .29738 L .37874 .31073 L p F P
0 g
s
.65 .5 .742 .1 k
.35212 .3223 m .37874 .31073 L .38825 .29738 L p F P
0 g
s
.183 .5 .125 .1 k
.71173 .84043 m .71895 .8305 L .69142 .84385 L p F P
0 g
s
.183 .5 .125 .1 k
.69142 .84385 m .68539 .85229 L .71173 .84043 L p F P
0 g
s
.15 .5 .508 .1 k
.37073 .85621 m .37913 .86403 L .40545 .87078 L p F P
0 g
s
.15 .5 .492 .1 k
.41344 .87676 m .40545 .87078 L .37913 .86403 L p F P
0 g
s
.083 .5 .375 .1 k
.49165 .89783 m .50206 .89931 L .50977 .89151 L p F P
0 g
s
.083 .5 .358 .1 k
.51704 .89216 m .50977 .89151 L .50206 .89931 L p F P
0 g
s
.517 .5 .992 .1 k
.8191 .46107 m .80384 .44201 L .80807 .46883 L p F P
0 g
s
.517 .5 .992 .1 k
.80807 .46883 m .82351 .48789 L .8191 .46107 L p F P
0 g
s
.617 .5 .725 .1 k
.35212 .3223 m .3279 .33561 L .31727 .35362 L p F P
0 g
s
.617 .5 .708 .1 k
.29468 .36909 m .31727 .35362 L .3279 .33561 L p F P
0 g
s
.383 .5 .042 .1 k
.83953 .63239 m .83533 .61358 L .82534 .64285 L p F P
0 g
s
.383 .5 .042 .1 k
.82534 .64285 m .82951 .66073 L .83953 .63239 L p F P
0 g
s
.083 .5 .275 .1 k
.55561 .89867 m .56588 .89694 L .5533 .88988 L p F P
0 g
s
.083 .5 .275 .1 k
.5533 .88988 m .54631 .89107 L .55561 .89867 L p F P
0 g
s
.55 .5 .975 .1 k
.79652 .41734 m .7781 .39947 L .785 .4239 L p F P
0 g
s
.55 .5 .975 .1 k
.785 .4239 m .80384 .44201 L .79652 .41734 L p F P
0 g
s
.117 .5 .475 .1 k
.41344 .87676 m .42257 .88227 L .44664 .8831 L p F P
0 g
s
.117 .5 .458 .1 k
.45437 .88694 m .44664 .8831 L .42257 .88227 L p F P
0 g
s
.083 .5 .392 .1 k
.48157 .89584 m .49165 .89783 L .50267 .8905 L p F P
0 g
s
.083 .5 .375 .1 k
.50977 .89151 m .50267 .8905 L .49165 .89783 L p F P
0 g
s
.283 .5 .075 .1 k
.79745 .74636 m .79949 .73107 L .77891 .75545 L p F P
0 g
s
.283 .5 .075 .1 k
.77891 .75545 m .77721 .76936 L .79745 .74636 L p F P
0 g
s
.483 .5 .642 .1 k
.21209 .54533 m .222 .52562 L .22303 .49732 L p F P
0 g
s
.45 .5 .642 .1 k
.222 .52562 m .21209 .54533 L .21466 .57431 L p F P
0 g
s
.083 .5 .258 .1 k
.56588 .89694 m .57576 .8947 L .56002 .88835 L p F P
0 g
s
.083 .5 .258 .1 k
.56002 .88835 m .5533 .88988 L .56588 .89694 L p F P
0 g
s
.65 .5 .892 .1 k
.65167 .29278 m .62399 .28465 L .63076 .29721 L p F P
0 g
s
.65 .5 .892 .1 k
.63076 .29721 m .66032 .30585 L .65167 .29278 L p F P
0 g
s
.083 .5 .408 .1 k
.47193 .89334 m .48157 .89584 L .49581 .88913 L p F P
0 g
s
.083 .5 .392 .1 k
.50267 .8905 m .49581 .88913 L .48157 .89584 L p F P
0 g
s
.383 .5 .608 .1 k
.22235 .66933 m .22485 .65144 L .21483 .62262 L p F P
0 g
s
.35 .5 .608 .1 k
.22485 .65144 m .22235 .66933 L .23601 .69666 L p F P
0 g
s
.15 .5 .142 .1 k
.67773 .86033 m .68539 .85229 L .65675 .8612 L p F P
0 g
s
.15 .5 .142 .1 k
.65675 .8612 m .6506 .86776 L .67773 .86033 L p F P
0 g
s
.117 .5 .175 .1 k
.63458 .87968 m .64318 .87394 L .61595 .87671 L p F P
0 g
s
.117 .5 .175 .1 k
.61595 .87671 m .60944 .88111 L .63458 .87968 L p F P
0 g
s
.25 .5 .558 .1 k
.30531 .80844 m .30039 .79642 L .2772 .77596 L p F P
0 g
s
.217 .5 .558 .1 k
.30039 .79642 m .30531 .80844 L .33071 .82518 L p F P
0 g
s
.217 .5 .542 .1 k
.33691 .83533 m .33071 .82518 L .30531 .80844 L p F P
0 g
s
.083 .5 .242 .1 k
.57576 .8947 m .58515 .89197 L .56639 .88648 L p F P
0 g
s
.083 .5 .242 .1 k
.56639 .88648 m .56002 .88835 L .57576 .8947 L p F P
0 g
s
.617 .5 .925 .1 k
.7134 .329 m .68799 .31651 L .69675 .33367 L p F P
0 g
s
.617 .5 .925 .1 k
.69675 .33367 m .72347 .34672 L .7134 .329 L p F P
0 g
s
.183 .5 .542 .1 k
.33071 .82518 m .33691 .83533 L .36391 .84795 L p F P
0 g
s
.183 .5 .525 .1 k
.37073 .85621 m .36391 .84795 L .33691 .83533 L p F P
0 g
s
.583 .5 .708 .1 k
.31727 .35362 m .29468 .36909 L .28542 .39066 L p F P
0 g
s
.583 .5 .692 .1 k
.26525 .40793 m .28542 .39066 L .29468 .36909 L p F P
0 g
s
.417 .5 .025 .1 k
.84162 .5844 m .8337 .56502 L .82751 .59492 L p F P
0 g
s
.417 .5 .025 .1 k
.82751 .59492 m .83533 .61358 L .84162 .5844 L p F P
0 g
s
.517 .5 .658 .1 k
.22303 .49732 m .23667 .4779 L .241 .45108 L p F P
0 g
s
.483 .5 .658 .1 k
.23667 .4779 m .22303 .49732 L .222 .52562 L p F P
0 g
s
.283 .5 .575 .1 k
.2772 .77596 m .2742 .76217 L .25375 .73846 L p F P
0 g
s
.25 .5 .575 .1 k
.2742 .76217 m .2772 .77596 L .30039 .79642 L p F P
0 g
s
.317 .5 .058 .1 k
.81665 .70532 m .81581 .68859 L .79853 .7156 L p F P
0 g
s
.317 .5 .058 .1 k
.79853 .7156 m .79949 .73107 L .81665 .70532 L p F P
0 g
s
.083 .5 .425 .1 k
.46284 .89037 m .47193 .89334 L .48926 .88742 L p F P
0 g
s
.083 .5 .408 .1 k
.49581 .88913 m .48926 .88742 L .47193 .89334 L p F P
0 g
s
.65 .5 .775 .1 k
.44358 .28123 m .41513 .28831 L .40744 .3011 L p F P
0 g
s
.65 .5 .758 .1 k
.37874 .31073 m .40744 .3011 L .41513 .28831 L p F P
0 g
s
.117 .5 .492 .1 k
.40545 .87078 m .41344 .87676 L .43971 .87887 L p F P
0 g
s
.117 .5 .475 .1 k
.44664 .8831 m .43971 .87887 L .41344 .87676 L p F P
0 g
s
.083 .5 .225 .1 k
.58515 .89197 m .59395 .88877 L .57235 .8843 L p F P
0 g
s
.083 .5 .225 .1 k
.57235 .8843 m .56639 .88648 L .58515 .89197 L p F P
0 g
s
.15 .5 .525 .1 k
.36391 .84795 m .37073 .85621 L .39868 .8644 L p F P
0 g
s
.15 .5 .508 .1 k
.40545 .87078 m .39868 .8644 L .37073 .85621 L p F P
0 g
s
.55 .5 .692 .1 k
.28542 .39066 m .26525 .40793 L .25813 .43247 L p F P
0 g
s
.55 .5 .675 .1 k
.241 .45108 m .25813 .43247 L .26525 .40793 L p F P
0 g
s
.517 .5 .675 .1 k
.25813 .43247 m .241 .45108 L .23667 .4779 L p F P
0 g
s
.417 .5 .625 .1 k
.21483 .62262 m .2209 .60386 L .21466 .57431 L p F P
0 g
s
.383 .5 .625 .1 k
.2209 .60386 m .21483 .62262 L .22485 .65144 L p F P
0 g
s
.65 .5 .875 .1 k
.62399 .28465 m .59492 .27857 L .5997 .29075 L p F P
0 g
s
.65 .5 .875 .1 k
.5997 .29075 m .63076 .29721 L .62399 .28465 L p F P
0 g
s
.083 .5 .442 .1 k
.45437 .88694 m .46284 .89037 L .48309 .88538 L p F P
0 g
s
.083 .5 .425 .1 k
.48926 .88742 m .48309 .88538 L .46284 .89037 L p F P
0 g
s
.317 .5 .592 .1 k
.25375 .73846 m .25326 .72306 L .23601 .69666 L p F P
0 g
s
.283 .5 .592 .1 k
.25326 .72306 m .25375 .73846 L .2742 .76217 L p F P
0 g
s
.183 .5 .108 .1 k
.71895 .8305 m .72419 .82016 L .69572 .83508 L p F P
0 g
s
.183 .5 .108 .1 k
.69572 .83508 m .69142 .84385 L .71895 .8305 L p F P
0 g
s
.617 .5 .742 .1 k
.37874 .31073 m .35212 .3223 L .34271 .33972 L p F P
0 g
s
.617 .5 .725 .1 k
.31727 .35362 m .34271 .33972 L .35212 .3223 L p F P
0 g
s
.45 .5 .008 .1 k
.83625 .5358 m .82453 .51632 L .82205 .54602 L p F P
0 g
s
.45 .5 .008 .1 k
.82205 .54602 m .8337 .56502 L .83625 .5358 L p F P
0 g
s
.117 .5 .158 .1 k
.64318 .87394 m .6506 .86776 L .62154 .87199 L p F P
0 g
s
.117 .5 .158 .1 k
.62154 .87199 m .61595 .87671 L .64318 .87394 L p F P
0 g
s
.217 .5 .092 .1 k
.74998 .8027 m .75376 .79052 L .72733 .80953 L p F P
0 g
s
.217 .5 .092 .1 k
.72733 .80953 m .72419 .82016 L .74998 .8027 L p F P
0 g
s
.083 .5 .208 .1 k
.59395 .88877 m .60207 .88514 L .57784 .88182 L p F P
0 g
s
.083 .5 .208 .1 k
.57784 .88182 m .57235 .8843 L .59395 .88877 L p F P
0 g
s
.583 .5 .942 .1 k
.74746 .36146 m .72347 .34672 L .73145 .36766 L p F P
0 g
s
.583 .5 .942 .1 k
.73145 .36766 m .75634 .38282 L .74746 .36146 L p F P
0 g
s
.35 .5 .042 .1 k
.82951 .66073 m .82534 .64285 L .81168 .67183 L p F P
0 g
s
.35 .5 .042 .1 k
.81168 .67183 m .81581 .68859 L .82951 .66073 L p F P
0 g
s
.65 .5 .792 .1 k
.4732 .27625 m .44358 .28123 L .43783 .29358 L p F P
0 g
s
.65 .5 .775 .1 k
.40744 .3011 m .43783 .29358 L .44358 .28123 L p F P
0 g
s
.15 .5 .125 .1 k
.68539 .85229 m .69142 .84385 L .66154 .85433 L p F P
0 g
s
.15 .5 .125 .1 k
.66154 .85433 m .65675 .8612 L .68539 .85229 L p F P
0 g
s
.25 .5 .075 .1 k
.77721 .76936 m .77891 .75545 L .75509 .7781 L p F P
0 g
s
.25 .5 .075 .1 k
.75509 .7781 m .75376 .79052 L .77721 .76936 L p F P
0 g
s
.083 .5 .458 .1 k
.44664 .8831 m .45437 .88694 L .47737 .88305 L p F P
0 g
s
.083 .5 .442 .1 k
.48309 .88538 m .47737 .88305 L .45437 .88694 L p F P
0 g
s
.65 .5 .858 .1 k
.59492 .27857 m .56488 .27463 L .56757 .28656 L p F P
0 g
s
.65 .5 .858 .1 k
.56757 .28656 m .5997 .29075 L .59492 .27857 L p F P
0 g
s
.117 .5 .508 .1 k
.39868 .8644 m .40545 .87078 L .43366 .8743 L p F P
0 g
s
.117 .5 .492 .1 k
.43971 .87887 m .43366 .8743 L .40545 .87078 L p F P
0 g
s
.483 .5 .992 .1 k
.82351 .48789 m .80807 .46883 L .80905 .4975 L p F P
0 g
s
.483 .5 .992 .1 k
.80905 .4975 m .82453 .51632 L .82351 .48789 L p F P
0 g
s
.45 .5 .642 .1 k
.21466 .57431 m .22451 .55509 L .222 .52562 L p F P
0 g
s
.417 .5 .642 .1 k
.22451 .55509 m .21466 .57431 L .2209 .60386 L p F P
0 g
s
.35 .5 .608 .1 k
.23601 .69666 m .23855 .67988 L .22485 .65144 L p F P
0 g
s
.317 .5 .608 .1 k
.23855 .67988 m .23601 .69666 L .25326 .72306 L p F P
0 g
s
.617 .5 .908 .1 k
.68799 .31651 m .66032 .30585 L .66762 .32253 L p F P
0 g
s
.617 .5 .908 .1 k
.66762 .32253 m .69675 .33367 L .68799 .31651 L p F P
0 g
s
.55 .5 .958 .1 k
.7781 .39947 m .75634 .38282 L .7627 .40702 L p F P
0 g
s
.55 .5 .958 .1 k
.7627 .40702 m .785 .4239 L .7781 .39947 L p F P
0 g
s
.083 .5 .192 .1 k
.60207 .88514 m .60944 .88111 L .58279 .87907 L p F P
0 g
s
.083 .5 .192 .1 k
.58279 .87907 m .57784 .88182 L .60207 .88514 L p F P
0 g
s
.65 .5 .808 .1 k
.50358 .27347 m .4732 .27625 L .4695 .28828 L p F P
0 g
s
.65 .5 .792 .1 k
.43783 .29358 m .4695 .28828 L .4732 .27625 L p F P
0 g
s
.517 .5 .975 .1 k
.80384 .44201 m .785 .4239 L .78898 .45071 L p F P
0 g
s
.517 .5 .975 .1 k
.78898 .45071 m .80807 .46883 L .80384 .44201 L p F P
0 g
s
.217 .5 .558 .1 k
.33071 .82518 m .32655 .81467 L .30039 .79642 L p F P
0 g
s
.183 .5 .558 .1 k
.32655 .81467 m .33071 .82518 L .35876 .83933 L p F P
0 g
s
.183 .5 .542 .1 k
.36391 .84795 m .35876 .83933 L .33071 .82518 L p F P
0 g
s
.65 .5 .842 .1 k
.56488 .27463 m .53429 .27292 L .53485 .28475 L p F P
0 g
s
.65 .5 .842 .1 k
.53485 .28475 m .56757 .28656 L .56488 .27463 L p F P
0 g
s
.25 .5 .575 .1 k
.30039 .79642 m .29787 .7841 L .2742 .76217 L p F P
0 g
s
.217 .5 .575 .1 k
.29787 .7841 m .30039 .79642 L .32655 .81467 L p F P
0 g
s
.15 .5 .542 .1 k
.35876 .83933 m .36391 .84795 L .39322 .85767 L p F P
0 g
s
.15 .5 .525 .1 k
.39868 .8644 m .39322 .85767 L .36391 .84795 L p F P
0 g
s
.283 .5 .058 .1 k
.79949 .73107 m .79853 .7156 L .77782 .74138 L p F P
0 g
s
.283 .5 .058 .1 k
.77782 .74138 m .77891 .75545 L .79949 .73107 L p F P
0 g
s
.117 .5 .142 .1 k
.6506 .86776 m .65675 .8612 L .62614 .86698 L p F P
0 g
s
.117 .5 .142 .1 k
.62614 .86698 m .62154 .87199 L .6506 .86776 L p F P
0 g
s
.383 .5 .025 .1 k
.83533 .61358 m .82751 .59492 L .81766 .62512 L p F P
0 g
s
.383 .5 .025 .1 k
.81766 .62512 m .82534 .64285 L .83533 .61358 L p F P
0 g
s
.083 .5 .475 .1 k
.43971 .87887 m .44664 .8831 L .47215 .88042 L p F P
0 g
s
.083 .5 .458 .1 k
.47737 .88305 m .47215 .88042 L .44664 .8831 L p F P
0 g
s
.65 .5 .825 .1 k
.53429 .27292 m .50358 .27347 L .502 .28532 L p F P
0 g
s
.65 .5 .808 .1 k
.4695 .28828 m .502 .28532 L .50358 .27347 L p F P
0 g
s
.583 .5 .725 .1 k
.34271 .33972 m .31727 .35362 L .30883 .37475 L p F P
0 g
s
.583 .5 .708 .1 k
.28542 .39066 m .30883 .37475 L .31727 .35362 L p F P
0 g
s
.65 .5 .825 .1 k
.502 .28532 m .53485 .28475 L .53429 .27292 L p F P
0 g
s
.617 .5 .758 .1 k
.40744 .3011 m .37874 .31073 L .37072 .32764 L p F P
0 g
s
.617 .5 .742 .1 k
.34271 .33972 m .37072 .32764 L .37874 .31073 L p F P
0 g
s
.483 .5 .658 .1 k
.222 .52562 m .23567 .50645 L .23667 .4779 L p F P
0 g
s
.45 .5 .658 .1 k
.23567 .50645 m .222 .52562 L .22451 .55509 L p F P
0 g
s
.083 .5 .175 .1 k
.60944 .88111 m .61595 .87671 L .58716 .87608 L p F P
0 g
s
.083 .5 .175 .1 k
.58716 .87608 m .58279 .87907 L .60944 .88111 L p F P
0 g
s
.05 .5 .342 .1 k
.51704 .89216 m .5244 .89244 L .52534 .88033 L p F P
0 g
s
.05 .5 .325 .1 k
.5244 .89244 m .53178 .89235 L .5291 .88028 L p F P
0 g
s
.05 .5 .325 .1 k
.5291 .88028 m .52534 .88033 L .5244 .89244 L p F P
0 g
s
.05 .5 .308 .1 k
.53178 .89235 m .53911 .89189 L .53284 .88005 L p F P
0 g
s
.05 .5 .308 .1 k
.53284 .88005 m .5291 .88028 L .53178 .89235 L p F P
0 g
s
.283 .5 .592 .1 k
.2742 .76217 m .27394 .74816 L .25326 .72306 L p F P
0 g
s
.25 .5 .592 .1 k
.27394 .74816 m .2742 .76217 L .29787 .7841 L p F P
0 g
s
.05 .5 .358 .1 k
.50977 .89151 m .51704 .89216 L .52158 .88019 L p F P
0 g
s
.05 .5 .342 .1 k
.52534 .88033 m .52158 .88019 L .51704 .89216 L p F P
0 g
s
.383 .5 .625 .1 k
.22485 .65144 m .23084 .63361 L .2209 .60386 L p F P
0 g
s
.35 .5 .625 .1 k
.23084 .63361 m .22485 .65144 L .23855 .67988 L p F P
0 g
s
.05 .5 .292 .1 k
.53911 .89189 m .54631 .89107 L .5365 .87962 L p F P
0 g
s
.05 .5 .292 .1 k
.5365 .87962 m .53284 .88005 L .53911 .89189 L p F P
0 g
s
.117 .5 .525 .1 k
.39322 .85767 m .39868 .8644 L .42858 .86942 L p F P
0 g
s
.117 .5 .508 .1 k
.43366 .8743 m .42858 .86942 L .39868 .8644 L p F P
0 g
s
.05 .5 .375 .1 k
.50267 .8905 m .50977 .89151 L .51788 .87985 L p F P
0 g
s
.05 .5 .358 .1 k
.52158 .88019 m .51788 .87985 L .50977 .89151 L p F P
0 g
s
.183 .5 .092 .1 k
.72419 .82016 m .72733 .80953 L .69823 .82608 L p F P
0 g
s
.183 .5 .092 .1 k
.69823 .82608 m .69572 .83508 L .72419 .82016 L p F P
0 g
s
.05 .5 .275 .1 k
.54631 .89107 m .5533 .88988 L .54006 .87901 L p F P
0 g
s
.05 .5 .275 .1 k
.54006 .87901 m .5365 .87962 L .54631 .89107 L p F P
0 g
s
.15 .5 .108 .1 k
.69142 .84385 m .69572 .83508 L .66492 .84721 L p F P
0 g
s
.15 .5 .108 .1 k
.66492 .84721 m .66154 .85433 L .69142 .84385 L p F P
0 g
s
.05 .5 .392 .1 k
.49581 .88913 m .50267 .8905 L .51427 .87933 L p F P
0 g
s
.05 .5 .375 .1 k
.51788 .87985 m .51427 .87933 L .50267 .8905 L p F P
0 g
s
.55 .5 .708 .1 k
.30883 .37475 m .28542 .39066 L .27879 .41497 L p F P
0 g
s
.55 .5 .692 .1 k
.25813 .43247 m .27879 .41497 L .28542 .39066 L p F P
0 g
s
.083 .5 .492 .1 k
.43366 .8743 m .43971 .87887 L .4675 .87755 L p F P
0 g
s
.083 .5 .475 .1 k
.47215 .88042 m .4675 .87755 L .43971 .87887 L p F P
0 g
s
.317 .5 .042 .1 k
.81581 .68859 m .81168 .67183 L .79447 .70012 L p F P
0 g
s
.317 .5 .042 .1 k
.79447 .70012 m .79853 .7156 L .81581 .68859 L p F P
0 g
s
.517 .5 .675 .1 k
.23667 .4779 m .25402 .45929 L .25813 .43247 L p F P
0 g
s
.483 .5 .675 .1 k
.25402 .45929 m .23667 .4779 L .23567 .50645 L p F P
0 g
s
.05 .5 .258 .1 k
.5533 .88988 m .56002 .88835 L .54347 .87823 L p F P
0 g
s
.05 .5 .258 .1 k
.54347 .87823 m .54006 .87901 L .5533 .88988 L p F P
0 g
s
.417 .5 .008 .1 k
.8337 .56502 m .82205 .54602 L .81602 .57664 L p F P
0 g
s
.417 .5 .008 .1 k
.81602 .57664 m .82751 .59492 L .8337 .56502 L p F P
0 g
s
.617 .5 .892 .1 k
.66032 .30585 m .63076 .29721 L .63648 .3135 L p F P
0 g
s
.617 .5 .892 .1 k
.63648 .3135 m .66762 .32253 L .66032 .30585 L p F P
0 g
s
.217 .5 .075 .1 k
.75376 .79052 m .75509 .7781 L .72831 .7987 L p F P
0 g
s
.217 .5 .075 .1 k
.72831 .7987 m .72733 .80953 L .75376 .79052 L p F P
0 g
s
.583 .5 .925 .1 k
.72347 .34672 m .69675 .33367 L .7037 .35422 L p F P
0 g
s
.583 .5 .925 .1 k
.7037 .35422 m .73145 .36766 L .72347 .34672 L p F P
0 g
s
.05 .5 .408 .1 k
.48926 .88742 m .49581 .88913 L .51078 .87863 L p F P
0 g
s
.05 .5 .392 .1 k
.51427 .87933 m .51078 .87863 L .49581 .88913 L p F P
0 g
s
.517 .5 .692 .1 k
.27879 .41497 m .25813 .43247 L .25402 .45929 L p F P
0 g
s
.117 .5 .125 .1 k
.65675 .8612 m .66154 .85433 L .62969 .86175 L p F P
0 g
s
.117 .5 .125 .1 k
.62969 .86175 m .62614 .86698 L .65675 .8612 L p F P
0 g
s
.05 .5 .242 .1 k
.56002 .88835 m .56639 .88648 L .5467 .87727 L p F P
0 g
s
.05 .5 .242 .1 k
.5467 .87727 m .54347 .87823 L .56002 .88835 L p F P
0 g
s
.083 .5 .158 .1 k
.61595 .87671 m .62154 .87199 L .59088 .87288 L p F P
0 g
s
.083 .5 .158 .1 k
.59088 .87288 m .58716 .87608 L .61595 .87671 L p F P
0 g
s
.317 .5 .608 .1 k
.25326 .72306 m .25582 .70756 L .23855 .67988 L p F P
0 g
s
.283 .5 .608 .1 k
.25582 .70756 m .25326 .72306 L .27394 .74816 L p F P
0 g
s
.05 .5 .425 .1 k
.48309 .88538 m .48926 .88742 L .50746 .87775 L p F P
0 g
s
.05 .5 .408 .1 k
.51078 .87863 m .50746 .87775 L .48926 .88742 L p F P
0 g
s
.183 .5 .558 .1 k
.35876 .83933 m .35538 .83043 L .32655 .81467 L p F P
0 g
s
.15 .5 .558 .1 k
.35538 .83043 m .35876 .83933 L .38916 .85066 L p F P
0 g
s
.15 .5 .542 .1 k
.39322 .85767 m .38916 .85066 L .35876 .83933 L p F P
0 g
s
.417 .5 .642 .1 k
.2209 .60386 m .23063 .58537 L .22451 .55509 L p F P
0 g
s
.383 .5 .642 .1 k
.23063 .58537 m .2209 .60386 L .23084 .63361 L p F P
0 g
s
.05 .5 .225 .1 k
.56639 .88648 m .57235 .8843 L .54972 .87615 L p F P
0 g
s
.05 .5 .225 .1 k
.54972 .87615 m .5467 .87727 L .56639 .88648 L p F P
0 g
s
.617 .5 .775 .1 k
.43783 .29358 m .40744 .3011 L .40095 .31757 L p F P
0 g
s
.617 .5 .758 .1 k
.37072 .32764 m .40095 .31757 L .40744 .3011 L p F P
0 g
s
.217 .5 .575 .1 k
.32655 .81467 m .32452 .80392 L .29787 .7841 L p F P
0 g
s
.183 .5 .575 .1 k
.32452 .80392 m .32655 .81467 L .35538 .83043 L p F P
0 g
s
.25 .5 .058 .1 k
.77891 .75545 m .77782 .74138 L .7539 .76557 L p F P
0 g
s
.25 .5 .058 .1 k
.7539 .76557 m .75509 .7781 L .77891 .75545 L p F P
0 g
s
.083 .5 .508 .1 k
.42858 .86942 m .43366 .8743 L .46346 .87444 L p F P
0 g
s
.083 .5 .492 .1 k
.4675 .87755 m .46346 .87444 L .43366 .8743 L p F P
0 g
s
.45 .5 .992 .1 k
.82453 .51632 m .80905 .4975 L .80667 .52768 L p F P
0 g
s
.45 .5 .992 .1 k
.80667 .52768 m .82205 .54602 L .82453 .51632 L p F P
0 g
s
.05 .5 .442 .1 k
.47737 .88305 m .48309 .88538 L .50433 .87671 L p F P
0 g
s
.05 .5 .425 .1 k
.50746 .87775 m .50433 .87671 L .48309 .88538 L p F P
0 g
s
.117 .5 .542 .1 k
.38916 .85066 m .39322 .85767 L .42452 .8643 L p F P
0 g
s
.117 .5 .525 .1 k
.42858 .86942 m .42452 .8643 L .39322 .85767 L p F P
0 g
s
.55 .5 .942 .1 k
.75634 .38282 m .73145 .36766 L .73717 .39163 L p F P
0 g
s
.55 .5 .942 .1 k
.73717 .39163 m .7627 .40702 L .75634 .38282 L p F P
0 g
s
.35 .5 .025 .1 k
.82534 .64285 m .81766 .62512 L .80421 .65522 L p F P
0 g
s
.35 .5 .025 .1 k
.80421 .65522 m .81168 .67183 L .82534 .64285 L p F P
0 g
s
.583 .5 .742 .1 k
.37072 .32764 m .34271 .33972 L .33525 .36045 L p F P
0 g
s
.583 .5 .725 .1 k
.30883 .37475 m .33525 .36045 L .34271 .33972 L p F P
0 g
s
.05 .5 .208 .1 k
.57235 .8843 m .57784 .88182 L .55249 .87489 L p F P
0 g
s
.05 .5 .208 .1 k
.55249 .87489 m .54972 .87615 L .57235 .8843 L p F P
0 g
s
.25 .5 .592 .1 k
.29787 .7841 m .29784 .7716 L .27394 .74816 L p F P
0 g
s
.217 .5 .592 .1 k
.29784 .7716 m .29787 .7841 L .32452 .80392 L p F P
0 g
s
.617 .5 .875 .1 k
.63076 .29721 m .5997 .29075 L .60373 .30674 L p F P
0 g
s
.617 .5 .875 .1 k
.60373 .30674 m .63648 .3135 L .63076 .29721 L p F P
0 g
s
.083 .5 .142 .1 k
.62154 .87199 m .62614 .86698 L .59392 .86949 L p F P
0 g
s
.083 .5 .142 .1 k
.59392 .86949 m .59088 .87288 L .62154 .87199 L p F P
0 g
s
.483 .5 .975 .1 k
.80807 .46883 m .78898 .45071 L .7899 .47961 L p F P
0 g
s
.483 .5 .975 .1 k
.7899 .47961 m .80905 .4975 L .80807 .46883 L p F P
0 g
s
.05 .5 .458 .1 k
.47215 .88042 m .47737 .88305 L .50144 .87551 L p F P
0 g
s
.05 .5 .442 .1 k
.50433 .87671 m .50144 .87551 L .47737 .88305 L p F P
0 g
s
.517 .5 .958 .1 k
.785 .4239 m .7627 .40702 L .76637 .43382 L p F P
0 g
s
.517 .5 .958 .1 k
.76637 .43382 m .78898 .45071 L .785 .4239 L p F P
0 g
s
.15 .5 .092 .1 k
.69572 .83508 m .69823 .82608 L .66681 .83992 L p F P
0 g
s
.15 .5 .092 .1 k
.66681 .83992 m .66492 .84721 L .69572 .83508 L p F P
0 g
s
.35 .5 .625 .1 k
.23855 .67988 m .24441 .66317 L .23084 .63361 L p F P
0 g
s
.317 .5 .625 .1 k
.24441 .66317 m .23855 .67988 L .25582 .70756 L p F P
0 g
s
.05 .5 .192 .1 k
.57784 .88182 m .58279 .87907 L .55497 .87348 L p F P
0 g
s
.05 .5 .192 .1 k
.55497 .87348 m .55249 .87489 L .57784 .88182 L p F P
0 g
s
.117 .5 .108 .1 k
.66154 .85433 m .66492 .84721 L .63214 .85635 L p F P
0 g
s
.117 .5 .108 .1 k
.63214 .85635 m .62969 .86175 L .66154 .85433 L p F P
0 g
s
.45 .5 .658 .1 k
.22451 .55509 m .2381 .53641 L .23567 .50645 L p F P
0 g
s
.417 .5 .658 .1 k
.2381 .53641 m .22451 .55509 L .23063 .58537 L p F P
0 g
s
.183 .5 .075 .1 k
.72733 .80953 m .72831 .7987 L .69888 .81694 L p F P
0 g
s
.183 .5 .075 .1 k
.69888 .81694 m .69823 .82608 L .72733 .80953 L p F P
0 g
s
.283 .5 .042 .1 k
.79853 .7156 m .79447 .70012 L .77388 .72733 L p F P
0 g
s
.283 .5 .042 .1 k
.77388 .72733 m .77782 .74138 L .79853 .7156 L p F P
0 g
s
.617 .5 .792 .1 k
.4695 .28828 m .43783 .29358 L .43298 .3097 L p F P
0 g
s
.617 .5 .775 .1 k
.40095 .31757 m .43298 .3097 L .43783 .29358 L p F P
0 g
s
.083 .5 .525 .1 k
.42452 .8643 m .42858 .86942 L .46009 .87114 L p F P
0 g
s
.083 .5 .508 .1 k
.46346 .87444 m .46009 .87114 L .42858 .86942 L p F P
0 g
s
.05 .5 .475 .1 k
.4675 .87755 m .47215 .88042 L .49882 .87417 L p F P
0 g
s
.05 .5 .458 .1 k
.50144 .87551 m .49882 .87417 L .47215 .88042 L p F P
0 g
s
.583 .5 .908 .1 k
.69675 .33367 m .66762 .32253 L .67342 .34275 L p F P
0 g
s
.583 .5 .908 .1 k
.67342 .34275 m .7037 .35422 L .69675 .33367 L p F P
0 g
s
.283 .5 .608 .1 k
.27394 .74816 m .2765 .73408 L .25582 .70756 L p F P
0 g
s
.25 .5 .608 .1 k
.2765 .73408 m .27394 .74816 L .29784 .7716 L p F P
0 g
s
.383 .5 .008 .1 k
.82751 .59492 m .81602 .57664 L .80645 .60777 L p F P
0 g
s
.383 .5 .008 .1 k
.80645 .60777 m .81766 .62512 L .82751 .59492 L p F P
0 g
s
.05 .5 .175 .1 k
.58279 .87907 m .58716 .87608 L .55715 .87196 L p F P
0 g
s
.05 .5 .175 .1 k
.55715 .87196 m .55497 .87348 L .58279 .87907 L p F P
0 g
s
.617 .5 .858 .1 k
.5997 .29075 m .56757 .28656 L .56984 .30236 L p F P
0 g
s
.617 .5 .858 .1 k
.56984 .30236 m .60373 .30674 L .5997 .29075 L p F P
0 g
s
.55 .5 .725 .1 k
.33525 .36045 m .30883 .37475 L .30279 .39883 L p F P
0 g
s
.55 .5 .708 .1 k
.27879 .41497 m .30279 .39883 L .30883 .37475 L p F P
0 g
s
.083 .5 .125 .1 k
.62614 .86698 m .62969 .86175 L .59624 .86596 L p F P
0 g
s
.083 .5 .125 .1 k
.59624 .86596 m .59392 .86949 L .62614 .86698 L p F P
0 g
s
.15 .5 .558 .1 k
.38916 .85066 m .38655 .84345 L .35538 .83043 L p F P
0 g
s
.117 .5 .558 .1 k
.38655 .84345 m .38916 .85066 L .42153 .85897 L p F P
0 g
s
.117 .5 .542 .1 k
.42452 .8643 m .42153 .85897 L .38916 .85066 L p F P
0 g
s
.183 .5 .575 .1 k
.35538 .83043 m .35383 .82135 L .32452 .80392 L p F P
0 g
s
.15 .5 .575 .1 k
.35383 .82135 m .35538 .83043 L .38655 .84345 L p F P
0 g
s
.217 .5 .058 .1 k
.75509 .7781 m .7539 .76557 L .72706 .7878 L p F P
0 g
s
.217 .5 .058 .1 k
.72706 .7878 m .72831 .7987 L .75509 .7781 L p F P
0 g
s
.483 .5 .675 .1 k
.23567 .50645 m .25307 .48808 L .25402 .45929 L p F P
0 g
s
.45 .5 .675 .1 k
.25307 .48808 m .23567 .50645 L .2381 .53641 L p F P
0 g
s
.05 .5 .492 .1 k
.46346 .87444 m .4675 .87755 L .49649 .87271 L p F P
0 g
s
.05 .5 .475 .1 k
.49882 .87417 m .49649 .87271 L .4675 .87755 L p F P
0 g
s
.617 .5 .808 .1 k
.502 .28532 m .4695 .28828 L .46638 .30416 L p F P
0 g
s
.617 .5 .792 .1 k
.43298 .3097 m .46638 .30416 L .4695 .28828 L p F P
0 g
s
.383 .5 .642 .1 k
.23084 .63361 m .24035 .61605 L .23063 .58537 L p F P
0 g
s
.35 .5 .642 .1 k
.24035 .61605 m .23084 .63361 L .24441 .66317 L p F P
0 g
s
.617 .5 .842 .1 k
.56757 .28656 m .53485 .28475 L .53532 .30046 L p F P
0 g
s
.617 .5 .842 .1 k
.53532 .30046 m .56984 .30236 L .56757 .28656 L p F P
0 g
s
.05 .5 .158 .1 k
.58716 .87608 m .59088 .87288 L .559 .87034 L p F P
0 g
s
.05 .5 .158 .1 k
.559 .87034 m .55715 .87196 L .58716 .87608 L p F P
0 g
s
.517 .5 .708 .1 k
.30279 .39883 m .27879 .41497 L .27496 .44178 L p F P
0 g
s
.517 .5 .692 .1 k
.25402 .45929 m .27496 .44178 L .27879 .41497 L p F P
0 g
s
.217 .5 .592 .1 k
.32452 .80392 m .32469 .79305 L .29784 .7716 L p F P
0 g
s
.183 .5 .592 .1 k
.32469 .79305 m .32452 .80392 L .35383 .82135 L p F P
0 g
s
.083 .5 .542 .1 k
.42153 .85897 m .42452 .8643 L .45742 .86767 L p F P
0 g
s
.083 .5 .525 .1 k
.46009 .87114 m .45742 .86767 L .42452 .8643 L p F P
0 g
s
.483 .5 .692 .1 k
.27496 .44178 m .25402 .45929 L .25307 .48808 L p F P
0 g
s
.583 .5 .758 .1 k
.40095 .31757 m .37072 .32764 L .36436 .34801 L p F P
0 g
s
.583 .5 .742 .1 k
.33525 .36045 m .36436 .34801 L .37072 .32764 L p F P
0 g
s
.317 .5 .025 .1 k
.81168 .67183 m .80421 .65522 L .78729 .6848 L p F P
0 g
s
.317 .5 .025 .1 k
.78729 .6848 m .79447 .70012 L .81168 .67183 L p F P
0 g
s
.617 .5 .825 .1 k
.53485 .28475 m .502 .28532 L .50066 .30106 L p F P
0 g
s
.617 .5 .808 .1 k
.46638 .30416 m .50066 .30106 L .502 .28532 L p F P
0 g
s
.617 .5 .825 .1 k
.50066 .30106 m .53532 .30046 L .53485 .28475 L p F P
0 g
s
.117 .5 .092 .1 k
.66492 .84721 m .66681 .83992 L .63345 .85082 L p F P
0 g
s
.117 .5 .092 .1 k
.63345 .85082 m .63214 .85635 L .66492 .84721 L p F P
0 g
s
.05 .5 .508 .1 k
.46009 .87114 m .46346 .87444 L .49448 .87113 L p F P
0 g
s
.05 .5 .492 .1 k
.49649 .87271 m .49448 .87113 L .46346 .87444 L p F P
0 g
s
.417 .5 .992 .1 k
.82205 .54602 m .80667 .52768 L .8009 .559 L p F P
0 g
s
.417 .5 .992 .1 k
.8009 .559 m .81602 .57664 L .82205 .54602 L p F P
0 g
s
.317 .5 .625 .1 k
.25582 .70756 m .26149 .69214 L .24441 .66317 L p F P
0 g
s
.283 .5 .625 .1 k
.26149 .69214 m .25582 .70756 L .2765 .73408 L p F P
0 g
s
.15 .5 .075 .1 k
.69823 .82608 m .69888 .81694 L .66717 .83253 L p F P
0 g
s
.15 .5 .075 .1 k
.66717 .83253 m .66681 .83992 L .69823 .82608 L p F P
0 g
s
.55 .5 .925 .1 k
.73145 .36766 m .7037 .35422 L .70868 .378 L p F P
0 g
s
.55 .5 .925 .1 k
.70868 .378 m .73717 .39163 L .73145 .36766 L p F P
0 g
s
.017 .5 .342 .1 k
.52632 .86433 m .52158 .88019 L .52534 .88033 L closepath p F P
0 g
s
.017 .5 .325 .1 k
.52632 .86433 m .52534 .88033 L .5291 .88028 L closepath p F P
0 g
s
.083 .5 .108 .1 k
.62969 .86175 m .63214 .85635 L .59781 .86232 L p F P
0 g
s
.083 .5 .108 .1 k
.59781 .86232 m .59624 .86596 L .62969 .86175 L p F P
0 g
s
.017 .5 .308 .1 k
.52632 .86433 m .5291 .88028 L .53284 .88005 L closepath p F P
0 g
s
.25 .5 .042 .1 k
.77782 .74138 m .77388 .72733 L .75015 .75306 L p F P
0 g
s
.25 .5 .042 .1 k
.75015 .75306 m .7539 .76557 L .77782 .74138 L p F P
0 g
s
.017 .5 .358 .1 k
.52632 .86433 m .51788 .87985 L .52158 .88019 L closepath p F P
0 g
s
.017 .5 .292 .1 k
.52632 .86433 m .53284 .88005 L .5365 .87962 L closepath p F P
0 g
s
.05 .5 .142 .1 k
.59088 .87288 m .59392 .86949 L .5605 .86862 L p F P
0 g
s
.05 .5 .142 .1 k
.5605 .86862 m .559 .87034 L .59088 .87288 L p F P
0 g
s
.017 .5 .375 .1 k
.52632 .86433 m .51427 .87933 L .51788 .87985 L closepath p F P
0 g
s
.017 .5 .275 .1 k
.52632 .86433 m .5365 .87962 L .54006 .87901 L closepath p F P
0 g
s
.017 .5 .392 .1 k
.52632 .86433 m .51078 .87863 L .51427 .87933 L closepath p F P
0 g
s
.583 .5 .892 .1 k
.66762 .32253 m .63648 .3135 L .64102 .33345 L p F P
0 g
s
.583 .5 .892 .1 k
.64102 .33345 m .67342 .34275 L .66762 .32253 L p F P
0 g
s
.017 .5 .258 .1 k
.52632 .86433 m .54006 .87901 L .54347 .87823 L closepath p F P
0 g
s
.25 .5 .608 .1 k
.29784 .7716 m .30035 .75906 L .2765 .73408 L p F P
0 g
s
.217 .5 .608 .1 k
.30035 .75906 m .29784 .7716 L .32469 .79305 L p F P
0 g
s
.017 .5 .408 .1 k
.52632 .86433 m .50746 .87775 L .51078 .87863 L closepath p F P
0 g
s
.417 .5 .658 .1 k
.23063 .58537 m .24401 .56739 L .2381 .53641 L p F P
0 g
s
.383 .5 .658 .1 k
.24401 .56739 m .23063 .58537 L .24035 .61605 L p F P
0 g
s
.017 .5 .242 .1 k
.52632 .86433 m .54347 .87823 L .5467 .87727 L closepath p F P
0 g
s
.05 .5 .525 .1 k
.45742 .86767 m .46009 .87114 L .49281 .86946 L p F P
0 g
s
.05 .5 .508 .1 k
.49448 .87113 m .49281 .86946 L .46009 .87114 L p F P
0 g
s
.15 .5 .575 .1 k
.38655 .84345 m .38544 .83609 L .35383 .82135 L p F P
0 g
s
.117 .5 .575 .1 k
.38544 .83609 m .38655 .84345 L .41967 .85349 L p F P
0 g
s
.117 .5 .558 .1 k
.42153 .85897 m .41967 .85349 L .38655 .84345 L p F P
0 g
s
.183 .5 .058 .1 k
.72831 .7987 m .72706 .7878 L .69763 .80775 L p F P
0 g
s
.183 .5 .058 .1 k
.69763 .80775 m .69888 .81694 L .72831 .7987 L p F P
0 g
s
.45 .5 .975 .1 k
.80905 .4975 m .7899 .47961 L .78766 .51025 L p F P
0 g
s
.45 .5 .975 .1 k
.78766 .51025 m .80667 .52768 L .80905 .4975 L p F P
0 g
s
.017 .5 .425 .1 k
.52632 .86433 m .50433 .87671 L .50746 .87775 L closepath p F P
0 g
s
.083 .5 .558 .1 k
.41967 .85349 m .42153 .85897 L .45548 .86408 L p F P
0 g
s
.083 .5 .542 .1 k
.45742 .86767 m .45548 .86408 L .42153 .85897 L p F P
0 g
s
.017 .5 .225 .1 k
.52632 .86433 m .5467 .87727 L .54972 .87615 L closepath p F P
0 g
s
.517 .5 .942 .1 k
.7627 .40702 m .73717 .39163 L .74047 .41842 L p F P
0 g
s
.517 .5 .942 .1 k
.74047 .41842 m .76637 .43382 L .7627 .40702 L p F P
0 g
s
.017 .5 .442 .1 k
.52632 .86433 m .50144 .87551 L .50433 .87671 L closepath p F P
0 g
s
.35 .5 .008 .1 k
.81766 .62512 m .80645 .60777 L .79339 .63899 L p F P
0 g
s
.35 .5 .008 .1 k
.79339 .63899 m .80421 .65522 L .81766 .62512 L p F P
0 g
s
.05 .5 .125 .1 k
.59392 .86949 m .59624 .86596 L .56163 .86684 L p F P
0 g
s
.05 .5 .125 .1 k
.56163 .86684 m .5605 .86862 L .59392 .86949 L p F P
0 g
s
.183 .5 .592 .1 k
.35383 .82135 m .35416 .81217 L .32469 .79305 L p F P
0 g
s
.15 .5 .592 .1 k
.35416 .81217 m .35383 .82135 L .38544 .83609 L p F P
0 g
s
.483 .5 .958 .1 k
.78898 .45071 m .76637 .43382 L .76722 .46293 L p F P
0 g
s
.483 .5 .958 .1 k
.76722 .46293 m .7899 .47961 L .78898 .45071 L p F P
0 g
s
.017 .5 .208 .1 k
.52632 .86433 m .54972 .87615 L .55249 .87489 L closepath p F P
0 g
s
.583 .5 .775 .1 k
.43298 .3097 m .40095 .31757 L .39579 .33764 L p F P
0 g
s
.583 .5 .758 .1 k
.36436 .34801 m .39579 .33764 L .40095 .31757 L p F P
0 g
s
.017 .5 .458 .1 k
.52632 .86433 m .49882 .87417 L .50144 .87551 L closepath p F P
0 g
s
.55 .5 .742 .1 k
.36436 .34801 m .33525 .36045 L .3299 .38432 L p F P
0 g
s
.55 .5 .725 .1 k
.30279 .39883 m .3299 .38432 L .33525 .36045 L p F P
0 g
s
.083 .5 .092 .1 k
.63214 .85635 m .63345 .85082 L .5986 .85861 L p F P
0 g
s
.083 .5 .092 .1 k
.5986 .85861 m .59781 .86232 L .63214 .85635 L p F P
0 g
s
.35 .5 .642 .1 k
.24441 .66317 m .25362 .64673 L .24035 .61605 L p F P
0 g
s
.317 .5 .642 .1 k
.25362 .64673 m .24441 .66317 L .26149 .69214 L p F P
0 g
s
.017 .5 .192 .1 k
.52632 .86433 m .55249 .87489 L .55497 .87348 L closepath p F P
0 g
s
.05 .5 .542 .1 k
.45548 .86408 m .45742 .86767 L .4915 .8677 L p F P
0 g
s
.05 .5 .525 .1 k
.49281 .86946 m .4915 .8677 L .45742 .86767 L p F P
0 g
s
.117 .5 .075 .1 k
.66681 .83992 m .66717 .83253 L .63359 .84524 L p F P
0 g
s
.117 .5 .075 .1 k
.63359 .84524 m .63345 .85082 L .66681 .83992 L p F P
0 g
s
.283 .5 .025 .1 k
.79447 .70012 m .78729 .6848 L .76707 .71345 L p F P
0 g
s
.283 .5 .025 .1 k
.76707 .71345 m .77388 .72733 L .79447 .70012 L p F P
0 g
s
.017 .5 .475 .1 k
.52632 .86433 m .49649 .87271 L .49882 .87417 L closepath p F P
0 g
s
.45 .5 .675 .1 k
.2381 .53641 m .25538 .51851 L .25307 .48808 L p F P
0 g
s
.417 .5 .675 .1 k
.25538 .51851 m .2381 .53641 L .24401 .56739 L p F P
0 g
s
.283 .5 .625 .1 k
.2765 .73408 m .28193 .72009 L .26149 .69214 L p F P
0 g
s
.25 .5 .625 .1 k
.28193 .72009 m .2765 .73408 L .30035 .75906 L p F P
0 g
s
.017 .5 .175 .1 k
.52632 .86433 m .55497 .87348 L .55715 .87196 L closepath p F P
0 g
s
.217 .5 .042 .1 k
.7539 .76557 m .75015 .75306 L .72355 .77695 L p F P
0 g
s
.217 .5 .042 .1 k
.72355 .77695 m .72706 .7878 L .7539 .76557 L p F P
0 g
s
.05 .5 .108 .1 k
.59624 .86596 m .59781 .86232 L .56237 .865 L p F P
0 g
s
.05 .5 .108 .1 k
.56237 .865 m .56163 .86684 L .59624 .86596 L p F P
0 g
s
.017 .5 .492 .1 k
.52632 .86433 m .49448 .87113 L .49649 .87271 L closepath p F P
0 g
s
.583 .5 .875 .1 k
.63648 .3135 m .60373 .30674 L .60693 .32647 L p F P
0 g
s
.583 .5 .875 .1 k
.60693 .32647 m .64102 .33345 L .63648 .3135 L p F P
0 g
s
.217 .5 .608 .1 k
.32469 .79305 m .32711 .78215 L .30035 .75906 L p F P
0 g
s
.183 .5 .608 .1 k
.32711 .78215 m .32469 .79305 L .35416 .81217 L p F P
0 g
s
.117 .5 .575 .1 k
.41967 .85349 m .41896 .84793 L .38544 .83609 L p F P
0 g
s
.083 .5 .575 .1 k
.41896 .84793 m .41967 .85349 L .45432 .8604 L p F P
0 g
s
.083 .5 .558 .1 k
.45548 .86408 m .45432 .8604 L .41967 .85349 L p F P
0 g
s
.15 .5 .058 .1 k
.69888 .81694 m .69763 .80775 L .66598 .82513 L p F P
0 g
s
.15 .5 .058 .1 k
.66598 .82513 m .66717 .83253 L .69888 .81694 L p F P
0 g
s
.017 .5 .158 .1 k
.52632 .86433 m .55715 .87196 L .559 .87034 L closepath p F P
0 g
s
.017 .5 .508 .1 k
.52632 .86433 m .49281 .86946 L .49448 .87113 L closepath p F P
0 g
s
.05 .5 .558 .1 k
.45432 .8604 m .45548 .86408 L .49057 .86589 L p F P
0 g
s
.05 .5 .542 .1 k
.4915 .8677 m .49057 .86589 L .45548 .86408 L p F P
0 g
s
.383 .5 .992 .1 k
.81602 .57664 m .8009 .559 L .79173 .59104 L p F P
0 g
s
.383 .5 .992 .1 k
.79173 .59104 m .80645 .60777 L .81602 .57664 L p F P
0 g
s
.517 .5 .725 .1 k
.3299 .38432 m .30279 .39883 L .29931 .42562 L p F P
0 g
s
.517 .5 .708 .1 k
.27496 .44178 m .29931 .42562 L .30279 .39883 L p F P
0 g
s
.15 .5 .592 .1 k
.38544 .83609 m .38588 .82868 L .35416 .81217 L p F P
0 g
s
.117 .5 .592 .1 k
.38588 .82868 m .38544 .83609 L .41896 .84793 L p F P
0 g
s
.55 .5 .908 .1 k
.7037 .35422 m .67342 .34275 L .67758 .36635 L p F P
0 g
s
.55 .5 .908 .1 k
.67758 .36635 m .70868 .378 L .7037 .35422 L p F P
0 g
s
.483 .5 .692 .1 k
.25307 .48808 m .27408 .47079 L .27496 .44178 L p F P
0 g
s
.45 .5 .692 .1 k
.27408 .47079 m .25307 .48808 L .25538 .51851 L p F P
0 g
s
.017 .5 .142 .1 k
.52632 .86433 m .559 .87034 L .5605 .86862 L closepath p F P
0 g
s
.583 .5 .792 .1 k
.46638 .30416 m .43298 .3097 L .42913 .32953 L p F P
0 g
s
.583 .5 .775 .1 k
.39579 .33764 m .42913 .32953 L .43298 .3097 L p F P
0 g
s
.083 .5 .075 .1 k
.63345 .85082 m .63359 .84524 L .5986 .85487 L p F P
0 g
s
.083 .5 .075 .1 k
.5986 .85487 m .5986 .85861 L .63345 .85082 L p F P
0 g
s
.017 .5 .525 .1 k
.52632 .86433 m .4915 .8677 L .49281 .86946 L closepath p F P
0 g
s
.483 .5 .708 .1 k
.29931 .42562 m .27496 .44178 L .27408 .47079 L p F P
0 g
s
.05 .5 .092 .1 k
.59781 .86232 m .5986 .85861 L .56272 .86314 L p F P
0 g
s
.05 .5 .092 .1 k
.56272 .86314 m .56237 .865 L .59781 .86232 L p F P
0 g
s
.383 .5 .658 .1 k
.24035 .61605 m .25339 .59899 L .24401 .56739 L p F P
0 g
s
.35 .5 .658 .1 k
.25339 .59899 m .24035 .61605 L .25362 .64673 L p F P
0 g
s
.017 .5 .125 .1 k
.52632 .86433 m .5605 .86862 L .56163 .86684 L closepath p F P
0 g
s
.317 .5 .008 .1 k
.80421 .65522 m .79339 .63899 L .77697 .66985 L p F P
0 g
s
.317 .5 .008 .1 k
.77697 .66985 m .78729 .6848 L .80421 .65522 L p F P
0 g
s
.583 .5 .858 .1 k
.60373 .30674 m .56984 .30236 L .57165 .32196 L p F P
0 g
s
.583 .5 .858 .1 k
.57165 .32196 m .60693 .32647 L .60373 .30674 L p F P
0 g
s
.017 .5 .542 .1 k
.52632 .86433 m .49057 .86589 L .4915 .8677 L closepath p F P
0 g
s
.183 .5 .042 .1 k
.72706 .7878 m .72355 .77695 L .69445 .79863 L p F P
0 g
s
.183 .5 .042 .1 k
.69445 .79863 m .69763 .80775 L .72706 .7878 L p F P
0 g
s
.183 .5 .608 .1 k
.35416 .81217 m .35641 .803 L .32711 .78215 L p F P
0 g
s
.15 .5 .608 .1 k
.35641 .803 m .35416 .81217 L .38588 .82868 L p F P
0 g
s
.083 .5 .575 .1 k
.45432 .8604 m .45393 .85667 L .41896 .84793 L p F P
0 g
s
.05 .5 .575 .1 k
.45393 .85667 m .45432 .8604 L .49003 .86404 L p F P
0 g
s
.05 .5 .558 .1 k
.49057 .86589 m .49003 .86404 L .45432 .8604 L p F P
0 g
s
.25 .5 .025 .1 k
.77388 .72733 m .76707 .71345 L .74379 .74074 L p F P
0 g
s
.25 .5 .025 .1 k
.74379 .74074 m .75015 .75306 L .77388 .72733 L p F P
0 g
s
.117 .5 .058 .1 k
.66717 .83253 m .66598 .82513 L .63256 .83966 L p F P
0 g
s
.117 .5 .058 .1 k
.63256 .83966 m .63359 .84524 L .66717 .83253 L p F P
0 g
s
.25 .5 .625 .1 k
.30035 .75906 m .30546 .74664 L .28193 .72009 L p F P
0 g
s
.217 .5 .625 .1 k
.30546 .74664 m .30035 .75906 L .32711 .78215 L p F P
0 g
s
.317 .5 .642 .1 k
.26149 .69214 m .27031 .67699 L .25362 .64673 L p F P
0 g
s
.283 .5 .642 .1 k
.27031 .67699 m .26149 .69214 L .28193 .72009 L p F P
0 g
s
.017 .5 .108 .1 k
.52632 .86433 m .56163 .86684 L .56237 .865 L closepath p F P
0 g
s
.117 .5 .592 .1 k
.41896 .84793 m .41943 .84234 L .38588 .82868 L p F P
0 g
s
.083 .5 .592 .1 k
.41943 .84234 m .41896 .84793 L .45393 .85667 L p F P
0 g
s
.417 .5 .975 .1 k
.80667 .52768 m .78766 .51025 L .78223 .54224 L p F P
0 g
s
.417 .5 .975 .1 k
.78223 .54224 m .8009 .559 L .80667 .52768 L p F P
0 g
s
.55 .5 .758 .1 k
.39579 .33764 m .36436 .34801 L .35979 .37169 L p F P
0 g
s
.55 .5 .742 .1 k
.3299 .38432 m .35979 .37169 L .36436 .34801 L p F P
0 g
s
.583 .5 .808 .1 k
.50066 .30106 m .46638 .30416 L .4639 .32382 L p F P
0 g
s
.583 .5 .792 .1 k
.42913 .32953 m .4639 .32382 L .46638 .30416 L p F P
0 g
s
.017 .5 .558 .1 k
.52632 .86433 m .49003 .86404 L .49057 .86589 L closepath p F P
0 g
s
.05 .5 .075 .1 k
.5986 .85861 m .5986 .85487 L .56268 .86126 L p F P
0 g
s
.05 .5 .075 .1 k
.56268 .86126 m .56272 .86314 L .5986 .85861 L p F P
0 g
s
.517 .5 .925 .1 k
.73717 .39163 m .70868 .378 L .71156 .40477 L p F P
0 g
s
.517 .5 .925 .1 k
.71156 .40477 m .74047 .41842 L .73717 .39163 L p F P
0 g
s
.017 .5 .092 .1 k
.52632 .86433 m .56237 .865 L .56272 .86314 L closepath p F P
0 g
s
.583 .5 .842 .1 k
.56984 .30236 m .53532 .30046 L .53569 .32 L p F P
0 g
s
.583 .5 .842 .1 k
.53569 .32 m .57165 .32196 L .56984 .30236 L p F P
0 g
s
.05 .5 .575 .1 k
.49003 .86404 m .48988 .86216 L .45393 .85667 L p F P
0 g
s
.017 .5 .575 .1 k
.52632 .86433 m .48988 .86216 L .49003 .86404 L closepath p F P
0 g
s
.083 .5 .058 .1 k
.63359 .84524 m .63256 .83966 L .59781 .85113 L p F P
0 g
s
.083 .5 .058 .1 k
.59781 .85113 m .5986 .85487 L .63359 .84524 L p F P
0 g
s
.45 .5 .958 .1 k
.7899 .47961 m .76722 .46293 L .76516 .494 L p F P
0 g
s
.45 .5 .958 .1 k
.76516 .494 m .78766 .51025 L .7899 .47961 L p F P
0 g
s
.583 .5 .825 .1 k
.53532 .30046 m .50066 .30106 L .49959 .32062 L p F P
0 g
s
.583 .5 .808 .1 k
.4639 .32382 m .49959 .32062 L .50066 .30106 L p F P
0 g
s
.083 .5 .592 .1 k
.45393 .85667 m .45434 .85292 L .41943 .84234 L p F P
0 g
s
.05 .5 .592 .1 k
.45434 .85292 m .45393 .85667 L .48988 .86216 L p F P
0 g
s
.15 .5 .608 .1 k
.38588 .82868 m .38788 .8213 L .35641 .803 L p F P
0 g
s
.117 .5 .608 .1 k
.38788 .8213 m .38588 .82868 L .41943 .84234 L p F P
0 g
s
.417 .5 .675 .1 k
.24401 .56739 m .26099 .55018 L .25538 .51851 L p F P
0 g
s
.383 .5 .675 .1 k
.26099 .55018 m .24401 .56739 L .25339 .59899 L p F P
0 g
s
.583 .5 .825 .1 k
.49959 .32062 m .53569 .32 L .53532 .30046 L p F P
0 g
s
.483 .5 .942 .1 k
.76637 .43382 m .74047 .41842 L .74123 .44773 L p F P
0 g
s
.483 .5 .942 .1 k
.74123 .44773 m .76722 .46293 L .76637 .43382 L p F P
0 g
s
.15 .5 .042 .1 k
.69763 .80775 m .69445 .79863 L .66323 .81778 L p F P
0 g
s
.15 .5 .042 .1 k
.66323 .81778 m .66598 .82513 L .69763 .80775 L p F P
0 g
s
.017 .5 .075 .1 k
.52632 .86433 m .56272 .86314 L .56268 .86126 L closepath p F P
0 g
s
.55 .5 .892 .1 k
.67342 .34275 m .64102 .33345 L .64428 .3569 L p F P
0 g
s
.55 .5 .892 .1 k
.64428 .3569 m .67758 .36635 L .67342 .34275 L p F P
0 g
s
.217 .5 .625 .1 k
.32711 .78215 m .3318 .77138 L .30546 .74664 L p F P
0 g
s
.183 .5 .625 .1 k
.3318 .77138 m .32711 .78215 L .35641 .803 L p F P
0 g
s
.05 .5 .592 .1 k
.48988 .86216 m .49014 .86029 L .45434 .85292 L p F P
0 g
s
.017 .5 .592 .1 k
.52632 .86433 m .49014 .86029 L .48988 .86216 L closepath p F P
0 g
s
.017 .5 .992 .1 k
.52632 .86433 m .55855 .85406 L .55658 .85244 L closepath p F P
0 g
s
.017 .5 .975 .1 k
.52632 .86433 m .55658 .85244 L .55428 .85093 L closepath p F P
0 g
s
.017 .5 .958 .1 k
.52632 .86433 m .55428 .85093 L .55166 .84954 L closepath p F P
0 g
s
.017 .5 .942 .1 k
.52632 .86433 m .55166 .84954 L .54875 .8483 L closepath p F P
0 g
s
.017 .5 .925 .1 k
.52632 .86433 m .54875 .8483 L .5456 .84721 L closepath p F P
0 g
s
.017 .5 .908 .1 k
.52632 .86433 m .5456 .84721 L .54222 .84629 L closepath p F P
0 g
s
.017 .5 .892 .1 k
.52632 .86433 m .54222 .84629 L .53866 .84556 L closepath p F P
0 g
s
.017 .5 .875 .1 k
.52632 .86433 m .53866 .84556 L .53496 .84501 L closepath p F P
0 g
s
.017 .5 .858 .1 k
.52632 .86433 m .53496 .84501 L .53117 .84466 L closepath p F P
0 g
s
.017 .5 .842 .1 k
.52632 .86433 m .53117 .84466 L .52732 .8445 L closepath p F P
0 g
s
.017 .5 .825 .1 k
.52632 .86433 m .52732 .8445 L .52346 .84455 L closepath p F P
0 g
s
.017 .5 .808 .1 k
.52632 .86433 m .52346 .84455 L .51963 .8448 L closepath p F P
0 g
s
.017 .5 .792 .1 k
.52632 .86433 m .51963 .8448 L .51587 .84525 L closepath p F P
0 g
s
.017 .5 .775 .1 k
.52632 .86433 m .51587 .84525 L .51224 .84589 L closepath p F P
0 g
s
.017 .5 .758 .1 k
.52632 .86433 m .51224 .84589 L .50876 .84671 L closepath p F P
0 g
s
.017 .5 .742 .1 k
.52632 .86433 m .50876 .84671 L .50549 .84771 L closepath p F P
0 g
s
.017 .5 .725 .1 k
.52632 .86433 m .50549 .84771 L .50245 .84888 L closepath p F P
0 g
s
.017 .5 .708 .1 k
.52632 .86433 m .50245 .84888 L .49968 .85019 L closepath p F P
0 g
s
.017 .5 .692 .1 k
.52632 .86433 m .49968 .85019 L .4972 .85164 L closepath p F P
0 g
s
.017 .5 .675 .1 k
.52632 .86433 m .4972 .85164 L .49506 .85321 L closepath p F P
0 g
s
.017 .5 .658 .1 k
.52632 .86433 m .49506 .85321 L .49326 .85488 L closepath p F P
0 g
s
.017 .5 .642 .1 k
.52632 .86433 m .49326 .85488 L .49184 .85662 L closepath p F P
0 g
s
.017 .5 .625 .1 k
.52632 .86433 m .49184 .85662 L .49079 .85844 L closepath p F P
0 g
s
.017 .5 .608 .1 k
.52632 .86433 m .49079 .85844 L .49014 .86029 L closepath p F P
0 g
s
.017 .5 .058 .1 k
.52632 .86433 m .56268 .86126 L .56223 .85939 L closepath p F P
0 g
s
.017 .5 .042 .1 k
.52632 .86433 m .56223 .85939 L .56139 .85756 L closepath p F P
0 g
s
.017 .5 .025 .1 k
.52632 .86433 m .56139 .85756 L .56016 .85577 L closepath p F P
0 g
s
.017 .5 .008 .1 k
.52632 .86433 m .56016 .85577 L .55855 .85406 L closepath p F P
0 g
s
.05 .5 .058 .1 k
.5986 .85487 m .59781 .85113 L .56223 .85939 L p F P
0 g
s
.05 .5 .058 .1 k
.56223 .85939 m .56268 .86126 L .5986 .85487 L p F P
0 g
s
.35 .5 .992 .1 k
.80645 .60777 m .79173 .59104 L .77924 .62334 L p F P
0 g
s
.35 .5 .992 .1 k
.77924 .62334 m .79339 .63899 L .80645 .60777 L p F P
0 g
s
.217 .5 .025 .1 k
.75015 .75306 m .74379 .74074 L .71777 .76627 L p F P
0 g
s
.217 .5 .025 .1 k
.71777 .76627 m .72355 .77695 L .75015 .75306 L p F P
0 g
s
.117 .5 .608 .1 k
.41943 .84234 m .42108 .83678 L .38788 .8213 L p F P
0 g
s
.083 .5 .608 .1 k
.42108 .83678 m .41943 .84234 L .45434 .85292 L p F P
0 g
s
.283 .5 .642 .1 k
.28193 .72009 m .29024 .70637 L .27031 .67699 L p F P
0 g
s
.25 .5 .642 .1 k
.29024 .70637 m .28193 .72009 L .30546 .74664 L p F P
0 g
s
.283 .5 .008 .1 k
.78729 .6848 m .77697 .66985 L .75737 .69992 L p F P
0 g
s
.283 .5 .008 .1 k
.75737 .69992 m .76707 .71345 L .78729 .6848 L p F P
0 g
s
.35 .5 .658 .1 k
.25362 .64673 m .26618 .63078 L .25339 .59899 L p F P
0 g
s
.317 .5 .658 .1 k
.26618 .63078 m .25362 .64673 L .27031 .67699 L p F P
0 g
s
.05 .5 .608 .1 k
.45555 .84921 m .45434 .85292 L .49014 .86029 L p F P
0 g
s
.05 .5 .608 .1 k
.49014 .86029 m .49079 .85844 L .45555 .84921 L p F P
0 g
s
.117 .5 .042 .1 k
.66598 .82513 m .66323 .81778 L .63033 .83414 L p F P
0 g
s
.117 .5 .042 .1 k
.63033 .83414 m .63256 .83966 L .66598 .82513 L p F P
0 g
s
.517 .5 .742 .1 k
.35979 .37169 m .3299 .38432 L .32681 .4111 L p F P
0 g
s
.517 .5 .725 .1 k
.29931 .42562 m .32681 .4111 L .3299 .38432 L p F P
0 g
s
.083 .5 .608 .1 k
.45434 .85292 m .45555 .84921 L .42108 .83678 L p F P
0 g
s
.05 .5 .042 .1 k
.56139 .85756 m .56223 .85939 L .59781 .85113 L p F P
0 g
s
.45 .5 .692 .1 k
.25538 .51851 m .27623 .50166 L .27408 .47079 L p F P
0 g
s
.417 .5 .692 .1 k
.27623 .50166 m .25538 .51851 L .26099 .55018 L p F P
0 g
s
.55 .5 .775 .1 k
.42913 .32953 m .39579 .33764 L .39209 .36116 L p F P
0 g
s
.55 .5 .758 .1 k
.35979 .37169 m .39209 .36116 L .39579 .33764 L p F P
0 g
s
.183 .5 .625 .1 k
.35641 .803 m .36059 .79395 L .3318 .77138 L p F P
0 g
s
.15 .5 .625 .1 k
.36059 .79395 m .35641 .803 L .38788 .8213 L p F P
0 g
s
.083 .5 .042 .1 k
.63256 .83966 m .63033 .83414 L .59622 .84745 L p F P
0 g
s
.083 .5 .042 .1 k
.59622 .84745 m .59781 .85113 L .63256 .83966 L p F P
0 g
s
.05 .5 .625 .1 k
.45754 .84558 m .45555 .84921 L .49079 .85844 L p F P
0 g
s
.05 .5 .625 .1 k
.49079 .85844 m .49184 .85662 L .45754 .84558 L p F P
0 g
s
.05 .5 .042 .1 k
.59781 .85113 m .59622 .84745 L .56139 .85756 L p F P
0 g
s
.05 .5 .025 .1 k
.56016 .85577 m .56139 .85756 L .59622 .84745 L p F P
0 g
s
.183 .5 .025 .1 k
.72355 .77695 m .71777 .76627 L .68934 .78967 L p F P
0 g
s
.183 .5 .025 .1 k
.68934 .78967 m .69445 .79863 L .72355 .77695 L p F P
0 g
s
.483 .5 .725 .1 k
.32681 .4111 m .29931 .42562 L .2985 .45484 L p F P
0 g
s
.483 .5 .708 .1 k
.27408 .47079 m .2985 .45484 L .29931 .42562 L p F P
0 g
s
.45 .5 .708 .1 k
.2985 .45484 m .27408 .47079 L .27623 .50166 L p F P
0 g
s
.05 .5 .642 .1 k
.4603 .84206 m .45754 .84558 L .49184 .85662 L p F P
0 g
s
.05 .5 .642 .1 k
.49184 .85662 m .49326 .85488 L .4603 .84206 L p F P
0 g
s
.383 .5 .975 .1 k
.8009 .559 m .78223 .54224 L .7736 .57515 L p F P
0 g
s
.383 .5 .975 .1 k
.7736 .57515 m .79173 .59104 L .8009 .559 L p F P
0 g
s
.15 .5 .625 .1 k
.38788 .8213 m .39145 .81403 L .36059 .79395 L p F P
0 g
s
.117 .5 .625 .1 k
.39145 .81403 m .38788 .8213 L .42108 .83678 L p F P
0 g
s
.083 .5 .625 .1 k
.42392 .83132 m .42108 .83678 L .45555 .84921 L p F P
0 g
s
.083 .5 .625 .1 k
.45555 .84921 m .45754 .84558 L .42392 .83132 L p F P
0 g
s
.25 .5 .642 .1 k
.30546 .74664 m .31316 .73446 L .29024 .70637 L p F P
0 g
s
.217 .5 .642 .1 k
.31316 .73446 m .30546 .74664 L .3318 .77138 L p F P
0 g
s
.05 .5 .025 .1 k
.59622 .84745 m .59386 .84387 L .56016 .85577 L p F P
0 g
s
.05 .5 .008 .1 k
.55855 .85406 m .56016 .85577 L .59386 .84387 L p F P
0 g
s
.117 .5 .625 .1 k
.42108 .83678 m .42392 .83132 L .39145 .81403 L p F P
0 g
s
.55 .5 .875 .1 k
.64102 .33345 m .60693 .32647 L .60923 .34982 L p F P
0 g
s
.55 .5 .875 .1 k
.60923 .34982 m .64428 .3569 L .64102 .33345 L p F P
0 g
s
.517 .5 .908 .1 k
.70868 .378 m .67758 .36635 L .67998 .39311 L p F P
0 g
s
.517 .5 .908 .1 k
.67998 .39311 m .71156 .40477 L .70868 .378 L p F P
0 g
s
.05 .5 .658 .1 k
.46382 .83869 m .4603 .84206 L .49326 .85488 L p F P
0 g
s
.05 .5 .658 .1 k
.49326 .85488 m .49506 .85321 L .46382 .83869 L p F P
0 g
s
.25 .5 .008 .1 k
.76707 .71345 m .75737 .69992 L .73486 .72874 L p F P
0 g
s
.25 .5 .008 .1 k
.73486 .72874 m .74379 .74074 L .76707 .71345 L p F P
0 g
s
.083 .5 .025 .1 k
.59386 .84387 m .59622 .84745 L .63033 .83414 L p F P
0 g
s
.15 .5 .025 .1 k
.69445 .79863 m .68934 .78967 L .65892 .8106 L p F P
0 g
s
.15 .5 .025 .1 k
.65892 .8106 m .66323 .81778 L .69445 .79863 L p F P
0 g
s
.383 .5 .675 .1 k
.25339 .59899 m .26989 .58267 L .26099 .55018 L p F P
0 g
s
.35 .5 .675 .1 k
.26989 .58267 m .25339 .59899 L .26618 .63078 L p F P
0 g
s
.05 .5 .992 .1 k
.55658 .85244 m .55855 .85406 L .59073 .84042 L p F P
0 g
s
.05 .5 .008 .1 k
.59386 .84387 m .59073 .84042 L .55855 .85406 L p F P
0 g
s
.317 .5 .992 .1 k
.79339 .63899 m .77924 .62334 L .76355 .65546 L p F P
0 g
s
.317 .5 .992 .1 k
.76355 .65546 m .77697 .66985 L .79339 .63899 L p F P
0 g
s
.317 .5 .658 .1 k
.27031 .67699 m .28225 .6623 L .26618 .63078 L p F P
0 g
s
.283 .5 .658 .1 k
.28225 .6623 m .27031 .67699 L .29024 .70637 L p F P
0 g
s
.05 .5 .675 .1 k
.46804 .83552 m .46382 .83869 L .49506 .85321 L p F P
0 g
s
.05 .5 .675 .1 k
.49506 .85321 m .4972 .85164 L .46804 .83552 L p F P
0 g
s
.117 .5 .025 .1 k
.62694 .82874 m .63033 .83414 L .66323 .81778 L p F P
0 g
s
.083 .5 .025 .1 k
.63033 .83414 m .62694 .82874 L .59386 .84387 L p F P
0 g
s
.117 .5 .025 .1 k
.66323 .81778 m .65892 .8106 L .62694 .82874 L p F P
0 g
s
.55 .5 .792 .1 k
.4639 .32382 m .42913 .32953 L .42636 .35292 L p F P
0 g
s
.55 .5 .775 .1 k
.39209 .36116 m .42636 .35292 L .42913 .32953 L p F P
0 g
s
.083 .5 .642 .1 k
.42791 .82602 m .42392 .83132 L .45754 .84558 L p F P
0 g
s
.083 .5 .642 .1 k
.45754 .84558 m .4603 .84206 L .42791 .82602 L p F P
0 g
s
.417 .5 .958 .1 k
.78766 .51025 m .76516 .494 L .76015 .52663 L p F P
0 g
s
.417 .5 .958 .1 k
.76015 .52663 m .78223 .54224 L .78766 .51025 L p F P
0 g
s
.05 .5 .992 .1 k
.59073 .84042 m .58687 .83714 L .55658 .85244 L p F P
0 g
s
.05 .5 .975 .1 k
.55428 .85093 m .55658 .85244 L .58687 .83714 L p F P
0 g
s
.217 .5 .642 .1 k
.3318 .77138 m .33876 .76084 L .31316 .73446 L p F P
0 g
s
.183 .5 .642 .1 k
.33876 .76084 m .3318 .77138 L .36059 .79395 L p F P
0 g
s
.05 .5 .692 .1 k
.47293 .83258 m .46804 .83552 L .4972 .85164 L p F P
0 g
s
.05 .5 .692 .1 k
.4972 .85164 m .49968 .85019 L .47293 .83258 L p F P
0 g
s
.483 .5 .925 .1 k
.74047 .41842 m .71156 .40477 L .71222 .43425 L p F P
0 g
s
.483 .5 .925 .1 k
.71222 .43425 m .74123 .44773 L .74047 .41842 L p F P
0 g
s
.083 .5 .008 .1 k
.59073 .84042 m .59386 .84387 L .62694 .82874 L p F P
0 g
s
.05 .5 .975 .1 k
.58687 .83714 m .58232 .83408 L .55428 .85093 L p F P
0 g
s
.05 .5 .958 .1 k
.55166 .84954 m .55428 .85093 L .58232 .83408 L p F P
0 g
s
.45 .5 .942 .1 k
.76722 .46293 m .74123 .44773 L .73938 .47919 L p F P
0 g
s
.45 .5 .942 .1 k
.73938 .47919 m .76516 .494 L .76722 .46293 L p F P
0 g
s
.517 .5 .758 .1 k
.39209 .36116 m .35979 .37169 L .35716 .39846 L p F P
0 g
s
.517 .5 .742 .1 k
.32681 .4111 m .35716 .39846 L .35979 .37169 L p F P
0 g
s
.55 .5 .858 .1 k
.60693 .32647 m .57165 .32196 L .57295 .34523 L p F P
0 g
s
.55 .5 .858 .1 k
.57295 .34523 m .60923 .34982 L .60693 .32647 L p F P
0 g
s
.217 .5 .008 .1 k
.74379 .74074 m .73486 .72874 L .70973 .7559 L p F P
0 g
s
.217 .5 .008 .1 k
.70973 .7559 m .71777 .76627 L .74379 .74074 L p F P
0 g
s
.117 .5 .642 .1 k
.39655 .80695 m .39145 .81403 L .42392 .83132 L p F P
0 g
s
.117 .5 .642 .1 k
.42392 .83132 m .42791 .82602 L .39655 .80695 L p F P
0 g
s
.05 .5 .708 .1 k
.47844 .82992 m .47293 .83258 L .49968 .85019 L p F P
0 g
s
.05 .5 .708 .1 k
.49968 .85019 m .50245 .84888 L .47844 .82992 L p F P
0 g
s
.183 .5 .642 .1 k
.36059 .79395 m .36669 .78512 L .33876 .76084 L p F P
0 g
s
.15 .5 .642 .1 k
.36669 .78512 m .36059 .79395 L .39145 .81403 L p F P
0 g
s
.05 .5 .958 .1 k
.58232 .83408 m .57712 .83126 L .55166 .84954 L p F P
0 g
s
.05 .5 .942 .1 k
.54875 .8483 m .55166 .84954 L .57712 .83126 L p F P
0 g
s
.15 .5 .642 .1 k
.39145 .81403 m .39655 .80695 L .36669 .78512 L p F P
0 g
s
.417 .5 .692 .1 k
.26099 .55018 m .28145 .53398 L .27623 .50166 L p F P
0 g
s
.383 .5 .692 .1 k
.28145 .53398 m .26099 .55018 L .26989 .58267 L p F P
0 g
s
.083 .5 .658 .1 k
.43304 .82094 m .42791 .82602 L .4603 .84206 L p F P
0 g
s
.083 .5 .658 .1 k
.4603 .84206 m .46382 .83869 L .43304 .82094 L p F P
0 g
s
.05 .5 .725 .1 k
.4845 .82755 m .47844 .82992 L .50245 .84888 L p F P
0 g
s
.05 .5 .725 .1 k
.50245 .84888 m .50549 .84771 L .4845 .82755 L p F P
0 g
s
.55 .5 .808 .1 k
.49959 .32062 m .4639 .32382 L .46211 .34712 L p F P
0 g
s
.55 .5 .792 .1 k
.42636 .35292 m .46211 .34712 L .4639 .32382 L p F P
0 g
s
.283 .5 .658 .1 k
.29024 .70637 m .30141 .69309 L .28225 .6623 L p F P
0 g
s
.25 .5 .658 .1 k
.30141 .69309 m .29024 .70637 L .31316 .73446 L p F P
0 g
s
.05 .5 .942 .1 k
.57712 .83126 m .57134 .82874 L .54875 .8483 L p F P
0 g
s
.05 .5 .925 .1 k
.5456 .84721 m .54875 .8483 L .57134 .82874 L p F P
0 g
s
.35 .5 .975 .1 k
.79173 .59104 m .7736 .57515 L .76185 .60851 L p F P
0 g
s
.35 .5 .975 .1 k
.76185 .60851 m .77924 .62334 L .79173 .59104 L p F P
0 g
s
.117 .5 .008 .1 k
.62239 .82354 m .62694 .82874 L .65892 .8106 L p F P
0 g
s
.083 .5 .008 .1 k
.62694 .82874 m .62239 .82354 L .59073 .84042 L p F P
0 g
s
.05 .5 .742 .1 k
.49106 .82551 m .4845 .82755 L .50549 .84771 L p F P
0 g
s
.05 .5 .742 .1 k
.50549 .84771 m .50876 .84671 L .49106 .82551 L p F P
0 g
s
.083 .5 .992 .1 k
.58687 .83714 m .59073 .84042 L .62239 .82354 L p F P
0 g
s
.283 .5 .992 .1 k
.77697 .66985 m .76355 .65546 L .74485 .68691 L p F P
0 g
s
.283 .5 .992 .1 k
.74485 .68691 m .75737 .69992 L .77697 .66985 L p F P
0 g
s
.183 .5 .008 .1 k
.71777 .76627 m .70973 .7559 L .68233 .78099 L p F P
0 g
s
.183 .5 .008 .1 k
.68233 .78099 m .68934 .78967 L .71777 .76627 L p F P
0 g
s
.55 .5 .842 .1 k
.57165 .32196 m .53569 .32 L .53596 .34324 L p F P
0 g
s
.55 .5 .842 .1 k
.53596 .34324 m .57295 .34523 L .57165 .32196 L p F P
0 g
s
.05 .5 .925 .1 k
.57134 .82874 m .56503 .82652 L .5456 .84721 L p F P
0 g
s
.05 .5 .908 .1 k
.54222 .84629 m .5456 .84721 L .56503 .82652 L p F P
0 g
s
.35 .5 .675 .1 k
.26618 .63078 m .28202 .61553 L .26989 .58267 L p F P
0 g
s
.317 .5 .675 .1 k
.28202 .61553 m .26618 .63078 L .28225 .6623 L p F P
0 g
s
.517 .5 .892 .1 k
.67758 .36635 m .64428 .3569 L .64616 .38364 L p F P
0 g
s
.517 .5 .892 .1 k
.64616 .38364 m .67998 .39311 L .67758 .36635 L p F P
0 g
s
.05 .5 .758 .1 k
.49802 .82383 m .49106 .82551 L .50876 .84671 L p F P
0 g
s
.05 .5 .758 .1 k
.50876 .84671 m .51224 .84589 L .49802 .82383 L p F P
0 g
s
.55 .5 .825 .1 k
.53569 .32 m .49959 .32062 L .49883 .34387 L p F P
0 g
s
.55 .5 .808 .1 k
.46211 .34712 m .49883 .34387 L .49959 .32062 L p F P
0 g
s
.05 .5 .908 .1 k
.56503 .82652 m .55827 .82465 L .54222 .84629 L p F P
0 g
s
.05 .5 .892 .1 k
.53866 .84556 m .54222 .84629 L .55827 .82465 L p F P
0 g
s
.15 .5 .008 .1 k
.65308 .80364 m .65892 .8106 L .68934 .78967 L p F P
0 g
s
.117 .5 .008 .1 k
.65892 .8106 m .65308 .80364 L .62239 .82354 L p F P
0 g
s
.483 .5 .742 .1 k
.35716 .39846 m .32681 .4111 L .3261 .4405 L p F P
0 g
s
.483 .5 .725 .1 k
.2985 .45484 m .3261 .4405 L .32681 .4111 L p F P
0 g
s
.05 .5 .775 .1 k
.50532 .82252 m .49802 .82383 L .51224 .84589 L p F P
0 g
s
.05 .5 .775 .1 k
.51224 .84589 m .51587 .84525 L .50532 .82252 L p F P
0 g
s
.55 .5 .825 .1 k
.49883 .34387 m .53596 .34324 L .53569 .32 L p F P
0 g
s
.15 .5 .008 .1 k
.68934 .78967 m .68233 .78099 L .65308 .80364 L p F P
0 g
s
.083 .5 .675 .1 k
.43924 .81614 m .43304 .82094 L .46382 .83869 L p F P
0 g
s
.083 .5 .675 .1 k
.46382 .83869 m .46804 .83552 L .43924 .81614 L p F P
0 g
s
.45 .5 .708 .1 k
.27623 .50166 m .30046 .48612 L .2985 .45484 L p F P
0 g
s
.417 .5 .708 .1 k
.30046 .48612 m .27623 .50166 L .28145 .53398 L p F P
0 g
s
.05 .5 .892 .1 k
.55827 .82465 m .55114 .82315 L .53866 .84556 L p F P
0 g
s
.05 .5 .875 .1 k
.53496 .84501 m .53866 .84556 L .55114 .82315 L p F P
0 g
s
.05 .5 .792 .1 k
.51286 .8216 m .50532 .82252 L .51587 .84525 L p F P
0 g
s
.05 .5 .792 .1 k
.51587 .84525 m .51963 .8448 L .51286 .8216 L p F P
0 g
s
.117 .5 .658 .1 k
.40317 .80015 m .39655 .80695 L .42791 .82602 L p F P
0 g
s
.117 .5 .658 .1 k
.42791 .82602 m .43304 .82094 L .40317 .80015 L p F P
0 g
s
.05 .5 .875 .1 k
.55114 .82315 m .54371 .82203 L .53496 .84501 L p F P
0 g
s
.05 .5 .858 .1 k
.53117 .84466 m .53496 .84501 L .54371 .82203 L p F P
0 g
s
.05 .5 .808 .1 k
.52056 .82109 m .51286 .8216 L .51963 .8448 L p F P
0 g
s
.05 .5 .808 .1 k
.51963 .8448 m .52346 .84455 L .52056 .82109 L p F P
0 g
s
.05 .5 .858 .1 k
.54371 .82203 m .53608 .82131 L .53117 .84466 L p F P
0 g
s
.05 .5 .842 .1 k
.52732 .8445 m .53117 .84466 L .53608 .82131 L p F P
0 g
s
.05 .5 .825 .1 k
.52833 .821 m .52056 .82109 L .52346 .84455 L p F P
0 g
s
.05 .5 .825 .1 k
.52346 .84455 m .52732 .8445 L .52833 .821 L p F P
0 g
s
.25 .5 .658 .1 k
.31316 .73446 m .32341 .7227 L .30141 .69309 L p F P
0 g
s
.217 .5 .658 .1 k
.32341 .7227 m .31316 .73446 L .33876 .76084 L p F P
0 g
s
.05 .5 .842 .1 k
.53608 .82131 m .52833 .821 L .52732 .8445 L p F P
0 g
s
.45 .5 .725 .1 k
.3261 .4405 m .2985 .45484 L .30046 .48612 L p F P
0 g
s
.083 .5 .992 .1 k
.62239 .82354 m .61674 .81859 L .58687 .83714 L p F P
0 g
s
.083 .5 .975 .1 k
.58232 .83408 m .58687 .83714 L .61674 .81859 L p F P
0 g
s
.517 .5 .775 .1 k
.42636 .35292 m .39209 .36116 L .38995 .38791 L p F P
0 g
s
.517 .5 .758 .1 k
.35716 .39846 m .38995 .38791 L .39209 .36116 L p F P
0 g
s
.383 .5 .958 .1 k
.78223 .54224 m .76015 .52663 L .75219 .56036 L p F P
0 g
s
.383 .5 .958 .1 k
.75219 .56036 m .7736 .57515 L .78223 .54224 L p F P
0 g
s
.083 .5 .692 .1 k
.44647 .81169 m .43924 .81614 L .46804 .83552 L p F P
0 g
s
.083 .5 .692 .1 k
.46804 .83552 m .47293 .83258 L .44647 .81169 L p F P
0 g
s
.117 .5 .992 .1 k
.61674 .81859 m .62239 .82354 L .65308 .80364 L p F P
0 g
s
.25 .5 .992 .1 k
.75737 .69992 m .74485 .68691 L .72339 .71724 L p F P
0 g
s
.25 .5 .992 .1 k
.72339 .71724 m .73486 .72874 L .75737 .69992 L p F P
0 g
s
.15 .5 .658 .1 k
.37467 .77663 m .36669 .78512 L .39655 .80695 L p F P
0 g
s
.15 .5 .658 .1 k
.39655 .80695 m .40317 .80015 L .37467 .77663 L p F P
0 g
s
.217 .5 .658 .1 k
.33876 .76084 m .34795 .75068 L .32341 .7227 L p F P
0 g
s
.183 .5 .658 .1 k
.34795 .75068 m .33876 .76084 L .36669 .78512 L p F P
0 g
s
.183 .5 .658 .1 k
.36669 .78512 m .37467 .77663 L .34795 .75068 L p F P
0 g
s
.083 .5 .975 .1 k
.61674 .81859 m .61003 .81395 L .58232 .83408 L p F P
0 g
s
.083 .5 .958 .1 k
.57712 .83126 m .58232 .83408 L .61003 .81395 L p F P
0 g
s
.483 .5 .908 .1 k
.71156 .40477 m .67998 .39311 L .68054 .42273 L p F P
0 g
s
.483 .5 .908 .1 k
.68054 .42273 m .71222 .43425 L .71156 .40477 L p F P
0 g
s
.317 .5 .675 .1 k
.28225 .6623 m .29725 .64828 L .28202 .61553 L p F P
0 g
s
.283 .5 .675 .1 k
.29725 .64828 m .28225 .6623 L .30141 .69309 L p F P
0 g
s
.383 .5 .692 .1 k
.26989 .58267 m .28974 .56732 L .28145 .53398 L p F P
0 g
s
.35 .5 .692 .1 k
.28974 .56732 m .26989 .58267 L .28202 .61553 L p F P
0 g
s
.317 .5 .975 .1 k
.77924 .62334 m .76185 .60851 L .74711 .64183 L p F P
0 g
s
.317 .5 .975 .1 k
.74711 .64183 m .76355 .65546 L .77924 .62334 L p F P
0 g
s
.117 .5 .675 .1 k
.41124 .79372 m .40317 .80015 L .43304 .82094 L p F P
0 g
s
.117 .5 .675 .1 k
.43304 .82094 m .43924 .81614 L .41124 .79372 L p F P
0 g
s
.083 .5 .708 .1 k
.45464 .80763 m .44647 .81169 L .47293 .83258 L p F P
0 g
s
.083 .5 .708 .1 k
.47293 .83258 m .47844 .82992 L .45464 .80763 L p F P
0 g
s
.517 .5 .875 .1 k
.64428 .3569 m .60923 .34982 L .61056 .37655 L p F P
0 g
s
.517 .5 .875 .1 k
.61056 .37655 m .64616 .38364 L .64428 .3569 L p F P
0 g
s
.417 .5 .942 .1 k
.76516 .494 m .73938 .47919 L .73487 .5124 L p F P
0 g
s
.417 .5 .942 .1 k
.73487 .5124 m .76015 .52663 L .76516 .494 L p F P
0 g
s
.15 .5 .992 .1 k
.64575 .79701 m .65308 .80364 L .68233 .78099 L p F P
0 g
s
.117 .5 .992 .1 k
.65308 .80364 m .64575 .79701 L .61674 .81859 L p F P
0 g
s
.217 .5 .992 .1 k
.73486 .72874 m .72339 .71724 L .69948 .74597 L p F P
0 g
s
.217 .5 .992 .1 k
.69948 .74597 m .70973 .7559 L .73486 .72874 L p F P
0 g
s
.45 .5 .925 .1 k
.74123 .44773 m .71222 .43425 L .71061 .46606 L p F P
0 g
s
.45 .5 .925 .1 k
.71061 .46606 m .73938 .47919 L .74123 .44773 L p F P
0 g
s
.083 .5 .958 .1 k
.61003 .81395 m .60234 .80968 L .57712 .83126 L p F P
0 g
s
.083 .5 .942 .1 k
.57134 .82874 m .57712 .83126 L .60234 .80968 L p F P
0 g
s
.117 .5 .975 .1 k
.61003 .81395 m .61674 .81859 L .64575 .79701 L p F P
0 g
s
.183 .5 .992 .1 k
.67347 .77269 m .68233 .78099 L .70973 .7559 L p F P
0 g
s
.15 .5 .992 .1 k
.68233 .78099 m .67347 .77269 L .64575 .79701 L p F P
0 g
s
.183 .5 .992 .1 k
.70973 .7559 m .69948 .74597 L .67347 .77269 L p F P
0 g
s
.083 .5 .725 .1 k
.46367 .80403 m .45464 .80763 L .47844 .82992 L p F P
0 g
s
.083 .5 .725 .1 k
.47844 .82992 m .4845 .82755 L .46367 .80403 L p F P
0 g
s
.517 .5 .792 .1 k
.46211 .34712 m .42636 .35292 L .42476 .37966 L p F P
0 g
s
.517 .5 .775 .1 k
.38995 .38791 m .42476 .37966 L .42636 .35292 L p F P
0 g
s
.283 .5 .675 .1 k
.30141 .69309 m .31538 .68043 L .29725 .64828 L p F P
0 g
s
.25 .5 .675 .1 k
.31538 .68043 m .30141 .69309 L .32341 .7227 L p F P
0 g
s
.483 .5 .758 .1 k
.38995 .38791 m .35716 .39846 L .35655 .42801 L p F P
0 g
s
.483 .5 .742 .1 k
.3261 .4405 m .35655 .42801 L .35716 .39846 L p F P
0 g
s
.083 .5 .942 .1 k
.60234 .80968 m .59375 .80584 L .57134 .82874 L p F P
0 g
s
.083 .5 .925 .1 k
.56503 .82652 m .57134 .82874 L .59375 .80584 L p F P
0 g
s
.417 .5 .708 .1 k
.28145 .53398 m .30522 .51905 L .30046 .48612 L p F P
0 g
s
.383 .5 .708 .1 k
.30522 .51905 m .28145 .53398 L .28974 .56732 L p F P
0 g
s
.15 .5 .675 .1 k
.38446 .76857 m .37467 .77663 L .40317 .80015 L p F P
0 g
s
.15 .5 .675 .1 k
.40317 .80015 m .41124 .79372 L .38446 .76857 L p F P
0 g
s
.117 .5 .692 .1 k
.42069 .78774 m .41124 .79372 L .43924 .81614 L p F P
0 g
s
.117 .5 .692 .1 k
.43924 .81614 m .44647 .81169 L .42069 .78774 L p F P
0 g
s
.083 .5 .742 .1 k
.47345 .80092 m .46367 .80403 L .4845 .82755 L p F P
0 g
s
.083 .5 .742 .1 k
.4845 .82755 m .49106 .82551 L .47345 .80092 L p F P
0 g
s
.283 .5 .975 .1 k
.76355 .65546 m .74711 .64183 L .72957 .67461 L p F P
0 g
s
.283 .5 .975 .1 k
.72957 .67461 m .74485 .68691 L .76355 .65546 L p F P
0 g
s
.517 .5 .858 .1 k
.60923 .34982 m .57295 .34523 L .57369 .37196 L p F P
0 g
s
.517 .5 .858 .1 k
.57369 .37196 m .61056 .37655 L .60923 .34982 L p F P
0 g
s
.35 .5 .958 .1 k
.7736 .57515 m .75219 .56036 L .74137 .5947 L p F P
0 g
s
.35 .5 .958 .1 k
.74137 .5947 m .76185 .60851 L .7736 .57515 L p F P
0 g
s
.083 .5 .925 .1 k
.59375 .80584 m .58435 .80247 L .56503 .82652 L p F P
0 g
s
.083 .5 .908 .1 k
.55827 .82465 m .56503 .82652 L .58435 .80247 L p F P
0 g
s
.35 .5 .692 .1 k
.28202 .61553 m .30103 .6012 L .28974 .56732 L p F P
0 g
s
.317 .5 .692 .1 k
.30103 .6012 m .28202 .61553 L .29725 .64828 L p F P
0 g
s
.25 .5 .675 .1 k
.32341 .7227 m .33616 .7115 L .31538 .68043 L p F P
0 g
s
.217 .5 .675 .1 k
.33616 .7115 m .32341 .7227 L .34795 .75068 L p F P
0 g
s
.183 .5 .675 .1 k
.35931 .74103 m .34795 .75068 L .37467 .77663 L p F P
0 g
s
.183 .5 .675 .1 k
.37467 .77663 m .38446 .76857 L .35931 .74103 L p F P
0 g
s
.45 .5 .742 .1 k
.35655 .42801 m .3261 .4405 L .32783 .47215 L p F P
0 g
s
.45 .5 .725 .1 k
.30046 .48612 m .32783 .47215 L .3261 .4405 L p F P
0 g
s
.417 .5 .725 .1 k
.32783 .47215 m .30046 .48612 L .30522 .51905 L p F P
0 g
s
.117 .5 .975 .1 k
.64575 .79701 m .63701 .79078 L .61003 .81395 L p F P
0 g
s
.117 .5 .958 .1 k
.60234 .80968 m .61003 .81395 L .63701 .79078 L p F P
0 g
s
.15 .5 .975 .1 k
.63701 .79078 m .64575 .79701 L .67347 .77269 L p F P
0 g
s
.083 .5 .758 .1 k
.48386 .79835 m .47345 .80092 L .49106 .82551 L p F P
0 g
s
.083 .5 .758 .1 k
.49106 .82551 m .49802 .82383 L .48386 .79835 L p F P
0 g
s
.217 .5 .675 .1 k
.34795 .75068 m .35931 .74103 L .33616 .7115 L p F P
0 g
s
.517 .5 .808 .1 k
.49883 .34387 m .46211 .34712 L .46108 .37385 L p F P
0 g
s
.517 .5 .792 .1 k
.42476 .37966 m .46108 .37385 L .46211 .34712 L p F P
0 g
s
.483 .5 .892 .1 k
.67998 .39311 m .64616 .38364 L .64659 .41338 L p F P
0 g
s
.483 .5 .892 .1 k
.64659 .41338 m .68054 .42273 L .67998 .39311 L p F P
0 g
s
.083 .5 .908 .1 k
.58435 .80247 m .57425 .79961 L .55827 .82465 L p F P
0 g
s
.083 .5 .892 .1 k
.55114 .82315 m .55827 .82465 L .57425 .79961 L p F P
0 g
s
.083 .5 .775 .1 k
.4948 .79635 m .48386 .79835 L .49802 .82383 L p F P
0 g
s
.083 .5 .775 .1 k
.49802 .82383 m .50532 .82252 L .4948 .79635 L p F P
0 g
s
.517 .5 .842 .1 k
.57295 .34523 m .53596 .34324 L .53612 .36996 L p F P
0 g
s
.517 .5 .842 .1 k
.53612 .36996 m .57369 .37196 L .57295 .34523 L p F P
0 g
s
.117 .5 .708 .1 k
.43141 .78228 m .42069 .78774 L .44647 .81169 L p F P
0 g
s
.117 .5 .708 .1 k
.44647 .81169 m .45464 .80763 L .43141 .78228 L p F P
0 g
s
.25 .5 .975 .1 k
.74485 .68691 m .72957 .67461 L .70947 .70637 L p F P
0 g
s
.25 .5 .975 .1 k
.70947 .70637 m .72339 .71724 L .74485 .68691 L p F P
0 g
s
.083 .5 .892 .1 k
.57425 .79961 m .56357 .79732 L .55114 .82315 L p F P
0 g
s
.083 .5 .875 .1 k
.54371 .82203 m .55114 .82315 L .56357 .79732 L p F P
0 g
s
.517 .5 .825 .1 k
.53596 .34324 m .49883 .34387 L .49839 .37059 L p F P
0 g
s
.517 .5 .808 .1 k
.46108 .37385 m .49839 .37059 L .49883 .34387 L p F P
0 g
s
.383 .5 .942 .1 k
.76015 .52663 m .73487 .5124 L .72772 .54688 L p F P
0 g
s
.383 .5 .942 .1 k
.72772 .54688 m .75219 .56036 L .76015 .52663 L p F P
0 g
s
.083 .5 .792 .1 k
.50611 .79496 m .4948 .79635 L .50532 .82252 L p F P
0 g
s
.083 .5 .792 .1 k
.50532 .82252 m .51286 .8216 L .50611 .79496 L p F P
0 g
s
.15 .5 .692 .1 k
.39598 .76106 m .38446 .76857 L .41124 .79372 L p F P
0 g
s
.15 .5 .692 .1 k
.41124 .79372 m .42069 .78774 L .39598 .76106 L p F P
0 g
s
.183 .5 .975 .1 k
.66284 .76488 m .67347 .77269 L .69948 .74597 L p F P
0 g
s
.15 .5 .975 .1 k
.67347 .77269 m .66284 .76488 L .63701 .79078 L p F P
0 g
s
.517 .5 .825 .1 k
.49839 .37059 m .53612 .36996 L .53596 .34324 L p F P
0 g
s
.083 .5 .875 .1 k
.56357 .79732 m .55243 .79561 L .54371 .82203 L p F P
0 g
s
.083 .5 .858 .1 k
.53608 .82131 m .54371 .82203 L .55243 .79561 L p F P
0 g
s
.117 .5 .958 .1 k
.63701 .79078 m .62694 .78504 L .60234 .80968 L p F P
0 g
s
.117 .5 .942 .1 k
.59375 .80584 m .60234 .80968 L .62694 .78504 L p F P
0 g
s
.083 .5 .808 .1 k
.51768 .79418 m .50611 .79496 L .51286 .8216 L p F P
0 g
s
.083 .5 .808 .1 k
.51286 .8216 m .52056 .82109 L .51768 .79418 L p F P
0 g
s
.083 .5 .858 .1 k
.55243 .79561 m .54098 .7945 L .53608 .82131 L p F P
0 g
s
.083 .5 .842 .1 k
.52833 .821 m .53608 .82131 L .54098 .7945 L p F P
0 g
s
.217 .5 .975 .1 k
.72339 .71724 m .70947 .70637 L .68712 .73661 L p F P
0 g
s
.217 .5 .975 .1 k
.68712 .73661 m .69948 .74597 L .72339 .71724 L p F P
0 g
s
.317 .5 .692 .1 k
.29725 .64828 m .31519 .63512 L .30103 .6012 L p F P
0 g
s
.283 .5 .692 .1 k
.31519 .63512 m .29725 .64828 L .31538 .68043 L p F P
0 g
s
.083 .5 .825 .1 k
.52935 .79402 m .51768 .79418 L .52056 .82109 L p F P
0 g
s
.083 .5 .825 .1 k
.52056 .82109 m .52833 .821 L .52935 .79402 L p F P
0 g
s
.45 .5 .908 .1 k
.71222 .43425 m .68054 .42273 L .67919 .45485 L p F P
0 g
s
.45 .5 .908 .1 k
.67919 .45485 m .71061 .46606 L .71222 .43425 L p F P
0 g
s
.483 .5 .775 .1 k
.42476 .37966 m .38995 .38791 L .38946 .4176 L p F P
0 g
s
.483 .5 .758 .1 k
.35655 .42801 m .38946 .4176 L .38995 .38791 L p F P
0 g
s
.083 .5 .842 .1 k
.54098 .7945 m .52935 .79402 L .52833 .821 L p F P
0 g
s
.183 .5 .975 .1 k
.69948 .74597 m .68712 .73661 L .66284 .76488 L p F P
0 g
s
.383 .5 .708 .1 k
.28974 .56732 m .31277 .55319 L .30522 .51905 L p F P
0 g
s
.35 .5 .708 .1 k
.31277 .55319 m .28974 .56732 L .30103 .6012 L p F P
0 g
s
.417 .5 .925 .1 k
.73938 .47919 m .71061 .46606 L .70668 .49979 L p F P
0 g
s
.417 .5 .925 .1 k
.70668 .49979 m .73487 .5124 L .73938 .47919 L p F P
0 g
s
.317 .5 .958 .1 k
.76185 .60851 m .74137 .5947 L .72781 .62916 L p F P
0 g
s
.317 .5 .958 .1 k
.72781 .62916 m .74711 .64183 L .76185 .60851 L p F P
0 g
s
.117 .5 .725 .1 k
.4433 .77742 m .43141 .78228 L .45464 .80763 L p F P
0 g
s
.117 .5 .725 .1 k
.45464 .80763 m .46367 .80403 L .4433 .77742 L p F P
0 g
s
.15 .5 .958 .1 k
.62694 .78504 m .63701 .79078 L .66284 .76488 L p F P
0 g
s
.183 .5 .692 .1 k
.37273 .73201 m .35931 .74103 L .38446 .76857 L p F P
0 g
s
.183 .5 .692 .1 k
.38446 .76857 m .39598 .76106 L .37273 .73201 L p F P
0 g
s
.117 .5 .942 .1 k
.62694 .78504 m .61564 .77986 L .59375 .80584 L p F P
0 g
s
.117 .5 .925 .1 k
.58435 .80247 m .59375 .80584 L .61564 .77986 L p F P
0 g
s
.483 .5 .875 .1 k
.64616 .38364 m .61056 .37655 L .61087 .40637 L p F P
0 g
s
.483 .5 .875 .1 k
.61087 .40637 m .64659 .41338 L .64616 .38364 L p F P
0 g
s
.283 .5 .692 .1 k
.31538 .68043 m .33203 .66857 L .31519 .63512 L p F P
0 g
s
.25 .5 .692 .1 k
.33203 .66857 m .31538 .68043 L .33616 .7115 L p F P
0 g
s
.15 .5 .708 .1 k
.40911 .7542 m .39598 .76106 L .42069 .78774 L p F P
0 g
s
.15 .5 .708 .1 k
.42069 .78774 m .43141 .78228 L .40911 .7542 L p F P
0 g
s
.417 .5 .725 .1 k
.30522 .51905 m .33205 .50564 L .32783 .47215 L p F P
0 g
s
.383 .5 .725 .1 k
.33205 .50564 m .30522 .51905 L .31277 .55319 L p F P
0 g
s
.45 .5 .758 .1 k
.38946 .4176 m .35655 .42801 L .35803 .45999 L p F P
0 g
s
.45 .5 .742 .1 k
.32783 .47215 m .35803 .45999 L .35655 .42801 L p F P
0 g
s
.217 .5 .692 .1 k
.3513 .70103 m .33616 .7115 L .35931 .74103 L p F P
0 g
s
.217 .5 .692 .1 k
.35931 .74103 m .37273 .73201 L .3513 .70103 L p F P
0 g
s
.117 .5 .742 .1 k
.45621 .77323 m .4433 .77742 L .46367 .80403 L p F P
0 g
s
.117 .5 .742 .1 k
.46367 .80403 m .47345 .80092 L .45621 .77323 L p F P
0 g
s
.25 .5 .692 .1 k
.33616 .7115 m .3513 .70103 L .33203 .66857 L p F P
0 g
s
.283 .5 .958 .1 k
.74711 .64183 m .72781 .62916 L .71169 .6632 L p F P
0 g
s
.283 .5 .958 .1 k
.71169 .6632 m .72957 .67461 L .74711 .64183 L p F P
0 g
s
.183 .5 .958 .1 k
.65053 .75767 m .66284 .76488 L .68712 .73661 L p F P
0 g
s
.15 .5 .958 .1 k
.66284 .76488 m .65053 .75767 L .62694 .78504 L p F P
0 g
s
.417 .5 .742 .1 k
.35803 .45999 m .32783 .47215 L .33205 .50564 L p F P
0 g
s
.483 .5 .792 .1 k
.46108 .37385 m .42476 .37966 L .42439 .40944 L p F P
0 g
s
.483 .5 .775 .1 k
.38946 .4176 m .42439 .40944 L .42476 .37966 L p F P
0 g
s
.35 .5 .942 .1 k
.75219 .56036 m .72772 .54688 L .718 .58214 L p F P
0 g
s
.35 .5 .942 .1 k
.718 .58214 m .74137 .5947 L .75219 .56036 L p F P
0 g
s
.117 .5 .925 .1 k
.61564 .77986 m .60324 .77532 L .58435 .80247 L p F P
0 g
s
.117 .5 .908 .1 k
.57425 .79961 m .58435 .80247 L .60324 .77532 L p F P
0 g
s
.35 .5 .708 .1 k
.30103 .6012 m .32304 .58802 L .31277 .55319 L p F P
0 g
s
.317 .5 .708 .1 k
.32304 .58802 m .30103 .6012 L .31519 .63512 L p F P
0 g
s
.15 .5 .942 .1 k
.61564 .77986 m .62694 .78504 L .65053 .75767 L p F P
0 g
s
.117 .5 .758 .1 k
.46999 .76975 m .45621 .77323 L .47345 .80092 L p F P
0 g
s
.117 .5 .758 .1 k
.47345 .80092 m .48386 .79835 L .46999 .76975 L p F P
0 g
s
.483 .5 .858 .1 k
.61056 .37655 m .57369 .37196 L .57387 .40184 L p F P
0 g
s
.483 .5 .858 .1 k
.57387 .40184 m .61087 .40637 L .61056 .37655 L p F P
0 g
s
.25 .5 .958 .1 k
.72957 .67461 m .71169 .6632 L .69324 .69629 L p F P
0 g
s
.25 .5 .958 .1 k
.69324 .69629 m .70947 .70637 L .72957 .67461 L p F P
0 g
s
.45 .5 .892 .1 k
.68054 .42273 m .64659 .41338 L .64554 .44574 L p F P
0 g
s
.45 .5 .892 .1 k
.64554 .44574 m .67919 .45485 L .68054 .42273 L p F P
0 g
s
.217 .5 .958 .1 k
.67274 .72794 m .68712 .73661 L .70947 .70637 L p F P
0 g
s
.183 .5 .958 .1 k
.68712 .73661 m .67274 .72794 L .65053 .75767 L p F P
0 g
s
.117 .5 .908 .1 k
.60324 .77532 m .5899 .77146 L .57425 .79961 L p F P
0 g
s
.117 .5 .892 .1 k
.56357 .79732 m .57425 .79961 L .5899 .77146 L p F P
0 g
s
.217 .5 .958 .1 k
.70947 .70637 m .69324 .69629 L .67274 .72794 L p F P
0 g
s
.15 .5 .725 .1 k
.42371 .74807 m .40911 .7542 L .43141 .78228 L p F P
0 g
s
.15 .5 .725 .1 k
.43141 .78228 m .4433 .77742 L .42371 .74807 L p F P
0 g
s
.183 .5 .708 .1 k
.38809 .72376 m .37273 .73201 L .39598 .76106 L p F P
0 g
s
.183 .5 .708 .1 k
.39598 .76106 m .40911 .7542 L .38809 .72376 L p F P
0 g
s
.383 .5 .925 .1 k
.73487 .5124 m .70668 .49979 L .70045 .53495 L p F P
0 g
s
.383 .5 .925 .1 k
.70045 .53495 m .72772 .54688 L .73487 .5124 L p F P
0 g
s
.117 .5 .775 .1 k
.48447 .76705 m .46999 .76975 L .48386 .79835 L p F P
0 g
s
.117 .5 .775 .1 k
.48386 .79835 m .4948 .79635 L .48447 .76705 L p F P
0 g
s
.483 .5 .808 .1 k
.49839 .37059 m .46108 .37385 L .46084 .40371 L p F P
0 g
s
.483 .5 .792 .1 k
.42439 .40944 m .46084 .40371 L .46108 .37385 L p F P
0 g
s
.417 .5 .908 .1 k
.71061 .46606 m .67919 .45485 L .67591 .48902 L p F P
0 g
s
.417 .5 .908 .1 k
.67591 .48902 m .70668 .49979 L .71061 .46606 L p F P
0 g
s
.117 .5 .892 .1 k
.5899 .77146 m .57575 .76835 L .56357 .79732 L p F P
0 g
s
.117 .5 .875 .1 k
.55243 .79561 m .56357 .79732 L .57575 .76835 L p F P
0 g
s
.317 .5 .708 .1 k
.31519 .63512 m .33591 .62303 L .32304 .58802 L p F P
0 g
s
.283 .5 .708 .1 k
.33591 .62303 m .31519 .63512 L .33203 .66857 L p F P
0 g
s
.483 .5 .842 .1 k
.57369 .37196 m .53612 .36996 L .53615 .39987 L p F P
0 g
s
.483 .5 .842 .1 k
.53615 .39987 m .57387 .40184 L .57369 .37196 L p F P
0 g
s
.15 .5 .942 .1 k
.65053 .75767 m .63667 .75115 L .61564 .77986 L p F P
0 g
s
.15 .5 .925 .1 k
.60324 .77532 m .61564 .77986 L .63667 .75115 L p F P
0 g
s
.117 .5 .792 .1 k
.49949 .76516 m .48447 .76705 L .4948 .79635 L p F P
0 g
s
.117 .5 .792 .1 k
.4948 .79635 m .50611 .79496 L .49949 .76516 L p F P
0 g
s
.383 .5 .725 .1 k
.31277 .55319 m .33873 .54049 L .33205 .50564 L p F P
0 g
s
.35 .5 .725 .1 k
.33873 .54049 m .31277 .55319 L .32304 .58802 L p F P
0 g
s
.317 .5 .942 .1 k
.74137 .5947 m .718 .58214 L .70582 .61764 L p F P
0 g
s
.317 .5 .942 .1 k
.70582 .61764 m .72781 .62916 L .74137 .5947 L p F P
0 g
s
.45 .5 .775 .1 k
.42439 .40944 m .38946 .4176 L .39066 .44985 L p F P
0 g
s
.45 .5 .758 .1 k
.35803 .45999 m .39066 .44985 L .38946 .4176 L p F P
0 g
s
.183 .5 .942 .1 k
.63667 .75115 m .65053 .75767 L .67274 .72794 L p F P
0 g
s
.483 .5 .825 .1 k
.53612 .36996 m .49839 .37059 L .49829 .40049 L p F P
0 g
s
.483 .5 .808 .1 k
.46084 .40371 m .49829 .40049 L .49839 .37059 L p F P
0 g
s
.117 .5 .875 .1 k
.57575 .76835 m .56099 .76604 L .55243 .79561 L p F P
0 g
s
.117 .5 .858 .1 k
.54098 .7945 m .55243 .79561 L .56099 .76604 L p F P
0 g
s
.217 .5 .708 .1 k
.36868 .69142 m .3513 .70103 L .37273 .73201 L p F P
0 g
s
.217 .5 .708 .1 k
.37273 .73201 m .38809 .72376 L .36868 .69142 L p F P
0 g
s
.483 .5 .825 .1 k
.49829 .40049 m .53615 .39987 L .53612 .36996 L p F P
0 g
s
.117 .5 .808 .1 k
.51484 .7641 m .49949 .76516 L .50611 .79496 L p F P
0 g
s
.117 .5 .808 .1 k
.50611 .79496 m .51768 .79418 L .51484 .7641 L p F P
0 g
s
.283 .5 .708 .1 k
.33203 .66857 m .3512 .65767 L .33591 .62303 L p F P
0 g
s
.25 .5 .708 .1 k
.3512 .65767 m .33203 .66857 L .3513 .70103 L p F P
0 g
s
.117 .5 .858 .1 k
.56099 .76604 m .54579 .76454 L .54098 .7945 L p F P
0 g
s
.117 .5 .842 .1 k
.52935 .79402 m .54098 .7945 L .54579 .76454 L p F P
0 g
s
.15 .5 .742 .1 k
.4396 .74278 m .42371 .74807 L .4433 .77742 L p F P
0 g
s
.15 .5 .742 .1 k
.4433 .77742 m .45621 .77323 L .4396 .74278 L p F P
0 g
s
.117 .5 .825 .1 k
.53034 .76389 m .51484 .7641 L .51768 .79418 L p F P
0 g
s
.117 .5 .825 .1 k
.51768 .79418 m .52935 .79402 L .53034 .76389 L p F P
0 g
s
.25 .5 .708 .1 k
.3513 .70103 m .36868 .69142 L .3512 .65767 L p F P
0 g
s
.117 .5 .842 .1 k
.54579 .76454 m .53034 .76389 L .52935 .79402 L p F P
0 g
s
.417 .5 .742 .1 k
.33205 .50564 m .36163 .49396 L .35803 .45999 L p F P
0 g
s
.383 .5 .742 .1 k
.36163 .49396 m .33205 .50564 L .33873 .54049 L p F P
0 g
s
.417 .5 .758 .1 k
.39066 .44985 m .35803 .45999 L .36163 .49396 L p F P
0 g
s
.45 .5 .875 .1 k
.64659 .41338 m .61087 .40637 L .61012 .43892 L p F P
0 g
s
.45 .5 .875 .1 k
.61012 .43892 m .64554 .44574 L .64659 .41338 L p F P
0 g
s
.183 .5 .725 .1 k
.40522 .71639 m .38809 .72376 L .40911 .7542 L p F P
0 g
s
.183 .5 .725 .1 k
.40911 .7542 m .42371 .74807 L .40522 .71639 L p F P
0 g
s
.15 .5 .925 .1 k
.63667 .75115 m .62143 .74542 L .60324 .77532 L p F P
0 g
s
.15 .5 .908 .1 k
.5899 .77146 m .60324 .77532 L .62143 .74542 L p F P
0 g
s
.283 .5 .942 .1 k
.72781 .62916 m .70582 .61764 L .69137 .65283 L p F P
0 g
s
.283 .5 .942 .1 k
.69137 .65283 m .71169 .6632 L .72781 .62916 L p F P
0 g
s
.217 .5 .942 .1 k
.65651 .7201 m .67274 .72794 L .69324 .69629 L p F P
0 g
s
.183 .5 .942 .1 k
.67274 .72794 m .65651 .7201 L .63667 .75115 L p F P
0 g
s
.35 .5 .925 .1 k
.72772 .54688 m .70045 .53495 L .69199 .57103 L p F P
0 g
s
.35 .5 .925 .1 k
.69199 .57103 m .718 .58214 L .72772 .54688 L p F P
0 g
s
.35 .5 .725 .1 k
.32304 .58802 m .34782 .57618 L .33873 .54049 L p F P
0 g
s
.317 .5 .725 .1 k
.34782 .57618 m .32304 .58802 L .33591 .62303 L p F P
0 g
s
.15 .5 .758 .1 k
.45661 .73839 m .4396 .74278 L .45621 .77323 L p F P
0 g
s
.15 .5 .758 .1 k
.45621 .77323 m .46999 .76975 L .45661 .73839 L p F P
0 g
s
.25 .5 .942 .1 k
.71169 .6632 m .69137 .65283 L .67484 .68716 L p F P
0 g
s
.25 .5 .942 .1 k
.67484 .68716 m .69324 .69629 L .71169 .6632 L p F P
0 g
s
.217 .5 .942 .1 k
.69324 .69629 m .67484 .68716 L .65651 .7201 L p F P
0 g
s
.45 .5 .792 .1 k
.46084 .40371 m .42439 .40944 L .42529 .44191 L p F P
0 g
s
.45 .5 .775 .1 k
.39066 .44985 m .42529 .44191 L .42439 .40944 L p F P
0 g
s
.183 .5 .925 .1 k
.62143 .74542 m .63667 .75115 L .65651 .7201 L p F P
0 g
s
.417 .5 .892 .1 k
.67919 .45485 m .64554 .44574 L .64297 .48029 L p F P
0 g
s
.417 .5 .892 .1 k
.64297 .48029 m .67591 .48902 L .67919 .45485 L p F P
0 g
s
.15 .5 .908 .1 k
.62143 .74542 m .60497 .74055 L .5899 .77146 L p F P
0 g
s
.15 .5 .892 .1 k
.57575 .76835 m .5899 .77146 L .60497 .74055 L p F P
0 g
s
.383 .5 .908 .1 k
.70668 .49979 m .67591 .48902 L .67071 .52477 L p F P
0 g
s
.383 .5 .908 .1 k
.67071 .52477 m .70045 .53495 L .70668 .49979 L p F P
0 g
s
.217 .5 .725 .1 k
.38812 .68283 m .36868 .69142 L .38809 .72376 L p F P
0 g
s
.217 .5 .725 .1 k
.38809 .72376 m .40522 .71639 L .38812 .68283 L p F P
0 g
s
.45 .5 .858 .1 k
.61087 .40637 m .57387 .40184 L .57345 .43451 L p F P
0 g
s
.45 .5 .858 .1 k
.57345 .43451 m .61012 .43892 L .61087 .40637 L p F P
0 g
s
.15 .5 .775 .1 k
.47452 .73498 m .45661 .73839 L .46999 .76975 L p F P
0 g
s
.15 .5 .775 .1 k
.46999 .76975 m .48447 .76705 L .47452 .73498 L p F P
0 g
s
.317 .5 .725 .1 k
.33591 .62303 m .3592 .61218 L .34782 .57618 L p F P
0 g
s
.283 .5 .725 .1 k
.3592 .61218 m .33591 .62303 L .3512 .65767 L p F P
0 g
s
.183 .5 .742 .1 k
.42391 .71001 m .40522 .71639 L .42371 .74807 L p F P
0 g
s
.183 .5 .742 .1 k
.42371 .74807 m .4396 .74278 L .42391 .71001 L p F P
0 g
s
.383 .5 .742 .1 k
.33873 .54049 m .36733 .52944 L .36163 .49396 L p F P
0 g
s
.35 .5 .742 .1 k
.36733 .52944 m .33873 .54049 L .34782 .57618 L p F P
0 g
s
.15 .5 .892 .1 k
.60497 .74055 m .58751 .73662 L .57575 .76835 L p F P
0 g
s
.15 .5 .875 .1 k
.56099 .76604 m .57575 .76835 L .58751 .73662 L p F P
0 g
s
.317 .5 .925 .1 k
.718 .58214 m .69199 .57103 L .6814 .60746 L p F P
0 g
s
.317 .5 .925 .1 k
.6814 .60746 m .70582 .61764 L .718 .58214 L p F P
0 g
s
.25 .5 .725 .1 k
.3727 .64791 m .3512 .65767 L .36868 .69142 L p F P
0 g
s
.25 .5 .725 .1 k
.36868 .69142 m .38812 .68283 L .3727 .64791 L p F P
0 g
s
.45 .5 .808 .1 k
.49829 .40049 m .46084 .40371 L .46142 .43632 L p F P
0 g
s
.45 .5 .792 .1 k
.42529 .44191 m .46142 .43632 L .46084 .40371 L p F P
0 g
s
.283 .5 .725 .1 k
.3512 .65767 m .3727 .64791 L .3592 .61218 L p F P
0 g
s
.417 .5 .775 .1 k
.42529 .44191 m .39066 .44985 L .39358 .48422 L p F P
0 g
s
.417 .5 .758 .1 k
.36163 .49396 m .39358 .48422 L .39066 .44985 L p F P
0 g
s
.217 .5 .925 .1 k
.63861 .71319 m .65651 .7201 L .67484 .68716 L p F P
0 g
s
.183 .5 .925 .1 k
.65651 .7201 m .63861 .71319 L .62143 .74542 L p F P
0 g
s
.15 .5 .792 .1 k
.49309 .73258 m .47452 .73498 L .48447 .76705 L p F P
0 g
s
.15 .5 .792 .1 k
.48447 .76705 m .49949 .76516 L .49309 .73258 L p F P
0 g
s
.183 .5 .908 .1 k
.60497 .74055 m .62143 .74542 L .63861 .71319 L p F P
0 g
s
.45 .5 .842 .1 k
.57387 .40184 m .53615 .39987 L .53606 .43259 L p F P
0 g
s
.45 .5 .842 .1 k
.53606 .43259 m .57345 .43451 L .57387 .40184 L p F P
0 g
s
.383 .5 .758 .1 k
.39358 .48422 m .36163 .49396 L .36733 .52944 L p F P
0 g
s
.15 .5 .875 .1 k
.58751 .73662 m .56925 .73369 L .56099 .76604 L p F P
0 g
s
.15 .5 .858 .1 k
.54579 .76454 m .56099 .76604 L .56925 .73369 L p F P
0 g
s
.45 .5 .825 .1 k
.53615 .39987 m .49829 .40049 L .49853 .43319 L p F P
0 g
s
.45 .5 .808 .1 k
.46142 .43632 m .49853 .43319 L .49829 .40049 L p F P
0 g
s
.15 .5 .808 .1 k
.5121 .73124 m .49309 .73258 L .49949 .76516 L p F P
0 g
s
.15 .5 .808 .1 k
.49949 .76516 m .51484 .7641 L .5121 .73124 L p F P
0 g
s
.45 .5 .825 .1 k
.49853 .43319 m .53606 .43259 L .53615 .39987 L p F P
0 g
s
.283 .5 .925 .1 k
.70582 .61764 m .6814 .60746 L .66884 .64367 L p F P
0 g
s
.283 .5 .925 .1 k
.66884 .64367 m .69137 .65283 L .70582 .61764 L p F P
0 g
s
.15 .5 .858 .1 k
.56925 .73369 m .55043 .7318 L .54579 .76454 L p F P
0 g
s
.15 .5 .842 .1 k
.53034 .76389 m .54579 .76454 L .55043 .7318 L p F P
0 g
s
.417 .5 .875 .1 k
.64554 .44574 m .61012 .43892 L .60831 .47374 L p F P
0 g
s
.417 .5 .875 .1 k
.60831 .47374 m .64297 .48029 L .64554 .44574 L p F P
0 g
s
.183 .5 .758 .1 k
.44395 .70471 m .42391 .71001 L .4396 .74278 L p F P
0 g
s
.183 .5 .758 .1 k
.4396 .74278 m .45661 .73839 L .44395 .70471 L p F P
0 g
s
.15 .5 .825 .1 k
.5313 .73098 m .5121 .73124 L .51484 .7641 L p F P
0 g
s
.15 .5 .825 .1 k
.51484 .7641 m .53034 .76389 L .5313 .73098 L p F P
0 g
s
.25 .5 .925 .1 k
.6545 .6791 m .67484 .68716 L .69137 .65283 L p F P
0 g
s
.217 .5 .925 .1 k
.67484 .68716 m .6545 .6791 L .63861 .71319 L p F P
0 g
s
.15 .5 .842 .1 k
.55043 .7318 m .5313 .73098 L .53034 .76389 L p F P
0 g
s
.35 .5 .908 .1 k
.70045 .53495 m .67071 .52477 L .66366 .56155 L p F P
0 g
s
.35 .5 .908 .1 k
.66366 .56155 m .69199 .57103 L .70045 .53495 L p F P
0 g
s
.217 .5 .742 .1 k
.40939 .67538 m .38812 .68283 L .40522 .71639 L p F P
0 g
s
.217 .5 .742 .1 k
.40522 .71639 m .42391 .71001 L .40939 .67538 L p F P
0 g
s
.25 .5 .925 .1 k
.69137 .65283 m .66884 .64367 L .6545 .6791 L p F P
0 g
s
.35 .5 .742 .1 k
.34782 .57618 m .37508 .56589 L .36733 .52944 L p F P
0 g
s
.317 .5 .742 .1 k
.37508 .56589 m .34782 .57618 L .3592 .61218 L p F P
0 g
s
.383 .5 .892 .1 k
.67591 .48902 m .64297 .48029 L .6389 .51651 L p F P
0 g
s
.383 .5 .892 .1 k
.6389 .51651 m .67071 .52477 L .67591 .48902 L p F P
0 g
s
.183 .5 .908 .1 k
.63861 .71319 m .61923 .70732 L .60497 .74055 L p F P
0 g
s
.183 .5 .892 .1 k
.58751 .73662 m .60497 .74055 L .61923 .70732 L p F P
0 g
s
.417 .5 .792 .1 k
.46142 .43632 m .42529 .44191 L .42747 .47661 L p F P
0 g
s
.417 .5 .775 .1 k
.39358 .48422 m .42747 .47661 L .42529 .44191 L p F P
0 g
s
.217 .5 .908 .1 k
.61923 .70732 m .63861 .71319 L .6545 .6791 L p F P
0 g
s
.25 .5 .742 .1 k
.39627 .63945 m .3727 .64791 L .38812 .68283 L p F P
0 g
s
.25 .5 .742 .1 k
.38812 .68283 m .40939 .67538 L .39627 .63945 L p F P
0 g
s
.183 .5 .775 .1 k
.46508 .70058 m .44395 .70471 L .45661 .73839 L p F P
0 g
s
.183 .5 .775 .1 k
.45661 .73839 m .47452 .73498 L .46508 .70058 L p F P
0 g
s
.317 .5 .742 .1 k
.3592 .61218 m .38477 .60276 L .37508 .56589 L p F P
0 g
s
.283 .5 .742 .1 k
.38477 .60276 m .3592 .61218 L .3727 .64791 L p F P
0 g
s
.383 .5 .758 .1 k
.36733 .52944 m .3982 .52023 L .39358 .48422 L p F P
0 g
s
.35 .5 .758 .1 k
.3982 .52023 m .36733 .52944 L .37508 .56589 L p F P
0 g
s
.283 .5 .742 .1 k
.3727 .64791 m .39627 .63945 L .38477 .60276 L p F P
0 g
s
.417 .5 .858 .1 k
.61012 .43892 m .57345 .43451 L .57242 .4695 L p F P
0 g
s
.417 .5 .858 .1 k
.57242 .4695 m .60831 .47374 L .61012 .43892 L p F P
0 g
s
.317 .5 .908 .1 k
.69199 .57103 m .66366 .56155 L .65483 .59878 L p F P
0 g
s
.317 .5 .908 .1 k
.65483 .59878 m .6814 .60746 L .69199 .57103 L p F P
0 g
s
.383 .5 .775 .1 k
.42747 .47661 m .39358 .48422 L .3982 .52023 L p F P
0 g
s
.183 .5 .892 .1 k
.61923 .70732 m .59864 .70257 L .58751 .73662 L p F P
0 g
s
.183 .5 .875 .1 k
.56925 .73369 m .58751 .73662 L .59864 .70257 L p F P
0 g
s
.217 .5 .758 .1 k
.43222 .6692 m .40939 .67538 L .42391 .71001 L p F P
0 g
s
.217 .5 .758 .1 k
.42391 .71001 m .44395 .70471 L .43222 .6692 L p F P
0 g
s
.183 .5 .792 .1 k
.48703 .69768 m .46508 .70058 L .47452 .73498 L p F P
0 g
s
.183 .5 .792 .1 k
.47452 .73498 m .49309 .73258 L .48703 .69768 L p F P
0 g
s
.417 .5 .808 .1 k
.49853 .43319 m .46142 .43632 L .46283 .47125 L p F P
0 g
s
.417 .5 .792 .1 k
.42747 .47661 m .46283 .47125 L .46142 .43632 L p F P
0 g
s
.25 .5 .908 .1 k
.63244 .67224 m .6545 .6791 L .66884 .64367 L p F P
0 g
s
.217 .5 .908 .1 k
.6545 .6791 m .63244 .67224 L .61923 .70732 L p F P
0 g
s
.283 .5 .908 .1 k
.6814 .60746 m .65483 .59878 L .64437 .63587 L p F P
0 g
s
.283 .5 .908 .1 k
.64437 .63587 m .66884 .64367 L .6814 .60746 L p F P
0 g
s
.183 .5 .875 .1 k
.59864 .70257 m .57708 .69903 L .56925 .73369 L p F P
0 g
s
.183 .5 .858 .1 k
.55043 .7318 m .56925 .73369 L .57708 .69903 L p F P
0 g
s
.417 .5 .842 .1 k
.57345 .43451 m .53606 .43259 L .53585 .46766 L p F P
0 g
s
.417 .5 .842 .1 k
.53585 .46766 m .57242 .4695 L .57345 .43451 L p F P
0 g
s
.35 .5 .892 .1 k
.67071 .52477 m .6389 .51651 L .63337 .55386 L p F P
0 g
s
.35 .5 .892 .1 k
.63337 .55386 m .66366 .56155 L .67071 .52477 L p F P
0 g
s
.383 .5 .875 .1 k
.64297 .48029 m .60831 .47374 L .60543 .51032 L p F P
0 g
s
.383 .5 .875 .1 k
.60543 .51032 m .6389 .51651 L .64297 .48029 L p F P
0 g
s
.217 .5 .892 .1 k
.59864 .70257 m .61923 .70732 L .63244 .67224 L p F P
0 g
s
.25 .5 .908 .1 k
.66884 .64367 m .64437 .63587 L .63244 .67224 L p F P
0 g
s
.183 .5 .808 .1 k
.50951 .69606 m .48703 .69768 L .49309 .73258 L p F P
0 g
s
.183 .5 .808 .1 k
.49309 .73258 m .5121 .73124 L .50951 .69606 L p F P
0 g
s
.417 .5 .825 .1 k
.53606 .43259 m .49853 .43319 L .49914 .46825 L p F P
0 g
s
.417 .5 .808 .1 k
.46283 .47125 m .49914 .46825 L .49853 .43319 L p F P
0 g
s
.35 .5 .758 .1 k
.37508 .56589 m .40447 .55732 L .3982 .52023 L p F P
0 g
s
.317 .5 .758 .1 k
.40447 .55732 m .37508 .56589 L .38477 .60276 L p F P
0 g
s
.417 .5 .825 .1 k
.49914 .46825 m .53585 .46766 L .53606 .43259 L p F P
0 g
s
.183 .5 .858 .1 k
.57708 .69903 m .55484 .69674 L .55043 .7318 L p F P
0 g
s
.183 .5 .842 .1 k
.5313 .73098 m .55043 .7318 L .55484 .69674 L p F P
0 g
s
.25 .5 .758 .1 k
.42162 .6324 m .39627 .63945 L .40939 .67538 L p F P
0 g
s
.25 .5 .758 .1 k
.40939 .67538 m .43222 .6692 L .42162 .6324 L p F P
0 g
s
.183 .5 .825 .1 k
.53221 .69575 m .50951 .69606 L .5121 .73124 L p F P
0 g
s
.183 .5 .825 .1 k
.5121 .73124 m .5313 .73098 L .53221 .69575 L p F P
0 g
s
.183 .5 .842 .1 k
.55484 .69674 m .53221 .69575 L .5313 .73098 L p F P
0 g
s
.217 .5 .775 .1 k
.45634 .66437 m .43222 .6692 L .44395 .70471 L p F P
0 g
s
.217 .5 .775 .1 k
.44395 .70471 m .46508 .70058 L .45634 .66437 L p F P
0 g
s
.383 .5 .792 .1 k
.46283 .47125 m .42747 .47661 L .43093 .51303 L p F P
0 g
s
.383 .5 .775 .1 k
.3982 .52023 m .43093 .51303 L .42747 .47661 L p F P
0 g
s
.317 .5 .758 .1 k
.38477 .60276 m .41232 .59491 L .40447 .55732 L p F P
0 g
s
.283 .5 .758 .1 k
.41232 .59491 m .38477 .60276 L .39627 .63945 L p F P
0 g
s
.35 .5 .775 .1 k
.43093 .51303 m .3982 .52023 L .40447 .55732 L p F P
0 g
s
.283 .5 .758 .1 k
.39627 .63945 m .42162 .6324 L .41232 .59491 L p F P
0 g
s
.217 .5 .892 .1 k
.63244 .67224 m .60895 .6667 L .59864 .70257 L p F P
0 g
s
.217 .5 .875 .1 k
.57708 .69903 m .59864 .70257 L .60895 .6667 L p F P
0 g
s
.317 .5 .892 .1 k
.66366 .56155 m .63337 .55386 L .62646 .59174 L p F P
0 g
s
.317 .5 .892 .1 k
.62646 .59174 m .65483 .59878 L .66366 .56155 L p F P
0 g
s
.25 .5 .892 .1 k
.60895 .6667 m .63244 .67224 L .64437 .63587 L p F P
0 g
s
.383 .5 .858 .1 k
.60831 .47374 m .57242 .4695 L .57081 .50632 L p F P
0 g
s
.383 .5 .858 .1 k
.57081 .50632 m .60543 .51032 L .60831 .47374 L p F P
0 g
s
.217 .5 .792 .1 k
.48141 .66098 m .45634 .66437 L .46508 .70058 L p F P
0 g
s
.217 .5 .792 .1 k
.46508 .70058 m .48703 .69768 L .48141 .66098 L p F P
0 g
s
.35 .5 .875 .1 k
.6389 .51651 m .60543 .51032 L .60154 .5481 L p F P
0 g
s
.35 .5 .875 .1 k
.60154 .5481 m .63337 .55386 L .6389 .51651 L p F P
0 g
s
.283 .5 .892 .1 k
.65483 .59878 m .62646 .59174 L .61828 .62956 L p F P
0 g
s
.283 .5 .892 .1 k
.61828 .62956 m .64437 .63587 L .65483 .59878 L p F P
0 g
s
.25 .5 .892 .1 k
.64437 .63587 m .61828 .62956 L .60895 .6667 L p F P
0 g
s
.383 .5 .808 .1 k
.49914 .46825 m .46283 .47125 L .46506 .50797 L p F P
0 g
s
.383 .5 .792 .1 k
.43093 .51303 m .46506 .50797 L .46283 .47125 L p F P
0 g
s
.25 .5 .775 .1 k
.44843 .62691 m .42162 .6324 L .43222 .6692 L p F P
0 g
s
.25 .5 .775 .1 k
.43222 .6692 m .45634 .66437 L .44843 .62691 L p F P
0 g
s
.217 .5 .875 .1 k
.60895 .6667 m .58433 .66256 L .57708 .69903 L p F P
0 g
s
.217 .5 .858 .1 k
.55484 .69674 m .57708 .69903 L .58433 .66256 L p F P
0 g
s
.35 .5 .775 .1 k
.40447 .55732 m .43562 .55062 L .43093 .51303 L p F P
0 g
s
.317 .5 .775 .1 k
.43562 .55062 m .40447 .55732 L .41232 .59491 L p F P
0 g
s
.383 .5 .842 .1 k
.57242 .4695 m .53585 .46766 L .53552 .50458 L p F P
0 g
s
.383 .5 .842 .1 k
.53552 .50458 m .57081 .50632 L .57242 .4695 L p F P
0 g
s
.217 .5 .808 .1 k
.5071 .65909 m .48141 .66098 L .48703 .69768 L p F P
0 g
s
.217 .5 .808 .1 k
.48703 .69768 m .50951 .69606 L .5071 .65909 L p F P
0 g
s
.35 .5 .792 .1 k
.46506 .50797 m .43093 .51303 L .43562 .55062 L p F P
0 g
s
.383 .5 .825 .1 k
.53585 .46766 m .49914 .46825 L .50009 .50513 L p F P
0 g
s
.383 .5 .808 .1 k
.46506 .50797 m .50009 .50513 L .49914 .46825 L p F P
0 g
s
.25 .5 .875 .1 k
.58433 .66256 m .60895 .6667 L .61828 .62956 L p F P
0 g
s
.217 .5 .858 .1 k
.58433 .66256 m .55892 .65988 L .55484 .69674 L p F P
0 g
s
.217 .5 .842 .1 k
.53221 .69575 m .55484 .69674 L .55892 .65988 L p F P
0 g
s
.383 .5 .825 .1 k
.50009 .50513 m .53552 .50458 L .53585 .46766 L p F P
0 g
s
.283 .5 .775 .1 k
.44148 .58878 m .41232 .59491 L .42162 .6324 L p F P
0 g
s
.283 .5 .775 .1 k
.42162 .6324 m .44843 .62691 L .44148 .58878 L p F P
0 g
s
.317 .5 .775 .1 k
.41232 .59491 m .44148 .58878 L .43562 .55062 L p F P
0 g
s
.217 .5 .825 .1 k
.53306 .65872 m .5071 .65909 L .50951 .69606 L p F P
0 g
s
.217 .5 .825 .1 k
.50951 .69606 m .53221 .69575 L .53306 .65872 L p F P
0 g
s
.217 .5 .842 .1 k
.55892 .65988 m .53306 .65872 L .53221 .69575 L p F P
0 g
s
.317 .5 .875 .1 k
.63337 .55386 m .60154 .5481 L .59667 .58648 L p F P
0 g
s
.317 .5 .875 .1 k
.59667 .58648 m .62646 .59174 L .63337 .55386 L p F P
0 g
s
.35 .5 .858 .1 k
.60543 .51032 m .57081 .50632 L .56861 .54438 L p F P
0 g
s
.35 .5 .858 .1 k
.56861 .54438 m .60154 .5481 L .60543 .51032 L p F P
0 g
s
.25 .5 .792 .1 k
.47632 .62304 m .44843 .62691 L .45634 .66437 L p F P
0 g
s
.25 .5 .792 .1 k
.45634 .66437 m .48141 .66098 L .47632 .62304 L p F P
0 g
s
.283 .5 .875 .1 k
.5909 .62484 m .61828 .62956 L .62646 .59174 L p F P
0 g
s
.25 .5 .875 .1 k
.61828 .62956 m .5909 .62484 L .58433 .66256 L p F P
0 g
s
.283 .5 .875 .1 k
.62646 .59174 m .59667 .58648 L .5909 .62484 L p F P
0 g
s
.25 .5 .858 .1 k
.55892 .65988 m .58433 .66256 L .5909 .62484 L p F P
0 g
s
.35 .5 .808 .1 k
.50009 .50513 m .46506 .50797 L .46808 .54591 L p F P
0 g
s
.35 .5 .792 .1 k
.43562 .55062 m .46808 .54591 L .46506 .50797 L p F P
0 g
s
.317 .5 .792 .1 k
.46808 .54591 m .43562 .55062 L .44148 .58878 L p F P
0 g
s
.25 .5 .808 .1 k
.50492 .62088 m .47632 .62304 L .48141 .66098 L p F P
0 g
s
.25 .5 .808 .1 k
.48141 .66098 m .5071 .65909 L .50492 .62088 L p F P
0 g
s
.283 .5 .792 .1 k
.47185 .58448 m .44148 .58878 L .44843 .62691 L p F P
0 g
s
.283 .5 .792 .1 k
.44843 .62691 m .47632 .62304 L .47185 .58448 L p F P
0 g
s
.35 .5 .842 .1 k
.57081 .50632 m .53552 .50458 L .53506 .54276 L p F P
0 g
s
.35 .5 .842 .1 k
.53506 .54276 m .56861 .54438 L .57081 .50632 L p F P
0 g
s
.317 .5 .792 .1 k
.44148 .58878 m .47185 .58448 L .46808 .54591 L p F P
0 g
s
.25 .5 .858 .1 k
.5909 .62484 m .56262 .62179 L .55892 .65988 L p F P
0 g
s
.25 .5 .842 .1 k
.53306 .65872 m .55892 .65988 L .56262 .62179 L p F P
0 g
s
.317 .5 .858 .1 k
.60154 .5481 m .56861 .54438 L .56587 .58308 L p F P
0 g
s
.317 .5 .858 .1 k
.56587 .58308 m .59667 .58648 L .60154 .5481 L p F P
0 g
s
.35 .5 .825 .1 k
.53552 .50458 m .50009 .50513 L .50139 .54327 L p F P
0 g
s
.35 .5 .808 .1 k
.46808 .54591 m .50139 .54327 L .50009 .50513 L p F P
0 g
s
.35 .5 .825 .1 k
.50139 .54327 m .53506 .54276 L .53552 .50458 L p F P
0 g
s
.25 .5 .825 .1 k
.53382 .62046 m .50492 .62088 L .5071 .65909 L p F P
0 g
s
.25 .5 .825 .1 k
.5071 .65909 m .53306 .65872 L .53382 .62046 L p F P
0 g
s
.283 .5 .858 .1 k
.56262 .62179 m .5909 .62484 L .59667 .58648 L p F P
0 g
s
.25 .5 .842 .1 k
.56262 .62179 m .53382 .62046 L .53306 .65872 L p F P
0 g
s
.283 .5 .858 .1 k
.59667 .58648 m .56587 .58308 L .56262 .62179 L p F P
0 g
s
.317 .5 .808 .1 k
.50139 .54327 m .46808 .54591 L .47185 .58448 L p F P
0 g
s
.283 .5 .808 .1 k
.503 .58207 m .47185 .58448 L .47632 .62304 L p F P
0 g
s
.283 .5 .808 .1 k
.47632 .62304 m .50492 .62088 L .503 .58207 L p F P
0 g
s
.317 .5 .842 .1 k
.56861 .54438 m .53506 .54276 L .53449 .5816 L p F P
0 g
s
.317 .5 .842 .1 k
.53449 .5816 m .56587 .58308 L .56861 .54438 L p F P
0 g
s
.317 .5 .808 .1 k
.47185 .58448 m .503 .58207 L .50139 .54327 L p F P
0 g
s
.283 .5 .842 .1 k
.53382 .62046 m .56262 .62179 L .56587 .58308 L p F P
0 g
s
.317 .5 .825 .1 k
.53506 .54276 m .50139 .54327 L .503 .58207 L p F P
0 g
s
.283 .5 .825 .1 k
.53449 .5816 m .503 .58207 L .50492 .62088 L p F P
0 g
s
.283 .5 .825 .1 k
.50492 .62088 m .53382 .62046 L .53449 .5816 L p F P
0 g
s
.317 .5 .825 .1 k
.503 .58207 m .53449 .5816 L .53506 .54276 L p F P
0 g
s
.283 .5 .842 .1 k
.56587 .58308 m .53449 .5816 L .53382 .62046 L p F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{265.312, 287.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 264.312}, {286.938, 0}} -> {0.0486402, -4.72903, \
0.00324458, 0.00324458}}],

Cell[OutputFormData["\<\
Graphics3D[{{CMYKColor[0.016666666666666666, 0.5, 0.008333333333333333, 0.1], \

   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.10395584540887964, \
0.010926199633097178, 0.9945218953682733}, 
     {0.10452846326765346, 0., 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.025, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.10224426555364696, \
0.021732689536559876, 0.9945218953682733}, 
     {0.10395584540887964, 0.010926199633097178, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.09941247612902042, \
0.03230107154560236, 0.9945218953682733}, 
     {0.10224426555364696, 0.021732689536559876, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.09549150281252627, \
0.04251555625535745, 0.9945218953682733}, 
     {0.09941247612902042, 0.03230107154560236, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.075, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.09052430460833645, \
0.05226423163382672, 0.9945218953682733}, 
     {0.09549150281252627, 0.04251555625535745, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.0845653031794291, \
0.0614402891535222, 0.9945218953682733}, 
     {0.09052430460833645, 0.05226423163382672, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.07767978659246055, \
0.06994319400804459, 0.9945218953682733}, 
     {0.0845653031794291, 0.0614402891535222, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.125, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.06994319400804459, \
0.07767978659246053, 0.9945218953682733}, 
     {0.07767978659246055, 0.06994319400804459, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.0614402891535222, \
0.0845653031794291, 0.9945218953682733}, 
     {0.06994319400804459, 0.07767978659246053, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.05226423163382674, \
0.09052430460833644, 0.9945218953682733}, 
     {0.0614402891535222, 0.0845653031794291, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.175, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.042515556255357474, \
0.09549150281252627, 0.9945218953682733}, 
     {0.05226423163382674, 0.09052430460833644, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.03230107154560237, \
0.09941247612902042, 0.9945218953682733}, 
     {0.042515556255357474, 0.09549150281252627, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.021732689536559893, \
0.10224426555364696, 0.9945218953682733}, 
     {0.03230107154560237, 0.09941247612902042, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.225, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.0109261996330972, \
0.10395584540887964, 0.9945218953682733}, 
     {0.021732689536559893, 0.10224426555364696, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {6.40031101364287*^-18, \
0.10452846326765346, 0.9945218953682733}, 
     {0.0109261996330972, 0.10395584540887964, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.010926199633097164, \
0.10395584540887966, 0.9945218953682733}, 
     {6.40031101364287*^-18, 0.10452846326765346, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.275, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.021732689536559855, \
0.10224426555364696, 0.9945218953682733}, 
     {-0.010926199633097164, 0.10395584540887966, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.032301071545602356, \
0.09941247612902043, 0.9945218953682733}, 
     {-0.021732689536559855, 0.10224426555364696, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.04251555625535744, \
0.09549150281252629, 0.9945218953682733}, 
     {-0.032301071545602356, 0.09941247612902043, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.325, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.05226423163382671, \
0.09052430460833645, 0.9945218953682733}, 
     {-0.04251555625535744, 0.09549150281252629, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.06144028915352218, \
0.0845653031794291, 0.9945218953682733}, 
     {-0.05226423163382671, 0.09052430460833645, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.06994319400804457, \
0.07767978659246057, 0.9945218953682733}, 
     {-0.06144028915352218, 0.0845653031794291, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.375, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.07767978659246053, \
0.0699431940080446, 0.9945218953682733}, 
     {-0.06994319400804457, 0.07767978659246057, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.08456530317942909, \
0.06144028915352221, 0.9945218953682733}, 
     {-0.07767978659246053, 0.0699431940080446, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.09052430460833644, \
0.05226423163382676, 0.9945218953682733}, 
     {-0.08456530317942909, 0.06144028915352221, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.425, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.09549150281252626, \
0.04251555625535748, 0.9945218953682733}, 
     {-0.09052430460833644, 0.05226423163382676, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.09941247612902042, \
0.032301071545602376, 0.9945218953682733}, 
     {-0.09549150281252626, 0.04251555625535748, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.10224426555364696, \
0.02173268953655992, 0.9945218953682733}, 
     {-0.09941247612902042, 0.032301071545602376, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.475, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.10395584540887964, \
0.010926199633097208, 0.9945218953682733}, 
     {-0.10224426555364696, 0.02173268953655992, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.10452846326765346, \
1.280062202728574*^-17, 0.9945218953682733}, 
     {-0.10395584540887964, 0.010926199633097208, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.10395584540887966, \
-0.010926199633097137, 0.9945218953682733}, 
     {-0.10452846326765346, 1.280062202728574*^-17, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.525, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.10224426555364696, \
-0.02173268953655985, 0.9945218953682733}, 
     {-0.10395584540887966, -0.010926199633097137, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.09941247612902043, \
-0.032301071545602356, 0.9945218953682733}, 
     {-0.10224426555364696, -0.02173268953655985, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.09549150281252629, \
-0.04251555625535742, 0.9945218953682733}, 
     {-0.09941247612902043, -0.032301071545602356, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.575, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.09052430460833646, \
-0.0522642316338267, 0.9945218953682733}, 
     {-0.09549150281252629, -0.04251555625535742, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.0845653031794291, \
-0.06144028915352218, 0.9945218953682733}, 
     {-0.09052430460833646, -0.0522642316338267, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.07767978659246058, \
-0.06994319400804457, 0.9945218953682733}, 
     {-0.0845653031794291, -0.06144028915352218, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.625, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.06994319400804462, \
-0.07767978659246053, 0.9945218953682733}, 
     {-0.07767978659246058, -0.06994319400804457, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.06144028915352221, \
-0.08456530317942909, 0.9945218953682733}, 
     {-0.06994319400804462, -0.07767978659246053, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.05226423163382678, \
-0.09052430460833642, 0.9945218953682733}, 
     {-0.06144028915352221, -0.08456530317942909, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.675, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.04251555625535753, \
-0.09549150281252623, 0.9945218953682733}, 
     {-0.05226423163382678, -0.09052430460833642, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.03230107154560238, \
-0.09941247612902042, 0.9945218953682733}, 
     {-0.04251555625535753, -0.09549150281252623, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.021732689536559928, \
-0.10224426555364696, 0.9945218953682733}, 
     {-0.03230107154560238, -0.09941247612902042, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.725, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-0.01092619963309726, \
-0.10395584540887964, 0.9945218953682733}, 
     {-0.021732689536559928, -0.10224426555364696, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {-1.9200933040928608*^-17, \
-0.10452846326765346, 0.9945218953682733}, 
     {-0.01092619963309726, -0.10395584540887964, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.01092619963309713, \
-0.10395584540887966, 0.9945218953682733}, 
     {-1.9200933040928608*^-17, -0.10452846326765346, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.775, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.0217326895365598, \
-0.10224426555364698, 0.9945218953682733}, 
     {0.01092619963309713, -0.10395584540887966, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.03230107154560235, \
-0.09941247612902043, 0.9945218953682733}, 
     {0.0217326895365598, -0.10224426555364698, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.04251555625535741, \
-0.09549150281252629, 0.9945218953682733}, 
     {0.03230107154560235, -0.09941247612902043, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.825, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.05226423163382666, \
-0.09052430460833649, 0.9945218953682733}, 
     {0.04251555625535741, -0.09549150281252629, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.061440289153522176, \
-0.0845653031794291, 0.9945218953682733}, 
     {0.05226423163382666, -0.09052430460833649, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.06994319400804455, \
-0.07767978659246058, 0.9945218953682733}, 
     {0.061440289153522176, -0.0845653031794291, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.875, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.07767978659246048, \
-0.06994319400804466, 0.9945218953682733}, 
     {0.06994319400804455, -0.07767978659246058, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.08456530317942909, \
-0.061440289153522225, 0.9945218953682733}, 
     {0.07767978659246048, -0.06994319400804466, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.09052430460833642, \
-0.05226423163382678, 0.9945218953682733}, 
     {0.08456530317942909, -0.061440289153522225, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.09549150281252623, \
-0.04251555625535753, 0.9945218953682733}, 
     {0.09052430460833642, -0.05226423163382678, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.09941247612902042, \
-0.03230107154560239, 0.9945218953682733}, 
     {0.09549150281252623, -0.04251555625535753, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.10224426555364696, \
-0.021732689536559935, 0.9945218953682733}, 
     {0.09941247612902042, -0.03230107154560239, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.975, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.10395584540887964, \
-0.010926199633097267, 0.9945218953682733}, 
     {0.10224426555364696, -0.021732689536559935, 0.9945218953682733}}]}, \
{CMYKColor[0.016666666666666666, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0., 0., 1.}, {0., 0., 1.}, {0.10452846326765346, \
-2.560124405457148*^-17, 0.9945218953682733}, 
     {0.10395584540887964, -0.010926199633097267, 0.9945218953682733}}]}, \
{CMYKColor[0.05, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.10452846326765346, 0., 0.9945218953682733}, \
{0.10395584540887964, 0.010926199633097178, 0.9945218953682733}, 
     {0.2067727288213004, 0.021732689536559876, 0.9781476007338057}, \
{0.20791169081775931, 0., 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.025, 0.1], Polygon[{{0.10395584540887964, \
0.010926199633097178, 0.9945218953682733}, 
     {0.10224426555364696, 0.021732689536559876, 0.9945218953682733}, \
{0.2033683215379001, 0.043227271178699546, 0.9781476007338057}, 
     {0.2067727288213004, 0.021732689536559876, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.10224426555364696, 0.021732689536559876, 0.9945218953682733}, \
{0.09941247612902042, 0.03230107154560236, 0.9945218953682733}, 
     {0.19773576836617324, 0.06424824579191733, 0.9781476007338057}, \
{0.2033683215379001, 0.043227271178699546, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.058333333333333334, 0.1], \
Polygon[{{0.09941247612902042, 0.03230107154560236, 0.9945218953682733}, 
     {0.09549150281252627, 0.04251555625535745, 0.9945218953682733}, \
{0.18993678073735687, 0.08456530317942909, 0.9781476007338057}, 
     {0.19773576836617324, 0.06424824579191733, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.075, 0.1], 
   Polygon[{{0.09549150281252627, 0.04251555625535745, 0.9945218953682733}, \
{0.09052430460833645, 0.05226423163382672, 0.9945218953682733}, 
     {0.1800568059919554, 0.10395584540887964, 0.9781476007338057}, \
{0.18993678073735687, 0.08456530317942909, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.09166666666666666, 0.1], \
Polygon[{{0.09052430460833645, 0.05226423163382672, 0.9945218953682733}, 
     {0.0845653031794291, 0.0614402891535222, 0.9945218953682733}, \
{0.168204091200797, 0.12220742564187133, 0.9781476007338057}, 
     {0.1800568059919554, 0.10395584540887964, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.0845653031794291, 0.0614402891535222, 0.9945218953682733}, \
{0.07767978659246055, 0.06994319400804459, 0.9945218953682733}, 
     {0.15450849718747373, 0.13912007574598273, 0.9781476007338057}, \
{0.168204091200797, 0.12220742564187133, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.125, 0.1], Polygon[{{0.07767978659246055, \
0.06994319400804459, 0.9945218953682733}, 
     {0.06994319400804459, 0.07767978659246053, 0.9945218953682733}, \
{0.13912007574598276, 0.15450849718747367, 0.9781476007338057}, 
     {0.15450849718747373, 0.13912007574598273, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.06994319400804459, 0.07767978659246053, 0.9945218953682733}, \
{0.0614402891535222, 0.0845653031794291, 0.9945218953682733}, 
     {0.12220742564187133, 0.168204091200797, 0.9781476007338057}, \
{0.13912007574598276, 0.15450849718747367, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.15833333333333333, 0.1], \
Polygon[{{0.0614402891535222, 0.0845653031794291, 0.9945218953682733}, 
     {0.05226423163382674, 0.09052430460833644, 0.9945218953682733}, \
{0.10395584540887969, 0.18005680599195537, 0.9781476007338057}, 
     {0.12220742564187133, 0.168204091200797, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.175, 0.1], 
   Polygon[{{0.05226423163382674, 0.09052430460833644, 0.9945218953682733}, \
{0.042515556255357474, 0.09549150281252627, 0.9945218953682733}, 
     {0.08456530317942913, 0.18993678073735687, 0.9781476007338057}, \
{0.10395584540887969, 0.18005680599195537, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.19166666666666665, 0.1], \
Polygon[{{0.042515556255357474, 0.09549150281252627, 0.9945218953682733}, 
     {0.03230107154560237, 0.09941247612902042, 0.9945218953682733}, \
{0.06424824579191735, 0.19773576836617324, 0.9781476007338057}, 
     {0.08456530317942913, 0.18993678073735687, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.03230107154560237, 0.09941247612902042, 0.9945218953682733}, \
{0.021732689536559893, 0.10224426555364696, 0.9945218953682733}, 
     {0.043227271178699574, 0.20336832153790008, 0.9781476007338057}, \
{0.06424824579191735, 0.19773576836617324, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.225, 0.1], Polygon[{{0.021732689536559893, \
0.10224426555364696, 0.9945218953682733}, 
     {0.0109261996330972, 0.10395584540887964, 0.9945218953682733}, \
{0.021732689536559924, 0.2067727288213004, 0.9781476007338057}, 
     {0.043227271178699574, 0.20336832153790008, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.0109261996330972, 0.10395584540887964, 0.9945218953682733}, \
{6.40031101364287*^-18, 0.10452846326765346, 0.9945218953682733}, 
     {1.2730498880469083*^-17, 0.20791169081775931, 0.9781476007338057}, \
{0.021732689536559924, 0.2067727288213004, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.2583333333333333, 0.1], \
Polygon[{{6.40031101364287*^-18, 0.10452846326765346, 0.9945218953682733}, 
     {-0.010926199633097164, 0.10395584540887966, 0.9945218953682733}, \
{-0.02173268953655985, 0.20677272882130043, 0.9781476007338057}, 
     {1.2730498880469083*^-17, 0.20791169081775931, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.275, 0.1], 
   Polygon[{{-0.010926199633097164, 0.10395584540887966, 0.9945218953682733}, \
{-0.021732689536559855, 0.10224426555364696, 0.9945218953682733}, 
     {-0.043227271178699504, 0.2033683215379001, 0.9781476007338057}, \
{-0.02173268953655985, 0.20677272882130043, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.2916666666666667, 0.1], \
Polygon[{{-0.021732689536559855, 0.10224426555364696, 0.9945218953682733}, 
     {-0.032301071545602356, 0.09941247612902043, 0.9945218953682733}, \
{-0.06424824579191732, 0.19773576836617326, 0.9781476007338057}, 
     {-0.043227271178699504, 0.2033683215379001, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.032301071545602356, 0.09941247612902043, 0.9945218953682733}, \
{-0.04251555625535744, 0.09549150281252629, 0.9945218953682733}, 
     {-0.08456530317942906, 0.1899367807373569, 0.9781476007338057}, \
{-0.06424824579191732, 0.19773576836617326, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.325, 0.1], Polygon[{{-0.04251555625535744, \
0.09549150281252629, 0.9945218953682733}, 
     {-0.05226423163382671, 0.09052430460833645, 0.9945218953682733}, \
{-0.10395584540887962, 0.1800568059919554, 0.9781476007338057}, 
     {-0.08456530317942906, 0.1899367807373569, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.05226423163382671, 0.09052430460833645, 0.9945218953682733}, \
{-0.06144028915352218, 0.0845653031794291, 0.9945218953682733}, 
     {-0.1222074256418713, 0.168204091200797, 0.9781476007338057}, \
{-0.10395584540887962, 0.1800568059919554, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.35833333333333334, 0.1], \
Polygon[{{-0.06144028915352218, 0.0845653031794291, 0.9945218953682733}, 
     {-0.06994319400804457, 0.07767978659246057, 0.9945218953682733}, \
{-0.13912007574598267, 0.15450849718747375, 0.9781476007338057}, 
     {-0.1222074256418713, 0.168204091200797, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.375, 0.1], 
   Polygon[{{-0.06994319400804457, 0.07767978659246057, 0.9945218953682733}, \
{-0.07767978659246053, 0.0699431940080446, 0.9945218953682733}, 
     {-0.15450849718747364, 0.13912007574598279, 0.9781476007338057}, \
{-0.13912007574598267, 0.15450849718747375, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.39166666666666666, 0.1], \
Polygon[{{-0.07767978659246053, 0.0699431940080446, 0.9945218953682733}, 
     {-0.08456530317942909, 0.06144028915352221, 0.9945218953682733}, \
{-0.168204091200797, 0.12220742564187136, 0.9781476007338057}, 
     {-0.15450849718747364, 0.13912007574598279, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.08456530317942909, 0.06144028915352221, 0.9945218953682733}, \
{-0.09052430460833644, 0.05226423163382676, 0.9945218953682733}, 
     {-0.18005680599195534, 0.10395584540887973, 0.9781476007338057}, \
{-0.168204091200797, 0.12220742564187136, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.425, 0.1], Polygon[{{-0.09052430460833644, \
0.05226423163382676, 0.9945218953682733}, 
     {-0.09549150281252626, 0.04251555625535748, 0.9945218953682733}, \
{-0.18993678073735684, 0.08456530317942915, 0.9781476007338057}, 
     {-0.18005680599195534, 0.10395584540887973, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.09549150281252626, 0.04251555625535748, 0.9945218953682733}, \
{-0.09941247612902042, 0.032301071545602376, 0.9945218953682733}, 
     {-0.19773576836617324, 0.06424824579191736, 0.9781476007338057}, \
{-0.18993678073735684, 0.08456530317942915, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.4583333333333333, 0.1], \
Polygon[{{-0.09941247612902042, 0.032301071545602376, 0.9945218953682733}, 
     {-0.10224426555364696, 0.02173268953655992, 0.9945218953682733}, \
{-0.20336832153790008, 0.04322727117869963, 0.9781476007338057}, 
     {-0.19773576836617324, 0.06424824579191736, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.475, 0.1], 
   Polygon[{{-0.10224426555364696, 0.02173268953655992, 0.9945218953682733}, \
{-0.10395584540887964, 0.010926199633097208, 0.9945218953682733}, 
     {-0.2067727288213004, 0.021732689536559935, 0.9781476007338057}, \
{-0.20336832153790008, 0.04322727117869963, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.49166666666666664, 0.1], \
Polygon[{{-0.10395584540887964, 0.010926199633097208, 0.9945218953682733}, 
     {-0.10452846326765346, 1.280062202728574*^-17, 0.9945218953682733}, \
{-0.20791169081775931, 2.5460997760938166*^-17, 0.9781476007338057}, 
     {-0.2067727288213004, 0.021732689536559935, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.10452846326765346, 1.280062202728574*^-17, \
0.9945218953682733}, {-0.10395584540887966, -0.010926199633097137, \
0.9945218953682733}, 
     {-0.20677272882130043, -0.021732689536559793, 0.9781476007338057}, \
{-0.20791169081775931, 2.5460997760938166*^-17, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.525, 0.1], Polygon[{{-0.10395584540887966, \
-0.010926199633097137, 0.9945218953682733}, 
     {-0.10224426555364696, -0.02173268953655985, 0.9945218953682733}, \
{-0.2033683215379001, -0.04322727117869949, 0.9781476007338057}, 
     {-0.20677272882130043, -0.021732689536559793, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-0.10224426555364696, -0.02173268953655985, 0.9945218953682733}, \
{-0.09941247612902043, -0.032301071545602356, 0.9945218953682733}, 
     {-0.19773576836617326, -0.0642482457919173, 0.9781476007338057}, \
{-0.2033683215379001, -0.04322727117869949, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.5583333333333333, 0.1], \
Polygon[{{-0.09941247612902043, -0.032301071545602356, 0.9945218953682733}, 
     {-0.09549150281252629, -0.04251555625535742, 0.9945218953682733}, \
{-0.18993678073735693, -0.08456530317942902, 0.9781476007338057}, 
     {-0.19773576836617326, -0.0642482457919173, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.575, 0.1], 
   Polygon[{{-0.09549150281252629, -0.04251555625535742, 0.9945218953682733}, \
{-0.09052430460833646, -0.0522642316338267, 0.9945218953682733}, 
     {-0.18005680599195542, -0.1039558454088796, 0.9781476007338057}, \
{-0.18993678073735693, -0.08456530317942902, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.5916666666666667, 0.1], \
Polygon[{{-0.09052430460833646, -0.0522642316338267, 0.9945218953682733}, 
     {-0.0845653031794291, -0.06144028915352218, 0.9945218953682733}, \
{-0.16820409120079702, -0.1222074256418713, 0.9781476007338057}, 
     {-0.18005680599195542, -0.1039558454088796, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-0.0845653031794291, -0.06144028915352218, 0.9945218953682733}, \
{-0.07767978659246058, -0.06994319400804457, 0.9945218953682733}, 
     {-0.15450849718747375, -0.13912007574598267, 0.9781476007338057}, \
{-0.16820409120079702, -0.1222074256418713, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.625, 0.1], Polygon[{{-0.07767978659246058, \
-0.06994319400804457, 0.9945218953682733}, 
     {-0.06994319400804462, -0.07767978659246053, 0.9945218953682733}, \
{-0.13912007574598279, -0.15450849718747364, 0.9781476007338057}, 
     {-0.15450849718747375, -0.13912007574598267, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{-0.06994319400804462, -0.07767978659246053, 0.9945218953682733}, \
{-0.06144028915352221, -0.08456530317942909, 0.9945218953682733}, 
     {-0.12220742564187136, -0.168204091200797, 0.9781476007338057}, \
{-0.13912007574598279, -0.15450849718747364, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.6583333333333333, 0.1], \
Polygon[{{-0.06144028915352221, -0.08456530317942909, 0.9945218953682733}, 
     {-0.05226423163382678, -0.09052430460833642, 0.9945218953682733}, \
{-0.10395584540887975, -0.1800568059919553, 0.9781476007338057}, 
     {-0.12220742564187136, -0.168204091200797, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.675, 0.1], 
   Polygon[{{-0.05226423163382678, -0.09052430460833642, 0.9945218953682733}, \
{-0.04251555625535753, -0.09549150281252623, 0.9945218953682733}, 
     {-0.08456530317942923, -0.18993678073735681, 0.9781476007338057}, \
{-0.10395584540887975, -0.1800568059919553, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.6916666666666667, 0.1], \
Polygon[{{-0.04251555625535753, -0.09549150281252623, 0.9945218953682733}, 
     {-0.03230107154560238, -0.09941247612902042, 0.9945218953682733}, \
{-0.06424824579191736, -0.19773576836617324, 0.9781476007338057}, 
     {-0.08456530317942923, -0.18993678073735681, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.03230107154560238, -0.09941247612902042, 0.9945218953682733}, \
{-0.021732689536559928, -0.10224426555364696, 0.9945218953682733}, 
     {-0.04322727117869964, -0.20336832153790008, 0.9781476007338057}, \
{-0.06424824579191736, -0.19773576836617324, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.725, 0.1], Polygon[{{-0.021732689536559928, \
-0.10224426555364696, 0.9945218953682733}, 
     {-0.01092619963309726, -0.10395584540887964, 0.9945218953682733}, \
{-0.02173268953656004, -0.2067727288213004, 0.9781476007338057}, 
     {-0.04322727117869964, -0.20336832153790008, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.01092619963309726, -0.10395584540887964, 0.9945218953682733}, \
{-1.9200933040928608*^-17, -0.10452846326765346, 
      0.9945218953682733}, {-3.819149664140725*^-17, -0.20791169081775931, \
0.9781476007338057}, {-0.02173268953656004, -0.2067727288213004, 
      0.9781476007338057}}]}, {CMYKColor[0.05, 0.5, 0.7583333333333333, 0.1], \

   Polygon[{{-1.9200933040928608*^-17, -0.10452846326765346, \
0.9945218953682733}, {0.01092619963309713, -0.10395584540887966, \
0.9945218953682733}, 
     {0.02173268953655978, -0.20677272882130043, 0.9781476007338057}, \
{-3.819149664140725*^-17, -0.20791169081775931, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.775, 0.1], Polygon[{{0.01092619963309713, \
-0.10395584540887966, 0.9945218953682733}, 
     {0.0217326895365598, -0.10224426555364698, 0.9945218953682733}, \
{0.043227271178699386, -0.2033683215379001, 0.9781476007338057}, 
     {0.02173268953655978, -0.20677272882130043, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.0217326895365598, -0.10224426555364698, 0.9945218953682733}, \
{0.03230107154560235, -0.09941247612902043, 0.9945218953682733}, 
     {0.06424824579191729, -0.19773576836617326, 0.9781476007338057}, \
{0.043227271178699386, -0.2033683215379001, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.03230107154560235, -0.09941247612902043, 0.9945218953682733}, 
     {0.04251555625535741, -0.09549150281252629, 0.9945218953682733}, \
{0.08456530317942901, -0.18993678073735693, 0.9781476007338057}, 
     {0.06424824579191729, -0.19773576836617326, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.825, 0.1], 
   Polygon[{{0.04251555625535741, -0.09549150281252629, 0.9945218953682733}, \
{0.05226423163382666, -0.09052430460833649, 0.9945218953682733}, 
     {0.10395584540887952, -0.18005680599195545, 0.9781476007338057}, \
{0.08456530317942901, -0.18993678073735693, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.05226423163382666, -0.09052430460833649, 0.9945218953682733}, 
     {0.061440289153522176, -0.0845653031794291, 0.9945218953682733}, \
{0.12220742564187129, -0.16820409120079702, 0.9781476007338057}, 
     {0.10395584540887952, -0.18005680599195545, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.061440289153522176, -0.0845653031794291, 0.9945218953682733}, \
{0.06994319400804455, -0.07767978659246058, 0.9945218953682733}, 
     {0.13912007574598265, -0.15450849718747375, 0.9781476007338057}, \
{0.12220742564187129, -0.16820409120079702, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.875, 0.1], Polygon[{{0.06994319400804455, \
-0.07767978659246058, 0.9945218953682733}, 
     {0.07767978659246048, -0.06994319400804466, 0.9945218953682733}, \
{0.1545084971874736, -0.13912007574598287, 0.9781476007338057}, 
     {0.13912007574598265, -0.15450849718747375, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.07767978659246048, -0.06994319400804466, 0.9945218953682733}, \
{0.08456530317942909, -0.061440289153522225, 0.9945218953682733}, 
     {0.168204091200797, -0.12220742564187137, 0.9781476007338057}, \
{0.1545084971874736, -0.13912007574598287, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.08456530317942909, -0.061440289153522225, 0.9945218953682733}, 
     {0.09052430460833642, -0.05226423163382678, 0.9945218953682733}, \
{0.1800568059919553, -0.10395584540887975, 0.9781476007338057}, 
     {0.168204091200797, -0.12220742564187137, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.09052430460833642, -0.05226423163382678, 0.9945218953682733}, \
{0.09549150281252623, -0.04251555625535753, 0.9945218953682733}, 
     {0.18993678073735681, -0.08456530317942924, 0.9781476007338057}, \
{0.1800568059919553, -0.10395584540887975, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.09549150281252623, -0.04251555625535753, 0.9945218953682733}, 
     {0.09941247612902042, -0.03230107154560239, 0.9945218953682733}, \
{0.19773576836617324, -0.06424824579191737, 0.9781476007338057}, 
     {0.18993678073735681, -0.08456530317942924, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.09941247612902042, -0.03230107154560239, 0.9945218953682733}, \
{0.10224426555364696, -0.021732689536559935, 0.9945218953682733}, 
     {0.20336832153790008, -0.04322727117869966, 0.9781476007338057}, \
{0.19773576836617324, -0.06424824579191737, 0.9781476007338057}}]}, 
  {CMYKColor[0.05, 0.5, 0.975, 0.1], Polygon[{{0.10224426555364696, \
-0.021732689536559935, 0.9945218953682733}, 
     {0.10395584540887964, -0.010926199633097267, 0.9945218953682733}, \
{0.2067727288213004, -0.021732689536560053, 0.9781476007338057}, 
     {0.20336832153790008, -0.04322727117869966, 0.9781476007338057}}]}, \
{CMYKColor[0.05, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.10395584540887964, -0.010926199633097267, 0.9945218953682733}, \
{0.10452846326765346, -2.560124405457148*^-17, 0.9945218953682733}, 
     {0.20791169081775931, -5.092199552187633*^-17, 0.9781476007338057}, \
{0.2067727288213004, -0.021732689536560053, 0.9781476007338057}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.20791169081775931, 0., 0.9781476007338057}, 
     {0.2067727288213004, 0.021732689536559876, 0.9781476007338057}, \
{0.3073241669467797, 0.03230107154560236, 0.9510565162951535}, 
     {0.3090169943749474, 0., 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{0.2067727288213004, 0.021732689536559876, 0.9781476007338057}, \
{0.2033683215379001, 0.043227271178699546, 0.9781476007338057}, 
     {0.3022642316338267, 0.06424824579191733, 0.9510565162951535}, \
{0.3073241669467797, 0.03230107154560236, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.2033683215379001, 0.043227271178699546, 0.9781476007338057}, 
     {0.19773576836617324, 0.06424824579191733, 0.9781476007338057}, \
{0.2938926261462365, 0.09549150281252627, 0.9510565162951535}, 
     {0.3022642316338267, 0.06424824579191733, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.19773576836617324, 0.06424824579191733, 0.9781476007338057}, \
{0.18993678073735687, 0.08456530317942909, 0.9781476007338057}, 
     {0.28230107154560236, 0.12568853494543952, 0.9510565162951535}, \
{0.2938926261462365, 0.09549150281252627, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.075, 0.1], \
Polygon[{{0.18993678073735687, 0.08456530317942909, 0.9781476007338057}, 
     {0.1800568059919554, 0.10395584540887964, 0.9781476007338057}, \
{0.2676165673298174, 0.15450849718747367, 0.9510565162951535}, 
     {0.28230107154560236, 0.12568853494543952, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.1800568059919554, 0.10395584540887964, 0.9781476007338057}, \
{0.168204091200797, 0.12220742564187133, 0.9781476007338057}, 
     {0.24999999999999997, 0.1816356320013402, 0.9510565162951535}, \
{0.2676165673298174, 0.15450849718747367, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.168204091200797, 0.12220742564187133, 0.9781476007338057}, 
     {0.15450849718747373, 0.13912007574598273, 0.9781476007338057}, \
{0.22964438035431922, 0.2067727288213004, 0.9510565162951535}, 
     {0.24999999999999997, 0.1816356320013402, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{0.15450849718747373, 0.13912007574598273, 0.9781476007338057}, \
{0.13912007574598276, 0.15450849718747367, 0.9781476007338057}, 
     {0.20677272882130043, 0.22964438035431917, 0.9510565162951535}, \
{0.22964438035431922, 0.2067727288213004, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.13912007574598276, 0.15450849718747367, 0.9781476007338057}, 
     {0.12220742564187133, 0.168204091200797, 0.9781476007338057}, \
{0.1816356320013402, 0.24999999999999997, 0.9510565162951535}, 
     {0.20677272882130043, 0.22964438035431917, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.12220742564187133, 0.168204091200797, 0.9781476007338057}, \
{0.10395584540887969, 0.18005680599195537, 0.9781476007338057}, 
     {0.15450849718747373, 0.2676165673298174, 0.9510565162951535}, \
{0.1816356320013402, 0.24999999999999997, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.175, 0.1], \
Polygon[{{0.10395584540887969, 0.18005680599195537, 0.9781476007338057}, 
     {0.08456530317942913, 0.18993678073735687, 0.9781476007338057}, \
{0.12568853494543958, 0.28230107154560236, 0.9510565162951535}, 
     {0.15450849718747373, 0.2676165673298174, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.08456530317942913, 0.18993678073735687, 0.9781476007338057}, \
{0.06424824579191735, 0.19773576836617324, 0.9781476007338057}, 
     {0.09549150281252629, 0.2938926261462365, 0.9510565162951535}, \
{0.12568853494543958, 0.28230107154560236, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.06424824579191735, 0.19773576836617324, 0.9781476007338057}, 
     {0.043227271178699574, 0.20336832153790008, 0.9781476007338057}, \
{0.06424824579191737, 0.3022642316338267, 0.9510565162951535}, 
     {0.09549150281252629, 0.2938926261462365, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{0.043227271178699574, 0.20336832153790008, 0.9781476007338057}, \
{0.021732689536559924, 0.2067727288213004, 0.9781476007338057}, 
     {0.03230107154560243, 0.3073241669467797, 0.9510565162951535}, \
{0.06424824579191737, 0.3022642316338267, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.021732689536559924, 0.2067727288213004, 0.9781476007338057}, 
     {1.2730498880469083*^-17, 0.20791169081775931, 0.9781476007338057}, \
{1.892120873753272*^-17, 0.3090169943749474, 0.9510565162951535}, 
     {0.03230107154560243, 0.3073241669467797, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.2730498880469083*^-17, 0.20791169081775931, \
0.9781476007338057}, {-0.02173268953655985, 0.20677272882130043, \
0.9781476007338057}, 
     {-0.03230107154560233, 0.3073241669467798, 0.9510565162951535}, \
{1.892120873753272*^-17, 0.3090169943749474, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.275, 0.1], \
Polygon[{{-0.02173268953655985, 0.20677272882130043, 0.9781476007338057}, 
     {-0.043227271178699504, 0.2033683215379001, 0.9781476007338057}, \
{-0.06424824579191728, 0.3022642316338267, 0.9510565162951535}, 
     {-0.03230107154560233, 0.3073241669467798, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.043227271178699504, 0.2033683215379001, 0.9781476007338057}, \
{-0.06424824579191732, 0.19773576836617326, 0.9781476007338057}, 
     {-0.09549150281252625, 0.29389262614623657, 0.9510565162951535}, \
{-0.06424824579191728, 0.3022642316338267, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.06424824579191732, 0.19773576836617326, 0.9781476007338057}, 
     {-0.08456530317942906, 0.1899367807373569, 0.9781476007338057}, \
{-0.1256885349454395, 0.28230107154560236, 0.9510565162951535}, 
     {-0.09549150281252625, 0.29389262614623657, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{-0.08456530317942906, 0.1899367807373569, 0.9781476007338057}, \
{-0.10395584540887962, 0.1800568059919554, 0.9781476007338057}, 
     {-0.15450849718747364, 0.2676165673298174, 0.9510565162951535}, \
{-0.1256885349454395, 0.28230107154560236, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.10395584540887962, 0.1800568059919554, 0.9781476007338057}, 
     {-0.1222074256418713, 0.168204091200797, 0.9781476007338057}, \
{-0.18163563200134017, 0.24999999999999997, 0.9510565162951535}, 
     {-0.15450849718747364, 0.2676165673298174, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.1222074256418713, 0.168204091200797, 0.9781476007338057}, \
{-0.13912007574598267, 0.15450849718747375, 0.9781476007338057}, 
     {-0.20677272882130032, 0.22964438035431928, 0.9510565162951535}, \
{-0.18163563200134017, 0.24999999999999997, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.375, 0.1], \
Polygon[{{-0.13912007574598267, 0.15450849718747375, 0.9781476007338057}, 
     {-0.15450849718747364, 0.13912007574598279, 0.9781476007338057}, \
{-0.22964438035431914, 0.20677272882130046, 0.9510565162951535}, 
     {-0.20677272882130032, 0.22964438035431928, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.15450849718747364, 0.13912007574598279, 0.9781476007338057}, \
{-0.168204091200797, 0.12220742564187136, 0.9781476007338057}, 
     {-0.24999999999999994, 0.18163563200134025, 0.9510565162951535}, \
{-0.22964438035431914, 0.20677272882130046, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.168204091200797, 0.12220742564187136, 0.9781476007338057}, 
     {-0.18005680599195534, 0.10395584540887973, 0.9781476007338057}, \
{-0.26761656732981737, 0.1545084971874738, 0.9510565162951535}, 
     {-0.24999999999999994, 0.18163563200134025, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{-0.18005680599195534, 0.10395584540887973, 0.9781476007338057}, \
{-0.18993678073735684, 0.08456530317942915, 0.9781476007338057}, 
     {-0.2823010715456023, 0.1256885349454396, 0.9510565162951535}, \
{-0.26761656732981737, 0.1545084971874738, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.18993678073735684, 0.08456530317942915, 0.9781476007338057}, 
     {-0.19773576836617324, 0.06424824579191736, 0.9781476007338057}, \
{-0.2938926261462365, 0.0954915028125263, 0.9510565162951535}, 
     {-0.2823010715456023, 0.1256885349454396, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.19773576836617324, 0.06424824579191736, 0.9781476007338057}, \
{-0.20336832153790008, 0.04322727117869963, 0.9781476007338057}, 
     {-0.3022642316338267, 0.06424824579191746, 0.9510565162951535}, \
{-0.2938926261462365, 0.0954915028125263, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.475, 0.1], \
Polygon[{{-0.20336832153790008, 0.04322727117869963, 0.9781476007338057}, 
     {-0.2067727288213004, 0.021732689536559935, 0.9781476007338057}, \
{-0.3073241669467797, 0.03230107154560245, 0.9510565162951535}, 
     {-0.3022642316338267, 0.06424824579191746, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.2067727288213004, 0.021732689536559935, 0.9781476007338057}, \
{-0.20791169081775931, 2.5460997760938166*^-17, 0.9781476007338057}, 
     {-0.3090169943749474, 3.784241747506544*^-17, 0.9510565162951535}, \
{-0.3073241669467797, 0.03230107154560245, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.20791169081775931, 2.5460997760938166*^-17, 0.9781476007338057}, \

     {-0.20677272882130043, -0.021732689536559793, 0.9781476007338057}, \
{-0.3073241669467798, -0.03230107154560224, 0.9510565162951535}, 
     {-0.3090169943749474, 3.784241747506544*^-17, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{-0.20677272882130043, -0.021732689536559793, \
0.9781476007338057}, {-0.2033683215379001, -0.04322727117869949, \
0.9781476007338057}, 
     {-0.3022642316338267, -0.06424824579191725, 0.9510565162951535}, \
{-0.3073241669467798, -0.03230107154560224, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.2033683215379001, -0.04322727117869949, 0.9781476007338057}, 
     {-0.19773576836617326, -0.0642482457919173, 0.9781476007338057}, \
{-0.29389262614623657, -0.09549150281252623, 0.9510565162951535}, 
     {-0.3022642316338267, -0.06424824579191725, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.19773576836617326, -0.0642482457919173, 0.9781476007338057}, \
{-0.18993678073735693, -0.08456530317942902, 0.9781476007338057}, 
     {-0.2823010715456024, -0.1256885349454394, 0.9510565162951535}, \
{-0.29389262614623657, -0.09549150281252623, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.575, 0.1], \
Polygon[{{-0.18993678073735693, -0.08456530317942902, 0.9781476007338057}, 
     {-0.18005680599195542, -0.1039558454088796, 0.9781476007338057}, \
{-0.2676165673298175, -0.15450849718747361, 0.9510565162951535}, 
     {-0.2823010715456024, -0.1256885349454394, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.18005680599195542, -0.1039558454088796, 0.9781476007338057}, \
{-0.16820409120079702, -0.1222074256418713, 0.9781476007338057}, 
     {-0.25, -0.18163563200134017, 0.9510565162951535}, {-0.2676165673298175, \
-0.15450849718747361, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.16820409120079702, -0.1222074256418713, 0.9781476007338057}, 
     {-0.15450849718747375, -0.13912007574598267, 0.9781476007338057}, \
{-0.2296443803543193, -0.20677272882130032, 0.9510565162951535}, 
     {-0.25, -0.18163563200134017, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{-0.15450849718747375, -0.13912007574598267, 0.9781476007338057}, \
{-0.13912007574598279, -0.15450849718747364, 0.9781476007338057}, 
     {-0.20677272882130052, -0.22964438035431914, 0.9510565162951535}, \
{-0.2296443803543193, -0.20677272882130032, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.13912007574598279, -0.15450849718747364, 0.9781476007338057}, 
     {-0.12220742564187136, -0.168204091200797, 0.9781476007338057}, \
{-0.18163563200134025, -0.24999999999999994, 0.9510565162951535}, 
     {-0.20677272882130052, -0.22964438035431914, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.12220742564187136, -0.168204091200797, 0.9781476007338057}, \
{-0.10395584540887975, -0.1800568059919553, 0.9781476007338057}, 
     {-0.15450849718747384, -0.26761656732981737, 0.9510565162951535}, \
{-0.18163563200134025, -0.24999999999999994, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.675, 0.1], \
Polygon[{{-0.10395584540887975, -0.1800568059919553, 0.9781476007338057}, 
     {-0.08456530317942923, -0.18993678073735681, 0.9781476007338057}, \
{-0.12568853494543974, -0.28230107154560224, 0.9510565162951535}, 
     {-0.15450849718747384, -0.26761656732981737, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.08456530317942923, -0.18993678073735681, 0.9781476007338057}, \
{-0.06424824579191736, -0.19773576836617324, 0.9781476007338057}, 
     {-0.09549150281252632, -0.2938926261462365, 0.9510565162951535}, \
{-0.12568853494543974, -0.28230107154560224, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.06424824579191736, -0.19773576836617324, 0.9781476007338057}, 
     {-0.04322727117869964, -0.20336832153790008, 0.9781476007338057}, \
{-0.06424824579191747, -0.3022642316338267, 0.9510565162951535}, 
     {-0.09549150281252632, -0.2938926261462365, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{-0.04322727117869964, -0.20336832153790008, 0.9781476007338057}, \
{-0.02173268953656004, -0.2067727288213004, 0.9781476007338057}, 
     {-0.032301071545602605, -0.3073241669467797, 0.9510565162951535}, \
{-0.06424824579191747, -0.3022642316338267, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.02173268953656004, -0.2067727288213004, 0.9781476007338057}, 
     {-3.819149664140725*^-17, -0.20791169081775931, 0.9781476007338057}, \
{-5.676362621259815*^-17, -0.3090169943749474, 0.9510565162951535}, 
     {-0.032301071545602605, -0.3073241669467797, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-3.819149664140725*^-17, -0.20791169081775931, \
0.9781476007338057}, {0.02173268953655978, -0.20677272882130043, \
0.9781476007338057}, 
     {0.03230107154560222, -0.3073241669467798, 0.9510565162951535}, \
{-5.676362621259815*^-17, -0.3090169943749474, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.775, 0.1], \
Polygon[{{0.02173268953655978, -0.20677272882130043, 0.9781476007338057}, 
     {0.043227271178699386, -0.2033683215379001, 0.9781476007338057}, \
{0.0642482457919171, -0.30226423163382676, 0.9510565162951535}, 
     {0.03230107154560222, -0.3073241669467798, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.043227271178699386, -0.2033683215379001, 0.9781476007338057}, \
{0.06424824579191729, -0.19773576836617326, 0.9781476007338057}, 
     {0.09549150281252622, -0.29389262614623657, 0.9510565162951535}, \
{0.0642482457919171, -0.30226423163382676, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.06424824579191729, -0.19773576836617326, 0.9781476007338057}, 
     {0.08456530317942901, -0.18993678073735693, 0.9781476007338057}, \
{0.1256885349454394, -0.2823010715456024, 0.9510565162951535}, 
     {0.09549150281252622, -0.29389262614623657, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{0.08456530317942901, -0.18993678073735693, 0.9781476007338057}, \
{0.10395584540887952, -0.18005680599195545, 0.9781476007338057}, 
     {0.1545084971874735, -0.26761656732981753, 0.9510565162951535}, \
{0.1256885349454394, -0.2823010715456024, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.10395584540887952, -0.18005680599195545, 0.9781476007338057}, 
     {0.12220742564187129, -0.16820409120079702, 0.9781476007338057}, \
{0.18163563200134014, -0.25, 0.9510565162951535}, 
     {0.1545084971874735, -0.26761656732981753, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.12220742564187129, -0.16820409120079702, 0.9781476007338057}, \
{0.13912007574598265, -0.15450849718747375, 0.9781476007338057}, 
     {0.2067727288213003, -0.2296443803543193, 0.9510565162951535}, \
{0.18163563200134014, -0.25, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.875, 0.1], \
Polygon[{{0.13912007574598265, -0.15450849718747375, 0.9781476007338057}, 
     {0.1545084971874736, -0.13912007574598287, 0.9781476007338057}, \
{0.22964438035431903, -0.2067727288213006, 0.9510565162951535}, 
     {0.2067727288213003, -0.2296443803543193, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.1545084971874736, -0.13912007574598287, 0.9781476007338057}, \
{0.168204091200797, -0.12220742564187137, 0.9781476007338057}, 
     {0.24999999999999994, -0.18163563200134028, 0.9510565162951535}, \
{0.22964438035431903, -0.2067727288213006, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.168204091200797, -0.12220742564187137, 0.9781476007338057}, 
     {0.1800568059919553, -0.10395584540887975, 0.9781476007338057}, \
{0.26761656732981737, -0.15450849718747384, 0.9510565162951535}, 
     {0.24999999999999994, -0.18163563200134028, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.1800568059919553, -0.10395584540887975, 0.9781476007338057}, \
{0.18993678073735681, -0.08456530317942924, 0.9781476007338057}, 
     {0.28230107154560224, -0.12568853494543977, 0.9510565162951535}, \
{0.26761656732981737, -0.15450849718747384, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.18993678073735681, -0.08456530317942924, 0.9781476007338057}, 
     {0.19773576836617324, -0.06424824579191737, 0.9781476007338057}, \
{0.2938926261462365, -0.09549150281252634, 0.9510565162951535}, 
     {0.28230107154560224, -0.12568853494543977, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.19773576836617324, -0.06424824579191737, 0.9781476007338057}, \
{0.20336832153790008, -0.04322727117869966, 0.9781476007338057}, 
     {0.3022642316338267, -0.0642482457919175, 0.9510565162951535}, \
{0.2938926261462365, -0.09549150281252634, 0.9510565162951535}}]}, 
  {CMYKColor[0.08333333333333333, 0.5, 0.975, 0.1], \
Polygon[{{0.20336832153790008, -0.04322727117869966, 0.9781476007338057}, 
     {0.2067727288213004, -0.021732689536560053, 0.9781476007338057}, \
{0.3073241669467797, -0.032301071545602626, 0.9510565162951535}, 
     {0.3022642316338267, -0.0642482457919175, 0.9510565162951535}}]}, \
{CMYKColor[0.08333333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.2067727288213004, -0.021732689536560053, 0.9781476007338057}, \
{0.20791169081775931, -5.092199552187633*^-17, 0.9781476007338057}, 
     {0.3090169943749474, -7.568483495013088*^-17, 0.9510565162951535}, \
{0.3073241669467797, -0.032301071545602626, 0.9510565162951535}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.3090169943749474, 0., 0.9510565162951535}, 
     {0.3073241669467797, 0.03230107154560236, 0.9510565162951535}, \
{0.4045084971874736, 0.04251555625535745, 0.9135454576426009}, 
     {0.40673664307580015, 0., 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{0.3073241669467797, 0.03230107154560236, 0.9510565162951535}, \
{0.3022642316338267, 0.06424824579191733, 0.9510565162951535}, 
     {0.3978484715551162, 0.08456530317942909, 0.9135454576426009}, \
{0.4045084971874736, 0.04251555625535745, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.3022642316338267, 0.06424824579191733, 0.9510565162951535}, 
     {0.2938926261462365, 0.09549150281252627, 0.9510565162951535}, \
{0.38682953481325577, 0.12568853494543952, 0.9135454576426009}, 
     {0.3978484715551162, 0.08456530317942909, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.2938926261462365, 0.09549150281252627, 0.9510565162951535}, \
{0.28230107154560236, 0.12568853494543952, 0.9510565162951535}, 
     {0.37157241273869707, 0.16543469682057085, 0.9135454576426009}, \
{0.38682953481325577, 0.12568853494543952, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.075, 0.1], \
Polygon[{{0.28230107154560236, 0.12568853494543952, 0.9510565162951535}, 
     {0.2676165673298174, 0.15450849718747367, 0.9510565162951535}, \
{0.35224426555364696, 0.20336832153790005, 0.9135454576426009}, 
     {0.37157241273869707, 0.16543469682057085, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.2676165673298174, 0.15450849718747367, 0.9510565162951535}, \
{0.24999999999999997, 0.1816356320013402, 0.9510565162951535}, 
     {0.3290568564833396, 0.2390738003669028, 0.9135454576426009}, \
{0.35224426555364696, 0.20336832153790005, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.24999999999999997, 0.1816356320013402, 0.9510565162951535}, 
     {0.22964438035431922, 0.2067727288213004, 0.9510565162951535}, \
{0.30226423163382676, 0.27215993660967663, 0.9135454576426009}, 
     {0.3290568564833396, 0.2390738003669028, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{0.22964438035431922, 0.2067727288213004, 0.9510565162951535}, \
{0.20677272882130043, 0.22964438035431917, 0.9510565162951535}, 
     {0.27215993660967663, 0.30226423163382665, 0.9135454576426009}, \
{0.30226423163382676, 0.27215993660967663, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.20677272882130043, 0.22964438035431917, 0.9510565162951535}, 
     {0.1816356320013402, 0.24999999999999997, 0.9510565162951535}, \
{0.2390738003669028, 0.3290568564833396, 0.9135454576426009}, 
     {0.27215993660967663, 0.30226423163382665, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.1816356320013402, 0.24999999999999997, 0.9510565162951535}, \
{0.15450849718747373, 0.2676165673298174, 0.9510565162951535}, 
     {0.20336832153790013, 0.3522442655536469, 0.9135454576426009}, \
{0.2390738003669028, 0.3290568564833396, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.175, 0.1], \
Polygon[{{0.15450849718747373, 0.2676165673298174, 0.9510565162951535}, 
     {0.12568853494543958, 0.28230107154560236, 0.9510565162951535}, \
{0.16543469682057094, 0.37157241273869707, 0.9135454576426009}, 
     {0.20336832153790013, 0.3522442655536469, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.12568853494543958, 0.28230107154560236, 0.9510565162951535}, \
{0.09549150281252629, 0.2938926261462365, 0.9510565162951535}, 
     {0.12568853494543955, 0.38682953481325577, 0.9135454576426009}, \
{0.16543469682057094, 0.37157241273869707, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.09549150281252629, 0.2938926261462365, 0.9510565162951535}, 
     {0.06424824579191737, 0.3022642316338267, 0.9510565162951535}, \
{0.08456530317942915, 0.39784847155511616, 0.9135454576426009}, 
     {0.12568853494543955, 0.38682953481325577, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{0.06424824579191737, 0.3022642316338267, 0.9510565162951535}, \
{0.03230107154560243, 0.3073241669467797, 0.9510565162951535}, 
     {0.042515556255357544, 0.4045084971874736, 0.9135454576426009}, \
{0.08456530317942915, 0.39784847155511616, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.03230107154560243, 0.3073241669467797, 0.9510565162951535}, 
     {1.892120873753272*^-17, 0.3090169943749474, 0.9510565162951535}, \
{2.4904613872150464*^-17, 0.40673664307580015, 0.9135454576426009}, 
     {0.042515556255357544, 0.4045084971874736, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.892120873753272*^-17, 0.3090169943749474, 0.9510565162951535}, \
{-0.03230107154560233, 0.3073241669467798, 0.9510565162951535}, 
     {-0.0425155562553574, 0.40450849718747367, 0.9135454576426009}, \
{2.4904613872150464*^-17, 0.40673664307580015, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.275, 0.1], \
Polygon[{{-0.03230107154560233, 0.3073241669467798, 0.9510565162951535}, 
     {-0.06424824579191728, 0.3022642316338267, 0.9510565162951535}, \
{-0.08456530317942901, 0.3978484715551162, 0.9135454576426009}, 
     {-0.0425155562553574, 0.40450849718747367, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.06424824579191728, 0.3022642316338267, 0.9510565162951535}, \
{-0.09549150281252625, 0.29389262614623657, 0.9510565162951535}, 
     {-0.1256885349454395, 0.3868295348132558, 0.9135454576426009}, \
{-0.08456530317942901, 0.3978484715551162, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.09549150281252625, 0.29389262614623657, 0.9510565162951535}, 
     {-0.1256885349454395, 0.28230107154560236, 0.9510565162951535}, \
{-0.1654346968205708, 0.3715724127386971, 0.9135454576426009}, 
     {-0.1256885349454395, 0.3868295348132558, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{-0.1256885349454395, 0.28230107154560236, 0.9510565162951535}, \
{-0.15450849718747364, 0.2676165673298174, 0.9510565162951535}, 
     {-0.2033683215379, 0.35224426555364696, 0.9135454576426009}, \
{-0.1654346968205708, 0.3715724127386971, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.15450849718747364, 0.2676165673298174, 0.9510565162951535}, 
     {-0.18163563200134017, 0.24999999999999997, 0.9510565162951535}, \
{-0.23907380036690273, 0.3290568564833396, 0.9135454576426009}, 
     {-0.2033683215379, 0.35224426555364696, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.18163563200134017, 0.24999999999999997, 0.9510565162951535}, \
{-0.20677272882130032, 0.22964438035431928, 0.9510565162951535}, 
     {-0.2721599366096765, 0.30226423163382676, 0.9135454576426009}, \
{-0.23907380036690273, 0.3290568564833396, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.375, 0.1], \
Polygon[{{-0.20677272882130032, 0.22964438035431928, 0.9510565162951535}, 
     {-0.22964438035431914, 0.20677272882130046, 0.9510565162951535}, \
{-0.3022642316338266, 0.2721599366096767, 0.9135454576426009}, 
     {-0.2721599366096765, 0.30226423163382676, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.22964438035431914, 0.20677272882130046, 0.9510565162951535}, \
{-0.24999999999999994, 0.18163563200134025, 0.9510565162951535}, 
     {-0.3290568564833396, 0.23907380036690284, 0.9135454576426009}, \
{-0.3022642316338266, 0.2721599366096767, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.24999999999999994, 0.18163563200134025, 0.9510565162951535}, 
     {-0.26761656732981737, 0.1545084971874738, 0.9510565162951535}, \
{-0.35224426555364685, 0.20336832153790022, 0.9135454576426009}, 
     {-0.3290568564833396, 0.23907380036690284, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{-0.26761656732981737, 0.1545084971874738, 0.9510565162951535}, \
{-0.2823010715456023, 0.1256885349454396, 0.9510565162951535}, 
     {-0.371572412738697, 0.16543469682057096, 0.9135454576426009}, \
{-0.35224426555364685, 0.20336832153790022, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.2823010715456023, 0.1256885349454396, 0.9510565162951535}, 
     {-0.2938926261462365, 0.0954915028125263, 0.9510565162951535}, \
{-0.38682953481325577, 0.12568853494543958, 0.9135454576426009}, 
     {-0.371572412738697, 0.16543469682057096, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.2938926261462365, 0.0954915028125263, 0.9510565162951535}, \
{-0.3022642316338267, 0.06424824579191746, 0.9510565162951535}, 
     {-0.39784847155511616, 0.08456530317942926, 0.9135454576426009}, \
{-0.38682953481325577, 0.12568853494543958, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.475, 0.1], \
Polygon[{{-0.3022642316338267, 0.06424824579191746, 0.9510565162951535}, 
     {-0.3073241669467797, 0.03230107154560245, 0.9510565162951535}, \
{-0.4045084971874736, 0.042515556255357564, 0.9135454576426009}, 
     {-0.39784847155511616, 0.08456530317942926, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.3073241669467797, 0.03230107154560245, 0.9510565162951535}, \
{-0.3090169943749474, 3.784241747506544*^-17, 0.9510565162951535}, 
     {-0.40673664307580015, 4.980922774430093*^-17, 0.9135454576426009}, \
{-0.4045084971874736, 0.042515556255357564, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.3090169943749474, 3.784241747506544*^-17, 0.9510565162951535}, 
     {-0.3073241669467798, -0.03230107154560224, 0.9510565162951535}, \
{-0.40450849718747367, -0.04251555625535729, 0.9135454576426009}, 
     {-0.40673664307580015, 4.980922774430093*^-17, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{-0.3073241669467798, -0.03230107154560224, 0.9510565162951535}, \
{-0.3022642316338267, -0.06424824579191725, 0.9510565162951535}, 
     {-0.3978484715551162, -0.08456530317942898, 0.9135454576426009}, \
{-0.40450849718747367, -0.04251555625535729, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.3022642316338267, -0.06424824579191725, 0.9510565162951535}, 
     {-0.29389262614623657, -0.09549150281252623, 0.9510565162951535}, \
{-0.3868295348132558, -0.12568853494543947, 0.9135454576426009}, 
     {-0.3978484715551162, -0.08456530317942898, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.29389262614623657, -0.09549150281252623, 0.9510565162951535}, \
{-0.2823010715456024, -0.1256885349454394, 0.9510565162951535}, 
     {-0.3715724127386971, -0.16543469682057071, 0.9135454576426009}, \
{-0.3868295348132558, -0.12568853494543947, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.575, 0.1], \
Polygon[{{-0.2823010715456024, -0.1256885349454394, 0.9510565162951535}, 
     {-0.2676165673298175, -0.15450849718747361, 0.9510565162951535}, \
{-0.352244265553647, -0.20336832153789997, 0.9135454576426009}, 
     {-0.3715724127386971, -0.16543469682057071, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.2676165673298175, -0.15450849718747361, 0.9510565162951535}, \
{-0.25, -0.18163563200134017, 0.9510565162951535}, 
     {-0.32905685648333965, -0.23907380036690273, 0.9135454576426009}, \
{-0.352244265553647, -0.20336832153789997, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.25, -0.18163563200134017, 0.9510565162951535}, 
     {-0.2296443803543193, -0.20677272882130032, 0.9510565162951535}, \
{-0.3022642316338268, -0.2721599366096765, 0.9135454576426009}, 
     {-0.32905685648333965, -0.23907380036690273, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{-0.2296443803543193, -0.20677272882130032, 0.9510565162951535}, \
{-0.20677272882130052, -0.22964438035431914, 0.9510565162951535}, 
     {-0.27215993660967674, -0.3022642316338266, 0.9135454576426009}, \
{-0.3022642316338268, -0.2721599366096765, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.20677272882130052, -0.22964438035431914, 0.9510565162951535}, 
     {-0.18163563200134025, -0.24999999999999994, 0.9510565162951535}, \
{-0.23907380036690284, -0.3290568564833396, 0.9135454576426009}, 
     {-0.27215993660967674, -0.3022642316338266, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.18163563200134025, -0.24999999999999994, 0.9510565162951535}, \
{-0.15450849718747384, -0.26761656732981737, 0.9510565162951535}, 
     {-0.20336832153790027, -0.3522442655536468, 0.9135454576426009}, \
{-0.23907380036690284, -0.3290568564833396, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.675, 0.1], \
Polygon[{{-0.15450849718747384, -0.26761656732981737, 0.9510565162951535}, 
     {-0.12568853494543974, -0.28230107154560224, 0.9510565162951535}, \
{-0.16543469682057113, -0.3715724127386969, 0.9135454576426009}, 
     {-0.20336832153790027, -0.3522442655536468, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.12568853494543974, -0.28230107154560224, 0.9510565162951535}, \
{-0.09549150281252632, -0.2938926261462365, 0.9510565162951535}, 
     {-0.12568853494543958, -0.38682953481325577, 0.9135454576426009}, \
{-0.16543469682057113, -0.3715724127386969, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.09549150281252632, -0.2938926261462365, 0.9510565162951535}, 
     {-0.06424824579191747, -0.3022642316338267, 0.9510565162951535}, \
{-0.08456530317942927, -0.39784847155511616, 0.9135454576426009}, 
     {-0.12568853494543958, -0.38682953481325577, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{-0.06424824579191747, -0.3022642316338267, 0.9510565162951535}, \
{-0.032301071545602605, -0.3073241669467797, 0.9510565162951535}, 
     {-0.042515556255357766, -0.4045084971874736, 0.9135454576426009}, \
{-0.08456530317942927, -0.39784847155511616, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.032301071545602605, -0.3073241669467797, 0.9510565162951535}, 
     {-5.676362621259815*^-17, -0.3090169943749474, 0.9510565162951535}, \
{-7.471384161645139*^-17, -0.40673664307580015, 0.9135454576426009}, 
     {-0.042515556255357766, -0.4045084971874736, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-5.676362621259815*^-17, -0.3090169943749474, \
0.9510565162951535}, {0.03230107154560222, -0.3073241669467798, \
0.9510565162951535}, 
     {0.04251555625535726, -0.40450849718747367, 0.9135454576426009}, \
{-7.471384161645139*^-17, -0.40673664307580015, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.775, 0.1], \
Polygon[{{0.03230107154560222, -0.3073241669467798, 0.9510565162951535}, 
     {0.0642482457919171, -0.30226423163382676, 0.9510565162951535}, \
{0.08456530317942879, -0.39784847155511627, 0.9135454576426009}, 
     {0.04251555625535726, -0.40450849718747367, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.0642482457919171, -0.30226423163382676, 0.9510565162951535}, \
{0.09549150281252622, -0.29389262614623657, 0.9510565162951535}, 
     {0.12568853494543947, -0.3868295348132558, 0.9135454576426009}, \
{0.08456530317942879, -0.39784847155511627, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.09549150281252622, -0.29389262614623657, 0.9510565162951535}, 
     {0.1256885349454394, -0.2823010715456024, 0.9510565162951535}, \
{0.1654346968205707, -0.3715724127386971, 0.9135454576426009}, 
     {0.12568853494543947, -0.3868295348132558, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{0.1256885349454394, -0.2823010715456024, 0.9510565162951535}, \
{0.1545084971874735, -0.26761656732981753, 0.9510565162951535}, 
     {0.2033683215378998, -0.3522442655536471, 0.9135454576426009}, \
{0.1654346968205707, -0.3715724127386971, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.1545084971874735, -0.26761656732981753, 0.9510565162951535}, 
     {0.18163563200134014, -0.25, 0.9510565162951535}, {0.2390738003669027, \
-0.32905685648333965, 0.9135454576426009}, 
     {0.2033683215378998, -0.3522442655536471, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.18163563200134014, -0.25, 0.9510565162951535}, \
{0.2067727288213003, -0.2296443803543193, 0.9510565162951535}, 
     {0.27215993660967647, -0.3022642316338268, 0.9135454576426009}, \
{0.2390738003669027, -0.32905685648333965, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.875, 0.1], \
Polygon[{{0.2067727288213003, -0.2296443803543193, 0.9510565162951535}, 
     {0.22964438035431903, -0.2067727288213006, 0.9510565162951535}, \
{0.3022642316338265, -0.27215993660967686, 0.9135454576426009}, 
     {0.27215993660967647, -0.3022642316338268, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.22964438035431903, -0.2067727288213006, 0.9510565162951535}, \
{0.24999999999999994, -0.18163563200134028, 0.9510565162951535}, 
     {0.3290568564833396, -0.23907380036690287, 0.9135454576426009}, \
{0.3022642316338265, -0.27215993660967686, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.24999999999999994, -0.18163563200134028, 0.9510565162951535}, 
     {0.26761656732981737, -0.15450849718747384, 0.9510565162951535}, \
{0.3522442655536468, -0.20336832153790027, 0.9135454576426009}, 
     {0.3290568564833396, -0.23907380036690287, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.26761656732981737, -0.15450849718747384, 0.9510565162951535}, \
{0.28230107154560224, -0.12568853494543977, 0.9510565162951535}, 
     {0.3715724127386969, -0.16543469682057116, 0.9135454576426009}, \
{0.3522442655536468, -0.20336832153790027, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.28230107154560224, -0.12568853494543977, 0.9510565162951535}, 
     {0.2938926261462365, -0.09549150281252634, 0.9510565162951535}, \
{0.38682953481325577, -0.1256885349454396, 0.9135454576426009}, 
     {0.3715724127386969, -0.16543469682057116, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.2938926261462365, -0.09549150281252634, 0.9510565162951535}, \
{0.3022642316338267, -0.0642482457919175, 0.9510565162951535}, 
     {0.39784847155511616, -0.08456530317942931, 0.9135454576426009}, \
{0.38682953481325577, -0.1256885349454396, 0.9135454576426009}}]}, 
  {CMYKColor[0.11666666666666667, 0.5, 0.975, 0.1], \
Polygon[{{0.3022642316338267, -0.0642482457919175, 0.9510565162951535}, 
     {0.3073241669467797, -0.032301071545602626, 0.9510565162951535}, \
{0.4045084971874736, -0.04251555625535779, 0.9135454576426009}, 
     {0.39784847155511616, -0.08456530317942931, 0.9135454576426009}}]}, \
{CMYKColor[0.11666666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.3073241669467797, -0.032301071545602626, 0.9510565162951535}, \
{0.3090169943749474, -7.568483495013088*^-17, 0.9510565162951535}, 
     {0.40673664307580015, -9.961845548860186*^-17, 0.9135454576426009}, \
{0.4045084971874736, -0.04251555625535779, 0.9135454576426009}}]}, 
  {CMYKColor[0.15, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.40673664307580015, 0., 0.9135454576426009}, 
     {0.4045084971874736, 0.04251555625535745, 0.9135454576426009}, \
{0.4972609476841366, 0.05226423163382672, 0.8660254037844387}, 
     {0.49999999999999994, 0., 0.8660254037844387}}]}, {CMYKColor[0.15, 0.5, \
0.025, 0.1], 
   Polygon[{{0.4045084971874736, 0.04251555625535745, 0.9135454576426009}, \
{0.3978484715551162, 0.08456530317942909, 0.9135454576426009}, 
     {0.4890738003669028, 0.10395584540887964, 0.8660254037844387}, \
{0.4972609476841366, 0.05226423163382672, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.3978484715551162, 0.08456530317942909, 0.9135454576426009}, 
     {0.38682953481325577, 0.12568853494543952, 0.9135454576426009}, \
{0.4755282581475767, 0.15450849718747367, 0.8660254037844387}, 
     {0.4890738003669028, 0.10395584540887964, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.38682953481325577, 0.12568853494543952, 0.9135454576426009}, \
{0.37157241273869707, 0.16543469682057085, 0.9135454576426009}, 
     {0.4567727288213004, 0.20336832153790005, 0.8660254037844387}, \
{0.4755282581475767, 0.15450849718747367, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.075, 0.1], Polygon[{{0.37157241273869707, \
0.16543469682057085, 0.9135454576426009}, 
     {0.35224426555364696, 0.20336832153790005, 0.9135454576426009}, \
{0.4330127018922193, 0.24999999999999994, 0.8660254037844387}, 
     {0.4567727288213004, 0.20336832153790005, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.35224426555364696, 0.20336832153790005, 0.9135454576426009}, \
{0.3290568564833396, 0.2390738003669028, 0.9135454576426009}, 
     {0.40450849718747367, 0.2938926261462365, 0.8660254037844387}, \
{0.4330127018922193, 0.24999999999999994, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.3290568564833396, 0.2390738003669028, 0.9135454576426009}, 
     {0.30226423163382676, 0.27215993660967663, 0.9135454576426009}, \
{0.3715724127386971, 0.334565303179429, 0.8660254037844387}, 
     {0.40450849718747367, 0.2938926261462365, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.125, 0.1], 
   Polygon[{{0.30226423163382676, 0.27215993660967663, 0.9135454576426009}, \
{0.27215993660967663, 0.30226423163382665, 0.9135454576426009}, 
     {0.33456530317942906, 0.371572412738697, 0.8660254037844387}, \
{0.3715724127386971, 0.334565303179429, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.27215993660967663, 0.30226423163382665, 0.9135454576426009}, 
     {0.2390738003669028, 0.3290568564833396, 0.9135454576426009}, \
{0.2938926261462365, 0.40450849718747367, 0.8660254037844387}, 
     {0.33456530317942906, 0.371572412738697, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.2390738003669028, 0.3290568564833396, 0.9135454576426009}, \
{0.20336832153790013, 0.3522442655536469, 0.9135454576426009}, 
     {0.25, 0.43301270189221924, 0.8660254037844387}, {0.2938926261462365, \
0.40450849718747367, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.175, 0.1], Polygon[{{0.20336832153790013, \
0.3522442655536469, 0.9135454576426009}, 
     {0.16543469682057094, 0.37157241273869707, 0.9135454576426009}, \
{0.20336832153790016, 0.4567727288213004, 0.8660254037844387}, 
     {0.25, 0.43301270189221924, 0.8660254037844387}}]}, {CMYKColor[0.15, \
0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.16543469682057094, 0.37157241273869707, 0.9135454576426009}, \
{0.12568853494543955, 0.38682953481325577, 0.9135454576426009}, 
     {0.1545084971874737, 0.4755282581475767, 0.8660254037844387}, \
{0.20336832153790016, 0.4567727288213004, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.12568853494543955, 0.38682953481325577, 0.9135454576426009}, 
     {0.08456530317942915, 0.39784847155511616, 0.9135454576426009}, \
{0.10395584540887971, 0.48907380036690273, 0.8660254037844387}, 
     {0.1545084971874737, 0.4755282581475767, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.225, 0.1], 
   Polygon[{{0.08456530317942915, 0.39784847155511616, 0.9135454576426009}, \
{0.042515556255357544, 0.4045084971874736, 0.9135454576426009}, 
     {0.05226423163382683, 0.4972609476841366, 0.8660254037844387}, \
{0.10395584540887971, 0.48907380036690273, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.042515556255357544, 0.4045084971874736, 0.9135454576426009}, 
     {2.4904613872150464*^-17, 0.40673664307580015, 0.9135454576426009}, \
{3.0615158845559425*^-17, 0.49999999999999994, 0.8660254037844387}, 
     {0.05226423163382683, 0.4972609476841366, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{2.4904613872150464*^-17, 0.40673664307580015, \
0.9135454576426009}, {-0.0425155562553574, 0.40450849718747367, \
0.9135454576426009}, 
     {-0.05226423163382666, 0.49726094768413664, 0.8660254037844387}, \
{3.0615158845559425*^-17, 0.49999999999999994, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.275, 0.1], Polygon[{{-0.0425155562553574, \
0.40450849718747367, 0.9135454576426009}, 
     {-0.08456530317942901, 0.3978484715551162, 0.9135454576426009}, \
{-0.10395584540887955, 0.4890738003669028, 0.8660254037844387}, 
     {-0.05226423163382666, 0.49726094768413664, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.08456530317942901, 0.3978484715551162, 0.9135454576426009}, \
{-0.1256885349454395, 0.3868295348132558, 0.9135454576426009}, 
     {-0.15450849718747364, 0.47552825814757677, 0.8660254037844387}, \
{-0.10395584540887955, 0.4890738003669028, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.1256885349454395, 0.3868295348132558, 0.9135454576426009}, 
     {-0.1654346968205708, 0.3715724127386971, 0.9135454576426009}, \
{-0.2033683215379, 0.45677272882130043, 0.8660254037844387}, 
     {-0.15450849718747364, 0.47552825814757677, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.325, 0.1], 
   Polygon[{{-0.1654346968205708, 0.3715724127386971, 0.9135454576426009}, \
{-0.2033683215379, 0.35224426555364696, 0.9135454576426009}, 
     {-0.24999999999999986, 0.4330127018922193, 0.8660254037844387}, \
{-0.2033683215379, 0.45677272882130043, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.3416666666666667, 0.1], Polygon[{{-0.2033683215379, \
0.35224426555364696, 0.9135454576426009}, 
     {-0.23907380036690273, 0.3290568564833396, 0.9135454576426009}, \
{-0.29389262614623646, 0.40450849718747367, 0.8660254037844387}, 
     {-0.24999999999999986, 0.4330127018922193, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.23907380036690273, 0.3290568564833396, 0.9135454576426009}, \
{-0.2721599366096765, 0.30226423163382676, 0.9135454576426009}, 
     {-0.3345653031794289, 0.3715724127386972, 0.8660254037844387}, \
{-0.29389262614623646, 0.40450849718747367, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.375, 0.1], Polygon[{{-0.2721599366096765, \
0.30226423163382676, 0.9135454576426009}, 
     {-0.3022642316338266, 0.2721599366096767, 0.9135454576426009}, \
{-0.37157241273869696, 0.3345653031794291, 0.8660254037844387}, 
     {-0.3345653031794289, 0.3715724127386972, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.3022642316338266, 0.2721599366096767, 0.9135454576426009}, \
{-0.3290568564833396, 0.23907380036690284, 0.9135454576426009}, 
     {-0.4045084971874736, 0.29389262614623657, 0.8660254037844387}, \
{-0.37157241273869696, 0.3345653031794291, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.3290568564833396, 0.23907380036690284, 0.9135454576426009}, 
     {-0.35224426555364685, 0.20336832153790022, 0.9135454576426009}, \
{-0.4330127018922192, 0.2500000000000001, 0.8660254037844387}, 
     {-0.4045084971874736, 0.29389262614623657, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.425, 0.1], 
   Polygon[{{-0.35224426555364685, 0.20336832153790022, 0.9135454576426009}, \
{-0.371572412738697, 0.16543469682057096, 0.9135454576426009}, 
     {-0.4567727288213003, 0.2033683215379002, 0.8660254037844387}, \
{-0.4330127018922192, 0.2500000000000001, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.371572412738697, 0.16543469682057096, 0.9135454576426009}, 
     {-0.38682953481325577, 0.12568853494543958, 0.9135454576426009}, \
{-0.4755282581475767, 0.15450849718747373, 0.8660254037844387}, 
     {-0.4567727288213003, 0.2033683215379002, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.38682953481325577, 0.12568853494543958, 0.9135454576426009}, \
{-0.39784847155511616, 0.08456530317942926, 0.9135454576426009}, 
     {-0.48907380036690273, 0.10395584540887985, 0.8660254037844387}, \
{-0.4755282581475767, 0.15450849718747373, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.475, 0.1], Polygon[{{-0.39784847155511616, \
0.08456530317942926, 0.9135454576426009}, 
     {-0.4045084971874736, 0.042515556255357564, 0.9135454576426009}, \
{-0.4972609476841366, 0.05226423163382686, 0.8660254037844387}, 
     {-0.48907380036690273, 0.10395584540887985, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.4045084971874736, 0.042515556255357564, 0.9135454576426009}, \
{-0.40673664307580015, 4.980922774430093*^-17, 0.9135454576426009}, 
     {-0.49999999999999994, 6.123031769111885*^-17, 0.8660254037844387}, \
{-0.4972609476841366, 0.05226423163382686, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.40673664307580015, 4.980922774430093*^-17, 0.9135454576426009}, 
     {-0.40450849718747367, -0.04251555625535729, 0.9135454576426009}, \
{-0.49726094768413664, -0.05226423163382652, 0.8660254037844387}, 
     {-0.49999999999999994, 6.123031769111885*^-17, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.525, 0.1], 
   Polygon[{{-0.40450849718747367, -0.04251555625535729, 0.9135454576426009}, \
{-0.3978484715551162, -0.08456530317942898, 0.9135454576426009}, 
     {-0.4890738003669028, -0.10395584540887952, 0.8660254037844387}, \
{-0.49726094768413664, -0.05226423163382652, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.3978484715551162, -0.08456530317942898, 0.9135454576426009}, 
     {-0.3868295348132558, -0.12568853494543947, 0.9135454576426009}, \
{-0.47552825814757677, -0.15450849718747361, 0.8660254037844387}, 
     {-0.4890738003669028, -0.10395584540887952, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.3868295348132558, -0.12568853494543947, 0.9135454576426009}, \
{-0.3715724127386971, -0.16543469682057071, 0.9135454576426009}, 
     {-0.4567727288213005, -0.20336832153789988, 0.8660254037844387}, \
{-0.47552825814757677, -0.15450849718747361, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.575, 0.1], Polygon[{{-0.3715724127386971, \
-0.16543469682057071, 0.9135454576426009}, 
     {-0.352244265553647, -0.20336832153789997, 0.9135454576426009}, \
{-0.43301270189221935, -0.24999999999999983, 0.8660254037844387}, 
     {-0.4567727288213005, -0.20336832153789988, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.352244265553647, -0.20336832153789997, 0.9135454576426009}, \
{-0.32905685648333965, -0.23907380036690273, 0.9135454576426009}, 
     {-0.4045084971874737, -0.29389262614623646, 0.8660254037844387}, \
{-0.43301270189221935, -0.24999999999999983, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.32905685648333965, -0.23907380036690273, 0.9135454576426009}, 
     {-0.3022642316338268, -0.2721599366096765, 0.9135454576426009}, \
{-0.37157241273869723, -0.3345653031794289, 0.8660254037844387}, 
     {-0.4045084971874737, -0.29389262614623646, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.625, 0.1], 
   Polygon[{{-0.3022642316338268, -0.2721599366096765, 0.9135454576426009}, \
{-0.27215993660967674, -0.3022642316338266, 0.9135454576426009}, 
     {-0.3345653031794292, -0.37157241273869696, 0.8660254037844387}, \
{-0.37157241273869723, -0.3345653031794289, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.27215993660967674, -0.3022642316338266, 0.9135454576426009}, 
     {-0.23907380036690284, -0.3290568564833396, 0.9135454576426009}, \
{-0.29389262614623657, -0.4045084971874736, 0.8660254037844387}, 
     {-0.3345653031794292, -0.37157241273869696, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.23907380036690284, -0.3290568564833396, 0.9135454576426009}, \
{-0.20336832153790027, -0.3522442655536468, 0.9135454576426009}, 
     {-0.2500000000000002, -0.43301270189221913, 0.8660254037844387}, \
{-0.29389262614623657, -0.4045084971874736, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.675, 0.1], Polygon[{{-0.20336832153790027, \
-0.3522442655536468, 0.9135454576426009}, 
     {-0.16543469682057113, -0.3715724127386969, 0.9135454576426009}, \
{-0.2033683215379004, -0.4567727288213002, 0.8660254037844387}, 
     {-0.2500000000000002, -0.43301270189221913, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.16543469682057113, -0.3715724127386969, 0.9135454576426009}, \
{-0.12568853494543958, -0.38682953481325577, 0.9135454576426009}, 
     {-0.15450849718747375, -0.4755282581475767, 0.8660254037844387}, \
{-0.2033683215379004, -0.4567727288213002, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.12568853494543958, -0.38682953481325577, 0.9135454576426009}, 
     {-0.08456530317942927, -0.39784847155511616, 0.9135454576426009}, \
{-0.10395584540887988, -0.48907380036690273, 0.8660254037844387}, 
     {-0.15450849718747375, -0.4755282581475767, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.725, 0.1], 
   Polygon[{{-0.08456530317942927, -0.39784847155511616, 0.9135454576426009}, \
{-0.042515556255357766, -0.4045084971874736, 0.9135454576426009}, 
     {-0.05226423163382711, -0.4972609476841366, 0.8660254037844387}, \
{-0.10395584540887988, -0.48907380036690273, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.042515556255357766, -0.4045084971874736, 0.9135454576426009}, 
     {-7.471384161645139*^-17, -0.40673664307580015, 0.9135454576426009}, \
{-9.184547653667828*^-17, -0.49999999999999994, 0.8660254037844387}, 
     {-0.05226423163382711, -0.4972609476841366, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-7.471384161645139*^-17, -0.40673664307580015, \
0.9135454576426009}, {0.04251555625535726, -0.40450849718747367, \
0.9135454576426009}, 
     {0.052264231633826486, -0.49726094768413664, 0.8660254037844387}, \
{-9.184547653667828*^-17, -0.49999999999999994, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.775, 0.1], Polygon[{{0.04251555625535726, \
-0.40450849718747367, 0.9135454576426009}, 
     {0.08456530317942879, -0.39784847155511627, 0.9135454576426009}, \
{0.10395584540887927, -0.48907380036690284, 0.8660254037844387}, 
     {0.052264231633826486, -0.49726094768413664, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.08456530317942879, -0.39784847155511627, 0.9135454576426009}, \
{0.12568853494543947, -0.3868295348132558, 0.9135454576426009}, 
     {0.1545084971874736, -0.47552825814757677, 0.8660254037844387}, \
{0.10395584540887927, -0.48907380036690284, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.12568853494543947, -0.3868295348132558, 0.9135454576426009}, 
     {0.1654346968205707, -0.3715724127386971, 0.9135454576426009}, \
{0.20336832153789985, -0.4567727288213005, 0.8660254037844387}, 
     {0.1545084971874736, -0.47552825814757677, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.825, 0.1], 
   Polygon[{{0.1654346968205707, -0.3715724127386971, 0.9135454576426009}, \
{0.2033683215378998, -0.3522442655536471, 0.9135454576426009}, 
     {0.24999999999999964, -0.43301270189221946, 0.8660254037844387}, \
{0.20336832153789985, -0.4567727288213005, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.2033683215378998, -0.3522442655536471, 0.9135454576426009}, 
     {0.2390738003669027, -0.32905685648333965, 0.9135454576426009}, \
{0.2938926261462364, -0.4045084971874737, 0.8660254037844387}, 
     {0.24999999999999964, -0.43301270189221946, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.2390738003669027, -0.32905685648333965, 0.9135454576426009}, \
{0.27215993660967647, -0.3022642316338268, 0.9135454576426009}, 
     {0.33456530317942884, -0.37157241273869723, 0.8660254037844387}, \
{0.2938926261462364, -0.4045084971874737, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.875, 0.1], Polygon[{{0.27215993660967647, \
-0.3022642316338268, 0.9135454576426009}, 
     {0.3022642316338265, -0.27215993660967686, 0.9135454576426009}, \
{0.3715724127386968, -0.33456530317942934, 0.8660254037844387}, 
     {0.33456530317942884, -0.37157241273869723, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.3022642316338265, -0.27215993660967686, 0.9135454576426009}, \
{0.3290568564833396, -0.23907380036690287, 0.9135454576426009}, 
     {0.4045084971874736, -0.2938926261462366, 0.8660254037844387}, \
{0.3715724127386968, -0.33456530317942934, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.3290568564833396, -0.23907380036690287, 0.9135454576426009}, 
     {0.3522442655536468, -0.20336832153790027, 0.9135454576426009}, \
{0.43301270189221913, -0.2500000000000002, 0.8660254037844387}, 
     {0.4045084971874736, -0.2938926261462366, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.3522442655536468, -0.20336832153790027, 0.9135454576426009}, \
{0.3715724127386969, -0.16543469682057116, 0.9135454576426009}, 
     {0.4567727288213002, -0.20336832153790044, 0.8660254037844387}, \
{0.43301270189221913, -0.2500000000000002, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.3715724127386969, -0.16543469682057116, 0.9135454576426009}, 
     {0.38682953481325577, -0.1256885349454396, 0.9135454576426009}, \
{0.4755282581475767, -0.15450849718747378, 0.8660254037844387}, 
     {0.4567727288213002, -0.20336832153790044, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.38682953481325577, -0.1256885349454396, 0.9135454576426009}, \
{0.39784847155511616, -0.08456530317942931, 0.9135454576426009}, 
     {0.48907380036690273, -0.10395584540887992, 0.8660254037844387}, \
{0.4755282581475767, -0.15450849718747378, 0.8660254037844387}}]}, 
  {CMYKColor[0.15, 0.5, 0.975, 0.1], Polygon[{{0.39784847155511616, \
-0.08456530317942931, 0.9135454576426009}, 
     {0.4045084971874736, -0.04251555625535779, 0.9135454576426009}, \
{0.4972609476841366, -0.052264231633827145, 0.8660254037844387}, 
     {0.48907380036690273, -0.10395584540887992, 0.8660254037844387}}]}, \
{CMYKColor[0.15, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.4045084971874736, -0.04251555625535779, 0.9135454576426009}, \
{0.40673664307580015, -9.961845548860186*^-17, 0.9135454576426009}, 
     {0.49999999999999994, -1.224606353822377*^-16, 0.8660254037844387}, \
{0.4972609476841366, -0.052264231633827145, 0.8660254037844387}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.49999999999999994, 0., 0.8660254037844387}, 
     {0.4972609476841366, 0.05226423163382672, 0.8660254037844387}, \
{0.5845653031794291, 0.0614402891535222, 0.8090169943749475}, 
     {0.5877852522924731, 0., 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.025, 0.1], 
   Polygon[{{0.4972609476841366, 0.05226423163382672, 0.8660254037844387}, \
{0.4890738003669028, 0.10395584540887964, 0.8660254037844387}, 
     {0.5749407342765973, 0.12220742564187133, 0.8090169943749475}, \
{0.5845653031794291, 0.0614402891535222, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.4890738003669028, 0.10395584540887964, 0.8660254037844387}, 
     {0.4755282581475767, 0.15450849718747367, 0.8660254037844387}, \
{0.5590169943749475, 0.1816356320013402, 0.8090169943749475}, 
     {0.5749407342765973, 0.12220742564187133, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.4755282581475767, 0.15450849718747367, 0.8660254037844387}, \
{0.4567727288213004, 0.20336832153790005, 0.8660254037844387}, 
     {0.536968547301099, 0.2390738003669028, 0.8090169943749475}, \
{0.5590169943749475, 0.1816356320013402, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.075, 0.1], \
Polygon[{{0.4567727288213004, 0.20336832153790005, 0.8660254037844387}, 
     {0.4330127018922193, 0.24999999999999994, 0.8660254037844387}, \
{0.5090369604551273, 0.2938926261462365, 0.8090169943749475}, 
     {0.536968547301099, 0.2390738003669028, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.4330127018922193, 0.24999999999999994, 0.8660254037844387}, \
{0.40450849718747367, 0.2938926261462365, 0.8660254037844387}, 
     {0.4755282581475768, 0.3454915028125263, 0.8090169943749475}, \
{0.5090369604551273, 0.2938926261462365, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.40450849718747367, 0.2938926261462365, 0.8660254037844387}, 
     {0.3715724127386971, 0.334565303179429, 0.8660254037844387}, \
{0.43680956873307614, 0.39330510227525695, 0.8090169943749475}, 
     {0.4755282581475768, 0.3454915028125263, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.125, 0.1], 
   Polygon[{{0.3715724127386971, 0.334565303179429, 0.8660254037844387}, \
{0.33456530317942906, 0.371572412738697, 0.8660254037844387}, 
     {0.393305102275257, 0.436809568733076, 0.8090169943749475}, \
{0.43680956873307614, 0.39330510227525695, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.33456530317942906, 0.371572412738697, 0.8660254037844387}, 
     {0.2938926261462365, 0.40450849718747367, 0.8660254037844387}, \
{0.3454915028125263, 0.4755282581475768, 0.8090169943749475}, 
     {0.393305102275257, 0.436809568733076, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.2938926261462365, 0.40450849718747367, 0.8660254037844387}, \
{0.25, 0.43301270189221924, 0.8660254037844387}, 
     {0.2938926261462366, 0.5090369604551271, 0.8090169943749475}, \
{0.3454915028125263, 0.4755282581475768, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.175, 0.1], Polygon[{{0.25, \
0.43301270189221924, 0.8660254037844387}, 
     {0.20336832153790016, 0.4567727288213004, 0.8660254037844387}, \
{0.23907380036690293, 0.536968547301099, 0.8090169943749475}, 
     {0.2938926261462366, 0.5090369604551271, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.20336832153790016, 0.4567727288213004, 0.8660254037844387}, \
{0.1545084971874737, 0.4755282581475767, 0.8660254037844387}, 
     {0.18163563200134025, 0.5590169943749475, 0.8090169943749475}, \
{0.23907380036690293, 0.536968547301099, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.1545084971874737, 0.4755282581475767, 0.8660254037844387}, 
     {0.10395584540887971, 0.48907380036690273, 0.8660254037844387}, \
{0.12220742564187141, 0.5749407342765972, 0.8090169943749475}, 
     {0.18163563200134025, 0.5590169943749475, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.225, 0.1], 
   Polygon[{{0.10395584540887971, 0.48907380036690273, 0.8660254037844387}, \
{0.05226423163382683, 0.4972609476841366, 0.8660254037844387}, 
     {0.06144028915352233, 0.5845653031794291, 0.8090169943749475}, \
{0.12220742564187141, 0.5749407342765972, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.05226423163382683, 0.4972609476841366, 0.8660254037844387}, 
     {3.0615158845559425*^-17, 0.49999999999999994, 0.8660254037844387}, \
{3.599027773202258*^-17, 0.5877852522924731, 0.8090169943749475}, 
     {0.06144028915352233, 0.5845653031794291, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{3.0615158845559425*^-17, 0.49999999999999994, \
0.8660254037844387}, {-0.05226423163382666, 0.49726094768413664, \
0.8660254037844387}, 
     {-0.06144028915352213, 0.5845653031794291, 0.8090169943749475}, \
{3.599027773202258*^-17, 0.5877852522924731, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.275, 0.1], \
Polygon[{{-0.05226423163382666, 0.49726094768413664, 0.8660254037844387}, 
     {-0.10395584540887955, 0.4890738003669028, 0.8660254037844387}, \
{-0.12220742564187122, 0.5749407342765973, 0.8090169943749475}, 
     {-0.06144028915352213, 0.5845653031794291, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.10395584540887955, 0.4890738003669028, 0.8660254037844387}, \
{-0.15450849718747364, 0.47552825814757677, 0.8660254037844387}, 
     {-0.18163563200134017, 0.5590169943749475, 0.8090169943749475}, \
{-0.12220742564187122, 0.5749407342765973, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.15450849718747364, 0.47552825814757677, 0.8660254037844387}, 
     {-0.2033683215379, 0.45677272882130043, 0.8660254037844387}, \
{-0.23907380036690273, 0.536968547301099, 0.8090169943749475}, 
     {-0.18163563200134017, 0.5590169943749475, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.325, 0.1], 
   Polygon[{{-0.2033683215379, 0.45677272882130043, 0.8660254037844387}, \
{-0.24999999999999986, 0.4330127018922193, 0.8660254037844387}, 
     {-0.29389262614623646, 0.5090369604551273, 0.8090169943749475}, \
{-0.23907380036690273, 0.536968547301099, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.24999999999999986, 0.4330127018922193, 0.8660254037844387}, 
     {-0.29389262614623646, 0.40450849718747367, 0.8660254037844387}, \
{-0.3454915028125262, 0.4755282581475768, 0.8090169943749475}, 
     {-0.29389262614623646, 0.5090369604551273, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.29389262614623646, 0.40450849718747367, 0.8660254037844387}, \
{-0.3345653031794289, 0.3715724127386972, 0.8660254037844387}, 
     {-0.39330510227525683, 0.43680956873307625, 0.8090169943749475}, \
{-0.3454915028125262, 0.4755282581475768, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.375, 0.1], \
Polygon[{{-0.3345653031794289, 0.3715724127386972, 0.8660254037844387}, 
     {-0.37157241273869696, 0.3345653031794291, 0.8660254037844387}, \
{-0.43680956873307597, 0.39330510227525706, 0.8090169943749475}, 
     {-0.39330510227525683, 0.43680956873307625, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.37157241273869696, 0.3345653031794291, 0.8660254037844387}, \
{-0.4045084971874736, 0.29389262614623657, 0.8660254037844387}, 
     {-0.47552825814757677, 0.3454915028125264, 0.8090169943749475}, \
{-0.43680956873307597, 0.39330510227525706, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.4045084971874736, 0.29389262614623657, 0.8660254037844387}, 
     {-0.4330127018922192, 0.2500000000000001, 0.8660254037844387}, \
{-0.5090369604551271, 0.2938926261462368, 0.8090169943749475}, 
     {-0.47552825814757677, 0.3454915028125264, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.425, 0.1], 
   Polygon[{{-0.4330127018922192, 0.2500000000000001, 0.8660254037844387}, \
{-0.4567727288213003, 0.2033683215379002, 0.8660254037844387}, 
     {-0.5369685473010989, 0.23907380036690296, 0.8090169943749475}, \
{-0.5090369604551271, 0.2938926261462368, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.4567727288213003, 0.2033683215379002, 0.8660254037844387}, 
     {-0.4755282581475767, 0.15450849718747373, 0.8660254037844387}, \
{-0.5590169943749475, 0.18163563200134028, 0.8090169943749475}, 
     {-0.5369685473010989, 0.23907380036690296, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.4755282581475767, 0.15450849718747373, 0.8660254037844387}, \
{-0.48907380036690273, 0.10395584540887985, 0.8660254037844387}, 
     {-0.5749407342765972, 0.12220742564187158, 0.8090169943749475}, \
{-0.5590169943749475, 0.18163563200134028, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.475, 0.1], \
Polygon[{{-0.48907380036690273, 0.10395584540887985, 0.8660254037844387}, 
     {-0.4972609476841366, 0.05226423163382686, 0.8660254037844387}, \
{-0.5845653031794291, 0.061440289153522364, 0.8090169943749475}, 
     {-0.5749407342765972, 0.12220742564187158, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.4972609476841366, 0.05226423163382686, 0.8660254037844387}, \
{-0.49999999999999994, 6.123031769111885*^-17, 0.8660254037844387}, 
     {-0.5877852522924731, 7.198055546404516*^-17, 0.8090169943749475}, \
{-0.5845653031794291, 0.061440289153522364, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.49999999999999994, 6.123031769111885*^-17, 0.8660254037844387}, 
     {-0.49726094768413664, -0.05226423163382652, 0.8660254037844387}, \
{-0.5845653031794291, -0.06144028915352196, 0.8090169943749475}, 
     {-0.5877852522924731, 7.198055546404516*^-17, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.525, 0.1], 
   Polygon[{{-0.49726094768413664, -0.05226423163382652, 0.8660254037844387}, \
{-0.4890738003669028, -0.10395584540887952, 0.8660254037844387}, 
     {-0.5749407342765973, -0.12220742564187118, 0.8090169943749475}, \
{-0.5845653031794291, -0.06144028915352196, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.4890738003669028, -0.10395584540887952, 0.8660254037844387}, 
     {-0.47552825814757677, -0.15450849718747361, 0.8660254037844387}, \
{-0.5590169943749475, -0.18163563200134014, 0.8090169943749475}, 
     {-0.5749407342765973, -0.12220742564187118, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.47552825814757677, -0.15450849718747361, 0.8660254037844387}, \
{-0.4567727288213005, -0.20336832153789988, 0.8660254037844387}, 
     {-0.5369685473010991, -0.2390738003669026, 0.8090169943749475}, \
{-0.5590169943749475, -0.18163563200134014, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.575, 0.1], \
Polygon[{{-0.4567727288213005, -0.20336832153789988, 0.8660254037844387}, 
     {-0.43301270189221935, -0.24999999999999983, 0.8660254037844387}, \
{-0.5090369604551273, -0.2938926261462364, 0.8090169943749475}, 
     {-0.5369685473010991, -0.2390738003669026, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.43301270189221935, -0.24999999999999983, 0.8660254037844387}, \
{-0.4045084971874737, -0.29389262614623646, 0.8660254037844387}, 
     {-0.4755282581475769, -0.3454915028125262, 0.8090169943749475}, \
{-0.5090369604551273, -0.2938926261462364, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.4045084971874737, -0.29389262614623646, 0.8660254037844387}, 
     {-0.37157241273869723, -0.3345653031794289, 0.8660254037844387}, \
{-0.4368095687330763, -0.39330510227525683, 0.8090169943749475}, 
     {-0.4755282581475769, -0.3454915028125262, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.625, 0.1], 
   Polygon[{{-0.37157241273869723, -0.3345653031794289, 0.8660254037844387}, \
{-0.3345653031794292, -0.37157241273869696, 0.8660254037844387}, 
     {-0.39330510227525717, -0.43680956873307597, 0.8090169943749475}, \
{-0.4368095687330763, -0.39330510227525683, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.3345653031794292, -0.37157241273869696, 0.8660254037844387}, 
     {-0.29389262614623657, -0.4045084971874736, 0.8660254037844387}, \
{-0.3454915028125264, -0.47552825814757677, 0.8090169943749475}, 
     {-0.39330510227525717, -0.43680956873307597, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.29389262614623657, -0.4045084971874736, 0.8660254037844387}, \
{-0.2500000000000002, -0.43301270189221913, 0.8660254037844387}, 
     {-0.29389262614623685, -0.509036960455127, 0.8090169943749475}, \
{-0.3454915028125264, -0.47552825814757677, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.675, 0.1], \
Polygon[{{-0.2500000000000002, -0.43301270189221913, 0.8660254037844387}, 
     {-0.2033683215379004, -0.4567727288213002, 0.8660254037844387}, \
{-0.2390738003669032, -0.5369685473010988, 0.8090169943749475}, 
     {-0.29389262614623685, -0.509036960455127, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.2033683215379004, -0.4567727288213002, 0.8660254037844387}, \
{-0.15450849718747375, -0.4755282581475767, 0.8660254037844387}, 
     {-0.1816356320013403, -0.5590169943749475, 0.8090169943749475}, \
{-0.2390738003669032, -0.5369685473010988, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.15450849718747375, -0.4755282581475767, 0.8660254037844387}, 
     {-0.10395584540887988, -0.48907380036690273, 0.8660254037844387}, \
{-0.1222074256418716, -0.5749407342765972, 0.8090169943749475}, 
     {-0.1816356320013403, -0.5590169943749475, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.725, 0.1], 
   Polygon[{{-0.10395584540887988, -0.48907380036690273, 0.8660254037844387}, \
{-0.05226423163382711, -0.4972609476841366, 0.8660254037844387}, 
     {-0.061440289153522655, -0.5845653031794291, 0.8090169943749475}, \
{-0.1222074256418716, -0.5749407342765972, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.05226423163382711, -0.4972609476841366, 0.8660254037844387}, 
     {-9.184547653667828*^-17, -0.49999999999999994, 0.8660254037844387}, \
{-1.0797083319606774*^-16, -0.5877852522924731, 0.8090169943749475}, 
     {-0.061440289153522655, -0.5845653031794291, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-9.184547653667828*^-17, -0.49999999999999994, \
0.8660254037844387}, {0.052264231633826486, -0.49726094768413664, \
0.8660254037844387}, 
     {0.06144028915352192, -0.5845653031794291, 0.8090169943749475}, \
{-1.0797083319606774*^-16, -0.5877852522924731, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.775, 0.1], \
Polygon[{{0.052264231633826486, -0.49726094768413664, 0.8660254037844387}, 
     {0.10395584540887927, -0.48907380036690284, 0.8660254037844387}, \
{0.12220742564187088, -0.5749407342765973, 0.8090169943749475}, 
     {0.06144028915352192, -0.5845653031794291, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.10395584540887927, -0.48907380036690284, 0.8660254037844387}, \
{0.1545084971874736, -0.47552825814757677, 0.8660254037844387}, 
     {0.1816356320013401, -0.5590169943749475, 0.8090169943749475}, \
{0.12220742564187088, -0.5749407342765973, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.1545084971874736, -0.47552825814757677, 0.8660254037844387}, 
     {0.20336832153789985, -0.4567727288213005, 0.8660254037844387}, \
{0.23907380036690257, -0.5369685473010991, 0.8090169943749475}, 
     {0.1816356320013401, -0.5590169943749475, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.825, 0.1], 
   Polygon[{{0.20336832153789985, -0.4567727288213005, 0.8660254037844387}, \
{0.24999999999999964, -0.43301270189221946, 0.8660254037844387}, 
     {0.2938926261462362, -0.5090369604551275, 0.8090169943749475}, \
{0.23907380036690257, -0.5369685473010991, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.24999999999999964, -0.43301270189221946, 0.8660254037844387}, 
     {0.2938926261462364, -0.4045084971874737, 0.8660254037844387}, \
{0.34549150281252616, -0.4755282581475769, 0.8090169943749475}, 
     {0.2938926261462362, -0.5090369604551275, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.2938926261462364, -0.4045084971874737, 0.8660254037844387}, \
{0.33456530317942884, -0.37157241273869723, 0.8660254037844387}, 
     {0.3933051022752568, -0.4368095687330763, 0.8090169943749475}, \
{0.34549150281252616, -0.4755282581475769, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.875, 0.1], \
Polygon[{{0.33456530317942884, -0.37157241273869723, 0.8660254037844387}, 
     {0.3715724127386968, -0.33456530317942934, 0.8660254037844387}, \
{0.43680956873307575, -0.39330510227525733, 0.8090169943749475}, 
     {0.3933051022752568, -0.4368095687330763, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.3715724127386968, -0.33456530317942934, 0.8660254037844387}, \
{0.4045084971874736, -0.2938926261462366, 0.8660254037844387}, 
     {0.47552825814757677, -0.34549150281252644, 0.8090169943749475}, \
{0.43680956873307575, -0.39330510227525733, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.4045084971874736, -0.2938926261462366, 0.8660254037844387}, 
     {0.43301270189221913, -0.2500000000000002, 0.8660254037844387}, \
{0.509036960455127, -0.29389262614623685, 0.8090169943749475}, 
     {0.47552825814757677, -0.34549150281252644, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.43301270189221913, -0.2500000000000002, 0.8660254037844387}, \
{0.4567727288213002, -0.20336832153790044, 0.8660254037844387}, 
     {0.5369685473010988, -0.23907380036690323, 0.8090169943749475}, \
{0.509036960455127, -0.29389262614623685, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.4567727288213002, -0.20336832153790044, 0.8660254037844387}, 
     {0.4755282581475767, -0.15450849718747378, 0.8660254037844387}, \
{0.5590169943749475, -0.18163563200134034, 0.8090169943749475}, 
     {0.5369685473010988, -0.23907380036690323, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.4755282581475767, -0.15450849718747378, 0.8660254037844387}, \
{0.48907380036690273, -0.10395584540887992, 0.8660254037844387}, 
     {0.5749407342765972, -0.12220742564187166, 0.8090169943749475}, \
{0.5590169943749475, -0.18163563200134034, 0.8090169943749475}}]}, 
  {CMYKColor[0.18333333333333332, 0.5, 0.975, 0.1], \
Polygon[{{0.48907380036690273, -0.10395584540887992, 0.8660254037844387}, 
     {0.4972609476841366, -0.052264231633827145, 0.8660254037844387}, \
{0.5845653031794291, -0.0614402891535227, 0.8090169943749475}, 
     {0.5749407342765972, -0.12220742564187166, 0.8090169943749475}}]}, \
{CMYKColor[0.18333333333333332, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.4972609476841366, -0.052264231633827145, 0.8660254037844387}, \
{0.49999999999999994, -1.224606353822377*^-16, 0.8660254037844387}, 
     {0.5877852522924731, -1.4396111092809032*^-16, 0.8090169943749475}, \
{0.5845653031794291, -0.0614402891535227, 0.8090169943749475}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.5877852522924731, 0., 0.8090169943749475}, 
     {0.5845653031794291, 0.0614402891535222, 0.8090169943749475}, \
{0.6654650388849336, 0.06994319400804459, 0.7431448254773944}, 
     {0.6691306063588581, 0., 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{0.5845653031794291, 0.0614402891535222, 0.8090169943749475}, \
{0.5749407342765973, 0.12220742564187133, 0.8090169943749475}, 
     {0.6545084971874736, 0.13912007574598273, 0.7431448254773944}, \
{0.6654650388849336, 0.06994319400804459, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.5749407342765973, 0.12220742564187133, 0.8090169943749475}, 
     {0.5590169943749475, 0.1816356320013402, 0.8090169943749475}, \
{0.6363810234301193, 0.2067727288213004, 0.7431448254773944}, 
     {0.6545084971874736, 0.13912007574598273, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.5590169943749475, 0.1816356320013402, 0.8090169943749475}, \
{0.536968547301099, 0.2390738003669028, 0.8090169943749475}, 
     {0.6112812260087741, 0.27215993660967663, 0.7431448254773944}, \
{0.6363810234301193, 0.2067727288213004, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.075, 0.1], \
Polygon[{{0.536968547301099, 0.2390738003669028, 0.8090169943749475}, 
     {0.5090369604551273, 0.2938926261462365, 0.8090169943749475}, \
{0.5794841035564564, 0.334565303179429, 0.7431448254773944}, 
     {0.6112812260087741, 0.27215993660967663, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.5090369604551273, 0.2938926261462365, 0.8090169943749475}, \
{0.4755282581475768, 0.3454915028125263, 0.8090169943749475}, 
     {0.5413380320007295, 0.39330510227525695, 0.7431448254773944}, \
{0.5794841035564564, 0.334565303179429, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.4755282581475768, 0.3454915028125263, 0.8090169943749475}, 
     {0.43680956873307614, 0.39330510227525695, 0.8090169943749475}, \
{0.4972609476841367, 0.4477357683661731, 0.7431448254773944}, 
     {0.5413380320007295, 0.39330510227525695, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{0.43680956873307614, 0.39330510227525695, 0.8090169943749475}, \
{0.393305102275257, 0.436809568733076, 0.8090169943749475}, 
     {0.44773576836617324, 0.49726094768413653, 0.7431448254773944}, \
{0.4972609476841367, 0.4477357683661731, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.393305102275257, 0.436809568733076, 0.8090169943749475}, 
     {0.3454915028125263, 0.4755282581475768, 0.8090169943749475}, \
{0.39330510227525695, 0.5413380320007295, 0.7431448254773944}, 
     {0.44773576836617324, 0.49726094768413653, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.3454915028125263, 0.4755282581475768, 0.8090169943749475}, \
{0.2938926261462366, 0.5090369604551271, 0.8090169943749475}, 
     {0.3345653031794291, 0.5794841035564563, 0.7431448254773944}, \
{0.39330510227525695, 0.5413380320007295, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.175, 0.1], \
Polygon[{{0.2938926261462366, 0.5090369604551271, 0.8090169943749475}, 
     {0.23907380036690293, 0.536968547301099, 0.8090169943749475}, \
{0.27215993660967674, 0.6112812260087741, 0.7431448254773944}, 
     {0.3345653031794291, 0.5794841035564563, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.23907380036690293, 0.536968547301099, 0.8090169943749475}, \
{0.18163563200134025, 0.5590169943749475, 0.8090169943749475}, 
     {0.20677272882130043, 0.6363810234301193, 0.7431448254773944}, \
{0.27215993660967674, 0.6112812260087741, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.18163563200134025, 0.5590169943749475, 0.8090169943749475}, 
     {0.12220742564187141, 0.5749407342765972, 0.8090169943749475}, \
{0.1391200757459828, 0.6545084971874736, 0.7431448254773944}, 
     {0.20677272882130043, 0.6363810234301193, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{0.12220742564187141, 0.5749407342765972, 0.8090169943749475}, \
{0.06144028915352233, 0.5845653031794291, 0.8090169943749475}, 
     {0.06994319400804473, 0.6654650388849336, 0.7431448254773944}, \
{0.1391200757459828, 0.6545084971874736, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.06144028915352233, 0.5845653031794291, 0.8090169943749475}, 
     {3.599027773202258*^-17, 0.5877852522924731, 0.8090169943749475}, \
{4.097107960420388*^-17, 0.6691306063588581, 0.7431448254773944}, 
     {0.06994319400804473, 0.6654650388849336, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{3.599027773202258*^-17, 0.5877852522924731, 0.8090169943749475}, \
{-0.06144028915352213, 0.5845653031794291, 0.8090169943749475}, 
     {-0.06994319400804451, 0.6654650388849337, 0.7431448254773944}, \
{4.097107960420388*^-17, 0.6691306063588581, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.275, 0.1], \
Polygon[{{-0.06144028915352213, 0.5845653031794291, 0.8090169943749475}, 
     {-0.12220742564187122, 0.5749407342765973, 0.8090169943749475}, \
{-0.1391200757459826, 0.6545084971874736, 0.7431448254773944}, 
     {-0.06994319400804451, 0.6654650388849337, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.12220742564187122, 0.5749407342765973, 0.8090169943749475}, \
{-0.18163563200134017, 0.5590169943749475, 0.8090169943749475}, 
     {-0.20677272882130038, 0.6363810234301194, 0.7431448254773944}, \
{-0.1391200757459826, 0.6545084971874736, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.18163563200134017, 0.5590169943749475, 0.8090169943749475}, 
     {-0.23907380036690273, 0.536968547301099, 0.8090169943749475}, \
{-0.2721599366096765, 0.6112812260087741, 0.7431448254773944}, 
     {-0.20677272882130038, 0.6363810234301194, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{-0.23907380036690273, 0.536968547301099, 0.8090169943749475}, \
{-0.29389262614623646, 0.5090369604551273, 0.8090169943749475}, 
     {-0.3345653031794289, 0.5794841035564564, 0.7431448254773944}, \
{-0.2721599366096765, 0.6112812260087741, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.29389262614623646, 0.5090369604551273, 0.8090169943749475}, 
     {-0.3454915028125262, 0.4755282581475768, 0.8090169943749475}, \
{-0.3933051022752569, 0.5413380320007295, 0.7431448254773944}, 
     {-0.3345653031794289, 0.5794841035564564, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.3454915028125262, 0.4755282581475768, 0.8090169943749475}, \
{-0.39330510227525683, 0.43680956873307625, 0.8090169943749475}, 
     {-0.447735768366173, 0.49726094768413676, 0.7431448254773944}, \
{-0.3933051022752569, 0.5413380320007295, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.375, 0.1], \
Polygon[{{-0.39330510227525683, 0.43680956873307625, 0.8090169943749475}, 
     {-0.43680956873307597, 0.39330510227525706, 0.8090169943749475}, \
{-0.4972609476841365, 0.4477357683661733, 0.7431448254773944}, 
     {-0.447735768366173, 0.49726094768413676, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.43680956873307597, 0.39330510227525706, 0.8090169943749475}, \
{-0.47552825814757677, 0.3454915028125264, 0.8090169943749475}, 
     {-0.5413380320007294, 0.393305102275257, 0.7431448254773944}, \
{-0.4972609476841365, 0.4477357683661733, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.47552825814757677, 0.3454915028125264, 0.8090169943749475}, 
     {-0.5090369604551271, 0.2938926261462368, 0.8090169943749475}, \
{-0.5794841035564563, 0.3345653031794293, 0.7431448254773944}, 
     {-0.5413380320007294, 0.393305102275257, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{-0.5090369604551271, 0.2938926261462368, 0.8090169943749475}, \
{-0.5369685473010989, 0.23907380036690296, 0.8090169943749475}, 
     {-0.611281226008774, 0.2721599366096768, 0.7431448254773944}, \
{-0.5794841035564563, 0.3345653031794293, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.5369685473010989, 0.23907380036690296, 0.8090169943749475}, 
     {-0.5590169943749475, 0.18163563200134028, 0.8090169943749475}, \
{-0.6363810234301193, 0.2067727288213005, 0.7431448254773944}, 
     {-0.611281226008774, 0.2721599366096768, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.5590169943749475, 0.18163563200134028, 0.8090169943749475}, \
{-0.5749407342765972, 0.12220742564187158, 0.8090169943749475}, 
     {-0.6545084971874736, 0.139120075745983, 0.7431448254773944}, \
{-0.6363810234301193, 0.2067727288213005, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.475, 0.1], \
Polygon[{{-0.5749407342765972, 0.12220742564187158, 0.8090169943749475}, 
     {-0.5845653031794291, 0.061440289153522364, 0.8090169943749475}, \
{-0.6654650388849336, 0.06994319400804477, 0.7431448254773944}, 
     {-0.6545084971874736, 0.139120075745983, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.5845653031794291, 0.061440289153522364, 0.8090169943749475}, \
{-0.5877852522924731, 7.198055546404516*^-17, 0.8090169943749475}, 
     {-0.6691306063588581, 8.194215920840776*^-17, 0.7431448254773944}, \
{-0.6654650388849336, 0.06994319400804477, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.5877852522924731, 7.198055546404516*^-17, 0.8090169943749475}, 
     {-0.5845653031794291, -0.06144028915352196, 0.8090169943749475}, \
{-0.6654650388849337, -0.06994319400804432, 0.7431448254773944}, 
     {-0.6691306063588581, 8.194215920840776*^-17, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{-0.5845653031794291, -0.06144028915352196, 0.8090169943749475}, \
{-0.5749407342765973, -0.12220742564187118, 0.8090169943749475}, 
     {-0.6545084971874736, -0.13912007574598256, 0.7431448254773944}, \
{-0.6654650388849337, -0.06994319400804432, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.5749407342765973, -0.12220742564187118, 0.8090169943749475}, 
     {-0.5590169943749475, -0.18163563200134014, 0.8090169943749475}, \
{-0.6363810234301194, -0.20677272882130032, 0.7431448254773944}, 
     {-0.6545084971874736, -0.13912007574598256, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.5590169943749475, -0.18163563200134014, 0.8090169943749475}, \
{-0.5369685473010991, -0.2390738003669026, 0.8090169943749475}, 
     {-0.6112812260087742, -0.2721599366096764, 0.7431448254773944}, \
{-0.6363810234301194, -0.20677272882130032, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.575, 0.1], \
Polygon[{{-0.5369685473010991, -0.2390738003669026, 0.8090169943749475}, 
     {-0.5090369604551273, -0.2938926261462364, 0.8090169943749475}, \
{-0.5794841035564565, -0.3345653031794289, 0.7431448254773944}, 
     {-0.6112812260087742, -0.2721599366096764, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.5090369604551273, -0.2938926261462364, 0.8090169943749475}, \
{-0.4755282581475769, -0.3454915028125262, 0.8090169943749475}, 
     {-0.5413380320007296, -0.3933051022752569, 0.7431448254773944}, \
{-0.5794841035564565, -0.3345653031794289, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.4755282581475769, -0.3454915028125262, 0.8090169943749475}, 
     {-0.4368095687330763, -0.39330510227525683, 0.8090169943749475}, \
{-0.4972609476841368, -0.447735768366173, 0.7431448254773944}, 
     {-0.5413380320007296, -0.3933051022752569, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{-0.4368095687330763, -0.39330510227525683, 0.8090169943749475}, \
{-0.39330510227525717, -0.43680956873307597, 0.8090169943749475}, 
     {-0.44773576836617335, -0.4972609476841365, 0.7431448254773944}, \
{-0.4972609476841368, -0.447735768366173, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.39330510227525717, -0.43680956873307597, 0.8090169943749475}, 
     {-0.3454915028125264, -0.47552825814757677, 0.8090169943749475}, \
{-0.393305102275257, -0.5413380320007294, 0.7431448254773944}, 
     {-0.44773576836617335, -0.4972609476841365, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.3454915028125264, -0.47552825814757677, 0.8090169943749475}, \
{-0.29389262614623685, -0.509036960455127, 0.8090169943749475}, 
     {-0.33456530317942934, -0.5794841035564562, 0.7431448254773944}, \
{-0.393305102275257, -0.5413380320007294, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.675, 0.1], \
Polygon[{{-0.29389262614623685, -0.509036960455127, 0.8090169943749475}, 
     {-0.2390738003669032, -0.5369685473010988, 0.8090169943749475}, \
{-0.2721599366096771, -0.6112812260087739, 0.7431448254773944}, 
     {-0.33456530317942934, -0.5794841035564562, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.2390738003669032, -0.5369685473010988, 0.8090169943749475}, \
{-0.1816356320013403, -0.5590169943749475, 0.8090169943749475}, 
     {-0.20677272882130052, -0.6363810234301193, 0.7431448254773944}, \
{-0.2721599366096771, -0.6112812260087739, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.1816356320013403, -0.5590169943749475, 0.8090169943749475}, 
     {-0.1222074256418716, -0.5749407342765972, 0.8090169943749475}, \
{-0.13912007574598304, -0.6545084971874736, 0.7431448254773944}, 
     {-0.20677272882130052, -0.6363810234301193, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{-0.1222074256418716, -0.5749407342765972, 0.8090169943749475}, \
{-0.061440289153522655, -0.5845653031794291, 0.8090169943749475}, 
     {-0.0699431940080451, -0.6654650388849336, 0.7431448254773944}, \
{-0.13912007574598304, -0.6545084971874736, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.061440289153522655, -0.5845653031794291, 0.8090169943749475}, 
     {-1.0797083319606774*^-16, -0.5877852522924731, 0.8090169943749475}, \
{-1.2291323881261164*^-16, -0.6691306063588581, 0.7431448254773944}, 
     {-0.0699431940080451, -0.6654650388849336, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.0797083319606774*^-16, -0.5877852522924731, \
0.8090169943749475}, {0.06144028915352192, -0.5845653031794291, \
0.8090169943749475}, 
     {0.06994319400804427, -0.6654650388849337, 0.7431448254773944}, \
{-1.2291323881261164*^-16, -0.6691306063588581, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.775, 0.1], \
Polygon[{{0.06144028915352192, -0.5845653031794291, 0.8090169943749475}, 
     {0.12220742564187088, -0.5749407342765973, 0.8090169943749475}, \
{0.13912007574598223, -0.6545084971874737, 0.7431448254773944}, 
     {0.06994319400804427, -0.6654650388849337, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.12220742564187088, -0.5749407342765973, 0.8090169943749475}, \
{0.1816356320013401, -0.5590169943749475, 0.8090169943749475}, 
     {0.2067727288213003, -0.6363810234301194, 0.7431448254773944}, \
{0.13912007574598223, -0.6545084971874737, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.1816356320013401, -0.5590169943749475, 0.8090169943749475}, 
     {0.23907380036690257, -0.5369685473010991, 0.8090169943749475}, \
{0.27215993660967636, -0.6112812260087742, 0.7431448254773944}, 
     {0.2067727288213003, -0.6363810234301194, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{0.23907380036690257, -0.5369685473010991, 0.8090169943749475}, \
{0.2938926261462362, -0.5090369604551275, 0.8090169943749475}, 
     {0.3345653031794286, -0.5794841035564566, 0.7431448254773944}, \
{0.27215993660967636, -0.6112812260087742, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.2938926261462362, -0.5090369604551275, 0.8090169943749475}, 
     {0.34549150281252616, -0.4755282581475769, 0.8090169943749475}, \
{0.3933051022752568, -0.5413380320007296, 0.7431448254773944}, 
     {0.3345653031794286, -0.5794841035564566, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.34549150281252616, -0.4755282581475769, 0.8090169943749475}, \
{0.3933051022752568, -0.4368095687330763, 0.8090169943749475}, 
     {0.4477357683661729, -0.4972609476841368, 0.7431448254773944}, \
{0.3933051022752568, -0.5413380320007296, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.875, 0.1], \
Polygon[{{0.3933051022752568, -0.4368095687330763, 0.8090169943749475}, 
     {0.43680956873307575, -0.39330510227525733, 0.8090169943749475}, \
{0.49726094768413626, -0.44773576836617357, 0.7431448254773944}, 
     {0.4477357683661729, -0.4972609476841368, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.43680956873307575, -0.39330510227525733, 0.8090169943749475}, \
{0.47552825814757677, -0.34549150281252644, 0.8090169943749475}, 
     {0.5413380320007294, -0.3933051022752571, 0.7431448254773944}, \
{0.49726094768413626, -0.44773576836617357, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.47552825814757677, -0.34549150281252644, 0.8090169943749475}, 
     {0.509036960455127, -0.29389262614623685, 0.8090169943749475}, \
{0.5794841035564562, -0.33456530317942934, 0.7431448254773944}, 
     {0.5413380320007294, -0.3933051022752571, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.509036960455127, -0.29389262614623685, 0.8090169943749475}, \
{0.5369685473010988, -0.23907380036690323, 0.8090169943749475}, 
     {0.6112812260087739, -0.27215993660967713, 0.7431448254773944}, \
{0.5794841035564562, -0.33456530317942934, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.5369685473010988, -0.23907380036690323, 0.8090169943749475}, 
     {0.5590169943749475, -0.18163563200134034, 0.8090169943749475}, \
{0.6363810234301193, -0.20677272882130054, 0.7431448254773944}, 
     {0.6112812260087739, -0.27215993660967713, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.5590169943749475, -0.18163563200134034, 0.8090169943749475}, \
{0.5749407342765972, -0.12220742564187166, 0.8090169943749475}, 
     {0.6545084971874736, -0.1391200757459831, 0.7431448254773944}, \
{0.6363810234301193, -0.20677272882130054, 0.7431448254773944}}]}, 
  {CMYKColor[0.21666666666666667, 0.5, 0.975, 0.1], \
Polygon[{{0.5749407342765972, -0.12220742564187166, 0.8090169943749475}, 
     {0.5845653031794291, -0.0614402891535227, 0.8090169943749475}, \
{0.6654650388849336, -0.06994319400804515, 0.7431448254773944}, 
     {0.6545084971874736, -0.1391200757459831, 0.7431448254773944}}]}, \
{CMYKColor[0.21666666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.5845653031794291, -0.0614402891535227, 0.8090169943749475}, \
{0.5877852522924731, -1.4396111092809032*^-16, 0.8090169943749475}, 
     {0.6691306063588581, -1.6388431841681552*^-16, 0.7431448254773944}, \
{0.6654650388849336, -0.06994319400804515, 0.7431448254773944}}]}, 
  {CMYKColor[0.25, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.6691306063588581, 0., 0.7431448254773944}, 
     {0.6654650388849336, 0.06994319400804459, 0.7431448254773944}, \
{0.7390738003669027, 0.07767978659246053, 0.6691306063588582}, 
     {0.7431448254773941, 0., 0.6691306063588582}}]}, {CMYKColor[0.25, 0.5, \
0.025, 0.1], 
   Polygon[{{0.6654650388849336, 0.06994319400804459, 0.7431448254773944}, \
{0.6545084971874736, 0.13912007574598273, 0.7431448254773944}, 
     {0.7269053280384559, 0.15450849718747367, 0.6691306063588582}, \
{0.7390738003669027, 0.07767978659246053, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.6545084971874736, 0.13912007574598273, 0.7431448254773944}, 
     {0.6363810234301193, 0.2067727288213004, 0.7431448254773944}, \
{0.7067727288213003, 0.22964438035431917, 0.6691306063588582}, 
     {0.7269053280384559, 0.15450849718747367, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.6363810234301193, 0.2067727288213004, 0.7431448254773944}, \
{0.6112812260087741, 0.27215993660967663, 0.7431448254773944}, 
     {0.6788965796854768, 0.30226423163382665, 0.6691306063588582}, \
{0.7067727288213003, 0.22964438035431917, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.075, 0.1], Polygon[{{0.6112812260087741, \
0.27215993660967663, 0.7431448254773944}, 
     {0.5794841035564564, 0.334565303179429, 0.7431448254773944}, \
{0.6435822975543765, 0.371572412738697, 0.6691306063588582}, 
     {0.6788965796854768, 0.30226423163382665, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.5794841035564564, 0.334565303179429, 0.7431448254773944}, \
{0.5413380320007295, 0.39330510227525695, 0.7431448254773944}, 
     {0.6012167930930162, 0.436809568733076, 0.6691306063588582}, \
{0.6435822975543765, 0.371572412738697, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.5413380320007295, 0.39330510227525695, 0.7431448254773944}, 
     {0.4972609476841367, 0.4477357683661731, 0.7431448254773944}, \
{0.5522642316338268, 0.49726094768413653, 0.6691306063588582}, 
     {0.6012167930930162, 0.436809568733076, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.125, 0.1], 
   Polygon[{{0.4972609476841367, 0.4477357683661731, 0.7431448254773944}, \
{0.44773576836617324, 0.49726094768413653, 0.7431448254773944}, 
     {0.49726094768413664, 0.5522642316338265, 0.6691306063588582}, \
{0.5522642316338268, 0.49726094768413653, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.44773576836617324, 0.49726094768413653, 0.7431448254773944}, 
     {0.39330510227525695, 0.5413380320007295, 0.7431448254773944}, \
{0.436809568733076, 0.6012167930930162, 0.6691306063588582}, 
     {0.49726094768413664, 0.5522642316338265, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.39330510227525695, 0.5413380320007295, 0.7431448254773944}, \
{0.3345653031794291, 0.5794841035564563, 0.7431448254773944}, 
     {0.3715724127386971, 0.6435822975543765, 0.6691306063588582}, \
{0.436809568733076, 0.6012167930930162, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.175, 0.1], Polygon[{{0.3345653031794291, \
0.5794841035564563, 0.7431448254773944}, 
     {0.27215993660967674, 0.6112812260087741, 0.7431448254773944}, \
{0.3022642316338268, 0.6788965796854768, 0.6691306063588582}, 
     {0.3715724127386971, 0.6435822975543765, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.27215993660967674, 0.6112812260087741, 0.7431448254773944}, \
{0.20677272882130043, 0.6363810234301193, 0.7431448254773944}, 
     {0.22964438035431922, 0.7067727288213003, 0.6691306063588582}, \
{0.3022642316338268, 0.6788965796854768, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.20677272882130043, 0.6363810234301193, 0.7431448254773944}, 
     {0.1391200757459828, 0.6545084971874736, 0.7431448254773944}, \
{0.15450849718747378, 0.7269053280384558, 0.6691306063588582}, 
     {0.22964438035431922, 0.7067727288213003, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.225, 0.1], 
   Polygon[{{0.1391200757459828, 0.6545084971874736, 0.7431448254773944}, \
{0.06994319400804473, 0.6654650388849336, 0.7431448254773944}, 
     {0.07767978659246069, 0.7390738003669027, 0.6691306063588582}, \
{0.15450849718747378, 0.7269053280384558, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.06994319400804473, 0.6654650388849336, 0.7431448254773944}, 
     {4.097107960420388*^-17, 0.6691306063588581, 0.7431448254773944}, \
{4.5502993754491925*^-17, 0.7431448254773941, 0.6691306063588582}, 
     {0.07767978659246069, 0.7390738003669027, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{4.097107960420388*^-17, 0.6691306063588581, 0.7431448254773944}, \
{-0.06994319400804451, 0.6654650388849337, 0.7431448254773944}, 
     {-0.07767978659246044, 0.7390738003669027, 0.6691306063588582}, \
{4.5502993754491925*^-17, 0.7431448254773941, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.275, 0.1], Polygon[{{-0.06994319400804451, \
0.6654650388849337, 0.7431448254773944}, 
     {-0.1391200757459826, 0.6545084971874736, 0.7431448254773944}, \
{-0.15450849718747353, 0.7269053280384559, 0.6691306063588582}, 
     {-0.07767978659246044, 0.7390738003669027, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.1391200757459826, 0.6545084971874736, 0.7431448254773944}, \
{-0.20677272882130038, 0.6363810234301194, 0.7431448254773944}, 
     {-0.22964438035431914, 0.7067727288213004, 0.6691306063588582}, \
{-0.15450849718747353, 0.7269053280384559, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.20677272882130038, 0.6363810234301194, 0.7431448254773944}, 
     {-0.2721599366096765, 0.6112812260087741, 0.7431448254773944}, \
{-0.3022642316338266, 0.6788965796854769, 0.6691306063588582}, 
     {-0.22964438035431914, 0.7067727288213004, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.325, 0.1], 
   Polygon[{{-0.2721599366096765, 0.6112812260087741, 0.7431448254773944}, \
{-0.3345653031794289, 0.5794841035564564, 0.7431448254773944}, 
     {-0.3715724127386969, 0.6435822975543765, 0.6691306063588582}, \
{-0.3022642316338266, 0.6788965796854769, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.3345653031794289, 0.5794841035564564, 0.7431448254773944}, 
     {-0.3933051022752569, 0.5413380320007295, 0.7431448254773944}, \
{-0.43680956873307597, 0.6012167930930162, 0.6691306063588582}, 
     {-0.3715724127386969, 0.6435822975543765, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.3933051022752569, 0.5413380320007295, 0.7431448254773944}, \
{-0.447735768366173, 0.49726094768413676, 0.7431448254773944}, 
     {-0.49726094768413637, 0.5522642316338269, 0.6691306063588582}, \
{-0.43680956873307597, 0.6012167930930162, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.375, 0.1], Polygon[{{-0.447735768366173, \
0.49726094768413676, 0.7431448254773944}, 
     {-0.4972609476841365, 0.4477357683661733, 0.7431448254773944}, \
{-0.5522642316338265, 0.4972609476841367, 0.6691306063588582}, 
     {-0.49726094768413637, 0.5522642316338269, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.4972609476841365, 0.4477357683661733, 0.7431448254773944}, \
{-0.5413380320007294, 0.393305102275257, 0.7431448254773944}, 
     {-0.6012167930930162, 0.43680956873307614, 0.6691306063588582}, \
{-0.5522642316338265, 0.4972609476841367, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.5413380320007294, 0.393305102275257, 0.7431448254773944}, 
     {-0.5794841035564563, 0.3345653031794293, 0.7431448254773944}, \
{-0.6435822975543763, 0.3715724127386973, 0.6691306063588582}, 
     {-0.6012167930930162, 0.43680956873307614, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.425, 0.1], 
   Polygon[{{-0.5794841035564563, 0.3345653031794293, 0.7431448254773944}, \
{-0.611281226008774, 0.2721599366096768, 0.7431448254773944}, 
     {-0.6788965796854767, 0.3022642316338269, 0.6691306063588582}, \
{-0.6435822975543763, 0.3715724127386973, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.611281226008774, 0.2721599366096768, 0.7431448254773944}, 
     {-0.6363810234301193, 0.2067727288213005, 0.7431448254773944}, \
{-0.7067727288213003, 0.22964438035431925, 0.6691306063588582}, 
     {-0.6788965796854767, 0.3022642316338269, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.6363810234301193, 0.2067727288213005, 0.7431448254773944}, \
{-0.6545084971874736, 0.139120075745983, 0.7431448254773944}, 
     {-0.7269053280384558, 0.15450849718747398, 0.6691306063588582}, \
{-0.7067727288213003, 0.22964438035431925, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.475, 0.1], Polygon[{{-0.6545084971874736, \
0.139120075745983, 0.7431448254773944}, 
     {-0.6654650388849336, 0.06994319400804477, 0.7431448254773944}, \
{-0.7390738003669027, 0.07767978659246073, 0.6691306063588582}, 
     {-0.7269053280384558, 0.15450849718747398, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.6654650388849336, 0.06994319400804477, 0.7431448254773944}, \
{-0.6691306063588581, 8.194215920840776*^-17, 0.7431448254773944}, 
     {-0.7431448254773941, 9.100598750898385*^-17, 0.6691306063588582}, \
{-0.7390738003669027, 0.07767978659246073, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.6691306063588581, 8.194215920840776*^-17, 0.7431448254773944}, 
     {-0.6654650388849337, -0.06994319400804432, 0.7431448254773944}, \
{-0.7390738003669027, -0.07767978659246023, 0.6691306063588582}, 
     {-0.7431448254773941, 9.100598750898385*^-17, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.525, 0.1], 
   Polygon[{{-0.6654650388849337, -0.06994319400804432, 0.7431448254773944}, \
{-0.6545084971874736, -0.13912007574598256, 0.7431448254773944}, 
     {-0.7269053280384559, -0.15450849718747348, 0.6691306063588582}, \
{-0.7390738003669027, -0.07767978659246023, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.6545084971874736, -0.13912007574598256, 0.7431448254773944}, 
     {-0.6363810234301194, -0.20677272882130032, 0.7431448254773944}, \
{-0.7067727288213004, -0.22964438035431908, 0.6691306063588582}, 
     {-0.7269053280384559, -0.15450849718747348, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.6363810234301194, -0.20677272882130032, 0.7431448254773944}, \
{-0.6112812260087742, -0.2721599366096764, 0.7431448254773944}, 
     {-0.6788965796854769, -0.30226423163382643, 0.6691306063588582}, \
{-0.7067727288213004, -0.22964438035431908, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.575, 0.1], Polygon[{{-0.6112812260087742, \
-0.2721599366096764, 0.7431448254773944}, 
     {-0.5794841035564565, -0.3345653031794289, 0.7431448254773944}, \
{-0.6435822975543766, -0.37157241273869684, 0.6691306063588582}, 
     {-0.6788965796854769, -0.30226423163382643, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.5794841035564565, -0.3345653031794289, 0.7431448254773944}, \
{-0.5413380320007296, -0.3933051022752569, 0.7431448254773944}, 
     {-0.6012167930930163, -0.43680956873307597, 0.6691306063588582}, \
{-0.6435822975543766, -0.37157241273869684, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.5413380320007296, -0.3933051022752569, 0.7431448254773944}, 
     {-0.4972609476841368, -0.447735768366173, 0.7431448254773944}, \
{-0.5522642316338269, -0.49726094768413637, 0.6691306063588582}, 
     {-0.6012167930930163, -0.43680956873307597, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.625, 0.1], 
   Polygon[{{-0.4972609476841368, -0.447735768366173, 0.7431448254773944}, \
{-0.44773576836617335, -0.4972609476841365, 0.7431448254773944}, 
     {-0.49726094768413676, -0.5522642316338265, 0.6691306063588582}, \
{-0.5522642316338269, -0.49726094768413637, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.44773576836617335, -0.4972609476841365, 0.7431448254773944}, 
     {-0.393305102275257, -0.5413380320007294, 0.7431448254773944}, \
{-0.43680956873307614, -0.6012167930930162, 0.6691306063588582}, 
     {-0.49726094768413676, -0.5522642316338265, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.393305102275257, -0.5413380320007294, 0.7431448254773944}, \
{-0.33456530317942934, -0.5794841035564562, 0.7431448254773944}, 
     {-0.3715724127386974, -0.6435822975543762, 0.6691306063588582}, \
{-0.43680956873307614, -0.6012167930930162, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.675, 0.1], Polygon[{{-0.33456530317942934, \
-0.5794841035564562, 0.7431448254773944}, 
     {-0.2721599366096771, -0.6112812260087739, 0.7431448254773944}, \
{-0.3022642316338272, -0.6788965796854766, 0.6691306063588582}, 
     {-0.3715724127386974, -0.6435822975543762, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.2721599366096771, -0.6112812260087739, 0.7431448254773944}, \
{-0.20677272882130052, -0.6363810234301193, 0.7431448254773944}, 
     {-0.22964438035431928, -0.7067727288213003, 0.6691306063588582}, \
{-0.3022642316338272, -0.6788965796854766, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.20677272882130052, -0.6363810234301193, 0.7431448254773944}, 
     {-0.13912007574598304, -0.6545084971874736, 0.7431448254773944}, \
{-0.15450849718747403, -0.7269053280384558, 0.6691306063588582}, 
     {-0.22964438035431928, -0.7067727288213003, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.725, 0.1], 
   Polygon[{{-0.13912007574598304, -0.6545084971874736, 0.7431448254773944}, \
{-0.0699431940080451, -0.6654650388849336, 0.7431448254773944}, 
     {-0.07767978659246111, -0.7390738003669027, 0.6691306063588582}, \
{-0.15450849718747403, -0.7269053280384558, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.0699431940080451, -0.6654650388849336, 0.7431448254773944}, 
     {-1.2291323881261164*^-16, -0.6691306063588581, 0.7431448254773944}, \
{-1.3650898126347578*^-16, -0.7431448254773941, 0.6691306063588582}, 
     {-0.07767978659246111, -0.7390738003669027, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.2291323881261164*^-16, -0.6691306063588581, \
0.7431448254773944}, {0.06994319400804427, -0.6654650388849337, \
0.7431448254773944}, 
     {0.07767978659246018, -0.7390738003669027, 0.6691306063588582}, \
{-1.3650898126347578*^-16, -0.7431448254773941, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.775, 0.1], Polygon[{{0.06994319400804427, \
-0.6654650388849337, 0.7431448254773944}, 
     {0.13912007574598223, -0.6545084971874737, 0.7431448254773944}, \
{0.15450849718747312, -0.7269053280384559, 0.6691306063588582}, 
     {0.07767978659246018, -0.7390738003669027, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.13912007574598223, -0.6545084971874737, 0.7431448254773944}, \
{0.2067727288213003, -0.6363810234301194, 0.7431448254773944}, 
     {0.22964438035431906, -0.7067727288213004, 0.6691306063588582}, \
{0.15450849718747312, -0.7269053280384559, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.2067727288213003, -0.6363810234301194, 0.7431448254773944}, 
     {0.27215993660967636, -0.6112812260087742, 0.7431448254773944}, \
{0.3022642316338264, -0.6788965796854769, 0.6691306063588582}, 
     {0.22964438035431906, -0.7067727288213004, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.825, 0.1], 
   Polygon[{{0.27215993660967636, -0.6112812260087742, 0.7431448254773944}, \
{0.3345653031794286, -0.5794841035564566, 0.7431448254773944}, 
     {0.37157241273869657, -0.6435822975543767, 0.6691306063588582}, \
{0.3022642316338264, -0.6788965796854769, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.3345653031794286, -0.5794841035564566, 0.7431448254773944}, 
     {0.3933051022752568, -0.5413380320007296, 0.7431448254773944}, \
{0.43680956873307586, -0.6012167930930163, 0.6691306063588582}, 
     {0.37157241273869657, -0.6435822975543767, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.3933051022752568, -0.5413380320007296, 0.7431448254773944}, \
{0.4477357683661729, -0.4972609476841368, 0.7431448254773944}, 
     {0.4972609476841363, -0.5522642316338269, 0.6691306063588582}, \
{0.43680956873307586, -0.6012167930930163, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.875, 0.1], Polygon[{{0.4477357683661729, \
-0.4972609476841368, 0.7431448254773944}, 
     {0.49726094768413626, -0.44773576836617357, 0.7431448254773944}, \
{0.5522642316338262, -0.49726094768413703, 0.6691306063588582}, 
     {0.4972609476841363, -0.5522642316338269, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.49726094768413626, -0.44773576836617357, 0.7431448254773944}, \
{0.5413380320007294, -0.3933051022752571, 0.7431448254773944}, 
     {0.6012167930930162, -0.4368095687330762, 0.6691306063588582}, \
{0.5522642316338262, -0.49726094768413703, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.5413380320007294, -0.3933051022752571, 0.7431448254773944}, 
     {0.5794841035564562, -0.33456530317942934, 0.7431448254773944}, \
{0.6435822975543762, -0.3715724127386974, 0.6691306063588582}, 
     {0.6012167930930162, -0.4368095687330762, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.5794841035564562, -0.33456530317942934, 0.7431448254773944}, \
{0.6112812260087739, -0.27215993660967713, 0.7431448254773944}, 
     {0.6788965796854766, -0.3022642316338272, 0.6691306063588582}, \
{0.6435822975543762, -0.3715724127386974, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.6112812260087739, -0.27215993660967713, 0.7431448254773944}, 
     {0.6363810234301193, -0.20677272882130054, 0.7431448254773944}, \
{0.7067727288213003, -0.22964438035431933, 0.6691306063588582}, 
     {0.6788965796854766, -0.3022642316338272, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.6363810234301193, -0.20677272882130054, 0.7431448254773944}, \
{0.6545084971874736, -0.1391200757459831, 0.7431448254773944}, 
     {0.7269053280384558, -0.1545084971874741, 0.6691306063588582}, \
{0.7067727288213003, -0.22964438035431933, 0.6691306063588582}}]}, 
  {CMYKColor[0.25, 0.5, 0.975, 0.1], Polygon[{{0.6545084971874736, \
-0.1391200757459831, 0.7431448254773944}, 
     {0.6654650388849336, -0.06994319400804515, 0.7431448254773944}, \
{0.7390738003669027, -0.07767978659246116, 0.6691306063588582}, 
     {0.7269053280384558, -0.1545084971874741, 0.6691306063588582}}]}, \
{CMYKColor[0.25, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.6654650388849336, -0.06994319400804515, 0.7431448254773944}, \
{0.6691306063588581, -1.6388431841681552*^-16, 0.7431448254773944}, 
     {0.7431448254773941, -1.820119750179677*^-16, 0.6691306063588582}, \
{0.7390738003669027, -0.07767978659246116, 0.6691306063588582}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.7431448254773941, 0., 0.6691306063588582}, 
     {0.7390738003669027, 0.07767978659246053, 0.6691306063588582}, \
{0.8045851146309164, 0.0845653031794291, 0.5877852522924731}, 
     {0.8090169943749475, 0., 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{0.7390738003669027, 0.07767978659246053, 0.6691306063588582}, \
{0.7269053280384559, 0.15450849718747367, 0.6691306063588582}, 
     {0.7913380320007296, 0.168204091200797, 0.5877852522924731}, \
{0.8045851146309164, 0.0845653031794291, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.7269053280384559, 0.15450849718747367, 0.6691306063588582}, 
     {0.7067727288213003, 0.22964438035431917, 0.6691306063588582}, \
{0.7694208842938134, 0.24999999999999997, 0.5877852522924731}, 
     {0.7913380320007296, 0.168204091200797, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.7067727288213003, 0.22964438035431917, 0.6691306063588582}, \
{0.6788965796854768, 0.30226423163382665, 0.6691306063588582}, 
     {0.7390738003669028, 0.3290568564833396, 0.5877852522924731}, \
{0.7694208842938134, 0.24999999999999997, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.075, 0.1], \
Polygon[{{0.6788965796854768, 0.30226423163382665, 0.6691306063588582}, 
     {0.6435822975543765, 0.371572412738697, 0.6691306063588582}, \
{0.7006292692220368, 0.40450849718747367, 0.5877852522924731}, 
     {0.7390738003669028, 0.3290568564833396, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.6435822975543765, 0.371572412738697, 0.6691306063588582}, \
{0.6012167930930162, 0.436809568733076, 0.6691306063588582}, 
     {0.6545084971874737, 0.4755282581475768, 0.5877852522924731}, \
{0.7006292692220368, 0.40450849718747367, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.6012167930930162, 0.436809568733076, 0.6691306063588582}, 
     {0.5522642316338268, 0.49726094768413653, 0.6691306063588582}, \
{0.6012167930930165, 0.5413380320007295, 0.5877852522924731}, 
     {0.6545084971874737, 0.4755282581475768, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{0.5522642316338268, 0.49726094768413653, 0.6691306063588582}, \
{0.49726094768413664, 0.5522642316338265, 0.6691306063588582}, 
     {0.5413380320007296, 0.6012167930930162, 0.5877852522924731}, \
{0.6012167930930165, 0.5413380320007295, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.49726094768413664, 0.5522642316338265, 0.6691306063588582}, 
     {0.436809568733076, 0.6012167930930162, 0.6691306063588582}, \
{0.4755282581475768, 0.6545084971874737, 0.5877852522924731}, 
     {0.5413380320007296, 0.6012167930930162, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.436809568733076, 0.6012167930930162, 0.6691306063588582}, \
{0.3715724127386971, 0.6435822975543765, 0.6691306063588582}, 
     {0.40450849718747384, 0.7006292692220367, 0.5877852522924731}, \
{0.4755282581475768, 0.6545084971874737, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.175, 0.1], \
Polygon[{{0.3715724127386971, 0.6435822975543765, 0.6691306063588582}, 
     {0.3022642316338268, 0.6788965796854768, 0.6691306063588582}, \
{0.3290568564833398, 0.7390738003669028, 0.5877852522924731}, 
     {0.40450849718747384, 0.7006292692220367, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.3022642316338268, 0.6788965796854768, 0.6691306063588582}, \
{0.22964438035431922, 0.7067727288213003, 0.6691306063588582}, 
     {0.25000000000000006, 0.7694208842938134, 0.5877852522924731}, \
{0.3290568564833398, 0.7390738003669028, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.22964438035431922, 0.7067727288213003, 0.6691306063588582}, 
     {0.15450849718747378, 0.7269053280384558, 0.6691306063588582}, \
{0.1682040912007971, 0.7913380320007295, 0.5877852522924731}, 
     {0.25000000000000006, 0.7694208842938134, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{0.15450849718747378, 0.7269053280384558, 0.6691306063588582}, \
{0.07767978659246069, 0.7390738003669027, 0.6691306063588582}, 
     {0.08456530317942927, 0.8045851146309164, 0.5877852522924731}, \
{0.1682040912007971, 0.7913380320007295, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.07767978659246069, 0.7390738003669027, 0.6691306063588582}, 
     {4.5502993754491925*^-17, 0.7431448254773941, 0.6691306063588582}, \
{4.9536367583092156*^-17, 0.8090169943749475, 0.5877852522924731}, 
     {0.08456530317942927, 0.8045851146309164, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{4.5502993754491925*^-17, 0.7431448254773941, \
0.6691306063588582}, {-0.07767978659246044, 0.7390738003669027, \
0.6691306063588582}, 
     {-0.084565303179429, 0.8045851146309165, 0.5877852522924731}, \
{4.9536367583092156*^-17, 0.8090169943749475, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.275, 0.1], \
Polygon[{{-0.07767978659246044, 0.7390738003669027, 0.6691306063588582}, 
     {-0.15450849718747353, 0.7269053280384559, 0.6691306063588582}, \
{-0.16820409120079685, 0.7913380320007296, 0.5877852522924731}, 
     {-0.084565303179429, 0.8045851146309165, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.15450849718747353, 0.7269053280384559, 0.6691306063588582}, \
{-0.22964438035431914, 0.7067727288213004, 0.6691306063588582}, 
     {-0.24999999999999994, 0.7694208842938134, 0.5877852522924731}, \
{-0.16820409120079685, 0.7913380320007296, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.22964438035431914, 0.7067727288213004, 0.6691306063588582}, 
     {-0.3022642316338266, 0.6788965796854769, 0.6691306063588582}, \
{-0.32905685648333954, 0.739073800366903, 0.5877852522924731}, 
     {-0.24999999999999994, 0.7694208842938134, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{-0.3022642316338266, 0.6788965796854769, 0.6691306063588582}, \
{-0.3715724127386969, 0.6435822975543765, 0.6691306063588582}, 
     {-0.40450849718747356, 0.7006292692220368, 0.5877852522924731}, \
{-0.32905685648333954, 0.739073800366903, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.3715724127386969, 0.6435822975543765, 0.6691306063588582}, 
     {-0.43680956873307597, 0.6012167930930162, 0.6691306063588582}, \
{-0.4755282581475767, 0.6545084971874737, 0.5877852522924731}, 
     {-0.40450849718747356, 0.7006292692220368, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.43680956873307597, 0.6012167930930162, 0.6691306063588582}, \
{-0.49726094768413637, 0.5522642316338269, 0.6691306063588582}, 
     {-0.5413380320007293, 0.6012167930930166, 0.5877852522924731}, \
{-0.4755282581475767, 0.6545084971874737, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.375, 0.1], \
Polygon[{{-0.49726094768413637, 0.5522642316338269, 0.6691306063588582}, 
     {-0.5522642316338265, 0.4972609476841367, 0.6691306063588582}, \
{-0.6012167930930162, 0.5413380320007297, 0.5877852522924731}, 
     {-0.5413380320007293, 0.6012167930930166, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.5522642316338265, 0.4972609476841367, 0.6691306063588582}, \
{-0.6012167930930162, 0.43680956873307614, 0.6691306063588582}, 
     {-0.6545084971874736, 0.4755282581475769, 0.5877852522924731}, \
{-0.6012167930930162, 0.5413380320007297, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.6012167930930162, 0.43680956873307614, 0.6691306063588582}, 
     {-0.6435822975543763, 0.3715724127386973, 0.6691306063588582}, \
{-0.7006292692220366, 0.404508497187474, 0.5877852522924731}, 
     {-0.6545084971874736, 0.4755282581475769, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{-0.6435822975543763, 0.3715724127386973, 0.6691306063588582}, \
{-0.6788965796854767, 0.3022642316338269, 0.6691306063588582}, 
     {-0.7390738003669027, 0.3290568564833398, 0.5877852522924731}, \
{-0.7006292692220366, 0.404508497187474, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.6788965796854767, 0.3022642316338269, 0.6691306063588582}, 
     {-0.7067727288213003, 0.22964438035431925, 0.6691306063588582}, \
{-0.7694208842938134, 0.25000000000000006, 0.5877852522924731}, 
     {-0.7390738003669027, 0.3290568564833398, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.7067727288213003, 0.22964438035431925, 0.6691306063588582}, \
{-0.7269053280384558, 0.15450849718747398, 0.6691306063588582}, 
     {-0.7913380320007295, 0.16820409120079735, 0.5877852522924731}, \
{-0.7694208842938134, 0.25000000000000006, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.475, 0.1], \
Polygon[{{-0.7269053280384558, 0.15450849718747398, 0.6691306063588582}, 
     {-0.7390738003669027, 0.07767978659246073, 0.6691306063588582}, \
{-0.8045851146309164, 0.08456530317942933, 0.5877852522924731}, 
     {-0.7913380320007295, 0.16820409120079735, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.7390738003669027, 0.07767978659246073, 0.6691306063588582}, \
{-0.7431448254773941, 9.100598750898385*^-17, 0.6691306063588582}, 
     {-0.8090169943749475, 9.907273516618431*^-17, 0.5877852522924731}, \
{-0.8045851146309164, 0.08456530317942933, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.7431448254773941, 9.100598750898385*^-17, 0.6691306063588582}, 
     {-0.7390738003669027, -0.07767978659246023, 0.6691306063588582}, \
{-0.8045851146309165, -0.08456530317942877, 0.5877852522924731}, 
     {-0.8090169943749475, 9.907273516618431*^-17, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{-0.7390738003669027, -0.07767978659246023, 0.6691306063588582}, \
{-0.7269053280384559, -0.15450849718747348, 0.6691306063588582}, 
     {-0.7913380320007296, -0.1682040912007968, 0.5877852522924731}, \
{-0.8045851146309165, -0.08456530317942877, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.7269053280384559, -0.15450849718747348, 0.6691306063588582}, 
     {-0.7067727288213004, -0.22964438035431908, 0.6691306063588582}, \
{-0.7694208842938134, -0.2499999999999999, 0.5877852522924731}, 
     {-0.7913380320007296, -0.1682040912007968, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.7067727288213004, -0.22964438035431908, 0.6691306063588582}, \
{-0.6788965796854769, -0.30226423163382643, 0.6691306063588582}, 
     {-0.739073800366903, -0.3290568564833394, 0.5877852522924731}, \
{-0.7694208842938134, -0.2499999999999999, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.575, 0.1], \
Polygon[{{-0.6788965796854769, -0.30226423163382643, 0.6691306063588582}, 
     {-0.6435822975543766, -0.37157241273869684, 0.6691306063588582}, \
{-0.7006292692220369, -0.4045084971874735, 0.5877852522924731}, 
     {-0.739073800366903, -0.3290568564833394, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.6435822975543766, -0.37157241273869684, 0.6691306063588582}, \
{-0.6012167930930163, -0.43680956873307597, 0.6691306063588582}, 
     {-0.6545084971874738, -0.4755282581475767, 0.5877852522924731}, \
{-0.7006292692220369, -0.4045084971874735, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.6012167930930163, -0.43680956873307597, 0.6691306063588582}, 
     {-0.5522642316338269, -0.49726094768413637, 0.6691306063588582}, \
{-0.6012167930930167, -0.5413380320007293, 0.5877852522924731}, 
     {-0.6545084971874738, -0.4755282581475767, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{-0.5522642316338269, -0.49726094768413637, 0.6691306063588582}, \
{-0.49726094768413676, -0.5522642316338265, 0.6691306063588582}, 
     {-0.5413380320007297, -0.6012167930930162, 0.5877852522924731}, \
{-0.6012167930930167, -0.5413380320007293, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.49726094768413676, -0.5522642316338265, 0.6691306063588582}, 
     {-0.43680956873307614, -0.6012167930930162, 0.6691306063588582}, \
{-0.4755282581475769, -0.6545084971874736, 0.5877852522924731}, 
     {-0.5413380320007297, -0.6012167930930162, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.43680956873307614, -0.6012167930930162, 0.6691306063588582}, \
{-0.3715724127386974, -0.6435822975543762, 0.6691306063588582}, 
     {-0.40450849718747406, -0.7006292692220366, 0.5877852522924731}, \
{-0.4755282581475769, -0.6545084971874736, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.675, 0.1], \
Polygon[{{-0.3715724127386974, -0.6435822975543762, 0.6691306063588582}, 
     {-0.3022642316338272, -0.6788965796854766, 0.6691306063588582}, \
{-0.3290568564833402, -0.7390738003669025, 0.5877852522924731}, 
     {-0.40450849718747406, -0.7006292692220366, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.3022642316338272, -0.6788965796854766, 0.6691306063588582}, \
{-0.22964438035431928, -0.7067727288213003, 0.6691306063588582}, 
     {-0.2500000000000001, -0.7694208842938134, 0.5877852522924731}, \
{-0.3290568564833402, -0.7390738003669025, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.22964438035431928, -0.7067727288213003, 0.6691306063588582}, 
     {-0.15450849718747403, -0.7269053280384558, 0.6691306063588582}, \
{-0.16820409120079738, -0.7913380320007295, 0.5877852522924731}, 
     {-0.2500000000000001, -0.7694208842938134, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{-0.15450849718747403, -0.7269053280384558, 0.6691306063588582}, \
{-0.07767978659246111, -0.7390738003669027, 0.6691306063588582}, 
     {-0.08456530317942973, -0.8045851146309164, 0.5877852522924731}, \
{-0.16820409120079738, -0.7913380320007295, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.07767978659246111, -0.7390738003669027, 0.6691306063588582}, 
     {-1.3650898126347578*^-16, -0.7431448254773941, 0.6691306063588582}, \
{-1.4860910274927647*^-16, -0.8090169943749475, 0.5877852522924731}, 
     {-0.08456530317942973, -0.8045851146309164, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.3650898126347578*^-16, -0.7431448254773941, \
0.6691306063588582}, {0.07767978659246018, -0.7390738003669027, \
0.6691306063588582}, 
     {0.08456530317942872, -0.8045851146309165, 0.5877852522924731}, \
{-1.4860910274927647*^-16, -0.8090169943749475, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.775, 0.1], \
Polygon[{{0.07767978659246018, -0.7390738003669027, 0.6691306063588582}, 
     {0.15450849718747312, -0.7269053280384559, 0.6691306063588582}, \
{0.1682040912007964, -0.7913380320007297, 0.5877852522924731}, 
     {0.08456530317942872, -0.8045851146309165, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.15450849718747312, -0.7269053280384559, 0.6691306063588582}, \
{0.22964438035431906, -0.7067727288213004, 0.6691306063588582}, 
     {0.24999999999999986, -0.7694208842938134, 0.5877852522924731}, \
{0.1682040912007964, -0.7913380320007297, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.22964438035431906, -0.7067727288213004, 0.6691306063588582}, 
     {0.3022642316338264, -0.6788965796854769, 0.6691306063588582}, \
{0.3290568564833393, -0.739073800366903, 0.5877852522924731}, 
     {0.24999999999999986, -0.7694208842938134, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{0.3022642316338264, -0.6788965796854769, 0.6691306063588582}, \
{0.37157241273869657, -0.6435822975543767, 0.6691306063588582}, 
     {0.40450849718747317, -0.7006292692220372, 0.5877852522924731}, \
{0.3290568564833393, -0.739073800366903, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.37157241273869657, -0.6435822975543767, 0.6691306063588582}, 
     {0.43680956873307586, -0.6012167930930163, 0.6691306063588582}, \
{0.47552825814757665, -0.6545084971874738, 0.5877852522924731}, 
     {0.40450849718747317, -0.7006292692220372, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.43680956873307586, -0.6012167930930163, 0.6691306063588582}, \
{0.4972609476841363, -0.5522642316338269, 0.6691306063588582}, 
     {0.5413380320007293, -0.6012167930930167, 0.5877852522924731}, \
{0.47552825814757665, -0.6545084971874738, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.875, 0.1], \
Polygon[{{0.4972609476841363, -0.5522642316338269, 0.6691306063588582}, 
     {0.5522642316338262, -0.49726094768413703, 0.6691306063588582}, \
{0.6012167930930159, -0.54133803200073, 0.5877852522924731}, 
     {0.5413380320007293, -0.6012167930930167, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.5522642316338262, -0.49726094768413703, 0.6691306063588582}, \
{0.6012167930930162, -0.4368095687330762, 0.6691306063588582}, 
     {0.6545084971874736, -0.475528258147577, 0.5877852522924731}, \
{0.6012167930930159, -0.54133803200073, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.6012167930930162, -0.4368095687330762, 0.6691306063588582}, 
     {0.6435822975543762, -0.3715724127386974, 0.6691306063588582}, \
{0.7006292692220366, -0.40450849718747406, 0.5877852522924731}, 
     {0.6545084971874736, -0.475528258147577, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.6435822975543762, -0.3715724127386974, 0.6691306063588582}, \
{0.6788965796854766, -0.3022642316338272, 0.6691306063588582}, 
     {0.7390738003669025, -0.32905685648334027, 0.5877852522924731}, \
{0.7006292692220366, -0.40450849718747406, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.6788965796854766, -0.3022642316338272, 0.6691306063588582}, 
     {0.7067727288213003, -0.22964438035431933, 0.6691306063588582}, \
{0.7694208842938134, -0.25000000000000017, 0.5877852522924731}, 
     {0.7390738003669025, -0.32905685648334027, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.7067727288213003, -0.22964438035431933, 0.6691306063588582}, \
{0.7269053280384558, -0.1545084971874741, 0.6691306063588582}, 
     {0.7913380320007295, -0.16820409120079746, 0.5877852522924731}, \
{0.7694208842938134, -0.25000000000000017, 0.5877852522924731}}]}, 
  {CMYKColor[0.2833333333333333, 0.5, 0.975, 0.1], \
Polygon[{{0.7269053280384558, -0.1545084971874741, 0.6691306063588582}, 
     {0.7390738003669027, -0.07767978659246116, 0.6691306063588582}, \
{0.8045851146309164, -0.08456530317942978, 0.5877852522924731}, 
     {0.7913380320007295, -0.16820409120079746, 0.5877852522924731}}]}, \
{CMYKColor[0.2833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.7390738003669027, -0.07767978659246116, 0.6691306063588582}, \
{0.7431448254773941, -1.820119750179677*^-16, 0.6691306063588582}, 
     {0.8090169943749475, -1.9814547033236862*^-16, 0.5877852522924731}, \
{0.8045851146309164, -0.08456530317942978, 0.5877852522924731}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.8090169943749475, 0., 0.5877852522924731}, 
     {0.8045851146309164, 0.0845653031794291, 0.5877852522924731}, \
{0.8612812260087741, 0.09052430460833644, 0.5000000000000001}, 
     {0.8660254037844386, 0., 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.025, 0.1], 
   Polygon[{{0.8045851146309164, 0.0845653031794291, 0.5877852522924731}, \
{0.7913380320007296, 0.168204091200797, 0.5877852522924731}, 
     {0.8471006708862739, 0.18005680599195537, 0.5000000000000001}, \
{0.8612812260087741, 0.09052430460833644, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.7913380320007296, 0.168204091200797, 0.5877852522924731}, 
     {0.7694208842938134, 0.24999999999999997, 0.5877852522924731}, \
{0.8236391035463319, 0.2676165673298174, 0.5000000000000001}, 
     {0.8471006708862739, 0.18005680599195537, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.7694208842938134, 0.24999999999999997, 0.5877852522924731}, \
{0.7390738003669028, 0.3290568564833396, 0.5877852522924731}, 
     {0.7911535738303732, 0.3522442655536469, 0.5000000000000001}, \
{0.8236391035463319, 0.2676165673298174, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.075, 0.1], \
Polygon[{{0.7390738003669028, 0.3290568564833396, 0.5877852522924731}, 
     {0.7006292692220368, 0.40450849718747367, 0.5877852522924731}, {0.75, \
0.43301270189221924, 0.5000000000000001}, 
     {0.7911535738303732, 0.3522442655536469, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.7006292692220368, 0.40450849718747367, 0.5877852522924731}, \
{0.6545084971874737, 0.4755282581475768, 0.5877852522924731}, 
     {0.7006292692220367, 0.5090369604551271, 0.5000000000000001}, {0.75, \
0.43301270189221924, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.6545084971874737, 0.4755282581475768, 0.5877852522924731}, 
     {0.6012167930930165, 0.5413380320007295, 0.5877852522924731}, \
{0.6435822975543766, 0.5794841035564563, 0.5000000000000001}, 
     {0.7006292692220367, 0.5090369604551271, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.125, 0.1], 
   Polygon[{{0.6012167930930165, 0.5413380320007295, 0.5877852522924731}, \
{0.5413380320007296, 0.6012167930930162, 0.5877852522924731}, 
     {0.5794841035564564, 0.6435822975543765, 0.5000000000000001}, \
{0.6435822975543766, 0.5794841035564563, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.5413380320007296, 0.6012167930930162, 0.5877852522924731}, 
     {0.4755282581475768, 0.6545084971874737, 0.5877852522924731}, \
{0.5090369604551271, 0.7006292692220367, 0.5000000000000001}, 
     {0.5794841035564564, 0.6435822975543765, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.4755282581475768, 0.6545084971874737, 0.5877852522924731}, \
{0.40450849718747384, 0.7006292692220367, 0.5877852522924731}, 
     {0.4330127018922194, 0.7499999999999999, 0.5000000000000001}, \
{0.5090369604551271, 0.7006292692220367, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.175, 0.1], \
Polygon[{{0.40450849718747384, 0.7006292692220367, 0.5877852522924731}, 
     {0.3290568564833398, 0.7390738003669028, 0.5877852522924731}, \
{0.3522442655536471, 0.7911535738303732, 0.5000000000000001}, 
     {0.4330127018922194, 0.7499999999999999, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.3290568564833398, 0.7390738003669028, 0.5877852522924731}, \
{0.25000000000000006, 0.7694208842938134, 0.5877852522924731}, 
     {0.2676165673298175, 0.8236391035463319, 0.5000000000000001}, \
{0.3522442655536471, 0.7911535738303732, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.25000000000000006, 0.7694208842938134, 0.5877852522924731}, 
     {0.1682040912007971, 0.7913380320007295, 0.5877852522924731}, \
{0.18005680599195548, 0.8471006708862738, 0.5000000000000001}, 
     {0.2676165673298175, 0.8236391035463319, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.225, 0.1], 
   Polygon[{{0.1682040912007971, 0.7913380320007295, 0.5877852522924731}, \
{0.08456530317942927, 0.8045851146309164, 0.5877852522924731}, 
     {0.09052430460833663, 0.8612812260087741, 0.5000000000000001}, \
{0.18005680599195548, 0.8471006708862738, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.08456530317942927, 0.8045851146309164, 0.5877852522924731}, 
     {4.9536367583092156*^-17, 0.8090169943749475, 0.5877852522924731}, \
{5.302701060230067*^-17, 0.8660254037844386, 0.5000000000000001}, 
     {0.09052430460833663, 0.8612812260087741, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{4.9536367583092156*^-17, 0.8090169943749475, \
0.5877852522924731}, {-0.084565303179429, 0.8045851146309165, \
0.5877852522924731}, 
     {-0.09052430460833634, 0.8612812260087742, 0.5000000000000001}, \
{5.302701060230067*^-17, 0.8660254037844386, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.275, 0.1], \
Polygon[{{-0.084565303179429, 0.8045851146309165, 0.5877852522924731}, 
     {-0.16820409120079685, 0.7913380320007296, 0.5877852522924731}, \
{-0.1800568059919552, 0.8471006708862739, 0.5000000000000001}, 
     {-0.09052430460833634, 0.8612812260087742, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.16820409120079685, 0.7913380320007296, 0.5877852522924731}, \
{-0.24999999999999994, 0.7694208842938134, 0.5877852522924731}, 
     {-0.26761656732981737, 0.823639103546332, 0.5000000000000001}, \
{-0.1800568059919552, 0.8471006708862739, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.24999999999999994, 0.7694208842938134, 0.5877852522924731}, 
     {-0.32905685648333954, 0.739073800366903, 0.5877852522924731}, \
{-0.3522442655536468, 0.7911535738303732, 0.5000000000000001}, 
     {-0.26761656732981737, 0.823639103546332, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.325, 0.1], 
   Polygon[{{-0.32905685648333954, 0.739073800366903, 0.5877852522924731}, \
{-0.40450849718747356, 0.7006292692220368, 0.5877852522924731}, 
     {-0.43301270189221913, 0.75, 0.5000000000000001}, {-0.3522442655536468, \
0.7911535738303732, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.40450849718747356, 0.7006292692220368, 0.5877852522924731}, 
     {-0.4755282581475767, 0.6545084971874737, 0.5877852522924731}, \
{-0.509036960455127, 0.7006292692220367, 0.5000000000000001}, 
     {-0.43301270189221913, 0.75, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.4755282581475767, 0.6545084971874737, 0.5877852522924731}, \
{-0.5413380320007293, 0.6012167930930166, 0.5877852522924731}, 
     {-0.5794841035564562, 0.6435822975543767, 0.5000000000000001}, \
{-0.509036960455127, 0.7006292692220367, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.375, 0.1], \
Polygon[{{-0.5413380320007293, 0.6012167930930166, 0.5877852522924731}, 
     {-0.6012167930930162, 0.5413380320007297, 0.5877852522924731}, \
{-0.6435822975543763, 0.5794841035564565, 0.5000000000000001}, 
     {-0.5794841035564562, 0.6435822975543767, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.6012167930930162, 0.5413380320007297, 0.5877852522924731}, \
{-0.6545084971874736, 0.4755282581475769, 0.5877852522924731}, 
     {-0.7006292692220366, 0.5090369604551273, 0.5000000000000001}, \
{-0.6435822975543763, 0.5794841035564565, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.6545084971874736, 0.4755282581475769, 0.5877852522924731}, 
     {-0.7006292692220366, 0.404508497187474, 0.5877852522924731}, \
{-0.7499999999999998, 0.4330127018922196, 0.5000000000000001}, 
     {-0.7006292692220366, 0.5090369604551273, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.425, 0.1], 
   Polygon[{{-0.7006292692220366, 0.404508497187474, 0.5877852522924731}, \
{-0.7390738003669027, 0.3290568564833398, 0.5877852522924731}, 
     {-0.7911535738303731, 0.35224426555364713, 0.5000000000000001}, \
{-0.7499999999999998, 0.4330127018922196, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.7390738003669027, 0.3290568564833398, 0.5877852522924731}, 
     {-0.7694208842938134, 0.25000000000000006, 0.5877852522924731}, \
{-0.8236391035463319, 0.2676165673298175, 0.5000000000000001}, 
     {-0.7911535738303731, 0.35224426555364713, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.7694208842938134, 0.25000000000000006, 0.5877852522924731}, \
{-0.7913380320007295, 0.16820409120079735, 0.5877852522924731}, 
     {-0.8471006708862738, 0.18005680599195573, 0.5000000000000001}, \
{-0.8236391035463319, 0.2676165673298175, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.475, 0.1], \
Polygon[{{-0.7913380320007295, 0.16820409120079735, 0.5877852522924731}, 
     {-0.8045851146309164, 0.08456530317942933, 0.5877852522924731}, \
{-0.8612812260087741, 0.09052430460833669, 0.5000000000000001}, 
     {-0.8471006708862738, 0.18005680599195573, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.8045851146309164, 0.08456530317942933, 0.5877852522924731}, \
{-0.8090169943749475, 9.907273516618431*^-17, 0.5877852522924731}, 
     {-0.8660254037844386, 1.0605402120460133*^-16, 0.5000000000000001}, \
{-0.8612812260087741, 0.09052430460833669, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.8090169943749475, 9.907273516618431*^-17, 0.5877852522924731}, 
     {-0.8045851146309165, -0.08456530317942877, 0.5877852522924731}, \
{-0.8612812260087742, -0.09052430460833609, 0.5000000000000001}, 
     {-0.8660254037844386, 1.0605402120460133*^-16, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.525, 0.1], 
   Polygon[{{-0.8045851146309165, -0.08456530317942877, 0.5877852522924731}, \
{-0.7913380320007296, -0.1682040912007968, 0.5877852522924731}, 
     {-0.8471006708862739, -0.18005680599195514, 0.5000000000000001}, \
{-0.8612812260087742, -0.09052430460833609, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.7913380320007296, -0.1682040912007968, 0.5877852522924731}, 
     {-0.7694208842938134, -0.2499999999999999, 0.5877852522924731}, \
{-0.823639103546332, -0.2676165673298173, 0.5000000000000001}, 
     {-0.8471006708862739, -0.18005680599195514, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.7694208842938134, -0.2499999999999999, 0.5877852522924731}, \
{-0.739073800366903, -0.3290568564833394, 0.5877852522924731}, 
     {-0.7911535738303733, -0.35224426555364663, 0.5000000000000001}, \
{-0.823639103546332, -0.2676165673298173, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.575, 0.1], \
Polygon[{{-0.739073800366903, -0.3290568564833394, 0.5877852522924731}, 
     {-0.7006292692220369, -0.4045084971874735, 0.5877852522924731}, \
{-0.7500000000000001, -0.4330127018922191, 0.5000000000000001}, 
     {-0.7911535738303733, -0.35224426555364663, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.7006292692220369, -0.4045084971874735, 0.5877852522924731}, \
{-0.6545084971874738, -0.4755282581475767, 0.5877852522924731}, 
     {-0.7006292692220368, -0.509036960455127, 0.5000000000000001}, \
{-0.7500000000000001, -0.4330127018922191, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.6545084971874738, -0.4755282581475767, 0.5877852522924731}, 
     {-0.6012167930930167, -0.5413380320007293, 0.5877852522924731}, \
{-0.6435822975543768, -0.5794841035564562, 0.5000000000000001}, 
     {-0.7006292692220368, -0.509036960455127, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.625, 0.1], 
   Polygon[{{-0.6012167930930167, -0.5413380320007293, 0.5877852522924731}, \
{-0.5413380320007297, -0.6012167930930162, 0.5877852522924731}, 
     {-0.5794841035564566, -0.6435822975543763, 0.5000000000000001}, \
{-0.6435822975543768, -0.5794841035564562, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.5413380320007297, -0.6012167930930162, 0.5877852522924731}, 
     {-0.4755282581475769, -0.6545084971874736, 0.5877852522924731}, \
{-0.5090369604551273, -0.7006292692220366, 0.5000000000000001}, 
     {-0.5794841035564566, -0.6435822975543763, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.4755282581475769, -0.6545084971874736, 0.5877852522924731}, \
{-0.40450849718747406, -0.7006292692220366, 0.5877852522924731}, 
     {-0.4330127018922197, -0.7499999999999997, 0.5000000000000001}, \
{-0.5090369604551273, -0.7006292692220366, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.675, 0.1], \
Polygon[{{-0.40450849718747406, -0.7006292692220366, 0.5877852522924731}, 
     {-0.3290568564833402, -0.7390738003669025, 0.5877852522924731}, \
{-0.3522442655536475, -0.7911535738303729, 0.5000000000000001}, 
     {-0.4330127018922197, -0.7499999999999997, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.3290568564833402, -0.7390738003669025, 0.5877852522924731}, \
{-0.2500000000000001, -0.7694208842938134, 0.5877852522924731}, 
     {-0.26761656732981753, -0.8236391035463319, 0.5000000000000001}, \
{-0.3522442655536475, -0.7911535738303729, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.2500000000000001, -0.7694208842938134, 0.5877852522924731}, 
     {-0.16820409120079738, -0.7913380320007295, 0.5877852522924731}, \
{-0.18005680599195578, -0.8471006708862738, 0.5000000000000001}, 
     {-0.26761656732981753, -0.8236391035463319, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.725, 0.1], 
   Polygon[{{-0.16820409120079738, -0.7913380320007295, 0.5877852522924731}, \
{-0.08456530317942973, -0.8045851146309164, 0.5877852522924731}, 
     {-0.09052430460833712, -0.8612812260087741, 0.5000000000000001}, \
{-0.18005680599195578, -0.8471006708862738, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.08456530317942973, -0.8045851146309164, 0.5877852522924731}, 
     {-1.4860910274927647*^-16, -0.8090169943749475, 0.5877852522924731}, \
{-1.59081031806902*^-16, -0.8660254037844386, 0.5000000000000001}, 
     {-0.09052430460833712, -0.8612812260087741, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.4860910274927647*^-16, -0.8090169943749475, \
0.5877852522924731}, {0.08456530317942872, -0.8045851146309165, \
0.5877852522924731}, 
     {0.09052430460833603, -0.8612812260087742, 0.5000000000000001}, \
{-1.59081031806902*^-16, -0.8660254037844386, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.775, 0.1], \
Polygon[{{0.08456530317942872, -0.8045851146309165, 0.5877852522924731}, 
     {0.1682040912007964, -0.7913380320007297, 0.5877852522924731}, \
{0.18005680599195473, -0.8471006708862739, 0.5000000000000001}, 
     {0.09052430460833603, -0.8612812260087742, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.1682040912007964, -0.7913380320007297, 0.5877852522924731}, \
{0.24999999999999986, -0.7694208842938134, 0.5877852522924731}, 
     {0.26761656732981726, -0.823639103546332, 0.5000000000000001}, \
{0.18005680599195473, -0.8471006708862739, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.24999999999999986, -0.7694208842938134, 0.5877852522924731}, 
     {0.3290568564833393, -0.739073800366903, 0.5877852522924731}, \
{0.3522442655536466, -0.7911535738303733, 0.5000000000000001}, 
     {0.26761656732981726, -0.823639103546332, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.825, 0.1], 
   Polygon[{{0.3290568564833393, -0.739073800366903, 0.5877852522924731}, \
{0.40450849718747317, -0.7006292692220372, 0.5877852522924731}, 
     {0.43301270189221874, -0.7500000000000003, 0.5000000000000001}, \
{0.3522442655536466, -0.7911535738303733, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.40450849718747317, -0.7006292692220372, 0.5877852522924731}, 
     {0.47552825814757665, -0.6545084971874738, 0.5877852522924731}, \
{0.5090369604551269, -0.7006292692220368, 0.5000000000000001}, 
     {0.43301270189221874, -0.7500000000000003, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.47552825814757665, -0.6545084971874738, 0.5877852522924731}, \
{0.5413380320007293, -0.6012167930930167, 0.5877852522924731}, 
     {0.5794841035564561, -0.6435822975543768, 0.5000000000000001}, \
{0.5090369604551269, -0.7006292692220368, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.875, 0.1], \
Polygon[{{0.5413380320007293, -0.6012167930930167, 0.5877852522924731}, 
     {0.6012167930930159, -0.54133803200073, 0.5877852522924731}, \
{0.643582297554376, -0.579484103556457, 0.5000000000000001}, 
     {0.5794841035564561, -0.6435822975543768, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.6012167930930159, -0.54133803200073, 0.5877852522924731}, \
{0.6545084971874736, -0.475528258147577, 0.5877852522924731}, 
     {0.7006292692220366, -0.5090369604551274, 0.5000000000000001}, \
{0.643582297554376, -0.579484103556457, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.6545084971874736, -0.475528258147577, 0.5877852522924731}, 
     {0.7006292692220366, -0.40450849718747406, 0.5877852522924731}, \
{0.7499999999999997, -0.4330127018922197, 0.5000000000000001}, 
     {0.7006292692220366, -0.5090369604551274, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.7006292692220366, -0.40450849718747406, 0.5877852522924731}, \
{0.7390738003669025, -0.32905685648334027, 0.5877852522924731}, 
     {0.7911535738303729, -0.3522442655536476, 0.5000000000000001}, \
{0.7499999999999997, -0.4330127018922197, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.7390738003669025, -0.32905685648334027, 0.5877852522924731}, 
     {0.7694208842938134, -0.25000000000000017, 0.5877852522924731}, \
{0.8236391035463319, -0.2676165673298176, 0.5000000000000001}, 
     {0.7911535738303729, -0.3522442655536476, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.7694208842938134, -0.25000000000000017, 0.5877852522924731}, \
{0.7913380320007295, -0.16820409120079746, 0.5877852522924731}, 
     {0.8471006708862738, -0.18005680599195584, 0.5000000000000001}, \
{0.8236391035463319, -0.2676165673298176, 0.5000000000000001}}]}, 
  {CMYKColor[0.31666666666666665, 0.5, 0.975, 0.1], \
Polygon[{{0.7913380320007295, -0.16820409120079746, 0.5877852522924731}, 
     {0.8045851146309164, -0.08456530317942978, 0.5877852522924731}, \
{0.8612812260087741, -0.09052430460833717, 0.5000000000000001}, 
     {0.8471006708862738, -0.18005680599195584, 0.5000000000000001}}]}, \
{CMYKColor[0.31666666666666665, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.8045851146309164, -0.08456530317942978, 0.5877852522924731}, \
{0.8090169943749475, -1.9814547033236862*^-16, 0.5877852522924731}, 
     {0.8660254037844386, -2.1210804240920267*^-16, 0.5000000000000001}, \
{0.8612812260087741, -0.09052430460833717, 0.5000000000000001}}]}, 
  {CMYKColor[0.35, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.8660254037844386, 0., 0.5000000000000001}, 
     {0.8612812260087741, 0.09052430460833644, 0.5000000000000001}, \
{0.908540960039796, 0.09549150281252627, 0.4067366430758004}, 
     {0.9135454576426009, 0., 0.4067366430758004}}]}, {CMYKColor[0.35, 0.5, \
0.025, 0.1], 
   Polygon[{{0.8612812260087741, 0.09052430460833644, 0.5000000000000001}, \
{0.8471006708862739, 0.18005680599195537, 0.5000000000000001}, 
     {0.8935822975543766, 0.18993678073735687, 0.4067366430758004}, \
{0.908540960039796, 0.09549150281252627, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.8471006708862739, 0.18005680599195537, 0.5000000000000001}, 
     {0.8236391035463319, 0.2676165673298174, 0.5000000000000001}, \
{0.8688333604228338, 0.28230107154560236, 0.4067366430758004}, 
     {0.8935822975543766, 0.18993678073735687, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.8236391035463319, 0.2676165673298174, 0.5000000000000001}, \
{0.7911535738303732, 0.3522442655536469, 0.5000000000000001}, 
     {0.834565303179429, 0.37157241273869707, 0.4067366430758004}, \
{0.8688333604228338, 0.28230107154560236, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.075, 0.1], Polygon[{{0.7911535738303732, \
0.3522442655536469, 0.5000000000000001}, 
     {0.75, 0.43301270189221924, 0.5000000000000001}, {0.7911535738303732, \
0.4567727288213004, 0.4067366430758004}, 
     {0.834565303179429, 0.37157241273869707, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.75, 0.43301270189221924, 0.5000000000000001}, \
{0.7006292692220367, 0.5090369604551271, 0.5000000000000001}, 
     {0.7390738003669028, 0.536968547301099, 0.4067366430758004}, \
{0.7911535738303732, 0.4567727288213004, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.7006292692220367, 0.5090369604551271, 0.5000000000000001}, 
     {0.6435822975543766, 0.5794841035564563, 0.5000000000000001}, \
{0.678896579685477, 0.6112812260087741, 0.4067366430758004}, 
     {0.7390738003669028, 0.536968547301099, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.125, 0.1], 
   Polygon[{{0.6435822975543766, 0.5794841035564563, 0.5000000000000001}, \
{0.5794841035564564, 0.6435822975543765, 0.5000000000000001}, 
     {0.6112812260087742, 0.6788965796854768, 0.4067366430758004}, \
{0.678896579685477, 0.6112812260087741, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.5794841035564564, 0.6435822975543765, 0.5000000000000001}, 
     {0.5090369604551271, 0.7006292692220367, 0.5000000000000001}, \
{0.536968547301099, 0.7390738003669028, 0.4067366430758004}, 
     {0.6112812260087742, 0.6788965796854768, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.5090369604551271, 0.7006292692220367, 0.5000000000000001}, \
{0.4330127018922194, 0.7499999999999999, 0.5000000000000001}, 
     {0.45677272882130054, 0.7911535738303732, 0.4067366430758004}, \
{0.536968547301099, 0.7390738003669028, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.175, 0.1], Polygon[{{0.4330127018922194, \
0.7499999999999999, 0.5000000000000001}, 
     {0.3522442655536471, 0.7911535738303732, 0.5000000000000001}, \
{0.37157241273869723, 0.834565303179429, 0.4067366430758004}, 
     {0.45677272882130054, 0.7911535738303732, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.3522442655536471, 0.7911535738303732, 0.5000000000000001}, \
{0.2676165673298175, 0.8236391035463319, 0.5000000000000001}, 
     {0.2823010715456024, 0.8688333604228338, 0.4067366430758004}, \
{0.37157241273869723, 0.834565303179429, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.2676165673298175, 0.8236391035463319, 0.5000000000000001}, 
     {0.18005680599195548, 0.8471006708862738, 0.5000000000000001}, \
{0.189936780737357, 0.8935822975543765, 0.4067366430758004}, 
     {0.2823010715456024, 0.8688333604228338, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.225, 0.1], 
   Polygon[{{0.18005680599195548, 0.8471006708862738, 0.5000000000000001}, \
{0.09052430460833663, 0.8612812260087741, 0.5000000000000001}, 
     {0.09549150281252647, 0.908540960039796, 0.4067366430758004}, \
{0.189936780737357, 0.8935822975543765, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.09052430460833663, 0.8612812260087741, 0.5000000000000001}, 
     {5.302701060230067*^-17, 0.8660254037844386, 0.5000000000000001}, \
{5.593667859673502*^-17, 0.9135454576426009, 0.4067366430758004}, 
     {0.09549150281252647, 0.908540960039796, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{5.302701060230067*^-17, 0.8660254037844386, 0.5000000000000001}, \
{-0.09052430460833634, 0.8612812260087742, 0.5000000000000001}, 
     {-0.09549150281252616, 0.9085409600397961, 0.4067366430758004}, \
{5.593667859673502*^-17, 0.9135454576426009, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.275, 0.1], Polygon[{{-0.09052430460833634, \
0.8612812260087742, 0.5000000000000001}, 
     {-0.1800568059919552, 0.8471006708862739, 0.5000000000000001}, \
{-0.1899367807373567, 0.8935822975543766, 0.4067366430758004}, 
     {-0.09549150281252616, 0.9085409600397961, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.1800568059919552, 0.8471006708862739, 0.5000000000000001}, \
{-0.26761656732981737, 0.823639103546332, 0.5000000000000001}, 
     {-0.2823010715456023, 0.8688333604228338, 0.4067366430758004}, \
{-0.1899367807373567, 0.8935822975543766, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.26761656732981737, 0.823639103546332, 0.5000000000000001}, 
     {-0.3522442655536468, 0.7911535738303732, 0.5000000000000001}, \
{-0.37157241273869696, 0.8345653031794291, 0.4067366430758004}, 
     {-0.2823010715456023, 0.8688333604228338, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.325, 0.1], 
   Polygon[{{-0.3522442655536468, 0.7911535738303732, 0.5000000000000001}, \
{-0.43301270189221913, 0.75, 0.5000000000000001}, 
     {-0.4567727288213002, 0.7911535738303732, 0.4067366430758004}, \
{-0.37157241273869696, 0.8345653031794291, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.43301270189221913, 0.75, 0.5000000000000001}, 
     {-0.509036960455127, 0.7006292692220367, 0.5000000000000001}, \
{-0.5369685473010989, 0.7390738003669028, 0.4067366430758004}, 
     {-0.4567727288213002, 0.7911535738303732, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.509036960455127, 0.7006292692220367, 0.5000000000000001}, \
{-0.5794841035564562, 0.6435822975543767, 0.5000000000000001}, 
     {-0.6112812260087739, 0.6788965796854771, 0.4067366430758004}, \
{-0.5369685473010989, 0.7390738003669028, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.375, 0.1], Polygon[{{-0.5794841035564562, \
0.6435822975543767, 0.5000000000000001}, 
     {-0.6435822975543763, 0.5794841035564565, 0.5000000000000001}, \
{-0.6788965796854767, 0.6112812260087742, 0.4067366430758004}, 
     {-0.6112812260087739, 0.6788965796854771, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.6435822975543763, 0.5794841035564565, 0.5000000000000001}, \
{-0.7006292692220366, 0.5090369604551273, 0.5000000000000001}, 
     {-0.7390738003669027, 0.5369685473010991, 0.4067366430758004}, \
{-0.6788965796854767, 0.6112812260087742, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.7006292692220366, 0.5090369604551273, 0.5000000000000001}, 
     {-0.7499999999999998, 0.4330127018922196, 0.5000000000000001}, \
{-0.7911535738303731, 0.4567727288213007, 0.4067366430758004}, 
     {-0.7390738003669027, 0.5369685473010991, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.425, 0.1], 
   Polygon[{{-0.7499999999999998, 0.4330127018922196, 0.5000000000000001}, \
{-0.7911535738303731, 0.35224426555364713, 0.5000000000000001}, 
     {-0.834565303179429, 0.3715724127386973, 0.4067366430758004}, \
{-0.7911535738303731, 0.4567727288213007, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.7911535738303731, 0.35224426555364713, 0.5000000000000001}, 
     {-0.8236391035463319, 0.2676165673298175, 0.5000000000000001}, \
{-0.8688333604228338, 0.2823010715456024, 0.4067366430758004}, 
     {-0.834565303179429, 0.3715724127386973, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.8236391035463319, 0.2676165673298175, 0.5000000000000001}, \
{-0.8471006708862738, 0.18005680599195573, 0.5000000000000001}, 
     {-0.8935822975543765, 0.18993678073735726, 0.4067366430758004}, \
{-0.8688333604228338, 0.2823010715456024, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.475, 0.1], Polygon[{{-0.8471006708862738, \
0.18005680599195573, 0.5000000000000001}, 
     {-0.8612812260087741, 0.09052430460833669, 0.5000000000000001}, \
{-0.908540960039796, 0.09549150281252652, 0.4067366430758004}, 
     {-0.8935822975543765, 0.18993678073735726, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.8612812260087741, 0.09052430460833669, 0.5000000000000001}, \
{-0.8660254037844386, 1.0605402120460133*^-16, 0.5000000000000001}, 
     {-0.9135454576426009, 1.1187335719347004*^-16, 0.4067366430758004}, \
{-0.908540960039796, 0.09549150281252652, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.8660254037844386, 1.0605402120460133*^-16, 0.5000000000000001}, 
     {-0.8612812260087742, -0.09052430460833609, 0.5000000000000001}, \
{-0.9085409600397961, -0.0954915028125259, 0.4067366430758004}, 
     {-0.9135454576426009, 1.1187335719347004*^-16, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.525, 0.1], 
   Polygon[{{-0.8612812260087742, -0.09052430460833609, 0.5000000000000001}, \
{-0.8471006708862739, -0.18005680599195514, 0.5000000000000001}, 
     {-0.8935822975543766, -0.18993678073735665, 0.4067366430758004}, \
{-0.9085409600397961, -0.0954915028125259, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.8471006708862739, -0.18005680599195514, 0.5000000000000001}, 
     {-0.823639103546332, -0.2676165673298173, 0.5000000000000001}, \
{-0.8688333604228338, -0.28230107154560224, 0.4067366430758004}, 
     {-0.8935822975543766, -0.18993678073735665, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.823639103546332, -0.2676165673298173, 0.5000000000000001}, \
{-0.7911535738303733, -0.35224426555364663, 0.5000000000000001}, 
     {-0.8345653031794292, -0.37157241273869673, 0.4067366430758004}, \
{-0.8688333604228338, -0.28230107154560224, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.575, 0.1], Polygon[{{-0.7911535738303733, \
-0.35224426555364663, 0.5000000000000001}, 
     {-0.7500000000000001, -0.4330127018922191, 0.5000000000000001}, \
{-0.7911535738303733, -0.45677272882130016, 0.4067366430758004}, 
     {-0.8345653031794292, -0.37157241273869673, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.7500000000000001, -0.4330127018922191, 0.5000000000000001}, \
{-0.7006292692220368, -0.509036960455127, 0.5000000000000001}, 
     {-0.739073800366903, -0.5369685473010989, 0.4067366430758004}, \
{-0.7911535738303733, -0.45677272882130016, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.7006292692220368, -0.509036960455127, 0.5000000000000001}, 
     {-0.6435822975543768, -0.5794841035564562, 0.5000000000000001}, \
{-0.6788965796854772, -0.6112812260087739, 0.4067366430758004}, 
     {-0.739073800366903, -0.5369685473010989, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.625, 0.1], 
   Polygon[{{-0.6435822975543768, -0.5794841035564562, 0.5000000000000001}, \
{-0.5794841035564566, -0.6435822975543763, 0.5000000000000001}, 
     {-0.6112812260087743, -0.6788965796854767, 0.4067366430758004}, \
{-0.6788965796854772, -0.6112812260087739, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.5794841035564566, -0.6435822975543763, 0.5000000000000001}, 
     {-0.5090369604551273, -0.7006292692220366, 0.5000000000000001}, \
{-0.5369685473010991, -0.7390738003669027, 0.4067366430758004}, 
     {-0.6112812260087743, -0.6788965796854767, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.5090369604551273, -0.7006292692220366, 0.5000000000000001}, \
{-0.4330127018922197, -0.7499999999999997, 0.5000000000000001}, 
     {-0.4567727288213008, -0.791153573830373, 0.4067366430758004}, \
{-0.5369685473010991, -0.7390738003669027, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.675, 0.1], Polygon[{{-0.4330127018922197, \
-0.7499999999999997, 0.5000000000000001}, 
     {-0.3522442655536475, -0.7911535738303729, 0.5000000000000001}, \
{-0.37157241273869773, -0.8345653031794288, 0.4067366430758004}, 
     {-0.4567727288213008, -0.791153573830373, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.3522442655536475, -0.7911535738303729, 0.5000000000000001}, \
{-0.26761656732981753, -0.8236391035463319, 0.5000000000000001}, 
     {-0.28230107154560247, -0.8688333604228338, 0.4067366430758004}, \
{-0.37157241273869773, -0.8345653031794288, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.26761656732981753, -0.8236391035463319, 0.5000000000000001}, 
     {-0.18005680599195578, -0.8471006708862738, 0.5000000000000001}, \
{-0.1899367807373573, -0.8935822975543765, 0.4067366430758004}, 
     {-0.28230107154560247, -0.8688333604228338, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.725, 0.1], 
   Polygon[{{-0.18005680599195578, -0.8471006708862738, 0.5000000000000001}, \
{-0.09052430460833712, -0.8612812260087741, 0.5000000000000001}, 
     {-0.09549150281252698, -0.908540960039796, 0.4067366430758004}, \
{-0.1899367807373573, -0.8935822975543765, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.09052430460833712, -0.8612812260087741, 0.5000000000000001}, 
     {-1.59081031806902*^-16, -0.8660254037844386, 0.5000000000000001}, \
{-1.6781003579020505*^-16, -0.9135454576426009, 0.4067366430758004}, 
     {-0.09549150281252698, -0.908540960039796, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.59081031806902*^-16, -0.8660254037844386, \
0.5000000000000001}, {0.09052430460833603, -0.8612812260087742, \
0.5000000000000001}, 
     {0.09549150281252584, -0.9085409600397961, 0.4067366430758004}, \
{-1.6781003579020505*^-16, -0.9135454576426009, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.775, 0.1], Polygon[{{0.09052430460833603, \
-0.8612812260087742, 0.5000000000000001}, 
     {0.18005680599195473, -0.8471006708862739, 0.5000000000000001}, \
{0.18993678073735618, -0.8935822975543767, 0.4067366430758004}, 
     {0.09549150281252584, -0.9085409600397961, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.18005680599195473, -0.8471006708862739, 0.5000000000000001}, \
{0.26761656732981726, -0.823639103546332, 0.5000000000000001}, 
     {0.2823010715456022, -0.8688333604228338, 0.4067366430758004}, \
{0.18993678073735618, -0.8935822975543767, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.26761656732981726, -0.823639103546332, 0.5000000000000001}, 
     {0.3522442655536466, -0.7911535738303733, 0.5000000000000001}, \
{0.3715724127386967, -0.8345653031794292, 0.4067366430758004}, 
     {0.2823010715456022, -0.8688333604228338, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.825, 0.1], 
   Polygon[{{0.3522442655536466, -0.7911535738303733, 0.5000000000000001}, \
{0.43301270189221874, -0.7500000000000003, 0.5000000000000001}, 
     {0.4567727288212998, -0.7911535738303735, 0.4067366430758004}, \
{0.3715724127386967, -0.8345653031794292, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.43301270189221874, -0.7500000000000003, 0.5000000000000001}, 
     {0.5090369604551269, -0.7006292692220368, 0.5000000000000001}, \
{0.5369685473010988, -0.739073800366903, 0.4067366430758004}, 
     {0.4567727288212998, -0.7911535738303735, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.5090369604551269, -0.7006292692220368, 0.5000000000000001}, \
{0.5794841035564561, -0.6435822975543768, 0.5000000000000001}, 
     {0.6112812260087738, -0.6788965796854772, 0.4067366430758004}, \
{0.5369685473010988, -0.739073800366903, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.875, 0.1], Polygon[{{0.5794841035564561, \
-0.6435822975543768, 0.5000000000000001}, 
     {0.643582297554376, -0.579484103556457, 0.5000000000000001}, \
{0.6788965796854763, -0.6112812260087747, 0.4067366430758004}, 
     {0.6112812260087738, -0.6788965796854772, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.643582297554376, -0.579484103556457, 0.5000000000000001}, \
{0.7006292692220366, -0.5090369604551274, 0.5000000000000001}, 
     {0.7390738003669027, -0.5369685473010992, 0.4067366430758004}, \
{0.6788965796854763, -0.6112812260087747, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.7006292692220366, -0.5090369604551274, 0.5000000000000001}, 
     {0.7499999999999997, -0.4330127018922197, 0.5000000000000001}, \
{0.791153573830373, -0.4567727288213008, 0.4067366430758004}, 
     {0.7390738003669027, -0.5369685473010992, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.7499999999999997, -0.4330127018922197, 0.5000000000000001}, \
{0.7911535738303729, -0.3522442655536476, 0.5000000000000001}, 
     {0.8345653031794288, -0.3715724127386978, 0.4067366430758004}, \
{0.791153573830373, -0.4567727288213008, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.7911535738303729, -0.3522442655536476, 0.5000000000000001}, 
     {0.8236391035463319, -0.2676165673298176, 0.5000000000000001}, \
{0.8688333604228338, -0.2823010715456025, 0.4067366430758004}, 
     {0.8345653031794288, -0.3715724127386978, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.8236391035463319, -0.2676165673298176, 0.5000000000000001}, \
{0.8471006708862738, -0.18005680599195584, 0.5000000000000001}, 
     {0.8935822975543765, -0.18993678073735737, 0.4067366430758004}, \
{0.8688333604228338, -0.2823010715456025, 0.4067366430758004}}]}, 
  {CMYKColor[0.35, 0.5, 0.975, 0.1], Polygon[{{0.8471006708862738, \
-0.18005680599195584, 0.5000000000000001}, 
     {0.8612812260087741, -0.09052430460833717, 0.5000000000000001}, \
{0.908540960039796, -0.09549150281252705, 0.4067366430758004}, 
     {0.8935822975543765, -0.18993678073735737, 0.4067366430758004}}]}, \
{CMYKColor[0.35, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.8612812260087741, -0.09052430460833717, 0.5000000000000001}, \
{0.8660254037844386, -2.1210804240920267*^-16, 0.5000000000000001}, 
     {0.9135454576426009, -2.237467143869401*^-16, 0.4067366430758004}, \
{0.908540960039796, -0.09549150281252705, 0.4067366430758004}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.9135454576426009, 0., 0.4067366430758004}, 
     {0.908540960039796, 0.09549150281252627, 0.4067366430758004}, \
{0.9458465291882032, 0.09941247612902042, 0.30901699437494745}, 
     {0.9510565162951535, 0., 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{0.908540960039796, 0.09549150281252627, 0.4067366430758004}, \
{0.8935822975543766, 0.18993678073735687, 0.4067366430758004}, 
     {0.930273649576356, 0.19773576836617324, 0.30901699437494745}, \
{0.9458465291882032, 0.09941247612902042, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.8935822975543766, 0.18993678073735687, 0.4067366430758004}, 
     {0.8688333604228338, 0.28230107154560236, 0.4067366430758004}, \
{0.9045084971874736, 0.2938926261462365, 0.30901699437494745}, 
     {0.930273649576356, 0.19773576836617324, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.8688333604228338, 0.28230107154560236, 0.4067366430758004}, \
{0.834565303179429, 0.37157241273869707, 0.4067366430758004}, 
     {0.8688333604228338, 0.38682953481325577, 0.30901699437494745}, \
{0.9045084971874736, 0.2938926261462365, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.075, 0.1], \
Polygon[{{0.834565303179429, 0.37157241273869707, 0.4067366430758004}, 
     {0.7911535738303732, 0.4567727288213004, 0.4067366430758004}, \
{0.823639103546332, 0.4755282581475767, 0.30901699437494745}, 
     {0.8688333604228338, 0.38682953481325577, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.7911535738303732, 0.4567727288213004, 0.4067366430758004}, \
{0.7390738003669028, 0.536968547301099, 0.4067366430758004}, 
     {0.7694208842938134, 0.5590169943749475, 0.30901699437494745}, \
{0.823639103546332, 0.4755282581475767, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.7390738003669028, 0.536968547301099, 0.4067366430758004}, 
     {0.678896579685477, 0.6112812260087741, 0.4067366430758004}, \
{0.7067727288213005, 0.6363810234301193, 0.30901699437494745}, 
     {0.7694208842938134, 0.5590169943749475, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{0.678896579685477, 0.6112812260087741, 0.4067366430758004}, \
{0.6112812260087742, 0.6788965796854768, 0.4067366430758004}, 
     {0.6363810234301194, 0.7067727288213003, 0.30901699437494745}, \
{0.7067727288213005, 0.6363810234301193, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.6112812260087742, 0.6788965796854768, 0.4067366430758004}, 
     {0.536968547301099, 0.7390738003669028, 0.4067366430758004}, \
{0.5590169943749475, 0.7694208842938134, 0.30901699437494745}, 
     {0.6363810234301194, 0.7067727288213003, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.536968547301099, 0.7390738003669028, 0.4067366430758004}, \
{0.45677272882130054, 0.7911535738303732, 0.4067366430758004}, 
     {0.4755282581475769, 0.8236391035463319, 0.30901699437494745}, \
{0.5590169943749475, 0.7694208842938134, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.175, 0.1], \
Polygon[{{0.45677272882130054, 0.7911535738303732, 0.4067366430758004}, 
     {0.37157241273869723, 0.834565303179429, 0.4067366430758004}, \
{0.386829534813256, 0.8688333604228338, 0.30901699437494745}, 
     {0.4755282581475769, 0.8236391035463319, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.37157241273869723, 0.834565303179429, 0.4067366430758004}, \
{0.2823010715456024, 0.8688333604228338, 0.4067366430758004}, 
     {0.29389262614623657, 0.9045084971874736, 0.30901699437494745}, \
{0.386829534813256, 0.8688333604228338, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.2823010715456024, 0.8688333604228338, 0.4067366430758004}, 
     {0.189936780737357, 0.8935822975543765, 0.4067366430758004}, \
{0.19773576836617338, 0.9302736495763559, 0.30901699437494745}, 
     {0.29389262614623657, 0.9045084971874736, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{0.189936780737357, 0.8935822975543765, 0.4067366430758004}, \
{0.09549150281252647, 0.908540960039796, 0.4067366430758004}, 
     {0.09941247612902063, 0.9458465291882032, 0.30901699437494745}, \
{0.19773576836617338, 0.9302736495763559, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.09549150281252647, 0.908540960039796, 0.4067366430758004}, 
     {5.593667859673502*^-17, 0.9135454576426009, 0.4067366430758004}, \
{5.823349263496101*^-17, 0.9510565162951535, 0.30901699437494745}, 
     {0.09941247612902063, 0.9458465291882032, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{5.593667859673502*^-17, 0.9135454576426009, 0.4067366430758004}, \
{-0.09549150281252616, 0.9085409600397961, 0.4067366430758004}, 
     {-0.0994124761290203, 0.9458465291882033, 0.30901699437494745}, \
{5.823349263496101*^-17, 0.9510565162951535, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.275, 0.1], \
Polygon[{{-0.09549150281252616, 0.9085409600397961, 0.4067366430758004}, 
     {-0.1899367807373567, 0.8935822975543766, 0.4067366430758004}, \
{-0.19773576836617304, 0.930273649576356, 0.30901699437494745}, 
     {-0.0994124761290203, 0.9458465291882033, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.1899367807373567, 0.8935822975543766, 0.4067366430758004}, \
{-0.2823010715456023, 0.8688333604228338, 0.4067366430758004}, 
     {-0.29389262614623646, 0.9045084971874737, 0.30901699437494745}, \
{-0.19773576836617304, 0.930273649576356, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.2823010715456023, 0.8688333604228338, 0.4067366430758004}, 
     {-0.37157241273869696, 0.8345653031794291, 0.4067366430758004}, \
{-0.38682953481325566, 0.8688333604228339, 0.30901699437494745}, 
     {-0.29389262614623646, 0.9045084971874737, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{-0.37157241273869696, 0.8345653031794291, 0.4067366430758004}, \
{-0.4567727288213002, 0.7911535738303732, 0.4067366430758004}, 
     {-0.47552825814757654, 0.823639103546332, 0.30901699437494745}, \
{-0.38682953481325566, 0.8688333604228339, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.4567727288213002, 0.7911535738303732, 0.4067366430758004}, 
     {-0.5369685473010989, 0.7390738003669028, 0.4067366430758004}, \
{-0.5590169943749473, 0.7694208842938134, 0.30901699437494745}, 
     {-0.47552825814757654, 0.823639103546332, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.5369685473010989, 0.7390738003669028, 0.4067366430758004}, \
{-0.6112812260087739, 0.6788965796854771, 0.4067366430758004}, 
     {-0.6363810234301192, 0.7067727288213006, 0.30901699437494745}, \
{-0.5590169943749473, 0.7694208842938134, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.375, 0.1], \
Polygon[{{-0.6112812260087739, 0.6788965796854771, 0.4067366430758004}, 
     {-0.6788965796854767, 0.6112812260087742, 0.4067366430758004}, \
{-0.7067727288213003, 0.6363810234301195, 0.30901699437494745}, 
     {-0.6363810234301192, 0.7067727288213006, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.6788965796854767, 0.6112812260087742, 0.4067366430758004}, \
{-0.7390738003669027, 0.5369685473010991, 0.4067366430758004}, 
     {-0.7694208842938133, 0.5590169943749476, 0.30901699437494745}, \
{-0.7067727288213003, 0.6363810234301195, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.7390738003669027, 0.5369685473010991, 0.4067366430758004}, 
     {-0.7911535738303731, 0.4567727288213007, 0.4067366430758004}, \
{-0.8236391035463317, 0.4755282581475771, 0.30901699437494745}, 
     {-0.7694208842938133, 0.5590169943749476, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{-0.7911535738303731, 0.4567727288213007, 0.4067366430758004}, \
{-0.834565303179429, 0.3715724127386973, 0.4067366430758004}, 
     {-0.8688333604228337, 0.38682953481325605, 0.30901699437494745}, \
{-0.8236391035463317, 0.4755282581475771, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.834565303179429, 0.3715724127386973, 0.4067366430758004}, 
     {-0.8688333604228338, 0.2823010715456024, 0.4067366430758004}, \
{-0.9045084971874736, 0.2938926261462366, 0.30901699437494745}, 
     {-0.8688333604228337, 0.38682953481325605, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.8688333604228338, 0.2823010715456024, 0.4067366430758004}, \
{-0.8935822975543765, 0.18993678073735726, 0.4067366430758004}, 
     {-0.9302736495763559, 0.19773576836617363, 0.30901699437494745}, \
{-0.9045084971874736, 0.2938926261462366, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.475, 0.1], \
Polygon[{{-0.8935822975543765, 0.18993678073735726, 0.4067366430758004}, 
     {-0.908540960039796, 0.09549150281252652, 0.4067366430758004}, \
{-0.9458465291882032, 0.09941247612902068, 0.30901699437494745}, 
     {-0.9302736495763559, 0.19773576836617363, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.908540960039796, 0.09549150281252652, 0.4067366430758004}, \
{-0.9135454576426009, 1.1187335719347004*^-16, 0.4067366430758004}, 
     {-0.9510565162951535, 1.1646698526992202*^-16, 0.30901699437494745}, \
{-0.9458465291882032, 0.09941247612902068, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.9135454576426009, 1.1187335719347004*^-16, 0.4067366430758004}, 
     {-0.9085409600397961, -0.0954915028125259, 0.4067366430758004}, \
{-0.9458465291882033, -0.09941247612902003, 0.30901699437494745}, 
     {-0.9510565162951535, 1.1646698526992202*^-16, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{-0.9085409600397961, -0.0954915028125259, 0.4067366430758004}, \
{-0.8935822975543766, -0.18993678073735665, 0.4067366430758004}, 
     {-0.930273649576356, -0.197735768366173, 0.30901699437494745}, \
{-0.9458465291882033, -0.09941247612902003, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.8935822975543766, -0.18993678073735665, 0.4067366430758004}, 
     {-0.8688333604228338, -0.28230107154560224, 0.4067366430758004}, \
{-0.9045084971874737, -0.2938926261462364, 0.30901699437494745}, 
     {-0.930273649576356, -0.197735768366173, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.8688333604228338, -0.28230107154560224, 0.4067366430758004}, \
{-0.8345653031794292, -0.37157241273869673, 0.4067366430758004}, 
     {-0.8688333604228339, -0.38682953481325544, 0.30901699437494745}, \
{-0.9045084971874737, -0.2938926261462364, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.575, 0.1], \
Polygon[{{-0.8345653031794292, -0.37157241273869673, 0.4067366430758004}, 
     {-0.7911535738303733, -0.45677272882130016, 0.4067366430758004}, \
{-0.8236391035463321, -0.4755282581475765, 0.30901699437494745}, 
     {-0.8688333604228339, -0.38682953481325544, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.7911535738303733, -0.45677272882130016, 0.4067366430758004}, \
{-0.739073800366903, -0.5369685473010989, 0.4067366430758004}, 
     {-0.7694208842938135, -0.5590169943749473, 0.30901699437494745}, \
{-0.8236391035463321, -0.4755282581475765, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.739073800366903, -0.5369685473010989, 0.4067366430758004}, 
     {-0.6788965796854772, -0.6112812260087739, 0.4067366430758004}, \
{-0.7067727288213007, -0.6363810234301192, 0.30901699437494745}, 
     {-0.7694208842938135, -0.5590169943749473, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{-0.6788965796854772, -0.6112812260087739, 0.4067366430758004}, \
{-0.6112812260087743, -0.6788965796854767, 0.4067366430758004}, 
     {-0.6363810234301196, -0.7067727288213003, 0.30901699437494745}, \
{-0.7067727288213007, -0.6363810234301192, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.6112812260087743, -0.6788965796854767, 0.4067366430758004}, 
     {-0.5369685473010991, -0.7390738003669027, 0.4067366430758004}, \
{-0.5590169943749476, -0.7694208842938133, 0.30901699437494745}, 
     {-0.6363810234301196, -0.7067727288213003, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.5369685473010991, -0.7390738003669027, 0.4067366430758004}, \
{-0.4567727288213008, -0.791153573830373, 0.4067366430758004}, 
     {-0.4755282581475772, -0.8236391035463316, 0.30901699437494745}, \
{-0.5590169943749476, -0.7694208842938133, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.675, 0.1], \
Polygon[{{-0.4567727288213008, -0.791153573830373, 0.4067366430758004}, 
     {-0.37157241273869773, -0.8345653031794288, 0.4067366430758004}, \
{-0.38682953481325644, -0.8688333604228334, 0.30901699437494745}, 
     {-0.4755282581475772, -0.8236391035463316, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.37157241273869773, -0.8345653031794288, 0.4067366430758004}, \
{-0.28230107154560247, -0.8688333604228338, 0.4067366430758004}, 
     {-0.2938926261462367, -0.9045084971874736, 0.30901699437494745}, \
{-0.38682953481325644, -0.8688333604228334, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.28230107154560247, -0.8688333604228338, 0.4067366430758004}, 
     {-0.1899367807373573, -0.8935822975543765, 0.4067366430758004}, \
{-0.19773576836617368, -0.9302736495763559, 0.30901699437494745}, 
     {-0.2938926261462367, -0.9045084971874736, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{-0.1899367807373573, -0.8935822975543765, 0.4067366430758004}, \
{-0.09549150281252698, -0.908540960039796, 0.4067366430758004}, 
     {-0.09941247612902115, -0.9458465291882032, 0.30901699437494745}, \
{-0.19773576836617368, -0.9302736495763559, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.09549150281252698, -0.908540960039796, 0.4067366430758004}, 
     {-1.6781003579020505*^-16, -0.9135454576426009, 0.4067366430758004}, \
{-1.7470047790488305*^-16, -0.9510565162951535, 0.30901699437494745}, 
     {-0.09941247612902115, -0.9458465291882032, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.6781003579020505*^-16, -0.9135454576426009, \
0.4067366430758004}, {0.09549150281252584, -0.9085409600397961, \
0.4067366430758004}, 
     {0.09941247612901997, -0.9458465291882033, 0.30901699437494745}, \
{-1.7470047790488305*^-16, -0.9510565162951535, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.775, 0.1], \
Polygon[{{0.09549150281252584, -0.9085409600397961, 0.4067366430758004}, 
     {0.18993678073735618, -0.8935822975543767, 0.4067366430758004}, \
{0.19773576836617252, -0.930273649576356, 0.30901699437494745}, 
     {0.09941247612901997, -0.9458465291882033, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.18993678073735618, -0.8935822975543767, 0.4067366430758004}, \
{0.2823010715456022, -0.8688333604228338, 0.4067366430758004}, 
     {0.29389262614623635, -0.9045084971874737, 0.30901699437494745}, \
{0.19773576836617252, -0.930273649576356, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.2823010715456022, -0.8688333604228338, 0.4067366430758004}, 
     {0.3715724127386967, -0.8345653031794292, 0.4067366430758004}, \
{0.3868295348132554, -0.8688333604228339, 0.30901699437494745}, 
     {0.29389262614623635, -0.9045084971874737, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{0.3715724127386967, -0.8345653031794292, 0.4067366430758004}, \
{0.4567727288212998, -0.7911535738303735, 0.4067366430758004}, 
     {0.47552825814757615, -0.8236391035463323, 0.30901699437494745}, \
{0.3868295348132554, -0.8688333604228339, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.4567727288212998, -0.7911535738303735, 0.4067366430758004}, 
     {0.5369685473010988, -0.739073800366903, 0.4067366430758004}, \
{0.5590169943749472, -0.7694208842938135, 0.30901699437494745}, 
     {0.47552825814757615, -0.8236391035463323, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.5369685473010988, -0.739073800366903, 0.4067366430758004}, \
{0.6112812260087738, -0.6788965796854772, 0.4067366430758004}, 
     {0.636381023430119, -0.7067727288213007, 0.30901699437494745}, \
{0.5590169943749472, -0.7694208842938135, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.875, 0.1], \
Polygon[{{0.6112812260087738, -0.6788965796854772, 0.4067366430758004}, 
     {0.6788965796854763, -0.6112812260087747, 0.4067366430758004}, \
{0.7067727288212999, -0.6363810234301199, 0.30901699437494745}, 
     {0.636381023430119, -0.7067727288213007, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.6788965796854763, -0.6112812260087747, 0.4067366430758004}, \
{0.7390738003669027, -0.5369685473010992, 0.4067366430758004}, 
     {0.7694208842938133, -0.5590169943749477, 0.30901699437494745}, \
{0.7067727288212999, -0.6363810234301199, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.7390738003669027, -0.5369685473010992, 0.4067366430758004}, 
     {0.791153573830373, -0.4567727288213008, 0.4067366430758004}, \
{0.8236391035463316, -0.4755282581475772, 0.30901699437494745}, 
     {0.7694208842938133, -0.5590169943749477, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.791153573830373, -0.4567727288213008, 0.4067366430758004}, \
{0.8345653031794288, -0.3715724127386978, 0.4067366430758004}, 
     {0.8688333604228334, -0.3868295348132565, 0.30901699437494745}, \
{0.8236391035463316, -0.4755282581475772, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.8345653031794288, -0.3715724127386978, 0.4067366430758004}, 
     {0.8688333604228338, -0.2823010715456025, 0.4067366430758004}, \
{0.9045084971874736, -0.29389262614623674, 0.30901699437494745}, 
     {0.8688333604228334, -0.3868295348132565, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.8688333604228338, -0.2823010715456025, 0.4067366430758004}, \
{0.8935822975543765, -0.18993678073735737, 0.4067366430758004}, 
     {0.9302736495763559, -0.19773576836617376, 0.30901699437494745}, \
{0.9045084971874736, -0.29389262614623674, 0.30901699437494745}}]}, 
  {CMYKColor[0.3833333333333333, 0.5, 0.975, 0.1], \
Polygon[{{0.8935822975543765, -0.18993678073735737, 0.4067366430758004}, 
     {0.908540960039796, -0.09549150281252705, 0.4067366430758004}, \
{0.9458465291882032, -0.09941247612902122, 0.30901699437494745}, 
     {0.9302736495763559, -0.19773576836617376, 0.30901699437494745}}]}, \
{CMYKColor[0.3833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.908540960039796, -0.09549150281252705, 0.4067366430758004}, \
{0.9135454576426009, -2.237467143869401*^-16, 0.4067366430758004}, 
     {0.9510565162951535, -2.3293397053984404*^-16, 0.30901699437494745}, \
{0.9458465291882032, -0.09941247612902122, 0.30901699437494745}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.9510565162951535, 0., 0.30901699437494745}, 
     {0.9458465291882032, 0.09941247612902042, 0.30901699437494745}, \
{0.9727892058317134, 0.10224426555364696, 0.20791169081775945}, 
     {0.9781476007338056, 0., 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{0.9458465291882032, 0.09941247612902042, 0.30901699437494745}, \
{0.930273649576356, 0.19773576836617324, 0.30901699437494745}, 
     {0.9567727288213005, 0.20336832153790008, 0.20791169081775945}, \
{0.9727892058317134, 0.10224426555364696, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.930273649576356, 0.19773576836617324, 0.30901699437494745}, 
     {0.9045084971874736, 0.2938926261462365, 0.30901699437494745}, \
{0.9302736495763559, 0.3022642316338267, 0.20791169081775945}, 
     {0.9567727288213005, 0.20336832153790008, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.9045084971874736, 0.2938926261462365, 0.30901699437494745}, \
{0.8688333604228338, 0.38682953481325577, 0.30901699437494745}, 
     {0.8935822975543765, 0.39784847155511616, 0.20791169081775945}, \
{0.9302736495763559, 0.3022642316338267, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.075, 0.1], \
Polygon[{{0.8688333604228338, 0.38682953481325577, 0.30901699437494745}, 
     {0.823639103546332, 0.4755282581475767, 0.30901699437494745}, \
{0.8471006708862739, 0.48907380036690273, 0.20791169081775945}, 
     {0.8935822975543765, 0.39784847155511616, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.823639103546332, 0.4755282581475767, 0.30901699437494745}, \
{0.7694208842938134, 0.5590169943749475, 0.30901699437494745}, 
     {0.7913380320007295, 0.5749407342765972, 0.20791169081775945}, \
{0.8471006708862739, 0.48907380036690273, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.7694208842938134, 0.5590169943749475, 0.30901699437494745}, 
     {0.7067727288213005, 0.6363810234301193, 0.30901699437494745}, \
{0.726905328038456, 0.6545084971874736, 0.20791169081775945}, 
     {0.7913380320007295, 0.5749407342765972, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{0.7067727288213005, 0.6363810234301193, 0.30901699437494745}, \
{0.6363810234301194, 0.7067727288213003, 0.30901699437494745}, 
     {0.6545084971874737, 0.7269053280384558, 0.20791169081775945}, \
{0.726905328038456, 0.6545084971874736, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.6363810234301194, 0.7067727288213003, 0.30901699437494745}, 
     {0.5590169943749475, 0.7694208842938134, 0.30901699437494745}, \
{0.5749407342765972, 0.7913380320007295, 0.20791169081775945}, 
     {0.6545084971874737, 0.7269053280384558, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.5590169943749475, 0.7694208842938134, 0.30901699437494745}, \
{0.4755282581475769, 0.8236391035463319, 0.30901699437494745}, 
     {0.4890738003669029, 0.8471006708862738, 0.20791169081775945}, \
{0.5749407342765972, 0.7913380320007295, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.175, 0.1], \
Polygon[{{0.4755282581475769, 0.8236391035463319, 0.30901699437494745}, 
     {0.386829534813256, 0.8688333604228338, 0.30901699437494745}, \
{0.3978484715551164, 0.8935822975543765, 0.20791169081775945}, 
     {0.4890738003669029, 0.8471006708862738, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.386829534813256, 0.8688333604228338, 0.30901699437494745}, \
{0.29389262614623657, 0.9045084971874736, 0.30901699437494745}, 
     {0.30226423163382676, 0.9302736495763559, 0.20791169081775945}, \
{0.3978484715551164, 0.8935822975543765, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.29389262614623657, 0.9045084971874736, 0.30901699437494745}, 
     {0.19773576836617338, 0.9302736495763559, 0.30901699437494745}, \
{0.20336832153790022, 0.9567727288213004, 0.20791169081775945}, 
     {0.30226423163382676, 0.9302736495763559, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{0.19773576836617338, 0.9302736495763559, 0.30901699437494745}, \
{0.09941247612902063, 0.9458465291882032, 0.30901699437494745}, 
     {0.10224426555364717, 0.9727892058317134, 0.20791169081775945}, \
{0.20336832153790022, 0.9567727288213004, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.09941247612902063, 0.9458465291882032, 0.30901699437494745}, 
     {5.823349263496101*^-17, 0.9510565162951535, 0.30901699437494745}, \
{5.98922883417366*^-17, 0.9781476007338056, 0.20791169081775945}, 
     {0.10224426555364717, 0.9727892058317134, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{5.823349263496101*^-17, 0.9510565162951535, \
0.30901699437494745}, {-0.0994124761290203, 0.9458465291882033, \
0.30901699437494745}, 
     {-0.10224426555364684, 0.9727892058317135, 0.20791169081775945}, \
{5.98922883417366*^-17, 0.9781476007338056, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.275, 0.1], \
Polygon[{{-0.0994124761290203, 0.9458465291882033, 0.30901699437494745}, 
     {-0.19773576836617304, 0.930273649576356, 0.30901699437494745}, \
{-0.20336832153789988, 0.9567727288213005, 0.20791169081775945}, 
     {-0.10224426555364684, 0.9727892058317135, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.19773576836617304, 0.930273649576356, 0.30901699437494745}, \
{-0.29389262614623646, 0.9045084971874737, 0.30901699437494745}, 
     {-0.30226423163382665, 0.930273649576356, 0.20791169081775945}, \
{-0.20336832153789988, 0.9567727288213005, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.29389262614623646, 0.9045084971874737, 0.30901699437494745}, 
     {-0.38682953481325566, 0.8688333604228339, 0.30901699437494745}, \
{-0.39784847155511605, 0.8935822975543766, 0.20791169081775945}, 
     {-0.30226423163382665, 0.930273649576356, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{-0.38682953481325566, 0.8688333604228339, 0.30901699437494745}, \
{-0.47552825814757654, 0.823639103546332, 0.30901699437494745}, 
     {-0.48907380036690257, 0.8471006708862739, 0.20791169081775945}, \
{-0.39784847155511605, 0.8935822975543766, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.47552825814757654, 0.823639103546332, 0.30901699437494745}, 
     {-0.5590169943749473, 0.7694208842938134, 0.30901699437494745}, \
{-0.5749407342765971, 0.7913380320007295, 0.20791169081775945}, 
     {-0.48907380036690257, 0.8471006708862739, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.5590169943749473, 0.7694208842938134, 0.30901699437494745}, \
{-0.6363810234301192, 0.7067727288213006, 0.30901699437494745}, 
     {-0.6545084971874734, 0.7269053280384561, 0.20791169081775945}, \
{-0.5749407342765971, 0.7913380320007295, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.375, 0.1], \
Polygon[{{-0.6363810234301192, 0.7067727288213006, 0.30901699437494745}, 
     {-0.7067727288213003, 0.6363810234301195, 0.30901699437494745}, \
{-0.7269053280384556, 0.6545084971874738, 0.20791169081775945}, 
     {-0.6545084971874734, 0.7269053280384561, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.7067727288213003, 0.6363810234301195, 0.30901699437494745}, \
{-0.7694208842938133, 0.5590169943749476, 0.30901699437494745}, 
     {-0.7913380320007294, 0.5749407342765973, 0.20791169081775945}, \
{-0.7269053280384556, 0.6545084971874738, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.7694208842938133, 0.5590169943749476, 0.30901699437494745}, 
     {-0.8236391035463317, 0.4755282581475771, 0.30901699437494745}, \
{-0.8471006708862737, 0.4890738003669031, 0.20791169081775945}, 
     {-0.7913380320007294, 0.5749407342765973, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{-0.8236391035463317, 0.4755282581475771, 0.30901699437494745}, \
{-0.8688333604228337, 0.38682953481325605, 0.30901699437494745}, 
     {-0.8935822975543763, 0.39784847155511643, 0.20791169081775945}, \
{-0.8471006708862737, 0.4890738003669031, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.8688333604228337, 0.38682953481325605, 0.30901699437494745}, 
     {-0.9045084971874736, 0.2938926261462366, 0.30901699437494745}, \
{-0.9302736495763559, 0.3022642316338268, 0.20791169081775945}, 
     {-0.8935822975543763, 0.39784847155511643, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.9045084971874736, 0.2938926261462366, 0.30901699437494745}, \
{-0.9302736495763559, 0.19773576836617363, 0.30901699437494745}, 
     {-0.9567727288213004, 0.20336832153790046, 0.20791169081775945}, \
{-0.9302736495763559, 0.3022642316338268, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.475, 0.1], \
Polygon[{{-0.9302736495763559, 0.19773576836617363, 0.30901699437494745}, 
     {-0.9458465291882032, 0.09941247612902068, 0.30901699437494745}, \
{-0.9727892058317134, 0.10224426555364723, 0.20791169081775945}, 
     {-0.9567727288213004, 0.20336832153790046, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.9458465291882032, 0.09941247612902068, 0.30901699437494745}, \
{-0.9510565162951535, 1.1646698526992202*^-16, 0.30901699437494745}, 
     {-0.9781476007338056, 1.197845766834732*^-16, 0.20791169081775945}, \
{-0.9727892058317134, 0.10224426555364723, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.9510565162951535, 1.1646698526992202*^-16, 0.30901699437494745}, \

     {-0.9458465291882033, -0.09941247612902003, 0.30901699437494745}, \
{-0.9727892058317135, -0.10224426555364656, 0.20791169081775945}, 
     {-0.9781476007338056, 1.197845766834732*^-16, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{-0.9458465291882033, -0.09941247612902003, 0.30901699437494745}, \
{-0.930273649576356, -0.197735768366173, 0.30901699437494745}, 
     {-0.9567727288213005, -0.20336832153789983, 0.20791169081775945}, \
{-0.9727892058317135, -0.10224426555364656, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.930273649576356, -0.197735768366173, 0.30901699437494745}, 
     {-0.9045084971874737, -0.2938926261462364, 0.30901699437494745}, \
{-0.930273649576356, -0.3022642316338266, 0.20791169081775945}, 
     {-0.9567727288213005, -0.20336832153789983, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.9045084971874737, -0.2938926261462364, 0.30901699437494745}, \
{-0.8688333604228339, -0.38682953481325544, 0.30901699437494745}, 
     {-0.8935822975543767, -0.3978484715551158, 0.20791169081775945}, \
{-0.930273649576356, -0.3022642316338266, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.575, 0.1], \
Polygon[{{-0.8688333604228339, -0.38682953481325544, 0.30901699437494745}, 
     {-0.8236391035463321, -0.4755282581475765, 0.30901699437494745}, \
{-0.847100670886274, -0.4890738003669025, 0.20791169081775945}, 
     {-0.8935822975543767, -0.3978484715551158, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.8236391035463321, -0.4755282581475765, 0.30901699437494745}, \
{-0.7694208842938135, -0.5590169943749473, 0.30901699437494745}, 
     {-0.7913380320007296, -0.5749407342765971, 0.20791169081775945}, \
{-0.847100670886274, -0.4890738003669025, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.7694208842938135, -0.5590169943749473, 0.30901699437494745}, 
     {-0.7067727288213007, -0.6363810234301192, 0.30901699437494745}, \
{-0.7269053280384562, -0.6545084971874734, 0.20791169081775945}, 
     {-0.7913380320007296, -0.5749407342765971, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{-0.7067727288213007, -0.6363810234301192, 0.30901699437494745}, \
{-0.6363810234301196, -0.7067727288213003, 0.30901699437494745}, 
     {-0.654508497187474, -0.7269053280384556, 0.20791169081775945}, \
{-0.7269053280384562, -0.6545084971874734, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.6363810234301196, -0.7067727288213003, 0.30901699437494745}, 
     {-0.5590169943749476, -0.7694208842938133, 0.30901699437494745}, \
{-0.5749407342765973, -0.7913380320007294, 0.20791169081775945}, 
     {-0.654508497187474, -0.7269053280384556, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.5590169943749476, -0.7694208842938133, 0.30901699437494745}, \
{-0.4755282581475772, -0.8236391035463316, 0.30901699437494745}, 
     {-0.48907380036690323, -0.8471006708862736, 0.20791169081775945}, \
{-0.5749407342765973, -0.7913380320007294, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.675, 0.1], \
Polygon[{{-0.4755282581475772, -0.8236391035463316, 0.30901699437494745}, 
     {-0.38682953481325644, -0.8688333604228334, 0.30901699437494745}, \
{-0.3978484715551169, -0.8935822975543761, 0.20791169081775945}, 
     {-0.48907380036690323, -0.8471006708862736, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.38682953481325644, -0.8688333604228334, 0.30901699437494745}, \
{-0.2938926261462367, -0.9045084971874736, 0.30901699437494745}, 
     {-0.3022642316338269, -0.9302736495763559, 0.20791169081775945}, \
{-0.3978484715551169, -0.8935822975543761, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.2938926261462367, -0.9045084971874736, 0.30901699437494745}, 
     {-0.19773576836617368, -0.9302736495763559, 0.30901699437494745}, \
{-0.20336832153790052, -0.9567727288213004, 0.20791169081775945}, 
     {-0.3022642316338269, -0.9302736495763559, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{-0.19773576836617368, -0.9302736495763559, 0.30901699437494745}, \
{-0.09941247612902115, -0.9458465291882032, 0.30901699437494745}, 
     {-0.10224426555364771, -0.9727892058317134, 0.20791169081775945}, \
{-0.20336832153790052, -0.9567727288213004, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.09941247612902115, -0.9458465291882032, 0.30901699437494745}, 
     {-1.7470047790488305*^-16, -0.9510565162951535, 0.30901699437494745}, \
{-1.7967686502520982*^-16, -0.9781476007338056, 0.20791169081775945}, 
     {-0.10224426555364771, -0.9727892058317134, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.7470047790488305*^-16, -0.9510565162951535, \
0.30901699437494745}, {0.09941247612901997, -0.9458465291882033, \
0.30901699437494745}, 
     {0.10224426555364649, -0.9727892058317135, 0.20791169081775945}, \
{-1.7967686502520982*^-16, -0.9781476007338056, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.775, 0.1], \
Polygon[{{0.09941247612901997, -0.9458465291882033, 0.30901699437494745}, 
     {0.19773576836617252, -0.930273649576356, 0.30901699437494745}, \
{0.20336832153789933, -0.9567727288213006, 0.20791169081775945}, 
     {0.10224426555364649, -0.9727892058317135, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.19773576836617252, -0.930273649576356, 0.30901699437494745}, \
{0.29389262614623635, -0.9045084971874737, 0.30901699437494745}, 
     {0.30226423163382654, -0.930273649576356, 0.20791169081775945}, \
{0.20336832153789933, -0.9567727288213006, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.29389262614623635, -0.9045084971874737, 0.30901699437494745}, 
     {0.3868295348132554, -0.8688333604228339, 0.30901699437494745}, \
{0.39784847155511577, -0.8935822975543767, 0.20791169081775945}, 
     {0.30226423163382654, -0.930273649576356, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{0.3868295348132554, -0.8688333604228339, 0.30901699437494745}, \
{0.47552825814757615, -0.8236391035463323, 0.30901699437494745}, 
     {0.4890738003669021, -0.8471006708862743, 0.20791169081775945}, \
{0.39784847155511577, -0.8935822975543767, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.47552825814757615, -0.8236391035463323, 0.30901699437494745}, 
     {0.5590169943749472, -0.7694208842938135, 0.30901699437494745}, \
{0.574940734276597, -0.7913380320007296, 0.20791169081775945}, 
     {0.4890738003669021, -0.8471006708862743, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.5590169943749472, -0.7694208842938135, 0.30901699437494745}, \
{0.636381023430119, -0.7067727288213007, 0.30901699437494745}, 
     {0.6545084971874733, -0.7269053280384562, 0.20791169081775945}, \
{0.574940734276597, -0.7913380320007296, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.875, 0.1], \
Polygon[{{0.636381023430119, -0.7067727288213007, 0.30901699437494745}, 
     {0.7067727288212999, -0.6363810234301199, 0.30901699437494745}, \
{0.7269053280384553, -0.6545084971874743, 0.20791169081775945}, 
     {0.6545084971874733, -0.7269053280384562, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.7067727288212999, -0.6363810234301199, 0.30901699437494745}, \
{0.7694208842938133, -0.5590169943749477, 0.30901699437494745}, 
     {0.7913380320007294, -0.5749407342765974, 0.20791169081775945}, \
{0.7269053280384553, -0.6545084971874743, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.7694208842938133, -0.5590169943749477, 0.30901699437494745}, 
     {0.8236391035463316, -0.4755282581475772, 0.30901699437494745}, \
{0.8471006708862736, -0.48907380036690323, 0.20791169081775945}, 
     {0.7913380320007294, -0.5749407342765974, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.8236391035463316, -0.4755282581475772, 0.30901699437494745}, \
{0.8688333604228334, -0.3868295348132565, 0.30901699437494745}, 
     {0.8935822975543761, -0.39784847155511693, 0.20791169081775945}, \
{0.8471006708862736, -0.48907380036690323, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.8688333604228334, -0.3868295348132565, 0.30901699437494745}, 
     {0.9045084971874736, -0.29389262614623674, 0.30901699437494745}, \
{0.9302736495763559, -0.30226423163382693, 0.20791169081775945}, 
     {0.8935822975543761, -0.39784847155511693, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.9045084971874736, -0.29389262614623674, 0.30901699437494745}, \
{0.9302736495763559, -0.19773576836617376, 0.30901699437494745}, 
     {0.9567727288213004, -0.2033683215379006, 0.20791169081775945}, \
{0.9302736495763559, -0.30226423163382693, 0.20791169081775945}}]}, 
  {CMYKColor[0.4166666666666667, 0.5, 0.975, 0.1], \
Polygon[{{0.9302736495763559, -0.19773576836617376, 0.30901699437494745}, 
     {0.9458465291882032, -0.09941247612902122, 0.30901699437494745}, \
{0.9727892058317134, -0.10224426555364778, 0.20791169081775945}, 
     {0.9567727288213004, -0.2033683215379006, 0.20791169081775945}}]}, \
{CMYKColor[0.4166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.9458465291882032, -0.09941247612902122, 0.30901699437494745}, \
{0.9510565162951535, -2.3293397053984404*^-16, 0.30901699437494745}, 
     {0.9781476007338056, -2.395691533669464*^-16, 0.20791169081775945}, \
{0.9727892058317134, -0.10224426555364778, 0.20791169081775945}}]}, 
  {CMYKColor[0.45, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.9781476007338056, 0., 0.20791169081775945}, 
     {0.9727892058317134, 0.10224426555364696, 0.20791169081775945}, \
{0.9890738003669027, 0.10395584540887964, 0.10452846326765368}, 
     {0.9945218953682733, 0., 0.10452846326765368}}]}, {CMYKColor[0.45, 0.5, \
0.025, 0.1], 
   Polygon[{{0.9727892058317134, 0.10224426555364696, 0.20791169081775945}, \
{0.9567727288213005, 0.20336832153790008, 0.20791169081775945}, 
     {0.9727892058317135, 0.2067727288213004, 0.10452846326765368}, \
{0.9890738003669027, 0.10395584540887964, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.9567727288213005, 0.20336832153790008, 0.20791169081775945}, 
     {0.9302736495763559, 0.3022642316338267, 0.20791169081775945}, \
{0.9458465291882032, 0.3073241669467797, 0.10452846326765368}, 
     {0.9727892058317135, 0.2067727288213004, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.9302736495763559, 0.3022642316338267, 0.20791169081775945}, \
{0.8935822975543765, 0.39784847155511616, 0.20791169081775945}, 
     {0.908540960039796, 0.4045084971874736, 0.10452846326765368}, \
{0.9458465291882032, 0.3073241669467797, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.075, 0.1], Polygon[{{0.8935822975543765, \
0.39784847155511616, 0.20791169081775945}, 
     {0.8471006708862739, 0.48907380036690273, 0.20791169081775945}, \
{0.8612812260087742, 0.4972609476841366, 0.10452846326765368}, 
     {0.908540960039796, 0.4045084971874736, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.8471006708862739, 0.48907380036690273, 0.20791169081775945}, \
{0.7913380320007295, 0.5749407342765972, 0.20791169081775945}, 
     {0.8045851146309164, 0.5845653031794291, 0.10452846326765368}, \
{0.8612812260087742, 0.4972609476841366, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.7913380320007295, 0.5749407342765972, 0.20791169081775945}, 
     {0.726905328038456, 0.6545084971874736, 0.20791169081775945}, \
{0.739073800366903, 0.6654650388849336, 0.10452846326765368}, 
     {0.8045851146309164, 0.5845653031794291, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.125, 0.1], 
   Polygon[{{0.726905328038456, 0.6545084971874736, 0.20791169081775945}, \
{0.6545084971874737, 0.7269053280384558, 0.20791169081775945}, 
     {0.6654650388849337, 0.7390738003669027, 0.10452846326765368}, \
{0.739073800366903, 0.6654650388849336, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.6545084971874737, 0.7269053280384558, 0.20791169081775945}, 
     {0.5749407342765972, 0.7913380320007295, 0.20791169081775945}, \
{0.5845653031794291, 0.8045851146309164, 0.10452846326765368}, 
     {0.6654650388849337, 0.7390738003669027, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.5749407342765972, 0.7913380320007295, 0.20791169081775945}, \
{0.4890738003669029, 0.8471006708862738, 0.20791169081775945}, 
     {0.49726094768413676, 0.8612812260087741, 0.10452846326765368}, \
{0.5845653031794291, 0.8045851146309164, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.175, 0.1], Polygon[{{0.4890738003669029, \
0.8471006708862738, 0.20791169081775945}, 
     {0.3978484715551164, 0.8935822975543765, 0.20791169081775945}, \
{0.40450849718747384, 0.908540960039796, 0.10452846326765368}, 
     {0.49726094768413676, 0.8612812260087741, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.3978484715551164, 0.8935822975543765, 0.20791169081775945}, \
{0.30226423163382676, 0.9302736495763559, 0.20791169081775945}, 
     {0.3073241669467798, 0.9458465291882032, 0.10452846326765368}, \
{0.40450849718747384, 0.908540960039796, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.30226423163382676, 0.9302736495763559, 0.20791169081775945}, 
     {0.20336832153790022, 0.9567727288213004, 0.20791169081775945}, \
{0.20677272882130054, 0.9727892058317134, 0.10452846326765368}, 
     {0.3073241669467798, 0.9458465291882032, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.225, 0.1], 
   Polygon[{{0.20336832153790022, 0.9567727288213004, 0.20791169081775945}, \
{0.10224426555364717, 0.9727892058317134, 0.20791169081775945}, 
     {0.10395584540887987, 0.9890738003669027, 0.10452846326765368}, \
{0.20677272882130054, 0.9727892058317134, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.10224426555364717, 0.9727892058317134, 0.20791169081775945}, 
     {5.98922883417366*^-17, 0.9781476007338056, 0.20791169081775945}, \
{6.089489160417305*^-17, 0.9945218953682733, 0.10452846326765368}, 
     {0.10395584540887987, 0.9890738003669027, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{5.98922883417366*^-17, 0.9781476007338056, 0.20791169081775945}, \
{-0.10224426555364684, 0.9727892058317135, 0.20791169081775945}, 
     {-0.10395584540887952, 0.9890738003669028, 0.10452846326765368}, \
{6.089489160417305*^-17, 0.9945218953682733, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.275, 0.1], Polygon[{{-0.10224426555364684, \
0.9727892058317135, 0.20791169081775945}, 
     {-0.20336832153789988, 0.9567727288213005, 0.20791169081775945}, \
{-0.2067727288213002, 0.9727892058317135, 0.10452846326765368}, 
     {-0.10395584540887952, 0.9890738003669028, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.20336832153789988, 0.9567727288213005, 0.20791169081775945}, \
{-0.30226423163382665, 0.930273649576356, 0.20791169081775945}, 
     {-0.30732416694677966, 0.9458465291882033, 0.10452846326765368}, \
{-0.2067727288213002, 0.9727892058317135, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.30226423163382665, 0.930273649576356, 0.20791169081775945}, 
     {-0.39784847155511605, 0.8935822975543766, 0.20791169081775945}, \
{-0.4045084971874735, 0.9085409600397961, 0.10452846326765368}, 
     {-0.30732416694677966, 0.9458465291882033, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.325, 0.1], 
   Polygon[{{-0.39784847155511605, 0.8935822975543766, 0.20791169081775945}, \
{-0.48907380036690257, 0.8471006708862739, 0.20791169081775945}, 
     {-0.4972609476841364, 0.8612812260087742, 0.10452846326765368}, \
{-0.4045084971874735, 0.9085409600397961, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.48907380036690257, 0.8471006708862739, 0.20791169081775945}, 
     {-0.5749407342765971, 0.7913380320007295, 0.20791169081775945}, \
{-0.584565303179429, 0.8045851146309164, 0.10452846326765368}, 
     {-0.4972609476841364, 0.8612812260087742, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.5749407342765971, 0.7913380320007295, 0.20791169081775945}, \
{-0.6545084971874734, 0.7269053280384561, 0.20791169081775945}, 
     {-0.6654650388849334, 0.7390738003669031, 0.10452846326765368}, \
{-0.584565303179429, 0.8045851146309164, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.375, 0.1], Polygon[{{-0.6545084971874734, \
0.7269053280384561, 0.20791169081775945}, 
     {-0.7269053280384556, 0.6545084971874738, 0.20791169081775945}, \
{-0.7390738003669026, 0.6654650388849338, 0.10452846326765368}, 
     {-0.6654650388849334, 0.7390738003669031, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.7269053280384556, 0.6545084971874738, 0.20791169081775945}, \
{-0.7913380320007294, 0.5749407342765973, 0.20791169081775945}, 
     {-0.8045851146309163, 0.5845653031794292, 0.10452846326765368}, \
{-0.7390738003669026, 0.6654650388849338, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.7913380320007294, 0.5749407342765973, 0.20791169081775945}, 
     {-0.8471006708862737, 0.4890738003669031, 0.20791169081775945}, \
{-0.861281226008774, 0.497260947684137, 0.10452846326765368}, 
     {-0.8045851146309163, 0.5845653031794292, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.425, 0.1], 
   Polygon[{{-0.8471006708862737, 0.4890738003669031, 0.20791169081775945}, \
{-0.8935822975543763, 0.39784847155511643, 0.20791169081775945}, 
     {-0.9085409600397959, 0.4045084971874739, 0.10452846326765368}, \
{-0.861281226008774, 0.497260947684137, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.8935822975543763, 0.39784847155511643, 0.20791169081775945}, 
     {-0.9302736495763559, 0.3022642316338268, 0.20791169081775945}, \
{-0.9458465291882032, 0.30732416694677983, 0.10452846326765368}, 
     {-0.9085409600397959, 0.4045084971874739, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.9302736495763559, 0.3022642316338268, 0.20791169081775945}, \
{-0.9567727288213004, 0.20336832153790046, 0.20791169081775945}, 
     {-0.9727892058317134, 0.20677272882130082, 0.10452846326765368}, \
{-0.9458465291882032, 0.30732416694677983, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.475, 0.1], Polygon[{{-0.9567727288213004, \
0.20336832153790046, 0.20791169081775945}, 
     {-0.9727892058317134, 0.10224426555364723, 0.20791169081775945}, \
{-0.9890738003669027, 0.10395584540887992, 0.10452846326765368}, 
     {-0.9727892058317134, 0.20677272882130082, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.9727892058317134, 0.10224426555364723, 0.20791169081775945}, \
{-0.9781476007338056, 1.197845766834732*^-16, 0.20791169081775945}, 
     {-0.9945218953682733, 1.217897832083461*^-16, 0.10452846326765368}, \
{-0.9890738003669027, 0.10395584540887992, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.9781476007338056, 1.197845766834732*^-16, 0.20791169081775945}, 
     {-0.9727892058317135, -0.10224426555364656, 0.20791169081775945}, \
{-0.9890738003669028, -0.10395584540887925, 0.10452846326765368}, 
     {-0.9945218953682733, 1.217897832083461*^-16, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.525, 0.1], 
   Polygon[{{-0.9727892058317135, -0.10224426555364656, 0.20791169081775945}, \
{-0.9567727288213005, -0.20336832153789983, 0.20791169081775945}, 
     {-0.9727892058317135, -0.20677272882130016, 0.10452846326765368}, \
{-0.9890738003669028, -0.10395584540887925, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.9567727288213005, -0.20336832153789983, 0.20791169081775945}, 
     {-0.930273649576356, -0.3022642316338266, 0.20791169081775945}, \
{-0.9458465291882033, -0.3073241669467796, 0.10452846326765368}, 
     {-0.9727892058317135, -0.20677272882130016, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.930273649576356, -0.3022642316338266, 0.20791169081775945}, \
{-0.8935822975543767, -0.3978484715551158, 0.20791169081775945}, 
     {-0.9085409600397962, -0.4045084971874733, 0.10452846326765368}, \
{-0.9458465291882033, -0.3073241669467796, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.575, 0.1], Polygon[{{-0.8935822975543767, \
-0.3978484715551158, 0.20791169081775945}, 
     {-0.847100670886274, -0.4890738003669025, 0.20791169081775945}, \
{-0.8612812260087743, -0.49726094768413637, 0.10452846326765368}, 
     {-0.9085409600397962, -0.4045084971874733, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.847100670886274, -0.4890738003669025, 0.20791169081775945}, \
{-0.7913380320007296, -0.5749407342765971, 0.20791169081775945}, 
     {-0.8045851146309165, -0.584565303179429, 0.10452846326765368}, \
{-0.8612812260087743, -0.49726094768413637, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.7913380320007296, -0.5749407342765971, 0.20791169081775945}, 
     {-0.7269053280384562, -0.6545084971874734, 0.20791169081775945}, \
{-0.7390738003669032, -0.6654650388849334, 0.10452846326765368}, 
     {-0.8045851146309165, -0.584565303179429, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.625, 0.1], 
   Polygon[{{-0.7269053280384562, -0.6545084971874734, 0.20791169081775945}, \
{-0.654508497187474, -0.7269053280384556, 0.20791169081775945}, 
     {-0.6654650388849339, -0.7390738003669026, 0.10452846326765368}, \
{-0.7390738003669032, -0.6654650388849334, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.654508497187474, -0.7269053280384556, 0.20791169081775945}, 
     {-0.5749407342765973, -0.7913380320007294, 0.20791169081775945}, \
{-0.5845653031794292, -0.8045851146309163, 0.10452846326765368}, 
     {-0.6654650388849339, -0.7390738003669026, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.5749407342765973, -0.7913380320007294, 0.20791169081775945}, \
{-0.48907380036690323, -0.8471006708862736, 0.20791169081775945}, 
     {-0.4972609476841371, -0.8612812260087739, 0.10452846326765368}, \
{-0.5845653031794292, -0.8045851146309163, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.675, 0.1], Polygon[{{-0.48907380036690323, \
-0.8471006708862736, 0.20791169081775945}, 
     {-0.3978484715551169, -0.8935822975543761, 0.20791169081775945}, \
{-0.40450849718747434, -0.9085409600397957, 0.10452846326765368}, 
     {-0.4972609476841371, -0.8612812260087739, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.3978484715551169, -0.8935822975543761, 0.20791169081775945}, \
{-0.3022642316338269, -0.9302736495763559, 0.20791169081775945}, 
     {-0.3073241669467799, -0.9458465291882032, 0.10452846326765368}, \
{-0.40450849718747434, -0.9085409600397957, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.3022642316338269, -0.9302736495763559, 0.20791169081775945}, 
     {-0.20336832153790052, -0.9567727288213004, 0.20791169081775945}, \
{-0.20677272882130088, -0.9727892058317134, 0.10452846326765368}, 
     {-0.3073241669467799, -0.9458465291882032, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.725, 0.1], 
   Polygon[{{-0.20336832153790052, -0.9567727288213004, 0.20791169081775945}, \
{-0.10224426555364771, -0.9727892058317134, 0.20791169081775945}, 
     {-0.10395584540888042, -0.9890738003669027, 0.10452846326765368}, \
{-0.20677272882130088, -0.9727892058317134, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.10224426555364771, -0.9727892058317134, 0.20791169081775945}, 
     {-1.7967686502520982*^-16, -0.9781476007338056, 0.20791169081775945}, \
{-1.8268467481251913*^-16, -0.9945218953682733, 0.10452846326765368}, 
     {-0.10395584540888042, -0.9890738003669027, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.7967686502520982*^-16, -0.9781476007338056, \
0.20791169081775945}, {0.10224426555364649, -0.9727892058317135, \
0.20791169081775945}, 
     {0.10395584540887919, -0.9890738003669028, 0.10452846326765368}, \
{-1.8268467481251913*^-16, -0.9945218953682733, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.775, 0.1], Polygon[{{0.10224426555364649, \
-0.9727892058317135, 0.20791169081775945}, 
     {0.20336832153789933, -0.9567727288213006, 0.20791169081775945}, \
{0.20677272882129968, -0.9727892058317136, 0.10452846326765368}, 
     {0.10395584540887919, -0.9890738003669028, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.20336832153789933, -0.9567727288213006, 0.20791169081775945}, \
{0.30226423163382654, -0.930273649576356, 0.20791169081775945}, 
     {0.30732416694677955, -0.9458465291882033, 0.10452846326765368}, \
{0.20677272882129968, -0.9727892058317136, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.30226423163382654, -0.930273649576356, 0.20791169081775945}, 
     {0.39784847155511577, -0.8935822975543767, 0.20791169081775945}, \
{0.4045084971874732, -0.9085409600397962, 0.10452846326765368}, 
     {0.30732416694677955, -0.9458465291882033, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.825, 0.1], 
   Polygon[{{0.39784847155511577, -0.8935822975543767, 0.20791169081775945}, \
{0.4890738003669021, -0.8471006708862743, 0.20791169081775945}, 
     {0.497260947684136, -0.8612812260087745, 0.10452846326765368}, \
{0.4045084971874732, -0.9085409600397962, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.4890738003669021, -0.8471006708862743, 0.20791169081775945}, 
     {0.574940734276597, -0.7913380320007296, 0.20791169081775945}, \
{0.5845653031794289, -0.8045851146309165, 0.10452846326765368}, 
     {0.497260947684136, -0.8612812260087745, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.574940734276597, -0.7913380320007296, 0.20791169081775945}, \
{0.6545084971874733, -0.7269053280384562, 0.20791169081775945}, 
     {0.6654650388849332, -0.7390738003669032, 0.10452846326765368}, \
{0.5845653031794289, -0.8045851146309165, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.875, 0.1], Polygon[{{0.6545084971874733, \
-0.7269053280384562, 0.20791169081775945}, 
     {0.7269053280384553, -0.6545084971874743, 0.20791169081775945}, \
{0.7390738003669023, -0.6654650388849342, 0.10452846326765368}, 
     {0.6654650388849332, -0.7390738003669032, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.7269053280384553, -0.6545084971874743, 0.20791169081775945}, \
{0.7913380320007294, -0.5749407342765974, 0.20791169081775945}, 
     {0.8045851146309163, -0.5845653031794293, 0.10452846326765368}, \
{0.7390738003669023, -0.6654650388849342, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.7913380320007294, -0.5749407342765974, 0.20791169081775945}, 
     {0.8471006708862736, -0.48907380036690323, 0.20791169081775945}, \
{0.8612812260087739, -0.4972609476841371, 0.10452846326765368}, 
     {0.8045851146309163, -0.5845653031794293, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.8471006708862736, -0.48907380036690323, 0.20791169081775945}, \
{0.8935822975543761, -0.39784847155511693, 0.20791169081775945}, 
     {0.9085409600397957, -0.4045084971874744, 0.10452846326765368}, \
{0.8612812260087739, -0.4972609476841371, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.8935822975543761, -0.39784847155511693, 0.20791169081775945}, 
     {0.9302736495763559, -0.30226423163382693, 0.20791169081775945}, \
{0.9458465291882032, -0.30732416694677994, 0.10452846326765368}, 
     {0.9085409600397957, -0.4045084971874744, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.9302736495763559, -0.30226423163382693, 0.20791169081775945}, \
{0.9567727288213004, -0.2033683215379006, 0.20791169081775945}, 
     {0.9727892058317134, -0.20677272882130096, 0.10452846326765368}, \
{0.9458465291882032, -0.30732416694677994, 0.10452846326765368}}]}, 
  {CMYKColor[0.45, 0.5, 0.975, 0.1], Polygon[{{0.9567727288213004, \
-0.2033683215379006, 0.20791169081775945}, 
     {0.9727892058317134, -0.10224426555364778, 0.20791169081775945}, \
{0.9890738003669027, -0.10395584540888049, 0.10452846326765368}, 
     {0.9727892058317134, -0.20677272882130096, 0.10452846326765368}}]}, \
{CMYKColor[0.45, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.9727892058317134, -0.10224426555364778, 0.20791169081775945}, \
{0.9781476007338056, -2.395691533669464*^-16, 0.20791169081775945}, 
     {0.9945218953682733, -2.435795664166922*^-16, 0.10452846326765368}, \
{0.9890738003669027, -0.10395584540888049, 0.10452846326765368}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.9945218953682733, 0., 0.10452846326765368}, 
     {0.9890738003669027, 0.10395584540887964, 0.10452846326765368}, \
{0.9945218953682733, 0.10452846326765346, 6.123031769111886*^-17}, 
     {1., 0., 6.123031769111886*^-17}}]}, {CMYKColor[0.48333333333333334, \
0.5, 0.025, 0.1], 
   Polygon[{{0.9890738003669027, 0.10395584540887964, 0.10452846326765368}, \
{0.9727892058317135, 0.2067727288213004, 0.10452846326765368}, 
     {0.9781476007338057, 0.20791169081775931, 6.123031769111886*^-17}, \
{0.9945218953682733, 0.10452846326765346, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.9727892058317135, 0.2067727288213004, 0.10452846326765368}, 
     {0.9458465291882032, 0.3073241669467797, 0.10452846326765368}, \
{0.9510565162951535, 0.3090169943749474, 6.123031769111886*^-17}, 
     {0.9781476007338057, 0.20791169081775931, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.9458465291882032, 0.3073241669467797, 0.10452846326765368}, \
{0.908540960039796, 0.4045084971874736, 0.10452846326765368}, 
     {0.9135454576426009, 0.40673664307580015, 6.123031769111886*^-17}, \
{0.9510565162951535, 0.3090169943749474, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.075, 0.1], \
Polygon[{{0.908540960039796, 0.4045084971874736, 0.10452846326765368}, 
     {0.8612812260087742, 0.4972609476841366, 0.10452846326765368}, \
{0.8660254037844387, 0.49999999999999994, 6.123031769111886*^-17}, 
     {0.9135454576426009, 0.40673664307580015, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.8612812260087742, 0.4972609476841366, 0.10452846326765368}, \
{0.8045851146309164, 0.5845653031794291, 0.10452846326765368}, 
     {0.8090169943749475, 0.5877852522924731, 6.123031769111886*^-17}, \
{0.8660254037844387, 0.49999999999999994, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.8045851146309164, 0.5845653031794291, 0.10452846326765368}, 
     {0.739073800366903, 0.6654650388849336, 0.10452846326765368}, \
{0.7431448254773944, 0.6691306063588581, 6.123031769111886*^-17}, 
     {0.8090169943749475, 0.5877852522924731, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.125, 0.1], 
   Polygon[{{0.739073800366903, 0.6654650388849336, 0.10452846326765368}, \
{0.6654650388849337, 0.7390738003669027, 0.10452846326765368}, 
     {0.6691306063588582, 0.7431448254773941, 6.123031769111886*^-17}, \
{0.7431448254773944, 0.6691306063588581, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.6654650388849337, 0.7390738003669027, 0.10452846326765368}, 
     {0.5845653031794291, 0.8045851146309164, 0.10452846326765368}, \
{0.5877852522924731, 0.8090169943749475, 6.123031769111886*^-17}, 
     {0.6691306063588582, 0.7431448254773941, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.5845653031794291, 0.8045851146309164, 0.10452846326765368}, \
{0.49726094768413676, 0.8612812260087741, 0.10452846326765368}, 
     {0.5000000000000001, 0.8660254037844386, 6.123031769111886*^-17}, \
{0.5877852522924731, 0.8090169943749475, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.175, 0.1], \
Polygon[{{0.49726094768413676, 0.8612812260087741, 0.10452846326765368}, 
     {0.40450849718747384, 0.908540960039796, 0.10452846326765368}, \
{0.4067366430758004, 0.9135454576426009, 6.123031769111886*^-17}, 
     {0.5000000000000001, 0.8660254037844386, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.40450849718747384, 0.908540960039796, 0.10452846326765368}, \
{0.3073241669467798, 0.9458465291882032, 0.10452846326765368}, 
     {0.30901699437494745, 0.9510565162951535, 6.123031769111886*^-17}, \
{0.4067366430758004, 0.9135454576426009, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.3073241669467798, 0.9458465291882032, 0.10452846326765368}, 
     {0.20677272882130054, 0.9727892058317134, 0.10452846326765368}, \
{0.20791169081775945, 0.9781476007338056, 6.123031769111886*^-17}, 
     {0.30901699437494745, 0.9510565162951535, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.225, 0.1], 
   Polygon[{{0.20677272882130054, 0.9727892058317134, 0.10452846326765368}, \
{0.10395584540887987, 0.9890738003669027, 0.10452846326765368}, 
     {0.10452846326765368, 0.9945218953682733, 6.123031769111886*^-17}, \
{0.20791169081775945, 0.9781476007338056, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.10395584540887987, 0.9890738003669027, 0.10452846326765368}, 
     {6.089489160417305*^-17, 0.9945218953682733, 0.10452846326765368}, \
{6.123031769111886*^-17, 1., 6.123031769111886*^-17}, 
     {0.10452846326765368, 0.9945218953682733, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{6.089489160417305*^-17, 0.9945218953682733, \
0.10452846326765368}, {-0.10395584540887952, 0.9890738003669028, \
0.10452846326765368}, 
     {-0.10452846326765333, 0.9945218953682734, 6.123031769111886*^-17}, \
{6.123031769111886*^-17, 1., 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.275, 0.1], \
Polygon[{{-0.10395584540887952, 0.9890738003669028, 0.10452846326765368}, 
     {-0.2067727288213002, 0.9727892058317135, 0.10452846326765368}, \
{-0.20791169081775912, 0.9781476007338057, 6.123031769111886*^-17}, 
     {-0.10452846326765333, 0.9945218953682734, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.2067727288213002, 0.9727892058317135, 0.10452846326765368}, \
{-0.30732416694677966, 0.9458465291882033, 0.10452846326765368}, 
     {-0.30901699437494734, 0.9510565162951536, 6.123031769111886*^-17}, \
{-0.20791169081775912, 0.9781476007338057, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.30732416694677966, 0.9458465291882033, 0.10452846326765368}, 
     {-0.4045084971874735, 0.9085409600397961, 0.10452846326765368}, \
{-0.40673664307580004, 0.913545457642601, 6.123031769111886*^-17}, 
     {-0.30901699437494734, 0.9510565162951536, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.325, 0.1], 
   Polygon[{{-0.4045084971874735, 0.9085409600397961, 0.10452846326765368}, \
{-0.4972609476841364, 0.8612812260087742, 0.10452846326765368}, 
     {-0.4999999999999998, 0.8660254037844387, 6.123031769111886*^-17}, \
{-0.40673664307580004, 0.913545457642601, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.4972609476841364, 0.8612812260087742, 0.10452846326765368}, 
     {-0.584565303179429, 0.8045851146309164, 0.10452846326765368}, \
{-0.587785252292473, 0.8090169943749475, 6.123031769111886*^-17}, 
     {-0.4999999999999998, 0.8660254037844387, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.584565303179429, 0.8045851146309164, 0.10452846326765368}, \
{-0.6654650388849334, 0.7390738003669031, 0.10452846326765368}, 
     {-0.6691306063588579, 0.7431448254773945, 6.123031769111886*^-17}, \
{-0.587785252292473, 0.8090169943749475, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.375, 0.1], \
Polygon[{{-0.6654650388849334, 0.7390738003669031, 0.10452846326765368}, 
     {-0.7390738003669026, 0.6654650388849338, 0.10452846326765368}, \
{-0.743144825477394, 0.6691306063588583, 6.123031769111886*^-17}, 
     {-0.6691306063588579, 0.7431448254773945, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.7390738003669026, 0.6654650388849338, 0.10452846326765368}, \
{-0.8045851146309163, 0.5845653031794292, 0.10452846326765368}, 
     {-0.8090169943749473, 0.5877852522924732, 6.123031769111886*^-17}, \
{-0.743144825477394, 0.6691306063588583, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.8045851146309163, 0.5845653031794292, 0.10452846326765368}, 
     {-0.861281226008774, 0.497260947684137, 0.10452846326765368}, \
{-0.8660254037844385, 0.5000000000000003, 6.123031769111886*^-17}, 
     {-0.8090169943749473, 0.5877852522924732, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.425, 0.1], 
   Polygon[{{-0.861281226008774, 0.497260947684137, 0.10452846326765368}, \
{-0.9085409600397959, 0.4045084971874739, 0.10452846326765368}, 
     {-0.9135454576426008, 0.40673664307580043, 6.123031769111886*^-17}, \
{-0.8660254037844385, 0.5000000000000003, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.9085409600397959, 0.4045084971874739, 0.10452846326765368}, 
     {-0.9458465291882032, 0.30732416694677983, 0.10452846326765368}, \
{-0.9510565162951535, 0.3090169943749475, 6.123031769111886*^-17}, 
     {-0.9135454576426008, 0.40673664307580043, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.9458465291882032, 0.30732416694677983, 0.10452846326765368}, \
{-0.9727892058317134, 0.20677272882130082, 0.10452846326765368}, 
     {-0.9781476007338056, 0.20791169081775973, 6.123031769111886*^-17}, \
{-0.9510565162951535, 0.3090169943749475, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.475, 0.1], \
Polygon[{{-0.9727892058317134, 0.20677272882130082, 0.10452846326765368}, 
     {-0.9890738003669027, 0.10395584540887992, 0.10452846326765368}, \
{-0.9945218953682733, 0.10452846326765373, 6.123031769111886*^-17}, 
     {-0.9781476007338056, 0.20791169081775973, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.9890738003669027, 0.10395584540887992, 0.10452846326765368}, \
{-0.9945218953682733, 1.217897832083461*^-16, 0.10452846326765368}, 
     {-1., 1.2246063538223773*^-16, 6.123031769111886*^-17}, \
{-0.9945218953682733, 0.10452846326765373, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.9945218953682733, 1.217897832083461*^-16, 0.10452846326765368}, 
     {-0.9890738003669028, -0.10395584540887925, 0.10452846326765368}, \
{-0.9945218953682734, -0.10452846326765305, 6.123031769111886*^-17}, 
     {-1., 1.2246063538223773*^-16, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.525, 0.1], 
   Polygon[{{-0.9890738003669028, -0.10395584540887925, 0.10452846326765368}, \
{-0.9727892058317135, -0.20677272882130016, 0.10452846326765368}, 
     {-0.9781476007338057, -0.20791169081775907, 6.123031769111886*^-17}, \
{-0.9945218953682734, -0.10452846326765305, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.9727892058317135, -0.20677272882130016, 0.10452846326765368}, 
     {-0.9458465291882033, -0.3073241669467796, 0.10452846326765368}, \
{-0.9510565162951536, -0.3090169943749473, 6.123031769111886*^-17}, 
     {-0.9781476007338057, -0.20791169081775907, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.9458465291882033, -0.3073241669467796, 0.10452846326765368}, \
{-0.9085409600397962, -0.4045084971874733, 0.10452846326765368}, 
     {-0.9135454576426011, -0.4067366430757998, 6.123031769111886*^-17}, \
{-0.9510565162951536, -0.3090169943749473, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.575, 0.1], \
Polygon[{{-0.9085409600397962, -0.4045084971874733, 0.10452846326765368}, 
     {-0.8612812260087743, -0.49726094768413637, 0.10452846326765368}, \
{-0.8660254037844388, -0.4999999999999997, 6.123031769111886*^-17}, 
     {-0.9135454576426011, -0.4067366430757998, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.8612812260087743, -0.49726094768413637, 0.10452846326765368}, \
{-0.8045851146309165, -0.584565303179429, 0.10452846326765368}, 
     {-0.8090169943749476, -0.587785252292473, 6.123031769111886*^-17}, \
{-0.8660254037844388, -0.4999999999999997, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.8045851146309165, -0.584565303179429, 0.10452846326765368}, 
     {-0.7390738003669032, -0.6654650388849334, 0.10452846326765368}, \
{-0.7431448254773946, -0.6691306063588579, 6.123031769111886*^-17}, 
     {-0.8090169943749476, -0.587785252292473, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.625, 0.1], 
   Polygon[{{-0.7390738003669032, -0.6654650388849334, 0.10452846326765368}, \
{-0.6654650388849339, -0.7390738003669026, 0.10452846326765368}, 
     {-0.6691306063588585, -0.743144825477394, 6.123031769111886*^-17}, \
{-0.7431448254773946, -0.6691306063588579, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.6654650388849339, -0.7390738003669026, 0.10452846326765368}, 
     {-0.5845653031794292, -0.8045851146309163, 0.10452846326765368}, \
{-0.5877852522924732, -0.8090169943749473, 6.123031769111886*^-17}, 
     {-0.6691306063588585, -0.743144825477394, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.5845653031794292, -0.8045851146309163, 0.10452846326765368}, \
{-0.4972609476841371, -0.8612812260087739, 0.10452846326765368}, 
     {-0.5000000000000004, -0.8660254037844384, 6.123031769111886*^-17}, \
{-0.5877852522924732, -0.8090169943749473, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.675, 0.1], \
Polygon[{{-0.4972609476841371, -0.8612812260087739, 0.10452846326765368}, 
     {-0.40450849718747434, -0.9085409600397957, 0.10452846326765368}, \
{-0.4067366430758009, -0.9135454576426005, 6.123031769111886*^-17}, 
     {-0.5000000000000004, -0.8660254037844384, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.40450849718747434, -0.9085409600397957, 0.10452846326765368}, \
{-0.3073241669467799, -0.9458465291882032, 0.10452846326765368}, 
     {-0.30901699437494756, -0.9510565162951535, 6.123031769111886*^-17}, \
{-0.4067366430758009, -0.9135454576426005, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.3073241669467799, -0.9458465291882032, 0.10452846326765368}, 
     {-0.20677272882130088, -0.9727892058317134, 0.10452846326765368}, \
{-0.2079116908177598, -0.9781476007338056, 6.123031769111886*^-17}, 
     {-0.30901699437494756, -0.9510565162951535, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.725, 0.1], 
   Polygon[{{-0.20677272882130088, -0.9727892058317134, 0.10452846326765368}, \
{-0.10395584540888042, -0.9890738003669027, 0.10452846326765368}, 
     {-0.10452846326765423, -0.9945218953682733, 6.123031769111886*^-17}, \
{-0.2079116908177598, -0.9781476007338056, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.10395584540888042, -0.9890738003669027, 0.10452846326765368}, 
     {-1.8268467481251913*^-16, -0.9945218953682733, 0.10452846326765368}, \
{-1.836909530733566*^-16, -1., 6.123031769111886*^-17}, 
     {-0.10452846326765423, -0.9945218953682733, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.8268467481251913*^-16, -0.9945218953682733, \
0.10452846326765368}, {0.10395584540887919, -0.9890738003669028, \
0.10452846326765368}, 
     {0.10452846326765299, -0.9945218953682734, 6.123031769111886*^-17}, \
{-1.836909530733566*^-16, -1., 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.775, 0.1], \
Polygon[{{0.10395584540887919, -0.9890738003669028, 0.10452846326765368}, 
     {0.20677272882129968, -0.9727892058317136, 0.10452846326765368}, \
{0.20791169081775857, -0.9781476007338058, 6.123031769111886*^-17}, 
     {0.10452846326765299, -0.9945218953682734, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.20677272882129968, -0.9727892058317136, 0.10452846326765368}, \
{0.30732416694677955, -0.9458465291882033, 0.10452846326765368}, 
     {0.30901699437494723, -0.9510565162951536, 6.123031769111886*^-17}, \
{0.20791169081775857, -0.9781476007338058, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.30732416694677955, -0.9458465291882033, 0.10452846326765368}, 
     {0.4045084971874732, -0.9085409600397962, 0.10452846326765368}, \
{0.40673664307579976, -0.9135454576426011, 6.123031769111886*^-17}, 
     {0.30901699437494723, -0.9510565162951536, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.825, 0.1], 
   Polygon[{{0.4045084971874732, -0.9085409600397962, 0.10452846326765368}, \
{0.497260947684136, -0.8612812260087745, 0.10452846326765368}, 
     {0.49999999999999933, -0.866025403784439, 6.123031769111886*^-17}, \
{0.40673664307579976, -0.9135454576426011, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.497260947684136, -0.8612812260087745, 0.10452846326765368}, 
     {0.5845653031794289, -0.8045851146309165, 0.10452846326765368}, \
{0.5877852522924729, -0.8090169943749476, 6.123031769111886*^-17}, 
     {0.49999999999999933, -0.866025403784439, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.5845653031794289, -0.8045851146309165, 0.10452846326765368}, \
{0.6654650388849332, -0.7390738003669032, 0.10452846326765368}, 
     {0.6691306063588578, -0.7431448254773946, 6.123031769111886*^-17}, \
{0.5877852522924729, -0.8090169943749476, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.875, 0.1], \
Polygon[{{0.6654650388849332, -0.7390738003669032, 0.10452846326765368}, 
     {0.7390738003669023, -0.6654650388849342, 0.10452846326765368}, \
{0.7431448254773937, -0.6691306063588588, 6.123031769111886*^-17}, 
     {0.6691306063588578, -0.7431448254773946, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.7390738003669023, -0.6654650388849342, 0.10452846326765368}, \
{0.8045851146309163, -0.5845653031794293, 0.10452846326765368}, 
     {0.8090169943749473, -0.5877852522924734, 6.123031769111886*^-17}, \
{0.7431448254773937, -0.6691306063588588, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.8045851146309163, -0.5845653031794293, 0.10452846326765368}, 
     {0.8612812260087739, -0.4972609476841371, 0.10452846326765368}, \
{0.8660254037844384, -0.5000000000000004, 6.123031769111886*^-17}, 
     {0.8090169943749473, -0.5877852522924734, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.8612812260087739, -0.4972609476841371, 0.10452846326765368}, \
{0.9085409600397957, -0.4045084971874744, 0.10452846326765368}, 
     {0.9135454576426005, -0.40673664307580093, 6.123031769111886*^-17}, \
{0.8660254037844384, -0.5000000000000004, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.9085409600397957, -0.4045084971874744, 0.10452846326765368}, 
     {0.9458465291882032, -0.30732416694677994, 0.10452846326765368}, \
{0.9510565162951535, -0.3090169943749476, 6.123031769111886*^-17}, 
     {0.9135454576426005, -0.40673664307580093, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.9458465291882032, -0.30732416694677994, 0.10452846326765368}, \
{0.9727892058317134, -0.20677272882130096, 0.10452846326765368}, 
     {0.9781476007338056, -0.20791169081775987, 6.123031769111886*^-17}, \
{0.9510565162951535, -0.3090169943749476, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.48333333333333334, 0.5, 0.975, 0.1], \
Polygon[{{0.9727892058317134, -0.20677272882130096, 0.10452846326765368}, 
     {0.9890738003669027, -0.10395584540888049, 0.10452846326765368}, \
{0.9945218953682733, -0.1045284632676543, 6.123031769111886*^-17}, 
     {0.9781476007338056, -0.20791169081775987, 6.123031769111886*^-17}}]}, \
{CMYKColor[0.48333333333333334, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.9890738003669027, -0.10395584540888049, 0.10452846326765368}, \
{0.9945218953682733, -2.435795664166922*^-16, 0.10452846326765368}, 
     {1., -2.4492127076447545*^-16, 6.123031769111886*^-17}, \
{0.9945218953682733, -0.1045284632676543, 6.123031769111886*^-17}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{1., 0., 6.123031769111886*^-17}, {0.9945218953682733, \
0.10452846326765346, 6.123031769111886*^-17}, 
     {0.9890738003669028, 0.10395584540887966, -0.10452846326765333}, \
{0.9945218953682734, 0., -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.025, 0.1], \
Polygon[{{0.9945218953682733, 0.10452846326765346, 6.123031769111886*^-17}, 
     {0.9781476007338057, 0.20791169081775931, 6.123031769111886*^-17}, \
{0.9727892058317136, 0.20677272882130043, -0.10452846326765333}, 
     {0.9890738003669028, 0.10395584540887966, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.9781476007338057, 0.20791169081775931, \
6.123031769111886*^-17}, {0.9510565162951535, 0.3090169943749474, \
6.123031769111886*^-17}, 
     {0.9458465291882033, 0.3073241669467798, -0.10452846326765333}, \
{0.9727892058317136, 0.20677272882130043, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.058333333333333334, 0.1], \
Polygon[{{0.9510565162951535, 0.3090169943749474, 6.123031769111886*^-17}, 
     {0.9135454576426009, 0.40673664307580015, 6.123031769111886*^-17}, \
{0.9085409600397961, 0.40450849718747367, -0.10452846326765333}, 
     {0.9458465291882033, 0.3073241669467798, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.075, 0.1], 
   Polygon[{{0.9135454576426009, 0.40673664307580015, \
6.123031769111886*^-17}, {0.8660254037844387, 0.49999999999999994, \
6.123031769111886*^-17}, 
     {0.8612812260087743, 0.49726094768413664, -0.10452846326765333}, \
{0.9085409600397961, 0.40450849718747367, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.09166666666666666, 0.1], \
Polygon[{{0.8660254037844387, 0.49999999999999994, 6.123031769111886*^-17}, 
     {0.8090169943749475, 0.5877852522924731, 6.123031769111886*^-17}, \
{0.8045851146309165, 0.5845653031794291, -0.10452846326765333}, 
     {0.8612812260087743, 0.49726094768413664, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.8090169943749475, 0.5877852522924731, 6.123031769111886*^-17}, \
{0.7431448254773944, 0.6691306063588581, 6.123031769111886*^-17}, 
     {0.739073800366903, 0.6654650388849337, -0.10452846326765333}, \
{0.8045851146309165, 0.5845653031794291, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.125, 0.1], \
Polygon[{{0.7431448254773944, 0.6691306063588581, 6.123031769111886*^-17}, 
     {0.6691306063588582, 0.7431448254773941, 6.123031769111886*^-17}, \
{0.6654650388849338, 0.7390738003669027, -0.10452846326765333}, 
     {0.739073800366903, 0.6654650388849337, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.6691306063588582, 0.7431448254773941, 6.123031769111886*^-17}, \
{0.5877852522924731, 0.8090169943749475, 6.123031769111886*^-17}, 
     {0.5845653031794291, 0.8045851146309165, -0.10452846326765333}, \
{0.6654650388849338, 0.7390738003669027, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.15833333333333333, 0.1], \
Polygon[{{0.5877852522924731, 0.8090169943749475, 6.123031769111886*^-17}, 
     {0.5000000000000001, 0.8660254037844386, 6.123031769111886*^-17}, \
{0.4972609476841368, 0.8612812260087742, -0.10452846326765333}, 
     {0.5845653031794291, 0.8045851146309165, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.175, 0.1], 
   Polygon[{{0.5000000000000001, 0.8660254037844386, 6.123031769111886*^-17}, \
{0.4067366430758004, 0.9135454576426009, 6.123031769111886*^-17}, 
     {0.4045084971874739, 0.9085409600397961, -0.10452846326765333}, \
{0.4972609476841368, 0.8612812260087742, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.19166666666666665, 0.1], \
Polygon[{{0.4067366430758004, 0.9135454576426009, 6.123031769111886*^-17}, 
     {0.30901699437494745, 0.9510565162951535, 6.123031769111886*^-17}, \
{0.30732416694677983, 0.9458465291882033, -0.10452846326765333}, 
     {0.4045084971874739, 0.9085409600397961, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.30901699437494745, 0.9510565162951535, \
6.123031769111886*^-17}, {0.20791169081775945, 0.9781476007338056, \
6.123031769111886*^-17}, 
     {0.20677272882130057, 0.9727892058317135, -0.10452846326765333}, \
{0.30732416694677983, 0.9458465291882033, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.225, 0.1], \
Polygon[{{0.20791169081775945, 0.9781476007338056, 6.123031769111886*^-17}, 
     {0.10452846326765368, 0.9945218953682733, 6.123031769111886*^-17}, \
{0.10395584540887988, 0.9890738003669028, -0.10452846326765333}, 
     {0.20677272882130057, 0.9727892058317135, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.10452846326765368, 0.9945218953682733, \
6.123031769111886*^-17}, {6.123031769111886*^-17, 1., \
6.123031769111886*^-17}, 
     {6.089489160417305*^-17, 0.9945218953682734, -0.10452846326765333}, \
{0.10395584540887988, 0.9890738003669028, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.2583333333333333, 0.1], \
Polygon[{{6.123031769111886*^-17, 1., 6.123031769111886*^-17}, 
     {-0.10452846326765333, 0.9945218953682734, 6.123031769111886*^-17}, \
{-0.10395584540887953, 0.989073800366903, -0.10452846326765333}, 
     {6.089489160417305*^-17, 0.9945218953682734, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.275, 0.1], 
   Polygon[{{-0.10452846326765333, 0.9945218953682734, \
6.123031769111886*^-17}, {-0.20791169081775912, 0.9781476007338057, 
      6.123031769111886*^-17}, {-0.20677272882130024, 0.9727892058317136, \
-0.10452846326765333}, 
     {-0.10395584540887953, 0.989073800366903, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.20791169081775912, 0.9781476007338057, \
6.123031769111886*^-17}, {-0.30901699437494734, 0.9510565162951536, 
      6.123031769111886*^-17}, {-0.3073241669467797, 0.9458465291882034, \
-0.10452846326765333}, {-0.20677272882130024, 0.9727892058317136, 
      -0.10452846326765333}}]}, {CMYKColor[0.5166666666666666, 0.5, \
0.30833333333333335, 0.1], 
   Polygon[{{-0.30901699437494734, 0.9510565162951536, \
6.123031769111886*^-17}, {-0.40673664307580004, 0.913545457642601, \
6.123031769111886*^-17}, 
     {-0.40450849718747356, 0.9085409600397962, -0.10452846326765333}, \
{-0.3073241669467797, 0.9458465291882034, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.325, 0.1], \
Polygon[{{-0.40673664307580004, 0.913545457642601, 6.123031769111886*^-17}, 
     {-0.4999999999999998, 0.8660254037844387, 6.123031769111886*^-17}, \
{-0.4972609476841365, 0.8612812260087743, -0.10452846326765333}, 
     {-0.40450849718747356, 0.9085409600397962, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.4999999999999998, 0.8660254037844387, \
6.123031769111886*^-17}, {-0.587785252292473, 0.8090169943749475, \
6.123031769111886*^-17}, 
     {-0.584565303179429, 0.8045851146309165, -0.10452846326765333}, \
{-0.4972609476841365, 0.8612812260087743, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.35833333333333334, 0.1], \
Polygon[{{-0.587785252292473, 0.8090169943749475, 6.123031769111886*^-17}, 
     {-0.6691306063588579, 0.7431448254773945, 6.123031769111886*^-17}, \
{-0.6654650388849335, 0.7390738003669031, -0.10452846326765333}, 
     {-0.584565303179429, 0.8045851146309165, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.375, 0.1], 
   Polygon[{{-0.6691306063588579, 0.7431448254773945, \
6.123031769111886*^-17}, {-0.743144825477394, 0.6691306063588583, \
6.123031769111886*^-17}, 
     {-0.7390738003669026, 0.6654650388849339, -0.10452846326765333}, \
{-0.6654650388849335, 0.7390738003669031, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.39166666666666666, 0.1], \
Polygon[{{-0.743144825477394, 0.6691306063588583, 6.123031769111886*^-17}, 
     {-0.8090169943749473, 0.5877852522924732, 6.123031769111886*^-17}, \
{-0.8045851146309164, 0.5845653031794292, -0.10452846326765333}, 
     {-0.7390738003669026, 0.6654650388849339, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.8090169943749473, 0.5877852522924732, \
6.123031769111886*^-17}, {-0.8660254037844385, 0.5000000000000003, \
6.123031769111886*^-17}, 
     {-0.8612812260087741, 0.49726094768413703, -0.10452846326765333}, \
{-0.8045851146309164, 0.5845653031794292, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.425, 0.1], \
Polygon[{{-0.8660254037844385, 0.5000000000000003, 6.123031769111886*^-17}, 
     {-0.9135454576426008, 0.40673664307580043, 6.123031769111886*^-17}, \
{-0.908540960039796, 0.40450849718747395, -0.10452846326765333}, 
     {-0.8612812260087741, 0.49726094768413703, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.9135454576426008, 0.40673664307580043, \
6.123031769111886*^-17}, {-0.9510565162951535, 0.3090169943749475, \
6.123031769111886*^-17}, 
     {-0.9458465291882033, 0.3073241669467799, -0.10452846326765333}, \
{-0.908540960039796, 0.40450849718747395, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.4583333333333333, 0.1], \
Polygon[{{-0.9510565162951535, 0.3090169943749475, 6.123031769111886*^-17}, 
     {-0.9781476007338056, 0.20791169081775973, 6.123031769111886*^-17}, \
{-0.9727892058317135, 0.20677272882130085, -0.10452846326765333}, 
     {-0.9458465291882033, 0.3073241669467799, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.475, 0.1], 
   Polygon[{{-0.9781476007338056, 0.20791169081775973, \
6.123031769111886*^-17}, {-0.9945218953682733, 0.10452846326765373, 
      6.123031769111886*^-17}, {-0.9890738003669028, 0.10395584540887993, \
-0.10452846326765333}, {-0.9727892058317135, 0.20677272882130085, 
      -0.10452846326765333}}]}, {CMYKColor[0.5166666666666666, 0.5, \
0.49166666666666664, 0.1], 
   Polygon[{{-0.9945218953682733, 0.10452846326765373, \
6.123031769111886*^-17}, {-1., 1.2246063538223773*^-16, \
6.123031769111886*^-17}, 
     {-0.9945218953682734, 1.217897832083461*^-16, -0.10452846326765333}, \
{-0.9890738003669028, 0.10395584540887993, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-1., 1.2246063538223773*^-16, 6.123031769111886*^-17}, 
     {-0.9945218953682734, -0.10452846326765305, 6.123031769111886*^-17}, \
{-0.989073800366903, -0.10395584540887925, -0.10452846326765333}, 
     {-0.9945218953682734, 1.217897832083461*^-16, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.525, 0.1], 
   Polygon[{{-0.9945218953682734, -0.10452846326765305, \
6.123031769111886*^-17}, {-0.9781476007338057, -0.20791169081775907, 
      6.123031769111886*^-17}, {-0.9727892058317136, -0.20677272882130018, \
-0.10452846326765333}, 
     {-0.989073800366903, -0.10395584540887925, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-0.9781476007338057, -0.20791169081775907, \
6.123031769111886*^-17}, {-0.9510565162951536, -0.3090169943749473, 
      6.123031769111886*^-17}, {-0.9458465291882034, -0.30732416694677966, \
-0.10452846326765333}, 
     {-0.9727892058317136, -0.20677272882130018, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.9510565162951536, -0.3090169943749473, \
6.123031769111886*^-17}, {-0.9135454576426011, -0.4067366430757998, 
      6.123031769111886*^-17}, {-0.9085409600397963, -0.40450849718747334, \
-0.10452846326765333}, 
     {-0.9458465291882034, -0.30732416694677966, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.575, 0.1], 
   Polygon[{{-0.9135454576426011, -0.4067366430757998, \
6.123031769111886*^-17}, {-0.8660254037844388, -0.4999999999999997, 
      6.123031769111886*^-17}, {-0.8612812260087744, -0.4972609476841364, \
-0.10452846326765333}, {-0.9085409600397963, -0.40450849718747334, 
      -0.10452846326765333}}]}, {CMYKColor[0.5166666666666666, 0.5, \
0.5916666666666667, 0.1], 
   Polygon[{{-0.8660254037844388, -0.4999999999999997, \
6.123031769111886*^-17}, {-0.8090169943749476, -0.587785252292473, \
6.123031769111886*^-17}, 
     {-0.8045851146309166, -0.584565303179429, -0.10452846326765333}, \
{-0.8612812260087744, -0.4972609476841364, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.8090169943749476, -0.587785252292473, 6.123031769111886*^-17}, 
     {-0.7431448254773946, -0.6691306063588579, 6.123031769111886*^-17}, \
{-0.7390738003669032, -0.6654650388849335, -0.10452846326765333}, 
     {-0.8045851146309166, -0.584565303179429, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.625, 0.1], 
   Polygon[{{-0.7431448254773946, -0.6691306063588579, \
6.123031769111886*^-17}, {-0.6691306063588585, -0.743144825477394, \
6.123031769111886*^-17}, 
     {-0.665465038884934, -0.7390738003669026, -0.10452846326765333}, \
{-0.7390738003669032, -0.6654650388849335, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.6691306063588585, -0.743144825477394, 6.123031769111886*^-17}, 
     {-0.5877852522924732, -0.8090169943749473, 6.123031769111886*^-17}, \
{-0.5845653031794292, -0.8045851146309164, -0.10452846326765333}, 
     {-0.665465038884934, -0.7390738003669026, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.5877852522924732, -0.8090169943749473, \
6.123031769111886*^-17}, {-0.5000000000000004, -0.8660254037844384, 
      6.123031769111886*^-17}, {-0.49726094768413714, -0.861281226008774, \
-0.10452846326765333}, {-0.5845653031794292, -0.8045851146309164, 
      -0.10452846326765333}}]}, {CMYKColor[0.5166666666666666, 0.5, 0.675, \
0.1], 
   Polygon[{{-0.5000000000000004, -0.8660254037844384, \
6.123031769111886*^-17}, {-0.4067366430758009, -0.9135454576426005, 
      6.123031769111886*^-17}, {-0.4045084971874744, -0.9085409600397958, \
-0.10452846326765333}, {-0.49726094768413714, -0.861281226008774, 
      -0.10452846326765333}}]}, {CMYKColor[0.5166666666666666, 0.5, \
0.6916666666666667, 0.1], 
   Polygon[{{-0.4067366430758009, -0.9135454576426005, \
6.123031769111886*^-17}, {-0.30901699437494756, -0.9510565162951535, 
      6.123031769111886*^-17}, {-0.30732416694677994, -0.9458465291882033, \
-0.10452846326765333}, 
     {-0.4045084971874744, -0.9085409600397958, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.30901699437494756, -0.9510565162951535, \
6.123031769111886*^-17}, {-0.2079116908177598, -0.9781476007338056, 
      6.123031769111886*^-17}, {-0.2067727288213009, -0.9727892058317135, \
-0.10452846326765333}, {-0.30732416694677994, -0.9458465291882033, 
      -0.10452846326765333}}]}, {CMYKColor[0.5166666666666666, 0.5, 0.725, \
0.1], 
   Polygon[{{-0.2079116908177598, -0.9781476007338056, \
6.123031769111886*^-17}, {-0.10452846326765423, -0.9945218953682733, 
      6.123031769111886*^-17}, {-0.10395584540888043, -0.9890738003669028, \
-0.10452846326765333}, 
     {-0.2067727288213009, -0.9727892058317135, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.10452846326765423, -0.9945218953682733, \
6.123031769111886*^-17}, {-1.836909530733566*^-16, -1., \
6.123031769111886*^-17}, 
     {-1.8268467481251916*^-16, -0.9945218953682734, -0.10452846326765333}, \
{-0.10395584540888043, -0.9890738003669028, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.7583333333333333, 0.1], \
Polygon[{{-1.836909530733566*^-16, -1., 6.123031769111886*^-17}, 
     {0.10452846326765299, -0.9945218953682734, 6.123031769111886*^-17}, \
{0.10395584540887919, -0.989073800366903, -0.10452846326765333}, 
     {-1.8268467481251916*^-16, -0.9945218953682734, \
-0.10452846326765333}}]}, {CMYKColor[0.5166666666666666, 0.5, 0.775, 0.1], 
   Polygon[{{0.10452846326765299, -0.9945218953682734, \
6.123031769111886*^-17}, {0.20791169081775857, -0.9781476007338058, 
      6.123031769111886*^-17}, {0.20677272882129968, -0.9727892058317137, \
-0.10452846326765333}, 
     {0.10395584540887919, -0.989073800366903, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.20791169081775857, -0.9781476007338058, \
6.123031769111886*^-17}, {0.30901699437494723, -0.9510565162951536, 
      6.123031769111886*^-17}, {0.3073241669467796, -0.9458465291882034, \
-0.10452846326765333}, {0.20677272882129968, -0.9727892058317137, 
      -0.10452846326765333}}]}, {CMYKColor[0.5166666666666666, 0.5, \
0.8083333333333333, 0.1], 
   Polygon[{{0.30901699437494723, -0.9510565162951536, \
6.123031769111886*^-17}, {0.40673664307579976, -0.9135454576426011, 
      6.123031769111886*^-17}, {0.4045084971874733, -0.9085409600397963, \
-0.10452846326765333}, {0.3073241669467796, -0.9458465291882034, 
      -0.10452846326765333}}]}, {CMYKColor[0.5166666666666666, 0.5, 0.825, \
0.1], 
   Polygon[{{0.40673664307579976, -0.9135454576426011, \
6.123031769111886*^-17}, {0.49999999999999933, -0.866025403784439, \
6.123031769111886*^-17}, 
     {0.49726094768413603, -0.8612812260087747, -0.10452846326765333}, \
{0.4045084971874733, -0.9085409600397963, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.49999999999999933, -0.866025403784439, 6.123031769111886*^-17}, 
     {0.5877852522924729, -0.8090169943749476, 6.123031769111886*^-17}, \
{0.5845653031794289, -0.8045851146309166, -0.10452846326765333}, 
     {0.49726094768413603, -0.8612812260087747, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.5877852522924729, -0.8090169943749476, \
6.123031769111886*^-17}, {0.6691306063588578, -0.7431448254773946, \
6.123031769111886*^-17}, 
     {0.6654650388849334, -0.7390738003669032, -0.10452846326765333}, \
{0.5845653031794289, -0.8045851146309166, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.875, 0.1], \
Polygon[{{0.6691306063588578, -0.7431448254773946, 6.123031769111886*^-17}, 
     {0.7431448254773937, -0.6691306063588588, 6.123031769111886*^-17}, \
{0.7390738003669023, -0.6654650388849342, -0.10452846326765333}, 
     {0.6654650388849334, -0.7390738003669032, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.7431448254773937, -0.6691306063588588, \
6.123031769111886*^-17}, {0.8090169943749473, -0.5877852522924734, \
6.123031769111886*^-17}, 
     {0.8045851146309164, -0.5845653031794293, -0.10452846326765333}, \
{0.7390738003669023, -0.6654650388849342, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.8090169943749473, -0.5877852522924734, 6.123031769111886*^-17}, 
     {0.8660254037844384, -0.5000000000000004, 6.123031769111886*^-17}, \
{0.861281226008774, -0.49726094768413714, -0.10452846326765333}, 
     {0.8045851146309164, -0.5845653031794293, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.8660254037844384, -0.5000000000000004, \
6.123031769111886*^-17}, {0.9135454576426005, -0.40673664307580093, \
6.123031769111886*^-17}, 
     {0.9085409600397958, -0.40450849718747445, -0.10452846326765333}, \
{0.861281226008774, -0.49726094768413714, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.9135454576426005, -0.40673664307580093, 6.123031769111886*^-17}, 
     {0.9510565162951535, -0.3090169943749476, 6.123031769111886*^-17}, \
{0.9458465291882033, -0.30732416694678, -0.10452846326765333}, 
     {0.9085409600397958, -0.40450849718747445, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.9510565162951535, -0.3090169943749476, \
6.123031769111886*^-17}, {0.9781476007338056, -0.20791169081775987, \
6.123031769111886*^-17}, 
     {0.9727892058317135, -0.206772728821301, -0.10452846326765333}, \
{0.9458465291882033, -0.30732416694678, -0.10452846326765333}}]}, 
  {CMYKColor[0.5166666666666666, 0.5, 0.975, 0.1], \
Polygon[{{0.9781476007338056, -0.20791169081775987, 6.123031769111886*^-17}, 
     {0.9945218953682733, -0.1045284632676543, 6.123031769111886*^-17}, \
{0.9890738003669028, -0.1039558454088805, -0.10452846326765333}, 
     {0.9727892058317135, -0.206772728821301, -0.10452846326765333}}]}, \
{CMYKColor[0.5166666666666666, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.9945218953682733, -0.1045284632676543, \
6.123031769111886*^-17}, {1., -2.4492127076447545*^-16, \
6.123031769111886*^-17}, 
     {0.9945218953682734, -2.435795664166922*^-16, -0.10452846326765333}, \
{0.9890738003669028, -0.1039558454088805, -0.10452846326765333}}]}, 
  {CMYKColor[0.55, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.9945218953682734, 0., -0.10452846326765333}, 
     {0.9890738003669028, 0.10395584540887966, -0.10452846326765333}, \
{0.9727892058317135, 0.10224426555364696, -0.20791169081775912}, 
     {0.9781476007338057, 0., -0.20791169081775912}}]}, {CMYKColor[0.55, 0.5, \
0.025, 0.1], 
   Polygon[{{0.9890738003669028, 0.10395584540887966, -0.10452846326765333}, \
{0.9727892058317136, 0.20677272882130043, -0.10452846326765333}, 
     {0.9567727288213006, 0.2033683215379001, -0.20791169081775912}, \
{0.9727892058317135, 0.10224426555364696, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.9727892058317136, 0.20677272882130043, -0.10452846326765333}, 
     {0.9458465291882033, 0.3073241669467798, -0.10452846326765333}, \
{0.930273649576356, 0.3022642316338267, -0.20791169081775912}, 
     {0.9567727288213006, 0.2033683215379001, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.9458465291882033, 0.3073241669467798, -0.10452846326765333}, \
{0.9085409600397961, 0.40450849718747367, -0.10452846326765333}, 
     {0.8935822975543766, 0.3978484715551162, -0.20791169081775912}, \
{0.930273649576356, 0.3022642316338267, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.075, 0.1], Polygon[{{0.9085409600397961, \
0.40450849718747367, -0.10452846326765333}, 
     {0.8612812260087743, 0.49726094768413664, -0.10452846326765333}, \
{0.847100670886274, 0.4890738003669028, -0.20791169081775912}, 
     {0.8935822975543766, 0.3978484715551162, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.8612812260087743, 0.49726094768413664, -0.10452846326765333}, \
{0.8045851146309165, 0.5845653031794291, -0.10452846326765333}, 
     {0.7913380320007296, 0.5749407342765973, -0.20791169081775912}, \
{0.847100670886274, 0.4890738003669028, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.8045851146309165, 0.5845653031794291, -0.10452846326765333}, 
     {0.739073800366903, 0.6654650388849337, -0.10452846326765333}, \
{0.7269053280384561, 0.6545084971874736, -0.20791169081775912}, 
     {0.7913380320007296, 0.5749407342765973, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.125, 0.1], 
   Polygon[{{0.739073800366903, 0.6654650388849337, -0.10452846326765333}, \
{0.6654650388849338, 0.7390738003669027, -0.10452846326765333}, 
     {0.6545084971874737, 0.7269053280384559, -0.20791169081775912}, \
{0.7269053280384561, 0.6545084971874736, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.6654650388849338, 0.7390738003669027, -0.10452846326765333}, 
     {0.5845653031794291, 0.8045851146309165, -0.10452846326765333}, \
{0.5749407342765973, 0.7913380320007296, -0.20791169081775912}, 
     {0.6545084971874737, 0.7269053280384559, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.5845653031794291, 0.8045851146309165, -0.10452846326765333}, \
{0.4972609476841368, 0.8612812260087742, -0.10452846326765333}, 
     {0.48907380036690296, 0.8471006708862739, -0.20791169081775912}, \
{0.5749407342765973, 0.7913380320007296, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.175, 0.1], Polygon[{{0.4972609476841368, \
0.8612812260087742, -0.10452846326765333}, 
     {0.4045084971874739, 0.9085409600397961, -0.10452846326765333}, \
{0.39784847155511643, 0.8935822975543766, -0.20791169081775912}, 
     {0.48907380036690296, 0.8471006708862739, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.4045084971874739, 0.9085409600397961, -0.10452846326765333}, \
{0.30732416694677983, 0.9458465291882033, -0.10452846326765333}, 
     {0.30226423163382676, 0.930273649576356, -0.20791169081775912}, \
{0.39784847155511643, 0.8935822975543766, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.30732416694677983, 0.9458465291882033, -0.10452846326765333}, 
     {0.20677272882130057, 0.9727892058317135, -0.10452846326765333}, \
{0.20336832153790022, 0.9567727288213005, -0.20791169081775912}, 
     {0.30226423163382676, 0.930273649576356, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.225, 0.1], 
   Polygon[{{0.20677272882130057, 0.9727892058317135, -0.10452846326765333}, \
{0.10395584540887988, 0.9890738003669028, -0.10452846326765333}, 
     {0.10224426555364718, 0.9727892058317135, -0.20791169081775912}, \
{0.20336832153790022, 0.9567727288213005, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.10395584540887988, 0.9890738003669028, -0.10452846326765333}, 
     {6.089489160417305*^-17, 0.9945218953682734, -0.10452846326765333}, \
{5.989228834173662*^-17, 0.9781476007338057, -0.20791169081775912}, 
     {0.10224426555364718, 0.9727892058317135, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{6.089489160417305*^-17, 0.9945218953682734, \
-0.10452846326765333}, {-0.10395584540887953, 0.989073800366903, \
-0.10452846326765333}, 
     {-0.10224426555364685, 0.9727892058317136, -0.20791169081775912}, \
{5.989228834173662*^-17, 0.9781476007338057, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.275, 0.1], Polygon[{{-0.10395584540887953, \
0.989073800366903, -0.10452846326765333}, 
     {-0.20677272882130024, 0.9727892058317136, -0.10452846326765333}, \
{-0.2033683215378999, 0.9567727288213006, -0.20791169081775912}, 
     {-0.10224426555364685, 0.9727892058317136, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.20677272882130024, 0.9727892058317136, -0.10452846326765333}, \
{-0.3073241669467797, 0.9458465291882034, -0.10452846326765333}, 
     {-0.30226423163382665, 0.930273649576356, -0.20791169081775912}, \
{-0.2033683215378999, 0.9567727288213006, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.3073241669467797, 0.9458465291882034, -0.10452846326765333}, 
     {-0.40450849718747356, 0.9085409600397962, -0.10452846326765333}, \
{-0.3978484715551161, 0.8935822975543767, -0.20791169081775912}, 
     {-0.30226423163382665, 0.930273649576356, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.325, 0.1], 
   Polygon[{{-0.40450849718747356, 0.9085409600397962, -0.10452846326765333}, \
{-0.4972609476841365, 0.8612812260087743, -0.10452846326765333}, 
     {-0.4890738003669026, 0.847100670886274, -0.20791169081775912}, \
{-0.3978484715551161, 0.8935822975543767, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.4972609476841365, 0.8612812260087743, -0.10452846326765333}, 
     {-0.584565303179429, 0.8045851146309165, -0.10452846326765333}, \
{-0.5749407342765972, 0.7913380320007296, -0.20791169081775912}, 
     {-0.4890738003669026, 0.847100670886274, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.584565303179429, 0.8045851146309165, -0.10452846326765333}, \
{-0.6654650388849335, 0.7390738003669031, -0.10452846326765333}, 
     {-0.6545084971874734, 0.7269053280384562, -0.20791169081775912}, \
{-0.5749407342765972, 0.7913380320007296, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.375, 0.1], Polygon[{{-0.6654650388849335, \
0.7390738003669031, -0.10452846326765333}, 
     {-0.7390738003669026, 0.6654650388849339, -0.10452846326765333}, \
{-0.7269053280384558, 0.6545084971874738, -0.20791169081775912}, 
     {-0.6545084971874734, 0.7269053280384562, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.7390738003669026, 0.6654650388849339, -0.10452846326765333}, \
{-0.8045851146309164, 0.5845653031794292, -0.10452846326765333}, 
     {-0.7913380320007295, 0.5749407342765974, -0.20791169081775912}, \
{-0.7269053280384558, 0.6545084971874738, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.8045851146309164, 0.5845653031794292, -0.10452846326765333}, 
     {-0.8612812260087741, 0.49726094768413703, -0.10452846326765333}, \
{-0.8471006708862738, 0.4890738003669032, -0.20791169081775912}, 
     {-0.7913380320007295, 0.5749407342765974, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.425, 0.1], 
   Polygon[{{-0.8612812260087741, 0.49726094768413703, -0.10452846326765333}, \
{-0.908540960039796, 0.40450849718747395, -0.10452846326765333}, 
     {-0.8935822975543765, 0.3978484715551165, -0.20791169081775912}, \
{-0.8471006708862738, 0.4890738003669032, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.908540960039796, 0.40450849718747395, -0.10452846326765333}, 
     {-0.9458465291882033, 0.3073241669467799, -0.10452846326765333}, \
{-0.930273649576356, 0.3022642316338268, -0.20791169081775912}, 
     {-0.8935822975543765, 0.3978484715551165, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.9458465291882033, 0.3073241669467799, -0.10452846326765333}, \
{-0.9727892058317135, 0.20677272882130085, -0.10452846326765333}, 
     {-0.9567727288213005, 0.2033683215379005, -0.20791169081775912}, \
{-0.930273649576356, 0.3022642316338268, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.475, 0.1], Polygon[{{-0.9727892058317135, \
0.20677272882130085, -0.10452846326765333}, 
     {-0.9890738003669028, 0.10395584540887993, -0.10452846326765333}, \
{-0.9727892058317135, 0.10224426555364724, -0.20791169081775912}, 
     {-0.9567727288213005, 0.2033683215379005, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.9890738003669028, 0.10395584540887993, -0.10452846326765333}, \
{-0.9945218953682734, 1.217897832083461*^-16, -0.10452846326765333}, 
     {-0.9781476007338057, 1.1978457668347324*^-16, -0.20791169081775912}, \
{-0.9727892058317135, 0.10224426555364724, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.9945218953682734, 1.217897832083461*^-16, -0.10452846326765333}, \

     {-0.989073800366903, -0.10395584540887925, -0.10452846326765333}, \
{-0.9727892058317136, -0.10224426555364657, -0.20791169081775912}, 
     {-0.9781476007338057, 1.1978457668347324*^-16, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.525, 0.1], 
   Polygon[{{-0.989073800366903, -0.10395584540887925, -0.10452846326765333}, \
{-0.9727892058317136, -0.20677272882130018, -0.10452846326765333}, 
     {-0.9567727288213006, -0.20336832153789985, -0.20791169081775912}, \
{-0.9727892058317136, -0.10224426555364657, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.9727892058317136, -0.20677272882130018, -0.10452846326765333}, 
     {-0.9458465291882034, -0.30732416694677966, -0.10452846326765333}, \
{-0.930273649576356, -0.3022642316338266, -0.20791169081775912}, 
     {-0.9567727288213006, -0.20336832153789985, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.9458465291882034, -0.30732416694677966, \
-0.10452846326765333}, {-0.9085409600397963, -0.40450849718747334, \
-0.10452846326765333}, 
     {-0.8935822975543768, -0.3978484715551159, -0.20791169081775912}, \
{-0.930273649576356, -0.3022642316338266, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.575, 0.1], Polygon[{{-0.9085409600397963, \
-0.40450849718747334, -0.10452846326765333}, 
     {-0.8612812260087744, -0.4972609476841364, -0.10452846326765333}, \
{-0.8471006708862742, -0.48907380036690257, -0.20791169081775912}, 
     {-0.8935822975543768, -0.3978484715551159, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.8612812260087744, -0.4972609476841364, -0.10452846326765333}, \
{-0.8045851146309166, -0.584565303179429, -0.10452846326765333}, 
     {-0.7913380320007297, -0.5749407342765972, -0.20791169081775912}, \
{-0.8471006708862742, -0.48907380036690257, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.8045851146309166, -0.584565303179429, -0.10452846326765333}, 
     {-0.7390738003669032, -0.6654650388849335, -0.10452846326765333}, \
{-0.7269053280384563, -0.6545084971874734, -0.20791169081775912}, 
     {-0.7913380320007297, -0.5749407342765972, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.625, 0.1], 
   Polygon[{{-0.7390738003669032, -0.6654650388849335, -0.10452846326765333}, \
{-0.665465038884934, -0.7390738003669026, -0.10452846326765333}, 
     {-0.654508497187474, -0.7269053280384558, -0.20791169081775912}, \
{-0.7269053280384563, -0.6545084971874734, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.665465038884934, -0.7390738003669026, -0.10452846326765333}, 
     {-0.5845653031794292, -0.8045851146309164, -0.10452846326765333}, \
{-0.5749407342765974, -0.7913380320007295, -0.20791169081775912}, 
     {-0.654508497187474, -0.7269053280384558, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.5845653031794292, -0.8045851146309164, -0.10452846326765333}, \
{-0.49726094768413714, -0.861281226008774, -0.10452846326765333}, 
     {-0.4890738003669033, -0.8471006708862737, -0.20791169081775912}, \
{-0.5749407342765974, -0.7913380320007295, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.675, 0.1], Polygon[{{-0.49726094768413714, \
-0.861281226008774, -0.10452846326765333}, 
     {-0.4045084971874744, -0.9085409600397958, -0.10452846326765333}, \
{-0.3978484715551169, -0.8935822975543762, -0.20791169081775912}, 
     {-0.4890738003669033, -0.8471006708862737, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.4045084971874744, -0.9085409600397958, -0.10452846326765333}, \
{-0.30732416694677994, -0.9458465291882033, -0.10452846326765333}, 
     {-0.3022642316338269, -0.930273649576356, -0.20791169081775912}, \
{-0.3978484715551169, -0.8935822975543762, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.30732416694677994, -0.9458465291882033, -0.10452846326765333}, 
     {-0.2067727288213009, -0.9727892058317135, -0.10452846326765333}, \
{-0.20336832153790055, -0.9567727288213005, -0.20791169081775912}, 
     {-0.3022642316338269, -0.930273649576356, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.725, 0.1], 
   Polygon[{{-0.2067727288213009, -0.9727892058317135, -0.10452846326765333}, \
{-0.10395584540888043, -0.9890738003669028, -0.10452846326765333}, 
     {-0.10224426555364773, -0.9727892058317135, -0.20791169081775912}, \
{-0.20336832153790055, -0.9567727288213005, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.10395584540888043, -0.9890738003669028, -0.10452846326765333}, 
     {-1.8268467481251916*^-16, -0.9945218953682734, -0.10452846326765333}, \
{-1.7967686502520984*^-16, -0.9781476007338057, -0.20791169081775912}, 
     {-0.10224426555364773, -0.9727892058317135, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.8268467481251916*^-16, -0.9945218953682734, \
-0.10452846326765333}, {0.10395584540887919, -0.989073800366903, 
      -0.10452846326765333}, {0.1022442655536465, -0.9727892058317136, \
-0.20791169081775912}, {-1.7967686502520984*^-16, -0.9781476007338057, 
      -0.20791169081775912}}]}, {CMYKColor[0.55, 0.5, 0.775, 0.1], \
Polygon[{{0.10395584540887919, -0.989073800366903, -0.10452846326765333}, 
     {0.20677272882129968, -0.9727892058317137, -0.10452846326765333}, \
{0.20336832153789935, -0.9567727288213007, -0.20791169081775912}, 
     {0.1022442655536465, -0.9727892058317136, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.20677272882129968, -0.9727892058317137, -0.10452846326765333}, \
{0.3073241669467796, -0.9458465291882034, -0.10452846326765333}, 
     {0.30226423163382654, -0.930273649576356, -0.20791169081775912}, \
{0.20336832153789935, -0.9567727288213007, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.3073241669467796, -0.9458465291882034, -0.10452846326765333}, 
     {0.4045084971874733, -0.9085409600397963, -0.10452846326765333}, \
{0.3978484715551158, -0.8935822975543768, -0.20791169081775912}, 
     {0.30226423163382654, -0.930273649576356, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.825, 0.1], 
   Polygon[{{0.4045084971874733, -0.9085409600397963, -0.10452846326765333}, \
{0.49726094768413603, -0.8612812260087747, -0.10452846326765333}, 
     {0.4890738003669022, -0.8471006708862744, -0.20791169081775912}, \
{0.3978484715551158, -0.8935822975543768, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.49726094768413603, -0.8612812260087747, -0.10452846326765333}, 
     {0.5845653031794289, -0.8045851146309166, -0.10452846326765333}, \
{0.5749407342765971, -0.7913380320007297, -0.20791169081775912}, 
     {0.4890738003669022, -0.8471006708862744, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.5845653031794289, -0.8045851146309166, -0.10452846326765333}, \
{0.6654650388849334, -0.7390738003669032, -0.10452846326765333}, 
     {0.6545084971874733, -0.7269053280384563, -0.20791169081775912}, \
{0.5749407342765971, -0.7913380320007297, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.875, 0.1], Polygon[{{0.6654650388849334, \
-0.7390738003669032, -0.10452846326765333}, 
     {0.7390738003669023, -0.6654650388849342, -0.10452846326765333}, \
{0.7269053280384554, -0.6545084971874743, -0.20791169081775912}, 
     {0.6545084971874733, -0.7269053280384563, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.7390738003669023, -0.6654650388849342, -0.10452846326765333}, \
{0.8045851146309164, -0.5845653031794293, -0.10452846326765333}, 
     {0.7913380320007295, -0.5749407342765975, -0.20791169081775912}, \
{0.7269053280384554, -0.6545084971874743, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.8045851146309164, -0.5845653031794293, -0.10452846326765333}, 
     {0.861281226008774, -0.49726094768413714, -0.10452846326765333}, \
{0.8471006708862737, -0.4890738003669033, -0.20791169081775912}, 
     {0.7913380320007295, -0.5749407342765975, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.861281226008774, -0.49726094768413714, -0.10452846326765333}, \
{0.9085409600397958, -0.40450849718747445, -0.10452846326765333}, 
     {0.8935822975543762, -0.39784847155511693, -0.20791169081775912}, \
{0.8471006708862737, -0.4890738003669033, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.9085409600397958, -0.40450849718747445, -0.10452846326765333}, 
     {0.9458465291882033, -0.30732416694678, -0.10452846326765333}, \
{0.930273649576356, -0.30226423163382693, -0.20791169081775912}, 
     {0.8935822975543762, -0.39784847155511693, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.9458465291882033, -0.30732416694678, -0.10452846326765333}, \
{0.9727892058317135, -0.206772728821301, -0.10452846326765333}, 
     {0.9567727288213005, -0.20336832153790063, -0.20791169081775912}, \
{0.930273649576356, -0.30226423163382693, -0.20791169081775912}}]}, 
  {CMYKColor[0.55, 0.5, 0.975, 0.1], Polygon[{{0.9727892058317135, \
-0.206772728821301, -0.10452846326765333}, 
     {0.9890738003669028, -0.1039558454088805, -0.10452846326765333}, \
{0.9727892058317135, -0.1022442655536478, -0.20791169081775912}, 
     {0.9567727288213005, -0.20336832153790063, -0.20791169081775912}}]}, \
{CMYKColor[0.55, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.9890738003669028, -0.1039558454088805, -0.10452846326765333}, \
{0.9945218953682734, -2.435795664166922*^-16, -0.10452846326765333}, 
     {0.9781476007338057, -2.3956915336694647*^-16, -0.20791169081775912}, \
{0.9727892058317135, -0.1022442655536478, -0.20791169081775912}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.9781476007338057, 0., -0.20791169081775912}, 
     {0.9727892058317135, 0.10224426555364696, -0.20791169081775912}, \
{0.9458465291882033, 0.09941247612902043, -0.30901699437494734}, 
     {0.9510565162951536, 0., -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.025, 0.1], 
   Polygon[{{0.9727892058317135, 0.10224426555364696, -0.20791169081775912}, \
{0.9567727288213006, 0.2033683215379001, -0.20791169081775912}, 
     {0.930273649576356, 0.19773576836617326, -0.30901699437494734}, \
{0.9458465291882033, 0.09941247612902043, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.9567727288213006, 0.2033683215379001, -0.20791169081775912}, 
     {0.930273649576356, 0.3022642316338267, -0.20791169081775912}, \
{0.9045084971874737, 0.29389262614623657, -0.30901699437494734}, 
     {0.930273649576356, 0.19773576836617326, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.930273649576356, 0.3022642316338267, -0.20791169081775912}, \
{0.8935822975543766, 0.3978484715551162, -0.20791169081775912}, 
     {0.8688333604228338, 0.3868295348132558, -0.30901699437494734}, \
{0.9045084971874737, 0.29389262614623657, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.075, 0.1], \
Polygon[{{0.8935822975543766, 0.3978484715551162, -0.20791169081775912}, 
     {0.847100670886274, 0.4890738003669028, -0.20791169081775912}, \
{0.8236391035463321, 0.47552825814757677, -0.30901699437494734}, 
     {0.8688333604228338, 0.3868295348132558, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.847100670886274, 0.4890738003669028, -0.20791169081775912}, \
{0.7913380320007296, 0.5749407342765973, -0.20791169081775912}, 
     {0.7694208842938134, 0.5590169943749475, -0.30901699437494734}, \
{0.8236391035463321, 0.47552825814757677, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.7913380320007296, 0.5749407342765973, -0.20791169081775912}, 
     {0.7269053280384561, 0.6545084971874736, -0.20791169081775912}, \
{0.7067727288213006, 0.6363810234301194, -0.30901699437494734}, 
     {0.7694208842938134, 0.5590169943749475, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.125, 0.1], 
   Polygon[{{0.7269053280384561, 0.6545084971874736, -0.20791169081775912}, \
{0.6545084971874737, 0.7269053280384559, -0.20791169081775912}, 
     {0.6363810234301195, 0.7067727288213004, -0.30901699437494734}, \
{0.7067727288213006, 0.6363810234301194, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.6545084971874737, 0.7269053280384559, -0.20791169081775912}, 
     {0.5749407342765973, 0.7913380320007296, -0.20791169081775912}, \
{0.5590169943749475, 0.7694208842938134, -0.30901699437494734}, 
     {0.6363810234301195, 0.7067727288213004, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.5749407342765973, 0.7913380320007296, -0.20791169081775912}, \
{0.48907380036690296, 0.8471006708862739, -0.20791169081775912}, 
     {0.47552825814757693, 0.823639103546332, -0.30901699437494734}, \
{0.5590169943749475, 0.7694208842938134, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.175, 0.1], \
Polygon[{{0.48907380036690296, 0.8471006708862739, -0.20791169081775912}, 
     {0.39784847155511643, 0.8935822975543766, -0.20791169081775912}, \
{0.38682953481325605, 0.8688333604228338, -0.30901699437494734}, 
     {0.47552825814757693, 0.823639103546332, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.39784847155511643, 0.8935822975543766, -0.20791169081775912}, \
{0.30226423163382676, 0.930273649576356, -0.20791169081775912}, 
     {0.2938926261462366, 0.9045084971874737, -0.30901699437494734}, \
{0.38682953481325605, 0.8688333604228338, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.30226423163382676, 0.930273649576356, -0.20791169081775912}, 
     {0.20336832153790022, 0.9567727288213005, -0.20791169081775912}, \
{0.1977357683661734, 0.930273649576356, -0.30901699437494734}, 
     {0.2938926261462366, 0.9045084971874737, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.225, 0.1], 
   Polygon[{{0.20336832153790022, 0.9567727288213005, -0.20791169081775912}, \
{0.10224426555364718, 0.9727892058317135, -0.20791169081775912}, 
     {0.09941247612902064, 0.9458465291882033, -0.30901699437494734}, \
{0.1977357683661734, 0.930273649576356, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.10224426555364718, 0.9727892058317135, -0.20791169081775912}, 
     {5.989228834173662*^-17, 0.9781476007338057, -0.20791169081775912}, \
{5.823349263496102*^-17, 0.9510565162951536, -0.30901699437494734}, 
     {0.09941247612902064, 0.9458465291882033, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{5.989228834173662*^-17, 0.9781476007338057, \
-0.20791169081775912}, {-0.10224426555364685, 0.9727892058317136, \
-0.20791169081775912}, 
     {-0.09941247612902031, 0.9458465291882034, -0.30901699437494734}, \
{5.823349263496102*^-17, 0.9510565162951536, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.275, 0.1], \
Polygon[{{-0.10224426555364685, 0.9727892058317136, -0.20791169081775912}, 
     {-0.2033683215378999, 0.9567727288213006, -0.20791169081775912}, \
{-0.19773576836617307, 0.930273649576356, -0.30901699437494734}, 
     {-0.09941247612902031, 0.9458465291882034, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.2033683215378999, 0.9567727288213006, -0.20791169081775912}, \
{-0.30226423163382665, 0.930273649576356, -0.20791169081775912}, 
     {-0.2938926261462365, 0.9045084971874738, -0.30901699437494734}, \
{-0.19773576836617307, 0.930273649576356, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.30226423163382665, 0.930273649576356, -0.20791169081775912}, 
     {-0.3978484715551161, 0.8935822975543767, -0.20791169081775912}, \
{-0.3868295348132557, 0.8688333604228339, -0.30901699437494734}, 
     {-0.2938926261462365, 0.9045084971874738, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.325, 0.1], 
   Polygon[{{-0.3978484715551161, 0.8935822975543767, -0.20791169081775912}, \
{-0.4890738003669026, 0.847100670886274, -0.20791169081775912}, 
     {-0.4755282581475766, 0.8236391035463321, -0.30901699437494734}, \
{-0.3868295348132557, 0.8688333604228339, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.4890738003669026, 0.847100670886274, -0.20791169081775912}, 
     {-0.5749407342765972, 0.7913380320007296, -0.20791169081775912}, \
{-0.5590169943749473, 0.7694208842938134, -0.30901699437494734}, 
     {-0.4755282581475766, 0.8236391035463321, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.5749407342765972, 0.7913380320007296, -0.20791169081775912}, \
{-0.6545084971874734, 0.7269053280384562, -0.20791169081775912}, 
     {-0.6363810234301192, 0.7067727288213007, -0.30901699437494734}, \
{-0.5590169943749473, 0.7694208842938134, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.375, 0.1], \
Polygon[{{-0.6545084971874734, 0.7269053280384562, -0.20791169081775912}, 
     {-0.7269053280384558, 0.6545084971874738, -0.20791169081775912}, \
{-0.7067727288213003, 0.6363810234301196, -0.30901699437494734}, 
     {-0.6363810234301192, 0.7067727288213007, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.7269053280384558, 0.6545084971874738, -0.20791169081775912}, \
{-0.7913380320007295, 0.5749407342765974, -0.20791169081775912}, 
     {-0.7694208842938133, 0.5590169943749476, -0.30901699437494734}, \
{-0.7067727288213003, 0.6363810234301196, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.7913380320007295, 0.5749407342765974, -0.20791169081775912}, 
     {-0.8471006708862738, 0.4890738003669032, -0.20791169081775912}, \
{-0.8236391035463319, 0.47552825814757715, -0.30901699437494734}, 
     {-0.7694208842938133, 0.5590169943749476, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.425, 0.1], 
   Polygon[{{-0.8471006708862738, 0.4890738003669032, -0.20791169081775912}, \
{-0.8935822975543765, 0.3978484715551165, -0.20791169081775912}, 
     {-0.8688333604228338, 0.3868295348132561, -0.30901699437494734}, \
{-0.8236391035463319, 0.47552825814757715, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.8935822975543765, 0.3978484715551165, -0.20791169081775912}, 
     {-0.930273649576356, 0.3022642316338268, -0.20791169081775912}, \
{-0.9045084971874737, 0.2938926261462367, -0.30901699437494734}, 
     {-0.8688333604228338, 0.3868295348132561, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.930273649576356, 0.3022642316338268, -0.20791169081775912}, \
{-0.9567727288213005, 0.2033683215379005, -0.20791169081775912}, 
     {-0.930273649576356, 0.19773576836617365, -0.30901699437494734}, \
{-0.9045084971874737, 0.2938926261462367, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.475, 0.1], \
Polygon[{{-0.9567727288213005, 0.2033683215379005, -0.20791169081775912}, 
     {-0.9727892058317135, 0.10224426555364724, -0.20791169081775912}, \
{-0.9458465291882033, 0.0994124761290207, -0.30901699437494734}, 
     {-0.930273649576356, 0.19773576836617365, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.9727892058317135, 0.10224426555364724, -0.20791169081775912}, \
{-0.9781476007338057, 1.1978457668347324*^-16, 
      -0.20791169081775912}, {-0.9510565162951536, 1.1646698526992204*^-16, \
-0.30901699437494734}, 
     {-0.9458465291882033, 0.0994124761290207, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.9781476007338057, 1.1978457668347324*^-16, \
-0.20791169081775912}, {-0.9727892058317136, -0.10224426555364657, 
      -0.20791169081775912}, {-0.9458465291882034, -0.09941247612902004, \
-0.30901699437494734}, {-0.9510565162951536, 1.1646698526992204*^-16, 
      -0.30901699437494734}}]}, {CMYKColor[0.5833333333333334, 0.5, 0.525, \
0.1], 
   Polygon[{{-0.9727892058317136, -0.10224426555364657, \
-0.20791169081775912}, {-0.9567727288213006, -0.20336832153789985, \
-0.20791169081775912}, 
     {-0.930273649576356, -0.19773576836617301, -0.30901699437494734}, \
{-0.9458465291882034, -0.09941247612902004, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.9567727288213006, -0.20336832153789985, -0.20791169081775912}, 
     {-0.930273649576356, -0.3022642316338266, -0.20791169081775912}, \
{-0.9045084971874738, -0.29389262614623646, -0.30901699437494734}, 
     {-0.930273649576356, -0.19773576836617301, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.930273649576356, -0.3022642316338266, -0.20791169081775912}, \
{-0.8935822975543768, -0.3978484715551159, -0.20791169081775912}, 
     {-0.868833360422834, -0.3868295348132555, -0.30901699437494734}, \
{-0.9045084971874738, -0.29389262614623646, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.575, 0.1], \
Polygon[{{-0.8935822975543768, -0.3978484715551159, -0.20791169081775912}, 
     {-0.8471006708862742, -0.48907380036690257, -0.20791169081775912}, \
{-0.8236391035463322, -0.47552825814757654, -0.30901699437494734}, 
     {-0.868833360422834, -0.3868295348132555, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.8471006708862742, -0.48907380036690257, \
-0.20791169081775912}, {-0.7913380320007297, -0.5749407342765972, \
-0.20791169081775912}, 
     {-0.7694208842938135, -0.5590169943749473, -0.30901699437494734}, \
{-0.8236391035463322, -0.47552825814757654, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.7913380320007297, -0.5749407342765972, -0.20791169081775912}, 
     {-0.7269053280384563, -0.6545084971874734, -0.20791169081775912}, \
{-0.7067727288213008, -0.6363810234301192, -0.30901699437494734}, 
     {-0.7694208842938135, -0.5590169943749473, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.625, 0.1], 
   Polygon[{{-0.7269053280384563, -0.6545084971874734, -0.20791169081775912}, \
{-0.654508497187474, -0.7269053280384558, -0.20791169081775912}, 
     {-0.6363810234301197, -0.7067727288213003, -0.30901699437494734}, \
{-0.7067727288213008, -0.6363810234301192, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.654508497187474, -0.7269053280384558, -0.20791169081775912}, 
     {-0.5749407342765974, -0.7913380320007295, -0.20791169081775912}, \
{-0.5590169943749476, -0.7694208842938133, -0.30901699437494734}, 
     {-0.6363810234301197, -0.7067727288213003, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.5749407342765974, -0.7913380320007295, -0.20791169081775912}, \
{-0.4890738003669033, -0.8471006708862737, -0.20791169081775912}, 
     {-0.47552825814757727, -0.8236391035463317, -0.30901699437494734}, \
{-0.5590169943749476, -0.7694208842938133, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.675, 0.1], \
Polygon[{{-0.4890738003669033, -0.8471006708862737, -0.20791169081775912}, 
     {-0.3978484715551169, -0.8935822975543762, -0.20791169081775912}, \
{-0.3868295348132565, -0.8688333604228335, -0.30901699437494734}, 
     {-0.47552825814757727, -0.8236391035463317, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.3978484715551169, -0.8935822975543762, -0.20791169081775912}, \
{-0.3022642316338269, -0.930273649576356, -0.20791169081775912}, 
     {-0.29389262614623674, -0.9045084971874737, -0.30901699437494734}, \
{-0.3868295348132565, -0.8688333604228335, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.3022642316338269, -0.930273649576356, -0.20791169081775912}, 
     {-0.20336832153790055, -0.9567727288213005, -0.20791169081775912}, \
{-0.1977357683661737, -0.930273649576356, -0.30901699437494734}, 
     {-0.29389262614623674, -0.9045084971874737, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.725, 0.1], 
   Polygon[{{-0.20336832153790055, -0.9567727288213005, \
-0.20791169081775912}, {-0.10224426555364773, -0.9727892058317135, \
-0.20791169081775912}, 
     {-0.09941247612902117, -0.9458465291882033, -0.30901699437494734}, \
{-0.1977357683661737, -0.930273649576356, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.10224426555364773, -0.9727892058317135, -0.20791169081775912}, 
     {-1.7967686502520984*^-16, -0.9781476007338057, -0.20791169081775912}, \
{-1.7470047790488305*^-16, -0.9510565162951536, -0.30901699437494734}, 
     {-0.09941247612902117, -0.9458465291882033, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.7967686502520984*^-16, -0.9781476007338057, \
-0.20791169081775912}, {0.1022442655536465, -0.9727892058317136, 
      -0.20791169081775912}, {0.09941247612901997, -0.9458465291882034, \
-0.30901699437494734}, {-1.7470047790488305*^-16, -0.9510565162951536, 
      -0.30901699437494734}}]}, {CMYKColor[0.5833333333333334, 0.5, 0.775, \
0.1], 
   Polygon[{{0.1022442655536465, -0.9727892058317136, -0.20791169081775912}, \
{0.20336832153789935, -0.9567727288213007, -0.20791169081775912}, 
     {0.19773576836617254, -0.9302736495763562, -0.30901699437494734}, \
{0.09941247612901997, -0.9458465291882034, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.7916666666666666, 0.1], \
Polygon[{{0.20336832153789935, -0.9567727288213007, -0.20791169081775912}, 
     {0.30226423163382654, -0.930273649576356, -0.20791169081775912}, \
{0.2938926261462364, -0.9045084971874738, -0.30901699437494734}, 
     {0.19773576836617254, -0.9302736495763562, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.30226423163382654, -0.930273649576356, -0.20791169081775912}, \
{0.3978484715551158, -0.8935822975543768, -0.20791169081775912}, 
     {0.38682953481325544, -0.868833360422834, -0.30901699437494734}, \
{0.2938926261462364, -0.9045084971874738, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.825, 0.1], \
Polygon[{{0.3978484715551158, -0.8935822975543768, -0.20791169081775912}, 
     {0.4890738003669022, -0.8471006708862744, -0.20791169081775912}, \
{0.4755282581475762, -0.8236391035463324, -0.30901699437494734}, 
     {0.38682953481325544, -0.868833360422834, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.4890738003669022, -0.8471006708862744, -0.20791169081775912}, \
{0.5749407342765971, -0.7913380320007297, -0.20791169081775912}, 
     {0.5590169943749472, -0.7694208842938135, -0.30901699437494734}, \
{0.4755282581475762, -0.8236391035463324, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.8583333333333333, 0.1], \
Polygon[{{0.5749407342765971, -0.7913380320007297, -0.20791169081775912}, 
     {0.6545084971874733, -0.7269053280384563, -0.20791169081775912}, \
{0.636381023430119, -0.7067727288213008, -0.30901699437494734}, 
     {0.5590169943749472, -0.7694208842938135, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.875, 0.1], 
   Polygon[{{0.6545084971874733, -0.7269053280384563, -0.20791169081775912}, \
{0.7269053280384554, -0.6545084971874743, -0.20791169081775912}, 
     {0.7067727288212999, -0.63638102343012, -0.30901699437494734}, \
{0.636381023430119, -0.7067727288213008, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.8916666666666666, 0.1], \
Polygon[{{0.7269053280384554, -0.6545084971874743, -0.20791169081775912}, 
     {0.7913380320007295, -0.5749407342765975, -0.20791169081775912}, \
{0.7694208842938133, -0.5590169943749477, -0.30901699437494734}, 
     {0.7067727288212999, -0.63638102343012, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.7913380320007295, -0.5749407342765975, -0.20791169081775912}, \
{0.8471006708862737, -0.4890738003669033, -0.20791169081775912}, 
     {0.8236391035463317, -0.47552825814757727, -0.30901699437494734}, \
{0.7694208842938133, -0.5590169943749477, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.9249999999999999, 0.1], \
Polygon[{{0.8471006708862737, -0.4890738003669033, -0.20791169081775912}, 
     {0.8935822975543762, -0.39784847155511693, -0.20791169081775912}, \
{0.8688333604228335, -0.38682953481325655, -0.30901699437494734}, 
     {0.8236391035463317, -0.47552825814757727, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.8935822975543762, -0.39784847155511693, -0.20791169081775912}, \
{0.930273649576356, -0.30226423163382693, -0.20791169081775912}, 
     {0.9045084971874737, -0.2938926261462368, -0.30901699437494734}, \
{0.8688333604228335, -0.38682953481325655, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.9583333333333334, 0.1], \
Polygon[{{0.930273649576356, -0.30226423163382693, -0.20791169081775912}, 
     {0.9567727288213005, -0.20336832153790063, -0.20791169081775912}, \
{0.930273649576356, -0.1977357683661738, -0.30901699437494734}, 
     {0.9045084971874737, -0.2938926261462368, -0.30901699437494734}}]}, \
{CMYKColor[0.5833333333333334, 0.5, 0.975, 0.1], 
   Polygon[{{0.9567727288213005, -0.20336832153790063, -0.20791169081775912}, \
{0.9727892058317135, -0.1022442655536478, -0.20791169081775912}, 
     {0.9458465291882033, -0.09941247612902124, -0.30901699437494734}, \
{0.930273649576356, -0.1977357683661738, -0.30901699437494734}}]}, 
  {CMYKColor[0.5833333333333334, 0.5, 0.9916666666666667, 0.1], \
Polygon[{{0.9727892058317135, -0.1022442655536478, -0.20791169081775912}, 
     {0.9781476007338057, -2.3956915336694647*^-16, -0.20791169081775912}, \
{0.9510565162951536, -2.329339705398441*^-16, -0.30901699437494734}, 
     {0.9458465291882033, -0.09941247612902124, -0.30901699437494734}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.9510565162951536, 0., -0.30901699437494734}, \
{0.9458465291882033, 0.09941247612902043, -0.30901699437494734}, 
     {0.9085409600397961, 0.09549150281252629, -0.40673664307580004}, \
{0.913545457642601, 0., -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.025, 0.1], \
Polygon[{{0.9458465291882033, 0.09941247612902043, -0.30901699437494734}, 
     {0.930273649576356, 0.19773576836617326, -0.30901699437494734}, \
{0.8935822975543767, 0.1899367807373569, -0.40673664307580004}, 
     {0.9085409600397961, 0.09549150281252629, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.930273649576356, 0.19773576836617326, -0.30901699437494734}, \
{0.9045084971874737, 0.29389262614623657, -0.30901699437494734}, 
     {0.8688333604228339, 0.28230107154560236, -0.40673664307580004}, \
{0.8935822975543767, 0.1899367807373569, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.058333333333333334, 0.1], \
Polygon[{{0.9045084971874737, 0.29389262614623657, -0.30901699437494734}, 
     {0.8688333604228338, 0.3868295348132558, -0.30901699437494734}, \
{0.8345653031794291, 0.3715724127386971, -0.40673664307580004}, 
     {0.8688333604228339, 0.28230107154560236, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.075, 0.1], 
   Polygon[{{0.8688333604228338, 0.3868295348132558, -0.30901699437494734}, \
{0.8236391035463321, 0.47552825814757677, -0.30901699437494734}, 
     {0.7911535738303733, 0.45677272882130043, -0.40673664307580004}, \
{0.8345653031794291, 0.3715724127386971, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.09166666666666666, 0.1], \
Polygon[{{0.8236391035463321, 0.47552825814757677, -0.30901699437494734}, 
     {0.7694208842938134, 0.5590169943749475, -0.30901699437494734}, \
{0.739073800366903, 0.536968547301099, -0.40673664307580004}, 
     {0.7911535738303733, 0.45677272882130043, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.7694208842938134, 0.5590169943749475, -0.30901699437494734}, \
{0.7067727288213006, 0.6363810234301194, -0.30901699437494734}, 
     {0.678896579685477, 0.6112812260087741, -0.40673664307580004}, \
{0.739073800366903, 0.536968547301099, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.125, 0.1], \
Polygon[{{0.7067727288213006, 0.6363810234301194, -0.30901699437494734}, 
     {0.6363810234301195, 0.7067727288213004, -0.30901699437494734}, \
{0.6112812260087742, 0.6788965796854769, -0.40673664307580004}, 
     {0.678896579685477, 0.6112812260087741, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.6363810234301195, 0.7067727288213004, -0.30901699437494734}, \
{0.5590169943749475, 0.7694208842938134, -0.30901699437494734}, 
     {0.536968547301099, 0.739073800366903, -0.40673664307580004}, \
{0.6112812260087742, 0.6788965796854769, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.15833333333333333, 0.1], \
Polygon[{{0.5590169943749475, 0.7694208842938134, -0.30901699437494734}, 
     {0.47552825814757693, 0.823639103546332, -0.30901699437494734}, \
{0.4567727288213006, 0.7911535738303732, -0.40673664307580004}, 
     {0.536968547301099, 0.739073800366903, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.175, 0.1], 
   Polygon[{{0.47552825814757693, 0.823639103546332, -0.30901699437494734}, \
{0.38682953481325605, 0.8688333604228338, -0.30901699437494734}, 
     {0.3715724127386973, 0.8345653031794291, -0.40673664307580004}, \
{0.4567727288213006, 0.7911535738303732, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.19166666666666665, 0.1], \
Polygon[{{0.38682953481325605, 0.8688333604228338, -0.30901699437494734}, 
     {0.2938926261462366, 0.9045084971874737, -0.30901699437494734}, \
{0.2823010715456024, 0.8688333604228339, -0.40673664307580004}, 
     {0.3715724127386973, 0.8345653031794291, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.2938926261462366, 0.9045084971874737, -0.30901699437494734}, \
{0.1977357683661734, 0.930273649576356, -0.30901699437494734}, 
     {0.189936780737357, 0.8935822975543766, -0.40673664307580004}, \
{0.2823010715456024, 0.8688333604228339, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.225, 0.1], \
Polygon[{{0.1977357683661734, 0.930273649576356, -0.30901699437494734}, 
     {0.09941247612902064, 0.9458465291882033, -0.30901699437494734}, \
{0.09549150281252648, 0.9085409600397961, -0.40673664307580004}, 
     {0.189936780737357, 0.8935822975543766, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.09941247612902064, 0.9458465291882033, -0.30901699437494734}, \
{5.823349263496102*^-17, 0.9510565162951536, -0.30901699437494734}, 
     {5.593667859673503*^-17, 0.913545457642601, -0.40673664307580004}, \
{0.09549150281252648, 0.9085409600397961, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.2583333333333333, 0.1], \
Polygon[{{5.823349263496102*^-17, 0.9510565162951536, -0.30901699437494734}, 
     {-0.09941247612902031, 0.9458465291882034, -0.30901699437494734}, \
{-0.09549150281252616, 0.9085409600397962, -0.40673664307580004}, 
     {5.593667859673503*^-17, 0.913545457642601, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.275, 0.1], 
   Polygon[{{-0.09941247612902031, 0.9458465291882034, -0.30901699437494734}, \
{-0.19773576836617307, 0.930273649576356, -0.30901699437494734}, 
     {-0.1899367807373567, 0.8935822975543767, -0.40673664307580004}, \
{-0.09549150281252616, 0.9085409600397962, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.2916666666666667, 0.1], \
Polygon[{{-0.19773576836617307, 0.930273649576356, -0.30901699437494734}, 
     {-0.2938926261462365, 0.9045084971874738, -0.30901699437494734}, \
{-0.2823010715456023, 0.8688333604228339, -0.40673664307580004}, 
     {-0.1899367807373567, 0.8935822975543767, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.2938926261462365, 0.9045084971874738, -0.30901699437494734}, \
{-0.3868295348132557, 0.8688333604228339, -0.30901699437494734}, 
     {-0.371572412738697, 0.8345653031794292, -0.40673664307580004}, \
{-0.2823010715456023, 0.8688333604228339, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.325, 0.1], \
Polygon[{{-0.3868295348132557, 0.8688333604228339, -0.30901699437494734}, 
     {-0.4755282581475766, 0.8236391035463321, -0.30901699437494734}, \
{-0.45677272882130027, 0.7911535738303733, -0.40673664307580004}, 
     {-0.371572412738697, 0.8345653031794292, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.4755282581475766, 0.8236391035463321, -0.30901699437494734}, \
{-0.5590169943749473, 0.7694208842938134, -0.30901699437494734}, 
     {-0.536968547301099, 0.739073800366903, -0.40673664307580004}, \
{-0.45677272882130027, 0.7911535738303733, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.35833333333333334, 0.1], \
Polygon[{{-0.5590169943749473, 0.7694208842938134, -0.30901699437494734}, 
     {-0.6363810234301192, 0.7067727288213007, -0.30901699437494734}, \
{-0.6112812260087739, 0.6788965796854771, -0.40673664307580004}, 
     {-0.536968547301099, 0.739073800366903, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.375, 0.1], 
   Polygon[{{-0.6363810234301192, 0.7067727288213007, -0.30901699437494734}, \
{-0.7067727288213003, 0.6363810234301196, -0.30901699437494734}, 
     {-0.6788965796854768, 0.6112812260087743, -0.40673664307580004}, \
{-0.6112812260087739, 0.6788965796854771, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.39166666666666666, 0.1], \
Polygon[{{-0.7067727288213003, 0.6363810234301196, -0.30901699437494734}, 
     {-0.7694208842938133, 0.5590169943749476, -0.30901699437494734}, \
{-0.7390738003669028, 0.5369685473010991, -0.40673664307580004}, 
     {-0.6788965796854768, 0.6112812260087743, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.7694208842938133, 0.5590169943749476, -0.30901699437494734}, \
{-0.8236391035463319, 0.47552825814757715, -0.30901699437494734}, 
     {-0.7911535738303731, 0.45677272882130077, -0.40673664307580004}, \
{-0.7390738003669028, 0.5369685473010991, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.425, 0.1], \
Polygon[{{-0.8236391035463319, 0.47552825814757715, -0.30901699437494734}, 
     {-0.8688333604228338, 0.3868295348132561, -0.30901699437494734}, \
{-0.834565303179429, 0.37157241273869734, -0.40673664307580004}, 
     {-0.7911535738303731, 0.45677272882130077, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.8688333604228338, 0.3868295348132561, -0.30901699437494734}, \
{-0.9045084971874737, 0.2938926261462367, -0.30901699437494734}, 
     {-0.8688333604228339, 0.28230107154560247, -0.40673664307580004}, \
{-0.834565303179429, 0.37157241273869734, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.4583333333333333, 0.1], \
Polygon[{{-0.9045084971874737, 0.2938926261462367, -0.30901699437494734}, 
     {-0.930273649576356, 0.19773576836617365, -0.30901699437494734}, \
{-0.8935822975543766, 0.18993678073735729, -0.40673664307580004}, 
     {-0.8688333604228339, 0.28230107154560247, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.475, 0.1], 
   Polygon[{{-0.930273649576356, 0.19773576836617365, -0.30901699437494734}, \
{-0.9458465291882033, 0.0994124761290207, -0.30901699437494734}, 
     {-0.9085409600397961, 0.09549150281252654, -0.40673664307580004}, \
{-0.8935822975543766, 0.18993678073735729, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.49166666666666664, 0.1], \
Polygon[{{-0.9458465291882033, 0.0994124761290207, -0.30901699437494734}, 
     {-0.9510565162951536, 1.1646698526992204*^-16, -0.30901699437494734}, \
{-0.913545457642601, 1.1187335719347007*^-16, -0.40673664307580004}, 
     {-0.9085409600397961, 0.09549150281252654, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.9510565162951536, 1.1646698526992204*^-16, \
-0.30901699437494734}, {-0.9458465291882034, -0.09941247612902004, 
      -0.30901699437494734}, {-0.9085409600397962, -0.09549150281252591, \
-0.40673664307580004}, {-0.913545457642601, 1.1187335719347007*^-16, 
      -0.40673664307580004}}]}, {CMYKColor[0.6166666666666667, 0.5, 0.525, \
0.1], 
   Polygon[{{-0.9458465291882034, -0.09941247612902004, \
-0.30901699437494734}, {-0.930273649576356, -0.19773576836617301, \
-0.30901699437494734}, 
     {-0.8935822975543767, -0.18993678073735668, -0.40673664307580004}, \
{-0.9085409600397962, -0.09549150281252591, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.930273649576356, -0.19773576836617301, -0.30901699437494734}, 
     {-0.9045084971874738, -0.29389262614623646, -0.30901699437494734}, \
{-0.8688333604228339, -0.28230107154560224, -0.40673664307580004}, 
     {-0.8935822975543767, -0.18993678073735668, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.9045084971874738, -0.29389262614623646, \
-0.30901699437494734}, {-0.868833360422834, -0.3868295348132555, \
-0.30901699437494734}, 
     {-0.8345653031794293, -0.3715724127386968, -0.40673664307580004}, \
{-0.8688333604228339, -0.28230107154560224, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.575, 0.1], \
Polygon[{{-0.868833360422834, -0.3868295348132555, -0.30901699437494734}, 
     {-0.8236391035463322, -0.47552825814757654, -0.30901699437494734}, \
{-0.7911535738303734, -0.4567727288213002, -0.40673664307580004}, 
     {-0.8345653031794293, -0.3715724127386968, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.8236391035463322, -0.47552825814757654, \
-0.30901699437494734}, {-0.7694208842938135, -0.5590169943749473, \
-0.30901699437494734}, 
     {-0.7390738003669031, -0.536968547301099, -0.40673664307580004}, \
{-0.7911535738303734, -0.4567727288213002, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.7694208842938135, -0.5590169943749473, -0.30901699437494734}, 
     {-0.7067727288213008, -0.6363810234301192, -0.30901699437494734}, \
{-0.6788965796854772, -0.6112812260087739, -0.40673664307580004}, 
     {-0.7390738003669031, -0.536968547301099, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{-0.7067727288213008, -0.6363810234301192, -0.30901699437494734}, \
{-0.6363810234301197, -0.7067727288213003, -0.30901699437494734}, 
     {-0.6112812260087744, -0.6788965796854768, -0.40673664307580004}, \
{-0.6788965796854772, -0.6112812260087739, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.6363810234301197, -0.7067727288213003, -0.30901699437494734}, 
     {-0.5590169943749476, -0.7694208842938133, -0.30901699437494734}, \
{-0.5369685473010991, -0.7390738003669028, -0.40673664307580004}, 
     {-0.6112812260087744, -0.6788965796854768, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.5590169943749476, -0.7694208842938133, -0.30901699437494734}, \
{-0.47552825814757727, -0.8236391035463317, -0.30901699437494734}, 
     {-0.4567727288213009, -0.7911535738303731, -0.40673664307580004}, \
{-0.5369685473010991, -0.7390738003669028, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.675, 0.1], \
Polygon[{{-0.47552825814757727, -0.8236391035463317, -0.30901699437494734}, 
     {-0.3868295348132565, -0.8688333604228335, -0.30901699437494734}, \
{-0.37157241273869773, -0.8345653031794289, -0.40673664307580004}, 
     {-0.4567727288213009, -0.7911535738303731, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.3868295348132565, -0.8688333604228335, -0.30901699437494734}, \
{-0.29389262614623674, -0.9045084971874737, -0.30901699437494734}, 
     {-0.2823010715456025, -0.8688333604228339, -0.40673664307580004}, \
{-0.37157241273869773, -0.8345653031794289, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.29389262614623674, -0.9045084971874737, -0.30901699437494734}, 
     {-0.1977357683661737, -0.930273649576356, -0.30901699437494734}, \
{-0.1899367807373573, -0.8935822975543766, -0.40673664307580004}, 
     {-0.2823010715456025, -0.8688333604228339, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{-0.1977357683661737, -0.930273649576356, -0.30901699437494734}, \
{-0.09941247612902117, -0.9458465291882033, -0.30901699437494734}, 
     {-0.095491502812527, -0.9085409600397961, -0.40673664307580004}, \
{-0.1899367807373573, -0.8935822975543766, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.09941247612902117, -0.9458465291882033, -0.30901699437494734}, 
     {-1.7470047790488305*^-16, -0.9510565162951536, -0.30901699437494734}, \
{-1.6781003579020508*^-16, -0.913545457642601, -0.40673664307580004}, 
     {-0.095491502812527, -0.9085409600397961, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.7470047790488305*^-16, -0.9510565162951536, \
-0.30901699437494734}, {0.09941247612901997, -0.9458465291882034, 
      -0.30901699437494734}, {0.09549150281252586, -0.9085409600397962, \
-0.40673664307580004}, {-1.6781003579020508*^-16, -0.913545457642601, 
      -0.40673664307580004}}]}, {CMYKColor[0.6166666666666667, 0.5, 0.775, \
0.1], 
   Polygon[{{0.09941247612901997, -0.9458465291882034, -0.30901699437494734}, \
{0.19773576836617254, -0.9302736495763562, -0.30901699437494734}, 
     {0.1899367807373562, -0.8935822975543768, -0.40673664307580004}, \
{0.09549150281252586, -0.9085409600397962, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.7916666666666666, 0.1], \
Polygon[{{0.19773576836617254, -0.9302736495763562, -0.30901699437494734}, 
     {0.2938926261462364, -0.9045084971874738, -0.30901699437494734}, \
{0.28230107154560224, -0.8688333604228339, -0.40673664307580004}, 
     {0.1899367807373562, -0.8935822975543768, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.2938926261462364, -0.9045084971874738, -0.30901699437494734}, \
{0.38682953481325544, -0.868833360422834, -0.30901699437494734}, 
     {0.37157241273869673, -0.8345653031794293, -0.40673664307580004}, \
{0.28230107154560224, -0.8688333604228339, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.825, 0.1], \
Polygon[{{0.38682953481325544, -0.868833360422834, -0.30901699437494734}, 
     {0.4755282581475762, -0.8236391035463324, -0.30901699437494734}, \
{0.4567727288212999, -0.7911535738303737, -0.40673664307580004}, 
     {0.37157241273869673, -0.8345653031794293, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.4755282581475762, -0.8236391035463324, -0.30901699437494734}, \
{0.5590169943749472, -0.7694208842938135, -0.30901699437494734}, 
     {0.5369685473010989, -0.7390738003669031, -0.40673664307580004}, \
{0.4567727288212999, -0.7911535738303737, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.8583333333333333, 0.1], \
Polygon[{{0.5590169943749472, -0.7694208842938135, -0.30901699437494734}, 
     {0.636381023430119, -0.7067727288213008, -0.30901699437494734}, \
{0.6112812260087739, -0.6788965796854772, -0.40673664307580004}, 
     {0.5369685473010989, -0.7390738003669031, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.875, 0.1], 
   Polygon[{{0.636381023430119, -0.7067727288213008, -0.30901699437494734}, \
{0.7067727288212999, -0.63638102343012, -0.30901699437494734}, 
     {0.6788965796854765, -0.6112812260087748, -0.40673664307580004}, \
{0.6112812260087739, -0.6788965796854772, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.8916666666666666, 0.1], \
Polygon[{{0.7067727288212999, -0.63638102343012, -0.30901699437494734}, 
     {0.7694208842938133, -0.5590169943749477, -0.30901699437494734}, \
{0.7390738003669028, -0.5369685473010992, -0.40673664307580004}, 
     {0.6788965796854765, -0.6112812260087748, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.7694208842938133, -0.5590169943749477, -0.30901699437494734}, \
{0.8236391035463317, -0.47552825814757727, -0.30901699437494734}, 
     {0.7911535738303731, -0.4567727288213009, -0.40673664307580004}, \
{0.7390738003669028, -0.5369685473010992, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.9249999999999999, 0.1], \
Polygon[{{0.8236391035463317, -0.47552825814757727, -0.30901699437494734}, 
     {0.8688333604228335, -0.38682953481325655, -0.30901699437494734}, \
{0.8345653031794289, -0.3715724127386978, -0.40673664307580004}, 
     {0.7911535738303731, -0.4567727288213009, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.8688333604228335, -0.38682953481325655, -0.30901699437494734}, \
{0.9045084971874737, -0.2938926261462368, -0.30901699437494734}, 
     {0.8688333604228339, -0.2823010715456026, -0.40673664307580004}, \
{0.8345653031794289, -0.3715724127386978, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.9583333333333334, 0.1], \
Polygon[{{0.9045084971874737, -0.2938926261462368, -0.30901699437494734}, 
     {0.930273649576356, -0.1977357683661738, -0.30901699437494734}, \
{0.8935822975543766, -0.1899367807373574, -0.40673664307580004}, 
     {0.8688333604228339, -0.2823010715456026, -0.40673664307580004}}]}, \
{CMYKColor[0.6166666666666667, 0.5, 0.975, 0.1], 
   Polygon[{{0.930273649576356, -0.1977357683661738, -0.30901699437494734}, \
{0.9458465291882033, -0.09941247612902124, -0.30901699437494734}, 
     {0.9085409600397961, -0.09549150281252705, -0.40673664307580004}, \
{0.8935822975543766, -0.1899367807373574, -0.40673664307580004}}]}, 
  {CMYKColor[0.6166666666666667, 0.5, 0.9916666666666667, 0.1], \
Polygon[{{0.9458465291882033, -0.09941247612902124, -0.30901699437494734}, 
     {0.9510565162951536, -2.329339705398441*^-16, -0.30901699437494734}, \
{0.913545457642601, -2.2374671438694014*^-16, -0.40673664307580004}, 
     {0.9085409600397961, -0.09549150281252705, -0.40673664307580004}}]}, \
{CMYKColor[0.65, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.913545457642601, 0., -0.40673664307580004}, \
{0.9085409600397961, 0.09549150281252629, -0.40673664307580004}, 
     {0.8612812260087742, 0.09052430460833645, -0.4999999999999998}, \
{0.8660254037844387, 0., -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.025, 0.1], Polygon[{{0.9085409600397961, \
0.09549150281252629, -0.40673664307580004}, 
     {0.8935822975543767, 0.1899367807373569, -0.40673664307580004}, \
{0.847100670886274, 0.1800568059919554, -0.4999999999999998}, 
     {0.8612812260087742, 0.09052430460833645, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.8935822975543767, 0.1899367807373569, -0.40673664307580004}, \
{0.8688333604228339, 0.28230107154560236, -0.40673664307580004}, 
     {0.823639103546332, 0.2676165673298174, -0.4999999999999998}, \
{0.847100670886274, 0.1800568059919554, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.058333333333333334, 0.1], \
Polygon[{{0.8688333604228339, 0.28230107154560236, -0.40673664307580004}, 
     {0.8345653031794291, 0.3715724127386971, -0.40673664307580004}, \
{0.7911535738303732, 0.35224426555364696, -0.4999999999999998}, 
     {0.823639103546332, 0.2676165673298174, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.075, 0.1], 
   Polygon[{{0.8345653031794291, 0.3715724127386971, -0.40673664307580004}, \
{0.7911535738303733, 0.45677272882130043, -0.40673664307580004}, 
     {0.7500000000000001, 0.4330127018922193, -0.4999999999999998}, \
{0.7911535738303732, 0.35224426555364696, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.09166666666666666, 0.1], \
Polygon[{{0.7911535738303733, 0.45677272882130043, -0.40673664307580004}, 
     {0.739073800366903, 0.536968547301099, -0.40673664307580004}, \
{0.7006292692220368, 0.5090369604551273, -0.4999999999999998}, 
     {0.7500000000000001, 0.4330127018922193, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.739073800366903, 0.536968547301099, -0.40673664307580004}, \
{0.678896579685477, 0.6112812260087741, -0.40673664307580004}, 
     {0.6435822975543767, 0.5794841035564564, -0.4999999999999998}, \
{0.7006292692220368, 0.5090369604551273, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.125, 0.1], Polygon[{{0.678896579685477, \
0.6112812260087741, -0.40673664307580004}, 
     {0.6112812260087742, 0.6788965796854769, -0.40673664307580004}, \
{0.5794841035564565, 0.6435822975543765, -0.4999999999999998}, 
     {0.6435822975543767, 0.5794841035564564, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.6112812260087742, 0.6788965796854769, -0.40673664307580004}, \
{0.536968547301099, 0.739073800366903, -0.40673664307580004}, 
     {0.5090369604551273, 0.7006292692220368, -0.4999999999999998}, \
{0.5794841035564565, 0.6435822975543765, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.15833333333333333, 0.1], \
Polygon[{{0.536968547301099, 0.739073800366903, -0.40673664307580004}, 
     {0.4567727288213006, 0.7911535738303732, -0.40673664307580004}, \
{0.43301270189221946, 0.75, -0.4999999999999998}, 
     {0.5090369604551273, 0.7006292692220368, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.175, 0.1], 
   Polygon[{{0.4567727288213006, 0.7911535738303732, -0.40673664307580004}, \
{0.3715724127386973, 0.8345653031794291, -0.40673664307580004}, 
     {0.35224426555364713, 0.7911535738303732, -0.4999999999999998}, \
{0.43301270189221946, 0.75, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.19166666666666665, 0.1], \
Polygon[{{0.3715724127386973, 0.8345653031794291, -0.40673664307580004}, 
     {0.2823010715456024, 0.8688333604228339, -0.40673664307580004}, \
{0.2676165673298175, 0.823639103546332, -0.4999999999999998}, 
     {0.35224426555364713, 0.7911535738303732, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.2823010715456024, 0.8688333604228339, -0.40673664307580004}, \
{0.189936780737357, 0.8935822975543766, -0.40673664307580004}, 
     {0.1800568059919555, 0.8471006708862739, -0.4999999999999998}, \
{0.2676165673298175, 0.823639103546332, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.225, 0.1], Polygon[{{0.189936780737357, \
0.8935822975543766, -0.40673664307580004}, 
     {0.09549150281252648, 0.9085409600397961, -0.40673664307580004}, \
{0.09052430460833664, 0.8612812260087742, -0.4999999999999998}, 
     {0.1800568059919555, 0.8471006708862739, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.09549150281252648, 0.9085409600397961, -0.40673664307580004}, \
{5.593667859673503*^-17, 0.913545457642601, -0.40673664307580004}, 
     {5.3027010602300673*^-17, 0.8660254037844387, -0.4999999999999998}, \
{0.09052430460833664, 0.8612812260087742, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.2583333333333333, 0.1], \
Polygon[{{5.593667859673503*^-17, 0.913545457642601, -0.40673664307580004}, 
     {-0.09549150281252616, 0.9085409600397962, -0.40673664307580004}, \
{-0.09052430460833634, 0.8612812260087743, -0.4999999999999998}, 
     {5.3027010602300673*^-17, 0.8660254037844387, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.275, 0.1], 
   Polygon[{{-0.09549150281252616, 0.9085409600397962, -0.40673664307580004}, \
{-0.1899367807373567, 0.8935822975543767, -0.40673664307580004}, 
     {-0.18005680599195523, 0.847100670886274, -0.4999999999999998}, \
{-0.09052430460833634, 0.8612812260087743, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.2916666666666667, 0.1], \
Polygon[{{-0.1899367807373567, 0.8935822975543767, -0.40673664307580004}, 
     {-0.2823010715456023, 0.8688333604228339, -0.40673664307580004}, \
{-0.26761656732981737, 0.8236391035463321, -0.4999999999999998}, 
     {-0.18005680599195523, 0.847100670886274, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.2823010715456023, 0.8688333604228339, -0.40673664307580004}, \
{-0.371572412738697, 0.8345653031794292, -0.40673664307580004}, 
     {-0.35224426555364685, 0.7911535738303733, -0.4999999999999998}, \
{-0.26761656732981737, 0.8236391035463321, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.325, 0.1], Polygon[{{-0.371572412738697, \
0.8345653031794292, -0.40673664307580004}, 
     {-0.45677272882130027, 0.7911535738303733, -0.40673664307580004}, \
{-0.4330127018922192, 0.7500000000000001, -0.4999999999999998}, 
     {-0.35224426555364685, 0.7911535738303733, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.45677272882130027, 0.7911535738303733, -0.40673664307580004}, \
{-0.536968547301099, 0.739073800366903, -0.40673664307580004}, 
     {-0.5090369604551271, 0.7006292692220368, -0.4999999999999998}, \
{-0.4330127018922192, 0.7500000000000001, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.35833333333333334, 0.1], \
Polygon[{{-0.536968547301099, 0.739073800366903, -0.40673664307580004}, 
     {-0.6112812260087739, 0.6788965796854771, -0.40673664307580004}, \
{-0.5794841035564562, 0.6435822975543768, -0.4999999999999998}, 
     {-0.5090369604551271, 0.7006292692220368, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.375, 0.1], 
   Polygon[{{-0.6112812260087739, 0.6788965796854771, -0.40673664307580004}, \
{-0.6788965796854768, 0.6112812260087743, -0.40673664307580004}, 
     {-0.6435822975543763, 0.5794841035564566, -0.4999999999999998}, \
{-0.5794841035564562, 0.6435822975543768, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.39166666666666666, 0.1], \
Polygon[{{-0.6788965796854768, 0.6112812260087743, -0.40673664307580004}, 
     {-0.7390738003669028, 0.5369685473010991, -0.40673664307580004}, \
{-0.7006292692220367, 0.5090369604551274, -0.4999999999999998}, 
     {-0.6435822975543763, 0.5794841035564566, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.7390738003669028, 0.5369685473010991, -0.40673664307580004}, \
{-0.7911535738303731, 0.45677272882130077, -0.40673664307580004}, 
     {-0.7499999999999999, 0.43301270189221963, -0.4999999999999998}, \
{-0.7006292692220367, 0.5090369604551274, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.425, 0.1], Polygon[{{-0.7911535738303731, \
0.45677272882130077, -0.40673664307580004}, 
     {-0.834565303179429, 0.37157241273869734, -0.40673664307580004}, \
{-0.7911535738303732, 0.3522442655536472, -0.4999999999999998}, 
     {-0.7499999999999999, 0.43301270189221963, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.834565303179429, 0.37157241273869734, -0.40673664307580004}, \
{-0.8688333604228339, 0.28230107154560247, -0.40673664307580004}, 
     {-0.823639103546332, 0.26761656732981753, -0.4999999999999998}, \
{-0.7911535738303732, 0.3522442655536472, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.4583333333333333, 0.1], \
Polygon[{{-0.8688333604228339, 0.28230107154560247, -0.40673664307580004}, 
     {-0.8935822975543766, 0.18993678073735729, -0.40673664307580004}, \
{-0.8471006708862739, 0.18005680599195575, -0.4999999999999998}, 
     {-0.823639103546332, 0.26761656732981753, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.475, 0.1], 
   Polygon[{{-0.8935822975543766, 0.18993678073735729, -0.40673664307580004}, \
{-0.9085409600397961, 0.09549150281252654, -0.40673664307580004}, 
     {-0.8612812260087742, 0.0905243046083367, -0.4999999999999998}, \
{-0.8471006708862739, 0.18005680599195575, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.49166666666666664, 0.1], \
Polygon[{{-0.9085409600397961, 0.09549150281252654, -0.40673664307580004}, 
     {-0.913545457642601, 1.1187335719347007*^-16, -0.40673664307580004}, \
{-0.8660254037844387, 1.0605402120460135*^-16, -0.4999999999999998}, 
     {-0.8612812260087742, 0.0905243046083367, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.913545457642601, 1.1187335719347007*^-16, \
-0.40673664307580004}, {-0.9085409600397962, -0.09549150281252591, 
      -0.40673664307580004}, {-0.8612812260087743, -0.0905243046083361, \
-0.4999999999999998}, {-0.8660254037844387, 1.0605402120460135*^-16, 
      -0.4999999999999998}}]}, {CMYKColor[0.65, 0.5, 0.525, 0.1], \
Polygon[{{-0.9085409600397962, -0.09549150281252591, -0.40673664307580004}, 
     {-0.8935822975543767, -0.18993678073735668, -0.40673664307580004}, \
{-0.847100670886274, -0.18005680599195517, -0.4999999999999998}, 
     {-0.8612812260087743, -0.0905243046083361, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-0.8935822975543767, -0.18993678073735668, \
-0.40673664307580004}, {-0.8688333604228339, -0.28230107154560224, \
-0.40673664307580004}, 
     {-0.8236391035463321, -0.26761656732981737, -0.4999999999999998}, \
{-0.847100670886274, -0.18005680599195517, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.5583333333333333, 0.1], \
Polygon[{{-0.8688333604228339, -0.28230107154560224, -0.40673664307580004}, 
     {-0.8345653031794293, -0.3715724127386968, -0.40673664307580004}, \
{-0.7911535738303734, -0.3522442655536467, -0.4999999999999998}, 
     {-0.8236391035463321, -0.26761656732981737, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.575, 0.1], 
   Polygon[{{-0.8345653031794293, -0.3715724127386968, -0.40673664307580004}, \
{-0.7911535738303734, -0.4567727288213002, -0.40673664307580004}, 
     {-0.7500000000000002, -0.43301270189221913, -0.4999999999999998}, \
{-0.7911535738303734, -0.3522442655536467, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.5916666666666667, 0.1], \
Polygon[{{-0.7911535738303734, -0.4567727288213002, -0.40673664307580004}, 
     {-0.7390738003669031, -0.536968547301099, -0.40673664307580004}, \
{-0.7006292692220369, -0.5090369604551271, -0.4999999999999998}, 
     {-0.7500000000000002, -0.43301270189221913, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-0.7390738003669031, -0.536968547301099, -0.40673664307580004}, \
{-0.6788965796854772, -0.6112812260087739, -0.40673664307580004}, 
     {-0.6435822975543769, -0.5794841035564562, -0.4999999999999998}, \
{-0.7006292692220369, -0.5090369604551271, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.625, 0.1], Polygon[{{-0.6788965796854772, \
-0.6112812260087739, -0.40673664307580004}, 
     {-0.6112812260087744, -0.6788965796854768, -0.40673664307580004}, \
{-0.5794841035564567, -0.6435822975543763, -0.4999999999999998}, 
     {-0.6435822975543769, -0.5794841035564562, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{-0.6112812260087744, -0.6788965796854768, -0.40673664307580004}, \
{-0.5369685473010991, -0.7390738003669028, -0.40673664307580004}, 
     {-0.5090369604551274, -0.7006292692220367, -0.4999999999999998}, \
{-0.5794841035564567, -0.6435822975543763, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.6583333333333333, 0.1], \
Polygon[{{-0.5369685473010991, -0.7390738003669028, -0.40673664307580004}, 
     {-0.4567727288213009, -0.7911535738303731, -0.40673664307580004}, \
{-0.43301270189221974, -0.7499999999999998, -0.4999999999999998}, 
     {-0.5090369604551274, -0.7006292692220367, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.675, 0.1], 
   Polygon[{{-0.4567727288213009, -0.7911535738303731, -0.40673664307580004}, \
{-0.37157241273869773, -0.8345653031794289, -0.40673664307580004}, 
     {-0.3522442655536476, -0.791153573830373, -0.4999999999999998}, \
{-0.43301270189221974, -0.7499999999999998, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.6916666666666667, 0.1], \
Polygon[{{-0.37157241273869773, -0.8345653031794289, -0.40673664307580004}, 
     {-0.2823010715456025, -0.8688333604228339, -0.40673664307580004}, \
{-0.2676165673298176, -0.823639103546332, -0.4999999999999998}, 
     {-0.3522442655536476, -0.791153573830373, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.2823010715456025, -0.8688333604228339, -0.40673664307580004}, \
{-0.1899367807373573, -0.8935822975543766, -0.40673664307580004}, 
     {-0.1800568059919558, -0.8471006708862739, -0.4999999999999998}, \
{-0.2676165673298176, -0.823639103546332, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.725, 0.1], Polygon[{{-0.1899367807373573, \
-0.8935822975543766, -0.40673664307580004}, 
     {-0.095491502812527, -0.9085409600397961, -0.40673664307580004}, \
{-0.09052430460833713, -0.8612812260087742, -0.4999999999999998}, 
     {-0.1800568059919558, -0.8471006708862739, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.095491502812527, -0.9085409600397961, -0.40673664307580004}, \
{-1.6781003579020508*^-16, -0.913545457642601, -0.40673664307580004}, 
     {-1.5908103180690203*^-16, -0.8660254037844387, -0.4999999999999998}, \
{-0.09052430460833713, -0.8612812260087742, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.7583333333333333, 0.1], \
Polygon[{{-1.6781003579020508*^-16, -0.913545457642601, \
-0.40673664307580004}, 
     {0.09549150281252586, -0.9085409600397962, -0.40673664307580004}, \
{0.09052430460833605, -0.8612812260087743, -0.4999999999999998}, 
     {-1.5908103180690203*^-16, -0.8660254037844387, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.775, 0.1], 
   Polygon[{{0.09549150281252586, -0.9085409600397962, -0.40673664307580004}, \
{0.1899367807373562, -0.8935822975543768, -0.40673664307580004}, 
     {0.18005680599195473, -0.847100670886274, -0.4999999999999998}, \
{0.09052430460833605, -0.8612812260087743, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.7916666666666666, 0.1], \
Polygon[{{0.1899367807373562, -0.8935822975543768, -0.40673664307580004}, 
     {0.28230107154560224, -0.8688333604228339, -0.40673664307580004}, \
{0.2676165673298173, -0.8236391035463321, -0.4999999999999998}, 
     {0.18005680599195473, -0.847100670886274, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.28230107154560224, -0.8688333604228339, -0.40673664307580004}, \
{0.37157241273869673, -0.8345653031794293, -0.40673664307580004}, 
     {0.35224426555364663, -0.7911535738303734, -0.4999999999999998}, \
{0.2676165673298173, -0.8236391035463321, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.825, 0.1], Polygon[{{0.37157241273869673, \
-0.8345653031794293, -0.40673664307580004}, 
     {0.4567727288212999, -0.7911535738303737, -0.40673664307580004}, \
{0.4330127018922188, -0.7500000000000004, -0.4999999999999998}, 
     {0.35224426555364663, -0.7911535738303734, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.4567727288212999, -0.7911535738303737, -0.40673664307580004}, \
{0.5369685473010989, -0.7390738003669031, -0.40673664307580004}, 
     {0.509036960455127, -0.7006292692220369, -0.4999999999999998}, \
{0.4330127018922188, -0.7500000000000004, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.8583333333333333, 0.1], \
Polygon[{{0.5369685473010989, -0.7390738003669031, -0.40673664307580004}, 
     {0.6112812260087739, -0.6788965796854772, -0.40673664307580004}, \
{0.5794841035564561, -0.6435822975543769, -0.4999999999999998}, 
     {0.509036960455127, -0.7006292692220369, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.875, 0.1], 
   Polygon[{{0.6112812260087739, -0.6788965796854772, -0.40673664307580004}, \
{0.6788965796854765, -0.6112812260087748, -0.40673664307580004}, 
     {0.6435822975543761, -0.579484103556457, -0.4999999999999998}, \
{0.5794841035564561, -0.6435822975543769, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.8916666666666666, 0.1], \
Polygon[{{0.6788965796854765, -0.6112812260087748, -0.40673664307580004}, 
     {0.7390738003669028, -0.5369685473010992, -0.40673664307580004}, \
{0.7006292692220367, -0.5090369604551274, -0.4999999999999998}, 
     {0.6435822975543761, -0.579484103556457, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.7390738003669028, -0.5369685473010992, -0.40673664307580004}, \
{0.7911535738303731, -0.4567727288213009, -0.40673664307580004}, 
     {0.7499999999999998, -0.43301270189221974, -0.4999999999999998}, \
{0.7006292692220367, -0.5090369604551274, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.9249999999999999, 0.1], \
Polygon[{{0.7911535738303731, -0.4567727288213009, -0.40673664307580004}, 
     {0.8345653031794289, -0.3715724127386978, -0.40673664307580004}, \
{0.791153573830373, -0.35224426555364763, -0.4999999999999998}, 
     {0.7499999999999998, -0.43301270189221974, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.8345653031794289, -0.3715724127386978, -0.40673664307580004}, \
{0.8688333604228339, -0.2823010715456026, -0.40673664307580004}, 
     {0.823639103546332, -0.26761656732981765, -0.4999999999999998}, \
{0.791153573830373, -0.35224426555364763, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.9583333333333334, 0.1], \
Polygon[{{0.8688333604228339, -0.2823010715456026, -0.40673664307580004}, 
     {0.8935822975543766, -0.1899367807373574, -0.40673664307580004}, \
{0.8471006708862739, -0.18005680599195586, -0.4999999999999998}, 
     {0.823639103546332, -0.26761656732981765, -0.4999999999999998}}]}, \
{CMYKColor[0.65, 0.5, 0.975, 0.1], 
   Polygon[{{0.8935822975543766, -0.1899367807373574, -0.40673664307580004}, \
{0.9085409600397961, -0.09549150281252705, -0.40673664307580004}, 
     {0.8612812260087742, -0.09052430460833719, -0.4999999999999998}, \
{0.8471006708862739, -0.18005680599195586, -0.4999999999999998}}]}, 
  {CMYKColor[0.65, 0.5, 0.9916666666666667, 0.1], \
Polygon[{{0.9085409600397961, -0.09549150281252705, -0.40673664307580004}, 
     {0.913545457642601, -2.2374671438694014*^-16, -0.40673664307580004}, \
{0.8660254037844387, -2.121080424092027*^-16, -0.4999999999999998}, 
     {0.8612812260087742, -0.09052430460833719, -0.4999999999999998}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.8660254037844387, 0., -0.4999999999999998}, \
{0.8612812260087742, 0.09052430460833645, -0.4999999999999998}, 
     {0.8045851146309164, 0.0845653031794291, -0.587785252292473}, \
{0.8090169943749475, 0., -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.025, 0.1], \
Polygon[{{0.8612812260087742, 0.09052430460833645, -0.4999999999999998}, 
     {0.847100670886274, 0.1800568059919554, -0.4999999999999998}, \
{0.7913380320007296, 0.168204091200797, -0.587785252292473}, 
     {0.8045851146309164, 0.0845653031794291, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.847100670886274, 0.1800568059919554, -0.4999999999999998}, \
{0.823639103546332, 0.2676165673298174, -0.4999999999999998}, 
     {0.7694208842938134, 0.24999999999999997, -0.587785252292473}, \
{0.7913380320007296, 0.168204091200797, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.058333333333333334, 0.1], \
Polygon[{{0.823639103546332, 0.2676165673298174, -0.4999999999999998}, 
     {0.7911535738303732, 0.35224426555364696, -0.4999999999999998}, \
{0.7390738003669028, 0.3290568564833396, -0.587785252292473}, 
     {0.7694208842938134, 0.24999999999999997, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{0.7911535738303732, 0.35224426555364696, -0.4999999999999998}, \
{0.7500000000000001, 0.4330127018922193, -0.4999999999999998}, 
     {0.7006292692220368, 0.40450849718747367, -0.587785252292473}, \
{0.7390738003669028, 0.3290568564833396, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.09166666666666666, 0.1], \
Polygon[{{0.7500000000000001, 0.4330127018922193, -0.4999999999999998}, 
     {0.7006292692220368, 0.5090369604551273, -0.4999999999999998}, \
{0.6545084971874737, 0.4755282581475768, -0.587785252292473}, 
     {0.7006292692220368, 0.40450849718747367, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.7006292692220368, 0.5090369604551273, -0.4999999999999998}, \
{0.6435822975543767, 0.5794841035564564, -0.4999999999999998}, 
     {0.6012167930930165, 0.5413380320007295, -0.587785252292473}, \
{0.6545084971874737, 0.4755282581475768, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.125, 0.1], \
Polygon[{{0.6435822975543767, 0.5794841035564564, -0.4999999999999998}, 
     {0.5794841035564565, 0.6435822975543765, -0.4999999999999998}, \
{0.5413380320007296, 0.6012167930930162, -0.587785252292473}, 
     {0.6012167930930165, 0.5413380320007295, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.5794841035564565, 0.6435822975543765, -0.4999999999999998}, \
{0.5090369604551273, 0.7006292692220368, -0.4999999999999998}, 
     {0.4755282581475768, 0.6545084971874737, -0.587785252292473}, \
{0.5413380320007296, 0.6012167930930162, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.15833333333333333, 0.1], \
Polygon[{{0.5090369604551273, 0.7006292692220368, -0.4999999999999998}, 
     {0.43301270189221946, 0.75, -0.4999999999999998}, {0.40450849718747384, \
0.7006292692220367, -0.587785252292473}, 
     {0.4755282581475768, 0.6545084971874737, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{0.43301270189221946, 0.75, -0.4999999999999998}, \
{0.35224426555364713, 0.7911535738303732, -0.4999999999999998}, 
     {0.3290568564833398, 0.7390738003669028, -0.587785252292473}, \
{0.40450849718747384, 0.7006292692220367, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.19166666666666665, 0.1], \
Polygon[{{0.35224426555364713, 0.7911535738303732, -0.4999999999999998}, 
     {0.2676165673298175, 0.823639103546332, -0.4999999999999998}, \
{0.25000000000000006, 0.7694208842938134, -0.587785252292473}, 
     {0.3290568564833398, 0.7390738003669028, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.2676165673298175, 0.823639103546332, -0.4999999999999998}, \
{0.1800568059919555, 0.8471006708862739, -0.4999999999999998}, 
     {0.1682040912007971, 0.7913380320007295, -0.587785252292473}, \
{0.25000000000000006, 0.7694208842938134, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.225, 0.1], \
Polygon[{{0.1800568059919555, 0.8471006708862739, -0.4999999999999998}, 
     {0.09052430460833664, 0.8612812260087742, -0.4999999999999998}, \
{0.08456530317942927, 0.8045851146309164, -0.587785252292473}, 
     {0.1682040912007971, 0.7913380320007295, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.09052430460833664, 0.8612812260087742, -0.4999999999999998}, \
{5.3027010602300673*^-17, 0.8660254037844387, -0.4999999999999998}, 
     {4.9536367583092156*^-17, 0.8090169943749475, -0.587785252292473}, \
{0.08456530317942927, 0.8045851146309164, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.2583333333333333, 0.1], \
Polygon[{{5.3027010602300673*^-17, 0.8660254037844387, -0.4999999999999998}, 
     {-0.09052430460833634, 0.8612812260087743, -0.4999999999999998}, \
{-0.084565303179429, 0.8045851146309165, -0.587785252292473}, 
     {4.9536367583092156*^-17, 0.8090169943749475, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{-0.09052430460833634, 0.8612812260087743, -0.4999999999999998}, \
{-0.18005680599195523, 0.847100670886274, -0.4999999999999998}, 
     {-0.16820409120079685, 0.7913380320007296, -0.587785252292473}, \
{-0.084565303179429, 0.8045851146309165, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.2916666666666667, 0.1], \
Polygon[{{-0.18005680599195523, 0.847100670886274, -0.4999999999999998}, 
     {-0.26761656732981737, 0.8236391035463321, -0.4999999999999998}, \
{-0.24999999999999994, 0.7694208842938134, -0.587785252292473}, 
     {-0.16820409120079685, 0.7913380320007296, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.26761656732981737, 0.8236391035463321, -0.4999999999999998}, \
{-0.35224426555364685, 0.7911535738303733, -0.4999999999999998}, 
     {-0.32905685648333954, 0.739073800366903, -0.587785252292473}, \
{-0.24999999999999994, 0.7694208842938134, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.325, 0.1], \
Polygon[{{-0.35224426555364685, 0.7911535738303733, -0.4999999999999998}, 
     {-0.4330127018922192, 0.7500000000000001, -0.4999999999999998}, \
{-0.40450849718747356, 0.7006292692220368, -0.587785252292473}, 
     {-0.32905685648333954, 0.739073800366903, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.4330127018922192, 0.7500000000000001, -0.4999999999999998}, \
{-0.5090369604551271, 0.7006292692220368, -0.4999999999999998}, 
     {-0.4755282581475767, 0.6545084971874737, -0.587785252292473}, \
{-0.40450849718747356, 0.7006292692220368, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.35833333333333334, 0.1], \
Polygon[{{-0.5090369604551271, 0.7006292692220368, -0.4999999999999998}, 
     {-0.5794841035564562, 0.6435822975543768, -0.4999999999999998}, \
{-0.5413380320007293, 0.6012167930930166, -0.587785252292473}, 
     {-0.4755282581475767, 0.6545084971874737, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{-0.5794841035564562, 0.6435822975543768, -0.4999999999999998}, \
{-0.6435822975543763, 0.5794841035564566, -0.4999999999999998}, 
     {-0.6012167930930162, 0.5413380320007297, -0.587785252292473}, \
{-0.5413380320007293, 0.6012167930930166, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.39166666666666666, 0.1], \
Polygon[{{-0.6435822975543763, 0.5794841035564566, -0.4999999999999998}, 
     {-0.7006292692220367, 0.5090369604551274, -0.4999999999999998}, \
{-0.6545084971874736, 0.4755282581475769, -0.587785252292473}, 
     {-0.6012167930930162, 0.5413380320007297, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.7006292692220367, 0.5090369604551274, -0.4999999999999998}, \
{-0.7499999999999999, 0.43301270189221963, -0.4999999999999998}, 
     {-0.7006292692220366, 0.404508497187474, -0.587785252292473}, \
{-0.6545084971874736, 0.4755282581475769, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.425, 0.1], \
Polygon[{{-0.7499999999999999, 0.43301270189221963, -0.4999999999999998}, 
     {-0.7911535738303732, 0.3522442655536472, -0.4999999999999998}, \
{-0.7390738003669027, 0.3290568564833398, -0.587785252292473}, 
     {-0.7006292692220366, 0.404508497187474, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.7911535738303732, 0.3522442655536472, -0.4999999999999998}, \
{-0.823639103546332, 0.26761656732981753, -0.4999999999999998}, 
     {-0.7694208842938134, 0.25000000000000006, -0.587785252292473}, \
{-0.7390738003669027, 0.3290568564833398, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.4583333333333333, 0.1], \
Polygon[{{-0.823639103546332, 0.26761656732981753, -0.4999999999999998}, 
     {-0.8471006708862739, 0.18005680599195575, -0.4999999999999998}, \
{-0.7913380320007295, 0.16820409120079735, -0.587785252292473}, 
     {-0.7694208842938134, 0.25000000000000006, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{-0.8471006708862739, 0.18005680599195575, -0.4999999999999998}, \
{-0.8612812260087742, 0.0905243046083367, -0.4999999999999998}, 
     {-0.8045851146309164, 0.08456530317942933, -0.587785252292473}, \
{-0.7913380320007295, 0.16820409120079735, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.49166666666666664, 0.1], \
Polygon[{{-0.8612812260087742, 0.0905243046083367, -0.4999999999999998}, 
     {-0.8660254037844387, 1.0605402120460135*^-16, -0.4999999999999998}, \
{-0.8090169943749475, 9.907273516618431*^-17, -0.587785252292473}, 
     {-0.8045851146309164, 0.08456530317942933, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.8660254037844387, 1.0605402120460135*^-16, \
-0.4999999999999998}, {-0.8612812260087743, -0.0905243046083361, \
-0.4999999999999998}, 
     {-0.8045851146309165, -0.08456530317942877, -0.587785252292473}, \
{-0.8090169943749475, 9.907273516618431*^-17, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.525, 0.1], \
Polygon[{{-0.8612812260087743, -0.0905243046083361, -0.4999999999999998}, 
     {-0.847100670886274, -0.18005680599195517, -0.4999999999999998}, \
{-0.7913380320007296, -0.1682040912007968, -0.587785252292473}, 
     {-0.8045851146309165, -0.08456530317942877, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-0.847100670886274, -0.18005680599195517, -0.4999999999999998}, \
{-0.8236391035463321, -0.26761656732981737, -0.4999999999999998}, 
     {-0.7694208842938134, -0.2499999999999999, -0.587785252292473}, \
{-0.7913380320007296, -0.1682040912007968, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.5583333333333333, 0.1], \
Polygon[{{-0.8236391035463321, -0.26761656732981737, -0.4999999999999998}, 
     {-0.7911535738303734, -0.3522442655536467, -0.4999999999999998}, \
{-0.739073800366903, -0.3290568564833394, -0.587785252292473}, 
     {-0.7694208842938134, -0.2499999999999999, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{-0.7911535738303734, -0.3522442655536467, -0.4999999999999998}, \
{-0.7500000000000002, -0.43301270189221913, -0.4999999999999998}, 
     {-0.7006292692220369, -0.4045084971874735, -0.587785252292473}, \
{-0.739073800366903, -0.3290568564833394, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.5916666666666667, 0.1], \
Polygon[{{-0.7500000000000002, -0.43301270189221913, -0.4999999999999998}, 
     {-0.7006292692220369, -0.5090369604551271, -0.4999999999999998}, \
{-0.6545084971874738, -0.4755282581475767, -0.587785252292473}, 
     {-0.7006292692220369, -0.4045084971874735, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-0.7006292692220369, -0.5090369604551271, -0.4999999999999998}, \
{-0.6435822975543769, -0.5794841035564562, -0.4999999999999998}, 
     {-0.6012167930930167, -0.5413380320007293, -0.587785252292473}, \
{-0.6545084971874738, -0.4755282581475767, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.625, 0.1], \
Polygon[{{-0.6435822975543769, -0.5794841035564562, -0.4999999999999998}, 
     {-0.5794841035564567, -0.6435822975543763, -0.4999999999999998}, \
{-0.5413380320007297, -0.6012167930930162, -0.587785252292473}, 
     {-0.6012167930930167, -0.5413380320007293, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{-0.5794841035564567, -0.6435822975543763, -0.4999999999999998}, \
{-0.5090369604551274, -0.7006292692220367, -0.4999999999999998}, 
     {-0.4755282581475769, -0.6545084971874736, -0.587785252292473}, \
{-0.5413380320007297, -0.6012167930930162, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.6583333333333333, 0.1], \
Polygon[{{-0.5090369604551274, -0.7006292692220367, -0.4999999999999998}, 
     {-0.43301270189221974, -0.7499999999999998, -0.4999999999999998}, \
{-0.40450849718747406, -0.7006292692220366, -0.587785252292473}, 
     {-0.4755282581475769, -0.6545084971874736, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{-0.43301270189221974, -0.7499999999999998, -0.4999999999999998}, \
{-0.3522442655536476, -0.791153573830373, -0.4999999999999998}, 
     {-0.3290568564833402, -0.7390738003669025, -0.587785252292473}, \
{-0.40450849718747406, -0.7006292692220366, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.6916666666666667, 0.1], \
Polygon[{{-0.3522442655536476, -0.791153573830373, -0.4999999999999998}, 
     {-0.2676165673298176, -0.823639103546332, -0.4999999999999998}, \
{-0.2500000000000001, -0.7694208842938134, -0.587785252292473}, 
     {-0.3290568564833402, -0.7390738003669025, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.2676165673298176, -0.823639103546332, -0.4999999999999998}, \
{-0.1800568059919558, -0.8471006708862739, -0.4999999999999998}, 
     {-0.16820409120079738, -0.7913380320007295, -0.587785252292473}, \
{-0.2500000000000001, -0.7694208842938134, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.725, 0.1], \
Polygon[{{-0.1800568059919558, -0.8471006708862739, -0.4999999999999998}, 
     {-0.09052430460833713, -0.8612812260087742, -0.4999999999999998}, \
{-0.08456530317942973, -0.8045851146309164, -0.587785252292473}, 
     {-0.16820409120079738, -0.7913380320007295, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.09052430460833713, -0.8612812260087742, -0.4999999999999998}, \
{-1.5908103180690203*^-16, -0.8660254037844387, 
      -0.4999999999999998}, {-1.4860910274927647*^-16, -0.8090169943749475, \
-0.587785252292473}, {-0.08456530317942973, -0.8045851146309164, 
      -0.587785252292473}}]}, {CMYKColor[0.6833333333333333, 0.5, \
0.7583333333333333, 0.1], 
   Polygon[{{-1.5908103180690203*^-16, -0.8660254037844387, \
-0.4999999999999998}, {0.09052430460833605, -0.8612812260087743, \
-0.4999999999999998}, 
     {0.08456530317942872, -0.8045851146309165, -0.587785252292473}, \
{-1.4860910274927647*^-16, -0.8090169943749475, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.775, 0.1], \
Polygon[{{0.09052430460833605, -0.8612812260087743, -0.4999999999999998}, 
     {0.18005680599195473, -0.847100670886274, -0.4999999999999998}, \
{0.1682040912007964, -0.7913380320007297, -0.587785252292473}, 
     {0.08456530317942872, -0.8045851146309165, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.18005680599195473, -0.847100670886274, -0.4999999999999998}, \
{0.2676165673298173, -0.8236391035463321, -0.4999999999999998}, 
     {0.24999999999999986, -0.7694208842938134, -0.587785252292473}, \
{0.1682040912007964, -0.7913380320007297, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.2676165673298173, -0.8236391035463321, -0.4999999999999998}, 
     {0.35224426555364663, -0.7911535738303734, -0.4999999999999998}, \
{0.3290568564833393, -0.739073800366903, -0.587785252292473}, 
     {0.24999999999999986, -0.7694208842938134, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{0.35224426555364663, -0.7911535738303734, -0.4999999999999998}, \
{0.4330127018922188, -0.7500000000000004, -0.4999999999999998}, 
     {0.40450849718747317, -0.7006292692220372, -0.587785252292473}, \
{0.3290568564833393, -0.739073800366903, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.4330127018922188, -0.7500000000000004, -0.4999999999999998}, 
     {0.509036960455127, -0.7006292692220369, -0.4999999999999998}, \
{0.47552825814757665, -0.6545084971874738, -0.587785252292473}, 
     {0.40450849718747317, -0.7006292692220372, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.509036960455127, -0.7006292692220369, -0.4999999999999998}, \
{0.5794841035564561, -0.6435822975543769, -0.4999999999999998}, 
     {0.5413380320007293, -0.6012167930930167, -0.587785252292473}, \
{0.47552825814757665, -0.6545084971874738, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.875, 0.1], \
Polygon[{{0.5794841035564561, -0.6435822975543769, -0.4999999999999998}, 
     {0.6435822975543761, -0.579484103556457, -0.4999999999999998}, \
{0.6012167930930159, -0.54133803200073, -0.587785252292473}, 
     {0.5413380320007293, -0.6012167930930167, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.6435822975543761, -0.579484103556457, -0.4999999999999998}, \
{0.7006292692220367, -0.5090369604551274, -0.4999999999999998}, 
     {0.6545084971874736, -0.475528258147577, -0.587785252292473}, \
{0.6012167930930159, -0.54133803200073, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.7006292692220367, -0.5090369604551274, -0.4999999999999998}, 
     {0.7499999999999998, -0.43301270189221974, -0.4999999999999998}, \
{0.7006292692220366, -0.40450849718747406, -0.587785252292473}, 
     {0.6545084971874736, -0.475528258147577, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.7499999999999998, -0.43301270189221974, -0.4999999999999998}, \
{0.791153573830373, -0.35224426555364763, -0.4999999999999998}, 
     {0.7390738003669025, -0.32905685648334027, -0.587785252292473}, \
{0.7006292692220366, -0.40450849718747406, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.791153573830373, -0.35224426555364763, -0.4999999999999998}, 
     {0.823639103546332, -0.26761656732981765, -0.4999999999999998}, \
{0.7694208842938134, -0.25000000000000017, -0.587785252292473}, 
     {0.7390738003669025, -0.32905685648334027, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.823639103546332, -0.26761656732981765, -0.4999999999999998}, \
{0.8471006708862739, -0.18005680599195586, -0.4999999999999998}, 
     {0.7913380320007295, -0.16820409120079746, -0.587785252292473}, \
{0.7694208842938134, -0.25000000000000017, -0.587785252292473}}]}, 
  {CMYKColor[0.6833333333333333, 0.5, 0.975, 0.1], \
Polygon[{{0.8471006708862739, -0.18005680599195586, -0.4999999999999998}, 
     {0.8612812260087742, -0.09052430460833719, -0.4999999999999998}, \
{0.8045851146309164, -0.08456530317942978, -0.587785252292473}, 
     {0.7913380320007295, -0.16820409120079746, -0.587785252292473}}]}, \
{CMYKColor[0.6833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.8612812260087742, -0.09052430460833719, -0.4999999999999998}, \
{0.8660254037844387, -2.121080424092027*^-16, -0.4999999999999998}, 
     {0.8090169943749475, -1.9814547033236862*^-16, -0.587785252292473}, \
{0.8045851146309164, -0.08456530317942978, -0.587785252292473}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.8090169943749475, 0., -0.587785252292473}, 
     {0.8045851146309164, 0.0845653031794291, -0.587785252292473}, \
{0.7390738003669031, 0.07767978659246057, -0.6691306063588579}, 
     {0.7431448254773945, 0., -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{0.8045851146309164, 0.0845653031794291, -0.587785252292473}, \
{0.7913380320007296, 0.168204091200797, -0.587785252292473}, 
     {0.7269053280384562, 0.15450849718747375, -0.6691306063588579}, \
{0.7390738003669031, 0.07767978659246057, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.7913380320007296, 0.168204091200797, -0.587785252292473}, 
     {0.7694208842938134, 0.24999999999999997, -0.587785252292473}, \
{0.7067727288213006, 0.22964438035431928, -0.6691306063588579}, 
     {0.7269053280384562, 0.15450849718747375, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.7694208842938134, 0.24999999999999997, -0.587785252292473}, \
{0.7390738003669028, 0.3290568564833396, -0.587785252292473}, 
     {0.6788965796854771, 0.30226423163382676, -0.6691306063588579}, \
{0.7067727288213006, 0.22964438035431928, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.075, 0.1], \
Polygon[{{0.7390738003669028, 0.3290568564833396, -0.587785252292473}, 
     {0.7006292692220368, 0.40450849718747367, -0.587785252292473}, \
{0.6435822975543768, 0.3715724127386972, -0.6691306063588579}, 
     {0.6788965796854771, 0.30226423163382676, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.7006292692220368, 0.40450849718747367, -0.587785252292473}, \
{0.6545084971874737, 0.4755282581475768, -0.587785252292473}, 
     {0.6012167930930166, 0.43680956873307625, -0.6691306063588579}, \
{0.6435822975543768, 0.3715724127386972, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.6545084971874737, 0.4755282581475768, -0.587785252292473}, 
     {0.6012167930930165, 0.5413380320007295, -0.587785252292473}, \
{0.552264231633827, 0.49726094768413676, -0.6691306063588579}, 
     {0.6012167930930166, 0.43680956873307625, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{0.6012167930930165, 0.5413380320007295, -0.587785252292473}, \
{0.5413380320007296, 0.6012167930930162, -0.587785252292473}, 
     {0.49726094768413687, 0.5522642316338269, -0.6691306063588579}, \
{0.552264231633827, 0.49726094768413676, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.5413380320007296, 0.6012167930930162, -0.587785252292473}, 
     {0.4755282581475768, 0.6545084971874737, -0.587785252292473}, \
{0.43680956873307625, 0.6012167930930166, -0.6691306063588579}, 
     {0.49726094768413687, 0.5522642316338269, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.4755282581475768, 0.6545084971874737, -0.587785252292473}, \
{0.40450849718747384, 0.7006292692220367, -0.587785252292473}, 
     {0.3715724127386973, 0.6435822975543767, -0.6691306063588579}, \
{0.43680956873307625, 0.6012167930930166, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.175, 0.1], \
Polygon[{{0.40450849718747384, 0.7006292692220367, -0.587785252292473}, 
     {0.3290568564833398, 0.7390738003669028, -0.587785252292473}, \
{0.30226423163382693, 0.6788965796854771, -0.6691306063588579}, 
     {0.3715724127386973, 0.6435822975543767, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.3290568564833398, 0.7390738003669028, -0.587785252292473}, \
{0.25000000000000006, 0.7694208842938134, -0.587785252292473}, 
     {0.2296443803543193, 0.7067727288213006, -0.6691306063588579}, \
{0.30226423163382693, 0.6788965796854771, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.25000000000000006, 0.7694208842938134, -0.587785252292473}, 
     {0.1682040912007971, 0.7913380320007295, -0.587785252292473}, \
{0.15450849718747384, 0.7269053280384561, -0.6691306063588579}, 
     {0.2296443803543193, 0.7067727288213006, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{0.1682040912007971, 0.7913380320007295, -0.587785252292473}, \
{0.08456530317942927, 0.8045851146309164, -0.587785252292473}, 
     {0.07767978659246073, 0.7390738003669031, -0.6691306063588579}, \
{0.15450849718747384, 0.7269053280384561, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.08456530317942927, 0.8045851146309164, -0.587785252292473}, 
     {4.9536367583092156*^-17, 0.8090169943749475, -0.587785252292473}, \
{4.5502993754491944*^-17, 0.7431448254773945, -0.6691306063588579}, 
     {0.07767978659246073, 0.7390738003669031, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{4.9536367583092156*^-17, 0.8090169943749475, \
-0.587785252292473}, {-0.084565303179429, 0.8045851146309165, \
-0.587785252292473}, 
     {-0.07767978659246047, 0.7390738003669031, -0.6691306063588579}, \
{4.5502993754491944*^-17, 0.7431448254773945, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.275, 0.1], \
Polygon[{{-0.084565303179429, 0.8045851146309165, -0.587785252292473}, 
     {-0.16820409120079685, 0.7913380320007296, -0.587785252292473}, \
{-0.1545084971874736, 0.7269053280384562, -0.6691306063588579}, 
     {-0.07767978659246047, 0.7390738003669031, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.16820409120079685, 0.7913380320007296, -0.587785252292473}, \
{-0.24999999999999994, 0.7694208842938134, -0.587785252292473}, 
     {-0.22964438035431922, 0.7067727288213007, -0.6691306063588579}, \
{-0.1545084971874736, 0.7269053280384562, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.24999999999999994, 0.7694208842938134, -0.587785252292473}, 
     {-0.32905685648333954, 0.739073800366903, -0.587785252292473}, \
{-0.3022642316338267, 0.6788965796854771, -0.6691306063588579}, 
     {-0.22964438035431922, 0.7067727288213007, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{-0.32905685648333954, 0.739073800366903, -0.587785252292473}, \
{-0.40450849718747356, 0.7006292692220368, -0.587785252292473}, 
     {-0.37157241273869707, 0.6435822975543768, -0.6691306063588579}, \
{-0.3022642316338267, 0.6788965796854771, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.40450849718747356, 0.7006292692220368, -0.587785252292473}, 
     {-0.4755282581475767, 0.6545084971874737, -0.587785252292473}, \
{-0.43680956873307614, 0.6012167930930166, -0.6691306063588579}, 
     {-0.37157241273869707, 0.6435822975543768, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.4755282581475767, 0.6545084971874737, -0.587785252292473}, \
{-0.5413380320007293, 0.6012167930930166, -0.587785252292473}, 
     {-0.4972609476841366, 0.5522642316338271, -0.6691306063588579}, \
{-0.43680956873307614, 0.6012167930930166, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.375, 0.1], \
Polygon[{{-0.5413380320007293, 0.6012167930930166, -0.587785252292473}, 
     {-0.6012167930930162, 0.5413380320007297, -0.587785252292473}, \
{-0.5522642316338268, 0.4972609476841369, -0.6691306063588579}, 
     {-0.4972609476841366, 0.5522642316338271, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.6012167930930162, 0.5413380320007297, -0.587785252292473}, \
{-0.6545084971874736, 0.4755282581475769, -0.587785252292473}, 
     {-0.6012167930930165, 0.4368095687330763, -0.6691306063588579}, \
{-0.5522642316338268, 0.4972609476841369, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.6545084971874736, 0.4755282581475769, -0.587785252292473}, 
     {-0.7006292692220366, 0.404508497187474, -0.587785252292473}, \
{-0.6435822975543766, 0.37157241273869746, -0.6691306063588579}, 
     {-0.6012167930930165, 0.4368095687330763, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{-0.7006292692220366, 0.404508497187474, -0.587785252292473}, \
{-0.7390738003669027, 0.3290568564833398, -0.587785252292473}, 
     {-0.678896579685477, 0.302264231633827, -0.6691306063588579}, \
{-0.6435822975543766, 0.37157241273869746, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.7390738003669027, 0.3290568564833398, -0.587785252292473}, 
     {-0.7694208842938134, 0.25000000000000006, -0.587785252292473}, \
{-0.7067727288213006, 0.22964438035431936, -0.6691306063588579}, 
     {-0.678896579685477, 0.302264231633827, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.7694208842938134, 0.25000000000000006, -0.587785252292473}, \
{-0.7913380320007295, 0.16820409120079735, -0.587785252292473}, 
     {-0.7269053280384561, 0.15450849718747406, -0.6691306063588579}, \
{-0.7067727288213006, 0.22964438035431936, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.475, 0.1], \
Polygon[{{-0.7913380320007295, 0.16820409120079735, -0.587785252292473}, 
     {-0.8045851146309164, 0.08456530317942933, -0.587785252292473}, \
{-0.7390738003669031, 0.07767978659246078, -0.6691306063588579}, 
     {-0.7269053280384561, 0.15450849718747406, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.8045851146309164, 0.08456530317942933, -0.587785252292473}, \
{-0.8090169943749475, 9.907273516618431*^-17, -0.587785252292473}, 
     {-0.7431448254773945, 9.100598750898389*^-17, -0.6691306063588579}, \
{-0.7390738003669031, 0.07767978659246078, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.8090169943749475, 9.907273516618431*^-17, -0.587785252292473}, 
     {-0.8045851146309165, -0.08456530317942877, -0.587785252292473}, \
{-0.7390738003669031, -0.07767978659246026, -0.6691306063588579}, 
     {-0.7431448254773945, 9.100598750898389*^-17, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{-0.8045851146309165, -0.08456530317942877, -0.587785252292473}, \
{-0.7913380320007296, -0.1682040912007968, -0.587785252292473}, 
     {-0.7269053280384562, -0.15450849718747356, -0.6691306063588579}, \
{-0.7390738003669031, -0.07767978659246026, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.7913380320007296, -0.1682040912007968, -0.587785252292473}, 
     {-0.7694208842938134, -0.2499999999999999, -0.587785252292473}, \
{-0.7067727288213007, -0.2296443803543192, -0.6691306063588579}, 
     {-0.7269053280384562, -0.15450849718747356, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.7694208842938134, -0.2499999999999999, -0.587785252292473}, \
{-0.739073800366903, -0.3290568564833394, -0.587785252292473}, 
     {-0.6788965796854772, -0.30226423163382654, -0.6691306063588579}, \
{-0.7067727288213007, -0.2296443803543192, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.575, 0.1], \
Polygon[{{-0.739073800366903, -0.3290568564833394, -0.587785252292473}, 
     {-0.7006292692220369, -0.4045084971874735, -0.587785252292473}, \
{-0.6435822975543769, -0.371572412738697, -0.6691306063588579}, 
     {-0.6788965796854772, -0.30226423163382654, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.7006292692220369, -0.4045084971874735, -0.587785252292473}, \
{-0.6545084971874738, -0.4755282581475767, -0.587785252292473}, 
     {-0.6012167930930167, -0.43680956873307614, -0.6691306063588579}, \
{-0.6435822975543769, -0.371572412738697, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.6545084971874738, -0.4755282581475767, -0.587785252292473}, 
     {-0.6012167930930167, -0.5413380320007293, -0.587785252292473}, \
{-0.5522642316338272, -0.4972609476841366, -0.6691306063588579}, 
     {-0.6012167930930167, -0.43680956873307614, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{-0.6012167930930167, -0.5413380320007293, -0.587785252292473}, \
{-0.5413380320007297, -0.6012167930930162, -0.587785252292473}, 
     {-0.49726094768413703, -0.5522642316338268, -0.6691306063588579}, \
{-0.5522642316338272, -0.4972609476841366, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.5413380320007297, -0.6012167930930162, -0.587785252292473}, 
     {-0.4755282581475769, -0.6545084971874736, -0.587785252292473}, \
{-0.4368095687330763, -0.6012167930930165, -0.6691306063588579}, 
     {-0.49726094768413703, -0.5522642316338268, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.4755282581475769, -0.6545084971874736, -0.587785252292473}, \
{-0.40450849718747406, -0.7006292692220366, -0.587785252292473}, 
     {-0.37157241273869757, -0.6435822975543766, -0.6691306063588579}, \
{-0.4368095687330763, -0.6012167930930165, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.675, 0.1], \
Polygon[{{-0.40450849718747406, -0.7006292692220366, -0.587785252292473}, 
     {-0.3290568564833402, -0.7390738003669025, -0.587785252292473}, \
{-0.3022642316338273, -0.6788965796854768, -0.6691306063588579}, 
     {-0.37157241273869757, -0.6435822975543766, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.3290568564833402, -0.7390738003669025, -0.587785252292473}, \
{-0.2500000000000001, -0.7694208842938134, -0.587785252292473}, 
     {-0.2296443803543194, -0.7067727288213006, -0.6691306063588579}, \
{-0.3022642316338273, -0.6788965796854768, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.2500000000000001, -0.7694208842938134, -0.587785252292473}, 
     {-0.16820409120079738, -0.7913380320007295, -0.587785252292473}, \
{-0.1545084971874741, -0.7269053280384561, -0.6691306063588579}, 
     {-0.2296443803543194, -0.7067727288213006, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{-0.16820409120079738, -0.7913380320007295, -0.587785252292473}, \
{-0.08456530317942973, -0.8045851146309164, -0.587785252292473}, 
     {-0.07767978659246115, -0.7390738003669031, -0.6691306063588579}, \
{-0.1545084971874741, -0.7269053280384561, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.08456530317942973, -0.8045851146309164, -0.587785252292473}, 
     {-1.4860910274927647*^-16, -0.8090169943749475, -0.587785252292473}, \
{-1.3650898126347585*^-16, -0.7431448254773945, -0.6691306063588579}, 
     {-0.07767978659246115, -0.7390738003669031, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.4860910274927647*^-16, -0.8090169943749475, \
-0.587785252292473}, {0.08456530317942872, -0.8045851146309165, \
-0.587785252292473}, 
     {0.07767978659246022, -0.7390738003669031, -0.6691306063588579}, \
{-1.3650898126347585*^-16, -0.7431448254773945, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.775, 0.1], \
Polygon[{{0.08456530317942872, -0.8045851146309165, -0.587785252292473}, 
     {0.1682040912007964, -0.7913380320007297, -0.587785252292473}, \
{0.1545084971874732, -0.7269053280384562, -0.6691306063588579}, 
     {0.07767978659246022, -0.7390738003669031, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.1682040912007964, -0.7913380320007297, -0.587785252292473}, \
{0.24999999999999986, -0.7694208842938134, -0.587785252292473}, 
     {0.22964438035431914, -0.7067727288213007, -0.6691306063588579}, \
{0.1545084971874732, -0.7269053280384562, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.24999999999999986, -0.7694208842938134, -0.587785252292473}, 
     {0.3290568564833393, -0.739073800366903, -0.587785252292473}, \
{0.3022642316338265, -0.6788965796854772, -0.6691306063588579}, 
     {0.22964438035431914, -0.7067727288213007, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{0.3290568564833393, -0.739073800366903, -0.587785252292473}, \
{0.40450849718747317, -0.7006292692220372, -0.587785252292473}, 
     {0.37157241273869673, -0.643582297554377, -0.6691306063588579}, \
{0.3022642316338265, -0.6788965796854772, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.40450849718747317, -0.7006292692220372, -0.587785252292473}, 
     {0.47552825814757665, -0.6545084971874738, -0.587785252292473}, \
{0.4368095687330761, -0.6012167930930167, -0.6691306063588579}, 
     {0.37157241273869673, -0.643582297554377, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.47552825814757665, -0.6545084971874738, -0.587785252292473}, \
{0.5413380320007293, -0.6012167930930167, -0.587785252292473}, 
     {0.49726094768413653, -0.5522642316338272, -0.6691306063588579}, \
{0.4368095687330761, -0.6012167930930167, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.875, 0.1], \
Polygon[{{0.5413380320007293, -0.6012167930930167, -0.587785252292473}, 
     {0.6012167930930159, -0.54133803200073, -0.587785252292473}, \
{0.5522642316338265, -0.49726094768413726, -0.6691306063588579}, 
     {0.49726094768413653, -0.5522642316338272, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.6012167930930159, -0.54133803200073, -0.587785252292473}, \
{0.6545084971874736, -0.475528258147577, -0.587785252292473}, 
     {0.6012167930930165, -0.4368095687330764, -0.6691306063588579}, \
{0.5522642316338265, -0.49726094768413726, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.6545084971874736, -0.475528258147577, -0.587785252292473}, 
     {0.7006292692220366, -0.40450849718747406, -0.587785252292473}, \
{0.6435822975543766, -0.37157241273869757, -0.6691306063588579}, 
     {0.6012167930930165, -0.4368095687330764, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.7006292692220366, -0.40450849718747406, -0.587785252292473}, \
{0.7390738003669025, -0.32905685648334027, -0.587785252292473}, 
     {0.6788965796854768, -0.3022642316338274, -0.6691306063588579}, \
{0.6435822975543766, -0.37157241273869757, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.7390738003669025, -0.32905685648334027, -0.587785252292473}, 
     {0.7694208842938134, -0.25000000000000017, -0.587785252292473}, \
{0.7067727288213006, -0.22964438035431944, -0.6691306063588579}, 
     {0.6788965796854768, -0.3022642316338274, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.7694208842938134, -0.25000000000000017, -0.587785252292473}, \
{0.7913380320007295, -0.16820409120079746, -0.587785252292473}, 
     {0.7269053280384561, -0.15450849718747417, -0.6691306063588579}, \
{0.7067727288213006, -0.22964438035431944, -0.6691306063588579}}]}, 
  {CMYKColor[0.7166666666666667, 0.5, 0.975, 0.1], \
Polygon[{{0.7913380320007295, -0.16820409120079746, -0.587785252292473}, 
     {0.8045851146309164, -0.08456530317942978, -0.587785252292473}, \
{0.7390738003669031, -0.07767978659246119, -0.6691306063588579}, 
     {0.7269053280384561, -0.15450849718747417, -0.6691306063588579}}]}, \
{CMYKColor[0.7166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.8045851146309164, -0.08456530317942978, -0.587785252292473}, \
{0.8090169943749475, -1.9814547033236862*^-16, -0.587785252292473}, 
     {0.7431448254773945, -1.8201197501796777*^-16, -0.6691306063588579}, \
{0.7390738003669031, -0.07767978659246119, -0.6691306063588579}}]}, 
  {CMYKColor[0.75, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.7431448254773945, 0., -0.6691306063588579}, 
     {0.7390738003669031, 0.07767978659246057, -0.6691306063588579}, \
{0.6654650388849338, 0.0699431940080446, -0.743144825477394}, 
     {0.6691306063588583, 0., -0.743144825477394}}]}, {CMYKColor[0.75, 0.5, \
0.025, 0.1], 
   Polygon[{{0.7390738003669031, 0.07767978659246057, -0.6691306063588579}, \
{0.7269053280384562, 0.15450849718747375, -0.6691306063588579}, 
     {0.6545084971874738, 0.13912007574598279, -0.743144825477394}, \
{0.6654650388849338, 0.0699431940080446, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.7269053280384562, 0.15450849718747375, -0.6691306063588579}, 
     {0.7067727288213006, 0.22964438035431928, -0.6691306063588579}, \
{0.6363810234301195, 0.20677272882130046, -0.743144825477394}, 
     {0.6545084971874738, 0.13912007574598279, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.7067727288213006, 0.22964438035431928, -0.6691306063588579}, \
{0.6788965796854771, 0.30226423163382676, -0.6691306063588579}, 
     {0.6112812260087742, 0.2721599366096767, -0.743144825477394}, \
{0.6363810234301195, 0.20677272882130046, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.075, 0.1], Polygon[{{0.6788965796854771, \
0.30226423163382676, -0.6691306063588579}, 
     {0.6435822975543768, 0.3715724127386972, -0.6691306063588579}, \
{0.5794841035564566, 0.3345653031794291, -0.743144825477394}, 
     {0.6112812260087742, 0.2721599366096767, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.6435822975543768, 0.3715724127386972, -0.6691306063588579}, \
{0.6012167930930166, 0.43680956873307625, -0.6691306063588579}, 
     {0.5413380320007297, 0.39330510227525706, -0.743144825477394}, \
{0.5794841035564566, 0.3345653031794291, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.6012167930930166, 0.43680956873307625, -0.6691306063588579}, 
     {0.552264231633827, 0.49726094768413676, -0.6691306063588579}, \
{0.49726094768413687, 0.4477357683661733, -0.743144825477394}, 
     {0.5413380320007297, 0.39330510227525706, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.125, 0.1], 
   Polygon[{{0.552264231633827, 0.49726094768413676, -0.6691306063588579}, \
{0.49726094768413687, 0.5522642316338269, -0.6691306063588579}, 
     {0.44773576836617335, 0.4972609476841367, -0.743144825477394}, \
{0.49726094768413687, 0.4477357683661733, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.49726094768413687, 0.5522642316338269, -0.6691306063588579}, 
     {0.43680956873307625, 0.6012167930930166, -0.6691306063588579}, \
{0.39330510227525706, 0.5413380320007297, -0.743144825477394}, 
     {0.44773576836617335, 0.4972609476841367, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.43680956873307625, 0.6012167930930166, -0.6691306063588579}, \
{0.3715724127386973, 0.6435822975543767, -0.6691306063588579}, 
     {0.33456530317942923, 0.5794841035564565, -0.743144825477394}, \
{0.39330510227525706, 0.5413380320007297, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.175, 0.1], Polygon[{{0.3715724127386973, \
0.6435822975543767, -0.6691306063588579}, 
     {0.30226423163382693, 0.6788965796854771, -0.6691306063588579}, \
{0.27215993660967686, 0.6112812260087742, -0.743144825477394}, 
     {0.33456530317942923, 0.5794841035564565, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.30226423163382693, 0.6788965796854771, -0.6691306063588579}, \
{0.2296443803543193, 0.7067727288213006, -0.6691306063588579}, 
     {0.20677272882130052, 0.6363810234301195, -0.743144825477394}, \
{0.27215993660967686, 0.6112812260087742, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.2296443803543193, 0.7067727288213006, -0.6691306063588579}, 
     {0.15450849718747384, 0.7269053280384561, -0.6691306063588579}, \
{0.13912007574598287, 0.6545084971874738, -0.743144825477394}, 
     {0.20677272882130052, 0.6363810234301195, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.225, 0.1], 
   Polygon[{{0.15450849718747384, 0.7269053280384561, -0.6691306063588579}, \
{0.07767978659246073, 0.7390738003669031, -0.6691306063588579}, 
     {0.06994319400804476, 0.6654650388849338, -0.743144825477394}, \
{0.13912007574598287, 0.6545084971874738, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.07767978659246073, 0.7390738003669031, -0.6691306063588579}, 
     {4.5502993754491944*^-17, 0.7431448254773945, -0.6691306063588579}, \
{4.0971079604203893*^-17, 0.6691306063588583, -0.743144825477394}, 
     {0.06994319400804476, 0.6654650388849338, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{4.5502993754491944*^-17, 0.7431448254773945, \
-0.6691306063588579}, {-0.07767978659246047, 0.7390738003669031, \
-0.6691306063588579}, 
     {-0.06994319400804452, 0.6654650388849339, -0.743144825477394}, \
{4.0971079604203893*^-17, 0.6691306063588583, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.275, 0.1], Polygon[{{-0.07767978659246047, \
0.7390738003669031, -0.6691306063588579}, 
     {-0.1545084971874736, 0.7269053280384562, -0.6691306063588579}, \
{-0.13912007574598265, 0.6545084971874738, -0.743144825477394}, 
     {-0.06994319400804452, 0.6654650388849339, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.1545084971874736, 0.7269053280384562, -0.6691306063588579}, \
{-0.22964438035431922, 0.7067727288213007, -0.6691306063588579}, 
     {-0.20677272882130043, 0.6363810234301196, -0.743144825477394}, \
{-0.13912007574598265, 0.6545084971874738, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.22964438035431922, 0.7067727288213007, -0.6691306063588579}, 
     {-0.3022642316338267, 0.6788965796854771, -0.6691306063588579}, \
{-0.27215993660967663, 0.6112812260087743, -0.743144825477394}, 
     {-0.20677272882130043, 0.6363810234301196, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.325, 0.1], 
   Polygon[{{-0.3022642316338267, 0.6788965796854771, -0.6691306063588579}, \
{-0.37157241273869707, 0.6435822975543768, -0.6691306063588579}, 
     {-0.334565303179429, 0.5794841035564566, -0.743144825477394}, \
{-0.27215993660967663, 0.6112812260087743, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.37157241273869707, 0.6435822975543768, -0.6691306063588579}, 
     {-0.43680956873307614, 0.6012167930930166, -0.6691306063588579}, \
{-0.393305102275257, 0.5413380320007297, -0.743144825477394}, 
     {-0.334565303179429, 0.5794841035564566, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.43680956873307614, 0.6012167930930166, -0.6691306063588579}, \
{-0.4972609476841366, 0.5522642316338271, -0.6691306063588579}, 
     {-0.4477357683661731, 0.4972609476841369, -0.743144825477394}, \
{-0.393305102275257, 0.5413380320007297, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.375, 0.1], Polygon[{{-0.4972609476841366, \
0.5522642316338271, -0.6691306063588579}, 
     {-0.5522642316338268, 0.4972609476841369, -0.6691306063588579}, \
{-0.49726094768413664, 0.44773576836617346, -0.743144825477394}, 
     {-0.4477357683661731, 0.4972609476841369, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.5522642316338268, 0.4972609476841369, -0.6691306063588579}, \
{-0.6012167930930165, 0.4368095687330763, -0.6691306063588579}, 
     {-0.5413380320007296, 0.39330510227525717, -0.743144825477394}, \
{-0.49726094768413664, 0.44773576836617346, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.6012167930930165, 0.4368095687330763, -0.6691306063588579}, 
     {-0.6435822975543766, 0.37157241273869746, -0.6691306063588579}, \
{-0.5794841035564564, 0.3345653031794294, -0.743144825477394}, 
     {-0.5413380320007296, 0.39330510227525717, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.425, 0.1], 
   Polygon[{{-0.6435822975543766, 0.37157241273869746, -0.6691306063588579}, \
{-0.678896579685477, 0.302264231633827, -0.6691306063588579}, 
     {-0.6112812260087742, 0.2721599366096769, -0.743144825477394}, \
{-0.5794841035564564, 0.3345653031794294, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.678896579685477, 0.302264231633827, -0.6691306063588579}, 
     {-0.7067727288213006, 0.22964438035431936, -0.6691306063588579}, \
{-0.6363810234301195, 0.20677272882130054, -0.743144825477394}, 
     {-0.6112812260087742, 0.2721599366096769, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.7067727288213006, 0.22964438035431936, -0.6691306063588579}, \
{-0.7269053280384561, 0.15450849718747406, -0.6691306063588579}, 
     {-0.6545084971874738, 0.13912007574598306, -0.743144825477394}, \
{-0.6363810234301195, 0.20677272882130054, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.475, 0.1], Polygon[{{-0.7269053280384561, \
0.15450849718747406, -0.6691306063588579}, 
     {-0.7390738003669031, 0.07767978659246078, -0.6691306063588579}, \
{-0.6654650388849338, 0.0699431940080448, -0.743144825477394}, 
     {-0.6545084971874738, 0.13912007574598306, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.7390738003669031, 0.07767978659246078, -0.6691306063588579}, \
{-0.7431448254773945, 9.100598750898389*^-17, -0.6691306063588579}, 
     {-0.6691306063588583, 8.194215920840779*^-17, -0.743144825477394}, \
{-0.6654650388849338, 0.0699431940080448, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.7431448254773945, 9.100598750898389*^-17, -0.6691306063588579}, 
     {-0.7390738003669031, -0.07767978659246026, -0.6691306063588579}, \
{-0.6654650388849339, -0.06994319400804434, -0.743144825477394}, 
     {-0.6691306063588583, 8.194215920840779*^-17, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.525, 0.1], 
   Polygon[{{-0.7390738003669031, -0.07767978659246026, -0.6691306063588579}, \
{-0.7269053280384562, -0.15450849718747356, -0.6691306063588579}, 
     {-0.6545084971874738, -0.1391200757459826, -0.743144825477394}, \
{-0.6654650388849339, -0.06994319400804434, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.7269053280384562, -0.15450849718747356, -0.6691306063588579}, 
     {-0.7067727288213007, -0.2296443803543192, -0.6691306063588579}, \
{-0.6363810234301196, -0.2067727288213004, -0.743144825477394}, 
     {-0.6545084971874738, -0.1391200757459826, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.7067727288213007, -0.2296443803543192, -0.6691306063588579}, \
{-0.6788965796854772, -0.30226423163382654, -0.6691306063588579}, 
     {-0.6112812260087744, -0.27215993660967647, -0.743144825477394}, \
{-0.6363810234301196, -0.2067727288213004, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.575, 0.1], Polygon[{{-0.6788965796854772, \
-0.30226423163382654, -0.6691306063588579}, 
     {-0.6435822975543769, -0.371572412738697, -0.6691306063588579}, \
{-0.5794841035564566, -0.334565303179429, -0.743144825477394}, 
     {-0.6112812260087744, -0.27215993660967647, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.6435822975543769, -0.371572412738697, -0.6691306063588579}, \
{-0.6012167930930167, -0.43680956873307614, -0.6691306063588579}, 
     {-0.5413380320007297, -0.393305102275257, -0.743144825477394}, \
{-0.5794841035564566, -0.334565303179429, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.6012167930930167, -0.43680956873307614, -0.6691306063588579}, 
     {-0.5522642316338272, -0.4972609476841366, -0.6691306063588579}, \
{-0.497260947684137, -0.4477357683661731, -0.743144825477394}, 
     {-0.5413380320007297, -0.393305102275257, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.625, 0.1], 
   Polygon[{{-0.5522642316338272, -0.4972609476841366, -0.6691306063588579}, \
{-0.49726094768413703, -0.5522642316338268, -0.6691306063588579}, 
     {-0.4477357683661735, -0.49726094768413664, -0.743144825477394}, \
{-0.497260947684137, -0.4477357683661731, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.49726094768413703, -0.5522642316338268, -0.6691306063588579}, 
     {-0.4368095687330763, -0.6012167930930165, -0.6691306063588579}, \
{-0.39330510227525717, -0.5413380320007296, -0.743144825477394}, 
     {-0.4477357683661735, -0.49726094768413664, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.4368095687330763, -0.6012167930930165, -0.6691306063588579}, \
{-0.37157241273869757, -0.6435822975543766, -0.6691306063588579}, 
     {-0.33456530317942945, -0.5794841035564564, -0.743144825477394}, \
{-0.39330510227525717, -0.5413380320007296, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.675, 0.1], Polygon[{{-0.37157241273869757, \
-0.6435822975543766, -0.6691306063588579}, 
     {-0.3022642316338273, -0.6788965796854768, -0.6691306063588579}, \
{-0.2721599366096772, -0.611281226008774, -0.743144825477394}, 
     {-0.33456530317942945, -0.5794841035564564, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.3022642316338273, -0.6788965796854768, -0.6691306063588579}, \
{-0.2296443803543194, -0.7067727288213006, -0.6691306063588579}, 
     {-0.20677272882130057, -0.6363810234301195, -0.743144825477394}, \
{-0.2721599366096772, -0.611281226008774, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.2296443803543194, -0.7067727288213006, -0.6691306063588579}, 
     {-0.1545084971874741, -0.7269053280384561, -0.6691306063588579}, \
{-0.1391200757459831, -0.6545084971874738, -0.743144825477394}, 
     {-0.20677272882130057, -0.6363810234301195, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.725, 0.1], 
   Polygon[{{-0.1545084971874741, -0.7269053280384561, -0.6691306063588579}, \
{-0.07767978659246115, -0.7390738003669031, -0.6691306063588579}, 
     {-0.06994319400804513, -0.6654650388849338, -0.743144825477394}, \
{-0.1391200757459831, -0.6545084971874738, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.07767978659246115, -0.7390738003669031, -0.6691306063588579}, 
     {-1.3650898126347585*^-16, -0.7431448254773945, -0.6691306063588579}, \
{-1.2291323881261169*^-16, -0.6691306063588583, -0.743144825477394}, 
     {-0.06994319400804513, -0.6654650388849338, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.3650898126347585*^-16, -0.7431448254773945, \
-0.6691306063588579}, {0.07767978659246022, -0.7390738003669031, \
-0.6691306063588579}, 
     {0.06994319400804429, -0.6654650388849339, -0.743144825477394}, \
{-1.2291323881261169*^-16, -0.6691306063588583, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.775, 0.1], Polygon[{{0.07767978659246022, \
-0.7390738003669031, -0.6691306063588579}, 
     {0.1545084971874732, -0.7269053280384562, -0.6691306063588579}, \
{0.13912007574598226, -0.654508497187474, -0.743144825477394}, 
     {0.06994319400804429, -0.6654650388849339, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.1545084971874732, -0.7269053280384562, -0.6691306063588579}, \
{0.22964438035431914, -0.7067727288213007, -0.6691306063588579}, 
     {0.20677272882130035, -0.6363810234301196, -0.743144825477394}, \
{0.13912007574598226, -0.654508497187474, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.22964438035431914, -0.7067727288213007, -0.6691306063588579}, 
     {0.3022642316338265, -0.6788965796854772, -0.6691306063588579}, \
{0.27215993660967647, -0.6112812260087744, -0.743144825477394}, 
     {0.20677272882130035, -0.6363810234301196, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.825, 0.1], 
   Polygon[{{0.3022642316338265, -0.6788965796854772, -0.6691306063588579}, \
{0.37157241273869673, -0.643582297554377, -0.6691306063588579}, 
     {0.33456530317942873, -0.5794841035564569, -0.743144825477394}, \
{0.27215993660967647, -0.6112812260087744, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.37157241273869673, -0.643582297554377, -0.6691306063588579}, 
     {0.4368095687330761, -0.6012167930930167, -0.6691306063588579}, \
{0.39330510227525695, -0.5413380320007297, -0.743144825477394}, 
     {0.33456530317942873, -0.5794841035564569, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.4368095687330761, -0.6012167930930167, -0.6691306063588579}, \
{0.49726094768413653, -0.5522642316338272, -0.6691306063588579}, 
     {0.44773576836617307, -0.497260947684137, -0.743144825477394}, \
{0.39330510227525695, -0.5413380320007297, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.875, 0.1], Polygon[{{0.49726094768413653, \
-0.5522642316338272, -0.6691306063588579}, 
     {0.5522642316338265, -0.49726094768413726, -0.6691306063588579}, \
{0.4972609476841364, -0.44773576836617374, -0.743144825477394}, 
     {0.44773576836617307, -0.497260947684137, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.5522642316338265, -0.49726094768413726, -0.6691306063588579}, \
{0.6012167930930165, -0.4368095687330764, -0.6691306063588579}, 
     {0.5413380320007296, -0.3933051022752572, -0.743144825477394}, \
{0.4972609476841364, -0.44773576836617374, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.6012167930930165, -0.4368095687330764, -0.6691306063588579}, 
     {0.6435822975543766, -0.37157241273869757, -0.6691306063588579}, \
{0.5794841035564564, -0.33456530317942945, -0.743144825477394}, 
     {0.5413380320007296, -0.3933051022752572, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.6435822975543766, -0.37157241273869757, -0.6691306063588579}, \
{0.6788965796854768, -0.3022642316338274, -0.6691306063588579}, 
     {0.611281226008774, -0.27215993660967724, -0.743144825477394}, \
{0.5794841035564564, -0.33456530317942945, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.6788965796854768, -0.3022642316338274, -0.6691306063588579}, 
     {0.7067727288213006, -0.22964438035431944, -0.6691306063588579}, \
{0.6363810234301195, -0.20677272882130063, -0.743144825477394}, 
     {0.611281226008774, -0.27215993660967724, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.7067727288213006, -0.22964438035431944, -0.6691306063588579}, \
{0.7269053280384561, -0.15450849718747417, -0.6691306063588579}, 
     {0.6545084971874738, -0.13912007574598315, -0.743144825477394}, \
{0.6363810234301195, -0.20677272882130063, -0.743144825477394}}]}, 
  {CMYKColor[0.75, 0.5, 0.975, 0.1], Polygon[{{0.7269053280384561, \
-0.15450849718747417, -0.6691306063588579}, 
     {0.7390738003669031, -0.07767978659246119, -0.6691306063588579}, \
{0.6654650388849338, -0.06994319400804518, -0.743144825477394}, 
     {0.6545084971874738, -0.13912007574598315, -0.743144825477394}}]}, \
{CMYKColor[0.75, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.7390738003669031, -0.07767978659246119, -0.6691306063588579}, \
{0.7431448254773945, -1.8201197501796777*^-16, -0.6691306063588579}, 
     {0.6691306063588583, -1.6388431841681557*^-16, -0.743144825477394}, \
{0.6654650388849338, -0.06994319400804518, -0.743144825477394}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.6691306063588583, 0., -0.743144825477394}, 
     {0.6654650388849338, 0.0699431940080446, -0.743144825477394}, \
{0.5845653031794292, 0.06144028915352221, -0.8090169943749473}, 
     {0.5877852522924732, 0., -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{0.6654650388849338, 0.0699431940080446, -0.743144825477394}, \
{0.6545084971874738, 0.13912007574598279, -0.743144825477394}, 
     {0.5749407342765974, 0.12220742564187136, -0.8090169943749473}, \
{0.5845653031794292, 0.06144028915352221, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.6545084971874738, 0.13912007574598279, -0.743144825477394}, 
     {0.6363810234301195, 0.20677272882130046, -0.743144825477394}, \
{0.5590169943749476, 0.18163563200134025, -0.8090169943749473}, 
     {0.5749407342765974, 0.12220742564187136, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.6363810234301195, 0.20677272882130046, -0.743144825477394}, \
{0.6112812260087742, 0.2721599366096767, -0.743144825477394}, 
     {0.5369685473010991, 0.23907380036690284, -0.8090169943749473}, \
{0.5590169943749476, 0.18163563200134025, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.075, 0.1], \
Polygon[{{0.6112812260087742, 0.2721599366096767, -0.743144825477394}, 
     {0.5794841035564566, 0.3345653031794291, -0.743144825477394}, \
{0.5090369604551274, 0.29389262614623657, -0.8090169943749473}, 
     {0.5369685473010991, 0.23907380036690284, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.5794841035564566, 0.3345653031794291, -0.743144825477394}, \
{0.5413380320007297, 0.39330510227525706, -0.743144825477394}, 
     {0.4755282581475769, 0.3454915028125264, -0.8090169943749473}, \
{0.5090369604551274, 0.29389262614623657, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.5413380320007297, 0.39330510227525706, -0.743144825477394}, 
     {0.49726094768413687, 0.4477357683661733, -0.743144825477394}, \
{0.43680956873307625, 0.393305102275257, -0.8090169943749473}, 
     {0.4755282581475769, 0.3454915028125264, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{0.49726094768413687, 0.4477357683661733, -0.743144825477394}, \
{0.44773576836617335, 0.4972609476841367, -0.743144825477394}, 
     {0.3933051022752571, 0.43680956873307614, -0.8090169943749473}, \
{0.43680956873307625, 0.393305102275257, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.44773576836617335, 0.4972609476841367, -0.743144825477394}, 
     {0.39330510227525706, 0.5413380320007297, -0.743144825477394}, \
{0.3454915028125264, 0.4755282581475769, -0.8090169943749473}, 
     {0.3933051022752571, 0.43680956873307614, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.39330510227525706, 0.5413380320007297, -0.743144825477394}, \
{0.33456530317942923, 0.5794841035564565, -0.743144825477394}, 
     {0.2938926261462367, 0.5090369604551273, -0.8090169943749473}, \
{0.3454915028125264, 0.4755282581475769, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.175, 0.1], \
Polygon[{{0.33456530317942923, 0.5794841035564565, -0.743144825477394}, 
     {0.27215993660967686, 0.6112812260087742, -0.743144825477394}, \
{0.23907380036690296, 0.5369685473010991, -0.8090169943749473}, 
     {0.2938926261462367, 0.5090369604551273, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.27215993660967686, 0.6112812260087742, -0.743144825477394}, \
{0.20677272882130052, 0.6363810234301195, -0.743144825477394}, 
     {0.18163563200134028, 0.5590169943749476, -0.8090169943749473}, \
{0.23907380036690296, 0.5369685473010991, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.20677272882130052, 0.6363810234301195, -0.743144825477394}, 
     {0.13912007574598287, 0.6545084971874738, -0.743144825477394}, \
{0.12220742564187144, 0.5749407342765973, -0.8090169943749473}, 
     {0.18163563200134028, 0.5590169943749476, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{0.13912007574598287, 0.6545084971874738, -0.743144825477394}, \
{0.06994319400804476, 0.6654650388849338, -0.743144825477394}, 
     {0.06144028915352234, 0.5845653031794292, -0.8090169943749473}, \
{0.12220742564187144, 0.5749407342765973, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.06994319400804476, 0.6654650388849338, -0.743144825477394}, 
     {4.0971079604203893*^-17, 0.6691306063588583, -0.743144825477394}, \
{3.599027773202259*^-17, 0.5877852522924732, -0.8090169943749473}, 
     {0.06144028915352234, 0.5845653031794292, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{4.0971079604203893*^-17, 0.6691306063588583, \
-0.743144825477394}, {-0.06994319400804452, 0.6654650388849339, \
-0.743144825477394}, 
     {-0.061440289153522135, 0.5845653031794292, -0.8090169943749473}, \
{3.599027773202259*^-17, 0.5877852522924732, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.275, 0.1], \
Polygon[{{-0.06994319400804452, 0.6654650388849339, -0.743144825477394}, 
     {-0.13912007574598265, 0.6545084971874738, -0.743144825477394}, \
{-0.12220742564187125, 0.5749407342765974, -0.8090169943749473}, 
     {-0.061440289153522135, 0.5845653031794292, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.13912007574598265, 0.6545084971874738, -0.743144825477394}, \
{-0.20677272882130043, 0.6363810234301196, -0.743144825477394}, 
     {-0.1816356320013402, 0.5590169943749476, -0.8090169943749473}, \
{-0.12220742564187125, 0.5749407342765974, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.20677272882130043, 0.6363810234301196, -0.743144825477394}, 
     {-0.27215993660967663, 0.6112812260087743, -0.743144825477394}, \
{-0.23907380036690276, 0.5369685473010991, -0.8090169943749473}, 
     {-0.1816356320013402, 0.5590169943749476, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{-0.27215993660967663, 0.6112812260087743, -0.743144825477394}, \
{-0.334565303179429, 0.5794841035564566, -0.743144825477394}, 
     {-0.2938926261462365, 0.5090369604551274, -0.8090169943749473}, \
{-0.23907380036690276, 0.5369685473010991, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.334565303179429, 0.5794841035564566, -0.743144825477394}, 
     {-0.393305102275257, 0.5413380320007297, -0.743144825477394}, \
{-0.3454915028125263, 0.4755282581475769, -0.8090169943749473}, 
     {-0.2938926261462365, 0.5090369604551274, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.393305102275257, 0.5413380320007297, -0.743144825477394}, \
{-0.4477357683661731, 0.4972609476841369, -0.743144825477394}, 
     {-0.3933051022752569, 0.4368095687330763, -0.8090169943749473}, \
{-0.3454915028125263, 0.4755282581475769, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.375, 0.1], \
Polygon[{{-0.4477357683661731, 0.4972609476841369, -0.743144825477394}, 
     {-0.49726094768413664, 0.44773576836617346, -0.743144825477394}, \
{-0.436809568733076, 0.39330510227525717, -0.8090169943749473}, 
     {-0.3933051022752569, 0.4368095687330763, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.49726094768413664, 0.44773576836617346, -0.743144825477394}, \
{-0.5413380320007296, 0.39330510227525717, -0.743144825477394}, 
     {-0.4755282581475768, 0.34549150281252644, -0.8090169943749473}, \
{-0.436809568733076, 0.39330510227525717, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.5413380320007296, 0.39330510227525717, -0.743144825477394}, 
     {-0.5794841035564564, 0.3345653031794294, -0.743144825477394}, \
{-0.5090369604551271, 0.29389262614623685, -0.8090169943749473}, 
     {-0.4755282581475768, 0.34549150281252644, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{-0.5794841035564564, 0.3345653031794294, -0.743144825477394}, \
{-0.6112812260087742, 0.2721599366096769, -0.743144825477394}, 
     {-0.536968547301099, 0.239073800366903, -0.8090169943749473}, \
{-0.5090369604551271, 0.29389262614623685, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.6112812260087742, 0.2721599366096769, -0.743144825477394}, 
     {-0.6363810234301195, 0.20677272882130054, -0.743144825477394}, \
{-0.5590169943749476, 0.1816356320013403, -0.8090169943749473}, 
     {-0.536968547301099, 0.239073800366903, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.6363810234301195, 0.20677272882130054, -0.743144825477394}, \
{-0.6545084971874738, 0.13912007574598306, -0.743144825477394}, 
     {-0.5749407342765973, 0.12220742564187159, -0.8090169943749473}, \
{-0.5590169943749476, 0.1816356320013403, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.475, 0.1], \
Polygon[{{-0.6545084971874738, 0.13912007574598306, -0.743144825477394}, 
     {-0.6654650388849338, 0.0699431940080448, -0.743144825477394}, \
{-0.5845653031794292, 0.06144028915352237, -0.8090169943749473}, 
     {-0.5749407342765973, 0.12220742564187159, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.6654650388849338, 0.0699431940080448, -0.743144825477394}, \
{-0.6691306063588583, 8.194215920840779*^-17, -0.743144825477394}, 
     {-0.5877852522924732, 7.198055546404518*^-17, -0.8090169943749473}, \
{-0.5845653031794292, 0.06144028915352237, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.6691306063588583, 8.194215920840779*^-17, -0.743144825477394}, 
     {-0.6654650388849339, -0.06994319400804434, -0.743144825477394}, \
{-0.5845653031794292, -0.061440289153521975, -0.8090169943749473}, 
     {-0.5877852522924732, 7.198055546404518*^-17, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{-0.6654650388849339, -0.06994319400804434, -0.743144825477394}, \
{-0.6545084971874738, -0.1391200757459826, -0.743144825477394}, 
     {-0.5749407342765974, -0.1222074256418712, -0.8090169943749473}, \
{-0.5845653031794292, -0.061440289153521975, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.6545084971874738, -0.1391200757459826, -0.743144825477394}, 
     {-0.6363810234301196, -0.2067727288213004, -0.743144825477394}, \
{-0.5590169943749476, -0.18163563200134017, -0.8090169943749473}, 
     {-0.5749407342765974, -0.1222074256418712, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.6363810234301196, -0.2067727288213004, -0.743144825477394}, \
{-0.6112812260087744, -0.27215993660967647, -0.743144825477394}, 
     {-0.5369685473010992, -0.23907380036690265, -0.8090169943749473}, \
{-0.5590169943749476, -0.18163563200134017, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.575, 0.1], \
Polygon[{{-0.6112812260087744, -0.27215993660967647, -0.743144825477394}, 
     {-0.5794841035564566, -0.334565303179429, -0.743144825477394}, \
{-0.5090369604551274, -0.29389262614623646, -0.8090169943749473}, 
     {-0.5369685473010992, -0.23907380036690265, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.5794841035564566, -0.334565303179429, -0.743144825477394}, \
{-0.5413380320007297, -0.393305102275257, -0.743144825477394}, 
     {-0.475528258147577, -0.3454915028125263, -0.8090169943749473}, \
{-0.5090369604551274, -0.29389262614623646, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.5413380320007297, -0.393305102275257, -0.743144825477394}, 
     {-0.497260947684137, -0.4477357683661731, -0.743144825477394}, \
{-0.43680956873307636, -0.3933051022752569, -0.8090169943749473}, 
     {-0.475528258147577, -0.3454915028125263, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{-0.497260947684137, -0.4477357683661731, -0.743144825477394}, \
{-0.4477357683661735, -0.49726094768413664, -0.743144825477394}, 
     {-0.3933051022752572, -0.436809568733076, -0.8090169943749473}, \
{-0.43680956873307636, -0.3933051022752569, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.4477357683661735, -0.49726094768413664, -0.743144825477394}, 
     {-0.39330510227525717, -0.5413380320007296, -0.743144825477394}, \
{-0.34549150281252644, -0.4755282581475768, -0.8090169943749473}, 
     {-0.3933051022752572, -0.436809568733076, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.39330510227525717, -0.5413380320007296, -0.743144825477394}, \
{-0.33456530317942945, -0.5794841035564564, -0.743144825477394}, 
     {-0.2938926261462369, -0.5090369604551271, -0.8090169943749473}, \
{-0.34549150281252644, -0.4755282581475768, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.675, 0.1], \
Polygon[{{-0.33456530317942945, -0.5794841035564564, -0.743144825477394}, 
     {-0.2721599366096772, -0.611281226008774, -0.743144825477394}, \
{-0.23907380036690326, -0.5369685473010989, -0.8090169943749473}, 
     {-0.2938926261462369, -0.5090369604551271, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.2721599366096772, -0.611281226008774, -0.743144825477394}, \
{-0.20677272882130057, -0.6363810234301195, -0.743144825477394}, 
     {-0.18163563200134034, -0.5590169943749476, -0.8090169943749473}, \
{-0.23907380036690326, -0.5369685473010989, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.20677272882130057, -0.6363810234301195, -0.743144825477394}, 
     {-0.1391200757459831, -0.6545084971874738, -0.743144825477394}, \
{-0.12220742564187163, -0.5749407342765973, -0.8090169943749473}, 
     {-0.18163563200134034, -0.5590169943749476, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{-0.1391200757459831, -0.6545084971874738, -0.743144825477394}, \
{-0.06994319400804513, -0.6654650388849338, -0.743144825477394}, 
     {-0.06144028915352267, -0.5845653031794292, -0.8090169943749473}, \
{-0.12220742564187163, -0.5749407342765973, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.06994319400804513, -0.6654650388849338, -0.743144825477394}, 
     {-1.2291323881261169*^-16, -0.6691306063588583, -0.743144825477394}, \
{-1.0797083319606777*^-16, -0.5877852522924732, -0.8090169943749473}, 
     {-0.06144028915352267, -0.5845653031794292, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.2291323881261169*^-16, -0.6691306063588583, \
-0.743144825477394}, {0.06994319400804429, -0.6654650388849339, \
-0.743144825477394}, 
     {0.06144028915352193, -0.5845653031794292, -0.8090169943749473}, \
{-1.0797083319606777*^-16, -0.5877852522924732, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.775, 0.1], \
Polygon[{{0.06994319400804429, -0.6654650388849339, -0.743144825477394}, 
     {0.13912007574598226, -0.654508497187474, -0.743144825477394}, \
{0.12220742564187091, -0.5749407342765974, -0.8090169943749473}, 
     {0.06144028915352193, -0.5845653031794292, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.13912007574598226, -0.654508497187474, -0.743144825477394}, \
{0.20677272882130035, -0.6363810234301196, -0.743144825477394}, 
     {0.18163563200134014, -0.5590169943749476, -0.8090169943749473}, \
{0.12220742564187091, -0.5749407342765974, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.20677272882130035, -0.6363810234301196, -0.743144825477394}, 
     {0.27215993660967647, -0.6112812260087744, -0.743144825477394}, \
{0.2390738003669026, -0.5369685473010992, -0.8090169943749473}, 
     {0.18163563200134014, -0.5590169943749476, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{0.27215993660967647, -0.6112812260087744, -0.743144825477394}, \
{0.33456530317942873, -0.5794841035564569, -0.743144825477394}, 
     {0.29389262614623624, -0.5090369604551275, -0.8090169943749473}, \
{0.2390738003669026, -0.5369685473010992, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.33456530317942873, -0.5794841035564569, -0.743144825477394}, 
     {0.39330510227525695, -0.5413380320007297, -0.743144825477394}, \
{0.3454915028125262, -0.475528258147577, -0.8090169943749473}, 
     {0.29389262614623624, -0.5090369604551275, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.39330510227525695, -0.5413380320007297, -0.743144825477394}, \
{0.44773576836617307, -0.497260947684137, -0.743144825477394}, 
     {0.39330510227525683, -0.43680956873307636, -0.8090169943749473}, \
{0.3454915028125262, -0.475528258147577, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.875, 0.1], \
Polygon[{{0.44773576836617307, -0.497260947684137, -0.743144825477394}, 
     {0.4972609476841364, -0.44773576836617374, -0.743144825477394}, \
{0.43680956873307586, -0.39330510227525745, -0.8090169943749473}, 
     {0.39330510227525683, -0.43680956873307636, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.4972609476841364, -0.44773576836617374, -0.743144825477394}, \
{0.5413380320007296, -0.3933051022752572, -0.743144825477394}, 
     {0.4755282581475768, -0.3454915028125265, -0.8090169943749473}, \
{0.43680956873307586, -0.39330510227525745, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.5413380320007296, -0.3933051022752572, -0.743144825477394}, 
     {0.5794841035564564, -0.33456530317942945, -0.743144825477394}, \
{0.5090369604551271, -0.2938926261462369, -0.8090169943749473}, 
     {0.4755282581475768, -0.3454915028125265, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.5794841035564564, -0.33456530317942945, -0.743144825477394}, \
{0.611281226008774, -0.27215993660967724, -0.743144825477394}, 
     {0.5369685473010989, -0.2390738003669033, -0.8090169943749473}, \
{0.5090369604551271, -0.2938926261462369, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.611281226008774, -0.27215993660967724, -0.743144825477394}, 
     {0.6363810234301195, -0.20677272882130063, -0.743144825477394}, \
{0.5590169943749476, -0.18163563200134036, -0.8090169943749473}, 
     {0.5369685473010989, -0.2390738003669033, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.6363810234301195, -0.20677272882130063, -0.743144825477394}, \
{0.6545084971874738, -0.13912007574598315, -0.743144825477394}, 
     {0.5749407342765973, -0.12220742564187168, -0.8090169943749473}, \
{0.5590169943749476, -0.18163563200134036, -0.8090169943749473}}]}, 
  {CMYKColor[0.7833333333333333, 0.5, 0.975, 0.1], \
Polygon[{{0.6545084971874738, -0.13912007574598315, -0.743144825477394}, 
     {0.6654650388849338, -0.06994319400804518, -0.743144825477394}, \
{0.5845653031794292, -0.06144028915352271, -0.8090169943749473}, 
     {0.5749407342765973, -0.12220742564187168, -0.8090169943749473}}]}, \
{CMYKColor[0.7833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.6654650388849338, -0.06994319400804518, -0.743144825477394}, \
{0.6691306063588583, -1.6388431841681557*^-16, -0.743144825477394}, 
     {0.5877852522924732, -1.4396111092809037*^-16, -0.8090169943749473}, \
{0.5845653031794292, -0.06144028915352271, -0.8090169943749473}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.5877852522924732, 0., -0.8090169943749473}, 
     {0.5845653031794292, 0.06144028915352221, -0.8090169943749473}, \
{0.497260947684137, 0.05226423163382676, -0.8660254037844385}, 
     {0.5000000000000003, 0., -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.025, 0.1], 
   Polygon[{{0.5845653031794292, 0.06144028915352221, -0.8090169943749473}, \
{0.5749407342765974, 0.12220742564187136, -0.8090169943749473}, 
     {0.4890738003669032, 0.10395584540887973, -0.8660254037844385}, \
{0.497260947684137, 0.05226423163382676, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.5749407342765974, 0.12220742564187136, -0.8090169943749473}, 
     {0.5590169943749476, 0.18163563200134025, -0.8090169943749473}, \
{0.4755282581475771, 0.1545084971874738, -0.8660254037844385}, 
     {0.4890738003669032, 0.10395584540887973, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.5590169943749476, 0.18163563200134025, -0.8090169943749473}, \
{0.5369685473010991, 0.23907380036690284, -0.8090169943749473}, 
     {0.4567727288213007, 0.20336832153790022, -0.8660254037844385}, \
{0.4755282581475771, 0.1545084971874738, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.075, 0.1], \
Polygon[{{0.5369685473010991, 0.23907380036690284, -0.8090169943749473}, 
     {0.5090369604551274, 0.29389262614623657, -0.8090169943749473}, \
{0.43301270189221963, 0.2500000000000001, -0.8660254037844385}, 
     {0.4567727288213007, 0.20336832153790022, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.5090369604551274, 0.29389262614623657, -0.8090169943749473}, \
{0.4755282581475769, 0.3454915028125264, -0.8090169943749473}, 
     {0.404508497187474, 0.2938926261462368, -0.8660254037844385}, \
{0.43301270189221963, 0.2500000000000001, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.4755282581475769, 0.3454915028125264, -0.8090169943749473}, 
     {0.43680956873307625, 0.393305102275257, -0.8090169943749473}, \
{0.3715724127386974, 0.3345653031794293, -0.8660254037844385}, 
     {0.404508497187474, 0.2938926261462368, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.125, 0.1], 
   Polygon[{{0.43680956873307625, 0.393305102275257, -0.8090169943749473}, \
{0.3933051022752571, 0.43680956873307614, -0.8090169943749473}, 
     {0.33456530317942934, 0.3715724127386973, -0.8660254037844385}, \
{0.3715724127386974, 0.3345653031794293, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.3933051022752571, 0.43680956873307614, -0.8090169943749473}, 
     {0.3454915028125264, 0.4755282581475769, -0.8090169943749473}, \
{0.2938926261462368, 0.404508497187474, -0.8660254037844385}, 
     {0.33456530317942934, 0.3715724127386973, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.3454915028125264, 0.4755282581475769, -0.8090169943749473}, \
{0.2938926261462367, 0.5090369604551273, -0.8090169943749473}, 
     {0.2500000000000002, 0.4330127018922196, -0.8660254037844385}, \
{0.2938926261462368, 0.404508497187474, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.175, 0.1], \
Polygon[{{0.2938926261462367, 0.5090369604551273, -0.8090169943749473}, 
     {0.23907380036690296, 0.5369685473010991, -0.8090169943749473}, \
{0.20336832153790033, 0.4567727288213007, -0.8660254037844385}, 
     {0.2500000000000002, 0.4330127018922196, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.23907380036690296, 0.5369685473010991, -0.8090169943749473}, \
{0.18163563200134028, 0.5590169943749476, -0.8090169943749473}, 
     {0.15450849718747384, 0.4755282581475771, -0.8660254037844385}, \
{0.20336832153790033, 0.4567727288213007, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.18163563200134028, 0.5590169943749476, -0.8090169943749473}, 
     {0.12220742564187144, 0.5749407342765973, -0.8090169943749473}, \
{0.1039558454088798, 0.4890738003669031, -0.8660254037844385}, 
     {0.15450849718747384, 0.4755282581475771, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.225, 0.1], 
   Polygon[{{0.12220742564187144, 0.5749407342765973, -0.8090169943749473}, \
{0.06144028915352234, 0.5845653031794292, -0.8090169943749473}, 
     {0.052264231633826874, 0.497260947684137, -0.8660254037844385}, \
{0.1039558454088798, 0.4890738003669031, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.06144028915352234, 0.5845653031794292, -0.8090169943749473}, 
     {3.599027773202259*^-17, 0.5877852522924732, -0.8090169943749473}, \
{3.061515884555945*^-17, 0.5000000000000003, -0.8660254037844385}, 
     {0.052264231633826874, 0.497260947684137, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{3.599027773202259*^-17, 0.5877852522924732, \
-0.8090169943749473}, {-0.061440289153522135, 0.5845653031794292, \
-0.8090169943749473}, 
     {-0.0522642316338267, 0.49726094768413703, -0.8660254037844385}, \
{3.061515884555945*^-17, 0.5000000000000003, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.275, 0.1], \
Polygon[{{-0.061440289153522135, 0.5845653031794292, -0.8090169943749473}, 
     {-0.12220742564187125, 0.5749407342765974, -0.8090169943749473}, \
{-0.10395584540887963, 0.4890738003669032, -0.8660254037844385}, 
     {-0.0522642316338267, 0.49726094768413703, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.12220742564187125, 0.5749407342765974, -0.8090169943749473}, \
{-0.1816356320013402, 0.5590169943749476, -0.8090169943749473}, 
     {-0.15450849718747378, 0.47552825814757715, -0.8660254037844385}, \
{-0.10395584540887963, 0.4890738003669032, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.1816356320013402, 0.5590169943749476, -0.8090169943749473}, 
     {-0.23907380036690276, 0.5369685473010991, -0.8090169943749473}, \
{-0.20336832153790016, 0.45677272882130077, -0.8660254037844385}, 
     {-0.15450849718747378, 0.47552825814757715, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.325, 0.1], 
   Polygon[{{-0.23907380036690276, 0.5369685473010991, -0.8090169943749473}, \
{-0.2938926261462365, 0.5090369604551274, -0.8090169943749473}, 
     {-0.25000000000000006, 0.43301270189221963, -0.8660254037844385}, \
{-0.20336832153790016, 0.45677272882130077, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.2938926261462365, 0.5090369604551274, -0.8090169943749473}, 
     {-0.3454915028125263, 0.4755282581475769, -0.8090169943749473}, \
{-0.29389262614623674, 0.404508497187474, -0.8660254037844385}, 
     {-0.25000000000000006, 0.43301270189221963, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.3454915028125263, 0.4755282581475769, -0.8090169943749473}, \
{-0.3933051022752569, 0.4368095687330763, -0.8090169943749473}, 
     {-0.3345653031794292, 0.37157241273869746, -0.8660254037844385}, \
{-0.29389262614623674, 0.404508497187474, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.375, 0.1], \
Polygon[{{-0.3933051022752569, 0.4368095687330763, -0.8090169943749473}, 
     {-0.436809568733076, 0.39330510227525717, -0.8090169943749473}, \
{-0.37157241273869723, 0.3345653031794294, -0.8660254037844385}, 
     {-0.3345653031794292, 0.37157241273869746, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.436809568733076, 0.39330510227525717, -0.8090169943749473}, \
{-0.4755282581475768, 0.34549150281252644, -0.8090169943749473}, 
     {-0.40450849718747395, 0.29389262614623685, -0.8660254037844385}, \
{-0.37157241273869723, 0.3345653031794294, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.4755282581475768, 0.34549150281252644, -0.8090169943749473}, 
     {-0.5090369604551271, 0.29389262614623685, -0.8090169943749473}, \
{-0.4330127018922195, 0.25000000000000033, -0.8660254037844385}, 
     {-0.40450849718747395, 0.29389262614623685, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.425, 0.1], 
   Polygon[{{-0.5090369604551271, 0.29389262614623685, -0.8090169943749473}, \
{-0.536968547301099, 0.239073800366903, -0.8090169943749473}, 
     {-0.45677272882130066, 0.20336832153790035, -0.8660254037844385}, \
{-0.4330127018922195, 0.25000000000000033, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.536968547301099, 0.239073800366903, -0.8090169943749473}, 
     {-0.5590169943749476, 0.1816356320013403, -0.8090169943749473}, \
{-0.4755282581475771, 0.15450849718747386, -0.8660254037844385}, 
     {-0.45677272882130066, 0.20336832153790035, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.5590169943749476, 0.1816356320013403, -0.8090169943749473}, \
{-0.5749407342765973, 0.12220742564187159, -0.8090169943749473}, 
     {-0.4890738003669031, 0.10395584540887993, -0.8660254037844385}, \
{-0.4755282581475771, 0.15450849718747386, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.475, 0.1], \
Polygon[{{-0.5749407342765973, 0.12220742564187159, -0.8090169943749473}, 
     {-0.5845653031794292, 0.06144028915352237, -0.8090169943749473}, \
{-0.497260947684137, 0.0522642316338269, -0.8660254037844385}, 
     {-0.4890738003669031, 0.10395584540887993, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.5845653031794292, 0.06144028915352237, -0.8090169943749473}, \
{-0.5877852522924732, 7.198055546404518*^-17, -0.8090169943749473}, 
     {-0.5000000000000003, 6.12303176911189*^-17, -0.8660254037844385}, \
{-0.497260947684137, 0.0522642316338269, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.5877852522924732, 7.198055546404518*^-17, -0.8090169943749473}, 
     {-0.5845653031794292, -0.061440289153521975, -0.8090169943749473}, \
{-0.49726094768413703, -0.05226423163382656, -0.8660254037844385}, 
     {-0.5000000000000003, 6.12303176911189*^-17, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.525, 0.1], 
   Polygon[{{-0.5845653031794292, -0.061440289153521975, \
-0.8090169943749473}, {-0.5749407342765974, -0.1222074256418712, \
-0.8090169943749473}, 
     {-0.4890738003669032, -0.1039558454088796, -0.8660254037844385}, \
{-0.49726094768413703, -0.05226423163382656, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.5749407342765974, -0.1222074256418712, -0.8090169943749473}, 
     {-0.5590169943749476, -0.18163563200134017, -0.8090169943749473}, \
{-0.47552825814757715, -0.15450849718747375, -0.8660254037844385}, 
     {-0.4890738003669032, -0.1039558454088796, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.5590169943749476, -0.18163563200134017, -0.8090169943749473}, \
{-0.5369685473010992, -0.23907380036690265, -0.8090169943749473}, 
     {-0.4567727288213008, -0.20336832153790005, -0.8660254037844385}, \
{-0.47552825814757715, -0.15450849718747375, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.575, 0.1], \
Polygon[{{-0.5369685473010992, -0.23907380036690265, -0.8090169943749473}, 
     {-0.5090369604551274, -0.29389262614623646, -0.8090169943749473}, \
{-0.4330127018922197, -0.25, -0.8660254037844385}, 
     {-0.4567727288213008, -0.20336832153790005, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.5090369604551274, -0.29389262614623646, -0.8090169943749473}, \
{-0.475528258147577, -0.3454915028125263, -0.8090169943749473}, 
     {-0.40450849718747406, -0.29389262614623674, -0.8660254037844385}, \
{-0.4330127018922197, -0.25, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.475528258147577, -0.3454915028125263, -0.8090169943749473}, 
     {-0.43680956873307636, -0.3933051022752569, -0.8090169943749473}, \
{-0.3715724127386975, -0.3345653031794292, -0.8660254037844385}, 
     {-0.40450849718747406, -0.29389262614623674, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.625, 0.1], 
   Polygon[{{-0.43680956873307636, -0.3933051022752569, -0.8090169943749473}, \
{-0.3933051022752572, -0.436809568733076, -0.8090169943749473}, 
     {-0.33456530317942945, -0.37157241273869723, -0.8660254037844385}, \
{-0.3715724127386975, -0.3345653031794292, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.3933051022752572, -0.436809568733076, -0.8090169943749473}, 
     {-0.34549150281252644, -0.4755282581475768, -0.8090169943749473}, \
{-0.29389262614623685, -0.40450849718747395, -0.8660254037844385}, 
     {-0.33456530317942945, -0.37157241273869723, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.34549150281252644, -0.4755282581475768, -0.8090169943749473}, \
{-0.2938926261462369, -0.5090369604551271, -0.8090169943749473}, 
     {-0.2500000000000004, -0.43301270189221946, -0.8660254037844385}, \
{-0.29389262614623685, -0.40450849718747395, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.675, 0.1], \
Polygon[{{-0.2938926261462369, -0.5090369604551271, -0.8090169943749473}, 
     {-0.23907380036690326, -0.5369685473010989, -0.8090169943749473}, \
{-0.20336832153790058, -0.45677272882130054, -0.8660254037844385}, 
     {-0.2500000000000004, -0.43301270189221946, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.23907380036690326, -0.5369685473010989, -0.8090169943749473}, \
{-0.18163563200134034, -0.5590169943749476, -0.8090169943749473}, 
     {-0.1545084971874739, -0.4755282581475771, -0.8660254037844385}, \
{-0.20336832153790058, -0.45677272882130054, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.18163563200134034, -0.5590169943749476, -0.8090169943749473}, 
     {-0.12220742564187163, -0.5749407342765973, -0.8090169943749473}, \
{-0.10395584540887996, -0.4890738003669031, -0.8660254037844385}, 
     {-0.1545084971874739, -0.4755282581475771, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.725, 0.1], 
   Polygon[{{-0.12220742564187163, -0.5749407342765973, -0.8090169943749473}, \
{-0.06144028915352267, -0.5845653031794292, -0.8090169943749473}, 
     {-0.05226423163382715, -0.497260947684137, -0.8660254037844385}, \
{-0.10395584540887996, -0.4890738003669031, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.06144028915352267, -0.5845653031794292, -0.8090169943749473}, 
     {-1.0797083319606777*^-16, -0.5877852522924732, -0.8090169943749473}, \
{-9.184547653667836*^-17, -0.5000000000000003, -0.8660254037844385}, 
     {-0.05226423163382715, -0.497260947684137, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.0797083319606777*^-16, -0.5877852522924732, \
-0.8090169943749473}, {0.06144028915352193, -0.5845653031794292, \
-0.8090169943749473}, 
     {0.05226423163382653, -0.49726094768413703, -0.8660254037844385}, \
{-9.184547653667836*^-17, -0.5000000000000003, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.775, 0.1], \
Polygon[{{0.06144028915352193, -0.5845653031794292, -0.8090169943749473}, 
     {0.12220742564187091, -0.5749407342765974, -0.8090169943749473}, \
{0.10395584540887935, -0.48907380036690323, -0.8660254037844385}, 
     {0.05226423163382653, -0.49726094768413703, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.12220742564187091, -0.5749407342765974, -0.8090169943749473}, \
{0.18163563200134014, -0.5590169943749476, -0.8090169943749473}, 
     {0.15450849718747373, -0.47552825814757715, -0.8660254037844385}, \
{0.10395584540887935, -0.48907380036690323, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.18163563200134014, -0.5590169943749476, -0.8090169943749473}, 
     {0.2390738003669026, -0.5369685473010992, -0.8090169943749473}, \
{0.20336832153790002, -0.4567727288213008, -0.8660254037844385}, 
     {0.15450849718747373, -0.47552825814757715, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.825, 0.1], 
   Polygon[{{0.2390738003669026, -0.5369685473010992, -0.8090169943749473}, \
{0.29389262614623624, -0.5090369604551275, -0.8090169943749473}, 
     {0.24999999999999983, -0.4330127018922198, -0.8660254037844385}, \
{0.20336832153790002, -0.4567727288213008, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.29389262614623624, -0.5090369604551275, -0.8090169943749473}, 
     {0.3454915028125262, -0.475528258147577, -0.8090169943749473}, \
{0.2938926261462367, -0.40450849718747406, -0.8660254037844385}, 
     {0.24999999999999983, -0.4330127018922198, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.3454915028125262, -0.475528258147577, -0.8090169943749473}, \
{0.39330510227525683, -0.43680956873307636, -0.8090169943749473}, 
     {0.3345653031794291, -0.3715724127386975, -0.8660254037844385}, \
{0.2938926261462367, -0.40450849718747406, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.875, 0.1], \
Polygon[{{0.39330510227525683, -0.43680956873307636, -0.8090169943749473}, 
     {0.43680956873307586, -0.39330510227525745, -0.8090169943749473}, \
{0.37157241273869707, -0.3345653031794296, -0.8660254037844385}, 
     {0.3345653031794291, -0.3715724127386975, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.43680956873307586, -0.39330510227525745, -0.8090169943749473}, \
{0.4755282581475768, -0.3454915028125265, -0.8090169943749473}, 
     {0.40450849718747395, -0.2938926261462369, -0.8660254037844385}, \
{0.37157241273869707, -0.3345653031794296, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.4755282581475768, -0.3454915028125265, -0.8090169943749473}, 
     {0.5090369604551271, -0.2938926261462369, -0.8090169943749473}, \
{0.43301270189221946, -0.2500000000000004, -0.8660254037844385}, 
     {0.40450849718747395, -0.2938926261462369, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.5090369604551271, -0.2938926261462369, -0.8090169943749473}, \
{0.5369685473010989, -0.2390738003669033, -0.8090169943749473}, 
     {0.45677272882130054, -0.2033683215379006, -0.8660254037844385}, \
{0.43301270189221946, -0.2500000000000004, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.5369685473010989, -0.2390738003669033, -0.8090169943749473}, 
     {0.5590169943749476, -0.18163563200134036, -0.8090169943749473}, \
{0.4755282581475771, -0.15450849718747392, -0.8660254037844385}, 
     {0.45677272882130054, -0.2033683215379006, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.5590169943749476, -0.18163563200134036, -0.8090169943749473}, \
{0.5749407342765973, -0.12220742564187168, -0.8090169943749473}, 
     {0.4890738003669031, -0.10395584540888, -0.8660254037844385}, \
{0.4755282581475771, -0.15450849718747392, -0.8660254037844385}}]}, 
  {CMYKColor[0.8166666666666667, 0.5, 0.975, 0.1], \
Polygon[{{0.5749407342765973, -0.12220742564187168, -0.8090169943749473}, 
     {0.5845653031794292, -0.06144028915352271, -0.8090169943749473}, \
{0.497260947684137, -0.052264231633827186, -0.8660254037844385}, 
     {0.4890738003669031, -0.10395584540888, -0.8660254037844385}}]}, \
{CMYKColor[0.8166666666666667, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.5845653031794292, -0.06144028915352271, -0.8090169943749473}, \
{0.5877852522924732, -1.4396111092809037*^-16, -0.8090169943749473}, 
     {0.5000000000000003, -1.224606353822378*^-16, -0.8660254037844385}, \
{0.497260947684137, -0.052264231633827186, -0.8660254037844385}}]}, 
  {CMYKColor[0.85, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.5000000000000003, 0., -0.8660254037844385}, 
     {0.497260947684137, 0.05226423163382676, -0.8660254037844385}, \
{0.4045084971874739, 0.04251555625535748, -0.9135454576426008}, 
     {0.40673664307580043, 0., -0.9135454576426008}}]}, {CMYKColor[0.85, 0.5, \
0.025, 0.1], 
   Polygon[{{0.497260947684137, 0.05226423163382676, -0.8660254037844385}, \
{0.4890738003669032, 0.10395584540887973, -0.8660254037844385}, 
     {0.3978484715551165, 0.08456530317942915, -0.9135454576426008}, \
{0.4045084971874739, 0.04251555625535748, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.4890738003669032, 0.10395584540887973, -0.8660254037844385}, 
     {0.4755282581475771, 0.1545084971874738, -0.8660254037844385}, \
{0.38682953481325605, 0.1256885349454396, -0.9135454576426008}, 
     {0.3978484715551165, 0.08456530317942915, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.4755282581475771, 0.1545084971874738, -0.8660254037844385}, \
{0.4567727288213007, 0.20336832153790022, -0.8660254037844385}, 
     {0.3715724127386973, 0.16543469682057096, -0.9135454576426008}, \
{0.38682953481325605, 0.1256885349454396, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.075, 0.1], Polygon[{{0.4567727288213007, \
0.20336832153790022, -0.8660254037844385}, 
     {0.43301270189221963, 0.2500000000000001, -0.8660254037844385}, \
{0.3522442655536472, 0.2033683215379002, -0.9135454576426008}, 
     {0.3715724127386973, 0.16543469682057096, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.43301270189221963, 0.2500000000000001, -0.8660254037844385}, \
{0.404508497187474, 0.2938926261462368, -0.8660254037844385}, 
     {0.3290568564833398, 0.23907380036690296, -0.9135454576426008}, \
{0.3522442655536472, 0.2033683215379002, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.404508497187474, 0.2938926261462368, -0.8660254037844385}, 
     {0.3715724127386974, 0.3345653031794293, -0.8660254037844385}, \
{0.30226423163382693, 0.2721599366096768, -0.9135454576426008}, 
     {0.3290568564833398, 0.23907380036690296, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.125, 0.1], 
   Polygon[{{0.3715724127386974, 0.3345653031794293, -0.8660254037844385}, \
{0.33456530317942934, 0.3715724127386973, -0.8660254037844385}, 
     {0.27215993660967686, 0.3022642316338269, -0.9135454576426008}, \
{0.30226423163382693, 0.2721599366096768, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.33456530317942934, 0.3715724127386973, -0.8660254037844385}, 
     {0.2938926261462368, 0.404508497187474, -0.8660254037844385}, \
{0.23907380036690296, 0.3290568564833398, -0.9135454576426008}, 
     {0.27215993660967686, 0.3022642316338269, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.2938926261462368, 0.404508497187474, -0.8660254037844385}, \
{0.2500000000000002, 0.4330127018922196, -0.8660254037844385}, 
     {0.20336832153790027, 0.35224426555364713, -0.9135454576426008}, \
{0.23907380036690296, 0.3290568564833398, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.175, 0.1], Polygon[{{0.2500000000000002, \
0.4330127018922196, -0.8660254037844385}, 
     {0.20336832153790033, 0.4567727288213007, -0.8660254037844385}, \
{0.16543469682057105, 0.3715724127386973, -0.9135454576426008}, 
     {0.20336832153790027, 0.35224426555364713, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.20336832153790033, 0.4567727288213007, -0.8660254037844385}, \
{0.15450849718747384, 0.4755282581475771, -0.8660254037844385}, 
     {0.12568853494543963, 0.38682953481325605, -0.9135454576426008}, \
{0.16543469682057105, 0.3715724127386973, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.15450849718747384, 0.4755282581475771, -0.8660254037844385}, 
     {0.1039558454088798, 0.4890738003669031, -0.8660254037844385}, \
{0.0845653031794292, 0.39784847155511643, -0.9135454576426008}, 
     {0.12568853494543963, 0.38682953481325605, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.225, 0.1], 
   Polygon[{{0.1039558454088798, 0.4890738003669031, -0.8660254037844385}, \
{0.052264231633826874, 0.497260947684137, -0.8660254037844385}, 
     {0.04251555625535757, 0.4045084971874739, -0.9135454576426008}, \
{0.0845653031794292, 0.39784847155511643, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.052264231633826874, 0.497260947684137, -0.8660254037844385}, 
     {3.061515884555945*^-17, 0.5000000000000003, -0.8660254037844385}, \
{2.4904613872150483*^-17, 0.40673664307580043, -0.9135454576426008}, 
     {0.04251555625535757, 0.4045084971874739, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{3.061515884555945*^-17, 0.5000000000000003, \
-0.8660254037844385}, {-0.0522642316338267, 0.49726094768413703, \
-0.8660254037844385}, 
     {-0.04251555625535743, 0.40450849718747395, -0.9135454576426008}, \
{2.4904613872150483*^-17, 0.40673664307580043, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.275, 0.1], Polygon[{{-0.0522642316338267, \
0.49726094768413703, -0.8660254037844385}, 
     {-0.10395584540887963, 0.4890738003669032, -0.8660254037844385}, \
{-0.08456530317942906, 0.3978484715551165, -0.9135454576426008}, 
     {-0.04251555625535743, 0.40450849718747395, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.10395584540887963, 0.4890738003669032, -0.8660254037844385}, \
{-0.15450849718747378, 0.47552825814757715, -0.8660254037844385}, 
     {-0.12568853494543958, 0.3868295348132561, -0.9135454576426008}, \
{-0.08456530317942906, 0.3978484715551165, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.15450849718747378, 0.47552825814757715, -0.8660254037844385}, 
     {-0.20336832153790016, 0.45677272882130077, -0.8660254037844385}, \
{-0.1654346968205709, 0.37157241273869734, -0.9135454576426008}, 
     {-0.12568853494543958, 0.3868295348132561, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.325, 0.1], 
   Polygon[{{-0.20336832153790016, 0.45677272882130077, -0.8660254037844385}, \
{-0.25000000000000006, 0.43301270189221963, -0.8660254037844385}, 
     {-0.20336832153790013, 0.3522442655536472, -0.9135454576426008}, \
{-0.1654346968205709, 0.37157241273869734, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.25000000000000006, 0.43301270189221963, -0.8660254037844385}, 
     {-0.29389262614623674, 0.404508497187474, -0.8660254037844385}, \
{-0.2390738003669029, 0.3290568564833398, -0.9135454576426008}, 
     {-0.20336832153790013, 0.3522442655536472, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.29389262614623674, 0.404508497187474, -0.8660254037844385}, \
{-0.3345653031794292, 0.37157241273869746, -0.8660254037844385}, 
     {-0.2721599366096767, 0.302264231633827, -0.9135454576426008}, \
{-0.2390738003669029, 0.3290568564833398, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.375, 0.1], Polygon[{{-0.3345653031794292, \
0.37157241273869746, -0.8660254037844385}, 
     {-0.37157241273869723, 0.3345653031794294, -0.8660254037844385}, \
{-0.3022642316338268, 0.2721599366096769, -0.9135454576426008}, 
     {-0.2721599366096767, 0.302264231633827, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.37157241273869723, 0.3345653031794294, -0.8660254037844385}, \
{-0.40450849718747395, 0.29389262614623685, -0.8660254037844385}, 
     {-0.3290568564833398, 0.239073800366903, -0.9135454576426008}, \
{-0.3022642316338268, 0.2721599366096769, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.40450849718747395, 0.29389262614623685, -0.8660254037844385}, 
     {-0.4330127018922195, 0.25000000000000033, -0.8660254037844385}, \
{-0.35224426555364713, 0.20336832153790035, -0.9135454576426008}, 
     {-0.3290568564833398, 0.239073800366903, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.425, 0.1], 
   Polygon[{{-0.4330127018922195, 0.25000000000000033, -0.8660254037844385}, \
{-0.45677272882130066, 0.20336832153790035, -0.8660254037844385}, 
     {-0.3715724127386973, 0.16543469682057108, -0.9135454576426008}, \
{-0.35224426555364713, 0.20336832153790035, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.45677272882130066, 0.20336832153790035, -0.8660254037844385}, 
     {-0.4755282581475771, 0.15450849718747386, -0.8660254037844385}, \
{-0.38682953481325605, 0.12568853494543966, -0.9135454576426008}, 
     {-0.3715724127386973, 0.16543469682057108, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.4755282581475771, 0.15450849718747386, -0.8660254037844385}, \
{-0.4890738003669031, 0.10395584540887993, -0.8660254037844385}, 
     {-0.39784847155511643, 0.08456530317942931, -0.9135454576426008}, \
{-0.38682953481325605, 0.12568853494543966, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.475, 0.1], Polygon[{{-0.4890738003669031, \
0.10395584540887993, -0.8660254037844385}, 
     {-0.497260947684137, 0.0522642316338269, -0.8660254037844385}, \
{-0.4045084971874739, 0.04251555625535759, -0.9135454576426008}, 
     {-0.39784847155511643, 0.08456530317942931, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.497260947684137, 0.0522642316338269, -0.8660254037844385}, \
{-0.5000000000000003, 6.12303176911189*^-17, -0.8660254037844385}, 
     {-0.40673664307580043, 4.9809227744300965*^-17, -0.9135454576426008}, \
{-0.4045084971874739, 0.04251555625535759, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.5000000000000003, 6.12303176911189*^-17, -0.8660254037844385}, 
     {-0.49726094768413703, -0.05226423163382656, -0.8660254037844385}, \
{-0.40450849718747395, -0.042515556255357315, -0.9135454576426008}, 
     {-0.40673664307580043, 4.9809227744300965*^-17, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.525, 0.1], 
   Polygon[{{-0.49726094768413703, -0.05226423163382656, \
-0.8660254037844385}, {-0.4890738003669032, -0.1039558454088796, \
-0.8660254037844385}, 
     {-0.3978484715551165, -0.08456530317942905, -0.9135454576426008}, \
{-0.40450849718747395, -0.042515556255357315, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.4890738003669032, -0.1039558454088796, -0.8660254037844385}, 
     {-0.47552825814757715, -0.15450849718747375, -0.8660254037844385}, \
{-0.3868295348132561, -0.12568853494543955, -0.9135454576426008}, 
     {-0.3978484715551165, -0.08456530317942905, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.47552825814757715, -0.15450849718747375, \
-0.8660254037844385}, {-0.4567727288213008, -0.20336832153790005, \
-0.8660254037844385}, 
     {-0.3715724127386974, -0.16543469682057083, -0.9135454576426008}, \
{-0.3868295348132561, -0.12568853494543955, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.575, 0.1], Polygon[{{-0.4567727288213008, \
-0.20336832153790005, -0.8660254037844385}, 
     {-0.4330127018922197, -0.25, -0.8660254037844385}, \
{-0.35224426555364724, -0.2033683215379001, -0.9135454576426008}, 
     {-0.3715724127386974, -0.16543469682057083, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.4330127018922197, -0.25, -0.8660254037844385}, \
{-0.40450849718747406, -0.29389262614623674, -0.8660254037844385}, 
     {-0.3290568564833399, -0.2390738003669029, -0.9135454576426008}, \
{-0.35224426555364724, -0.2033683215379001, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.40450849718747406, -0.29389262614623674, -0.8660254037844385}, 
     {-0.3715724127386975, -0.3345653031794292, -0.8660254037844385}, \
{-0.30226423163382704, -0.2721599366096767, -0.9135454576426008}, 
     {-0.3290568564833399, -0.2390738003669029, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.625, 0.1], 
   Polygon[{{-0.3715724127386975, -0.3345653031794292, -0.8660254037844385}, \
{-0.33456530317942945, -0.37157241273869723, -0.8660254037844385}, 
     {-0.2721599366096769, -0.3022642316338268, -0.9135454576426008}, \
{-0.30226423163382704, -0.2721599366096767, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.33456530317942945, -0.37157241273869723, -0.8660254037844385}, 
     {-0.29389262614623685, -0.40450849718747395, -0.8660254037844385}, \
{-0.239073800366903, -0.3290568564833398, -0.9135454576426008}, 
     {-0.2721599366096769, -0.3022642316338268, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.29389262614623685, -0.40450849718747395, \
-0.8660254037844385}, {-0.2500000000000004, -0.43301270189221946, \
-0.8660254037844385}, 
     {-0.2033683215379004, -0.3522442655536471, -0.9135454576426008}, \
{-0.239073800366903, -0.3290568564833398, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.675, 0.1], Polygon[{{-0.2500000000000004, \
-0.43301270189221946, -0.8660254037844385}, 
     {-0.20336832153790058, -0.45677272882130054, -0.8660254037844385}, \
{-0.16543469682057124, -0.3715724127386972, -0.9135454576426008}, 
     {-0.2033683215379004, -0.3522442655536471, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.20336832153790058, -0.45677272882130054, \
-0.8660254037844385}, {-0.1545084971874739, -0.4755282581475771, \
-0.8660254037844385}, 
     {-0.1256885349454397, -0.38682953481325605, -0.9135454576426008}, \
{-0.16543469682057124, -0.3715724127386972, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.1545084971874739, -0.4755282581475771, -0.8660254037844385}, 
     {-0.10395584540887996, -0.4890738003669031, -0.8660254037844385}, \
{-0.08456530317942934, -0.39784847155511643, -0.9135454576426008}, 
     {-0.1256885349454397, -0.38682953481325605, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.725, 0.1], 
   Polygon[{{-0.10395584540887996, -0.4890738003669031, -0.8660254037844385}, \
{-0.05226423163382715, -0.497260947684137, -0.8660254037844385}, 
     {-0.04251555625535779, -0.4045084971874739, -0.9135454576426008}, \
{-0.08456530317942934, -0.39784847155511643, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.05226423163382715, -0.497260947684137, -0.8660254037844385}, 
     {-9.184547653667836*^-17, -0.5000000000000003, -0.8660254037844385}, \
{-7.471384161645145*^-17, -0.40673664307580043, -0.9135454576426008}, 
     {-0.04251555625535779, -0.4045084971874739, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-9.184547653667836*^-17, -0.5000000000000003, \
-0.8660254037844385}, {0.05226423163382653, -0.49726094768413703, \
-0.8660254037844385}, 
     {0.04251555625535729, -0.40450849718747395, -0.9135454576426008}, \
{-7.471384161645145*^-17, -0.40673664307580043, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.775, 0.1], Polygon[{{0.05226423163382653, \
-0.49726094768413703, -0.8660254037844385}, 
     {0.10395584540887935, -0.48907380036690323, -0.8660254037844385}, \
{0.08456530317942884, -0.3978484715551165, -0.9135454576426008}, 
     {0.04251555625535729, -0.40450849718747395, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.10395584540887935, -0.48907380036690323, -0.8660254037844385}, \
{0.15450849718747373, -0.47552825814757715, -0.8660254037844385}, 
     {0.12568853494543955, -0.3868295348132561, -0.9135454576426008}, \
{0.08456530317942884, -0.3978484715551165, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.15450849718747373, -0.47552825814757715, -0.8660254037844385}, 
     {0.20336832153790002, -0.4567727288213008, -0.8660254037844385}, \
{0.1654346968205708, -0.3715724127386974, -0.9135454576426008}, 
     {0.12568853494543955, -0.3868295348132561, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.825, 0.1], 
   Polygon[{{0.20336832153790002, -0.4567727288213008, -0.8660254037844385}, \
{0.24999999999999983, -0.4330127018922198, -0.8660254037844385}, 
     {0.20336832153789994, -0.35224426555364735, -0.9135454576426008}, \
{0.1654346968205708, -0.3715724127386974, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.24999999999999983, -0.4330127018922198, -0.8660254037844385}, 
     {0.2938926261462367, -0.40450849718747406, -0.8660254037844385}, \
{0.23907380036690287, -0.3290568564833399, -0.9135454576426008}, 
     {0.20336832153789994, -0.35224426555364735, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.2938926261462367, -0.40450849718747406, -0.8660254037844385}, \
{0.3345653031794291, -0.3715724127386975, -0.8660254037844385}, 
     {0.27215993660967663, -0.30226423163382704, -0.9135454576426008}, \
{0.23907380036690287, -0.3290568564833399, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.875, 0.1], Polygon[{{0.3345653031794291, \
-0.3715724127386975, -0.8660254037844385}, 
     {0.37157241273869707, -0.3345653031794296, -0.8660254037844385}, \
{0.30226423163382665, -0.2721599366096771, -0.9135454576426008}, 
     {0.27215993660967663, -0.30226423163382704, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.37157241273869707, -0.3345653031794296, -0.8660254037844385}, \
{0.40450849718747395, -0.2938926261462369, -0.8660254037844385}, 
     {0.3290568564833398, -0.23907380036690304, -0.9135454576426008}, \
{0.30226423163382665, -0.2721599366096771, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.40450849718747395, -0.2938926261462369, -0.8660254037844385}, 
     {0.43301270189221946, -0.2500000000000004, -0.8660254037844385}, \
{0.3522442655536471, -0.2033683215379004, -0.9135454576426008}, 
     {0.3290568564833398, -0.23907380036690304, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.43301270189221946, -0.2500000000000004, -0.8660254037844385}, \
{0.45677272882130054, -0.2033683215379006, -0.8660254037844385}, 
     {0.3715724127386972, -0.16543469682057127, -0.9135454576426008}, \
{0.3522442655536471, -0.2033683215379004, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.45677272882130054, -0.2033683215379006, -0.8660254037844385}, 
     {0.4755282581475771, -0.15450849718747392, -0.8660254037844385}, \
{0.38682953481325605, -0.1256885349454397, -0.9135454576426008}, 
     {0.3715724127386972, -0.16543469682057127, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.4755282581475771, -0.15450849718747392, -0.8660254037844385}, \
{0.4890738003669031, -0.10395584540888, -0.8660254037844385}, 
     {0.39784847155511643, -0.08456530317942937, -0.9135454576426008}, \
{0.38682953481325605, -0.1256885349454397, -0.9135454576426008}}]}, 
  {CMYKColor[0.85, 0.5, 0.975, 0.1], Polygon[{{0.4890738003669031, \
-0.10395584540888, -0.8660254037844385}, 
     {0.497260947684137, -0.052264231633827186, -0.8660254037844385}, \
{0.4045084971874739, -0.04251555625535782, -0.9135454576426008}, 
     {0.39784847155511643, -0.08456530317942937, -0.9135454576426008}}]}, \
{CMYKColor[0.85, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.497260947684137, -0.052264231633827186, -0.8660254037844385}, \
{0.5000000000000003, -1.224606353822378*^-16, -0.8660254037844385}, 
     {0.40673664307580043, -9.961845548860193*^-17, -0.9135454576426008}, \
{0.4045084971874739, -0.04251555625535782, -0.9135454576426008}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.40673664307580043, 0., -0.9135454576426008}, 
     {0.4045084971874739, 0.04251555625535748, -0.9135454576426008}, \
{0.30732416694677983, 0.032301071545602376, -0.9510565162951535}, 
     {0.3090169943749475, 0., -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.025, 0.1], 
   Polygon[{{0.4045084971874739, 0.04251555625535748, -0.9135454576426008}, \
{0.3978484715551165, 0.08456530317942915, -0.9135454576426008}, 
     {0.3022642316338268, 0.06424824579191736, -0.9510565162951535}, \
{0.30732416694677983, 0.032301071545602376, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.3978484715551165, 0.08456530317942915, -0.9135454576426008}, 
     {0.38682953481325605, 0.1256885349454396, -0.9135454576426008}, \
{0.2938926261462366, 0.0954915028125263, -0.9510565162951535}, 
     {0.3022642316338268, 0.06424824579191736, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.38682953481325605, 0.1256885349454396, -0.9135454576426008}, \
{0.3715724127386973, 0.16543469682057096, -0.9135454576426008}, 
     {0.2823010715456024, 0.12568853494543958, -0.9510565162951535}, \
{0.2938926261462366, 0.0954915028125263, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.075, 0.1], \
Polygon[{{0.3715724127386973, 0.16543469682057096, -0.9135454576426008}, 
     {0.3522442655536472, 0.2033683215379002, -0.9135454576426008}, \
{0.26761656732981753, 0.15450849718747373, -0.9510565162951535}, 
     {0.2823010715456024, 0.12568853494543958, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.3522442655536472, 0.2033683215379002, -0.9135454576426008}, \
{0.3290568564833398, 0.23907380036690296, -0.9135454576426008}, 
     {0.25000000000000006, 0.18163563200134028, -0.9510565162951535}, \
{0.26761656732981753, 0.15450849718747373, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.3290568564833398, 0.23907380036690296, -0.9135454576426008}, 
     {0.30226423163382693, 0.2721599366096768, -0.9135454576426008}, \
{0.2296443803543193, 0.2067727288213005, -0.9510565162951535}, 
     {0.25000000000000006, 0.18163563200134028, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.125, 0.1], 
   Polygon[{{0.30226423163382693, 0.2721599366096768, -0.9135454576426008}, \
{0.27215993660967686, 0.3022642316338269, -0.9135454576426008}, 
     {0.20677272882130052, 0.22964438035431925, -0.9510565162951535}, \
{0.2296443803543193, 0.2067727288213005, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.27215993660967686, 0.3022642316338269, -0.9135454576426008}, 
     {0.23907380036690296, 0.3290568564833398, -0.9135454576426008}, \
{0.18163563200134028, 0.25000000000000006, -0.9510565162951535}, 
     {0.20677272882130052, 0.22964438035431925, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.23907380036690296, 0.3290568564833398, -0.9135454576426008}, \
{0.20336832153790027, 0.35224426555364713, -0.9135454576426008}, 
     {0.15450849718747378, 0.2676165673298175, -0.9510565162951535}, \
{0.18163563200134028, 0.25000000000000006, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.175, 0.1], \
Polygon[{{0.20336832153790027, 0.35224426555364713, -0.9135454576426008}, 
     {0.16543469682057105, 0.3715724127386973, -0.9135454576426008}, \
{0.12568853494543963, 0.2823010715456024, -0.9510565162951535}, 
     {0.15450849718747378, 0.2676165673298175, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.16543469682057105, 0.3715724127386973, -0.9135454576426008}, \
{0.12568853494543963, 0.38682953481325605, -0.9135454576426008}, 
     {0.09549150281252632, 0.2938926261462366, -0.9510565162951535}, \
{0.12568853494543963, 0.2823010715456024, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.12568853494543963, 0.38682953481325605, -0.9135454576426008}, 
     {0.0845653031794292, 0.39784847155511643, -0.9135454576426008}, \
{0.0642482457919174, 0.3022642316338268, -0.9510565162951535}, 
     {0.09549150281252632, 0.2938926261462366, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.225, 0.1], 
   Polygon[{{0.0845653031794292, 0.39784847155511643, -0.9135454576426008}, \
{0.04251555625535757, 0.4045084971874739, -0.9135454576426008}, 
     {0.032301071545602446, 0.30732416694677983, -0.9510565162951535}, \
{0.0642482457919174, 0.3022642316338268, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.04251555625535757, 0.4045084971874739, -0.9135454576426008}, 
     {2.4904613872150483*^-17, 0.40673664307580043, -0.9135454576426008}, \
{1.8921208737532727*^-17, 0.3090169943749475, -0.9510565162951535}, 
     {0.032301071545602446, 0.30732416694677983, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{2.4904613872150483*^-17, 0.40673664307580043, \
-0.9135454576426008}, {-0.04251555625535743, 0.40450849718747395, \
-0.9135454576426008}, 
     {-0.032301071545602335, 0.3073241669467799, -0.9510565162951535}, \
{1.8921208737532727*^-17, 0.3090169943749475, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.275, 0.1], \
Polygon[{{-0.04251555625535743, 0.40450849718747395, -0.9135454576426008}, 
     {-0.08456530317942906, 0.3978484715551165, -0.9135454576426008}, \
{-0.06424824579191729, 0.3022642316338268, -0.9510565162951535}, 
     {-0.032301071545602335, 0.3073241669467799, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.08456530317942906, 0.3978484715551165, -0.9135454576426008}, \
{-0.12568853494543958, 0.3868295348132561, -0.9135454576426008}, 
     {-0.09549150281252629, 0.2938926261462367, -0.9510565162951535}, \
{-0.06424824579191729, 0.3022642316338268, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.12568853494543958, 0.3868295348132561, -0.9135454576426008}, 
     {-0.1654346968205709, 0.37157241273869734, -0.9135454576426008}, \
{-0.12568853494543952, 0.28230107154560247, -0.9510565162951535}, 
     {-0.09549150281252629, 0.2938926261462367, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.325, 0.1], 
   Polygon[{{-0.1654346968205709, 0.37157241273869734, -0.9135454576426008}, \
{-0.20336832153790013, 0.3522442655536472, -0.9135454576426008}, 
     {-0.1545084971874737, 0.26761656732981753, -0.9510565162951535}, \
{-0.12568853494543952, 0.28230107154560247, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.20336832153790013, 0.3522442655536472, -0.9135454576426008}, 
     {-0.2390738003669029, 0.3290568564833398, -0.9135454576426008}, \
{-0.18163563200134022, 0.25000000000000006, -0.9510565162951535}, 
     {-0.1545084971874737, 0.26761656732981753, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.2390738003669029, 0.3290568564833398, -0.9135454576426008}, \
{-0.2721599366096767, 0.302264231633827, -0.9135454576426008}, 
     {-0.2067727288213004, 0.22964438035431936, -0.9510565162951535}, \
{-0.18163563200134022, 0.25000000000000006, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.375, 0.1], \
Polygon[{{-0.2721599366096767, 0.302264231633827, -0.9135454576426008}, 
     {-0.3022642316338268, 0.2721599366096769, -0.9135454576426008}, \
{-0.22964438035431922, 0.20677272882130054, -0.9510565162951535}, 
     {-0.2067727288213004, 0.22964438035431936, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.3022642316338268, 0.2721599366096769, -0.9135454576426008}, \
{-0.3290568564833398, 0.239073800366903, -0.9135454576426008}, 
     {-0.25000000000000006, 0.1816356320013403, -0.9510565162951535}, \
{-0.22964438035431922, 0.20677272882130054, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.3290568564833398, 0.239073800366903, -0.9135454576426008}, 
     {-0.35224426555364713, 0.20336832153790035, -0.9135454576426008}, \
{-0.2676165673298175, 0.15450849718747386, -0.9510565162951535}, 
     {-0.25000000000000006, 0.1816356320013403, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.425, 0.1], 
   Polygon[{{-0.35224426555364713, 0.20336832153790035, -0.9135454576426008}, \
{-0.3715724127386973, 0.16543469682057108, -0.9135454576426008}, 
     {-0.2823010715456024, 0.12568853494543966, -0.9510565162951535}, \
{-0.2676165673298175, 0.15450849718747386, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.3715724127386973, 0.16543469682057108, -0.9135454576426008}, 
     {-0.38682953481325605, 0.12568853494543966, -0.9135454576426008}, \
{-0.2938926261462366, 0.09549150281252634, -0.9510565162951535}, 
     {-0.2823010715456024, 0.12568853494543966, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.38682953481325605, 0.12568853494543966, -0.9135454576426008}, \
{-0.39784847155511643, 0.08456530317942931, -0.9135454576426008}, 
     {-0.3022642316338268, 0.06424824579191749, -0.9510565162951535}, \
{-0.2938926261462366, 0.09549150281252634, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.475, 0.1], \
Polygon[{{-0.39784847155511643, 0.08456530317942931, -0.9135454576426008}, 
     {-0.4045084971874739, 0.04251555625535759, -0.9135454576426008}, \
{-0.30732416694677983, 0.03230107154560246, -0.9510565162951535}, 
     {-0.3022642316338268, 0.06424824579191749, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.4045084971874739, 0.04251555625535759, -0.9135454576426008}, \
{-0.40673664307580043, 4.9809227744300965*^-17, -0.9135454576426008}, 
     {-0.3090169943749475, 3.7842417475065455*^-17, -0.9510565162951535}, \
{-0.30732416694677983, 0.03230107154560246, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.40673664307580043, 4.9809227744300965*^-17, \
-0.9135454576426008}, 
     {-0.40450849718747395, -0.042515556255357315, -0.9135454576426008}, \
{-0.3073241669467799, -0.03230107154560225, -0.9510565162951535}, 
     {-0.3090169943749475, 3.7842417475065455*^-17, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.525, 0.1], 
   Polygon[{{-0.40450849718747395, -0.042515556255357315, \
-0.9135454576426008}, {-0.3978484715551165, -0.08456530317942905, \
-0.9135454576426008}, 
     {-0.3022642316338268, -0.06424824579191728, -0.9510565162951535}, \
{-0.3073241669467799, -0.03230107154560225, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.3978484715551165, -0.08456530317942905, -0.9135454576426008}, 
     {-0.3868295348132561, -0.12568853494543955, -0.9135454576426008}, \
{-0.2938926261462367, -0.09549150281252627, -0.9510565162951535}, 
     {-0.3022642316338268, -0.06424824579191728, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.3868295348132561, -0.12568853494543955, -0.9135454576426008}, \
{-0.3715724127386974, -0.16543469682057083, -0.9135454576426008}, 
     {-0.2823010715456025, -0.12568853494543947, -0.9510565162951535}, \
{-0.2938926261462367, -0.09549150281252627, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.575, 0.1], \
Polygon[{{-0.3715724127386974, -0.16543469682057083, -0.9135454576426008}, 
     {-0.35224426555364724, -0.2033683215379001, -0.9135454576426008}, \
{-0.2676165673298176, -0.15450849718747367, -0.9510565162951535}, 
     {-0.2823010715456025, -0.12568853494543947, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.35224426555364724, -0.2033683215379001, -0.9135454576426008}, \
{-0.3290568564833399, -0.2390738003669029, -0.9135454576426008}, 
     {-0.2500000000000001, -0.18163563200134022, -0.9510565162951535}, \
{-0.2676165673298176, -0.15450849718747367, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.3290568564833399, -0.2390738003669029, -0.9135454576426008}, 
     {-0.30226423163382704, -0.2721599366096767, -0.9135454576426008}, \
{-0.2296443803543194, -0.2067727288213004, -0.9510565162951535}, 
     {-0.2500000000000001, -0.18163563200134022, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.625, 0.1], 
   Polygon[{{-0.30226423163382704, -0.2721599366096767, -0.9135454576426008}, \
{-0.2721599366096769, -0.3022642316338268, -0.9135454576426008}, 
     {-0.20677272882130057, -0.22964438035431922, -0.9510565162951535}, \
{-0.2296443803543194, -0.2067727288213004, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.2721599366096769, -0.3022642316338268, -0.9135454576426008}, 
     {-0.239073800366903, -0.3290568564833398, -0.9135454576426008}, \
{-0.1816356320013403, -0.25000000000000006, -0.9510565162951535}, 
     {-0.20677272882130057, -0.22964438035431922, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.239073800366903, -0.3290568564833398, -0.9135454576426008}, \
{-0.2033683215379004, -0.3522442655536471, -0.9135454576426008}, 
     {-0.1545084971874739, -0.2676165673298174, -0.9510565162951535}, \
{-0.1816356320013403, -0.25000000000000006, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.675, 0.1], \
Polygon[{{-0.2033683215379004, -0.3522442655536471, -0.9135454576426008}, 
     {-0.16543469682057124, -0.3715724127386972, -0.9135454576426008}, \
{-0.1256885349454398, -0.28230107154560236, -0.9510565162951535}, 
     {-0.1545084971874739, -0.2676165673298174, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.16543469682057124, -0.3715724127386972, -0.9135454576426008}, \
{-0.1256885349454397, -0.38682953481325605, -0.9135454576426008}, 
     {-0.09549150281252636, -0.2938926261462366, -0.9510565162951535}, \
{-0.1256885349454398, -0.28230107154560236, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.1256885349454397, -0.38682953481325605, -0.9135454576426008}, 
     {-0.08456530317942934, -0.39784847155511643, -0.9135454576426008}, \
{-0.0642482457919175, -0.3022642316338268, -0.9510565162951535}, 
     {-0.09549150281252636, -0.2938926261462366, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.725, 0.1], 
   Polygon[{{-0.08456530317942934, -0.39784847155511643, \
-0.9135454576426008}, {-0.04251555625535779, -0.4045084971874739, \
-0.9135454576426008}, 
     {-0.03230107154560261, -0.30732416694677983, -0.9510565162951535}, \
{-0.0642482457919175, -0.3022642316338268, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.04251555625535779, -0.4045084971874739, -0.9135454576426008}, 
     {-7.471384161645145*^-17, -0.40673664307580043, -0.9135454576426008}, \
{-5.676362621259818*^-17, -0.3090169943749475, -0.9510565162951535}, 
     {-0.03230107154560261, -0.30732416694677983, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-7.471384161645145*^-17, -0.40673664307580043, \
-0.9135454576426008}, {0.04251555625535729, -0.40450849718747395, 
      -0.9135454576426008}, {0.03230107154560223, -0.3073241669467799, \
-0.9510565162951535}, {-5.676362621259818*^-17, -0.3090169943749475, 
      -0.9510565162951535}}]}, {CMYKColor[0.8833333333333333, 0.5, 0.775, \
0.1], 
   Polygon[{{0.04251555625535729, -0.40450849718747395, -0.9135454576426008}, \
{0.08456530317942884, -0.3978484715551165, -0.9135454576426008}, 
     {0.06424824579191712, -0.3022642316338269, -0.9510565162951535}, \
{0.03230107154560223, -0.3073241669467799, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.7916666666666666, 0.1], \
Polygon[{{0.08456530317942884, -0.3978484715551165, -0.9135454576426008}, 
     {0.12568853494543955, -0.3868295348132561, -0.9135454576426008}, \
{0.09549150281252625, -0.2938926261462367, -0.9510565162951535}, 
     {0.06424824579191712, -0.3022642316338269, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.8083333333333333, 0.1], 
   Polygon[{{0.12568853494543955, -0.3868295348132561, -0.9135454576426008}, \
{0.1654346968205708, -0.3715724127386974, -0.9135454576426008}, 
     {0.12568853494543944, -0.2823010715456025, -0.9510565162951535}, \
{0.09549150281252625, -0.2938926261462367, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.825, 0.1], \
Polygon[{{0.1654346968205708, -0.3715724127386974, -0.9135454576426008}, 
     {0.20336832153789994, -0.35224426555364735, -0.9135454576426008}, \
{0.15450849718747356, -0.26761656732981765, -0.9510565162951535}, 
     {0.12568853494543944, -0.2823010715456025, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.8416666666666667, 0.1], 
   Polygon[{{0.20336832153789994, -0.35224426555364735, -0.9135454576426008}, \
{0.23907380036690287, -0.3290568564833399, -0.9135454576426008}, 
     {0.1816356320013402, -0.2500000000000001, -0.9510565162951535}, \
{0.15450849718747356, -0.26761656732981765, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.8583333333333333, 0.1], \
Polygon[{{0.23907380036690287, -0.3290568564833399, -0.9135454576426008}, 
     {0.27215993660967663, -0.30226423163382704, -0.9135454576426008}, \
{0.20677272882130038, -0.2296443803543194, -0.9510565162951535}, 
     {0.1816356320013402, -0.2500000000000001, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.875, 0.1], 
   Polygon[{{0.27215993660967663, -0.30226423163382704, -0.9135454576426008}, \
{0.30226423163382665, -0.2721599366096771, -0.9135454576426008}, 
     {0.2296443803543191, -0.20677272882130068, -0.9510565162951535}, \
{0.20677272882130038, -0.2296443803543194, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.8916666666666666, 0.1], \
Polygon[{{0.30226423163382665, -0.2721599366096771, -0.9135454576426008}, 
     {0.3290568564833398, -0.23907380036690304, -0.9135454576426008}, \
{0.25000000000000006, -0.18163563200134034, -0.9510565162951535}, 
     {0.2296443803543191, -0.20677272882130068, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9083333333333333, 0.1], 
   Polygon[{{0.3290568564833398, -0.23907380036690304, -0.9135454576426008}, \
{0.3522442655536471, -0.2033683215379004, -0.9135454576426008}, 
     {0.2676165673298174, -0.1545084971874739, -0.9510565162951535}, \
{0.25000000000000006, -0.18163563200134034, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.9249999999999999, 0.1], \
Polygon[{{0.3522442655536471, -0.2033683215379004, -0.9135454576426008}, 
     {0.3715724127386972, -0.16543469682057127, -0.9135454576426008}, \
{0.28230107154560236, -0.1256885349454398, -0.9510565162951535}, 
     {0.2676165673298174, -0.1545084971874739, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.9416666666666667, 0.1], 
   Polygon[{{0.3715724127386972, -0.16543469682057127, -0.9135454576426008}, \
{0.38682953481325605, -0.1256885349454397, -0.9135454576426008}, 
     {0.2938926261462366, -0.09549150281252637, -0.9510565162951535}, \
{0.28230107154560236, -0.1256885349454398, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.9583333333333334, 0.1], \
Polygon[{{0.38682953481325605, -0.1256885349454397, -0.9135454576426008}, 
     {0.39784847155511643, -0.08456530317942937, -0.9135454576426008}, \
{0.3022642316338268, -0.06424824579191753, -0.9510565162951535}, 
     {0.2938926261462366, -0.09549150281252637, -0.9510565162951535}}]}, \
{CMYKColor[0.8833333333333333, 0.5, 0.975, 0.1], 
   Polygon[{{0.39784847155511643, -0.08456530317942937, -0.9135454576426008}, \
{0.4045084971874739, -0.04251555625535782, -0.9135454576426008}, 
     {0.30732416694677983, -0.03230107154560264, -0.9510565162951535}, \
{0.3022642316338268, -0.06424824579191753, -0.9510565162951535}}]}, 
  {CMYKColor[0.8833333333333333, 0.5, 0.9916666666666667, 0.1], \
Polygon[{{0.4045084971874739, -0.04251555625535782, -0.9135454576426008}, 
     {0.40673664307580043, -9.961845548860193*^-17, -0.9135454576426008}, \
{0.3090169943749475, -7.568483495013091*^-17, -0.9510565162951535}, 
     {0.30732416694677983, -0.03230107154560264, -0.9510565162951535}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.3090169943749475, 0., -0.9510565162951535}, \
{0.30732416694677983, 0.032301071545602376, -0.9510565162951535}, 
     {0.20677272882130082, 0.02173268953655992, -0.9781476007338056}, \
{0.20791169081775973, 0., -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.025, 0.1], \
Polygon[{{0.30732416694677983, 0.032301071545602376, -0.9510565162951535}, 
     {0.3022642316338268, 0.06424824579191736, -0.9510565162951535}, \
{0.2033683215379005, 0.04322727117869963, -0.9781476007338056}, 
     {0.20677272882130082, 0.02173268953655992, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.3022642316338268, 0.06424824579191736, -0.9510565162951535}, \
{0.2938926261462366, 0.0954915028125263, -0.9510565162951535}, 
     {0.19773576836617363, 0.06424824579191746, -0.9781476007338056}, \
{0.2033683215379005, 0.04322727117869963, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.058333333333333334, 0.1], \
Polygon[{{0.2938926261462366, 0.0954915028125263, -0.9510565162951535}, 
     {0.2823010715456024, 0.12568853494543958, -0.9510565162951535}, \
{0.18993678073735726, 0.08456530317942926, -0.9781476007338056}, 
     {0.19773576836617363, 0.06424824579191746, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.075, 0.1], 
   Polygon[{{0.2823010715456024, 0.12568853494543958, -0.9510565162951535}, \
{0.26761656732981753, 0.15450849718747373, -0.9510565162951535}, 
     {0.18005680599195575, 0.10395584540887985, -0.9781476007338056}, \
{0.18993678073735726, 0.08456530317942926, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.09166666666666666, 0.1], \
Polygon[{{0.26761656732981753, 0.15450849718747373, -0.9510565162951535}, 
     {0.25000000000000006, 0.18163563200134028, -0.9510565162951535}, \
{0.16820409120079735, 0.12220742564187158, -0.9781476007338056}, 
     {0.18005680599195575, 0.10395584540887985, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.25000000000000006, 0.18163563200134028, -0.9510565162951535}, \
{0.2296443803543193, 0.2067727288213005, -0.9510565162951535}, 
     {0.15450849718747403, 0.139120075745983, -0.9781476007338056}, \
{0.16820409120079735, 0.12220742564187158, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.125, 0.1], \
Polygon[{{0.2296443803543193, 0.2067727288213005, -0.9510565162951535}, 
     {0.20677272882130052, 0.22964438035431925, -0.9510565162951535}, \
{0.13912007574598304, 0.15450849718747398, -0.9781476007338056}, 
     {0.15450849718747403, 0.139120075745983, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.20677272882130052, 0.22964438035431925, -0.9510565162951535}, \
{0.18163563200134028, 0.25000000000000006, -0.9510565162951535}, 
     {0.12220742564187158, 0.16820409120079735, -0.9781476007338056}, \
{0.13912007574598304, 0.15450849718747398, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.15833333333333333, 0.1], \
Polygon[{{0.18163563200134028, 0.25000000000000006, -0.9510565162951535}, 
     {0.15450849718747378, 0.2676165673298175, -0.9510565162951535}, \
{0.1039558454088799, 0.18005680599195573, -0.9781476007338056}, 
     {0.12220742564187158, 0.16820409120079735, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.175, 0.1], 
   Polygon[{{0.15450849718747378, 0.2676165673298175, -0.9510565162951535}, \
{0.12568853494543963, 0.2823010715456024, -0.9510565162951535}, 
     {0.0845653031794293, 0.18993678073735726, -0.9781476007338056}, \
{0.1039558454088799, 0.18005680599195573, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.19166666666666665, 0.1], \
Polygon[{{0.12568853494543963, 0.2823010715456024, -0.9510565162951535}, 
     {0.09549150281252632, 0.2938926261462366, -0.9510565162951535}, \
{0.06424824579191747, 0.19773576836617363, -0.9781476007338056}, 
     {0.0845653031794293, 0.18993678073735726, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.09549150281252632, 0.2938926261462366, -0.9510565162951535}, \
{0.0642482457919174, 0.3022642316338268, -0.9510565162951535}, 
     {0.04322727117869966, 0.20336832153790046, -0.9781476007338056}, \
{0.06424824579191747, 0.19773576836617363, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.225, 0.1], \
Polygon[{{0.0642482457919174, 0.3022642316338268, -0.9510565162951535}, 
     {0.032301071545602446, 0.30732416694677983, -0.9510565162951535}, \
{0.021732689536559966, 0.20677272882130082, -0.9781476007338056}, 
     {0.04322727117869966, 0.20336832153790046, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.032301071545602446, 0.30732416694677983, -0.9510565162951535}, \
{1.8921208737532727*^-17, 0.3090169943749475, -0.9510565162951535}, 
     {1.273049888046911*^-17, 0.20791169081775973, -0.9781476007338056}, \
{0.021732689536559966, 0.20677272882130082, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.2583333333333333, 0.1], \
Polygon[{{1.8921208737532727*^-17, 0.3090169943749475, -0.9510565162951535}, 
     {-0.032301071545602335, 0.3073241669467799, -0.9510565162951535}, \
{-0.021732689536559893, 0.20677272882130085, -0.9781476007338056}, 
     {1.273049888046911*^-17, 0.20791169081775973, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.275, 0.1], 
   Polygon[{{-0.032301071545602335, 0.3073241669467799, -0.9510565162951535}, \
{-0.06424824579191729, 0.3022642316338268, -0.9510565162951535}, 
     {-0.04322727117869959, 0.2033683215379005, -0.9781476007338056}, \
{-0.021732689536559893, 0.20677272882130085, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.2916666666666667, 0.1], \
Polygon[{{-0.06424824579191729, 0.3022642316338268, -0.9510565162951535}, 
     {-0.09549150281252629, 0.2938926261462367, -0.9510565162951535}, \
{-0.06424824579191744, 0.19773576836617365, -0.9781476007338056}, 
     {-0.04322727117869959, 0.2033683215379005, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.09549150281252629, 0.2938926261462367, -0.9510565162951535}, \
{-0.12568853494543952, 0.28230107154560247, -0.9510565162951535}, 
     {-0.08456530317942923, 0.18993678073735729, -0.9781476007338056}, \
{-0.06424824579191744, 0.19773576836617365, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.325, 0.1], \
Polygon[{{-0.12568853494543952, 0.28230107154560247, -0.9510565162951535}, 
     {-0.1545084971874737, 0.26761656732981753, -0.9510565162951535}, \
{-0.10395584540887982, 0.18005680599195575, -0.9781476007338056}, 
     {-0.08456530317942923, 0.18993678073735729, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.1545084971874737, 0.26761656732981753, -0.9510565162951535}, \
{-0.18163563200134022, 0.25000000000000006, -0.9510565162951535}, 
     {-0.12220742564187155, 0.16820409120079735, -0.9781476007338056}, \
{-0.10395584540887982, 0.18005680599195575, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.35833333333333334, 0.1], \
Polygon[{{-0.18163563200134022, 0.25000000000000006, -0.9510565162951535}, 
     {-0.2067727288213004, 0.22964438035431936, -0.9510565162951535}, \
{-0.13912007574598295, 0.15450849718747406, -0.9781476007338056}, 
     {-0.12220742564187155, 0.16820409120079735, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.375, 0.1], 
   Polygon[{{-0.2067727288213004, 0.22964438035431936, -0.9510565162951535}, \
{-0.22964438035431922, 0.20677272882130054, -0.9510565162951535}, 
     {-0.15450849718747395, 0.13912007574598306, -0.9781476007338056}, \
{-0.13912007574598295, 0.15450849718747406, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.39166666666666666, 0.1], \
Polygon[{{-0.22964438035431922, 0.20677272882130054, -0.9510565162951535}, 
     {-0.25000000000000006, 0.1816356320013403, -0.9510565162951535}, \
{-0.16820409120079732, 0.12220742564187159, -0.9781476007338056}, 
     {-0.15450849718747395, 0.13912007574598306, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.25000000000000006, 0.1816356320013403, -0.9510565162951535}, \
{-0.2676165673298175, 0.15450849718747386, -0.9510565162951535}, 
     {-0.1800568059919557, 0.10395584540887993, -0.9781476007338056}, \
{-0.16820409120079732, 0.12220742564187159, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.425, 0.1], \
Polygon[{{-0.2676165673298175, 0.15450849718747386, -0.9510565162951535}, 
     {-0.2823010715456024, 0.12568853494543966, -0.9510565162951535}, \
{-0.18993678073735723, 0.08456530317942931, -0.9781476007338056}, 
     {-0.1800568059919557, 0.10395584540887993, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.2823010715456024, 0.12568853494543966, -0.9510565162951535}, \
{-0.2938926261462366, 0.09549150281252634, -0.9510565162951535}, 
     {-0.19773576836617363, 0.06424824579191749, -0.9781476007338056}, \
{-0.18993678073735723, 0.08456530317942931, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.4583333333333333, 0.1], \
Polygon[{{-0.2938926261462366, 0.09549150281252634, -0.9510565162951535}, 
     {-0.3022642316338268, 0.06424824579191749, -0.9510565162951535}, \
{-0.20336832153790046, 0.04322727117869972, -0.9781476007338056}, 
     {-0.19773576836617363, 0.06424824579191749, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.475, 0.1], 
   Polygon[{{-0.3022642316338268, 0.06424824579191749, -0.9510565162951535}, \
{-0.30732416694677983, 0.03230107154560246, -0.9510565162951535}, 
     {-0.20677272882130082, 0.02173268953655998, -0.9781476007338056}, \
{-0.20336832153790046, 0.04322727117869972, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.49166666666666664, 0.1], \
Polygon[{{-0.30732416694677983, 0.03230107154560246, -0.9510565162951535}, 
     {-0.3090169943749475, 3.7842417475065455*^-17, -0.9510565162951535}, \
{-0.20791169081775973, 2.546099776093822*^-17, -0.9781476007338056}, 
     {-0.20677272882130082, 0.02173268953655998, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.3090169943749475, 3.7842417475065455*^-17, \
-0.9510565162951535}, {-0.3073241669467799, -0.03230107154560225, \
-0.9510565162951535}, 
     {-0.20677272882130085, -0.021732689536559838, -0.9781476007338056}, \
{-0.20791169081775973, 2.546099776093822*^-17, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.525, 0.1], \
Polygon[{{-0.3073241669467799, -0.03230107154560225, -0.9510565162951535}, 
     {-0.3022642316338268, -0.06424824579191728, -0.9510565162951535}, \
{-0.2033683215379005, -0.04322727117869958, -0.9781476007338056}, 
     {-0.20677272882130085, -0.021732689536559838, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-0.3022642316338268, -0.06424824579191728, -0.9510565162951535}, \
{-0.2938926261462367, -0.09549150281252627, -0.9510565162951535}, 
     {-0.19773576836617365, -0.06424824579191744, -0.9781476007338056}, \
{-0.2033683215379005, -0.04322727117869958, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.5583333333333333, 0.1], \
Polygon[{{-0.2938926261462367, -0.09549150281252627, -0.9510565162951535}, 
     {-0.2823010715456025, -0.12568853494543947, -0.9510565162951535}, \
{-0.18993678073735729, -0.08456530317942919, -0.9781476007338056}, 
     {-0.19773576836617365, -0.06424824579191744, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.575, 0.1], 
   Polygon[{{-0.2823010715456025, -0.12568853494543947, -0.9510565162951535}, \
{-0.2676165673298176, -0.15450849718747367, -0.9510565162951535}, 
     {-0.18005680599195578, -0.10395584540887981, -0.9781476007338056}, \
{-0.18993678073735729, -0.08456530317942919, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.5916666666666667, 0.1], \
Polygon[{{-0.2676165673298176, -0.15450849718747367, -0.9510565162951535}, 
     {-0.2500000000000001, -0.18163563200134022, -0.9510565162951535}, \
{-0.16820409120079735, -0.12220742564187155, -0.9781476007338056}, 
     {-0.18005680599195578, -0.10395584540887981, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-0.2500000000000001, -0.18163563200134022, -0.9510565162951535}, \
{-0.2296443803543194, -0.2067727288213004, -0.9510565162951535}, 
     {-0.1545084971874741, -0.13912007574598295, -0.9781476007338056}, \
{-0.16820409120079735, -0.12220742564187155, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.625, 0.1], \
Polygon[{{-0.2296443803543194, -0.2067727288213004, -0.9510565162951535}, 
     {-0.20677272882130057, -0.22964438035431922, -0.9510565162951535}, \
{-0.13912007574598306, -0.15450849718747395, -0.9781476007338056}, 
     {-0.1545084971874741, -0.13912007574598295, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{-0.20677272882130057, -0.22964438035431922, \
-0.9510565162951535}, {-0.1816356320013403, -0.25000000000000006, \
-0.9510565162951535}, 
     {-0.12220742564187159, -0.16820409120079732, -0.9781476007338056}, \
{-0.13912007574598306, -0.15450849718747395, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.6583333333333333, 0.1], \
Polygon[{{-0.1816356320013403, -0.25000000000000006, -0.9510565162951535}, 
     {-0.1545084971874739, -0.2676165673298174, -0.9510565162951535}, \
{-0.10395584540887996, -0.18005680599195567, -0.9781476007338056}, 
     {-0.12220742564187159, -0.16820409120079732, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.675, 0.1], 
   Polygon[{{-0.1545084971874739, -0.2676165673298174, -0.9510565162951535}, \
{-0.1256885349454398, -0.28230107154560236, -0.9510565162951535}, 
     {-0.08456530317942941, -0.18993678073735717, -0.9781476007338056}, \
{-0.10395584540887996, -0.18005680599195567, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.6916666666666667, 0.1], \
Polygon[{{-0.1256885349454398, -0.28230107154560236, -0.9510565162951535}, 
     {-0.09549150281252636, -0.2938926261462366, -0.9510565162951535}, \
{-0.0642482457919175, -0.19773576836617363, -0.9781476007338056}, 
     {-0.08456530317942941, -0.18993678073735717, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.09549150281252636, -0.2938926261462366, -0.9510565162951535}, \
{-0.0642482457919175, -0.3022642316338268, -0.9510565162951535}, 
     {-0.043227271178699726, -0.20336832153790046, -0.9781476007338056}, \
{-0.0642482457919175, -0.19773576836617363, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.725, 0.1], \
Polygon[{{-0.0642482457919175, -0.3022642316338268, -0.9510565162951535}, 
     {-0.03230107154560261, -0.30732416694677983, -0.9510565162951535}, \
{-0.02173268953656008, -0.20677272882130082, -0.9781476007338056}, 
     {-0.043227271178699726, -0.20336832153790046, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.03230107154560261, -0.30732416694677983, \
-0.9510565162951535}, {-5.676362621259818*^-17, -0.3090169943749475, 
      -0.9510565162951535}, {-3.819149664140733*^-17, -0.20791169081775973, \
-0.9781476007338056}, 
     {-0.02173268953656008, -0.20677272882130082, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-5.676362621259818*^-17, -0.3090169943749475, \
-0.9510565162951535}, {0.03230107154560223, -0.3073241669467799, \
-0.9510565162951535}, 
     {0.021732689536559824, -0.20677272882130085, -0.9781476007338056}, \
{-3.819149664140733*^-17, -0.20791169081775973, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.775, 0.1], \
Polygon[{{0.03230107154560223, -0.3073241669467799, -0.9510565162951535}, 
     {0.06424824579191712, -0.3022642316338269, -0.9510565162951535}, \
{0.043227271178699476, -0.20336832153790052, -0.9781476007338056}, 
     {0.021732689536559824, -0.20677272882130085, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.06424824579191712, -0.3022642316338269, -0.9510565162951535}, \
{0.09549150281252625, -0.2938926261462367, -0.9510565162951535}, 
     {0.06424824579191743, -0.19773576836617365, -0.9781476007338056}, \
{0.043227271178699476, -0.20336832153790052, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.09549150281252625, -0.2938926261462367, -0.9510565162951535}, 
     {0.12568853494543944, -0.2823010715456025, -0.9510565162951535}, \
{0.08456530317942917, -0.18993678073735729, -0.9781476007338056}, 
     {0.06424824579191743, -0.19773576836617365, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.825, 0.1], 
   Polygon[{{0.12568853494543944, -0.2823010715456025, -0.9510565162951535}, \
{0.15450849718747356, -0.26761656732981765, -0.9510565162951535}, 
     {0.10395584540887973, -0.1800568059919558, -0.9781476007338056}, \
{0.08456530317942917, -0.18993678073735729, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.15450849718747356, -0.26761656732981765, -0.9510565162951535}, 
     {0.1816356320013402, -0.2500000000000001, -0.9510565162951535}, \
{0.12220742564187152, -0.16820409120079735, -0.9781476007338056}, 
     {0.10395584540887973, -0.1800568059919558, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.1816356320013402, -0.2500000000000001, -0.9510565162951535}, \
{0.20677272882130038, -0.2296443803543194, -0.9510565162951535}, 
     {0.13912007574598292, -0.1545084971874741, -0.9781476007338056}, \
{0.12220742564187152, -0.16820409120079735, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.875, 0.1], \
Polygon[{{0.20677272882130038, -0.2296443803543194, -0.9510565162951535}, 
     {0.2296443803543191, -0.20677272882130068, -0.9510565162951535}, \
{0.1545084971874739, -0.13912007574598315, -0.9781476007338056}, 
     {0.13912007574598292, -0.1545084971874741, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.2296443803543191, -0.20677272882130068, -0.9510565162951535}, \
{0.25000000000000006, -0.18163563200134034, -0.9510565162951535}, 
     {0.16820409120079732, -0.12220742564187162, -0.9781476007338056}, \
{0.1545084971874739, -0.13912007574598315, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.25000000000000006, -0.18163563200134034, -0.9510565162951535}, 
     {0.2676165673298174, -0.1545084971874739, -0.9510565162951535}, \
{0.18005680599195567, -0.10395584540887996, -0.9781476007338056}, 
     {0.16820409120079732, -0.12220742564187162, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.2676165673298174, -0.1545084971874739, -0.9510565162951535}, \
{0.28230107154560236, -0.1256885349454398, -0.9510565162951535}, 
     {0.18993678073735717, -0.08456530317942942, -0.9781476007338056}, \
{0.18005680599195567, -0.10395584540887996, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.28230107154560236, -0.1256885349454398, -0.9510565162951535}, 
     {0.2938926261462366, -0.09549150281252637, -0.9510565162951535}, \
{0.19773576836617363, -0.06424824579191751, -0.9781476007338056}, 
     {0.18993678073735717, -0.08456530317942942, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.2938926261462366, -0.09549150281252637, -0.9510565162951535}, \
{0.3022642316338268, -0.06424824579191753, -0.9510565162951535}, 
     {0.20336832153790046, -0.04322727117869975, -0.9781476007338056}, \
{0.19773576836617363, -0.06424824579191751, -0.9781476007338056}}]}, 
  {CMYKColor[0.9166666666666666, 0.5, 0.975, 0.1], \
Polygon[{{0.3022642316338268, -0.06424824579191753, -0.9510565162951535}, 
     {0.30732416694677983, -0.03230107154560264, -0.9510565162951535}, \
{0.20677272882130082, -0.021732689536560098, -0.9781476007338056}, 
     {0.20336832153790046, -0.04322727117869975, -0.9781476007338056}}]}, \
{CMYKColor[0.9166666666666666, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.30732416694677983, -0.03230107154560264, -0.9510565162951535}, \
{0.3090169943749475, -7.568483495013091*^-17, -0.9510565162951535}, 
     {0.20791169081775973, -5.092199552187644*^-17, -0.9781476007338056}, \
{0.20677272882130082, -0.021732689536560098, -0.9781476007338056}}]}, 
  {CMYKColor[0.95, 0.5, 0.008333333333333333, 0.1], \
Polygon[{{0.20791169081775973, 0., -0.9781476007338056}, 
     {0.20677272882130082, 0.02173268953655992, -0.9781476007338056}, \
{0.10395584540887992, 0.010926199633097208, -0.9945218953682733}, 
     {0.10452846326765373, 0., -0.9945218953682733}}]}, {CMYKColor[0.95, 0.5, \
0.025, 0.1], 
   Polygon[{{0.20677272882130082, 0.02173268953655992, -0.9781476007338056}, \
{0.2033683215379005, 0.04322727117869963, -0.9781476007338056}, 
     {0.10224426555364724, 0.021732689536559935, -0.9945218953682733}, \
{0.10395584540887992, 0.010926199633097208, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.041666666666666664, 0.1], \
Polygon[{{0.2033683215379005, 0.04322727117869963, -0.9781476007338056}, 
     {0.19773576836617363, 0.06424824579191746, -0.9781476007338056}, \
{0.09941247612902068, 0.03230107154560245, -0.9945218953682733}, 
     {0.10224426555364724, 0.021732689536559935, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.058333333333333334, 0.1], 
   Polygon[{{0.19773576836617363, 0.06424824579191746, -0.9781476007338056}, \
{0.18993678073735726, 0.08456530317942926, -0.9781476007338056}, 
     {0.09549150281252652, 0.042515556255357564, -0.9945218953682733}, \
{0.09941247612902068, 0.03230107154560245, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.075, 0.1], Polygon[{{0.18993678073735726, \
0.08456530317942926, -0.9781476007338056}, 
     {0.18005680599195575, 0.10395584540887985, -0.9781476007338056}, \
{0.0905243046083367, 0.05226423163382686, -0.9945218953682733}, 
     {0.09549150281252652, 0.042515556255357564, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.09166666666666666, 0.1], 
   Polygon[{{0.18005680599195575, 0.10395584540887985, -0.9781476007338056}, \
{0.16820409120079735, 0.12220742564187158, -0.9781476007338056}, 
     {0.08456530317942933, 0.061440289153522364, -0.9945218953682733}, \
{0.0905243046083367, 0.05226423163382686, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.10833333333333334, 0.1], \
Polygon[{{0.16820409120079735, 0.12220742564187158, -0.9781476007338056}, 
     {0.15450849718747403, 0.139120075745983, -0.9781476007338056}, \
{0.07767978659246076, 0.06994319400804477, -0.9945218953682733}, 
     {0.08456530317942933, 0.061440289153522364, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.125, 0.1], 
   Polygon[{{0.15450849718747403, 0.139120075745983, -0.9781476007338056}, \
{0.13912007574598304, 0.15450849718747398, -0.9781476007338056}, 
     {0.06994319400804479, 0.07767978659246073, -0.9945218953682733}, \
{0.07767978659246076, 0.06994319400804477, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.14166666666666666, 0.1], \
Polygon[{{0.13912007574598304, 0.15450849718747398, -0.9781476007338056}, 
     {0.12220742564187158, 0.16820409120079735, -0.9781476007338056}, \
{0.061440289153522364, 0.08456530317942933, -0.9945218953682733}, 
     {0.06994319400804479, 0.07767978659246073, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.15833333333333333, 0.1], 
   Polygon[{{0.12220742564187158, 0.16820409120079735, -0.9781476007338056}, \
{0.1039558454088799, 0.18005680599195573, -0.9781476007338056}, 
     {0.05226423163382688, 0.09052430460833669, -0.9945218953682733}, \
{0.061440289153522364, 0.08456530317942933, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.175, 0.1], Polygon[{{0.1039558454088799, \
0.18005680599195573, -0.9781476007338056}, 
     {0.0845653031794293, 0.18993678073735726, -0.9781476007338056}, \
{0.042515556255357585, 0.09549150281252652, -0.9945218953682733}, 
     {0.05226423163382688, 0.09052430460833669, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.19166666666666665, 0.1], 
   Polygon[{{0.0845653031794293, 0.18993678073735726, -0.9781476007338056}, \
{0.06424824579191747, 0.19773576836617363, -0.9781476007338056}, 
     {0.03230107154560245, 0.09941247612902068, -0.9945218953682733}, \
{0.042515556255357585, 0.09549150281252652, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.20833333333333334, 0.1], \
Polygon[{{0.06424824579191747, 0.19773576836617363, -0.9781476007338056}, 
     {0.04322727117869966, 0.20336832153790046, -0.9781476007338056}, \
{0.02173268953655995, 0.10224426555364723, -0.9945218953682733}, 
     {0.03230107154560245, 0.09941247612902068, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.225, 0.1], 
   Polygon[{{0.04322727117869966, 0.20336832153790046, -0.9781476007338056}, \
{0.021732689536559966, 0.20677272882130082, -0.9781476007338056}, 
     {0.01092619963309723, 0.10395584540887992, -0.9945218953682733}, \
{0.02173268953655995, 0.10224426555364723, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.24166666666666667, 0.1], \
Polygon[{{0.021732689536559966, 0.20677272882130082, -0.9781476007338056}, 
     {1.273049888046911*^-17, 0.20791169081775973, -0.9781476007338056}, \
{6.400311013642887*^-18, 0.10452846326765373, -0.9945218953682733}, 
     {0.01092619963309723, 0.10395584540887992, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.2583333333333333, 0.1], 
   Polygon[{{1.273049888046911*^-17, 0.20791169081775973, \
-0.9781476007338056}, {-0.021732689536559893, 0.20677272882130085, \
-0.9781476007338056}, 
     {-0.010926199633097194, 0.10395584540887993, -0.9945218953682733}, \
{6.400311013642887*^-18, 0.10452846326765373, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.275, 0.1], Polygon[{{-0.021732689536559893, \
0.20677272882130085, -0.9781476007338056}, 
     {-0.04322727117869959, 0.2033683215379005, -0.9781476007338056}, \
{-0.021732689536559914, 0.10224426555364724, -0.9945218953682733}, 
     {-0.010926199633097194, 0.10395584540887993, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.2916666666666667, 0.1], 
   Polygon[{{-0.04322727117869959, 0.2033683215379005, -0.9781476007338056}, \
{-0.06424824579191744, 0.19773576836617365, -0.9781476007338056}, 
     {-0.032301071545602446, 0.0994124761290207, -0.9945218953682733}, \
{-0.021732689536559914, 0.10224426555364724, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.30833333333333335, 0.1], \
Polygon[{{-0.06424824579191744, 0.19773576836617365, -0.9781476007338056}, 
     {-0.08456530317942923, 0.18993678073735729, -0.9781476007338056}, \
{-0.04251555625535755, 0.09549150281252654, -0.9945218953682733}, 
     {-0.032301071545602446, 0.0994124761290207, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.325, 0.1], 
   Polygon[{{-0.08456530317942923, 0.18993678073735729, -0.9781476007338056}, \
{-0.10395584540887982, 0.18005680599195575, -0.9781476007338056}, 
     {-0.052264231633826846, 0.0905243046083367, -0.9945218953682733}, \
{-0.04251555625535755, 0.09549150281252654, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.3416666666666667, 0.1], \
Polygon[{{-0.10395584540887982, 0.18005680599195575, -0.9781476007338056}, 
     {-0.12220742564187155, 0.16820409120079735, -0.9781476007338056}, \
{-0.06144028915352235, 0.08456530317942933, -0.9945218953682733}, 
     {-0.052264231633826846, 0.0905243046083367, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.35833333333333334, 0.1], 
   Polygon[{{-0.12220742564187155, 0.16820409120079735, -0.9781476007338056}, \
{-0.13912007574598295, 0.15450849718747406, -0.9781476007338056}, 
     {-0.06994319400804475, 0.07767978659246078, -0.9945218953682733}, \
{-0.06144028915352235, 0.08456530317942933, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.375, 0.1], Polygon[{{-0.13912007574598295, \
0.15450849718747406, -0.9781476007338056}, 
     {-0.15450849718747395, 0.13912007574598306, -0.9781476007338056}, \
{-0.07767978659246072, 0.0699431940080448, -0.9945218953682733}, 
     {-0.06994319400804475, 0.07767978659246078, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.39166666666666666, 0.1], 
   Polygon[{{-0.15450849718747395, 0.13912007574598306, -0.9781476007338056}, \
{-0.16820409120079732, 0.12220742564187159, -0.9781476007338056}, 
     {-0.08456530317942931, 0.06144028915352237, -0.9945218953682733}, \
{-0.07767978659246072, 0.0699431940080448, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.4083333333333333, 0.1], \
Polygon[{{-0.16820409120079732, 0.12220742564187159, -0.9781476007338056}, 
     {-0.1800568059919557, 0.10395584540887993, -0.9781476007338056}, \
{-0.09052430460833667, 0.0522642316338269, -0.9945218953682733}, 
     {-0.08456530317942931, 0.06144028915352237, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.425, 0.1], 
   Polygon[{{-0.1800568059919557, 0.10395584540887993, -0.9781476007338056}, \
{-0.18993678073735723, 0.08456530317942931, -0.9781476007338056}, 
     {-0.09549150281252651, 0.04251555625535759, -0.9945218953682733}, \
{-0.09052430460833667, 0.0522642316338269, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.44166666666666665, 0.1], \
Polygon[{{-0.18993678073735723, 0.08456530317942931, -0.9781476007338056}, 
     {-0.19773576836617363, 0.06424824579191749, -0.9781476007338056}, \
{-0.09941247612902068, 0.03230107154560246, -0.9945218953682733}, 
     {-0.09549150281252651, 0.04251555625535759, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.4583333333333333, 0.1], 
   Polygon[{{-0.19773576836617363, 0.06424824579191749, -0.9781476007338056}, \
{-0.20336832153790046, 0.04322727117869972, -0.9781476007338056}, 
     {-0.10224426555364723, 0.02173268953655998, -0.9945218953682733}, \
{-0.09941247612902068, 0.03230107154560246, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.475, 0.1], Polygon[{{-0.20336832153790046, \
0.04322727117869972, -0.9781476007338056}, 
     {-0.20677272882130082, 0.02173268953655998, -0.9781476007338056}, \
{-0.10395584540887992, 0.010926199633097235, -0.9945218953682733}, 
     {-0.10224426555364723, 0.02173268953655998, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.49166666666666664, 0.1], 
   Polygon[{{-0.20677272882130082, 0.02173268953655998, -0.9781476007338056}, \
{-0.20791169081775973, 2.546099776093822*^-17, -0.9781476007338056}, 
     {-0.10452846326765373, 1.2800622027285774*^-17, -0.9945218953682733}, \
{-0.10395584540887992, 0.010926199633097235, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.5083333333333333, 0.1], \
Polygon[{{-0.20791169081775973, 2.546099776093822*^-17, -0.9781476007338056}, \

     {-0.20677272882130085, -0.021732689536559838, -0.9781476007338056}, \
{-0.10395584540887993, -0.010926199633097164, -0.9945218953682733}, 
     {-0.10452846326765373, 1.2800622027285774*^-17, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.525, 0.1], 
   Polygon[{{-0.20677272882130085, -0.021732689536559838, \
-0.9781476007338056}, {-0.2033683215379005, -0.04322727117869958, \
-0.9781476007338056}, 
     {-0.10224426555364724, -0.021732689536559907, -0.9945218953682733}, \
{-0.10395584540887993, -0.010926199633097164, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.5416666666666666, 0.1], \
Polygon[{{-0.2033683215379005, -0.04322727117869958, -0.9781476007338056}, 
     {-0.19773576836617365, -0.06424824579191744, -0.9781476007338056}, \
{-0.0994124761290207, -0.03230107154560244, -0.9945218953682733}, 
     {-0.10224426555364724, -0.021732689536559907, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.5583333333333333, 0.1], 
   Polygon[{{-0.19773576836617365, -0.06424824579191744, \
-0.9781476007338056}, {-0.18993678073735729, -0.08456530317942919, \
-0.9781476007338056}, 
     {-0.09549150281252655, -0.04251555625535753, -0.9945218953682733}, \
{-0.0994124761290207, -0.03230107154560244, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.575, 0.1], Polygon[{{-0.18993678073735729, \
-0.08456530317942919, -0.9781476007338056}, 
     {-0.18005680599195578, -0.10395584540887981, -0.9781476007338056}, \
{-0.0905243046083367, -0.05226423163382684, -0.9945218953682733}, 
     {-0.09549150281252655, -0.04251555625535753, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.5916666666666667, 0.1], 
   Polygon[{{-0.18005680599195578, -0.10395584540887981, \
-0.9781476007338056}, {-0.16820409120079735, -0.12220742564187155, \
-0.9781476007338056}, 
     {-0.08456530317942934, -0.06144028915352235, -0.9945218953682733}, \
{-0.0905243046083367, -0.05226423163382684, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.6083333333333333, 0.1], \
Polygon[{{-0.16820409120079735, -0.12220742564187155, -0.9781476007338056}, 
     {-0.1545084971874741, -0.13912007574598295, -0.9781476007338056}, \
{-0.07767978659246079, -0.06994319400804475, -0.9945218953682733}, 
     {-0.08456530317942934, -0.06144028915352235, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.625, 0.1], 
   Polygon[{{-0.1545084971874741, -0.13912007574598295, -0.9781476007338056}, \
{-0.13912007574598306, -0.15450849718747395, -0.9781476007338056}, 
     {-0.0699431940080448, -0.07767978659246072, -0.9945218953682733}, \
{-0.07767978659246079, -0.06994319400804475, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.6416666666666666, 0.1], \
Polygon[{{-0.13912007574598306, -0.15450849718747395, -0.9781476007338056}, 
     {-0.12220742564187159, -0.16820409120079732, -0.9781476007338056}, \
{-0.06144028915352237, -0.08456530317942931, -0.9945218953682733}, 
     {-0.0699431940080448, -0.07767978659246072, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.6583333333333333, 0.1], 
   Polygon[{{-0.12220742564187159, -0.16820409120079732, \
-0.9781476007338056}, {-0.10395584540887996, -0.18005680599195567, \
-0.9781476007338056}, 
     {-0.052264231633826916, -0.09052430460833666, -0.9945218953682733}, \
{-0.06144028915352237, -0.08456530317942931, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.675, 0.1], Polygon[{{-0.10395584540887996, \
-0.18005680599195567, -0.9781476007338056}, 
     {-0.08456530317942941, -0.18993678073735717, -0.9781476007338056}, \
{-0.04251555625535764, -0.0954915028125265, -0.9945218953682733}, 
     {-0.052264231633826916, -0.09052430460833666, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.6916666666666667, 0.1], 
   Polygon[{{-0.08456530317942941, -0.18993678073735717, \
-0.9781476007338056}, {-0.0642482457919175, -0.19773576836617363, \
-0.9781476007338056}, 
     {-0.03230107154560247, -0.09941247612902068, -0.9945218953682733}, \
{-0.04251555625535764, -0.0954915028125265, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.7083333333333334, 0.1], \
Polygon[{{-0.0642482457919175, -0.19773576836617363, -0.9781476007338056}, 
     {-0.043227271178699726, -0.20336832153790046, -0.9781476007338056}, \
{-0.021732689536559983, -0.10224426555364723, -0.9945218953682733}, 
     {-0.03230107154560247, -0.09941247612902068, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.725, 0.1], 
   Polygon[{{-0.043227271178699726, -0.20336832153790046, \
-0.9781476007338056}, {-0.02173268953656008, -0.20677272882130082, \
-0.9781476007338056}, 
     {-0.010926199633097287, -0.10395584540887992, -0.9945218953682733}, \
{-0.021732689536559983, -0.10224426555364723, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.7416666666666667, 0.1], \
Polygon[{{-0.02173268953656008, -0.20677272882130082, -0.9781476007338056}, 
     {-3.819149664140733*^-17, -0.20791169081775973, -0.9781476007338056}, \
{-1.920093304092866*^-17, -0.10452846326765373, -0.9945218953682733}, 
     {-0.010926199633097287, -0.10395584540887992, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-3.819149664140733*^-17, -0.20791169081775973, \
-0.9781476007338056}, {0.021732689536559824, -0.20677272882130085, 
      -0.9781476007338056}, {0.010926199633097157, -0.10395584540887993, \
-0.9945218953682733}, {-1.920093304092866*^-17, -0.10452846326765373, 
      -0.9945218953682733}}]}, {CMYKColor[0.95, 0.5, 0.775, 0.1], \
Polygon[{{0.021732689536559824, -0.20677272882130085, -0.9781476007338056}, 
     {0.043227271178699476, -0.20336832153790052, -0.9781476007338056}, \
{0.021732689536559855, -0.10224426555364725, -0.9945218953682733}, 
     {0.010926199633097157, -0.10395584540887993, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.043227271178699476, -0.20336832153790052, \
-0.9781476007338056}, {0.06424824579191743, -0.19773576836617365, \
-0.9781476007338056}, 
     {0.03230107154560243, -0.0994124761290207, -0.9945218953682733}, \
{0.021732689536559855, -0.10224426555364725, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.06424824579191743, -0.19773576836617365, -0.9781476007338056}, 
     {0.08456530317942917, -0.18993678073735729, -0.9781476007338056}, \
{0.04251555625535752, -0.09549150281252655, -0.9945218953682733}, 
     {0.03230107154560243, -0.0994124761290207, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.825, 0.1], 
   Polygon[{{0.08456530317942917, -0.18993678073735729, -0.9781476007338056}, \
{0.10395584540887973, -0.1800568059919558, -0.9781476007338056}, 
     {0.0522642316338268, -0.09052430460833673, -0.9945218953682733}, \
{0.04251555625535752, -0.09549150281252655, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.10395584540887973, -0.1800568059919558, -0.9781476007338056}, 
     {0.12220742564187152, -0.16820409120079735, -0.9781476007338056}, \
{0.061440289153522336, -0.08456530317942934, -0.9945218953682733}, 
     {0.0522642316338268, -0.09052430460833673, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.12220742564187152, -0.16820409120079735, -0.9781476007338056}, \
{0.13912007574598292, -0.1545084971874741, -0.9781476007338056}, 
     {0.06994319400804473, -0.07767978659246079, -0.9945218953682733}, \
{0.061440289153522336, -0.08456530317942934, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.875, 0.1], Polygon[{{0.13912007574598292, \
-0.1545084971874741, -0.9781476007338056}, 
     {0.1545084971874739, -0.13912007574598315, -0.9781476007338056}, \
{0.07767978659246069, -0.06994319400804484, -0.9945218953682733}, 
     {0.06994319400804473, -0.07767978659246079, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.1545084971874739, -0.13912007574598315, -0.9781476007338056}, \
{0.16820409120079732, -0.12220742564187162, -0.9781476007338056}, 
     {0.08456530317942931, -0.061440289153522384, -0.9945218953682733}, \
{0.07767978659246069, -0.06994319400804484, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.16820409120079732, -0.12220742564187162, -0.9781476007338056}, 
     {0.18005680599195567, -0.10395584540887996, -0.9781476007338056}, \
{0.09052430460833666, -0.052264231633826916, -0.9945218953682733}, 
     {0.08456530317942931, -0.061440289153522384, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.18005680599195567, -0.10395584540887996, -0.9781476007338056}, \
{0.18993678073735717, -0.08456530317942942, -0.9781476007338056}, 
     {0.0954915028125265, -0.04251555625535765, -0.9945218953682733}, \
{0.09052430460833666, -0.052264231633826916, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.18993678073735717, -0.08456530317942942, -0.9781476007338056}, 
     {0.19773576836617363, -0.06424824579191751, -0.9781476007338056}, \
{0.09941247612902068, -0.032301071545602474, -0.9945218953682733}, 
     {0.0954915028125265, -0.04251555625535765, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.19773576836617363, -0.06424824579191751, -0.9781476007338056}, \
{0.20336832153790046, -0.04322727117869975, -0.9781476007338056}, 
     {0.10224426555364723, -0.021732689536559994, -0.9945218953682733}, \
{0.09941247612902068, -0.032301071545602474, -0.9945218953682733}}]}, 
  {CMYKColor[0.95, 0.5, 0.975, 0.1], Polygon[{{0.20336832153790046, \
-0.04322727117869975, -0.9781476007338056}, 
     {0.20677272882130082, -0.021732689536560098, -0.9781476007338056}, \
{0.10395584540887992, -0.010926199633097296, -0.9945218953682733}, 
     {0.10224426555364723, -0.021732689536559994, -0.9945218953682733}}]}, \
{CMYKColor[0.95, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.20677272882130082, -0.021732689536560098, \
-0.9781476007338056}, {0.20791169081775973, -5.092199552187644*^-17, 
      -0.9781476007338056}, {0.10452846326765373, -2.5601244054571548*^-17, \
-0.9945218953682733}, 
     {0.10395584540887992, -0.010926199633097296, -0.9945218953682733}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.008333333333333333, 0.1], 
   Polygon[{{0.10452846326765373, 0., -0.9945218953682733}, \
{0.10395584540887992, 0.010926199633097208, -0.9945218953682733}, 
     {1.217897832083461*^-16, 1.280062202728574*^-17, -1.}, \
{1.2246063538223773*^-16, 0., -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.025, 0.1], \
Polygon[{{0.10395584540887992, 0.010926199633097208, -0.9945218953682733}, 
     {0.10224426555364724, 0.021732689536559935, -0.9945218953682733}, \
{1.1978457668347324*^-16, 2.5460997760938166*^-17, -1.}, 
     {1.217897832083461*^-16, 1.280062202728574*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.041666666666666664, 0.1], 
   Polygon[{{0.10224426555364724, 0.021732689536559935, -0.9945218953682733}, \
{0.09941247612902068, 0.03230107154560245, -0.9945218953682733}, 
     {1.1646698526992202*^-16, 3.784241747506544*^-17, -1.}, \
{1.1978457668347324*^-16, 2.5460997760938166*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.058333333333333334, 0.1], \
Polygon[{{0.09941247612902068, 0.03230107154560245, -0.9945218953682733}, 
     {0.09549150281252652, 0.042515556255357564, -0.9945218953682733}, \
{1.1187335719347004*^-16, 4.980922774430093*^-17, -1.}, 
     {1.1646698526992202*^-16, 3.784241747506544*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.075, 0.1], 
   Polygon[{{0.09549150281252652, 0.042515556255357564, -0.9945218953682733}, \
{0.0905243046083367, 0.05226423163382686, -0.9945218953682733}, 
     {1.0605402120460135*^-16, 6.123031769111885*^-17, -1.}, \
{1.1187335719347004*^-16, 4.980922774430093*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.09166666666666666, 0.1], \
Polygon[{{0.0905243046083367, 0.05226423163382686, -0.9945218953682733}, 
     {0.08456530317942933, 0.061440289153522364, -0.9945218953682733}, \
{9.907273516618431*^-17, 7.198055546404516*^-17, -1.}, 
     {1.0605402120460135*^-16, 6.123031769111885*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.10833333333333334, 0.1], 
   Polygon[{{0.08456530317942933, 0.061440289153522364, -0.9945218953682733}, \
{0.07767978659246076, 0.06994319400804477, -0.9945218953682733}, 
     {9.100598750898387*^-17, 8.194215920840776*^-17, -1.}, \
{9.907273516618431*^-17, 7.198055546404516*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.125, 0.1], \
Polygon[{{0.07767978659246076, 0.06994319400804477, -0.9945218953682733}, 
     {0.06994319400804479, 0.07767978659246073, -0.9945218953682733}, \
{8.194215920840777*^-17, 9.100598750898385*^-17, -1.}, 
     {9.100598750898387*^-17, 8.194215920840776*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.14166666666666666, 0.1], 
   Polygon[{{0.06994319400804479, 0.07767978659246073, -0.9945218953682733}, \
{0.061440289153522364, 0.08456530317942933, -0.9945218953682733}, 
     {7.198055546404516*^-17, 9.907273516618431*^-17, -1.}, \
{8.194215920840777*^-17, 9.100598750898385*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.15833333333333333, 0.1], \
Polygon[{{0.061440289153522364, 0.08456530317942933, -0.9945218953682733}, 
     {0.05226423163382688, 0.09052430460833669, -0.9945218953682733}, \
{6.123031769111888*^-17, 1.0605402120460133*^-16, -1.}, 
     {7.198055546404516*^-17, 9.907273516618431*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.175, 0.1], 
   Polygon[{{0.05226423163382688, 0.09052430460833669, -0.9945218953682733}, \
{0.042515556255357585, 0.09549150281252652, -0.9945218953682733}, 
     {4.980922774430096*^-17, 1.1187335719347004*^-16, -1.}, \
{6.123031769111888*^-17, 1.0605402120460133*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.19166666666666665, 0.1], \
Polygon[{{0.042515556255357585, 0.09549150281252652, -0.9945218953682733}, 
     {0.03230107154560245, 0.09941247612902068, -0.9945218953682733}, \
{3.784241747506545*^-17, 1.1646698526992202*^-16, -1.}, 
     {4.980922774430096*^-17, 1.1187335719347004*^-16, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.20833333333333334, 0.1], 
   Polygon[{{0.03230107154560245, 0.09941247612902068, -0.9945218953682733}, \
{0.02173268953655995, 0.10224426555364723, -0.9945218953682733}, 
     {2.5460997760938185*^-17, 1.197845766834732*^-16, -1.}, \
{3.784241747506545*^-17, 1.1646698526992202*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.225, 0.1], \
Polygon[{{0.02173268953655995, 0.10224426555364723, -0.9945218953682733}, 
     {0.01092619963309723, 0.10395584540887992, -0.9945218953682733}, \
{1.2800622027285766*^-17, 1.217897832083461*^-16, -1.}, 
     {2.5460997760938185*^-17, 1.197845766834732*^-16, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.24166666666666667, 0.1], 
   Polygon[{{0.01092619963309723, 0.10395584540887992, -0.9945218953682733}, \
{6.400311013642887*^-18, 0.10452846326765373, -0.9945218953682733}, 
     {7.498303609110687*^-33, 1.2246063538223773*^-16, -1.}, \
{1.2800622027285766*^-17, 1.217897832083461*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.2583333333333333, 0.1], \
Polygon[{{6.400311013642887*^-18, 0.10452846326765373, -0.9945218953682733}, 
     {-0.010926199633097194, 0.10395584540887993, -0.9945218953682733}, \
{-1.2800622027285725*^-17, 1.217897832083461*^-16, -1.}, 
     {7.498303609110687*^-33, 1.2246063538223773*^-16, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.275, 0.1], 
   Polygon[{{-0.010926199633097194, 0.10395584540887993, \
-0.9945218953682733}, {-0.021732689536559914, 0.10224426555364724, \
-0.9945218953682733}, 
     {-2.5460997760938145*^-17, 1.1978457668347324*^-16, -1.}, \
{-1.2800622027285725*^-17, 1.217897832083461*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.2916666666666667, 0.1], \
Polygon[{{-0.021732689536559914, 0.10224426555364724, -0.9945218953682733}, 
     {-0.032301071545602446, 0.0994124761290207, -0.9945218953682733}, \
{-3.784241747506543*^-17, 1.1646698526992204*^-16, -1.}, 
     {-2.5460997760938145*^-17, 1.1978457668347324*^-16, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.30833333333333335, 0.1], 
   Polygon[{{-0.032301071545602446, 0.0994124761290207, -0.9945218953682733}, \
{-0.04251555625535755, 0.09549150281252654, -0.9945218953682733}, 
     {-4.9809227744300916*^-17, 1.1187335719347007*^-16, -1.}, \
{-3.784241747506543*^-17, 1.1646698526992204*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.325, 0.1], \
Polygon[{{-0.04251555625535755, 0.09549150281252654, -0.9945218953682733}, 
     {-0.052264231633826846, 0.0905243046083367, -0.9945218953682733}, \
{-6.123031769111884*^-17, 1.0605402120460135*^-16, -1.}, 
     {-4.9809227744300916*^-17, 1.1187335719347007*^-16, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.3416666666666667, 0.1], 
   Polygon[{{-0.052264231633826846, 0.0905243046083367, -0.9945218953682733}, \
{-0.06144028915352235, 0.08456530317942933, -0.9945218953682733}, 
     {-7.198055546404515*^-17, 9.907273516618431*^-17, -1.}, \
{-6.123031769111884*^-17, 1.0605402120460135*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.35833333333333334, 0.1], \
Polygon[{{-0.06144028915352235, 0.08456530317942933, -0.9945218953682733}, 
     {-0.06994319400804475, 0.07767978659246078, -0.9945218953682733}, \
{-8.194215920840774*^-17, 9.100598750898389*^-17, -1.}, 
     {-7.198055546404515*^-17, 9.907273516618431*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.375, 0.1], 
   Polygon[{{-0.06994319400804475, 0.07767978659246078, -0.9945218953682733}, \
{-0.07767978659246072, 0.0699431940080448, -0.9945218953682733}, 
     {-9.100598750898384*^-17, 8.194215920840779*^-17, -1.}, \
{-8.194215920840774*^-17, 9.100598750898389*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.39166666666666666, 0.1], \
Polygon[{{-0.07767978659246072, 0.0699431940080448, -0.9945218953682733}, 
     {-0.08456530317942931, 0.06144028915352237, -0.9945218953682733}, \
{-9.90727351661843*^-17, 7.198055546404518*^-17, -1.}, 
     {-9.100598750898384*^-17, 8.194215920840779*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.4083333333333333, 0.1], 
   Polygon[{{-0.08456530317942931, 0.06144028915352237, -0.9945218953682733}, \
{-0.09052430460833667, 0.0522642316338269, -0.9945218953682733}, 
     {-1.0605402120460132*^-16, 6.12303176911189*^-17, -1.}, \
{-9.90727351661843*^-17, 7.198055546404518*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.425, 0.1], \
Polygon[{{-0.09052430460833667, 0.0522642316338269, -0.9945218953682733}, 
     {-0.09549150281252651, 0.04251555625535759, -0.9945218953682733}, \
{-1.1187335719347002*^-16, 4.9809227744300965*^-17, -1.}, 
     {-1.0605402120460132*^-16, 6.12303176911189*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.44166666666666665, 0.1], 
   Polygon[{{-0.09549150281252651, 0.04251555625535759, -0.9945218953682733}, \
{-0.09941247612902068, 0.03230107154560246, -0.9945218953682733}, 
     {-1.1646698526992202*^-16, 3.7842417475065455*^-17, -1.}, \
{-1.1187335719347002*^-16, 4.9809227744300965*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.4583333333333333, 0.1], \
Polygon[{{-0.09941247612902068, 0.03230107154560246, -0.9945218953682733}, 
     {-0.10224426555364723, 0.02173268953655998, -0.9945218953682733}, \
{-1.197845766834732*^-16, 2.546099776093822*^-17, -1.}, 
     {-1.1646698526992202*^-16, 3.7842417475065455*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.475, 0.1], 
   Polygon[{{-0.10224426555364723, 0.02173268953655998, -0.9945218953682733}, \
{-0.10395584540887992, 0.010926199633097235, -0.9945218953682733}, 
     {-1.217897832083461*^-16, 1.2800622027285774*^-17, -1.}, \
{-1.197845766834732*^-16, 2.546099776093822*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.49166666666666664, 0.1], \
Polygon[{{-0.10395584540887992, 0.010926199633097235, -0.9945218953682733}, 
     {-0.10452846326765373, 1.2800622027285774*^-17, -0.9945218953682733}, \
{-1.2246063538223773*^-16, 1.4996607218221374*^-32, -1.}, 
     {-1.217897832083461*^-16, 1.2800622027285774*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.5083333333333333, 0.1], 
   Polygon[{{-0.10452846326765373, 1.2800622027285774*^-17, \
-0.9945218953682733}, {-0.10395584540887993, -0.010926199633097164, 
      -0.9945218953682733}, {-1.217897832083461*^-16, \
-1.280062202728569*^-17, -1.}, {-1.2246063538223773*^-16, \
1.4996607218221374*^-32, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.525, 0.1], \
Polygon[{{-0.10395584540887993, -0.010926199633097164, -0.9945218953682733}, 
     {-0.10224426555364724, -0.021732689536559907, -0.9945218953682733}, \
{-1.1978457668347324*^-16, -2.5460997760938135*^-17, -1.}, 
     {-1.217897832083461*^-16, -1.280062202728569*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.5416666666666666, 0.1], 
   Polygon[{{-0.10224426555364724, -0.021732689536559907, \
-0.9945218953682733}, {-0.0994124761290207, -0.03230107154560244, \
-0.9945218953682733}, 
     {-1.1646698526992204*^-16, -3.7842417475065424*^-17, -1.}, \
{-1.1978457668347324*^-16, -2.5460997760938135*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.5583333333333333, 0.1], \
Polygon[{{-0.0994124761290207, -0.03230107154560244, -0.9945218953682733}, 
     {-0.09549150281252655, -0.04251555625535753, -0.9945218953682733}, \
{-1.1187335719347007*^-16, -4.980922774430089*^-17, -1.}, 
     {-1.1646698526992204*^-16, -3.7842417475065424*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.575, 0.1], 
   Polygon[{{-0.09549150281252655, -0.04251555625535753, \
-0.9945218953682733}, {-0.0905243046083367, -0.05226423163382684, \
-0.9945218953682733}, 
     {-1.0605402120460136*^-16, -6.123031769111883*^-17, -1.}, \
{-1.1187335719347007*^-16, -4.980922774430089*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.5916666666666667, 0.1], \
Polygon[{{-0.0905243046083367, -0.05226423163382684, -0.9945218953682733}, 
     {-0.08456530317942934, -0.06144028915352235, -0.9945218953682733}, \
{-9.907273516618432*^-17, -7.198055546404515*^-17, -1.}, 
     {-1.0605402120460136*^-16, -6.123031769111883*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.6083333333333333, 0.1], 
   Polygon[{{-0.08456530317942934, -0.06144028915352235, \
-0.9945218953682733}, {-0.07767978659246079, -0.06994319400804475, \
-0.9945218953682733}, 
     {-9.100598750898391*^-17, -8.194215920840774*^-17, -1.}, \
{-9.907273516618432*^-17, -7.198055546404515*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.625, 0.1], \
Polygon[{{-0.07767978659246079, -0.06994319400804475, -0.9945218953682733}, 
     {-0.0699431940080448, -0.07767978659246072, -0.9945218953682733}, \
{-8.194215920840781*^-17, -9.100598750898384*^-17, -1.}, 
     {-9.100598750898391*^-17, -8.194215920840774*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.6416666666666666, 0.1], 
   Polygon[{{-0.0699431940080448, -0.07767978659246072, -0.9945218953682733}, \
{-0.06144028915352237, -0.08456530317942931, -0.9945218953682733}, 
     {-7.198055546404518*^-17, -9.90727351661843*^-17, -1.}, \
{-8.194215920840781*^-17, -9.100598750898384*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.6583333333333333, 0.1], \
Polygon[{{-0.06144028915352237, -0.08456530317942931, -0.9945218953682733}, 
     {-0.052264231633826916, -0.09052430460833666, -0.9945218953682733}, \
{-6.123031769111891*^-17, -1.0605402120460131*^-16, -1.}, 
     {-7.198055546404518*^-17, -9.90727351661843*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.675, 0.1], 
   Polygon[{{-0.052264231633826916, -0.09052430460833666, \
-0.9945218953682733}, {-0.04251555625535764, -0.0954915028125265, \
-0.9945218953682733}, 
     {-4.980922774430102*^-17, -1.1187335719347*^-16, -1.}, \
{-6.123031769111891*^-17, -1.0605402120460131*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.6916666666666667, 0.1], \
Polygon[{{-0.04251555625535764, -0.0954915028125265, -0.9945218953682733}, 
     {-0.03230107154560247, -0.09941247612902068, -0.9945218953682733}, \
{-3.784241747506546*^-17, -1.1646698526992202*^-16, -1.}, 
     {-4.980922774430102*^-17, -1.1187335719347*^-16, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.7083333333333334, 0.1], 
   Polygon[{{-0.03230107154560247, -0.09941247612902068, \
-0.9945218953682733}, {-0.021732689536559983, -0.10224426555364723, \
-0.9945218953682733}, 
     {-2.5460997760938225*^-17, -1.197845766834732*^-16, -1.}, \
{-3.784241747506546*^-17, -1.1646698526992202*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.725, 0.1], \
Polygon[{{-0.021732689536559983, -0.10224426555364723, -0.9945218953682733}, 
     {-0.010926199633097287, -0.10395584540887992, -0.9945218953682733}, \
{-1.2800622027285834*^-17, -1.217897832083461*^-16, -1.}, 
     {-2.5460997760938225*^-17, -1.197845766834732*^-16, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.7416666666666667, 0.1], 
   Polygon[{{-0.010926199633097287, -0.10395584540887992, \
-0.9945218953682733}, {-1.920093304092866*^-17, -0.10452846326765373, 
      -0.9945218953682733}, {-2.2494910827332062*^-32, \
-1.2246063538223773*^-16, -1.}, {-1.2800622027285834*^-17, \
-1.217897832083461*^-16, 
      -1.}}]}, {CMYKColor[0.9833333333333333, 0.5, 0.7583333333333333, 0.1], 
   Polygon[{{-1.920093304092866*^-17, -0.10452846326765373, \
-0.9945218953682733}, {0.010926199633097157, -0.10395584540887993, 
      -0.9945218953682733}, {1.2800622027285681*^-17, \
-1.217897832083461*^-16, -1.}, {-2.2494910827332062*^-32, \
-1.2246063538223773*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.775, 0.1], \
Polygon[{{0.010926199633097157, -0.10395584540887993, -0.9945218953682733}, 
     {0.021732689536559855, -0.10224426555364725, -0.9945218953682733}, \
{2.5460997760938074*^-17, -1.1978457668347324*^-16, -1.}, 
     {1.2800622027285681*^-17, -1.217897832083461*^-16, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.7916666666666666, 0.1], 
   Polygon[{{0.021732689536559855, -0.10224426555364725, \
-0.9945218953682733}, {0.03230107154560243, -0.0994124761290207, \
-0.9945218953682733}, 
     {3.784241747506542*^-17, -1.1646698526992204*^-16, -1.}, \
{2.5460997760938074*^-17, -1.1978457668347324*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.8083333333333333, 0.1], \
Polygon[{{0.03230107154560243, -0.0994124761290207, -0.9945218953682733}, 
     {0.04251555625535752, -0.09549150281252655, -0.9945218953682733}, \
{4.980922774430088*^-17, -1.1187335719347007*^-16, -1.}, 
     {3.784241747506542*^-17, -1.1646698526992204*^-16, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.825, 0.1], 
   Polygon[{{0.04251555625535752, -0.09549150281252655, -0.9945218953682733}, \
{0.0522642316338268, -0.09052430460833673, -0.9945218953682733}, 
     {6.123031769111878*^-17, -1.0605402120460138*^-16, -1.}, \
{4.980922774430088*^-17, -1.1187335719347007*^-16, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.8416666666666667, 0.1], \
Polygon[{{0.0522642316338268, -0.09052430460833673, -0.9945218953682733}, 
     {0.061440289153522336, -0.08456530317942934, -0.9945218953682733}, \
{7.198055546404513*^-17, -9.907273516618432*^-17, -1.}, 
     {6.123031769111878*^-17, -1.0605402120460138*^-16, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.8583333333333333, 0.1], 
   Polygon[{{0.061440289153522336, -0.08456530317942934, \
-0.9945218953682733}, {0.06994319400804473, -0.07767978659246079, \
-0.9945218953682733}, 
     {8.194215920840772*^-17, -9.100598750898391*^-17, -1.}, \
{7.198055546404513*^-17, -9.907273516618432*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.875, 0.1], \
Polygon[{{0.06994319400804473, -0.07767978659246079, -0.9945218953682733}, 
     {0.07767978659246069, -0.06994319400804484, -0.9945218953682733}, \
{9.10059875089838*^-17, -8.194215920840785*^-17, -1.}, 
     {8.194215920840772*^-17, -9.100598750898391*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.8916666666666666, 0.1], 
   Polygon[{{0.07767978659246069, -0.06994319400804484, -0.9945218953682733}, \
{0.08456530317942931, -0.061440289153522384, -0.9945218953682733}, 
     {9.90727351661843*^-17, -7.19805554640452*^-17, -1.}, \
{9.10059875089838*^-17, -8.194215920840785*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.9083333333333333, 0.1], \
Polygon[{{0.08456530317942931, -0.061440289153522384, -0.9945218953682733}, 
     {0.09052430460833666, -0.052264231633826916, -0.9945218953682733}, \
{1.0605402120460131*^-16, -6.123031769111891*^-17, -1.}, 
     {9.90727351661843*^-17, -7.19805554640452*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.9249999999999999, 0.1], 
   Polygon[{{0.09052430460833666, -0.052264231633826916, \
-0.9945218953682733}, {0.0954915028125265, -0.04251555625535765, \
-0.9945218953682733}, 
     {1.1187335719347*^-16, -4.9809227744301027*^-17, -1.}, \
{1.0605402120460131*^-16, -6.123031769111891*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.9416666666666667, 0.1], \
Polygon[{{0.0954915028125265, -0.04251555625535765, -0.9945218953682733}, 
     {0.09941247612902068, -0.032301071545602474, -0.9945218953682733}, \
{1.1646698526992202*^-16, -3.784241747506547*^-17, -1.}, 
     {1.1187335719347*^-16, -4.9809227744301027*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.9583333333333334, 0.1], 
   Polygon[{{0.09941247612902068, -0.032301071545602474, \
-0.9945218953682733}, {0.10224426555364723, -0.021732689536559994, \
-0.9945218953682733}, 
     {1.197845766834732*^-16, -2.5460997760938234*^-17, -1.}, \
{1.1646698526992202*^-16, -3.784241747506547*^-17, -1.}}]}, 
  {CMYKColor[0.9833333333333333, 0.5, 0.975, 0.1], \
Polygon[{{0.10224426555364723, -0.021732689536559994, -0.9945218953682733}, 
     {0.10395584540887992, -0.010926199633097296, -0.9945218953682733}, \
{1.217897832083461*^-16, -1.2800622027285843*^-17, -1.}, 
     {1.197845766834732*^-16, -2.5460997760938234*^-17, -1.}}]}, \
{CMYKColor[0.9833333333333333, 0.5, 0.9916666666666667, 0.1], 
   Polygon[{{0.10395584540887992, -0.010926199633097296, \
-0.9945218953682733}, {0.10452846326765373, -2.5601244054571548*^-17, 
      -0.9945218953682733}, {1.2246063538223773*^-16, \
-2.999321443644275*^-32, -1.}, {1.217897832083461*^-16, \
-1.2800622027285843*^-17, -1.}}]}}, 
 {Lighting -> False}]\
\>", "\<\
-Graphics3D-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
SetDirectory[\"/local/constant/ElasticaBook/C02_Dynamics/EPS\"]
\
\>", "Input"],

Cell[OutputFormData["\<\
\"/local/constant/ElasticaBook/C02_Dynamics/EPS\"\
\>", "\<\
/local/constant/ElasticaBook/C02_Dynamics/EPS\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Export[ \"C02_euler_angles.eps\", %44]
Export[ \"C02_euler_mohr.eps\", %63]
Export[ \"C02_euler_sphere.eps\", %51]\
\>", "Input"],

Cell[OutputFormData["\<\
\"C02_euler_angles.eps\"\
\>", "\<\
C02_euler_angles.eps\
\>"], "Output"],

Cell[OutputFormData["\<\
\"C02_euler_mohr.eps\"\
\>", "\<\
C02_euler_mohr.eps\
\>"], "Output"],

Cell[OutputFormData["\<\
\"C02_euler_sphere.eps\"\
\>", "\<\
C02_euler_sphere.eps\
\>"], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Condensed",
WindowSize->{1163, 821},
WindowMargins->{{57, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 55, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1411, 43, 322, 9, 77, "Input"],
Cell[1736, 54, 132, 4, 37, "Output"]
}, Open  ]],
Cell[1883, 61, 61, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[1969, 66, 60, 0, 32, "Input"],
Cell[2032, 68, 126, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2195, 77, 61, 3, 50, "Input"],
Cell[2259, 82, 78, 4, 37, "Output"],
Cell[2340, 88, 96, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2473, 97, 215, 8, 140, "Input"],
Cell[2691, 107, 383, 8, 47, "Output"],
Cell[3077, 117, 374, 8, 47, "Output"],
Cell[3454, 127, 120, 3, 24, "Message"],
Cell[3577, 132, 211, 6, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3825, 143, 166, 3, 59, "Subsection"],
Cell[CellGroupData[{
Cell[4016, 150, 62, 0, 32, "Input"],
Cell[4081, 152, 182, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4300, 162, 25, 0, 32, "Input"],
Cell[4328, 164, 222, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4587, 174, 38, 0, 32, "Input"],
Cell[4628, 176, 3054, 66, 366, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7719, 247, 91, 2, 32, "Input"],
Cell[7813, 251, 613, 19, 175, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8475, 276, 56, 0, 39, "Subsection"],
Cell[CellGroupData[{
Cell[8556, 280, 234, 5, 55, "Input"],
Cell[8793, 287, 90, 4, 37, "Output"],
Cell[8886, 293, 72, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8995, 302, 50, 0, 32, "Input"],
Cell[9048, 304, 130, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9215, 313, 36, 0, 32, "Input"],
Cell[9254, 315, 148, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9439, 324, 78, 3, 50, "Input"],
Cell[9520, 329, 215, 5, 47, "Output"],
Cell[9738, 336, 413, 8, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10188, 349, 53, 0, 32, "Input"],
Cell[10244, 351, 110, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10391, 360, 47, 0, 32, "Input"],
Cell[10441, 362, 569, 12, 79, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11059, 380, 77, 0, 39, "Subsection"],
Cell[11139, 382, 36, 0, 32, "Input"],
Cell[CellGroupData[{
Cell[11200, 386, 150, 3, 32, "Input"],
Cell[11353, 391, 295089, 21988, 152, 287322, 21857, "GraphicsData", \
"PostScript", "Graphics"],
Cell[306445, 22381, 1771438, 28572, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2077920, 50958, 166, 3, 32, "Input"],
Cell[2078089, 50963, 405573, 24961, 296, 385515, 24629, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2483665, 75926, 1491824, 24322, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3975538, 100254, 110, 3, 39, "Subsection"],
Cell[3975651, 100259, 135, 5, 86, "Input"],
Cell[CellGroupData[{
Cell[3975811, 100268, 122, 3, 50, "Input"],
Cell[3975936, 100273, 120, 4, 37, "Output"],
Cell[3976059, 100279, 120, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3976216, 100288, 47, 0, 32, "Input"],
Cell[3976266, 100290, 569, 12, 79, "Output"]
}, Open  ]],
Cell[3976850, 100305, 348, 9, 140, "Input"],
Cell[CellGroupData[{
Cell[3977223, 100318, 43, 0, 32, "Input"],
Cell[3977269, 100320, 153259, 10945, 186, 146984, 10839, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4130531, 111267, 401487, 6969, 37, "Output"]
}, Open  ]],
Cell[4532033, 118239, 204, 5, 50, "Input"],
Cell[CellGroupData[{
Cell[4532262, 118248, 213, 5, 68, "Input"],
Cell[4532478, 118255, 151, 3, 24, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4532666, 118263, 183, 4, 68, "Input"],
Cell[4532852, 118269, 303799, 21804, 186, 293968, 21639, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4836654, 140075, 841352, 14274, 37, "Output"]
}, Open  ]],
Cell[5678021, 154352, 17, 0, 32, "Input"],
Cell[CellGroupData[{
Cell[5678063, 154356, 214, 4, 68, "Input"],
Cell[5678280, 154362, 307009, 21992, 152, 299612, 21867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5985292, 176356, 837613, 14122, 37, "Output"]
}, Open  ]],
Cell[6822920, 190481, 233, 5, 68, "Input"],
Cell[CellGroupData[{
Cell[6823178, 190490, 148, 4, 50, "Input"],
Cell[6823329, 190496, 289233, 14343, 296, 270521, 14033, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7112565, 204841, 607559, 9073, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7720161, 213919, 89, 3, 50, "Input"],
Cell[7720253, 213924, 148, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7720438, 213933, 139, 4, 68, "Input"],
Cell[7720580, 213939, 98, 4, 37, "Output"],
Cell[7720681, 213945, 94, 4, 37, "Output"],
Cell[7720778, 213951, 98, 4, 37, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

