(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      6011,        212]
NotebookOptionsPosition[      5057,        173]
NotebookOutlinePosition[      5410,        189]
CellTagsIndexPosition[      5367,        186]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"",
   "]"}], "\n", 
 RowBox[{"<<", "Tensor2Analysis.m"}], "\n"}], "Input"],

Cell[OutputFormData["\<\
\"/local/constant/ElasticaBook/Packages\"\
\>", "\<\
/local/constant/ElasticaBook/Packages\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Spherical", "[", 
   RowBox[{"r", ",", "t", ",", "p"}], "]"}], "]"}], "\n", 
 RowBox[{"pos", "=", 
  RowBox[{"Coordinates", "[", "]"}]}]}], "Input"],

Cell[OutputFormData["\<\
Spherical[r, t, p]\
\>", "\<\
Spherical[r, t, p]\
\>"], "Output"],

Cell[OutputFormData["\<\
{r, t, p}\
\>", "\<\
{r, t, p}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CoordinatesToCartesian[pos]", "Input"],

Cell[OutputFormData["\<\
{r*Cos[p]*Sin[t], r*Sin[p]*Sin[t], r*Cos[t]}\
\>", "\<\
{r Cos[p] Sin[t], r Sin[p] Sin[t], r Cos[t]}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"stress", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"srr", "[", "r", "]"}], ",", 
      RowBox[{"srt", "[", "r", "]"}], ",", 
      RowBox[{"srp", "[", "r", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"srt", "[", "r", "]"}], ",", 
      RowBox[{"stt", "[", "r", "]"}], ",", 
      RowBox[{"stp", "[", "r", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"srp", "[", "r", "]"}], ",", 
      RowBox[{"stp", "[", "r", "]"}], ",", 
      RowBox[{"spp", "[", "r", "]"}]}], "}"}]}], "}"}]}]], "Input"],

Cell[OutputFormData["\<\
{{srr[r], srt[r], srp[r]}, {srt[r], stt[r], stp[r]}, {srp[r], stp[r], \
spp[r]}}\
\>", "\<\
{{srr[r], srt[r], srp[r]}, {srt[r], stt[r], stp[r]}, {srp[r], stp[r], \
spp[r]}}\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(thediv = Div[ stress ]) // MatrixForm", "Input"],

Cell[OutputFormData["\<\
{-(spp[r]/r) + (2*srr[r])/r + (Cot[t]*srt[r])/r - stt[r]/r + \
Derivative[1][srr][r], 
 -((Cot[t]*spp[r])/r) + (3*srt[r])/r + (Cot[t]*stt[r])/r + \
Derivative[1][srt][r], 
 (3*srp[r])/r + (2*Cot[t]*stp[r])/r + Derivative[1][srp][r]}\
\>", "\<\
  spp[r]    2 srr[r]   Cot[t] srt[r]   stt[r]
-(------) + -------- + ------------- - ------ + srr'[r]
    r          r             r           r

  Cot[t] spp[r]    3 srt[r]   Cot[t] stt[r]
-(-------------) + -------- + ------------- + srt'[r]
        r             r             r

3 srp[r]   2 Cot[t] stp[r]
-------- + --------------- + srp'[r]
   r              r\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Solve[ Thread[ thediv == {0,0,0}] , {stt[r], spp[r], stp[r] }]\
\>", "Input"],

Cell[OutputFormData["\<\
{{stp[r] -> -(Tan[t]*(3*srp[r] + r*Derivative[1][srp][r]))/2, 
  stt[r] -> -(-2*srr[r] - Cot[t]*srt[r] + 3*srt[r]*Tan[t] - \
r*Derivative[1][srr][r] + r*Tan[t]*Derivative[1][srt][r])/2, 
  spp[r] -> (Tan[t]*(2*Cot[t]*srr[r] + 3*srt[r] + Cot[t]^2*srt[r] + \
r*Cot[t]*Derivative[1][srr][r] + 
      r*Derivative[1][srt][r]))/2}}\
\>", "\<\
            -(Tan[t] (3 srp[r] + r srp'[r]))
{{stp[r] -> --------------------------------, stt[r] -> 
                           2
 
    -(-2 srr[r] - Cot[t] srt[r] + 3 srt[r] Tan[t] - r srr'[r] + r Tan[t] \
srt'[r])
    --------------------------------------------------------------------------\
---, 
                                          2
 
                                                        2
             Tan[t] (2 Cot[t] srr[r] + 3 srt[r] + Cot[t]  srt[r] + r Cot[t] \
srr'[r] + r srt'[r])
   spp[r] -> \
------------------------------------------------------------------------------\
-----}}
                                                      2\
\>"], "Output"]
}, Open  ]]
},
WindowSize->{999, 821},
WindowMargins->{{63, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 165, 3, 77, "Input"],
Cell[1499, 43, 132, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1668, 52, 207, 5, 55, "Input"],
Cell[1878, 59, 90, 4, 37, "Output"],
Cell[1971, 65, 72, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2080, 74, 44, 0, 32, "Input"],
Cell[2127, 76, 142, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2306, 85, 600, 18, 32, "Input"],
Cell[2909, 105, 214, 6, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3160, 116, 55, 0, 32, "Input"],
Cell[3218, 118, 652, 18, 143, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3907, 141, 87, 2, 32, "Input"],
Cell[3997, 145, 1044, 25, 154, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

