(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     22508,        800]
NotebookOptionsPosition[     19535,        689]
NotebookOutlinePosition[     19868,        704]
CellTagsIndexPosition[     19825,        701]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["Bending of a anisotropic bar  (Lehnitskii art. 15)", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "IntegrateStrain.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cartesian", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cartesian", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The stress field with the nonzero component along the \
z - axis",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sig", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", " ", 
        RowBox[{
         RowBox[{"Mx", "/", "Ix"}], "  ", "y"}]}], " ", "}"}]}], "}"}]}], 
   ")"}], "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"Mx", " ", "y"}], "Ix"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"C4", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C11", ",", "C16", ",", "C15"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C16", ",", "C12", ",", "C14"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C15", ",", "C14", ",", "C13"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C12", ",", "C26", ",", "C25"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C26", ",", "C22", ",", "C24"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C25", ",", "C24", ",", "C23"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C13", ",", "C36", ",", "C35"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C36", ",", "C23", ",", "C34"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C35", ",", "C34", ",", "C33"}], "}"}]}], "}"}]}], "}"}]}],
      "}"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"eps", "=", 
    RowBox[{"DDot", "[", 
     RowBox[{"C4", ",", "sig"}], "]"}]}], ")"}], "//", "MatrixForm"}], "\n", 
 RowBox[{
  RowBox[{"Inc", "[", "eps", "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"C13", " ", "Mx", " ", "y"}], "Ix"], 
      FractionBox[
       RowBox[{"C36", " ", "Mx", " ", "y"}], "Ix"], 
      FractionBox[
       RowBox[{"C35", " ", "Mx", " ", "y"}], "Ix"]},
     {
      FractionBox[
       RowBox[{"C36", " ", "Mx", " ", "y"}], "Ix"], 
      FractionBox[
       RowBox[{"C23", " ", "Mx", " ", "y"}], "Ix"], 
      FractionBox[
       RowBox[{"C34", " ", "Mx", " ", "y"}], "Ix"]},
     {
      FractionBox[
       RowBox[{"C35", " ", "Mx", " ", "y"}], "Ix"], 
      FractionBox[
       RowBox[{"C34", " ", "Mx", " ", "y"}], "Ix"], 
      FractionBox[
       RowBox[{"C33", " ", "Mx", " ", "y"}], "Ix"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"IntegrateStrain", "[", " ", "eps", " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"C13", " ", "Mx", " ", "x", " ", "y"}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C36", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C35", " ", "Mx", " ", "y", " ", "z"}], "Ix"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"C13", " ", "Mx", " ", 
       SuperscriptBox["x", "2"]}], 
      RowBox[{"2", " ", "Ix"}]]}], "+", 
    FractionBox[
     RowBox[{"C23", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], 
     RowBox[{"2", " ", "Ix"}]], "-", 
    FractionBox[
     RowBox[{"C35", " ", "Mx", " ", "x", " ", "z"}], "Ix"], "-", 
    FractionBox[
     RowBox[{"C33", " ", "Mx", " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"2", " ", "Ix"}]]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"C35", " ", "Mx", " ", "x", " ", "y"}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C34", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C33", " ", "Mx", " ", "y", " ", "z"}], "Ix"]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "[", 
  RowBox[{"[", "3", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"C35", " ", "Mx", " ", "x", " ", "y"}], "Ix"], "+", 
  FractionBox[
   RowBox[{"C34", " ", "Mx", " ", 
    SuperscriptBox["y", "2"]}], "Ix"], "+", 
  FractionBox[
   RowBox[{"C33", " ", "Mx", " ", "y", " ", "z"}], "Ix"]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"C13", " ", "Mx", " ", "x", " ", "y"}], "Ix"], "+", 
  FractionBox[
   RowBox[{"C36", " ", "Mx", " ", 
    SuperscriptBox["y", "2"]}], "Ix"], "+", 
  FractionBox[
   RowBox[{"C35", " ", "Mx", " ", "y", " ", "z"}], "Ix"]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["remark wrapping ",
  FontFamily->"Courier"],
 "u[[3]]",
 StyleBox[" and twisting ",
  FontFamily->"Courier"],
 "u[[1]]",
 StyleBox[" of the crosssection  ",
  FontFamily->"Courier"]
}], "Subsection"],

Cell[BoxData[
 RowBox[{"cw", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"C35", " ", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"C34", " ", "\[Rule]", " ", "0"}]}], "}"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "/.", " ", "cw"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"C13", " ", "Mx", " ", "x", " ", "y"}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C36", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], "Ix"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"C13", " ", "Mx", " ", 
       SuperscriptBox["x", "2"]}], 
      RowBox[{"2", " ", "Ix"}]]}], "+", 
    FractionBox[
     RowBox[{"C23", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], 
     RowBox[{"2", " ", "Ix"}]], "-", 
    FractionBox[
     RowBox[{"C33", " ", "Mx", " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"2", " ", "Ix"}]]}], ",", 
   FractionBox[
    RowBox[{"C33", " ", "Mx", " ", "y", " ", "z"}], "Ix"]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["shape of the deflected axis:  ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"u", " ", "/.", " ", "cw"}], " ", "/.", " ", 
   RowBox[{"x", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
  RowBox[{"y", " ", "\[Rule]", " ", "0", "   "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"C33", " ", "Mx", " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"2", " ", "Ix"}]]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "  ", "/.", " ", 
   RowBox[{"x", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
  RowBox[{"y", " ", "\[Rule]", " ", "0", " "}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"C33", " ", "Mx", " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"2", " ", "Ix"}]]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["beam on two supports - complete end boundary \
conditions  ",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"uc", " ", "=", " ", 
   RowBox[{"u", " ", "+", " ", 
    RowBox[{"{", 
     RowBox[{"a1", ",", " ", "a2", ",", " ", "a3"}], "}"}], " ", "+", " ", 
    RowBox[{"Cross", "[", "  ", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"b1", ",", " ", "b2", ",", " ", "b3"}], "}"}], " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], "  "}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a1", "-", 
    RowBox[{"b3", " ", "y"}], "+", 
    FractionBox[
     RowBox[{"C13", " ", "Mx", " ", "x", " ", "y"}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C36", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], "Ix"], "+", 
    RowBox[{"b2", " ", "z"}], "+", 
    FractionBox[
     RowBox[{"C35", " ", "Mx", " ", "y", " ", "z"}], "Ix"]}], ",", 
   RowBox[{"a2", "+", 
    RowBox[{"b3", " ", "x"}], "-", 
    FractionBox[
     RowBox[{"C13", " ", "Mx", " ", 
      SuperscriptBox["x", "2"]}], 
     RowBox[{"2", " ", "Ix"}]], "+", 
    FractionBox[
     RowBox[{"C23", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], 
     RowBox[{"2", " ", "Ix"}]], "-", 
    RowBox[{"b1", " ", "z"}], "-", 
    FractionBox[
     RowBox[{"C35", " ", "Mx", " ", "x", " ", "z"}], "Ix"], "-", 
    FractionBox[
     RowBox[{"C33", " ", "Mx", " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"2", " ", "Ix"}]]}], ",", 
   RowBox[{"a3", "-", 
    RowBox[{"b2", " ", "x"}], "+", 
    RowBox[{"b1", " ", "y"}], "+", 
    FractionBox[
     RowBox[{"C35", " ", "Mx", " ", "x", " ", "y"}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C34", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C33", " ", "Mx", " ", "y", " ", "z"}], "Ix"]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Strain", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a1", ",", " ", "a2", ",", " ", "a3"}], "}"}], " ", "+", " ", 
   RowBox[{"Cross", "[", "  ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"b1", ",", " ", "b2", ",", " ", "b3"}], "}"}], " ", ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["fixed axis of the beam in z = 0 and z = L",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"u0", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"uc", " ", "/.", " ", 
     RowBox[{"z", " ", "\[Rule]", " ", "0"}]}], "  ", "/.", " ", 
    RowBox[{"x", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
   RowBox[{"y", " ", "\[Rule]", " ", "0"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"uL", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"uc", " ", "/.", " ", 
     RowBox[{"z", " ", "\[Rule]", " ", "L"}]}], " ", "/.", " ", 
    RowBox[{"x", " ", "\[Rule]", " ", "0"}]}], " ", "/.", " ", 
   RowBox[{"y", " ", "\[Rule]", " ", "0", " "}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a1", ",", "a2", ",", "a3"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a1", "+", 
    RowBox[{"b2", " ", "L"}]}], ",", 
   RowBox[{"a2", "-", 
    RowBox[{"b1", " ", "L"}], "-", 
    FractionBox[
     RowBox[{"C33", " ", 
      SuperscriptBox["L", "2"], " ", "Mx"}], 
     RowBox[{"2", " ", "Ix"}]]}], ",", "a3"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c0", " ", "=", " ", 
  RowBox[{"Thread", "[", "  ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a1", ",", " ", "a2", ",", " ", "a3"}], "}"}], " ", "\[Rule]", 
    " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a1", "\[Rule]", "0"}], ",", 
   RowBox[{"a2", "\[Rule]", "0"}], ",", 
   RowBox[{"a3", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uL", " ", "/.", " ", "c0"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"b2", " ", "L"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "b1"}], " ", "L"}], "-", 
    FractionBox[
     RowBox[{"C33", " ", 
      SuperscriptBox["L", "2"], " ", "Mx"}], 
     RowBox[{"2", " ", "Ix"}]]}], ",", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cL", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"b2", " ", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"b1", " ", "\[Rule]", " ", 
     FractionBox[
      RowBox[{"C33", " ", 
       SuperscriptBox["L", "2"], " ", "Mx"}], 
      RowBox[{"2", " ", "Ix"}]]}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"b2", "\[Rule]", "0"}], ",", 
   RowBox[{"b1", "\[Rule]", 
    FractionBox[
     RowBox[{"C33", " ", 
      SuperscriptBox["L", "2"], " ", "Mx"}], 
     RowBox[{"2", " ", "Ix"}]]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"uc", " ", "/.", " ", "c0"}], " ", "/.", " ", "cL", " "}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "b3"}], " ", "y"}], "+", 
    FractionBox[
     RowBox[{"C13", " ", "Mx", " ", "x", " ", "y"}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C36", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C35", " ", "Mx", " ", "y", " ", "z"}], "Ix"]}], ",", 
   RowBox[{
    RowBox[{"b3", " ", "x"}], "-", 
    FractionBox[
     RowBox[{"C13", " ", "Mx", " ", 
      SuperscriptBox["x", "2"]}], 
     RowBox[{"2", " ", "Ix"}]], "+", 
    FractionBox[
     RowBox[{"C23", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], 
     RowBox[{"2", " ", "Ix"}]], "-", 
    FractionBox[
     RowBox[{"C33", " ", 
      SuperscriptBox["L", "2"], " ", "Mx", " ", "z"}], 
     RowBox[{"2", " ", "Ix"}]], "-", 
    FractionBox[
     RowBox[{"C35", " ", "Mx", " ", "x", " ", "z"}], "Ix"], "-", 
    FractionBox[
     RowBox[{"C33", " ", "Mx", " ", 
      SuperscriptBox["z", "2"]}], 
     RowBox[{"2", " ", "Ix"}]]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"C33", " ", 
      SuperscriptBox["L", "2"], " ", "Mx", " ", "y"}], 
     RowBox[{"2", " ", "Ix"}]], "+", 
    FractionBox[
     RowBox[{"C35", " ", "Mx", " ", "x", " ", "y"}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C34", " ", "Mx", " ", 
      SuperscriptBox["y", "2"]}], "Ix"], "+", 
    FractionBox[
     RowBox[{"C33", " ", "Mx", " ", "y", " ", "z"}], "Ix"]}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["conditions do not prevent the rotation of the bar \
around its own axis ",
 FontFamily->"Courier"]], "Subsection"],

Cell[BoxData[
 RowBox[{"crot", " ", "=", " ", 
  RowBox[{"b3", " ", "\[Rule]", " ", "0"}]}]], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1170, 769},
WindowMargins->{{35, Automatic}, {Automatic, 2}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 93, 1, 73, "Section"],
Cell[CellGroupData[{
Cell[1449, 43, 291, 8, 55, "Input"],
Cell[1743, 53, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1830, 56, 189, 3, 77, "Input"],
Cell[CellGroupData[{
Cell[2044, 63, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2156, 68, 137, 3, 32, "Input"],
Cell[2296, 73, 96, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2441, 81, 130, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2596, 87, 445, 14, 32, "Input"],
Cell[3044, 103, 274, 10, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3355, 118, 3409, 94, 231, "Input"],
Cell[6767, 214, 822, 26, 88, "Output"],
Cell[7592, 242, 219, 8, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7848, 255, 113, 2, 32, "Input"],
Cell[7964, 259, 1120, 35, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9121, 299, 77, 2, 32, "Input"],
Cell[9201, 303, 283, 8, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9521, 316, 77, 2, 32, "Input"],
Cell[9601, 320, 283, 8, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9933, 334, 226, 9, 40, "Subsection"],
Cell[10162, 345, 198, 5, 32, "Input"],
Cell[CellGroupData[{
Cell[10385, 354, 61, 1, 32, "Input"],
Cell[10449, 357, 751, 24, 48, "Output"]
}, Open  ]],
Cell[11215, 384, 26, 0, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11278, 389, 96, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[11399, 394, 216, 5, 32, "Input"],
Cell[11618, 401, 219, 7, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11874, 413, 179, 4, 32, "Input"],
Cell[12056, 419, 219, 7, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12324, 432, 125, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[12474, 438, 431, 11, 32, "Input"],
Cell[12908, 451, 1345, 40, 87, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14290, 496, 377, 10, 32, "Input"],
Cell[14670, 508, 260, 8, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14979, 522, 107, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[15111, 527, 587, 14, 55, "Input"],
Cell[15701, 543, 86, 2, 31, "Output"],
Cell[15790, 547, 313, 10, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16140, 562, 284, 8, 32, "Input"],
Cell[16427, 572, 176, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16640, 582, 62, 1, 32, "Input"],
Cell[16705, 585, 296, 10, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17038, 600, 317, 9, 55, "Input"],
Cell[17358, 611, 252, 8, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17647, 624, 102, 2, 32, "Input"],
Cell[17752, 628, 1463, 45, 87, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19264, 679, 138, 2, 39, "Subsection"],
Cell[19405, 683, 102, 2, 32, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

