(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     14636,        516]
NotebookOptionsPosition[     12720,        444]
NotebookOutlinePosition[     13164,        462]
CellTagsIndexPosition[     13121,        459]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "This notebook forms part of the supporting material for the book\n\n",
 StyleBox["Elasticity with Mathematica (r)\nby A. Constantinescu and A.M. \
Korsunsky\npublished by Cambridge University Press, 2007\n(ISBN-13: \
9780521842013)\n",
  FontSlant->"Italic"],
 "\nCopyright (c) 2007 A. Constantinescu and A.M. Korsunsky\n\nPlease \
acknowledge the use of this material in teaching, research and \nfurther \
development.\n\nAuthors accept no responsibility for the results obtained and \
\nconclusions drawn on the basis of using this material."
}], "Text",
 CellChangeTimes->{{3.402067937883517*^9, 3.402067938554608*^9}, {
  3.402067978596741*^9, 3.402067984940596*^9}, {3.402068090073731*^9, 
  3.402068091731965*^9}}],

Cell[CellGroupData[{

Cell["\<\
Extension of a bar with cylindrical anisotropy (Lehnitskii art. 17)\
\>", "Section",
 FontFamily->"Courier"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "SetDirectory", "[", "\"\<D:\\AMK04\\elastica\\ElasticaBook\\Packages\>\"",
     "]"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "SetDirectory", "[", "\"\</local/constant/ElasticaBook/Packages\>\"", 
   "]"}]}]], "Input"],

Cell[BoxData["\<\"/local/constant/ElasticaBook/Packages\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"<<", "Tensor2Analysis.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", " ", "Displacement.m"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "IntegrateStrain.m"}]}], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The coordinate system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetCoordinates", "[", 
  RowBox[{"Cylindrical", "[", 
   RowBox[{"r", ",", "t", ",", "z"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cylindrical", "[", 
  RowBox[{"r", ",", "t", ",", "z"}], "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The general solution in cylindrical coordinate \
system",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"sig", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", 
        RowBox[{"P", "/", "S"}]}], "}"}]}], "}"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", "0"},
     {"0", "0", 
      FractionBox["P", "S"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"C4", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C11", ",", "C16", ",", "C15"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C16", ",", "C12", ",", "C14"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C15", ",", "C14", ",", "C13"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C16", ",", "C66", ",", "C56"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C66", ",", "C26", ",", "C46"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C46", ",", "C36"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C12", ",", "C26", ",", "C25"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C26", ",", "C22", ",", "C24"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C25", ",", "C24", ",", "C23"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C15", ",", "C56", ",", "C55"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C56", ",", "C25", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C55", ",", "C45", ",", "C35"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C14", ",", "C46", ",", "C45"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C46", ",", "C24", ",", "C44"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C45", ",", "C44", ",", "C34"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"C13", ",", "C36", ",", "C35"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C36", ",", "C23", ",", "C34"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"C35", ",", "C34", ",", "C33"}], "}"}]}], "}"}]}], "}"}]}],
      "}"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"eps", "=", 
    RowBox[{"DDot", "[", 
     RowBox[{"C4", ",", "sig"}], "]"}]}], ")"}], "//", "MatrixForm"}], "\n", 
 RowBox[{
  RowBox[{"Inc", "[", "eps", "]"}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"C13", " ", "P"}], "S"], 
      FractionBox[
       RowBox[{"C36", " ", "P"}], "S"], 
      FractionBox[
       RowBox[{"C35", " ", "P"}], "S"]},
     {
      FractionBox[
       RowBox[{"C36", " ", "P"}], "S"], 
      FractionBox[
       RowBox[{"C23", " ", "P"}], "S"], 
      FractionBox[
       RowBox[{"C34", " ", "P"}], "S"]},
     {
      FractionBox[
       RowBox[{"C35", " ", "P"}], "S"], 
      FractionBox[
       RowBox[{"C34", " ", "P"}], "S"], 
      FractionBox[
       RowBox[{"C33", " ", "P"}], "S"]}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0"},
     {"0", "0", 
      FractionBox[
       RowBox[{"C34", " ", "P"}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "S"}]]},
     {"0", 
      FractionBox[
       RowBox[{"C34", " ", "P"}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "S"}]], "0"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Constitutive Compatibility condition",
 FontFamily->"Courier"]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ccc", " ", "=", " ", 
  RowBox[{"C34", " ", "\[Rule]", " ", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"C34", "\[Rule]", "0"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{"eps", " ", "/.", " ", "ccc"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"C13", " ", "P"}], "S"], ",", 
     FractionBox[
      RowBox[{"C36", " ", "P"}], "S"], ",", 
     FractionBox[
      RowBox[{"C35", " ", "P"}], "S"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"C36", " ", "P"}], "S"], ",", 
     FractionBox[
      RowBox[{"C23", " ", "P"}], "S"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"C35", " ", "P"}], "S"], ",", "0", ",", 
     FractionBox[
      RowBox[{"C33", " ", "P"}], "S"]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"IntegrateStrain", "[", " ", "eps", " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"C13", " ", "P", " ", "r"}], "S"], "+", 
    FractionBox[
     RowBox[{"C35", " ", "P", " ", "z"}], "S"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"C35", " ", "P", " ", "t", " ", "z"}], "S"]}], "+", 
    FractionBox[
     RowBox[{"P", " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "C36"}], "-", 
        RowBox[{"C13", " ", "t"}], "+", 
        RowBox[{"C23", " ", "t"}], "+", 
        RowBox[{"2", " ", "C36", " ", 
         RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}], "S"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"C35", " ", "P", " ", "r"}], "S"], "+", 
    FractionBox[
     RowBox[{"C35", " ", "P", " ", "r", " ", 
      SuperscriptBox["t", "2"]}], 
     RowBox[{"2", " ", "S"}]], "+", 
    FractionBox[
     RowBox[{"C33", " ", "P", " ", "z"}], "S"]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["remark ",
  FontFamily->"Courier"],
 "(-C13 +C23) t   ",
 StyleBox["implies multiplicity of the solution so this implies a new \
constitutive compatibility condition",
  FontFamily->"Courier"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cccc", " ", "=", " ", 
  RowBox[{"C23", " ", "\[Rule]", " ", "C13"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"General", "::", "\<\"spell1\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Possible spelling error: new symbol name \\\"\\!\\(cccc\\)\
\\\" is similar to existing symbol \\\"\\!\\(ccc\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
 RowBox[{"C23", "\[Rule]", "C13"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eps", " ", "=", " ", 
  RowBox[{"eps", " ", "/.", " ", "cccc"}]}], "\[IndentingNewLine]", 
 RowBox[{"u", " ", "=", " ", 
  RowBox[{"u", " ", "/.", " ", "cccc"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"C13", " ", "P"}], "S"], ",", 
     FractionBox[
      RowBox[{"C36", " ", "P"}], "S"], ",", 
     FractionBox[
      RowBox[{"C35", " ", "P"}], "S"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"C36", " ", "P"}], "S"], ",", 
     FractionBox[
      RowBox[{"C13", " ", "P"}], "S"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"C35", " ", "P"}], "S"], ",", "0", ",", 
     FractionBox[
      RowBox[{"C33", " ", "P"}], "S"]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"C13", " ", "P", " ", "r"}], "S"], "+", 
    FractionBox[
     RowBox[{"C35", " ", "P", " ", "z"}], "S"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"C35", " ", "P", " ", "t", " ", "z"}], "S"]}], "+", 
    FractionBox[
     RowBox[{"P", " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "C36"}], "+", 
        RowBox[{"2", " ", "C36", " ", 
         RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}], "S"]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"C35", " ", "P", " ", "r"}], "S"], "+", 
    FractionBox[
     RowBox[{"C35", " ", "P", " ", "r", " ", 
      SuperscriptBox["t", "2"]}], 
     RowBox[{"2", " ", "S"}]], "+", 
    FractionBox[
     RowBox[{"C33", " ", "P", " ", "z"}], "S"]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[" "], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1170, 769},
WindowMargins->{{Automatic, 20}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 738, 13, 291, "Text"],
Cell[CellGroupData[{
Cell[1331, 38, 118, 3, 73, "Section"],
Cell[CellGroupData[{
Cell[1474, 45, 291, 8, 55, "Input"],
Cell[1768, 55, 72, 0, 31, "Output"]
}, Open  ]],
Cell[1855, 58, 189, 3, 77, "Input"],
Cell[CellGroupData[{
Cell[2069, 65, 87, 1, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2181, 70, 139, 3, 32, "Input"],
Cell[2323, 75, 98, 2, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2470, 83, 121, 2, 39, "Subsection"],
Cell[CellGroupData[{
Cell[2616, 89, 401, 13, 32, "Input"],
Cell[3020, 104, 244, 9, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3301, 118, 3409, 94, 231, "Input"],
Cell[6713, 214, 714, 26, 88, "Output"],
Cell[7430, 242, 445, 16, 90, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7924, 264, 102, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[8051, 269, 102, 2, 27, "Input"],
Cell[8156, 273, 58, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8251, 279, 99, 2, 27, "Input"],
Cell[8353, 283, 631, 22, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9021, 310, 113, 2, 27, "Input"],
Cell[9137, 314, 927, 29, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10113, 349, 237, 7, 38, "Subsection"],
Cell[CellGroupData[{
Cell[10375, 360, 105, 2, 27, "Input"],
Cell[10483, 364, 386, 8, 20, "Message"],
Cell[10872, 374, 60, 1, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10969, 380, 199, 4, 43, "Input"],
Cell[11171, 386, 631, 22, 44, "Output"],
Cell[11805, 410, 845, 27, 46, "Output"]
}, Open  ]],
Cell[12665, 440, 27, 0, 27, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

